

define('js/namespace',[],function() {
    /**@type {!Object}*/
    var noProto = {};

    /**
        A Namespace contains the bindings currenlty defined in the runtime
        @constructor
        @template T 
        ^the type of values stored in the namespace

        @param {!Object.<string, T>} initialBindings
    */
    function Namespace(initialBindings) {
      if (typeof initialBindings !== "object") {
          throw new Error("Non-object " + initialBindings + " given to Namespace constructor");
      }
      /**@type {!Object.<string, T>}*/
      this.bindings = initialBindings;

      /**@type {T}*/
      this.proto = noProto;
    }

      /**
        Merges this namesspace with another
        @param {!Namespace.<T>} other

        @return {!Namespace.<T>} A namespace that is the result of merging this namespace with the other namespace
      */
      Namespace.prototype.merge = function(other) {
          var combined = Object.create(this.bindings);
          for (var k in other.bindings) {
            combined[k] = other.bindings[k];
          }
          var newNamespace = new Namespace(combined);
          if (other.proto !== noProto) {
            newNamespace.proto = other.proto;
          }
          else {
            newNamespace.proto = this.proto;
          }
          return newNamespace;
      };

      /**
        Gets the value of the specified binding with key 'key'
        Throws an error if binding not bound

        @param {string} key the key to look up
        @return {T} 
      */
      Namespace.prototype.get = function(key) {
          if (key === "__proto__") {
            if (this.proto === noProto) {
                throw new Error("Looked up __proto__, not bound in namespace");
            }
            return this.proto;
          }
          else {
            if (!(key in this.bindings)) {
                throw new Error("Looked up " + key + ", not bound in namespace");
            }
            return this.bindings[key];
          }
      };

      /**
        Sets the value of the specified binding with key 'key'

        @param {string} key the key to bind
        @param {T} value the value to set
        @return {!Namespace.<T>} the updated namespace
      */
      Namespace.prototype.set = function(key, value) {
          if (key === "__proto__") {
            var newNamespace = new Namespace(this.bindings);
            newNamespace.proto = value;
            return newNamespace;
          } 
          else {
            var o = Object.create(null);
            o[key] = value;
            return this.merge(new Namespace(o));
          }
      };

      /**
        Checks whether the namespace has 'key' bound 

        @param {string} key the key to check
        @return {boolean} whether or not key is bound
      */
      Namespace.prototype.hasBinding = function(key) {
          if (key === "__proto__") {
            return this.proto !== noProto;
          }
          else {
            return key in this.bindings;
          }
      };

      /**
        Gives an array of all names bound

        @return {Array.<string>}
      */
      Namespace.prototype.getNames = function() {
        var keys = [];
        if (this.proto !== noProto) { keys.push("__proto__"); }
        for (var key in this.bindings) {
          keys.push(key);
        }
        return keys;
      };

    var makeNamespace = function(bindingsObj) {
      var bindings = Object.create(null);
      Object.keys(bindingsObj).forEach(function(k) {
          bindings[k] = bindingsObj[k];
      });
      return new Namespace(bindings);
    }
    
    return {
        namespace: makeNamespace,
        Namespace: Namespace
      };
});

// Scheme numbers.

//var jsnums = {};


// The numeric tower has the following levels:
//     integers
//     rationals
//     floats
//     complex numbers
//
// with the representations:
//     integers: fixnum or BigInteger [level=0]
//     rationals: Rational [level=1]
//     floats: FloatPoint [level=2]
//     complex numbers: Complex [level=3]

// We try to stick with the unboxed fixnum representation for
// integers, since that's what scheme programs commonly deal with, and
// we want that common type to be lightweight.


// A boxed-scheme-number is either BigInteger, Rational, FloatPoint, or Complex.
// An integer-scheme-number is either fixnum or BigInteger.


define('js/js-numbers',[],function() {
    
    // Abbreviation
    var Numbers = {};
    //var Numbers = jsnums;


    // makeNumericBinop: (fixnum fixnum -> any) (scheme-number scheme-number -> any) -> (scheme-number scheme-number) X
    // Creates a binary function that works either on fixnums or boxnums.
    // Applies the appropriate binary function, ensuring that both scheme numbers are
    // lifted to the same level.
    var makeNumericBinop = function(onFixnums, onBoxednums, options) {
	options = options || {};
	return function(x, y) {
	    if (options.isXSpecialCase && options.isXSpecialCase(x))
		return options.onXSpecialCase(x, y);
	    if (options.isYSpecialCase && options.isYSpecialCase(y))
		return options.onYSpecialCase(x, y);

	    if (typeof(x) === 'number' &&
		typeof(y) === 'number') {
		return onFixnums(x, y);
	    }
	    if (typeof(x) === 'number') {
		x = liftFixnumInteger(x, y);
	    }
	    if (typeof(y) === 'number') {
		y = liftFixnumInteger(y, x);
	    }

	    if (x.level < y.level) x = x.liftTo(y);
	    if (y.level < x.level) y = y.liftTo(x);
	    return onBoxednums(x, y);
	};
    };
    
    
    // fromFixnum: fixnum -> scheme-number
    var fromFixnum = function(x) {
	if (isNaN(x) || (! isFinite(x))) {
	    return FloatPoint.makeInstance(x);
	}
	var nf = Math.floor(x);
	if (nf === x) {
            if (isOverflow(nf)) {
		return makeBignum(expandExponent(x+''));
            } else {
		return nf;
	    }
	} else {
            return FloatPoint.makeInstance(x);
	}
    };

    var expandExponent = function(s) {
	var match = s.match(scientificPattern), mantissaChunks, exponent;
	if (match) {
	    mantissaChunks = match[1].match(/^([^.]*)(.*)$/);
	    exponent = Number(match[2]);

	    if (mantissaChunks[2].length === 0) {
		return mantissaChunks[1] + zfill(exponent);
	    }

	    if (exponent >= mantissaChunks[2].length - 1) {
		return (mantissaChunks[1] + 
			mantissaChunks[2].substring(1) + 
			zfill(exponent - (mantissaChunks[2].length - 1)));
	    } else {
		return (mantissaChunks[1] +
			mantissaChunks[2].substring(1, 1+exponent));
	    }
	} else {
	    return s;
	}
    };

    // zfill: integer -> string
    // builds a string of "0"'s of length n.
    var zfill = function(n) {
	var buffer = [];
	buffer.length = n;
	for (var i = 0; i < n; i++) {
	    buffer[i] = '0';
	}
	return buffer.join('');
    };
    

    
    // liftFixnumInteger: fixnum-integer boxed-scheme-number -> boxed-scheme-number
    // Lifts up fixnum integers to a boxed type.
    var liftFixnumInteger = function(x, other) {
	switch(other.level) {
	case 0: // BigInteger
	    return makeBignum(x);
	case 1: // Rational
	    return new Rational(x, 1);
	case 2: // FloatPoint
	    return new FloatPoint(x);
	case 3: // Complex
	    return new Complex(x, 0);
	default:
	    throwRuntimeError("IMPOSSIBLE: cannot lift fixnum integer to " + other.toString(), x, other);
	}
    };
    
    
    // throwRuntimeError: string (scheme-number | undefined) (scheme-number | undefined) -> void
    // Throws a runtime error with the given message string.
    var throwRuntimeError = function(msg, x, y) {
	Numbers['onThrowRuntimeError'](msg, x, y);
    };



    // onThrowRuntimeError: string (scheme-number | undefined) (scheme-number | undefined) -> void
    // By default, will throw a new Error with the given message.
    // Override Numbers['onThrowRuntimeError'] if you need to do something special.
    var onThrowRuntimeError = function(msg, x, y) {
	throw new Error(msg);
    };


    // isSchemeNumber: any -> boolean
    // Returns true if the thing is a scheme number.
    var isSchemeNumber = function(thing) {
	return (typeof(thing) === 'number'
		|| (thing instanceof Rational ||
		    thing instanceof FloatPoint ||
		    thing instanceof Complex ||
		    thing instanceof BigInteger));
    };


    // isRational: scheme-number -> boolean
    var isRational = function(n) {
	return (typeof(n) === 'number' ||
		(isSchemeNumber(n) && n.isRational()));
    };

    // isReal: scheme-number -> boolean
    var isReal = function(n) {
	return (typeof(n) === 'number' ||
		(isSchemeNumber(n) && n.isReal()));
    };

    // isExact: scheme-number -> boolean
    var isExact = function(n) {
	return (typeof(n) === 'number' || 
		(isSchemeNumber(n) && n.isExact()));
    };

    // isExact: scheme-number -> boolean
    var isInexact = function(n) {
	if (typeof(n) === 'number') {
	    return false;
	} else {
	    return (isSchemeNumber(n) && n.isInexact());
	}
    };

    // isInteger: scheme-number -> boolean
    var isInteger = function(n) {
	return (typeof(n) === 'number' ||
		(isSchemeNumber(n) && n.isInteger()));
    };

    // isExactInteger: scheme-number -> boolean
    var isExactInteger = function(n) {
	return (typeof(n) === 'number' ||
		(isSchemeNumber(n) && 
		 n.isInteger() && 
		 n.isExact()));
    }



    // toFixnum: scheme-number -> javascript-number
    var toFixnum = function(n) {
	if (typeof(n) === 'number')
	    return n;
	return n.toFixnum();
    };

    // toExact: scheme-number -> scheme-number
    var toExact = function(n) {
	if (typeof(n) === 'number')
	    return n;
	return n.toExact();
    };


    // toExact: scheme-number -> scheme-number
    var toInexact = function(n) {
	if (typeof(n) === 'number')
	    return FloatPoint.makeInstance(n);
	return n.toInexact();
    };



    //////////////////////////////////////////////////////////////////////


    // add: scheme-number scheme-number -> scheme-number
    var add = function(x, y) {
        var sum;
        if (typeof(x) === 'number' && typeof(y) === 'number') {
            sum = x + y;
            if (isOverflow(sum)) {
		return (makeBignum(x)).add(makeBignum(y));
            }
        }
        if (x instanceof FloatPoint && y instanceof FloatPoint) {
            return x.add(y);
        }
        return addSlow(x, y);        
    };

    var addSlow = makeNumericBinop(
	function(x, y) {
	    var sum = x + y;
	    if (isOverflow(sum)) {
		return (makeBignum(x)).add(makeBignum(y));
	    } else {
		return sum;
	    }
	},
	function(x, y) {
	    return x.add(y);
	},
	{isXSpecialCase: function(x) { 
	    return isExactInteger(x) && _integerIsZero(x) },
	 onXSpecialCase: function(x, y) { return y; },
	 isYSpecialCase: function(y) { 
	     return isExactInteger(y) && _integerIsZero(y) },
	 onYSpecialCase: function(x, y) { return x; }
	});


    // subtract: scheme-number scheme-number -> scheme-number
    var subtract = makeNumericBinop(
	function(x, y) {
	    var diff = x - y;
	    if (isOverflow(diff)) {
		return (makeBignum(x)).subtract(makeBignum(y));
	    } else {
		return diff;
	    }
	},
	function(x, y) {
	    return x.subtract(y);
	},
	{isXSpecialCase: function(x) { 
	    return isExactInteger(x) && _integerIsZero(x) },
	 onXSpecialCase: function(x, y) { return negate(y); },
	 isYSpecialCase: function(y) { 
	     return isExactInteger(y) && _integerIsZero(y) },
	 onYSpecialCase: function(x, y) { return x; }
	});


    // mulitply: scheme-number scheme-number -> scheme-number
    var multiply = function(x, y) {
        var prod;
        if (typeof(x) === 'number' && typeof(y) === 'number') {
	    prod = x * y;
	    if (isOverflow(prod)) {
		return (makeBignum(x)).multiply(makeBignum(y));
            } else {
                return prod;
            }
        }
        if (x instanceof FloatPoint && y instanceof FloatPoint) {
            return x.multiply(y);
        }
        return multiplySlow(x, y);
    };
    var multiplySlow = makeNumericBinop(
	function(x, y) {
	    var prod = x * y;
	    if (isOverflow(prod)) {
		return (makeBignum(x)).multiply(makeBignum(y));
	    } else {
		return prod;
	    }
	},
	function(x, y) {
	    return x.multiply(y);
	},
	{isXSpecialCase: function(x) { 
	    return (isExactInteger(x) && 
		    (_integerIsZero(x) || _integerIsOne(x) || _integerIsNegativeOne(x))) },
	 onXSpecialCase: function(x, y) { 
	     if (_integerIsZero(x))
		 return 0;
	     if (_integerIsOne(x))
		 return y;
	     if (_integerIsNegativeOne(x))
		 return negate(y);
	 },
	 isYSpecialCase: function(y) { 
	     return (isExactInteger(y) && 
		     (_integerIsZero(y) || _integerIsOne(y) || _integerIsNegativeOne(y)))},
	 onYSpecialCase: function(x, y) { 
	     if (_integerIsZero(y))
		 return 0;
	     if (_integerIsOne(y))
		 return x;
	     if (_integerIsNegativeOne(y)) 
		 return negate(x);
	 }
	});

    
    // divide: scheme-number scheme-number -> scheme-number
    var divide = makeNumericBinop(
	function(x, y) {
	    if (_integerIsZero(y))
		throwRuntimeError("/: division by zero", x, y);
	    var div = x / y;
	    if (isOverflow(div)) {
		return (makeBignum(x)).divide(makeBignum(y));
	    } else if (Math.floor(div) !== div) {
		return Rational.makeInstance(x, y);
	    } else {
		return div;
	    }
	},
	function(x, y) {
	    return x.divide(y);
	},
	{ isXSpecialCase: function(x) {
	    return (eqv(x, 0));
	},
	  onXSpecialCase: function(x, y) {
	      if (eqv(y, 0)) {
		  throwRuntimeError("/: division by zero", x, y);
	      }
	      return 0;
	  },
	  isYSpecialCase: function(y) { 
	    return (eqv(y, 0)); },
	  onYSpecialCase: function(x, y) {
	      throwRuntimeError("/: division by zero", x, y);
	  }
	});
    
    
    // equals: scheme-number scheme-number -> boolean
    var equals = makeNumericBinop(
	function(x, y) {
	    return x === y;
	},
	function(x, y) {
	    return x.equals(y);
	});


    // eqv: scheme-number scheme-number -> boolean
    var eqv = function(x, y) {
	if (x === y)
	    return true;
	if (typeof(x) === 'number' && typeof(y) === 'number')
	    return x === y;
	if (x === NEGATIVE_ZERO || y === NEGATIVE_ZERO)
	    return x === y;
	if (x instanceof Complex || y instanceof Complex) {
	    return (eqv(realPart(x), realPart(y)) &&
		    eqv(imaginaryPart(x), imaginaryPart(y)));
	}
	var ex = isExact(x), ey = isExact(y);
	return (((ex && ey) || (!ex && !ey)) && equals(x, y));
    };

    // approxEqual: scheme-number scheme-number scheme-number -> boolean
    var approxEquals = function(x, y, delta) {
	return lessThan(abs(subtract(x, y)),
                        delta);
    };

    // greaterThanOrEqual: scheme-number scheme-number -> boolean
    var greaterThanOrEqual = makeNumericBinop(
	function(x, y) {
	    return x >= y;
	},
	function(x, y) {
	    if (!(isReal(x) && isReal(y)))
		throwRuntimeError(
		    ">=: couldn't be applied to complex number", x, y);
	    return x.greaterThanOrEqual(y);
	});


    // lessThanOrEqual: scheme-number scheme-number -> boolean
    var lessThanOrEqual = makeNumericBinop(
	function(x, y){

	    return x <= y;
	},
	function(x, y) {
	    if (!(isReal(x) && isReal(y)))
		throwRuntimeError("<=: couldn't be applied to complex number", x, y);
	    return x.lessThanOrEqual(y);
	});


    // greaterThan: scheme-number scheme-number -> boolean
    var greaterThan = makeNumericBinop(
	function(x, y){
	    return x > y;
	},
	function(x, y) {
	    if (!(isReal(x) && isReal(y)))
		throwRuntimeError(">: couldn't be applied to complex number", x, y);
	    return x.greaterThan(y);
	});


    // lessThan: scheme-number scheme-number -> boolean
    var lessThan = makeNumericBinop(
	function(x, y){

	    return x < y;
	},
	function(x, y) {
	    if (!(isReal(x) && isReal(y)))
		throwRuntimeError("<: couldn't be applied to complex number", x, y);
	    return x.lessThan(y);
	});



    // expt: scheme-number scheme-number -> scheme-number
    var expt = (function() {
	var _expt = makeNumericBinop(
	    function(x, y){
		var pow = Math.pow(x, y);
		if (isOverflow(pow)) {
		    return (makeBignum(x)).expt(makeBignum(y));
		} else {
		    return pow;
		}
	    },
	    function(x, y) {
		if (equals(y, 0)) {
		    return add(y, 1);
		} else {
		    return x.expt(y);
		}
	    });
	return function(x, y) {
	    if (equals(y, 0)) 
		return add(y, 1);
	    if (isReal(y) && lessThan(y, 0)) {
		return _expt(divide(1, x), negate(y));
	    }
	    return _expt(x, y);
	};
    })();


    // exp: scheme-number -> scheme-number
    var exp = function(n) {
	if ( eqv(n, 0) ) {
		return 1;
	}
	if (typeof(n) === 'number') {
	    return FloatPoint.makeInstance(Math.exp(n));
	}
	return n.exp();
    };


    // modulo: scheme-number scheme-number -> scheme-number
    var modulo = function(m, n) {
	if (! isInteger(m)) {
	    throwRuntimeError('modulo: the first argument '
			      + m + " is not an integer.", m, n);
	}
	if (! isInteger(n)) {
	    throwRuntimeError('modulo: the second argument '
			      + n + " is not an integer.", m, n);
	}
	var result;
	if (typeof(m) === 'number') {
	    result = m % n;
	    if (n < 0) {
		if (result <= 0)
		    return result;
		else
		    return result + n;
	    } else {
		if (result < 0)
		    return result + n;
		else
		    return result;
	    }
	}
	result = _integerModulo(floor(m), floor(n));
	// The sign of the result should match the sign of n.
	if (lessThan(n, 0)) {
	    if (lessThanOrEqual(result, 0)) {
		return result;
	    }
	    return add(result, n);

	} else {
	    if (lessThan(result, 0)) {
		return add(result, n);
	    }
	    return result;
	}
    };



    // numerator: scheme-number -> scheme-number
    var numerator = function(n) {
	if (typeof(n) === 'number')
	    return n;
	return n.numerator();
    };


    // denominator: scheme-number -> scheme-number
    var denominator = function(n) {
	if (typeof(n) === 'number')
	    return 1;
	return n.denominator();
    };

    // sqrt: scheme-number -> scheme-number
    var sqrt = function(n) {
	if (typeof(n) === 'number') {
	    if (n >= 0) {
		var result = Math.sqrt(n);
		if (Math.floor(result) === result) {
		    return result;
		} else {
		    return FloatPoint.makeInstance(result);
		}
	    } else {
		return (Complex.makeInstance(0, sqrt(-n)));
	    }
	}
	return n.sqrt();
    };

    // abs: scheme-number -> scheme-number
    var abs = function(n) {
	if (typeof(n) === 'number') {
	    return Math.abs(n);
	}
	return n.abs();
    };

    // floor: scheme-number -> scheme-number
    var floor = function(n) {
	if (typeof(n) === 'number')
	    return Math.floor(n);
	return n.floor();
    };

    // ceiling: scheme-number -> scheme-number
    var ceiling = function(n) {
	if (typeof(n) === 'number')
	    return Math.ceil(n);
	return n.ceiling();
    };

    // conjugate: scheme-number -> scheme-number
    var conjugate = function(n) {
	if (typeof(n) === 'number')
	    return n;
	return n.conjugate();
    };

    // magnitude: scheme-number -> scheme-number
    var magnitude = function(n) {
	if (typeof(n) === 'number')
	    return Math.abs(n);
	return n.magnitude();
    };


    // log: scheme-number -> scheme-number
    var log = function(n) {
	if ( eqv(n, 1) ) {
		return 0;
	}
	if (typeof(n) === 'number') {
	    return FloatPoint.makeInstance(Math.log(n));
	}
	return n.log();
    };

    // angle: scheme-number -> scheme-number
    var angle = function(n) {
	if (typeof(n) === 'number') {
	    if (n > 0)
		return 0;
	    else
		return FloatPoint.pi;
	}
	return n.angle();
    };

    // tan: scheme-number -> scheme-number
    var tan = function(n) {
	if (eqv(n, 0)) { return 0; }
	if (typeof(n) === 'number') {
	    return FloatPoint.makeInstance(Math.tan(n));
	}
	return n.tan();
    };

    // atan: scheme-number -> scheme-number
    var atan = function(n) {
	if (eqv(n, 0)) { return 0; }
	if (typeof(n) === 'number') {
	    return FloatPoint.makeInstance(Math.atan(n));
	}
	return n.atan();
    };

    // cos: scheme-number -> scheme-number
    var cos = function(n) {
	if (eqv(n, 0)) { return 1; }
	if (typeof(n) === 'number') {
	    return FloatPoint.makeInstance(Math.cos(n));
	}
	return n.cos();
    };

    // sin: scheme-number -> scheme-number
    var sin = function(n) {
	if (eqv(n, 0)) { return 0; }
	if (typeof(n) === 'number') {
	    return FloatPoint.makeInstance(Math.sin(n));
	}
	return n.sin();
    };

    // acos: scheme-number -> scheme-number
    var acos = function(n) {
	if (eqv(n, 1)) { return 0; }
	if (typeof(n) === 'number') {
	    return FloatPoint.makeInstance(Math.acos(n));
	}
	return n.acos();
    };

    // asin: scheme-number -> scheme-number
    var asin = function(n) {
        if (eqv(n, 0)) { return 0; }
	if (typeof(n) === 'number') {
	    return FloatPoint.makeInstance(Math.asin(n));
	}
	return n.asin();
    };

    // imaginaryPart: scheme-number -> scheme-number
    var imaginaryPart = function(n) {
	if (typeof(n) === 'number') {
	    return 0;
	}
	return n.imaginaryPart();
    };

    // realPart: scheme-number -> scheme-number
    var realPart = function(n) {
	if (typeof(n) === 'number') {
	    return n;
	}
	return n.realPart();
    };

    // round: scheme-number -> scheme-number
    var round = function(n) {
	if (typeof(n) === 'number') {
	    return n;
	}
	return n.round();
    };



    // sqr: scheme-number -> scheme-number
    var sqr = function(x) {
	return multiply(x, x);
    };


    // integerSqrt: scheme-number -> scheme-number
    var integerSqrt = function(x) {
	if (! isInteger(x)) {
	    throwRuntimeError('integer-sqrt: the argument ' + x.toString() +
			      " is not an integer.", x);
	}
	if (typeof (x) === 'number') {
	    if(x < 0) {
	        return Complex.makeInstance(0,
					    Math.floor(Math.sqrt(-x)))
	    } else {
		return Math.floor(Math.sqrt(x));
	    }
	}
	return x.integerSqrt();
    };


    // gcd: scheme-number [scheme-number ...] -> scheme-number
    var gcd = function(first, rest) {
	if (! isInteger(first)) {
	    throwRuntimeError('gcd: the argument ' + first.toString() +
			      " is not an integer.", first);
	}
	var a = abs(first), t, b;
	for(var i = 0; i < rest.length; i++) {
	    b = abs(rest[i]);	
	    if (! isInteger(b)) {
		throwRuntimeError('gcd: the argument ' + b.toString() +
				  " is not an integer.", b);
	    }
	    while (! _integerIsZero(b)) {
		t = a;
		a = b;
		b = _integerModulo(t, b);
	    }
	}
	return a;
    };

    // lcm: scheme-number [scheme-number ...] -> scheme-number
    var lcm = function(first, rest) {
	if (! isInteger(first)) {
	    throwRuntimeError('lcm: the argument ' + first.toString() +
			      " is not an integer.", first);
	}
	var result = abs(first);
	if (_integerIsZero(result)) { return 0; }
	for (var i = 0; i < rest.length; i++) {
	    if (! isInteger(rest[i])) {
		throwRuntimeError('lcm: the argument ' + rest[i].toString() +
				  " is not an integer.", rest[i]);
	    }
	    var divisor = _integerGcd(result, rest[i]);
	    if (_integerIsZero(divisor)) {
		return 0;
	    }
	    result = divide(multiply(result, rest[i]), divisor);
	}
	return result;
    };
    

    var quotient = function(x, y) {
 	if (! isInteger(x)) {
	    throwRuntimeError('quotient: the first argument ' + x.toString() +
			      " is not an integer.", x);
	}
	if (! isInteger(y)) {
	    throwRuntimeError('quotient: the second argument ' + y.toString() +
			      " is not an integer.", y);
	}
	return _integerQuotient(x, y);
    };

    
    var remainder = function(x, y) {
	if (! isInteger(x)) {
	    throwRuntimeError('remainder: the first argument ' + x.toString() +
			      " is not an integer.", x);
	}
	if (! isInteger(y)) {
	    throwRuntimeError('remainder: the second argument ' + y.toString() +
			      " is not an integer.", y);
	}
	return _integerRemainder(x, y);
    };


    // Implementation of the hyperbolic functions
    // http://en.wikipedia.org/wiki/Hyperbolic_cosine
    var cosh = function(x) {
	if (eqv(x, 0)) {
	    return FloatPoint.makeInstance(1.0);
	}
	return divide(add(exp(x), exp(negate(x))),
		      2);
    };
	
    var sinh = function(x) {
	return divide(subtract(exp(x), exp(negate(x))),
		      2);
    };


        
    var makeComplexPolar = function(r, theta) {
	// special case: if theta is zero, just return
	// the scalar.
	if (eqv(theta, 0)) {
	    return r;
	}
	return Complex.makeInstance(multiply(r, cos(theta)),
				    multiply(r, sin(theta)));
    };



    //////////////////////////////////////////////////////////////////////

    // Helpers


    // IsFinite: scheme-number -> boolean
    // Returns true if the scheme number is finite or not.
    var isSchemeNumberFinite = function(n) {
	if (typeof(n) === 'number') {
	    return isFinite(n);
	} else {
	    return n.isFinite();
	}
    };

    // isOverflow: javascript-number -> boolean
    // Returns true if we consider the number an overflow.
    var MIN_FIXNUM = -(9e15);
    var MAX_FIXNUM = (9e15);
    var isOverflow = function(n) {
	return (n < MIN_FIXNUM ||  MAX_FIXNUM < n);
    };


    // negate: scheme-number -> scheme-number
    // multiplies a number times -1.
    var negate = function(n) {
	if (typeof(n) === 'number') {
	    return -n;
	}
	return n.negate();
    };


    // halve: scheme-number -> scheme-number
    // Divide a number by 2.
    var halve = function(n) {
	return divide(n, 2);
    };


    // timesI: scheme-number scheme-number
    // multiplies a number times i.
    var timesI = function(x) {
	return multiply(x, plusI);
    };


    // fastExpt: computes n^k by squaring.
    // n^k = (n^2)^(k/2)
    // Assumes k is non-negative integer.
    var fastExpt = function(n, k) {
	var acc = 1;
	while (true) {
	    if (_integerIsZero(k)) {
		return acc;
	    }
	    if (equals(modulo(k, 2), 0)) {
		n = multiply(n, n);
		k = divide(k, 2);
	    } else {
		acc = multiply(acc, n);
		k = subtract(k, 1);
	    }
	}
    };



    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////


    // Integer operations
    // Integers are either represented as fixnums or as BigIntegers.

    // makeIntegerBinop: (fixnum fixnum -> X) (BigInteger BigInteger -> X) -> X
    // Helper to collect the common logic for coersing integer fixnums or bignums to a
    // common type before doing an operation.
    var makeIntegerBinop = function(onFixnums, onBignums, options) {
	options = options || {};
	return (function(m, n) {
	    if (m instanceof Rational) {
		m = numerator(m);
	    } else if (m instanceof Complex) {
		m = realPart(m);
	    }

	    if (n instanceof Rational) {
		n = numerator(n);
	    }else if (n instanceof Complex) {
		n = realPart(n);
	    }

	    if (typeof(m) === 'number' && typeof(n) === 'number') {
		var result = onFixnums(m, n);
		if (! isOverflow(result) ||
		    (options.ignoreOverflow)) {
		    return result;
		}
	    }
	    if (m instanceof FloatPoint || n instanceof FloatPoint) {
		if (options.doNotCoerseToFloating) {
		    return onFixnums(toFixnum(m), toFixnum(n));
		}
		else {
		    return FloatPoint.makeInstance(
			onFixnums(toFixnum(m), toFixnum(n)));
		}
	    }
	    if (typeof(m) === 'number') {
		m = makeBignum(m);
	    }
	    if (typeof(n) === 'number') {
		n = makeBignum(n);
	    }
	    return onBignums(m, n);
	});
    };


    var makeIntegerUnOp = function(onFixnums, onBignums, options) {
	options = options || {};
	return (function(m) {
	    if (m instanceof Rational) {
		m = numerator(m);
	    } else if (m instanceof Complex) {
		m = realPart(m);
	    }

	    if (typeof(m) === 'number') {
		var result = onFixnums(m);
		if (! isOverflow(result) ||
		    (options.ignoreOverflow)) {
		    return result;
		}
	    }
	    if (m instanceof FloatPoint) {
		return onFixnums(toFixnum(m));
	    }
	    if (typeof(m) === 'number') {
		m = makeBignum(m);
	    }
	    return onBignums(m);
	});
    };



    // _integerModulo: integer-scheme-number integer-scheme-number -> integer-scheme-number
    var _integerModulo = makeIntegerBinop(
	function(m, n) {
	    return m % n;
	},
	function(m, n) {
	    return bnMod.call(m, n);
	});


    // _integerGcd: integer-scheme-number integer-scheme-number -> integer-scheme-number
    var _integerGcd = makeIntegerBinop(
	function(a, b) {
	    var t;
	    while (b !== 0) {
		t = a;
		a = b;
		b = t % b;
	    }
	    return a;
	},
	function(m, n) {
	    return bnGCD.call(m, n);
	});


    // _integerIsZero: integer-scheme-number -> boolean
    // Returns true if the number is zero.
    var _integerIsZero = makeIntegerUnOp(
	function(n){
	    return n === 0;
	},
	function(n) {
	    return bnEquals.call(n, BigInteger.ZERO);
	}
    );


    // _integerIsOne: integer-scheme-number -> boolean
    var _integerIsOne = makeIntegerUnOp(
	function(n) {
	    return n === 1;
	},
	function(n) {
	    return bnEquals.call(n, BigInteger.ONE);
	});
    

 
    // _integerIsNegativeOne: integer-scheme-number -> boolean
    var _integerIsNegativeOne = makeIntegerUnOp(
	function(n) {
	    return n === -1;
	},
	function(n) {
	    return bnEquals.call(n, BigInteger.NEGATIVE_ONE);
	});
    


    // _integerAdd: integer-scheme-number integer-scheme-number -> integer-scheme-number
    var _integerAdd = makeIntegerBinop(
	function(m, n) {
	    return m + n;
	},
	function(m, n) {
	    return bnAdd.call(m, n);
	});

    // _integerSubtract: integer-scheme-number integer-scheme-number -> integer-scheme-number
    var _integerSubtract = makeIntegerBinop(
	function(m, n) {
	    return m - n;
	},
	function(m, n) {
	    return bnSubtract.call(m, n);
	});

    // _integerMultiply: integer-scheme-number integer-scheme-number -> integer-scheme-number
    var _integerMultiply = makeIntegerBinop(
	function(m, n) {
	    return m * n;
	},
	function(m, n) {
	    return bnMultiply.call(m, n);
	});

    //_integerQuotient: integer-scheme-number integer-scheme-number -> integer-scheme-number
    var _integerQuotient = makeIntegerBinop(
	function(m, n) {
	    return ((m - (m % n))/ n);
	},
	function(m, n) {
            return bnDivide.call(m, n);
	});

    var _integerRemainder = makeIntegerBinop(
	function(m, n) {
	    return m % n;
	},
	function(m, n) {
	    return bnRemainder.call(m, n);
	});


    // _integerDivideToFixnum: integer-scheme-number integer-scheme-number -> fixnum
    var _integerDivideToFixnum = makeIntegerBinop(
	function(m, n) {
	    return m / n;
	},
	function(m, n) {
	    return toFixnum(m) / toFixnum(n);
	},
	{ignoreOverflow: true,
	 doNotCoerseToFloating: true});


    // _integerEquals: integer-scheme-number integer-scheme-number -> boolean
    var _integerEquals = makeIntegerBinop(
	function(m, n) {
	    return m === n;
	},
	function(m, n) {
	    return bnEquals.call(m, n);
	},
	{doNotCoerseToFloating: true});

    // _integerGreaterThan: integer-scheme-number integer-scheme-number -> boolean
    var _integerGreaterThan = makeIntegerBinop(
	function(m, n) {
	    return m > n;
	},
	function(m, n) {
	    return bnCompareTo.call(m, n) > 0;
	},
	{doNotCoerseToFloating: true});

    // _integerLessThan: integer-scheme-number integer-scheme-number -> boolean
    var _integerLessThan = makeIntegerBinop(
	function(m, n) {
	    return m < n;
	},
	function(m, n) {
	    return bnCompareTo.call(m, n) < 0;
	},
	{doNotCoerseToFloating: true});

    // _integerGreaterThanOrEqual: integer-scheme-number integer-scheme-number -> boolean
    var _integerGreaterThanOrEqual = makeIntegerBinop(
	function(m, n) {
	    return m >= n;
	},
	function(m, n) {
	    return bnCompareTo.call(m, n) >= 0;
	},
	{doNotCoerseToFloating: true});

    // _integerLessThanOrEqual: integer-scheme-number integer-scheme-number -> boolean
    var _integerLessThanOrEqual = makeIntegerBinop(
	function(m, n) {
	    return m <= n;
	},
	function(m, n) {
	    return bnCompareTo.call(m, n) <= 0;
	},
	{doNotCoerseToFloating: true});



    //////////////////////////////////////////////////////////////////////
    // The boxed number types are expected to implement the following
    // interface.
    //
    // toString: -> string

    // level: number

    // liftTo: scheme-number -> scheme-number

    // isFinite: -> boolean

    // isInteger: -> boolean
    // Produce true if this number can be coersed into an integer.

    // isRational: -> boolean
    // Produce true if the number is rational.

    // isReal: -> boolean
    // Produce true if the number is real.

    // isExact: -> boolean
    // Produce true if the number is exact

    // toExact: -> scheme-number
    // Produce an exact number.

    // toFixnum: -> javascript-number
    // Produce a javascript number.

    // greaterThan: scheme-number -> boolean
    // Compare against instance of the same type.

    // greaterThanOrEqual: scheme-number -> boolean
    // Compare against instance of the same type.

    // lessThan: scheme-number -> boolean
    // Compare against instance of the same type.

    // lessThanOrEqual: scheme-number -> boolean
    // Compare against instance of the same type.

    // add: scheme-number -> scheme-number
    // Add with an instance of the same type.

    // subtract: scheme-number -> scheme-number
    // Subtract with an instance of the same type.

    // multiply: scheme-number -> scheme-number
    // Multiply with an instance of the same type.

    // divide: scheme-number -> scheme-number
    // Divide with an instance of the same type.

    // numerator: -> scheme-number
    // Return the numerator.

    // denominator: -> scheme-number
    // Return the denominator.

    // integerSqrt: -> scheme-number
    // Produce the integer square root.

    // sqrt: -> scheme-number
    // Produce the square root.

    // abs: -> scheme-number
    // Produce the absolute value.

    // floor: -> scheme-number
    // Produce the floor.

    // ceiling: -> scheme-number
    // Produce the ceiling.

    // conjugate: -> scheme-number
    // Produce the conjugate.

    // magnitude: -> scheme-number
    // Produce the magnitude.

    // log: -> scheme-number
    // Produce the log.

    // angle: -> scheme-number
    // Produce the angle.

    // atan: -> scheme-number
    // Produce the arc tangent.

    // cos: -> scheme-number
    // Produce the cosine.

    // sin: -> scheme-number
    // Produce the sine.

    // expt: scheme-number -> scheme-number
    // Produce the power to the input.

    // exp: -> scheme-number
    // Produce e raised to the given power.

    // acos: -> scheme-number
    // Produce the arc cosine.

    // asin: -> scheme-number
    // Produce the arc sine.

    // imaginaryPart: -> scheme-number
    // Produce the imaginary part

    // realPart: -> scheme-number
    // Produce the real part.

    // round: -> scheme-number
    // Round to the nearest integer.

    // equals: scheme-number -> boolean
    // Produce true if the given number of the same type is equal.



    //////////////////////////////////////////////////////////////////////

    // Rationals


    var Rational = function(n, d) {
	this.n = n;
	this.d = d;
    };


    Rational.prototype.toString = function() {
	if (_integerIsOne(this.d)) {
	    return this.n.toString() + "";
	} else {
	    return this.n.toString() + "/" + this.d.toString();
	}
    };


    Rational.prototype.level = 1;


    Rational.prototype.liftTo = function(target) {
	if (target.level === 2)
	    return new FloatPoint(
		_integerDivideToFixnum(this.n, this.d));
	if (target.level === 3)
	    return new Complex(this, 0);
	return throwRuntimeError("invalid level of Number", this, target);
    };

    Rational.prototype.isFinite = function() {
	return true;
    };

    Rational.prototype.equals = function(other) {
	return (other instanceof Rational &&
		_integerEquals(this.n, other.n) &&
		_integerEquals(this.d, other.d));
    };



    Rational.prototype.isInteger = function() {
	return _integerIsOne(this.d);
    };

    Rational.prototype.isRational = function() {
        return true;
    };

    Rational.prototype.isReal = function() {
	return true;
    };


    Rational.prototype.add = function(other) {
	return Rational.makeInstance(_integerAdd(_integerMultiply(this.n, other.d),
						 _integerMultiply(this.d, other.n)),
				     _integerMultiply(this.d, other.d));
    };

    Rational.prototype.subtract = function(other) {
	return Rational.makeInstance(_integerSubtract(_integerMultiply(this.n, other.d),
						      _integerMultiply(this.d, other.n)),
				     _integerMultiply(this.d, other.d));
    };

    Rational.prototype.negate = function() { 
	return Rational.makeInstance(-this.n, this.d) 
    };

    Rational.prototype.multiply = function(other) {
	return Rational.makeInstance(_integerMultiply(this.n, other.n),
				     _integerMultiply(this.d, other.d));
    };

    Rational.prototype.divide = function(other) {
	if (_integerIsZero(this.d) || _integerIsZero(other.n)) {
	    throwRuntimeError("/: division by zero", this, other);
	}
	return Rational.makeInstance(_integerMultiply(this.n, other.d),
				     _integerMultiply(this.d, other.n));
    };


    Rational.prototype.toExact = function() {
	return this;
    };

    Rational.prototype.toInexact = function() {
	return FloatPoint.makeInstance(this.toFixnum());
    };


    Rational.prototype.isExact = function() {
        return true;
    };

    Rational.prototype.isInexact = function() {
        return false;
    };


    Rational.prototype.toFixnum = function() {
	return _integerDivideToFixnum(this.n, this.d);
    };

    Rational.prototype.numerator = function() {
	return this.n;
    };

    Rational.prototype.denominator = function() {
	return this.d;
    };

    Rational.prototype.greaterThan = function(other) {
	return _integerGreaterThan(_integerMultiply(this.n, other.d),
				   _integerMultiply(this.d, other.n));
    };

    Rational.prototype.greaterThanOrEqual = function(other) {
	return _integerGreaterThanOrEqual(_integerMultiply(this.n, other.d),
					  _integerMultiply(this.d, other.n));
    };

    Rational.prototype.lessThan = function(other) {
	return _integerLessThan(_integerMultiply(this.n, other.d),
				_integerMultiply(this.d, other.n));
    };

    Rational.prototype.lessThanOrEqual = function(other) {
	return _integerLessThanOrEqual(_integerMultiply(this.n, other.d),
				       _integerMultiply(this.d, other.n));
    };

    Rational.prototype.integerSqrt = function() {
	var result = sqrt(this);
	if (isRational(result)) {
	    return toExact(floor(result));
	} else if (isReal(result)) {
	    return toExact(floor(result));
	} else {
	    return Complex.makeInstance(toExact(floor(realPart(result))),
					toExact(floor(imaginaryPart(result))));
	}
    };


    Rational.prototype.sqrt = function() {
	if (_integerGreaterThanOrEqual(this.n,  0)) {
	    var newN = sqrt(this.n);
	    var newD = sqrt(this.d);
	    if (equals(floor(newN), newN) &&
		equals(floor(newD), newD)) {
		return Rational.makeInstance(newN, newD);
	    } else {
		return FloatPoint.makeInstance(_integerDivideToFixnum(newN, newD));
	    }
	} else {
	    var newN = sqrt(negate(this.n));
	    var newD = sqrt(this.d);
	    if (equals(floor(newN), newN) &&
		equals(floor(newD), newD)) {
		return Complex.makeInstance(
		    0,
		    Rational.makeInstance(newN, newD));
	    } else {
		return Complex.makeInstance(
		    0,
		    FloatPoint.makeInstance(_integerDivideToFixnum(newN, newD)));
	    }
	}
    };

    Rational.prototype.abs = function() {
	return Rational.makeInstance(abs(this.n),
				     this.d);
    };


    Rational.prototype.floor = function() {
	var quotient = _integerQuotient(this.n, this.d);
	if (_integerLessThan(this.n, 0)) {
	    return subtract(quotient, 1);
	} else {
	    return quotient;
	}
    };


    Rational.prototype.ceiling = function() {
	var quotient = _integerQuotient(this.n, this.d);
	if (_integerLessThan(this.n, 0)) {
	    return quotient;
	} else {
	    return add(quotient, 1);
	}
    };

    Rational.prototype.conjugate = function() {
	return this;
    };

    Rational.prototype.magnitude = Rational.prototype.abs;

    Rational.prototype.log = function(){
	return FloatPoint.makeInstance(Math.log(this.n / this.d));
    };

    Rational.prototype.angle = function(){
	if (_integerIsZero(this.n))
	    return 0;
	if (_integerGreaterThan(this.n, 0))
	    return 0;
	else
	    return FloatPoint.pi;
    };

    Rational.prototype.tan = function(){
	return FloatPoint.makeInstance(Math.tan(_integerDivideToFixnum(this.n, this.d)));
    };

    Rational.prototype.atan = function(){
	return FloatPoint.makeInstance(Math.atan(_integerDivideToFixnum(this.n, this.d)));
    };

    Rational.prototype.cos = function(){
	return FloatPoint.makeInstance(Math.cos(_integerDivideToFixnum(this.n, this.d)));
    };

    Rational.prototype.sin = function(){
	return FloatPoint.makeInstance(Math.sin(_integerDivideToFixnum(this.n, this.d)));
    };

    Rational.prototype.expt = function(a){
	if (isExactInteger(a) && greaterThanOrEqual(a, 0)) {
	    return fastExpt(this, a);
	}
	return FloatPoint.makeInstance(Math.pow(_integerDivideToFixnum(this.n, this.d),
						_integerDivideToFixnum(a.n, a.d)));
    };

    Rational.prototype.exp = function(){
	return FloatPoint.makeInstance(Math.exp(_integerDivideToFixnum(this.n, this.d)));
    };

    Rational.prototype.acos = function(){
	return FloatPoint.makeInstance(Math.acos(_integerDivideToFixnum(this.n, this.d)));
    };

    Rational.prototype.asin = function(){
	return FloatPoint.makeInstance(Math.asin(_integerDivideToFixnum(this.n, this.d)));
    };

    Rational.prototype.imaginaryPart = function(){
	return 0;
    };

    Rational.prototype.realPart = function(){
	return this;
    };


    Rational.prototype.round = function() {
	// FIXME: not correct when values are bignums
	if (equals(this.d, 2)) {
	    // Round to even if it's a n/2
	    var v = _integerDivideToFixnum(this.n, this.d);
	    var fl = Math.floor(v);
	    var ce = Math.ceil(v);
	    if (_integerIsZero(fl % 2)) {
		return fl;
	    }
	    else {
		return ce;
	    }
	} else {
	    return Math.round(this.n / this.d);
	}
    };


    Rational.makeInstance = function(n, d) {
	if (n === undefined)
	    throwRuntimeError("n undefined", n, d);

	if (d === undefined) { d = 1; }

	if (_integerLessThan(d, 0)) {
	    n = negate(n);
	    d = negate(d);
	}

	var divisor = _integerGcd(abs(n), abs(d));
	n = _integerQuotient(n, divisor);
	d = _integerQuotient(d, divisor);

	// Optimization: if we can get around construction the rational
	// in favor of just returning n, do it:
	if (_integerIsOne(d) || _integerIsZero(n)) {
	    return n;
	}

	return new Rational(n, d);
    };



    // Floating Point numbers
    var FloatPoint = function(n) {
	this.n = n;
    };
    FloatPoint = FloatPoint;


    var NaN = new FloatPoint(Number.NaN);
    var inf = new FloatPoint(Number.POSITIVE_INFINITY);
    var neginf = new FloatPoint(Number.NEGATIVE_INFINITY);

    // We use these two constants to represent the floating-point coersion
    // of bignums that can't be represented with fidelity.
    var TOO_POSITIVE_TO_REPRESENT = new FloatPoint(Number.POSITIVE_INFINITY);
    var TOO_NEGATIVE_TO_REPRESENT = new FloatPoint(Number.NEGATIVE_INFINITY);

    // Negative zero is a distinguished value representing -0.0.
    // There should only be one instance for -0.0.
    var NEGATIVE_ZERO = new FloatPoint(-0.0);
    var INEXACT_ZERO = new FloatPoint(0.0);

    FloatPoint.pi = new FloatPoint(Math.PI);
    FloatPoint.e = new FloatPoint(Math.E);
    FloatPoint.nan = NaN;
    FloatPoint.inf = inf;
    FloatPoint.neginf = neginf;

    FloatPoint.makeInstance = function(n) {
	if (isNaN(n)) {
	    return FloatPoint.nan;
	} else if (n === Number.POSITIVE_INFINITY) {
	    return FloatPoint.inf;
	} else if (n === Number.NEGATIVE_INFINITY) {
	    return FloatPoint.neginf;
	} else if (n === 0) {
	    if ((1/n) === -Infinity) {
		return NEGATIVE_ZERO;
	    } else {
		return INEXACT_ZERO;
	    }
	}
	return new FloatPoint(n);
    };


    FloatPoint.prototype.isExact = function() {
	return false;
    };

    FloatPoint.prototype.isInexact = function() {
	return true;
    };


    FloatPoint.prototype.isFinite = function() {
	return (isFinite(this.n) ||
		this === TOO_POSITIVE_TO_REPRESENT ||
		this === TOO_NEGATIVE_TO_REPRESENT);
    };


    FloatPoint.prototype.toExact = function() {
	// The precision of ieee is about 16 decimal digits, which we use here.
	if (! isFinite(this.n) || isNaN(this.n)) {
	    throwRuntimeError("toExact: no exact representation for " + this, this);
	}

	var stringRep = this.n.toString();
	var match = stringRep.match(/^(.*)\.(.*)$/);
	if (match) {
	    var intPart = parseInt(match[1]);
	    var fracPart = parseInt(match[2]);
	    var tenToDecimalPlaces = Math.pow(10, match[2].length);
	    return Rational.makeInstance(Math.round(this.n * tenToDecimalPlaces),
					 tenToDecimalPlaces);
	}
	else {
	    return this.n;
	}
    };

    FloatPoint.prototype.toInexact = function() {
	return this;
    };

    FloatPoint.prototype.isInexact = function() {
	return true;
    };


    FloatPoint.prototype.level = 2;


    FloatPoint.prototype.liftTo = function(target) {
	if (target.level === 3)
	    return new Complex(this, 0);
	return throwRuntimeError("invalid level of Number", this, target);
    };

    FloatPoint.prototype.toString = function() {
	if (isNaN(this.n))
	    return "+nan.0";
	if (this.n === Number.POSITIVE_INFINITY)
	    return "+inf.0";
	if (this.n === Number.NEGATIVE_INFINITY)
	    return "-inf.0";
	if (this === NEGATIVE_ZERO)
	    return "-0.0";
	var partialResult = this.n.toString();
	if (! partialResult.match('\\.') && ! partialResult.match('e')) {
	    return partialResult + ".0";
	} else {
	    return partialResult;
	}
    };


    FloatPoint.prototype.equals = function(other, aUnionFind) {
	return ((other instanceof FloatPoint) &&
		((this.n === other.n)));
    };



    FloatPoint.prototype.isRational = function() {
        return this.isFinite();
    };

    FloatPoint.prototype.isInteger = function() {
	return this.isFinite() && this.n === Math.floor(this.n);
    };

    FloatPoint.prototype.isReal = function() {
	return true;
    };


    // sign: Number -> {-1, 0, 1}
    var sign = function(n) {
	if (lessThan(n, 0)) {
	    return -1;
	} else if (greaterThan(n, 0)) {
	    return 1;
	} else if (n === NEGATIVE_ZERO) {
	    return -1;
	} else {
	    return 0;
	}
    };


    FloatPoint.prototype.add = function(other) {
	if (this.isFinite() && other.isFinite()) {
	    return FloatPoint.makeInstance(this.n + other.n);
	} else {
	    if (isNaN(this.n) || isNaN(other.n)) {
		return NaN;
	    } else if (this.isFinite() && ! other.isFinite()) {
		return other;
	    } else if (!this.isFinite() && other.isFinite()) {
		return this;
	    } else {
		return ((sign(this) * sign(other) === 1) ?
			this : NaN);
	    };
	}
    };

    FloatPoint.prototype.subtract = function(other) {
	if (this.isFinite() && other.isFinite()) {
	    return FloatPoint.makeInstance(this.n - other.n);
	} else if (isNaN(this.n) || isNaN(other.n)) {
	    return NaN;
	} else if (! this.isFinite() && ! other.isFinite()) {
	    if (sign(this) === sign(other)) {
		return NaN;
	    } else {
		return this;
	    }
	} else if (this.isFinite()) {
	    return multiply(other, -1);
	} else {  // other.isFinite()
	    return this;
	}
    };


    FloatPoint.prototype.negate = function() {
	return FloatPoint.makeInstance(-this.n);
    };

    FloatPoint.prototype.multiply = function(other) {
	return FloatPoint.makeInstance(this.n * other.n);
    };

    FloatPoint.prototype.divide = function(other) {
        return FloatPoint.makeInstance(this.n / other.n);
    };


    FloatPoint.prototype.toFixnum = function() {
	return this.n;
    };

    FloatPoint.prototype.numerator = function() {
	var stringRep = this.n.toString();
	var match = stringRep.match(/^(.*)\.(.*)$/);
	if (match) {
	    var afterDecimal = parseInt(match[2]);
	    var factorToInt = Math.pow(10, match[2].length);
	    var extraFactor = _integerGcd(factorToInt, afterDecimal);
	    var multFactor = factorToInt / extraFactor;
	    return FloatPoint.makeInstance( Math.round(this.n * multFactor) );
	} else {
	    return this;
	}
    };

    FloatPoint.prototype.denominator = function() {
	var stringRep = this.n.toString();
	var match = stringRep.match(/^(.*)\.(.*)$/);
	if (match) {
	    var afterDecimal = parseInt(match[2]);
	    var factorToInt = Math.pow(10, match[2].length);
	    var extraFactor = _integerGcd(factorToInt, afterDecimal);
	    return FloatPoint.makeInstance( Math.round(factorToInt/extraFactor) );
	} else {
	    return FloatPoint.makeInstance(1);
	}
    };


    FloatPoint.prototype.floor = function() {
	return FloatPoint.makeInstance(Math.floor(this.n));
    };

    FloatPoint.prototype.ceiling = function() {
	return FloatPoint.makeInstance(Math.ceil(this.n));
    };


    FloatPoint.prototype.greaterThan = function(other) {
	return this.n > other.n;
    };

    FloatPoint.prototype.greaterThanOrEqual = function(other) {
	return this.n >= other.n;
    };

    FloatPoint.prototype.lessThan = function(other) {
	return this.n < other.n;
    };

    FloatPoint.prototype.lessThanOrEqual = function(other) {
	return this.n <= other.n;
    };


    FloatPoint.prototype.integerSqrt = function() {
	if (this === NEGATIVE_ZERO) { return this; }
	if (isInteger(this)) {
	    if(this.n >= 0) {
	        return FloatPoint.makeInstance(Math.floor(Math.sqrt(this.n)));
	    } else {
	        return Complex.makeInstance(
		    INEXACT_ZERO,
		    FloatPoint.makeInstance(Math.floor(Math.sqrt(-this.n))));
	    }
	} else {
	    throwRuntimeError("integerSqrt: can only be applied to an integer", this);
	}
    };

    FloatPoint.prototype.sqrt = function() {
	if (this.n < 0) {
	    var result = Complex.makeInstance(
		0,
		FloatPoint.makeInstance(Math.sqrt(-this.n)));
	    return result;
	} else {
	    return FloatPoint.makeInstance(Math.sqrt(this.n));
	}
    };

    FloatPoint.prototype.abs = function() {
	return FloatPoint.makeInstance(Math.abs(this.n));
    };



    FloatPoint.prototype.log = function(){
	if (this.n < 0)
	    return (new Complex(this, 0)).log();
	else
	    return FloatPoint.makeInstance(Math.log(this.n));
    };

    FloatPoint.prototype.angle = function(){
	if (0 === this.n)
	    return 0;
	if (this.n > 0)
	    return 0;
	else
	    return FloatPoint.pi;
    };

    FloatPoint.prototype.tan = function(){
	return FloatPoint.makeInstance(Math.tan(this.n));
    };

    FloatPoint.prototype.atan = function(){
	return FloatPoint.makeInstance(Math.atan(this.n));
    };

    FloatPoint.prototype.cos = function(){
	return FloatPoint.makeInstance(Math.cos(this.n));
    };

    FloatPoint.prototype.sin = function(){
	return FloatPoint.makeInstance(Math.sin(this.n));
    };

    FloatPoint.prototype.expt = function(a){
	if (this.n === 1) {
	    if (a.isFinite()) {
		return this;
	    } else if (isNaN(a.n)){
		return this;
	    } else {
		return this;
	    }
	} else {
	    return FloatPoint.makeInstance(Math.pow(this.n, a.n));
	}
    };

    FloatPoint.prototype.exp = function(){
	return FloatPoint.makeInstance(Math.exp(this.n));
    };

    FloatPoint.prototype.acos = function(){
	return FloatPoint.makeInstance(Math.acos(this.n));
    };

    FloatPoint.prototype.asin = function(){
	return FloatPoint.makeInstance(Math.asin(this.n));
    };

    FloatPoint.prototype.imaginaryPart = function(){
	return 0;
    };

    FloatPoint.prototype.realPart = function(){
	return this;
    };


    FloatPoint.prototype.round = function(){
	if (isFinite(this.n)) {
	    if (this === NEGATIVE_ZERO) {
		return this;
	    }
	    if (Math.abs(Math.floor(this.n) - this.n) === 0.5) {
		if (Math.floor(this.n) % 2 === 0)
		    return FloatPoint.makeInstance(Math.floor(this.n));
		return FloatPoint.makeInstance(Math.ceil(this.n));
	    } else {
		return FloatPoint.makeInstance(Math.round(this.n));
	    }
	} else {
	    return this;
	}
    };


    FloatPoint.prototype.conjugate = function() {
	return this;
    };

    FloatPoint.prototype.magnitude = FloatPoint.prototype.abs;



    //////////////////////////////////////////////////////////////////////
    // Complex numbers
    //////////////////////////////////////////////////////////////////////

    var Complex = function(r, i){
	this.r = r;
	this.i = i;
    };

    // Constructs a complex number from two basic number r and i.  r and i can
    // either be plt.type.Rational or plt.type.FloatPoint.
    Complex.makeInstance = function(r, i){
	if (i === undefined) { i = 0; }
	if (isExact(i) && isInteger(i) && _integerIsZero(i)) {
	    return r;
	}
	if (isInexact(r) || isInexact(i)) {
	    r = toInexact(r);
	    i = toInexact(i);
	}
	return new Complex(r, i);
    };

    Complex.prototype.toString = function() {
	var realPart = this.r.toString(), imagPart = this.i.toString();
	if (imagPart[0] === '-' || imagPart[0] === '+') {
	    return realPart + imagPart + 'i';
	} else {
	    return realPart + "+" + imagPart + 'i';
	}
    };


    Complex.prototype.isFinite = function() {
	return isSchemeNumberFinite(this.r) && isSchemeNumberFinite(this.i);
    };


    Complex.prototype.isRational = function() {
	return isRational(this.r) && eqv(this.i, 0);
    };

    Complex.prototype.isInteger = function() {
	return (isInteger(this.r) &&
		eqv(this.i, 0));
    };

    Complex.prototype.toExact = function() {
	return Complex.makeInstance( toExact(this.r), toExact(this.i) );
    };

    Complex.prototype.toInexact = function() {
	return Complex.makeInstance(toInexact(this.r),
				    toInexact(this.i));
    };


    Complex.prototype.isExact = function() {
        return isExact(this.r) && isExact(this.i);
    };


    Complex.prototype.isInexact = function() {
	return isInexact(this.r) || isInexact(this.i);
    };


    Complex.prototype.level = 3;


    Complex.prototype.liftTo = function(target){
	throwRuntimeError("Don't know how to lift Complex number", this, target);
    };

    Complex.prototype.equals = function(other) {
	var result = ((other instanceof Complex) &&
		      (equals(this.r, other.r)) &&
		      (equals(this.i, other.i)));
	return result;
    };



    Complex.prototype.greaterThan = function(other) {
	if (! this.isReal() || ! other.isReal()) {
	    throwRuntimeError(">: expects argument of type real number", this, other);
	}
	return greaterThan(this.r, other.r);
    };

    Complex.prototype.greaterThanOrEqual = function(other) {
	if (! this.isReal() || ! other.isReal()) {
	    throwRuntimeError(">=: expects argument of type real number", this, other);
	}
	return greaterThanOrEqual(this.r, other.r);
    };

    Complex.prototype.lessThan = function(other) {
	if (! this.isReal() || ! other.isReal()) {
	    throwRuntimeError("<: expects argument of type real number", this, other);
	}
	return lessThan(this.r, other.r);
    };

    Complex.prototype.lessThanOrEqual = function(other) {
	if (! this.isReal() || ! other.isReal()) {
	    throwRuntimeError("<=: expects argument of type real number", this, other);
	}
	return lessThanOrEqual(this.r, other.r);
    };


    Complex.prototype.abs = function(){
	if (!equals(this.i, 0).valueOf())
	    throwRuntimeError("abs: expects argument of type real number", this);
	return abs(this.r);
    };

    Complex.prototype.toFixnum = function(){
	if (!equals(this.i, 0).valueOf())
	    throwRuntimeError("toFixnum: expects argument of type real number", this);
	return toFixnum(this.r);
    };

    Complex.prototype.numerator = function() {
	if (!this.isReal())
	    throwRuntimeError("numerator: can only be applied to real number", this);
	return numerator(this.n);
    };


    Complex.prototype.denominator = function() {
	if (!this.isReal())
	    throwRuntimeError("floor: can only be applied to real number", this);
	return denominator(this.n);
    };

    Complex.prototype.add = function(other){
	return Complex.makeInstance(
	    add(this.r, other.r),
	    add(this.i, other.i));
    };

    Complex.prototype.subtract = function(other){
	return Complex.makeInstance(
	    subtract(this.r, other.r),
	    subtract(this.i, other.i));
    };

    Complex.prototype.negate = function() {
	return Complex.makeInstance(negate(this.r),
				    negate(this.i));
    };


    Complex.prototype.multiply = function(other){
	// If the other value is real, just do primitive division
	if (other.isReal()) {
	    return Complex.makeInstance(
		multiply(this.r, other.r),
		multiply(this.i, other.r));
	}
	var r = subtract(
	    multiply(this.r, other.r),
	    multiply(this.i, other.i));
	var i = add(
	    multiply(this.r, other.i),
	    multiply(this.i, other.r));
	return Complex.makeInstance(r, i);
    };





    Complex.prototype.divide = function(other){
	var a, b, c, d, r, x, y;
	// If the other value is real, just do primitive division
	if (other.isReal()) {
	    return Complex.makeInstance(
		divide(this.r, other.r),
		divide(this.i, other.r));
	}

	if (this.isInexact() || other.isInexact()) {
	    // http://portal.acm.org/citation.cfm?id=1039814
	    // We currently use Smith's method, though we should
	    // probably switch over to Priest's method.
	    a = this.r;
	    b = this.i;
	    c = other.r;
	    d = other.i;
	    if (lessThanOrEqual(abs(d), abs(c))) {
		r = divide(d, c);
		x = divide(add(a, multiply(b, r)),
			   add(c, multiply(d, r)));
		y = divide(subtract(b, multiply(a, r)),
			   add(c, multiply(d, r)));
	    } else {
		r = divide(c, d);
		x = divide(add(multiply(a, r), b),
			   add(multiply(c, r), d));
		y = divide(subtract(multiply(b, r), a),
			   add(multiply(c, r), d));
	    }
	    return Complex.makeInstance(x, y);
	} else {
	    var con = conjugate(other);
	    var up = multiply(this, con);

	    // Down is guaranteed to be real by this point.
	    var down = realPart(multiply(other, con));

	    var result = Complex.makeInstance(
		divide(realPart(up), down),
		divide(imaginaryPart(up), down));
	    return result;
	}
    };

    Complex.prototype.conjugate = function(){
	var result = Complex.makeInstance(
	    this.r,
	    subtract(0, this.i));

	return result;
    };

    Complex.prototype.magnitude = function(){
	var sum = add(
	    multiply(this.r, this.r),
	    multiply(this.i, this.i));
	return sqrt(sum);
    };

    Complex.prototype.isReal = function(){
	return eqv(this.i, 0);
    };

    Complex.prototype.integerSqrt = function() {
	if (isInteger(this)) {
	    return integerSqrt(this.r);
	} else {
	    throwRuntimeError("integerSqrt: can only be applied to an integer", this);
	}
    };

    Complex.prototype.sqrt = function(){
	if (this.isReal())
	    return sqrt(this.r);
	// http://en.wikipedia.org/wiki/Square_root#Square_roots_of_negative_and_complex_numbers
	var r_plus_x = add(this.magnitude(), this.r);

	var r = sqrt(halve(r_plus_x));

	var i = divide(this.i, sqrt(multiply(r_plus_x, 2)));


	return Complex.makeInstance(r, i);
    };

    Complex.prototype.log = function(){
	var m = this.magnitude();
	var theta = this.angle();
	var result = add(
	    log(m),
	    timesI(theta));
	return result;
    };

    Complex.prototype.angle = function(){
	if (this.isReal()) {
	    return angle(this.r);
	}
	if (equals(0, this.r)) {
	    var tmp = halve(FloatPoint.pi);
	    return greaterThan(this.i, 0) ?
		tmp : negate(tmp);
	} else {
	    var tmp = atan(divide(abs(this.i), abs(this.r)));
	    if (greaterThan(this.r, 0)) {
		return greaterThan(this.i, 0) ?
		    tmp : negate(tmp);
	    } else {
		return greaterThan(this.i, 0) ?
		    subtract(FloatPoint.pi, tmp) : subtract(tmp, FloatPoint.pi);
	    }
	}
    };

    var plusI = Complex.makeInstance(0, 1);
    var minusI = Complex.makeInstance(0, -1);


    Complex.prototype.tan = function() {
	return divide(this.sin(), this.cos());
    };

    Complex.prototype.atan = function(){
	if (equals(this, plusI) ||
	    equals(this, minusI)) {
	    return neginf;
	}
	return multiply(
	    plusI,
	    multiply(
		FloatPoint.makeInstance(0.5),
		log(divide(
		    add(plusI, this),
		    add(
			plusI,
			subtract(0, this))))));
    };

    Complex.prototype.cos = function(){
	if (this.isReal())
	    return cos(this.r);
	var iz = timesI(this);
	var iz_negate = negate(iz);

	return halve(add(exp(iz), exp(iz_negate)));
    };

    Complex.prototype.sin = function(){
	if (this.isReal())
	    return sin(this.r);
	var iz = timesI(this);
	var iz_negate = negate(iz);
	var z2 = Complex.makeInstance(0, 2);
	var exp_negate = subtract(exp(iz), exp(iz_negate));
	var result = divide(exp_negate, z2);
	return result;
    };


    Complex.prototype.expt = function(y){
	if (isExactInteger(y) && greaterThanOrEqual(y, 0)) {
	    return fastExpt(this, y);
	}
	var expo = multiply(y, this.log());
	return exp(expo);
    };

    Complex.prototype.exp = function(){
	var r = exp(this.r);
	var cos_a = cos(this.i);
	var sin_a = sin(this.i);

	return multiply(
	    r,
	    add(cos_a, timesI(sin_a)));
    };

    Complex.prototype.acos = function(){
	if (this.isReal())
	    return acos(this.r);
	var pi_half = halve(FloatPoint.pi);
	var iz = timesI(this);
	var root = sqrt(subtract(1, sqr(this)));
	var l = timesI(log(add(iz, root)));
	return add(pi_half, l);
    };

    Complex.prototype.asin = function(){
	if (this.isReal())
	    return asin(this.r);

	var oneNegateThisSq =
	    subtract(1, sqr(this));
	var sqrtOneNegateThisSq = sqrt(oneNegateThisSq);
	return multiply(2, atan(divide(this,
				       add(1, sqrtOneNegateThisSq))));
    };

    Complex.prototype.ceiling = function(){
	if (!this.isReal())
	    throwRuntimeError("ceiling: can only be applied to real number", this);
	return ceiling(this.r);
    };

    Complex.prototype.floor = function(){
	if (!this.isReal())
	    throwRuntimeError("floor: can only be applied to real number", this);
	return floor(this.r);
    };

    Complex.prototype.imaginaryPart = function(){
	return this.i;
    };

    Complex.prototype.realPart = function(){
	return this.r;
    };

    Complex.prototype.round = function(){
	if (!this.isReal())
	    throwRuntimeError("round: can only be applied to real number", this);
	return round(this.r);
    };



    var rationalRegexp = new RegExp("^([+-]?\\d+)/(\\d+)$");
    var complexRegexp = new RegExp("^([+-]?[\\d\\w/\\.]*)([+-])([\\d\\w/\\.]*)i$");
    var digitRegexp = new RegExp("^[+-]?\\d+$");
    var flonumRegexp = new RegExp("^([+-]?\\d*)\\.(\\d*)$");
    var scientificPattern = new RegExp("^([+-]?\\d*\\.?\\d*)[Ee](\\+?\\d+)$");

    // fromString: string -> (scheme-number | false)
    var fromString = function(x) {
	var aMatch = x.match(rationalRegexp);
	if (aMatch) {
	    return Rational.makeInstance(fromString(aMatch[1]),
					 fromString(aMatch[2]));
	}

	var cMatch = x.match(complexRegexp);
	if (cMatch) {
	    return Complex.makeInstance(fromString(cMatch[1] || "0"),
					fromString(cMatch[2] + (cMatch[3] || "1")));
	}

	// Floating point tests
	if (x === '+nan.0' || x === '-nan.0')
	    return FloatPoint.nan;
	if (x === '+inf.0')
	    return FloatPoint.inf;
	if (x === '-inf.0')
	    return FloatPoint.neginf;
	if (x === "-0.0") {
	    return NEGATIVE_ZERO;
	}
	if (x.match(flonumRegexp) ||  x.match(scientificPattern)) {
	    return FloatPoint.makeInstance(Number(x));
	}

	// Finally, integer tests.
	if (x.match(digitRegexp)) {
	    var n = Number(x);
	    if (isOverflow(n)) {
		return makeBignum(x);
	    } else {
		return n;
	    }
	} else {
	    return false;
	}
    };





    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////

    // The code below comes from Tom Wu's BigInteger implementation:

    // Copyright (c) 2005  Tom Wu
    // All Rights Reserved.
    // See "LICENSE" for details.

    // Basic JavaScript BN library - subset useful for RSA encryption.

    // Bits per digit
    var dbits;

    // JavaScript engine analysis
    var canary = 0xdeadbeefcafe;
    var j_lm = ((canary&0xffffff)==0xefcafe);

    // (public) Constructor
    function BigInteger(a,b,c) {
	if(a != null)
	    if("number" == typeof a) this.fromNumber(a,b,c);
	else if(b == null && "string" != typeof a) this.fromString(a,256);
	else this.fromString(a,b);
    }

    // return new, unset BigInteger
    function nbi() { return new BigInteger(null); }

    // am: Compute w_j += (x*this_i), propagate carries,
    // c is initial carry, returns final carry.
    // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
    // We need to select the fastest one that works in this environment.

    // am1: use a single mult and divide to get the high bits,
    // max digit bits should be 26 because
    // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
    function am1(i,x,w,j,c,n) {
	while(--n >= 0) {
	    var v = x*this[i++]+w[j]+c;
	    c = Math.floor(v/0x4000000);
	    w[j++] = v&0x3ffffff;
	}
	return c;
    }
    // am2 avoids a big mult-and-extract completely.
    // Max digit bits should be <= 30 because we do bitwise ops
    // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
    function am2(i,x,w,j,c,n) {
	var xl = x&0x7fff, xh = x>>15;
	while(--n >= 0) {
	    var l = this[i]&0x7fff;
	    var h = this[i++]>>15;
	    var m = xh*l+h*xl;
	    l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
	    c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
	    w[j++] = l&0x3fffffff;
	}
	return c;
    }
    // Alternately, set max digit bits to 28 since some
    // browsers slow down when dealing with 32-bit numbers.
    function am3(i,x,w,j,c,n) {
	var xl = x&0x3fff, xh = x>>14;
	while(--n >= 0) {
	    var l = this[i]&0x3fff;
	    var h = this[i++]>>14;
	    var m = xh*l+h*xl;
	    l = xl*l+((m&0x3fff)<<14)+w[j]+c;
	    c = (l>>28)+(m>>14)+xh*h;
	    w[j++] = l&0xfffffff;
	}
	return c;
    }
    if(j_lm && (typeof(navigator) !== 'undefined' && navigator.appName == "Microsoft Internet Explorer")) {
	BigInteger.prototype.am = am2;
	dbits = 30;
    }
    else if(j_lm && (typeof(navigator) !== 'undefined' && navigator.appName != "Netscape")) {
	BigInteger.prototype.am = am1;
	dbits = 26;
    }
    else { // Mozilla/Netscape seems to prefer am3
	BigInteger.prototype.am = am3;
	dbits = 28;
    }

    BigInteger.prototype.DB = dbits;
    BigInteger.prototype.DM = ((1<<dbits)-1);
    BigInteger.prototype.DV = (1<<dbits);

    var BI_FP = 52;
    BigInteger.prototype.FV = Math.pow(2,BI_FP);
    BigInteger.prototype.F1 = BI_FP-dbits;
    BigInteger.prototype.F2 = 2*dbits-BI_FP;

    // Digit conversions
    var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
    var BI_RC = [];
    var rr,vv;
    rr = "0".charCodeAt(0);
    for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
    rr = "a".charCodeAt(0);
    for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
    rr = "A".charCodeAt(0);
    for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

    function int2char(n) { return BI_RM.charAt(n); }
    function intAt(s,i) {
	var c = BI_RC[s.charCodeAt(i)];
	return (c==null)?-1:c;
    }

    // (protected) copy this to r
    function bnpCopyTo(r) {
	for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
	r.t = this.t;
	r.s = this.s;
    }

    // (protected) set from integer value x, -DV <= x < DV
    function bnpFromInt(x) {
	this.t = 1;
	this.s = (x<0)?-1:0;
	if(x > 0) this[0] = x;
	else if(x < -1) this[0] = x+DV;
	else this.t = 0;
    }

    // return bigint initialized to value
    function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

    // (protected) set from string and radix
    function bnpFromString(s,b) {
	var k;
	if(b == 16) k = 4;
	else if(b == 8) k = 3;
	else if(b == 256) k = 8; // byte array
	else if(b == 2) k = 1;
	else if(b == 32) k = 5;
	else if(b == 4) k = 2;
	else { this.fromRadix(s,b); return; }
	this.t = 0;
	this.s = 0;
	var i = s.length, mi = false, sh = 0;
	while(--i >= 0) {
	    var x = (k==8)?s[i]&0xff:intAt(s,i);
	    if(x < 0) {
		if(s.charAt(i) == "-") mi = true;
		continue;
	    }
	    mi = false;
	    if(sh == 0)
		this[this.t++] = x;
	    else if(sh+k > this.DB) {
		this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
		this[this.t++] = (x>>(this.DB-sh));
	    }
	    else
		this[this.t-1] |= x<<sh;
	    sh += k;
	    if(sh >= this.DB) sh -= this.DB;
	}
	if(k == 8 && (s[0]&0x80) != 0) {
	    this.s = -1;
	    if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
	}
	this.clamp();
	if(mi) BigInteger.ZERO.subTo(this,this);
    }

    // (protected) clamp off excess high words
    function bnpClamp() {
	var c = this.s&this.DM;
	while(this.t > 0 && this[this.t-1] == c) --this.t;
    }

    // (public) return string representation in given radix
    function bnToString(b) {
	if(this.s < 0) return "-"+this.negate().toString(b);
	var k;
	if(b == 16) k = 4;
	else if(b == 8) k = 3;
	else if(b == 2) k = 1;
	else if(b == 32) k = 5;
	else if(b == 4) k = 2;
	else return this.toRadix(b);
	var km = (1<<k)-1, d, m = false, r = [], i = this.t;
	var p = this.DB-(i*this.DB)%k;
	if(i-- > 0) {
	    if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r.push(int2char(d)); }
	    while(i >= 0) {
		if(p < k) {
		    d = (this[i]&((1<<p)-1))<<(k-p);
		    d |= this[--i]>>(p+=this.DB-k);
		}
		else {
		    d = (this[i]>>(p-=k))&km;
		    if(p <= 0) { p += this.DB; --i; }
		}
		if(d > 0) m = true;
		if(m) r.push(int2char(d));
	    }
	}
	return m?r.join(""):"0";
    }

    // (public) -this
    function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

    // (public) |this|
    function bnAbs() { return (this.s<0)?this.negate():this; }

    // (public) return + if this > a, - if this < a, 0 if equal
    function bnCompareTo(a) {
	var r = this.s-a.s;
	if(r != 0) return r;
	var i = this.t;
	if ( this.s < 0 ) {
		r = a.t - i;
	}
	else {
		r = i - a.t;
	}
	if(r != 0) return r;
	while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
	return 0;
    }

    // returns bit length of the integer x
    function nbits(x) {
	var r = 1, t;
	if((t=x>>>16) != 0) { x = t; r += 16; }
	if((t=x>>8) != 0) { x = t; r += 8; }
	if((t=x>>4) != 0) { x = t; r += 4; }
	if((t=x>>2) != 0) { x = t; r += 2; }
	if((t=x>>1) != 0) { x = t; r += 1; }
	return r;
    }

    // (public) return the number of bits in "this"
    function bnBitLength() {
	if(this.t <= 0) return 0;
	return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
    }

    // (protected) r = this << n*DB
    function bnpDLShiftTo(n,r) {
	var i;
	for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
	for(i = n-1; i >= 0; --i) r[i] = 0;
	r.t = this.t+n;
	r.s = this.s;
    }

    // (protected) r = this >> n*DB
    function bnpDRShiftTo(n,r) {
	for(var i = n; i < this.t; ++i) r[i-n] = this[i];
	r.t = Math.max(this.t-n,0);
	r.s = this.s;
    }

    // (protected) r = this << n
    function bnpLShiftTo(n,r) {
	var bs = n%this.DB;
	var cbs = this.DB-bs;
	var bm = (1<<cbs)-1;
	var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
	for(i = this.t-1; i >= 0; --i) {
	    r[i+ds+1] = (this[i]>>cbs)|c;
	    c = (this[i]&bm)<<bs;
	}
	for(i = ds-1; i >= 0; --i) r[i] = 0;
	r[ds] = c;
	r.t = this.t+ds+1;
	r.s = this.s;
	r.clamp();
    }

    // (protected) r = this >> n
    function bnpRShiftTo(n,r) {
	r.s = this.s;
	var ds = Math.floor(n/this.DB);
	if(ds >= this.t) { r.t = 0; return; }
	var bs = n%this.DB;
	var cbs = this.DB-bs;
	var bm = (1<<bs)-1;
	r[0] = this[ds]>>bs;
	for(var i = ds+1; i < this.t; ++i) {
	    r[i-ds-1] |= (this[i]&bm)<<cbs;
	    r[i-ds] = this[i]>>bs;
	}
	if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
	r.t = this.t-ds;
	r.clamp();
    }

    // (protected) r = this - a
    function bnpSubTo(a,r) {
	var i = 0, c = 0, m = Math.min(a.t,this.t);
	while(i < m) {
	    c += this[i]-a[i];
	    r[i++] = c&this.DM;
	    c >>= this.DB;
	}
	if(a.t < this.t) {
	    c -= a.s;
	    while(i < this.t) {
		c += this[i];
		r[i++] = c&this.DM;
		c >>= this.DB;
	    }
	    c += this.s;
	}
	else {
	    c += this.s;
	    while(i < a.t) {
		c -= a[i];
		r[i++] = c&this.DM;
		c >>= this.DB;
	    }
	    c -= a.s;
	}
	r.s = (c<0)?-1:0;
	if(c < -1) r[i++] = this.DV+c;
	else if(c > 0) r[i++] = c;
	r.t = i;
	r.clamp();
    }

    // (protected) r = this * a, r != this,a (HAC 14.12)
    // "this" should be the larger one if appropriate.
    function bnpMultiplyTo(a,r) {
	var x = this.abs(), y = a.abs();
	var i = x.t;
	r.t = i+y.t;
	while(--i >= 0) r[i] = 0;
	for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
	r.s = 0;
	r.clamp();
	if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
    }

    // (protected) r = this^2, r != this (HAC 14.16)
    function bnpSquareTo(r) {
	var x = this.abs();
	var i = r.t = 2*x.t;
	while(--i >= 0) r[i] = 0;
	for(i = 0; i < x.t-1; ++i) {
	    var c = x.am(i,x[i],r,2*i,0,1);
	    if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
		r[i+x.t] -= x.DV;
		r[i+x.t+1] = 1;
	    }
	}
	if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
	r.s = 0;
	r.clamp();
    }


    // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
    // r != q, this != m.  q or r may be null.
    function bnpDivRemTo(m,q,r) {
	var pm = m.abs();
	if(pm.t <= 0) return;
	var pt = this.abs();
	if(pt.t < pm.t) {
	    if(q != null) q.fromInt(0);
	    if(r != null) this.copyTo(r);
	    return;
	}
	if(r == null) r = nbi();
	var y = nbi(), ts = this.s, ms = m.s;
	var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
	if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
	else { pm.copyTo(y); pt.copyTo(r); }
	var ys = y.t;
	var y0 = y[ys-1];
	if(y0 == 0) return;
	var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
	var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
	var i = r.t, j = i-ys, t = (q==null)?nbi():q;
	y.dlShiftTo(j,t);
	if(r.compareTo(t) >= 0) {
	    r[r.t++] = 1;
	    r.subTo(t,r);
	}
	BigInteger.ONE.dlShiftTo(ys,t);
	t.subTo(y,y);	// "negative" y so we can replace sub with am later
	while(y.t < ys) y[y.t++] = 0;
	while(--j >= 0) {
	    // Estimate quotient digit
	    var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
	    if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
		y.dlShiftTo(j,t);
		r.subTo(t,r);
		while(r[i] < --qd) r.subTo(t,r);
	    }
	}
	if(q != null) {
	    r.drShiftTo(ys,q);
	    if(ts != ms) BigInteger.ZERO.subTo(q,q);
	}
	r.t = ys;
	r.clamp();
	if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
	if(ts < 0) BigInteger.ZERO.subTo(r,r);
    }

    // (public) this mod a
    function bnMod(a) {
	var r = nbi();
	this.abs().divRemTo(a,null,r);
	if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
	return r;
    }

    // Modular reduction using "classic" algorithm
    function Classic(m) { this.m = m; }
    function cConvert(x) {
	if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
	else return x;
    }
    function cRevert(x) { return x; }
    function cReduce(x) { x.divRemTo(this.m,null,x); }
    function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
    function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

    Classic.prototype.convert = cConvert;
    Classic.prototype.revert = cRevert;
    Classic.prototype.reduce = cReduce;
    Classic.prototype.mulTo = cMulTo;
    Classic.prototype.sqrTo = cSqrTo;

    // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
    // justification:
    //         xy == 1 (mod m)
    //         xy =  1+km
    //   xy(2-xy) = (1+km)(1-km)
    // x[y(2-xy)] = 1-k^2m^2
    // x[y(2-xy)] == 1 (mod m^2)
    // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
    // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
    // JS multiply "overflows" differently from C/C++, so care is needed here.
    function bnpInvDigit() {
	if(this.t < 1) return 0;
	var x = this[0];
	if((x&1) == 0) return 0;
	var y = x&3;		// y == 1/x mod 2^2
	y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
	y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
	y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
	// last step - calculate inverse mod DV directly;
	// assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
	y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
	// we really want the negative inverse, and -DV < y < DV
	return (y>0)?this.DV-y:-y;
    }

    // Montgomery reduction
    function Montgomery(m) {
	this.m = m;
	this.mp = m.invDigit();
	this.mpl = this.mp&0x7fff;
	this.mph = this.mp>>15;
	this.um = (1<<(m.DB-15))-1;
	this.mt2 = 2*m.t;
    }

    // xR mod m
    function montConvert(x) {
	var r = nbi();
	x.abs().dlShiftTo(this.m.t,r);
	r.divRemTo(this.m,null,r);
	if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
	return r;
    }

    // x/R mod m
    function montRevert(x) {
	var r = nbi();
	x.copyTo(r);
	this.reduce(r);
	return r;
    }

    // x = x/R mod m (HAC 14.32)
    function montReduce(x) {
	while(x.t <= this.mt2)	// pad x so am has enough room later
	    x[x.t++] = 0;
	for(var i = 0; i < this.m.t; ++i) {
	    // faster way of calculating u0 = x[i]*mp mod DV
	    var j = x[i]&0x7fff;
	    var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
	    // use am to combine the multiply-shift-add into one call
	    j = i+this.m.t;
	    x[j] += this.m.am(0,u0,x,i,0,this.m.t);
	    // propagate carry
	    while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
	}
	x.clamp();
	x.drShiftTo(this.m.t,x);
	if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
    }

    // r = "x^2/R mod m"; x != r
    function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

    // r = "xy/R mod m"; x,y != r
    function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

    Montgomery.prototype.convert = montConvert;
    Montgomery.prototype.revert = montRevert;
    Montgomery.prototype.reduce = montReduce;
    Montgomery.prototype.mulTo = montMulTo;
    Montgomery.prototype.sqrTo = montSqrTo;

    // (protected) true iff this is even
    function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

    // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
    function bnpExp(e,z) {
	    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
	    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
	    g.copyTo(r);
	    while(--i >= 0) {
	        z.sqrTo(r,r2);
	        if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
	        else { var t = r; r = r2; r2 = t; }
	    }
	    return z.revert(r);
    }

    // (public) this^e % m, 0 <= e < 2^32
    function bnModPowInt(e,m) {
	var z;
	if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
	return this.exp(e,z);
    }

    // protected
    BigInteger.prototype.copyTo = bnpCopyTo;
    BigInteger.prototype.fromInt = bnpFromInt;
    BigInteger.prototype.fromString = bnpFromString;
    BigInteger.prototype.clamp = bnpClamp;
    BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
    BigInteger.prototype.drShiftTo = bnpDRShiftTo;
    BigInteger.prototype.lShiftTo = bnpLShiftTo;
    BigInteger.prototype.rShiftTo = bnpRShiftTo;
    BigInteger.prototype.subTo = bnpSubTo;
    BigInteger.prototype.multiplyTo = bnpMultiplyTo;
    BigInteger.prototype.squareTo = bnpSquareTo;
    BigInteger.prototype.divRemTo = bnpDivRemTo;
    BigInteger.prototype.invDigit = bnpInvDigit;
    BigInteger.prototype.isEven = bnpIsEven;
    BigInteger.prototype.exp = bnpExp;

    // public
    BigInteger.prototype.toString = bnToString;
    BigInteger.prototype.negate = bnNegate;
    BigInteger.prototype.abs = bnAbs;
    BigInteger.prototype.compareTo = bnCompareTo;
    BigInteger.prototype.bitLength = bnBitLength;
    BigInteger.prototype.mod = bnMod;
    BigInteger.prototype.modPowInt = bnModPowInt;

    // "constants"
    BigInteger.ZERO = nbv(0);
    BigInteger.ONE = nbv(1);

    // Copyright (c) 2005-2009  Tom Wu
    // All Rights Reserved.
    // See "LICENSE" for details.

    // Extended JavaScript BN functions, required for RSA private ops.

    // Version 1.1: new BigInteger("0", 10) returns "proper" zero

    // (public)
    function bnClone() { var r = nbi(); this.copyTo(r); return r; }

    // (public) return value as integer
    function bnIntValue() {
	if(this.s < 0) {
	    if(this.t == 1) return this[0]-this.DV;
	    else if(this.t == 0) return -1;
	}
	else if(this.t == 1) return this[0];
	else if(this.t == 0) return 0;
	// assumes 16 < DB < 32
	return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
    }

    // (public) return value as byte
    function bnByteValue() { return (this.t==0)?this.s:(this[0]<<24)>>24; }

    // (public) return value as short (assumes DB>=16)
    function bnShortValue() { return (this.t==0)?this.s:(this[0]<<16)>>16; }

    // (protected) return x s.t. r^x < DV
    function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

    // (public) 0 if this == 0, 1 if this > 0
    function bnSigNum() {
	if(this.s < 0) return -1;
	else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
	else return 1;
    }

    // (protected) convert to radix string
    function bnpToRadix(b) {
	if(b == null) b = 10;
	if(this.signum() == 0 || b < 2 || b > 36) return "0";
	var cs = this.chunkSize(b);
	var a = Math.pow(b,cs);
	var d = nbv(a), y = nbi(), z = nbi(), r = "";
	this.divRemTo(d,y,z);
	while(y.signum() > 0) {
	    r = (a+z.intValue()).toString(b).substr(1) + r;
	    y.divRemTo(d,y,z);
	}
	return z.intValue().toString(b) + r;
    }

    // (protected) convert from radix string
    function bnpFromRadix(s,b) {
	this.fromInt(0);
	if(b == null) b = 10;
	var cs = this.chunkSize(b);
	var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
	for(var i = 0; i < s.length; ++i) {
	    var x = intAt(s,i);
	    if(x < 0) {
		if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
		continue;
	    }
	    w = b*w+x;
	    if(++j >= cs) {
		this.dMultiply(d);
		this.dAddOffset(w,0);
		j = 0;
		w = 0;
	    }
	}
	if(j > 0) {
	    this.dMultiply(Math.pow(b,j));
	    this.dAddOffset(w,0);
	}
	if(mi) BigInteger.ZERO.subTo(this,this);
    }

    // (protected) alternate constructor
    function bnpFromNumber(a,b,c) {
	if("number" == typeof b) {
	    // new BigInteger(int,int,RNG)
	    if(a < 2) this.fromInt(1);
	    else {
		this.fromNumber(a,c);
		if(!this.testBit(a-1))	// force MSB set
		    this.bitwiseTo(BigInteger.ONE.shiftLeft(a-1),op_or,this);
		if(this.isEven()) this.dAddOffset(1,0); // force odd
		while(!this.isProbablePrime(b)) {
		    this.dAddOffset(2,0);
		    if(this.bitLength() > a) this.subTo(BigInteger.ONE.shiftLeft(a-1),this);
		}
	    }
	}
	else {
	    // new BigInteger(int,RNG)
	    var x = [], t = a&7;
	    x.length = (a>>3)+1;
	    b.nextBytes(x);
	    if(t > 0) x[0] &= ((1<<t)-1); else x[0] = 0;
	    this.fromString(x,256);
	}
    }

    // (public) convert to bigendian byte array
    function bnToByteArray() {
	var i = this.t, r = [];
	r[0] = this.s;
	var p = this.DB-(i*this.DB)%8, d, k = 0;
	if(i-- > 0) {
	    if(p < this.DB && (d = this[i]>>p) != (this.s&this.DM)>>p)
		r[k++] = d|(this.s<<(this.DB-p));
	    while(i >= 0) {
		if(p < 8) {
		    d = (this[i]&((1<<p)-1))<<(8-p);
		    d |= this[--i]>>(p+=this.DB-8);
		}
		else {
		    d = (this[i]>>(p-=8))&0xff;
		    if(p <= 0) { p += this.DB; --i; }
		}
		if((d&0x80) != 0) d |= -256;
		if(k == 0 && (this.s&0x80) != (d&0x80)) ++k;
		if(k > 0 || d != this.s) r[k++] = d;
	    }
	}
	return r;
    }

    function bnEquals(a) { return(this.compareTo(a)==0); }
    function bnMin(a) { return(this.compareTo(a)<0)?this:a; }
    function bnMax(a) { return(this.compareTo(a)>0)?this:a; }

    // (protected) r = this op a (bitwise)
    function bnpBitwiseTo(a,op,r) {
	var i, f, m = Math.min(a.t,this.t);
	for(i = 0; i < m; ++i) r[i] = op(this[i],a[i]);
	if(a.t < this.t) {
	    f = a.s&this.DM;
	    for(i = m; i < this.t; ++i) r[i] = op(this[i],f);
	    r.t = this.t;
	}
	else {
	    f = this.s&this.DM;
	    for(i = m; i < a.t; ++i) r[i] = op(f,a[i]);
	    r.t = a.t;
	}
	r.s = op(this.s,a.s);
	r.clamp();
    }

    // (public) this & a
    function op_and(x,y) { return x&y; }
    function bnAnd(a) { var r = nbi(); this.bitwiseTo(a,op_and,r); return r; }

    // (public) this | a
    function op_or(x,y) { return x|y; }
    function bnOr(a) { var r = nbi(); this.bitwiseTo(a,op_or,r); return r; }

    // (public) this ^ a
    function op_xor(x,y) { return x^y; }
    function bnXor(a) { var r = nbi(); this.bitwiseTo(a,op_xor,r); return r; }

    // (public) this & ~a
    function op_andnot(x,y) { return x&~y; }
    function bnAndNot(a) { var r = nbi(); this.bitwiseTo(a,op_andnot,r); return r; }

    // (public) ~this
    function bnNot() {
	var r = nbi();
	for(var i = 0; i < this.t; ++i) r[i] = this.DM&~this[i];
	r.t = this.t;
	r.s = ~this.s;
	return r;
    }

    // (public) this << n
    function bnShiftLeft(n) {
	var r = nbi();
	if(n < 0) this.rShiftTo(-n,r); else this.lShiftTo(n,r);
	return r;
    }

    // (public) this >> n
    function bnShiftRight(n) {
	var r = nbi();
	if(n < 0) this.lShiftTo(-n,r); else this.rShiftTo(n,r);
	return r;
    }

    // return index of lowest 1-bit in x, x < 2^31
    function lbit(x) {
	if(x == 0) return -1;
	var r = 0;
	if((x&0xffff) == 0) { x >>= 16; r += 16; }
	if((x&0xff) == 0) { x >>= 8; r += 8; }
	if((x&0xf) == 0) { x >>= 4; r += 4; }
	if((x&3) == 0) { x >>= 2; r += 2; }
	if((x&1) == 0) ++r;
	return r;
    }

    // (public) returns index of lowest 1-bit (or -1 if none)
    function bnGetLowestSetBit() {
	for(var i = 0; i < this.t; ++i)
	    if(this[i] != 0) return i*this.DB+lbit(this[i]);
	if(this.s < 0) return this.t*this.DB;
	return -1;
    }

    // return number of 1 bits in x
    function cbit(x) {
	var r = 0;
	while(x != 0) { x &= x-1; ++r; }
	return r;
    }

    // (public) return number of set bits
    function bnBitCount() {
	var r = 0, x = this.s&this.DM;
	for(var i = 0; i < this.t; ++i) r += cbit(this[i]^x);
	return r;
    }

    // (public) true iff nth bit is set
    function bnTestBit(n) {
	var j = Math.floor(n/this.DB);
	if(j >= this.t) return(this.s!=0);
	return((this[j]&(1<<(n%this.DB)))!=0);
    }

    // (protected) this op (1<<n)
    function bnpChangeBit(n,op) {
	var r = BigInteger.ONE.shiftLeft(n);
	this.bitwiseTo(r,op,r);
	return r;
    }

    // (public) this | (1<<n)
    function bnSetBit(n) { return this.changeBit(n,op_or); }

    // (public) this & ~(1<<n)
    function bnClearBit(n) { return this.changeBit(n,op_andnot); }

    // (public) this ^ (1<<n)
    function bnFlipBit(n) { return this.changeBit(n,op_xor); }

    // (protected) r = this + a
    function bnpAddTo(a,r) {
	var i = 0, c = 0, m = Math.min(a.t,this.t);
	while(i < m) {
	    c += this[i]+a[i];
	    r[i++] = c&this.DM;
	    c >>= this.DB;
	}
	if(a.t < this.t) {
	    c += a.s;
	    while(i < this.t) {
		c += this[i];
		r[i++] = c&this.DM;
		c >>= this.DB;
	    }
	    c += this.s;
	}
	else {
	    c += this.s;
	    while(i < a.t) {
		c += a[i];
		r[i++] = c&this.DM;
		c >>= this.DB;
	    }
	    c += a.s;
	}
	r.s = (c<0)?-1:0;
	if(c > 0) r[i++] = c;
	else if(c < -1) r[i++] = this.DV+c;
	r.t = i;
	r.clamp();
    }

    // (public) this + a
    function bnAdd(a) { var r = nbi(); this.addTo(a,r); return r; }

    // (public) this - a
    function bnSubtract(a) { var r = nbi(); this.subTo(a,r); return r; }

    // (public) this * a
    function bnMultiply(a) { var r = nbi(); this.multiplyTo(a,r); return r; }

    // (public) this / a
    function bnDivide(a) { var r = nbi(); this.divRemTo(a,r,null); return r; }

    // (public) this % a
    function bnRemainder(a) { var r = nbi(); this.divRemTo(a,null,r); return r; }

    // (public) [this/a,this%a]
    function bnDivideAndRemainder(a) {
	var q = nbi(), r = nbi();
	this.divRemTo(a,q,r);
	return [q,r];
    }

    // (protected) this *= n, this >= 0, 1 < n < DV
    function bnpDMultiply(n) {
	this[this.t] = this.am(0,n-1,this,0,0,this.t);
	++this.t;
	this.clamp();
    }

    // (protected) this += n << w words, this >= 0
    function bnpDAddOffset(n,w) {
	if(n == 0) return;
	while(this.t <= w) this[this.t++] = 0;
	this[w] += n;
	while(this[w] >= this.DV) {
	    this[w] -= this.DV;
	    if(++w >= this.t) this[this.t++] = 0;
	    ++this[w];
	}
    }

    // A "null" reducer
    function NullExp() {}
    function nNop(x) { return x; }
    function nMulTo(x,y,r) { x.multiplyTo(y,r); }
    function nSqrTo(x,r) { x.squareTo(r); }

    NullExp.prototype.convert = nNop;
    NullExp.prototype.revert = nNop;
    NullExp.prototype.mulTo = nMulTo;
    NullExp.prototype.sqrTo = nSqrTo;

    // (public) this^e
    function bnPow(e) { return this.exp(e,new NullExp()); }

    // (protected) r = lower n words of "this * a", a.t <= n
    // "this" should be the larger one if appropriate.
    function bnpMultiplyLowerTo(a,n,r) {
	var i = Math.min(this.t+a.t,n);
	r.s = 0; // assumes a,this >= 0
	r.t = i;
	while(i > 0) r[--i] = 0;
	var j;
	for(j = r.t-this.t; i < j; ++i) r[i+this.t] = this.am(0,a[i],r,i,0,this.t);
	for(j = Math.min(a.t,n); i < j; ++i) this.am(0,a[i],r,i,0,n-i);
	r.clamp();
    }

    // (protected) r = "this * a" without lower n words, n > 0
    // "this" should be the larger one if appropriate.
    function bnpMultiplyUpperTo(a,n,r) {
	--n;
	var i = r.t = this.t+a.t-n;
	r.s = 0; // assumes a,this >= 0
	while(--i >= 0) r[i] = 0;
	for(i = Math.max(n-this.t,0); i < a.t; ++i)
	    r[this.t+i-n] = this.am(n-i,a[i],r,0,0,this.t+i-n);
	r.clamp();
	r.drShiftTo(1,r);
    }

    // Barrett modular reduction
    function Barrett(m) {
	// setup Barrett
	this.r2 = nbi();
	this.q3 = nbi();
	BigInteger.ONE.dlShiftTo(2*m.t,this.r2);
	this.mu = this.r2.divide(m);
	this.m = m;
    }

    function barrettConvert(x) {
	if(x.s < 0 || x.t > 2*this.m.t) return x.mod(this.m);
	else if(x.compareTo(this.m) < 0) return x;
	else { var r = nbi(); x.copyTo(r); this.reduce(r); return r; }
    }

    function barrettRevert(x) { return x; }

    // x = x mod m (HAC 14.42)
    function barrettReduce(x) {
	x.drShiftTo(this.m.t-1,this.r2);
	if(x.t > this.m.t+1) { x.t = this.m.t+1; x.clamp(); }
	this.mu.multiplyUpperTo(this.r2,this.m.t+1,this.q3);
	this.m.multiplyLowerTo(this.q3,this.m.t+1,this.r2);
	while(x.compareTo(this.r2) < 0) x.dAddOffset(1,this.m.t+1);
	x.subTo(this.r2,x);
	while(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
    }

    // r = x^2 mod m; x != r
    function barrettSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

    // r = x*y mod m; x,y != r
    function barrettMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

    Barrett.prototype.convert = barrettConvert;
    Barrett.prototype.revert = barrettRevert;
    Barrett.prototype.reduce = barrettReduce;
    Barrett.prototype.mulTo = barrettMulTo;
    Barrett.prototype.sqrTo = barrettSqrTo;

    // (public) this^e % m (HAC 14.85)
    function bnModPow(e,m) {
	var i = e.bitLength(), k, r = nbv(1), z;
	if(i <= 0) return r;
	else if(i < 18) k = 1;
	else if(i < 48) k = 3;
	else if(i < 144) k = 4;
	else if(i < 768) k = 5;
	else k = 6;
	if(i < 8)
	    z = new Classic(m);
	else if(m.isEven())
	    z = new Barrett(m);
	else
	    z = new Montgomery(m);

	// precomputation
	var g = [], n = 3, k1 = k-1, km = (1<<k)-1;
	g[1] = z.convert(this);
	if(k > 1) {
	    var g2 = nbi();
	    z.sqrTo(g[1],g2);
	    while(n <= km) {
		g[n] = nbi();
		z.mulTo(g2,g[n-2],g[n]);
		n += 2;
	    }
	}

	var j = e.t-1, w, is1 = true, r2 = nbi(), t;
	i = nbits(e[j])-1;
	while(j >= 0) {
	    if(i >= k1) w = (e[j]>>(i-k1))&km;
	    else {
		w = (e[j]&((1<<(i+1))-1))<<(k1-i);
		if(j > 0) w |= e[j-1]>>(this.DB+i-k1);
	    }

	    n = k;
	    while((w&1) == 0) { w >>= 1; --n; }
	    if((i -= n) < 0) { i += this.DB; --j; }
	    if(is1) {	// ret == 1, don't bother squaring or multiplying it
		g[w].copyTo(r);
		is1 = false;
	    }
	    else {
		while(n > 1) { z.sqrTo(r,r2); z.sqrTo(r2,r); n -= 2; }
		if(n > 0) z.sqrTo(r,r2); else { t = r; r = r2; r2 = t; }
		z.mulTo(r2,g[w],r);
	    }

	    while(j >= 0 && (e[j]&(1<<i)) == 0) {
		z.sqrTo(r,r2); t = r; r = r2; r2 = t;
		if(--i < 0) { i = this.DB-1; --j; }
	    }
	}
	return z.revert(r);
    }

    // (public) gcd(this,a) (HAC 14.54)
    function bnGCD(a) {
	var x = (this.s<0)?this.negate():this.clone();
	var y = (a.s<0)?a.negate():a.clone();
	if(x.compareTo(y) < 0) { var t = x; x = y; y = t; }
	var i = x.getLowestSetBit(), g = y.getLowestSetBit();
	if(g < 0) return x;
	if(i < g) g = i;
	if(g > 0) {
	    x.rShiftTo(g,x);
	    y.rShiftTo(g,y);
	}
	while(x.signum() > 0) {
	    if((i = x.getLowestSetBit()) > 0) x.rShiftTo(i,x);
	    if((i = y.getLowestSetBit()) > 0) y.rShiftTo(i,y);
	    if(x.compareTo(y) >= 0) {
		x.subTo(y,x);
		x.rShiftTo(1,x);
	    }
	    else {
		y.subTo(x,y);
		y.rShiftTo(1,y);
	    }
	}
	if(g > 0) y.lShiftTo(g,y);
	return y;
    }

    // (protected) this % n, n < 2^26
    function bnpModInt(n) {
	if(n <= 0) return 0;
	var d = this.DV%n, r = (this.s<0)?n-1:0;
	if(this.t > 0)
	    if(d == 0) r = this[0]%n;
	else for(var i = this.t-1; i >= 0; --i) r = (d*r+this[i])%n;
	return r;
    }

    // (public) 1/this % m (HAC 14.61)
    function bnModInverse(m) {
	var ac = m.isEven();
	if((this.isEven() && ac) || m.signum() == 0) return BigInteger.ZERO;
	var u = m.clone(), v = this.clone();
	var a = nbv(1), b = nbv(0), c = nbv(0), d = nbv(1);
	while(u.signum() != 0) {
	    while(u.isEven()) {
		u.rShiftTo(1,u);
		if(ac) {
		    if(!a.isEven() || !b.isEven()) { a.addTo(this,a); b.subTo(m,b); }
		    a.rShiftTo(1,a);
		}
		else if(!b.isEven()) b.subTo(m,b);
		b.rShiftTo(1,b);
	    }
	    while(v.isEven()) {
		v.rShiftTo(1,v);
		if(ac) {
		    if(!c.isEven() || !d.isEven()) { c.addTo(this,c); d.subTo(m,d); }
		    c.rShiftTo(1,c);
		}
		else if(!d.isEven()) d.subTo(m,d);
		d.rShiftTo(1,d);
	    }
	    if(u.compareTo(v) >= 0) {
		u.subTo(v,u);
		if(ac) a.subTo(c,a);
		b.subTo(d,b);
	    }
	    else {
		v.subTo(u,v);
		if(ac) c.subTo(a,c);
		d.subTo(b,d);
	    }
	}
	if(v.compareTo(BigInteger.ONE) != 0) return BigInteger.ZERO;
	if(d.compareTo(m) >= 0) return d.subtract(m);
	if(d.signum() < 0) d.addTo(m,d); else return d;
	if(d.signum() < 0) return d.add(m); else return d;
    }

    var lowprimes = [2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509];
    var lplim = (1<<26)/lowprimes[lowprimes.length-1];

    // (public) test primality with certainty >= 1-.5^t
    function bnIsProbablePrime(t) {
	var i, x = this.abs();
	if(x.t == 1 && x[0] <= lowprimes[lowprimes.length-1]) {
	    for(i = 0; i < lowprimes.length; ++i)
		if(x[0] == lowprimes[i]) return true;
	    return false;
	}
	if(x.isEven()) return false;
	i = 1;
	while(i < lowprimes.length) {
	    var m = lowprimes[i], j = i+1;
	    while(j < lowprimes.length && m < lplim) m *= lowprimes[j++];
	    m = x.modInt(m);
	    while(i < j) if(m%lowprimes[i++] == 0) return false;
	}
	return x.millerRabin(t);
    }

    // (protected) true if probably prime (HAC 4.24, Miller-Rabin)
    function bnpMillerRabin(t) {
	var n1 = this.subtract(BigInteger.ONE);
	var k = n1.getLowestSetBit();
	if(k <= 0) return false;
	var r = n1.shiftRight(k);
	t = (t+1)>>1;
	if(t > lowprimes.length) t = lowprimes.length;
	var a = nbi();
	for(var i = 0; i < t; ++i) {
	    a.fromInt(lowprimes[i]);
	    var y = a.modPow(r,this);
	    if(y.compareTo(BigInteger.ONE) != 0 && y.compareTo(n1) != 0) {
		var j = 1;
		while(j++ < k && y.compareTo(n1) != 0) {
		    y = y.modPowInt(2,this);
		    if(y.compareTo(BigInteger.ONE) == 0) return false;
		}
		if(y.compareTo(n1) != 0) return false;
	    }
	}
	return true;
    }
    
    

    // protected
    BigInteger.prototype.chunkSize = bnpChunkSize;
    BigInteger.prototype.toRadix = bnpToRadix;
    BigInteger.prototype.fromRadix = bnpFromRadix;
    BigInteger.prototype.fromNumber = bnpFromNumber;
    BigInteger.prototype.bitwiseTo = bnpBitwiseTo;
    BigInteger.prototype.changeBit = bnpChangeBit;
    BigInteger.prototype.addTo = bnpAddTo;
    BigInteger.prototype.dMultiply = bnpDMultiply;
    BigInteger.prototype.dAddOffset = bnpDAddOffset;
    BigInteger.prototype.multiplyLowerTo = bnpMultiplyLowerTo;
    BigInteger.prototype.multiplyUpperTo = bnpMultiplyUpperTo;
    BigInteger.prototype.modInt = bnpModInt;
    BigInteger.prototype.millerRabin = bnpMillerRabin;

    // public
    BigInteger.prototype.clone = bnClone;
    BigInteger.prototype.intValue = bnIntValue;
    BigInteger.prototype.byteValue = bnByteValue;
    BigInteger.prototype.shortValue = bnShortValue;
    BigInteger.prototype.signum = bnSigNum;
    BigInteger.prototype.toByteArray = bnToByteArray;
    BigInteger.prototype.equals = bnEquals;
    BigInteger.prototype.min = bnMin;
    BigInteger.prototype.max = bnMax;
    BigInteger.prototype.and = bnAnd;
    BigInteger.prototype.or = bnOr;
    BigInteger.prototype.xor = bnXor;
    BigInteger.prototype.andNot = bnAndNot;
    BigInteger.prototype.not = bnNot;
    BigInteger.prototype.shiftLeft = bnShiftLeft;
    BigInteger.prototype.shiftRight = bnShiftRight;
    BigInteger.prototype.getLowestSetBit = bnGetLowestSetBit;
    BigInteger.prototype.bitCount = bnBitCount;
    BigInteger.prototype.testBit = bnTestBit;
    BigInteger.prototype.setBit = bnSetBit;
    BigInteger.prototype.clearBit = bnClearBit;
    BigInteger.prototype.flipBit = bnFlipBit;
    BigInteger.prototype.add = bnAdd;
    BigInteger.prototype.subtract = bnSubtract;
    BigInteger.prototype.multiply = bnMultiply;
    BigInteger.prototype.divide = bnDivide;
    BigInteger.prototype.remainder = bnRemainder;
    BigInteger.prototype.divideAndRemainder = bnDivideAndRemainder;
    BigInteger.prototype.modPow = bnModPow;
    BigInteger.prototype.modInverse = bnModInverse;
    BigInteger.prototype.pow = bnPow;
    BigInteger.prototype.gcd = bnGCD;
    BigInteger.prototype.isProbablePrime = bnIsProbablePrime;

    // BigInteger interfaces not implemented in jsbn:

    // BigInteger(int signum, byte[] magnitude)
    // double doubleValue()
    // float floatValue()
    // int hashCode()
    // long longValue()
    // static BigInteger valueOf(long val)



    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////
    // END OF copy-and-paste of jsbn.



    BigInteger.NEGATIVE_ONE = BigInteger.ONE.negate();


    // Other methods we need to add for compatibilty with js-numbers numeric tower.

    // add is implemented above.
    // subtract is implemented above.
    // multiply is implemented above.
    // equals is implemented above.
    // abs is implemented above.
    // negate is defined above.

    // makeBignum: string -> BigInteger
    var makeBignum = function(s) {
	if (typeof(s) === 'number') { s = s + ''; }
	s = expandExponent(s);
	return new BigInteger(s, 10);
    };

    var zerostring = function(n) {
	var buf = [];
	for (var i = 0; i < n; i++) {
	    buf.push('0');
	}
	return buf.join('');
    };


    BigInteger.prototype.level = 0;
    BigInteger.prototype.liftTo = function(target) {
	if (target.level === 1) {
	    return new Rational(this, 1);
	}
	if (target.level === 2) {
	    var fixrep = this.toFixnum();
	    if (fixrep === Number.POSITIVE_INFINITY)
		return TOO_POSITIVE_TO_REPRESENT;
	    if (fixrep === Number.NEGATIVE_INFINITY)
		return TOO_NEGATIVE_TO_REPRESENT;
	    return new FloatPoint(fixrep);
	}
	if (target.level === 3) {
	    return new Complex(this, 0);
	}
	return throwRuntimeError("invalid level for BigInteger lift", this, target);
    };

    BigInteger.prototype.isFinite = function() {
	return true;
    };

    BigInteger.prototype.isInteger = function() {
	return true;
    };

    BigInteger.prototype.isRational = function() {
	return true;
    };

    BigInteger.prototype.isReal = function() {
	return true;
    };

    BigInteger.prototype.isExact = function() {
	return true;
    };

    BigInteger.prototype.isInexact = function() {
	return false;
    };

    BigInteger.prototype.toExact = function() {
	return this;
    };

    BigInteger.prototype.toInexact = function() {
	return FloatPoint.makeInstance(this.toFixnum());
    };

    BigInteger.prototype.toFixnum = function() {
	var result = 0, str = this.toString(), i;
	if (str[0] === '-') {
	    for (i=1; i < str.length; i++) {
		result = result * 10 + Number(str[i]);
	    }
	    return -result;
	} else {
	    for (i=0; i < str.length; i++) {
		result = result * 10 + Number(str[i]);
	    }
	    return result;
	}
    };


    BigInteger.prototype.greaterThan = function(other) {
	return this.compareTo(other) > 0;
    };

    BigInteger.prototype.greaterThanOrEqual = function(other) {
	return this.compareTo(other) >= 0;
    };

    BigInteger.prototype.lessThan = function(other) {
	return this.compareTo(other) < 0;
    };

    BigInteger.prototype.lessThanOrEqual = function(other) {
	return this.compareTo(other) <= 0;
    };

    // divide: scheme-number -> scheme-number
    // WARNING NOTE: we override the old version of divide.
    BigInteger.prototype.divide = function(other) {
	var quotientAndRemainder = bnDivideAndRemainder.call(this, other);
	if (quotientAndRemainder[1].compareTo(BigInteger.ZERO) === 0) {
	    return quotientAndRemainder[0];
	} else {
	    var result = add(quotientAndRemainder[0],
			     Rational.makeInstance(quotientAndRemainder[1], other));
	    return result;
	}
    };

    BigInteger.prototype.numerator = function() {
	return this;
    };

    BigInteger.prototype.denominator = function() {
	return 1;
    };


    (function() {
	// Classic implementation of Newton-Ralphson square-root search,
	// adapted for integer-sqrt.
	// http://en.wikipedia.org/wiki/Newton's_method#Square_root_of_a_number
	    var searchIter = function(n, guess) {
		while(!(lessThanOrEqual(sqr(guess),n) &&
			lessThan(n,sqr(add(guess, 1))))) {
		    guess = floor(divide(add(guess,
					     floor(divide(n, guess))),
					 2));
		}
		return guess;
	    };

	    // integerSqrt: -> scheme-number
	    BigInteger.prototype.integerSqrt = function() {
		var n;
		if(sign(this) >= 0) {
		    return searchIter(this, this);
		} else {
		    n = this.negate();
		    return Complex.makeInstance(0, searchIter(n, n));
		}
	    };
    })();


    (function() {	
	// Get an approximation using integerSqrt, and then start another
	// Newton-Ralphson search if necessary.
	BigInteger.prototype.sqrt = function() {
	    var approx = this.integerSqrt(), fix;
	    if (eqv(sqr(approx), this)) {
		return approx;
	    }
	    fix = toFixnum(this);
	    if (isFinite(fix)) {
		if (fix >= 0) {
		    return FloatPoint.makeInstance(Math.sqrt(fix));
		} else {
		    return Complex.makeInstance(
			0,
			FloatPoint.makeInstance(Math.sqrt(-fix)));
		}
	    } else {
		return approx;
	    }
	};
    })();




    
    // sqrt: -> scheme-number
    // http://en.wikipedia.org/wiki/Newton's_method#Square_root_of_a_number
    // Produce the square root.

    // floor: -> scheme-number
    // Produce the floor.
    BigInteger.prototype.floor = function() {
        return this;
    }

    // ceiling: -> scheme-number
    // Produce the ceiling.
    BigInteger.prototype.ceiling = function() {
        return this;
    }

    // conjugate: -> scheme-number
    // Produce the conjugate.

    // magnitude: -> scheme-number
    // Produce the magnitude.

    // log: -> scheme-number
    // Produce the log.

    // angle: -> scheme-number
    // Produce the angle.

    // atan: -> scheme-number
    // Produce the arc tangent.

    // cos: -> scheme-number
    // Produce the cosine.

    // sin: -> scheme-number
    // Produce the sine.


    // expt: scheme-number -> scheme-number
    // Produce the power to the input.
    BigInteger.prototype.expt = function(n) {
	return bnPow.call(this, n);
    };



    // exp: -> scheme-number
    // Produce e raised to the given power.

    // acos: -> scheme-number
    // Produce the arc cosine.

    // asin: -> scheme-number
    // Produce the arc sine.

    BigInteger.prototype.imaginaryPart = function() {
	    return 0;
    }
    BigInteger.prototype.realPart = function() {
	    return this;
    }

    // round: -> scheme-number
    // Round to the nearest integer.





    //////////////////////////////////////////////////////////////////////
    // toRepeatingDecimal: jsnum jsnum {limit: number}? -> [string, string, string]
    //
    // Given the numerator and denominator parts of a rational,
    // produces the repeating-decimal representation, where the first
    // part are the digits before the decimal, the second are the
    // non-repeating digits after the decimal, and the third are the
    // remaining repeating decimals.
    // 
    // An optional limit on the decimal expansion can be provided, in which
    // case the search cuts off if we go past the limit.
    // If this happens, the third argument returned becomes '...' to indicate
    // that the search was prematurely cut off.
    var toRepeatingDecimal = (function() {
	var getResidue = function(r, d, limit) {
	    var digits = [];
	    var seenRemainders = {};
	    seenRemainders[r] = true;
	    while(true) {	
		if (limit-- <= 0) {
		    return [digits.join(''), '...']
		}

		var nextDigit = quotient(
		    multiply(r, 10), d);
		var nextRemainder = remainder(
		    multiply(r, 10),
		    d);
		digits.push(nextDigit.toString());
		if (seenRemainders[nextRemainder]) {
		    r = nextRemainder;
		    break;
		} else {
		    seenRemainders[nextRemainder] = true;
		    r = nextRemainder;
		}
	    }
	    
	    var firstRepeatingRemainder = r;
	    var repeatingDigits = [];
	    while (true) {
		var nextDigit = quotient(multiply(r, 10), d);
		var nextRemainder = remainder(
		    multiply(r, 10),
		    d);
		repeatingDigits.push(nextDigit.toString());
		if (equals(nextRemainder, firstRepeatingRemainder)) {
		    break;
		} else {
		    r = nextRemainder;
		}
	    };

	    var digitString = digits.join('');
	    var repeatingDigitString = repeatingDigits.join('');

	    while (digitString.length >= repeatingDigitString.length &&
		   (digitString.substring(
		       digitString.length - repeatingDigitString.length)
		    === repeatingDigitString)) {
		digitString = digitString.substring(
		    0, digitString.length - repeatingDigitString.length);
	    }

	    return [digitString, repeatingDigitString];

	};

	return function(n, d, options) {
	    // default limit on decimal expansion; can be overridden
	    var limit = 512;
	    if (options && typeof(options.limit) !== 'undefined') {
		limit = options.limit;
	    }
	    if (! isInteger(n)) {
		throwRuntimeError('toRepeatingDecimal: n ' + n.toString() +
				  " is not an integer.");
	    }
	    if (! isInteger(d)) {
		throwRuntimeError('toRepeatingDecimal: d ' + d.toString() +
				  " is not an integer.");
	    }
	    if (equals(d, 0)) {
		throwRuntimeError('toRepeatingDecimal: d equals 0');
	    }
	    if (lessThan(d, 0)) {
		throwRuntimeError('toRepeatingDecimal: d < 0');
	    }
 	    var sign = (lessThan(n, 0) ? "-" : "");
 	    n = abs(n);
 	    var beforeDecimalPoint = sign + quotient(n, d);
 	    var afterDecimals = getResidue(remainder(n, d), d, limit);
 	    return [beforeDecimalPoint].concat(afterDecimals);
	};
    })();
    //////////////////////////////////////////////////////////////////////




    // External interface of js-numbers:

    Numbers['fromFixnum'] = fromFixnum;
    Numbers['fromString'] = fromString;
    Numbers['makeBignum'] = makeBignum;
    Numbers['makeRational'] = Rational.makeInstance;
    Numbers['makeFloat'] = FloatPoint.makeInstance;
    Numbers['makeComplex'] = Complex.makeInstance;
    Numbers['makeComplexPolar'] = makeComplexPolar;

    Numbers['pi'] = FloatPoint.pi;
    Numbers['e'] = FloatPoint.e;
    Numbers['nan'] = FloatPoint.nan;
    Numbers['negative_inf'] = FloatPoint.neginf;
    Numbers['inf'] = FloatPoint.inf;
    Numbers['negative_one'] = -1;   // Rational.NEGATIVE_ONE;
    Numbers['zero'] = 0;            // Rational.ZERO;
    Numbers['one'] = 1;             // Rational.ONE;
    Numbers['i'] = plusI;
    Numbers['negative_i'] = minusI;
    Numbers['negative_zero'] = NEGATIVE_ZERO;

    Numbers['onThrowRuntimeError'] = onThrowRuntimeError;
    Numbers['isSchemeNumber'] = isSchemeNumber;
    Numbers['isRational'] = isRational;
    Numbers['isReal'] = isReal;
    Numbers['isExact'] = isExact;
    Numbers['isExactInteger'] = isExactInteger;
    Numbers['isInexact'] = isInexact;
    Numbers['isInteger'] = isInteger;

    Numbers['toFixnum'] = toFixnum;
    Numbers['toExact'] = toExact;
    Numbers['toInexact'] = toInexact;
    Numbers['add'] = add;
    Numbers['subtract'] = subtract;
    Numbers['multiply'] = multiply;
    Numbers['divide'] = divide;
    Numbers['equals'] = equals;
    Numbers['eqv'] = eqv;
    Numbers['approxEquals'] = approxEquals;
    Numbers['greaterThanOrEqual'] = greaterThanOrEqual;
    Numbers['lessThanOrEqual'] = lessThanOrEqual;
    Numbers['greaterThan'] = greaterThan;
    Numbers['lessThan'] = lessThan;
    Numbers['expt'] = expt;
    Numbers['exp'] = exp;
    Numbers['modulo'] = modulo;
    Numbers['numerator'] = numerator;
    Numbers['denominator'] = denominator;
    Numbers['integerSqrt'] = integerSqrt;
    Numbers['sqrt'] = sqrt;
    Numbers['abs'] = abs;
    Numbers['quotient'] = quotient;
    Numbers['remainder'] = remainder;
    Numbers['floor'] = floor;
    Numbers['ceiling'] = ceiling;
    Numbers['conjugate'] = conjugate;
    Numbers['magnitude'] = magnitude;
    Numbers['log'] = log;
    Numbers['angle'] = angle;
    Numbers['tan'] = tan;
    Numbers['atan'] = atan;
    Numbers['cos'] = cos;
    Numbers['sin'] = sin;
    Numbers['tan'] = tan;
    Numbers['acos'] = acos;
    Numbers['asin'] = asin;
    Numbers['cosh'] = cosh;
    Numbers['sinh'] = sinh;
    Numbers['imaginaryPart'] = imaginaryPart;
    Numbers['realPart'] = realPart;
    Numbers['round'] = round;
    Numbers['sqr'] = sqr;
    Numbers['gcd'] = gcd;
    Numbers['lcm'] = lcm;

    Numbers['toRepeatingDecimal'] = toRepeatingDecimal;



    // The following exposes the class representations for easier
    // integration with other projects.
    Numbers['BigInteger'] = BigInteger;
    Numbers['Rational'] = Rational;
    Numbers['FloatPoint'] = FloatPoint;
    Numbers['Complex'] = Complex;   

    Numbers['MIN_FIXNUM'] = MIN_FIXNUM;
    Numbers['MAX_FIXNUM'] = MAX_FIXNUM;

    return Numbers;
});

/***
This is the runtime for the ANF'd version of pyret
*/

/** @typedef {!Object} */
var Bignum;


define('js/runtime-anf',["js/namespace", "js/js-numbers"],
       function (Namespace, jsnumsIn) {
  if(requirejs.isBrowser) {
    var require = requirejs;
  }
  else {
    var require = requirejs.nodeRequire("requirejs");
  }



  //var Namespace = require('./namespace.js').Namespace;

  /**
    @type {{
        fromFixnum : function(number) : Bignum,
        fromString : function(string) : (Bignum|boolean),
        toFixnum : function() : number,

        isSchemeNumber : function(Object) : boolean,

        equals : function(Bignum, Bignum) : boolean,
        lessThan : function(Bignum, Bignum) : boolean,
        greaterThan : function(Bignum, Bignum) : boolean,
        lessThanOrEqual : function(Bignum, Bignum) : boolean,
        greaterThanOrEqual : function(Bignum, Bignum) : boolean,

        add : function(Bignum, Bignum) : Bignum,
        subtract : function(Bignum, Bignum) : Bignum,
        multiply : function(Bignum, Bignum) : Bignum,
        divide : function(Bignum, Bignum) : Bignum,

        sin : function(Bignum) : Bignum,
        cos : function(Bignum) : Bignum,
        tan : function(Bignum) : Bignum,
        asin : function(Bignum) : Bignum,
        acos : function(Bignum) : Bignum,
        atan : function(Bignum) : Bignum
          }}
   */
  var jsnums = jsnumsIn;



/**
Creates a Pyret runtime
@param {{stdout : function(string), initialGas : number}} theOutsideWorld contains the hooks
into the environment

@return {Object} that contains all the necessary components of a runtime
*/
function makeRuntime(theOutsideWorld) {
/**
    Extends an object with the new fields in fields
    If all the fields are new, the brands are kept,
    otherwise, the extended object has no brands

    The original object is not mutated, instead it is cloned and the clone
    is mutated

    @param {!Object.<string, !PBase>} fields: a PObj whose fields will be added to the Pyret base
    If any of the fields exist, they will be overwritten with the new value

    @return {!PBase} the extended object 
*/
function extendWith(fields) {
    /**@type {!Object}*/
    var newDict = Object.create(this.dict);
    /**@type {!boolean}*/
    var allNewFields = true;

    for(var field in fields) {
        if(allNewFields && hasProperty(this.dict, field)) {
            allNewFields = false;
        }

        newDict[field] = fields[field];
    } 

    var newObj = this.updateDict(newDict, allNewFields);

    return newObj;
}

    function brandClone(newObj, obj, b) {
      newObj.dict = obj.dict;
      if (b in obj.brands) {
        newObj.brands = obj.brands;
      }
      else {
        newObj.brands = Object.create(obj.brands);
        newObj.brands[b] = true;
        newObj.brands.brandCount++;
      }
      return newObj;
    }

    var noBrands = { brandCount: 0 };

    /**
      The base of all pyret values
      @constructor
    */
    function PBase() {
        /**@type {!Object.<string, Boolean>}*/
        this.brands = noBrands;
        /**@type {!Object.<string, !PBase>}*/
        this.dict   = emptyDict;
    }

    /**@type {!Object.<string, !PBase>}*/
    PBase.prototype.dict = emptyDict;
    /**@type {!function(!Object.<string, !PBase>) : !PBase}*/
    PBase.prototype.extendWith = extendWith;

/**
  Sets up Inheritance with a function call
  This needs to be done socompiler recognizes it

  @param {Function} sub the class that will become a subclass
  @param {Function} from the class that sub will subclass
  */
function inherits(sub, from) {
    sub.prototype = new from();
    //sub.prototype = Object.create(from.prototype);
}

//Set up heirarchy
//We need to set it up before all the other classes
inherits(PNothing, PBase);
inherits(PObject, PBase);
inherits(PFunction, PBase);
inherits(PMethod, PBase);
inherits(POpaque, PBase);

/**
    Tests whether a JS Object has a property

    @param {!Object} obj the object to test
    @param {!string} p the property to look for
    @return {boolean} true if obj has property p, false otherwise
*/
function hasProperty(obj, p) {
    return p in obj;
}

/**
    Tests whether a JS Object has a property, but not on 
    any of its prototypes.
    Useful for objects that lack the .hasOwnProperty method

    @param {!Object} obj the object to test
    @param {!string} p the property to look for
    @return {boolean} true if obj has property p, false otherwise
*/
function hasOwnProperty(obj, p) {
    return Object.prototype.hasOwnProperty.call(obj, p);
}

var parameters = Object.create(null);

function getParam(param) {
  if(hasOwnProperty(parameters, param)) {
    return parameters[param];
  }
  else {
    throw new Error("Parameter " + param + " not defined");
  }
}
function setParam(param, val) {
  parameters[param] = val;
}
function hasParam(param) {
  return param in parameters;
}

/**
    Get the brands on an object

    @param {!PBase} obj the object to get the brands of
    @return {Object.<string,!Boolean>}
*/
function getBrands(obj) {
  return obj.brands;
}

var getProto = Object.getPrototypeOf;

/**
    Get the fields in an object.

    @param {!PBase} obj the object to get the fields of
    @return {Array.<string>}

*/
function getFields(obj) {
  var fields = [];
  var currentProto = obj.dict;
  while(currentProto !== null) {
    fields = fields.concat(Object.keys(currentProto));
    currentProto = getProto(currentProto);
  }
  return fields;
}

/**
    Fold a function over the fields of an object (key and value)

    @param {!PBase} obj the object to fold over
    @param {Function} f the folding function takes the accumulator, then the
                        field name, then the value
    @param {!Object} init the initial value to fold over
*/
function foldFields(obj, f, init) {
  var fields = getFields(obj);
  var acc = init;
  fields.forEach(function(fld) {
      acc = f(acc, fld, obj.dict[fld]);
    });
  return acc;
}


/**
  Makes a copy of a dictionary
  Use this when cloning an object
  Not a deep copy, field values are merely references and are shared between the copies

  @param {!Object.<string, !PBase>} dict the dictionary to clone
  @return {!Object.<string, !PBase>} a copy of the dict such that changes to the copy are *not* reflected in the original
*/
function copyDict(dict) {
    return Object.create(dict);
}

/**
  @param {Array.<number>} brands
  @return Array.<number>
*/
function copyBrands(brands) {
  return brands;
}

var emptyDict = Object.create(null);

/** Creates a truly empty dictonary, with no inherit fields 
    @return {!Object} an empty object
 **/
function makeEmptyDict() {
    return Object.create(null);
}

/**Tests whether an object is a PBase
    @param {Object} obj the item to test
    @return {boolean} true if object is a PBase
*/
function isBase(obj) { return obj instanceof PBase; }

/********************   
    Getting Fields
********************/
/**
  Gets the field from an object of the given name
    -If field is a method, it binds self correctly and returns a function
    -If field is a placeholder, it calls get on the placeholder
    -If field is a mutable -> error
    -If field undefined -> error
    -Otherwise, returns field value

  @param {PBase} val
  @param {string} field

  @return {!PBase}
**/
function getFieldLoc(val, field, loc) {
    if(val === undefined) { 
      if (ffi === undefined) {
        throw ("FFI is not yet defined, and lookup of field " + field + " on undefined failed at location " + JSON.stringify(loc));
      } else {
        ffi.throwInternalError("Field lookup on undefined ", ffi.makeList([field])); }
    }
    if(!isObject(val)) { ffi.throwLookupNonObject(makeSrcloc(loc), val, field); }
    var fieldVal = val.dict[field];
    if(fieldVal === undefined) {
        //TODO: Throw field not found error
        //NOTE: When we change JSON.stringify to toReprJS, we'll need to support
        //reentrant errors (see commit 24ff13d9e9)
      if (ffi === undefined) {
        throw ("FFI is not yet defined, and lookup of field " + field + " on " + toReprJS(val, "_torepr") + " failed at location " + JSON.stringify(loc));
      } else {
        throw ffi.throwFieldNotFound(makeSrcloc(loc), val, field);
      }
    }
    /*else if(isMutable(fieldVal)){
        //TODO: Implement mutables then throw an error here
    }*/
    /*else if(isPlaceholder(fieldVal)){
        //TODO: Implement placeholders then call get here
        //Be wary of guards blowing up stack
    }*/
    else if(isMethod(fieldVal)){
        var curried = fieldVal['meth'](val);
        return makeFunctionArity(curried, fieldVal.arity - 1);
    }
    else {
        return fieldVal;
    }
}

function getField(obj, field) {
  return thisRuntime.getFieldLoc(obj, field, ["runtime"]);
}


/**
  Gets the field from an object of the given name
  -Returns the raw field value

  @param {!PBase} val
  @param {string} field

  @return {!PBase}
**/
function getColonField(val, field) {
  if(val === undefined) { ffi.throwInternalError("Field lookup on undefined ", [field]); }
  if(!isObject(val)) { ffi.throwLookupNonObject(makeSrcloc(["runtime"]), val, field); }
  var fieldVal = val.dict[field];
  if(fieldVal === undefined) {
    ffi.throwFieldNotFound(makeSrcloc(["runtime"]), val, field);
  }
  else {
    return fieldVal;
  }
}

/**

  @constructor
*/
function POpaque(val, equals) {
  this.val = val;
  this.equals = equals;
  /**@type {!Object.<string, Boolean>}*/
  this.brands = noBrands;
}
POpaque.prototype = Object.create(PBase.prototype);

POpaque.prototype.extendWith = function() {
  ffi.throwInternalError("Cannot extend opaque values", ffi.makeList([this]));
};
POpaque.prototype.updateDict = function(dict, keepBrands) {
  ffi.throwInternalError("Cannot clone opaque values", ffi.makeList([this]));
};

function makeOpaque(val, equals) { return new POpaque(val, equals); }
function isOpaque(val) { return val instanceof POpaque; }

/*********************
        Nothing
**********************/
/**
  Pyret Nothing
  Represents the 'nothing' value in pyret
  @constructor
  @extends {PBase}
**/
function PNothing() {
    /**@type {!Object.<string, !PBase>}*/
    this.dict   = emptyDict;
    /**@type {!Object.<string, Boolean>}*/
    this.brands = noBrands;
}
PNothing.prototype = Object.create(PBase.prototype);

/**Clones the nothing
  @return {!PNothing} With same dict
*/
PNothing.prototype.updateDict = function(dict, keepBrands) { 
    var newNoth = makeNothing(); 
    newNoth.dict = dict;
    newNoth.brands = keepBrands ? this.brands : noBrands;
    return newNoth;
};

/**Clones the nothing
  @param {!String} b The brand
  @return {!PNothing} With same dict
*/
PNothing.prototype.brand = function(b) { 
    var newNoth = makeNothing(); 
    return brandClone(newNoth, this, b);
};
/**Tests whether an object is a PNothing
    @param {Object} obj the item to test
    @return {boolean} true if object is a PNothing
*/
function isNothing(obj) { return obj instanceof PNothing; }

/**Makes a nothing
   @return {!PNothing}
*/
function makeNothing() {return new PNothing();}
var nothing = makeNothing();

/*********************
        Number
**********************/
/**Tests whether an object is a PNumber
    @param {Object} obj the item to test
    @return {boolean} true if object is a PNumber
*/
function isNumber(obj) { 
  return jsnums.isSchemeNumber(obj);
}

/**Makes a PNumber using the given bignum

  @param {Bignum} n the number the PNumber will contain
  @return {!PNumber} with value n
*/
function makeNumberBig(n) {
  return n;
}

/**Makes a PNumber using the given JSNum

  @param {number} n the number the PNumber will contain
  @return {!PNumber} with value n
*/
function makeNumber(n) {
  return jsnums.fromFixnum(n);
}
//TODO: for BIG numbers, we'll need to compile them in as strings and use jsnums.fromString(_) to get the value
/**Makes a PNumber using the given string

  @param {string} s 
  @return {!PNumber} with value n
*/
function makeNumberFromString(s) {
  var result = jsnums.fromString(s);
  if(result === false) {
    ffi.throwMessageException("Could not create number from: " + s);
  }
  return result;
}

/*********************
        String
**********************/
/**Tests whether an object is a PString
    @param {Object} obj the item to test
    @return {boolean} true if object is a PString
*/
function isString(obj) { 
  return typeof obj === 'string';
}

/**Makes a PString using the given s

  @param {string} s the string the PString will contain
  @return {!PString} with value s
*/
function makeString(s) {
  if(typeof s !== "string") { throw Error("Non-string given to makeString " + JSON.stringify(s)); }
  return s;
}

/*********************
       Boolean 
**********************/
//Boolean Singletons
var pyretTrue =  true;
var pyretFalse = false;

/**Makes a PBoolean using the given s

  @param {boolean} b the Boolean the PBoolean will contain
  @return {!PBoolean} with value b
*/
function makeBoolean(b) {
  return b;
}

function isBoolean(b) {
  return b === !!b;
}

/**Tests whether the boolean is equal to the singleton true value

  @param {PBoolean} b
  @return {boolean}
*/
function isPyretTrue(b) {
    return b === pyretTrue;
}
function isPyretFalse(b) {
    return b === pyretFalse;
}

/*********************
        Function
**********************/

/**The representation of a function
    @constructor
    @extends {PBase}

    @param {Function} fun the function body
*/
function PFunction(fun, arity) { 
    /**@type {Function}*/
    this.app   = fun;

    /**@type {number}*/
    this.arity = arity || fun.length;

    /**@type {!Object.<string, !PBase>}*/
    this.dict = createFunctionDict(); 

    /**@type {!Object.<string, Boolean>}*/
    this.brands = noBrands;
}
//PFunction.prototype = Object.create(PBase.prototype); 

/**Clones the function
  @return {!PFunction} With same app and dict
*/
PFunction.prototype.updateDict = function(dict, keepBrands) { 
    var newFun = makeFunction(this.app); 
    newFun.dict = dict;
    newFun.brands = keepBrands ? this.brands : noBrands;
    return newFun;
};

/**Clones the function
  @param {!string} b The brand to add
  @return {!PFunction} With same app and dict
*/
PFunction.prototype.brand = function(b) { 
    var newFun = makeFunction(this.app); 
    return brandClone(newFun, this, b);
};

/**Tests whether an object is a PFunction
    @param {Object} obj the item to test
    @return {boolean} true if object is a PFunction
*/
function isFunction(obj) {return obj instanceof PFunction; }

/**Creates a copy of the common dictionary all function have
  @return {!Object.<string, !PBase>} the dictionary for a function
*/
function createFunctionDict() {
    return emptyDict;
}

/**Makes a PFunction using the given n

  @param {Function} fun The JS function that represents the body of the function, must contain at least one arg, which represents self
  @return {!PFunction} with app of fun
*/
function makeFunction(fun) {
   return new PFunction(fun, fun.length); 
}
function makeFunctionArity(fun, arity) {
   return new PFunction(fun, arity); 
}


/*********************
        Method
**********************/

/**The representation of a method
    @constructor
    @param {Function} meth 
    @param {Function} full_meth 
    @extends {PBase}
*/
function PMethod(meth, full_meth) { 
    /**@type {Function}*/
    this['meth']   = meth;

    /**@type {Function}*/
    this['full_meth']   = full_meth;

    /**@type {number}*/
    this.arity = full_meth.length;

    /**@type {!Object.<string, !PBase>}*/
    this.dict = createMethodDict(); 

    /**@type {!Object.<string, Boolean>}*/
    this.brands = noBrands;

}
//PMethod.prototype = Object.create(PBase.prototype); 

/**Clones the method
  @return {!PMethod} With same meth and dict
*/
PMethod.prototype.updateDict = function(dict, keepBrands) { 
    var newMeth = makeMethod(this['meth'], this['full_meth']); 
    newMeth.dict = dict;
    newMeth.brands = keepBrands ? this.brands : noBrands;
    return newMeth;
};

/**Clones the method
  @param {!string} b The brand to add
  @return {!PMethod} With same meth and dict
*/
PMethod.prototype.brand = function(b) { 
    var newMeth = makeMethod(this['meth'], this['full_meth']); 
    return brandClone(newMeth, this, b);
};

/**Tests whether an object is a PMethod
    @param {Object} obj the item to test
    @return {boolean} true if object is a PMethod
*/
function isMethod(obj) { return obj instanceof PMethod; }

/**Creates a copy of the common dictionary all function have
  @return {!Object.<string, !PBase>} the dictionary for a method
*/
function createMethodDict() {
    return emptyDict;
}

/**Makes a PMethod using the given function
  The function first argument should be self

  @param {Function} meth The Curried JS function that represents the body of the method
  @param {Function} full_meth The Full JS function that represents the body of the method
      @return {!PMethod} with app of fun
    */
    function makeMethod(meth, full_meth) {
      return new PMethod(meth, full_meth); 
    }

    function makeMethodFromFun(meth) {
      return new PMethod(function(obj) {
          return function() {
              var argList = Array.prototype.slice.call(arguments);
              return meth.apply(null, [obj].concat(argList));
            };
        }, meth);
    }

    /*********************
            Object
    **********************/
    /**The representation of an object
        @constructor
        @param {!Object.<string, !PBase>} dict
        @extends {PBase}
    */
    function PObject(dict, brands) { 
        /**@type {!Object.<string, !PBase>}*/
        this.dict = dict;

        /**@type {!Object.<string, Boolean>}*/
        this.brands = brands;
    }
    //PObject.prototype = Object.create(PBase.prototype); 

    PObject.prototype.updateDict = function(dict, keepBrands) {
      var newObj = new PObject(dict, keepBrands ? this.brands : noBrands);
      return newObj;
    }

    /**Clones the object
      @return {!PObject} With same dict
    */
    PObject.prototype.brand = function(b) { 
        var newObj = makeObject(this.dict); 
        return brandClone(newObj, this, b);
    };

    /**Tests whether an object is a PObject
        @param {Object} obj the item to test
        @return {!boolean} true if object is a PObject
    */
    function isObject(obj) { return obj instanceof PObject; }

    /**Makes a PObject using the given dict

      @param {!Object.<string, !PBase>} dict
      @return {!PObject} with given dict
    */
    function makeObject(dict) {
       return new PObject(dict, noBrands); 
    }

    function makeBrandedObject(dict, brands) {
        return new PObject(dict, brands);
    }

    /**The representation of an array
       A PArray is simply a JavaScript array
    */
    function isArray(val) {
      return val instanceof Array;
    }
    function makeArray(arr) {
      return arr;
    }

    PObject.prototype.updateDict = function(dict, keepBrands) {
      var newObj = new PObject(dict, keepBrands ? this.brands : noBrands);
      return newObj;
    }

    /**Clones the object
      @return {!PObject} With same dict
    */
    PObject.prototype.brand = function(b) { 
        var newObj = makeObject(this.dict); 
        return brandClone(newObj, this, b);
    };

    /**Tests whether an object is a PObject
        @param {Object} obj the item to test
        @return {!boolean} true if object is a PObject
    */
    function isObject(obj) { return obj instanceof PObject; }

    /**Makes a PObject using the given dict

      @param {!Object.<string, !PBase>} dict
      @return {!PObject} with given dict
    */
    function makeObject(dict) {
       return new PObject(dict, noBrands); 
    }

    function makeBrandedObject(dict, brands) {
        return new PObject(dict, brands);
    }
    
    /************************
          Type Checking
    ************************/
    /**
      Checks if value is ___
      @param {!PBase} val the value to test
      @param {!function(!PBase) : boolean} test

      @return {!boolean} true if val passes test
    */
    function checkIf(val, test) {
        if(!test(val)) {
            throw makeMessageException("Pyret Type Error: " + test + ": " + JSON.stringify(val))
        }
        return true;
    }

    function checkType(val, test, typeName) {
      if(!test(val)) { ffi.throwTypeMismatch(val, typeName) }
      return true;
    }

    function isPyretVal(val) {
      if (typeof val === "string" || typeof val === "boolean" || val instanceof Array) {
        return true;
      }
      else if (jsnums.isSchemeNumber(val)) {
        return true;
      }
      else if (isObject(val) ||
               isFunction(val) ||
               isMethod(val) ||
               isOpaque(val) ||
               isNothing(val)) {
        return true
      }
    }

    var checkArity = function(expected, args, source) {
      if (expected !== args.length) {
        throw ffi.throwArityErrorC([source], expected, args);
      }
    }


    var makeCheckType = function(test, typeName) {
      if (arguments.length !== 2) {
        // can't use checkArity yet because ffi isn't initialized
        throw("MakeCheckType was called with the wrong number of arguments: expected 2, got " + arguments.length);
      }
      return function(val) { 
        checkArity(1, arguments, "runtime");
        return checkType(val, test, typeName); 
      };
    }
    var checkString = makeCheckType(isString, "String");
    var checkNumber = makeCheckType(isNumber, "Number");
    var checkArray = makeCheckType(isArray, "Array");
    var checkBoolean = makeCheckType(isBoolean, "Boolean");
    var checkObject = makeCheckType(isObject, "Object");
    var checkFunction = makeCheckType(isFunction, "Function");
    var checkMethod = makeCheckType(isMethod, "Method");
    var checkOpaque = makeCheckType(isOpaque, "Opaque");
    var checkPyretVal = makeCheckType(isPyretVal, "Pyret Value");

    function confirm(val, test) {
      checkArity(2, arguments, "runtime");
      if(!test(val)) {
          throw makeMessageException("Pyret Type Error: " + test + ": " + JSON.stringify(val))
      }
      return thisRuntime.unwrap(val);
    }

    var NumberC = makePrimitiveAnn("Number", isNumber);
    var StringC = makePrimitiveAnn("String", isString);
    var BooleanC = makePrimitiveAnn("Boolean", isBoolean);
    var RawArrayC = makePrimitiveAnn("RawArray", isArray);
    var FunctionC = makePrimitiveAnn("Function",
      function(v) { return isFunction(v) || isMethod(v) });
    var MethodC = makePrimitiveAnn("Method", isMethod);
    var NothingC = makePrimitiveAnn("Nothing", isNothing);
    var ObjectC = makePrimitiveAnn("Nothing", isObject);
    var AnyC = makePrimitiveAnn("Any", function() { return true; });


    /************************
       Builtin Functions
    ************************/

    function hasBrand(obj, brand) {
      return Boolean(obj.brands && obj.brands[brand] === true);
    }

    var brandCounter = 0;
    function mkBrandName(name) {
      if(typeof name === "undefined") { name = ""; }
      var thisBrandStr = "$brand" + name + String(++brandCounter);
      return thisBrandStr;
    }
    var namedBrander = function(name) {
      var thisBrandStr = mkBrandName(name);
      var brander = makeObject({
          'test': makeFunction(function(obj) {
              return makeBoolean(hasBrand(obj, thisBrandStr));
            }),
          'brand': makeFunction(function(obj) {
              return obj.brand(thisBrandStr);
            })
        });
      brander._brand = thisBrandStr;
      return brander;
    }
    /**@type {PFunction} */
    var brander = makeFunction(
    /**
      @return {!PBase}
    */
    function() {
      return namedBrander("brander");
    }
    );

    // Stolen from https://github.com/dyoo/whalesong/blob/master\
    // /whalesong/js-assembler/runtime-src/baselib-strings.js
    var replaceUnprintableStringChars = function (s) {
      var ret = [], i;
      for (i = 0; i < s.length; i++) {
        var val = s.charCodeAt(i);
        switch(val) {
          case 7: ret.push('\\a'); break;
          case 8: ret.push('\\b'); break;
          case 9: ret.push('\\t'); break;
          case 10: ret.push('\\n'); break;
          case 11: ret.push('\\v'); break;
          case 12: ret.push('\\f'); break;
          case 13: ret.push('\\r'); break;
          case 34: ret.push('\\"'); break;
          case 92: ret.push('\\\\'); break;
          default: 
            if (val >= 32 && val <= 126) {
              ret.push( s.charAt(i) );
            }
            else {
              var numStr = val.toString(16).toUpperCase();
              while (numStr.length < 4) {
                numStr = '0' + numStr;
              }
              ret.push('\\u' + numStr);
            }
            break;
        }
      }
      return ret.join('');
    };

    var escapeString = function (s) {
        return '"' + replaceUnprintableStringChars(s) + '"';
    };

    function toReprLoop(val, method) {
      var stack = [{todo: [val], done: []}];
      function toReprHelp() {
        try {
          while (stack.length > 0 && stack[0].todo.length > 0) {
            var top = stack[stack.length - 1];
            if (top.todo.length > 0) {
              var next = top.todo[top.todo.length - 1];
              if (isNumber(next)) {
                top.todo.pop();
                top.done.push(String(/**@type {!PNumber}*/ (next)));
              } else if (isBoolean(next)) {
                top.todo.pop();
                top.done.push(String(/**@type {!PBoolean}*/ (next)));
              } else if (isString(next)) {
                top.todo.pop();
                if (method === "_torepr") {
                  top.done.push('"' + replaceUnprintableStringChars(String(/**@type {!PString}*/ (next))) + '"');
                } else {
                  top.done.push(String(/**@type {!PString}*/ (next)));
                }
              } else if (isNothing(next)) {
                top.todo.pop();
                top.done.push("nothing");
              } else if (isObject(next)) {
                if (next.dict[method]) {
                  // If this call fails
                  var s = getField(next, method).app();
                  // the continuation stacklet will get the result value, and do the next two steps manually
                  top.todo.pop();
                  top.done.push(thisRuntime.unwrap(s));
                } else { // Push the fields of this nested object onto the work stack
                  var keys = [];
                  var vals = [];
                  for (var field in next.dict) {
                    keys.push(field); // NOTE: this is reversed order from the values,
                    vals.unshift(next.dict[field]); // because processing will reverse them back
                  }
                  stack.push({todo: vals, done: [], keys: keys});
                }
              } else if (isFunction(next)) {
                top.todo.pop();
                top.done.push("<function>");
              } else if (isMethod(next)) {
                top.todo.pop();
                top.done.push("<method>");
              } else {
                top.todo.pop();
                top.done.push(String(next));
              }
            } else { // All fields of a nested object have been stringified; collapse
              stack.pop();
              var prev = stack[stack.length - 1];
              prev.todo.pop();
              var s = "{";
              for (var i = 0; i < top.keys.length; i++) {
                if (i > 0) { s += ", "; }
                s += top.keys[i] + ": " + top.done[i];
              }
              s += "}";
              prev.done.push(s);
            }
          }
          return stack[0].done[0];
        } catch(e) {
          if (thisRuntime.isCont(e)) {
            var stacklet = {
              from: ["runtime torepr"], near: "toRepr",
              go: function(ret) {
                if (stack.length === 0) {
                  ffi.throwInternalError("Somehow we've drained the toRepr worklist, but have results coming back");
                }
                var top = stack[stack.length - 1];
                top.todo.pop();
                top.done.push(thisRuntime.unwrap(ret));
                return makeString(toReprHelp());
              }
            };
            e.stack[thisRuntime.EXN_STACKHEIGHT++] = stacklet;
            throw e;
          } else {
            if (thisRuntime.isPyretException(e)) {
              e.pyretStack.push(["runtime torepr"]); 
            }
            throw e;
          }
        }
      }
      return toReprHelp();
    }
    /**
      Creates the js string representation for the value
      @param {!PBase} val

      @return {!string} the value given in
    */
    function toReprJS(val, method) {
      if (isNumber(val)) { return String(val); }
      else if (isBoolean(val)) { return String(val); }
      else if (isString(val)) {
        if (method === "_torepr") {
          return ('"' + replaceUnprintableStringChars(String(/**@type {!PString}*/ (val))) + '"');
        } else {
          return String(/**@type {!PString}*/ (val));
        }
      }
      return toReprLoop(val, method);
    }

    /**@type {PFunction} */
    var torepr = makeFunction(function(val) {return makeString(toReprJS(val, "_torepr"));});
    var tostring = makeFunction(function(val) {
        if(isString(val)) {
          return makeString(val);
        }
        else {
          return makeString(toReprJS(val, "tostring"));
        }
      });

    var print = makeFunction(
    /**
      Prints the value to the world by passing the repr to stdout
      @param {!PBase} val

      @return {!PBase} the value given in
    */
       function(val){
        display.app(val);
        theOutsideWorld.stdout("\n");
        return val;
    });

    var display = makeFunction(
    /**
      Prints the value to the world by passing the repr to stdout
      @param {!PBase} val

      @return {!PBase} the value given in
    */
       function(val){
        if (isString(val)) {
          var repr = val;
        }
        else {
          var repr = toReprJS(val, "tostring");
        }
        theOutsideWorld.stdout(repr);
        return val;
    });

    var print_error = makeFunction(
    /**
      Prints the value to the world by passing the repr to stderr
      @param {!PBase} val

      @return {!PBase} the value given in
    */
       function(val){
        display_error.app(val);
        theOutsideWorld.stderr("\n");
        return val;
    });

    var display_error = makeFunction(
    /**
      Prints the value to the world by passing the repr to stderr
      @param {!PBase} val

      @return {!PBase} the value given in
    */
       function(val){
        if (isString(val)) {
          var repr = val;
        }
        else {
          var repr = toReprJS(val, "tostring");
        }
        theOutsideWorld.stderr(repr);
        return val;
    });

    /********************
         Exceptions
     *******************/

    /**
      An Exception that represents a pyret exception

      @param {!PBase} e the value to raise
      @constructor
    */
    function PyretFailException(e) {
      this.exn = e;
      this.pyretStack = [];
      this.stack = (new Error).stack;
    }

    /**
      Tests if result is a PyretException
      @param {Object} val the value to test
      @return {boolean} true if it is a FailueResult
    */
    function isPyretException(val) { return val instanceof PyretFailException; }
    PyretFailException.prototype.toString = function() {
      var stackStr = this.pyretStack && this.pyretStack.length > 0 ? 
        this.getStack().map(function(s) {
            var g = getField;
            return s && hasField.app(s, "source") ? g(s, "source") +
                   " at " +
                   g(s, "start-line") +
                   ":" +
                   g(s, "start-column")
              : "<builtin>";
          }).join("\n") :
        "<no stack trace>";
      return toReprJS(this.exn, "tostring") + "\n" + stackStr;
    };
    PyretFailException.prototype.getStack = function() {
      return this.pyretStack.map(makeSrcloc);
    };

    function makeSrcloc(arr) {
      if (typeof arr === "object" && arr.length === 1) {
        checkString(arr[0]);
        if (srcloc === undefined) {
          return makeString(JSON.stringify(arr));
        } else {
          return getField(srcloc, "builtin").app(arr[0])
        }
      }
      else if (typeof arr === "object" && arr.length === 7) {
        return getField(srcloc, "srcloc").app(
            arr[0], arr[1], arr[2], arr[3], arr[4], arr[5], arr[6]
          );
      }
    }

    function makePyretFailException(exn) {
      return new PyretFailException(exn);
    }

    /**
      Raises a PyretFailException with the given string
      @param {!string} str
      @return {!PyretFailException}
    */
    function makeMessageException(str) {
      ffi.throwMessageException(str);
    }

    var raiseJSJS = 
      /**
        Raises any Pyret value as an exception
        @param {!PBase} val the value to raise
      */
      function(val) { 
        throw new PyretFailException(val); 
      };
    /** type {!PFunction} */
    var raisePyPy = makeFunction(raiseJSJS);

    /** type {!PFunction} */
    var hasField = makeFunction(
        /**
          Checks if an object has a given field
          @param {!PBase} obj The object to test
          @param {!PBase} str The field to test for, signals error if non-string
          @return {!PBase} 
        */
        function(obj, str) {
          checkString(str);
          return makeBoolean(hasProperty(obj.dict, str));
        }
      );

    function sameBrands(brands1, brands2) {
      if (brands1.brandCount !== brands2.brandCount) { return false; }
      for(var i in brands1) {
        if(brands1[i] !== brands2[i]) { return false; }
      }
      return true;
    }
    // JS function from Pyret values to JS booleans
    // Needs to be a worklist algorithm to avoid blowing the stack
    function same(left, right) {
      if (left === right) { return true; }

      var toCompare = [{left: left, right: right}];
      var current, curLeft, curRight;
      // Hunts for differences in the worklist, returning false when it finds them.
      // "continue" is equivalent to a recursive call returning "true", false
      // is returned directly when it is encountered
      while(toCompare.length > 0) {
        current = toCompare.pop();
        left = current.left;
        right = current.right;
        if (left === right) { continue; }
        if (isNumber(left) && isNumber(right) && jsnums.equals(left, right)) {
          continue;
        }
        // redundant becase it's just === now
        // else if (isString(left) && isString(right) && left.s === right.s) {
        //   continue;
        // }
        // else if (isBoolean(left) && isBoolean(right) && left.b === right.b) {
        //   continue;
        // }
        else if (isFunction(left) && isFunction(right) && left === right) {
          continue;
        }
        else if (isMethod(left) && isMethod(right) && left === right) {
          continue;
        }
        else if (isOpaque(left) && isOpaque(right) && left.equals(left.val, right.val)) {
          continue;
        }
        else if (isArray(left) && isArray(right)) {
          if (left.length !== right.length) { return false; }
          for (var i = 0; i < left.length; i++) {
            toCompare.push({
              left: left[i],
              right: right[i]
            });
          }
        }
        else if (isObject(left) && isObject(right)) {
          var dictLeft = left.dict;
          var dictRight = right.dict;
          var fieldsLeft;
          var fieldsRight;
          // Fast case, for objects that get extended with similar patterns
          // (e.g. variants of data have same proto), just check own props
          if(getProto(dictLeft) === getProto(dictRight)) {
            fieldsLeft = Object.keys(dictLeft);
            fieldsRight = Object.keys(dictRight);
            if(fieldsLeft.length !== fieldsRight.length) { return false; }
            for(var k = 0; k < fieldsLeft.length; k++) {
              toCompare.push({
                  left: left.dict[fieldsLeft[k]],
                  right: right.dict[fieldsLeft[k]]
                });
            }
          }
          // Slower case, just iterate all fields, all the way down to the bottom
          else {
            fieldsLeft = getFields(left);
            fieldsRight = getFields(right);
            if(fieldsLeft.length !== fieldsRight.length) { return false; }
            for(var k = 0; k < fieldsLeft.length; k++) {
              toCompare.push({
                  left: left.dict[fieldsLeft[k]],
                  right: right.dict[fieldsLeft[k]]
                });
            }
          }
          if(!sameBrands(getBrands(left), getBrands(right))) {
            return false;
          }
          // continue would be inappropriate (but not incorrect)
          // here, because we have enqueued things
        }
        else {
          // In all other cases, things are not equal
          return false;
        }
      }

      return true;

    };
    // Pyret function from Pyret values to Pyret booleans
    var samePyPy = makeFunction(function(v1, v2) { return makeBoolean(same(v1, v2)); });
    // JS function from Pyret values to Pyret booleans
    var sameJSPy = function(v1, v2) { return makeBoolean(same(v1, v2)); };

    var gensymCounter = Math.floor(Math.random() * 1000);
    var gensym = makeFunction(function(base) {
        checkString(base);
        return makeString(unwrap(base) + String(gensymCounter++))
      });

    // These are all intentional no-ops.  Some checker needs to be
    // defined by default in order to bootstrap libraries (since
    // all Pyret modules might use these functions to try and run
    // tests).  This one simply discards all the tests, and is
    // an appropriate choice for, say, loading a checker library.
    // See src/arr/trove/checker.arr for the default check
    // implementation in Pyret that is used by the standard evaluator
    var nullChecker = makeObject({
      "run-checks": makeFunction(function(moduleName, checks) {
        return nothing;
      }),
      "check-is": makeFunction(function(code, left, right, loc) {
        return nothing;
      }),
      "check-satisfies": makeFunction(function(code, left, pred, loc) {
        return nothing;
      }),
      "results": makeFunction(function() {
        return nothing;
      })
    });

    setParam("current-checker", nullChecker);

    /** type {!PBase} */
    var builtins = makeObject({
        'has-field': hasField,
        'equiv': samePyPy,
        'current-checker': makeFunction(function() {
          return getParam("current-checker");
        })
      });


    function unwrap(v) {
      if(isNumber(v)) { return v; }
      else if(isString(v)) { return v; }
      else if(isBoolean(v)) { return v; }
      else if(isObject(v)) { return v; }
      else if(isOpaque(v)) { return v; }
      else { ffi.throwInternalError("Cannot unwrap", [v]); }
    }

    function wrap(v) {
      if(jsnums.isSchemeNumber(v)) { return makeNumberBig(v); }
      else if(typeof v === "number") { return makeNumber(v); }
      else if(typeof v === "string") { return makeString(v); }
      else if(typeof v === "boolean") { return makeBoolean(v); }
      else if(isOpaque(v)) { return v; }
      else if(isObject(v)) { return v; }
      else { ffi.throwInternalError("Cannot wrap", v); }
    }

    function mkPred(jsPred) {
      return makeFunction(function(v) { return makeBoolean(jsPred(v)); });
    }

    function returnOrRaise(result, val, after) {
      if(ffi.isOk(result)) { return after(val); }
      if(ffi.isFail(result)) { raiseJSJS(result); }
      throw "Internal error: got invalid result from annotation check";
    }

    function checkAnn(compilerLoc, ann, val, after) {
      if(!ann.refinement) {
        return returnOrRaise(ann.check(compilerLoc, val), val, after);
      }
      else {
        return safeCall(function() {
          return ann.check(compilerLoc, val);
        }, function(result) {
          return returnOrRaise(result, val, after);
        });
      }
    }

    function _checkAnn(compilerLoc, ann, val) {
      var result = ann.check(compilerLoc, val);
      if(ffi.isOk(result)) { return val; }
      if(ffi.isFail(result)) { raiseJSJS(result); }
      throw "Internal error: got invalid result from annotation check";
    }

    function safeCheckAnnArg(compilerLoc, ann, val, after) {
      if(!ann.refinement) {
        return returnOrRaise(ann.check(compilerLoc, val), val, after);
      }
      else {
        return safeCall(function() {
          return ann.check(compilerLoc, val);
        }, function(result) {
          return returnOrRaise(result, val, after);
        });
      };
    }

    function checkAnnArg(compilerLoc, ann, val) {
      return safeCall(function() {
        return ann.check(compilerLoc, val);
      }, function(result) {
        if(ffi.isOk(result)) { return val; }
        if(ffi.isFail(result)) {
          raiseJSJS(ffi.contractFailArg(getField(result, "loc"), getField(result, "reason")));
        }
        throw "Internal error: got invalid result from annotation check";
      });
    }

    function _checkAnnArg(compilerLoc, ann, val) {
      var result = ann.check(compilerLoc, val);
      if(ffi.isOk(result)) { return val; }
      if(ffi.isFail(result)) {
        raiseJSJS(ffi.contractFailArg(getField(result, "loc"), getField(result, "reason")));
      }
      throw "Internal error: got invalid result from annotation check";
    }

    function checkAnnArgs(anns, args, locs, after) {
      function checkI(i) {
        if(i >= args.length) { return after(); }
        else {
          return safeCheckAnnArg(locs[i], anns[i], args[i], function(ignoredArg) {
            return checkI(i + 1);
          });
        }
      }
      return checkI(0);
    }

    function getDotAnn(loc, name, ann, field) {
      checkString(name);
      checkString(field);
      if(ann.hasOwnProperty(field)) {
        return ann[field];
      }
      raiseJSJS(ffi.contractFail(makeSrcloc(loc),
              ffi.makeDotAnnNotPresent(name, field)))
    }

    function PPrimAnn(name, pred) {
      this.name = name;
      this.pred = pred;
      this.refinement = false;
    }
    PPrimAnn.prototype.checkOrFail = function(passed, val, loc) {
      var that = this;
      if(passed) { return ffi.contractOk; }
      else {
        return ffi.contractFail(
          makeSrcloc(loc),
          ffi.makeTypeMismatch(val, that.name));
      }
    }
    PPrimAnn.prototype.check = function(compilerLoc, val) {
      var that = this;
      if(!this.refinement) {
        return this.checkOrFail(this.pred(val), val, compilerLoc);
      }
      else {
        return safeCall(function() {
          return that.pred(val);
        }, function(passed) {
          return that.checkOrFail(passed, val, compilerLoc);
        });
      }
    }

    function makePrimitiveAnn(name, jsPred) {
      return new PPrimAnn(name, jsPred);
    }

    function PPredAnn(ann, pred, predname) {
      this.ann = ann;
      this.pred = pred;
      this.predname = predname;
      this.refinement = true;
    }
    function makePredAnn(ann, pred, predname) {
      checkFunction(pred);
      checkString(predname);
      return new PPredAnn(ann, pred, predname);
    }
    PPredAnn.prototype.check = function(compilerLoc, val) {
      var that = this;
      return safeCall(function() {
        return that.ann.check(compilerLoc, val);
      }, function(result) {
        if(ffi.isOk(result)) {
          return safeCall(function() {
            return that.pred.app(val);
          }, function(result) {
            if(isPyretTrue(result)) {
              return ffi.contractOk;
            }
            else {
              return ffi.contractFail(
                makeSrcloc(compilerLoc),
                ffi.makePredicateFailure(val, that.predname));
            }
          })
        }
        else {
          return result;
        }
      });
    }

    function makeBranderAnn(brander, name) {
      return makePrimitiveAnn(name, function(val) {
        return isObject(val) && hasBrand(val, brander._brand);
      });
    }

    function PRecordAnn(fields, locs, anns) {
      this.fields = fields;
      this.locs = locs;
      this.anns = anns;
      var hasRefinement = false;
      for (var i = 0; i < fields.length; i++) {
        hasRefinement = hasRefinement || anns[fields[i]].refinement;
      }
      this.refinement = hasRefinement;
    }
    function makeRecordAnn(fields, locs, anns) {
      return new PRecordAnn(fields, locs, anns);
    }
    PRecordAnn.prototype.createMissingFieldsError = function(compilerLoc, val) {
      var that = this;
      var missingFields = [];
      for(var i = 0; i < that.fields.length; i++) {
        if(!hasField.app(val, that.fields[i])) {
          var reason = ffi.makeMissingField(
            makeSrcloc(that.locs[i]),
            that.fields[i]
          );
          missingFields.push(reason);
        }
      }
      return ffi.contractFail(
        makeSrcloc(compilerLoc),
        ffi.makeRecordFieldsFail(val, ffi.makeList(missingFields))
      );
    };
    PRecordAnn.prototype.createRecordFailureError = function(compilerLoc, val, field, result) {
      var that = this;
      var loc;
      for(var i = 0; i < that.fields.length; i++) {
        if(that.fields[i] === field) { loc = that.locs[i]; }
      }
      return ffi.contractFail(
        makeSrcloc(compilerLoc),
        ffi.makeRecordFieldsFail(val, ffi.makeList([
            ffi.makeFieldFailure(
              makeSrcloc(loc),
              field,
              getField(result, "reason")
            )
          ]))
      );
    };
    PRecordAnn.prototype.check = function(compilerLoc, val) {
      var that = this;
      if(!isObject(val)) {
        return ffi.contractFail(
            makeSrcloc(compilerLoc),
            ffi.makeTypeMismatch(val, "Object")
          );
      }
      for(var i = 0; i < that.fields.length; i++) {
        if(!hasField.app(val, that.fields[i])) {
          return that.createMissingFieldsError(compilerLoc, val);
        }
      }

      function deepCheckFields(remainingFields) {
        var thisField;
        return safeCall(function() {
          thisField = remainingFields.pop();
          var thisChecker = that.anns[thisField];
          return thisChecker.check(that.locs[that.locs.length - remainingFields.ength], getColonField(val, thisField));
        }, function(result) {
          if(ffi.isOk(result)) {
            if(remainingFields.length === 0) { return ffi.contractOk; }
            else { return deepCheckFields(remainingFields); }
          }
          else if(ffi.isFail(result)) {
            return that.createRecordFailureError(compilerLoc, val, thisField, result);
          }
        });
      }
      return deepCheckFields(that.fields.slice());
    }

    /********************

     *******************/

    /********************
           Results
     *******************/
    /**
      Result containing the value of a successful evaluation

      @constructor
      @param {!PBase} r result value
    */
    function SuccessResult(r, stats) {
      this.result = r;
      this.stats = stats;
    }

    /**
      Tests if result is a successResult
      @param {Object} val the value to test
      @return {boolean} true if it is a SuccessResult
    */
    function isSuccessResult(val) { return val instanceof SuccessResult; }
    function makeSuccessResult(r) { return new SuccessResult(r); }

    /**
      Result containing the exception of a failed evaluation

      @constructor
      @param {!Error} e exception's value
    */
    function FailureResult(e, stats) {
      this.exn = e;
      this.stats = stats;
    }
    FailureResult.prototype.toString = function() {
      return "FailureResult(" + this.exn + ")";
    };
    /**
      Tests if result is a FailueResult
      @param {Object} val the value to test
      @return {boolean} true if it is a FailueResult
    */
    function isFailureResult(val) { return val instanceof FailureResult; }
    function makeFailureResult(e) { return new FailureResult(e); }

    /**
      Represents a continuation
      @constructor
    */
    function Cont(stack, bottom) {
      this.stack = stack;
      this.bottom = bottom;
    }
    function makeCont(bottom) { return new Cont([], bottom); }
    function isCont(v) { return v instanceof Cont; }
    Cont.prototype.toString = function() {
      var stack = this.stack;
      var stackStr = stack && stack.length > 0 ? 
        stack.map(function(s) { return s && s.from ? s.from.join(",") : "<blank frame>"; }).join("\n") : "<no stack trace>";
      return stackStr;
    }

    function Pause(stack, pause, resumer) {
      this.stack = stack;
      this.pause = pause;
      this.resumer = resumer;
    }
    function makePause(pause, resumer) { return new Pause([], pause, resumer); }
    function isPause(v) { return v instanceof Pause; }
    Pause.prototype = Object.create(Cont.prototype);

    function safeTail(fun) {
      var result;
      if (thisRuntime.GAS-- > 0) {
        result = fun();
      }
      else {
        thisRuntime.EXN_STACKHEIGHT = 0;
        throw thisRuntime.makeCont({
            go: function(ignored) {
              return fun();
            }
          });
      }
      thisRuntime.GAS++;
      return result;
    }

    function safeCall(fun, after, stackFrame) {
      var result;
      try {
        if (thisRuntime.GAS-- > 0) {
          result = fun();
        }
        else {
          thisRuntime.EXN_STACKHEIGHT = 0;
          throw thisRuntime.makeCont({
              go: function(ignored) {
                return fun();
              }
            });
        }
      }
      catch(e) {
        if (isCont(e)) {
          e.stack[thisRuntime.EXN_STACKHEIGHT++] = {
              go: function(retval) {
                return after(retval);
              },
              from: stackFrame
            };
          throw e;
        }
        else if (isPyretException(e)) {
          e.pyretStack.push(stackFrame);
          throw e;
        }
        else {
          throw e;
        }
      }
      return after(result);
    }


    var RUN_ACTIVE = false;
    var currentThreadId = 0;
    var activeThreads = {};
      
    /**@type {function(function(Object, Object) : !PBase, Object, function(Object))}*/
    function run(program, namespace, options, onDone) {
      
      if(RUN_ACTIVE) {
        onDone(new FailureResult(ffi.makeMessageException("Internal: run called while already running")));
        return;
      }
      RUN_ACTIVE = true;
      var start;
      function startTimer() {
        if (typeof window !== "undefined" && window.performance) {
          start = window.performance.now();
        } else if (typeof process !== "undefined" && process.hrtime) {
          start = process.hrtime();
        }
      }
      function endTimer() {
        if (typeof window !== "undefined" && window.performance) {
          return window.performance.now() - start; 
        } else if (typeof process !== "undefined" && process.hrtime) {
          return process.hrtime(start);
        }
      }
      function getStats() {
        return { bounces: BOUNCES, tos: TOS, time: endTimer() };
      }
      function finishFailure(exn) {
        RUN_ACTIVE = false;
        delete activeThreads[thisThread.id];
        onDone(new FailureResult(exn, getStats()));
      }
      function finishSuccess(answer) {
        RUN_ACTIVE = false;
        delete activeThreads[thisThread.id];
        onDone(new SuccessResult(answer, getStats()));
      }

      startTimer();
      var that = this;
      var theOneTrueStackTop = ["top-of-stack"]
      var kickoff = {
          go: function(ignored) {
            return program(thisRuntime, namespace);
          },
          from: theOneTrueStackTop
        };
      var theOneTrueStack = [kickoff];
      var theOneTrueStart = {};
      var val = theOneTrueStart;
      var theOneTrueStackHeight = 1;
      var BOUNCES = 0;
      var TOS = 0;

      var sync = options.sync || false;
      var initialGas = options.initialGas || INITIAL_GAS;

      var threadIsCurrentlyPaused = false;
      var threadIsDead = false;
      currentThreadId += 1;
      // Special case of the first thread to run in between breaks.
      // This is the only thread notified of the break, others just die
      // silently.
      if(Object.keys(activeThreads).length === 0) {
        var breakFun = function() {
          threadIsCurrentlyPaused = true;
          threadIsDead = true;
          finishFailure(new PyretFailException(ffi.userBreak));
        };
      }
      else {
        var breakFun = function() {
          threadIsCurrentlyPaused = true;
          threadIsDead = true;
        };
      }

      var thisThread = {
        handlers: {
          resume: function(restartVal) {
            if(!threadIsCurrentlyPaused) { throw new Error("Stack already running"); }
            if(threadIsDead) { throw new Error("Failed to resume; thread has been killed"); }
            threadIsCurrentlyPaused = false;
            val = restartVal;
            TOS++;
            RUN_ACTIVE = true;
            setTimeout(iter, 0);
          },
          break: breakFun,
          error: function(errVal) {
            threadIsCurrentlyPaused = true;
            threadIsDead = true;
            var exn;
            if(isPyretException(errVal)) {
              exn = errVal;
            } else {
              exn = new PyretFailException(errVal); 
            }
            finishFailure(exn);
          }
        },
        pause: function() {
          threadIsCurrentlyPaused = true;
        },
        id: currentThreadId
      };
      activeThreads[currentThreadId] = thisThread;

      // iter :: () -> Undefined
      // This function should not return anything meaningful, as state
      // and fallthrough are carefully managed.
      function iter() {
        // If the thread is dead, return has already been processed
        if (threadIsDead) {
          return;
        }
        // If the thread is paused, something is wrong; only resume() should
        // be used to re-enter
        if (threadIsCurrentlyPaused) { throw new Error("iter entered during stopped execution"); }
        var loop = true;
        while (loop) {
          loop = false;
          try {
            if (manualPause !== null) {
              var thePause = manualPause;
              manualPause = null;
              pauseStack(function(restarter) {
                  thePause.setHandlers({
                      resume: function() { restarter.resume(val); },
                      break: restarter.break,
                      error: restarter.error
                    });
                });
            }
            var frameCount = 0;
            while(theOneTrueStackHeight > 0) {
              if(!sync && frameCount++ > 100) {
                TOS++;
                setTimeout(iter, 0);
                return;
              }
              var next = theOneTrueStack[--theOneTrueStackHeight];
              theOneTrueStack[theOneTrueStackHeight] = undefined;
              val = next.go(val);
            }
          } catch(e) {
            if(isCont(e)) {
              BOUNCES++;
              thisRuntime.GAS = initialGas;
              for(var i = e.stack.length - 1; i >= 0; i--) {
                theOneTrueStack[theOneTrueStackHeight++] = e.stack[i];
              }

              if(isPause(e)) {
                thisThread.pause();
                e.pause.setHandlers(thisThread.handlers);
                if(e.resumer) { e.resumer(e.pause); }
                return;
              }
              else if(isCont(e)) {
                theOneTrueStack[theOneTrueStackHeight++] = e.bottom;
                val = theOneTrueStart;
                if(sync) {
                  loop = true;
                  // DON'T return; we synchronously loop back to the outer while loop
                  continue;
                }
                else {
                  TOS++;
                  setTimeout(iter, 0);
                  return;
                }
              }
            }

            else if(isPyretException(e)) {
              while(theOneTrueStackHeight > 0) {
                var next = theOneTrueStack[--theOneTrueStackHeight];
                theOneTrueStack[theOneTrueStackHeight] = "sentinel";
                e.pyretStack.push(next.from);
              }
              finishFailure(e);
              return;
            } else {
              finishFailure(e);
              return;
            }
          }
        }
        finishSuccess(val);
        return;
      }
      thisRuntime.GAS = initialGas;
      iter();
    }

    function runThunk(f, then) {
      return run(f, thisRuntime.namespace, {}, then);
    }


    function printPyretStack(stack) {
      if (stack === undefined) return "  undefined";
      var stackStr = stack.map(function(val) {
        if (val instanceof Array && val.length == 7) {
          return (val[0] + ": line " + val[1] + ", column " + val[2]);
        } else if (val) {
          return JSON.stringify(val);
        }
      });
      return "  " + stackStr.join("\n  ");
    }

    function breakAll() {
      RUN_ACTIVE = false;
      var threadsToBreak = activeThreads;
      var keys = Object.keys(threadsToBreak);
      activeThreads = {};
      for(var i = 0; i < keys.length; i++) {
        threadsToBreak[keys[i]].handlers.break();
      }
    }

    function pauseStack(resumer) {
      RUN_ACTIVE = false;
      thisRuntime.EXN_STACKHEIGHT = 0;
      var pause = new PausePackage();
      throw makePause(pause, resumer);
    }

    function PausePackage() {
      this.resumeVal = null;
      this.errorVal = null;
      this.breakFlag = false;
      this.handlers = null;
    }
    PausePackage.prototype = {
      setHandlers: function(handlers) {
        if(this.breakFlag) {
          handlers.break();
        }
        else if (this.resumeVal !== null) {
          handlers.resume(this.resumeVal);
        }
        else if (this.errorVal !== null) {
          handlers.error(this.errorVal);
        }
        else {
          this.handlers = handlers;
        }
      },
      break: function() {
        if(this.resumeVal !== null || this.errorVal !== null) {
          throw "Cannot break with resume or error requested";
        }
        if(this.handlers !== null) {
          this.handlers.break();
        }
        else {
          this.breakFlag = true;
        }
      },
      error: function(err) {
        if(this.resumeVal !== null || this.breakFlag) {
          throw "Cannot error with resume or break requested";
        }
        if(this.handlers !== null) {
          this.handlers.error(err);
        }
        else {
          this.errorVal = err;
        }
      },
      resume: function(val) {
        if(this.errorVal !== null || this.breakFlag) {
          throw "Cannot resume eith error or break requested";
        }
        if(this.handlers !== null) {
          this.handlers.resume(val);
        }
        else {
          this.resumeVal = val;
        }
      }
    };

    var manualPause = null;
    function schedulePause(resumer) {
      var pause = new PausePackage();
      manualPause = pause;
      resumer(pause);
    }

    function execThunk(thunk) {
      function wrapResult(res) {
        if(isSuccessResult(res)) {
          return ffi.makeLeft(res.result);
        } else if (isFailureResult(res)) {
          if(isPyretException(res.exn)) {
            return ffi.makeRight(res.exn.exn);
          }
          else {
            return ffi.makeRight(makeMessageException(String(res.exn)));
          }
        } else {
          console.error("Bad execThunk result: ", res);
          return;
        }
      }
      thisRuntime.pauseStack(function(restarter) {
        thisRuntime.run(function(_, __) {
            return thunk.app();
          }, thisRuntime.namespace, {
            sync: false
          }, function(result) {
            if(isFailureResult(result) &&
               isPyretException(result.exn) &&
               ffi.isUserBreak(result.exn.exn)) { restarter.break(); }
            else {
              restarter.resume(wrapResult(result))
            }
          });
      });
    }

    var INITIAL_GAS = theOutsideWorld.initialGas || 1000;

    var DEBUGLOG = true;
    /**
      @type {function(...[?]): undefined}
    */
    var log = function() {
      if(DEBUGLOG) { console.log.apply(console, arguments); }
    }

    var plus = function(l, r) {
      if (thisRuntime.isNumber(l)) {
        thisRuntime.checkNumber(r);
        return thisRuntime.makeNumberBig(jsnums.add(l, r));
      } else if (thisRuntime.isString(l)) {
        thisRuntime.checkString(r);
        return thisRuntime.makeString(l.concat(r));
      } else if (thisRuntime.isObject(l) && hasProperty(l.dict, "_plus")) {
        return safeTail(function() {
            return thisRuntime.getField(l, "_plus").app(r);
          });
      } else {
        ffi.throwPlusError(l, r);        
      }
    };

    var minus = function(l, r) {
      if (thisRuntime.isNumber(l)) {
        thisRuntime.checkNumber(r)
        return thisRuntime.makeNumberBig(jsnums.subtract(l, r));
      } else if (thisRuntime.isObject(l) && hasProperty(l.dict, "_minus")) {
        return safeTail(function() {
            return thisRuntime.getField(l, "_minus").app(r);
          });
      } else {
        ffi.throwNumericBinopError(l, r, "-", "_minus");
      }
    };

    var times = function(l, r) {
      if (thisRuntime.isNumber(l)) {
        thisRuntime.checkNumber(r);
        return thisRuntime.makeNumberBig(jsnums.multiply(l, r));
      } else if (thisRuntime.isObject(l) && hasProperty(l.dict, "_times")) {
        return safeTail(function() {
            return thisRuntime.getField(l, "_times").app(r);
          });
      } else {
        ffi.throwNumericBinopError(l, r, "*", "_times");
      }
    };

    var divide = function(l, r) {
      if (thisRuntime.isNumber(l)) {
        thisRuntime.checkNumber(r);
        if (jsnums.equals(0, r)) {
          throw makeMessageException("Division by zero");
        }
        return thisRuntime.makeNumberBig(jsnums.divide(l, r));
      } else if (thisRuntime.isObject(l) && hasProperty(l.dict, "_divide")) {
        return safeTail(function() {
            return thisRuntime.getField(l, "_divide").app(r);
          });
      } else {
        ffi.throwNumericBinopError(l, r, "/", "_divide");
      }
    };

    var lessthan = function(l, r) {
      if (thisRuntime.isNumber(l)) {
        thisRuntime.checkNumber(r);
        return thisRuntime.makeBoolean(jsnums.lessThan(l, r));
      } else if (thisRuntime.isString(l)) {
        thisRuntime.checkString(r);
        return thisRuntime.makeBoolean(l < r);
      } else if (thisRuntime.isObject(l) && hasProperty(l.dict, "_lessthan")) {
        return safeTail(function() {
            return thisRuntime.getField(l, "_lessthan").app(r);
          });
      } else {
        ffi.throwNumericBinopError(l, r, "<", "_lessthan");
      }
    };

    var greaterthan = function(l, r) {
      if (thisRuntime.isNumber(l)) {
        thisRuntime.checkNumber(r);
        return thisRuntime.makeBoolean(jsnums.greaterThan(l, r));
      } else if (thisRuntime.isString(l)) {
        thisRuntime.checkString(r);
        return thisRuntime.makeBoolean(l > r);
      } else if (thisRuntime.isObject(l) && hasProperty(l.dict, "_greaterthan")) {
        return safeTail(function() {
            return thisRuntime.getField(l, "_greaterthan").app(r);
          });
      } else {
        ffi.throwNumericBinopError(l, r, ">", "_greaterthan");
      }
    };

    var lessequal = function(l, r) {
      if (thisRuntime.isNumber(l)) {
        thisRuntime.checkNumber(r);
        return thisRuntime.makeBoolean(jsnums.lessThanOrEqual(l, r));
      } else if (thisRuntime.isString(l)) {
        thisRuntime.checkString(r);
        return thisRuntime.makeBoolean(l <= r);
      } else if (thisRuntime.isObject(l) && hasProperty(l.dict, "_lessequal")) {
        return safeTail(function() {
            return thisRuntime.getField(l, "_lessequal").app(r);
          });
      } else {
        ffi.throwNumericBinopError(l, r, "<=", "_lessequal");
      }
    };

    var greaterequal = function(l, r) {
      if (thisRuntime.isNumber(l)) {
        thisRuntime.checkNumber(r);
        return thisRuntime.makeBoolean(jsnums.greaterThanOrEqual(l, r));
      } else if (thisRuntime.isString(l)) {
        thisRuntime.checkString(r);
        return thisRuntime.makeBoolean(l >= r);
      } else if (thisRuntime.isObject(l) && hasProperty(l.dict, "_greaterequal")) {
        return safeTail(function() {
            return thisRuntime.getField(l, "_greaterequal").app(r);
          });
      } else {
        ffi.throwNumericBinopError(l, r, ">=", "_greaterequal");
      }
    };

    var checkArrayIndex = function(methodName, arr, ix) {
      var throwErr = function(reason) {
        ffi.throwInvalidArrayIndex(methodName, arr, ix, reason);
      };
      if(ix >= arr.length) {
        throwErr("index too large; array length was " + arr.length);
      }
      if(ix < 0) {
        throwErr("negative index");
      }
      if(!(num_is_integer(ix))) {
        throwErr("non-integer index");
      }
    }

    var raw_array_of = function(val, len) {
      thisRuntime.checkArity(2, arguments, "raw-array-of");
      thisRuntime.checkNumber(len);
      var arr = new Array(len);
      var i = 0;
      while(i < len) {
        arr[i++] = val;
      }
      return arr;
    }

    var raw_array_get = function(arr, ix) {
      thisRuntime.checkArity(2, arguments, "raw-array-get");
      thisRuntime.checkArray(arr);
      thisRuntime.checkNumber(ix);
      checkArrayIndex("raw-array-get", arr, ix);
      return arr[ix];
    };

    var raw_array_set = function(arr, ix, newVal) {
      thisRuntime.checkArity(3, arguments, "raw-array-set");
      thisRuntime.checkArray(arr);
      thisRuntime.checkNumber(ix);
      checkArrayIndex("raw-array-set", arr, ix);
      arr[ix] = newVal;
      return arr;
    };

    var raw_array_length = function(arr) {
      thisRuntime.checkArity(1, arguments, "raw-array-length");
      thisRuntime.checkArray(arr);
      return makeNumber(arr.length);
    };

    var raw_array_to_list = function(arr) {
      thisRuntime.checkArity(1, arguments, "raw-array-to-list");
      thisRuntime.checkArray(arr);
      return ffi.makeList(arr);
    };

    var raw_array_fold = function(f, init, arr, start) {
      thisRuntime.checkArity(4, arguments, "raw-array-fold");
      thisRuntime.checkFunction(f);
      thisRuntime.checkPyretVal(init);
      thisRuntime.checkArray(arr);
      thisRuntime.checkNumber(start);
      var currentIndex = -1;
      var currentAcc = init;
      var length = arr.length;
      function foldHelp() {
        try {
          while(++currentIndex < length) {
            currentAcc = f.app(currentAcc, arr[currentIndex], currentIndex + start);
          }
          return currentAcc;
        } catch(e) {
          if(isCont(e)) {
            var stacklet = {
              from: ["raw-array-fold"],
              go: function(ret) {
                currentAcc = ret;
                return foldHelp();
              }
            };
            e.stack[thisRuntime.EXN_STACKHEIGHT++] = stacklet;
          }
          if (thisRuntime.isPyretException(e)) {
            e.pyretStack.push(["raw-array-fold"]); 
          }
          throw e;
        }
      }
      return foldHelp();
    };

    var string_substring = function(s, min, max) {
      thisRuntime.checkString(s);
      thisRuntime.checkNumber(min);
      thisRuntime.checkNumber(max);
      if(jsnums.greaterThan(min, max)) {
        throw makeMessageException("substring: min index " + String(min) + " is greater than max index " + String(max));
      }
      if(jsnums.lessThan(min, 0)) {
        throw makeMessageException("substring: min index " + String(min) + " is less than 0");
      }
      if(jsnums.greaterThan(max, string_length(s))) {
        throw makeMessageException("substring: max index " + String(max) + " is larger than the string length " + String(string_length(s)));
      }
      return thisRuntime.makeString(s.substring(jsnums.toFixnum(min), jsnums.toFixnum(max)));
    }
    var string_replace = function(s, find, replace) {
      thisRuntime.checkString(s);
      thisRuntime.checkString(find);
      thisRuntime.checkString(replace);
      var escapedFind = find.replace(/\\/g, "\\\\");
      return thisRuntime.makeString(s.replace(new RegExp(escapedFind,'g'), replace));
    }

    var string_equals = function(l, r) {
      thisRuntime.checkString(l);
      thisRuntime.checkString(r);
      return thisRuntime.makeBoolean(same(l, r));
    }
    var string_append = function(l, r) {
      thisRuntime.checkString(l);
      thisRuntime.checkString(r);
      return thisRuntime.makeString(l.concat(r));
    }
    var string_contains = function(l, r) {
      thisRuntime.checkString(l);
      thisRuntime.checkString(r);
      return thisRuntime.makeBoolean(l.indexOf(r) !== -1);
    }
    var string_length = function(s) {
      thisRuntime.checkString(s);
      return thisRuntime.makeNumber(s.length);
    }
    var string_tonumber = function(s) {
      thisRuntime.checkString(s);
      var num = jsnums.fromString(s);
      if(num !== false) {
        return makeNumberBig(/**@type {Bignum}*/ (num));
      }
      else {
        return makeNothing();
      }
    }
    var string_repeat = function(s, n) {
      thisRuntime.checkString(s);
      thisRuntime.checkNumber(n);
      var resultStr = "";
      // TODO(joe): loop up to a fixnum?
      for(var i = 0; i < jsnums.toFixnum(n); i++) {
        resultStr += s;
      }
      return makeString(resultStr);
    }
    var string_split = function(s, splitstr) {
      thisRuntime.checkString(s);
      thisRuntime.checkString(splitstr);
      
      return ffi.makeList(s.split(splitstr).map(thisRuntime.makeString));
    }
    var string_charat = function(s, n) {
      thisRuntime.checkString(s);
      thisRuntime.checkNumber(n);
      
      //TODO: Handle bignums that are beyond javascript
      return thisRuntime.makeString(String(s.charAt(jsnums.toFixnum(n))));
    }
    var string_toupper = function(s) {
      thisRuntime.checkString(s);
      return thisRuntime.makeString(s.toUpperCase());
    }
    var string_tolower = function(s) {
      thisRuntime.checkString(s);
      return thisRuntime.makeString(s.toLowerCase());
    }
    var string_explode = function(s) {
      thisRuntime.checkString(s);
      return ffi.makeList(s.split("").map(thisRuntime.makeString));
    }
    var string_indexOf = function(s, find) {
      thisRuntime.checkString(s);
      thisRuntime.checkString(find);
      return thisRuntime.makeNumberBig(s.indexOf(find));
    }

    var bool_not = function(l) {
      checkArity(1, arguments, "not");
      thisRuntime.checkBoolean(l);
      return thisRuntime.makeBoolean(!l);
    }

    var num_equals = function(l, r) {
      thisRuntime.checkNumber(l);
      thisRuntime.checkNumber(r);
      return thisRuntime.makeBoolean(same(l, r));
    }
    var num_max = function(l, r) {
      thisRuntime.checkNumber(l);
      thisRuntime.checkNumber(r);
      if (jsnums.greaterThanOrEqual(l, r)) { return l; } else { return r; }
    }

    var num_min = function(l, r) {
      thisRuntime.checkNumber(l);
      thisRuntime.checkNumber(r);
      if (jsnums.lessThanOrEqual(l, r)) { return l; } else { return r; }
    }

    var num_abs = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.abs(n));
    }
      
    var num_sin = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.sin(n));
    }
    var num_cos = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.cos(n));
    }
    var num_tan = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.tan(n));
    }
    var num_asin = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.asin(n));
    }
    var num_acos = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.acos(n));
    }
    var num_atan = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.atan(n));
    }

    var num_modulo = function(n, mod) { 
      thisRuntime.checkNumber(n);
      thisRuntime.checkNumber(mod);
      return thisRuntime.makeNumberBig(jsnums.modulo(n, mod));
    }
    var num_truncate = function(n) { 
      thisRuntime.checkNumber(n);
      if (isNaN(n)) {
        return n;
      } else if (jsnums.greaterThanOrEqual(n, 0)) {
        return thisRuntime.makeNumberBig(jsnums.floor(n));
      } else {
        return thisRuntime.makeNumberBig(jsnums.ceiling(n));
      }
    }
    var num_sqrt = function(n) { 
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.sqrt(n));
    }
    var num_sqr = function(n) { 
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.sqr(n));
    }
    var num_ceiling = function(n) { 
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.ceiling(n));
    }
    var num_floor = function(n) { 
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.floor(n));
    }
    var num_log = function(n) {
      thisRuntime.checkNumber(n);
      if (jsnums.greaterThan(n, 0)) {
        return thisRuntime.makeNumberBig(jsnums.log(n));
      }
      else {
        throw makeMessageException("log: expected a number greater than 0 but got " + String(n));
      }
    }
    var num_exp = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.exp(n));
    }
    var num_exact = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeNumberBig(jsnums.toExact(n));
    }
    var num_is_integer = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeBoolean(jsnums.isInteger(n))
    }
    var num_is_fixnum = function(n) {
      thisRuntime.checkNumber(n);
      return thisRuntime.makeBoolean(typeof n === "number");
    }
    var num_expt = function(n, pow) {
      thisRuntime.checkNumber(n);
      thisRuntime.checkNumber(pow);
      return thisRuntime.makeNumberBig(jsnums.expt(n, pow));
    }
    var num_tostring = function(n) {
      checkArity(1, arguments, "num-tostring");
      thisRuntime.checkNumber(n);
      return makeString(String(n));
    }
    var num_tostring_digits = function(n, digits) {
      checkArity(2, arguments, "num-tostring-digits");
      thisRuntime.checkNumber(n);
      thisRuntime.checkNumber(digits);
      var d = jsnums.toFixnum(digits);
      var tenDigits = jsnums.expt(10, digits);
      if (n != n) { return thisRuntime.makeString("NaN"); }
      else if (jsnums.equals(n, Number.POSITIVE_INFINITY)) { return thisRuntime.makeString("+inf"); }
      else if (jsnums.equals(n, Number.NEGATIVE_INFINITY)) { return thisRuntime.makeString("-inf"); }
      else if (jsnums.equals(n, jsnums.negative_zero)) { 
        var s = "-0.";
        for (var i = 0; i < d; i++)
          s += "0";
        return thisRuntime.makeString(s);
      } else if (jsnums.isReal(n)) {
        n = jsnums.divide(jsnums.round(jsnums.multiply(n, tenDigits)), tenDigits)
        var s = jsnums.toFixnum(n).toString().split(".");
        s[1] = (s[1] || "").substring(0, d);
        for (var i = s[1].length; i < d; i++)
          s[1] += "0";
        return thisRuntime.makeString(s[0] + "." + s[1]);
      } else {
        var nreal = jsnums.realPart(n);
        nreal = jsnums.divide(jsnums.round(jsnums.multiply(nreal, tenDigits)), tenDigits)
        var sreal = jsnums.toFixnum(nreal).toString().split(".");
        sreal[1] = (sreal[1] || "").substring(0, d);
        for (var i = sreal[1].length; i < d; i++)
          sreal[1] += "0";
        var nimag = jsnums.imaginaryPart(n);
        nimag = jsnums.divide(jsnums.round(jsnums.multiply(nimag, tenDigits)), tenDigits)
        var simag = jsnums.toFixnum(nimag).toString().split(".");
        simag[1] = (simag[1] || "").substring(0, d);
        for (var i = simag[1].length; i < d; i++)
          simag[1] += "0";
        if (simag[0][0] === "-" || simag[0][0] === "+") {
          return thisRuntime.makeString(sreal[0] + "." + sreal[1] + simag[0] + "." + simag[1] + "i");
        } else {
          return thisRuntime.makeString(sreal[0] + "." + sreal[1] + "+" + simag[0] + "." + simag[1] + "i");
        }
      }
    }
    function random(max) {
      return makeNumber(jsnums.floor(jsnums.multiply(Math.random(), max)));
    }

    function loadModule(module, runtime, namespace, withModule) {
      var modstring = String(module).substring(0, 500);
      return thisRuntime.safeCall(function() {
          return module(thisRuntime, namespace);
        },
        withModule);
    }
    function loadJSModules(namespace, modules, withModules) {
      function loadModulesInt(toLoad, loaded) {
        if(toLoad.length > 0) {
          var nextMod = toLoad.pop();
          return loadModule(nextMod, thisRuntime, namespace, function(m) {
            return safeTail(function() {
              loaded.unshift(m);
              return loadModulesInt(toLoad, loaded);
            });
          });
        }
        else {
          return safeTail(function() { return withModules.apply(null, loaded); });
        }
      }
      var modulesCopy = modules.slice(0, modules.length);
      return loadModulesInt(modulesCopy, []);
    }
    function loadModulesNew(namespace, modules, withModules) {
      return loadJSModules(namespace, modules, function(/* args */) {
        var ms = Array.prototype.slice.call(arguments);
        function wrapMod(m) {
          if (hasField.app(m, "provide-plus-types")) {
            return getField(m, "provide-plus-types");
          }
          else {
            return thisRuntime.makeObject({
              "values": getField(m, "provide"),
              "types": {}
            });
          }
        };
        var wrappedMods = ms.map(wrapMod);
        return withModules.apply(null, wrappedMods);
      });
    }
    function loadModules(namespace, modules, withModules) {
      return loadModulesNew(namespace, modules, function(/* varargs */) {
        var ms = Array.prototype.slice.call(arguments);
        return safeTail(function() {
          return withModules.apply(null, ms.map(function(m) { return getField(m, "values"); }));
        });
      });
    }

    //Export the runtime
    //String keys should be used to prevent renaming
    var thisRuntime = {
        'namespace': Namespace.namespace({
          'torepr': torepr,
          'tostring': tostring,
          'test-print': print,
          'print': print,
          'display': display,
          'print-error': print_error,
          'display-error': display_error,
          'brander': brander,
          'raise': raisePyPy,
          'builtins': builtins,
          'nothing': nothing,
          'is-nothing': mkPred(isNothing),
          'is-number': mkPred(isNumber),
          'is-boolean': mkPred(isBoolean),
          'is-string': mkPred(isString),
          'is-function': mkPred(isFunction),
          'is-object': mkPred(isObject),
          'is-raw-array': mkPred(isArray),

          // NOTE(joe): the $type$ sadness is because we only have one dynamic
          // namespace
          '$type$Number': NumberC,
          '$type$String': StringC,
          '$type$Boolean': BooleanC,
          '$type$Nothing': NothingC,
          '$type$Function': FunctionC,
          '$type$RawArray': RawArrayC,
          '$type$Method': MethodC,
          '$type$Object': ObjectC,
          '$type$Any': AnyC,

          'Number': NumberC,
          'String': StringC,
          'Boolean': BooleanC,
          'Nothing': NothingC,
          'Function': FunctionC,
          'RawArray': RawArrayC,
          'Method': MethodC,
          'Object': ObjectC,
          'Any': AnyC,

          'run-task': makeFunction(execThunk),

          'gensym': gensym,
          'random': makeFunction(random),

          '_plus': makeFunction(plus),
          '_minus': makeFunction(minus),
          '_times': makeFunction(times),
          '_divide': makeFunction(divide),
          '_lessthan': makeFunction(lessthan),
          '_greaterthan': makeFunction(greaterthan),
          '_greaterequal': makeFunction(greaterequal),
          '_lessequal': makeFunction(lessequal),

          'num-max': makeFunction(num_max),
          'num-min': makeFunction(num_min),
          'nums-equal': makeFunction(num_equals),
          'num-abs': makeFunction(num_abs),
          'num-sin': makeFunction(num_sin),
          'num-cos': makeFunction(num_cos),
          'num-tan': makeFunction(num_tan),
          'num-asin': makeFunction(num_asin),
          'num-acos': makeFunction(num_acos),
          'num-atan': makeFunction(num_atan),
          'num-modulo': makeFunction(num_modulo),
          'num-truncate': makeFunction(num_truncate),
          'num-sqrt': makeFunction(num_sqrt),
          'num-sqr': makeFunction(num_sqr),
          'num-ceiling': makeFunction(num_ceiling),
          'num-floor': makeFunction(num_floor),
          'num-log': makeFunction(num_log),
          'num-exp': makeFunction(num_exp),
          'num-exact': makeFunction(num_exact),
          'num-is-integer': makeFunction(num_is_integer),
          'num-is-fixnum': makeFunction(num_is_fixnum),
          'num-expt': makeFunction(num_expt),
          'num-tostring': makeFunction(num_tostring),

          'strings-equal': makeFunction(string_equals),
          'string-contains': makeFunction(string_contains),
          'string-append': makeFunction(string_append),
          'string-length': makeFunction(string_length),
          'string-tonumber': makeFunction(string_tonumber),
          'string-repeat': makeFunction(string_repeat),
          'string-substring': makeFunction(string_substring),
          'string-replace': makeFunction(string_replace),
          'string-split': makeFunction(string_split),
          'string-char-at': makeFunction(string_charat),
          'string-toupper': makeFunction(string_toupper),
          'string-tolower': makeFunction(string_tolower),
          'string-explode': makeFunction(string_explode),
          'string-index-of': makeFunction(string_indexOf),

          'raw-array-of': makeFunction(raw_array_of),
          'raw-array-get': makeFunction(raw_array_get),
          'raw-array-set': makeFunction(raw_array_set),
          'raw-array-length': makeFunction(raw_array_length),
          'raw-array-to-list': makeFunction(raw_array_to_list),
          'raw-array-fold': makeFunction(raw_array_fold),

          'not': makeFunction(bool_not)

        }),
        'run': run,
        'runThunk': runThunk,
        'safeCall': safeCall,
        'safeTail': safeTail,
        'printPyretStack': printPyretStack,

        'GAS': INITIAL_GAS,

        'namedBrander': namedBrander,

        'checkAnn': checkAnn,
        'checkAnnArg': checkAnnArg,
        'checkAnnArgs': checkAnnArgs,
        'getDotAnn': getDotAnn,
        'makePredAnn': makePredAnn,
        'makePrimitiveAnn': makePrimitiveAnn,
        'makeBranderAnn': makeBranderAnn,
        'makeRecordAnn': makeRecordAnn,

        'Number': NumberC,
        'String': StringC,
        'Boolean': BooleanC,
        'RawArray': RawArrayC,
        'Any': AnyC,
        'Function': FunctionC,
        'Method': MethodC,
        'Object': ObjectC,
        'Nothing': NothingC,

        'makeCont'    : makeCont,
        'isCont'      : isCont,
        'makePause'   : makePause,
        'isPause'     : isPause,

        'pauseStack'  : pauseStack,
        'schedulePause'  : schedulePause,
        'breakAll' : breakAll,

        'getField'    : getField,
        'getFieldLoc'    : getFieldLoc,
        'getFields'    : getFields,
        'getColonField'    : getColonField,

        'hasBrand' : hasBrand,

        'isPyretTrue' : isPyretTrue,
        'isPyretFalse' : isPyretFalse,

        'isBase'      : isBase,
        'isNothing'   : isNothing,
        'isNumber'    : isNumber,
        'isString'    : isString,
        'isBoolean'   : isBoolean,
        'isFunction'  : isFunction,
        'isMethod'    : isMethod,
        'isObject'    : isObject,
        'isOpaque'    : isOpaque,
        'isPyretVal'  : isPyretVal,

        'makePyretFailException': makePyretFailException,

        'isSuccessResult' : isSuccessResult,
        'makeSuccessResult' : makeSuccessResult,
        'isFailureResult' : isFailureResult,
        'makeFailureResult' : makeFailureResult,
        'isPyretException' : isPyretException,

        'makeNothing'  : makeNothing,
        'makeNumber'   : makeNumber,
        'makeNumberBig'   : makeNumberBig,
        'makeNumberFromString'   : makeNumberFromString,
        'makeBoolean'  : makeBoolean,
        'makeString'   : makeString,
        'makeFunction' : makeFunction,
        'makeMethod'   : makeMethod,
        'makeMethodFromFun' : makeMethodFromFun,
        'makeObject'   : makeObject,
        'makeArray' : makeArray,
        'makeBrandedObject'   : makeBrandedObject,
        'makeOpaque'   : makeOpaque,

        'plus': plus,
        'minus': minus,
        'times': times,
        'divide': divide,
        'lessthan': lessthan,
        'greaterthan': greaterthan,
        'greaterequal': greaterequal,
        'lessequal': lessequal,

        'num_max': num_max,
        'num_min': num_min,
        'num_abs': num_abs,
        'num_sin': num_sin,
        'num_cos': num_cos,
        'num_tan': num_tan,
        'num_asin': num_asin,
        'num_acos': num_acos,
        'num_atan': num_atan,
        'num_modulo': num_modulo,
        'num_truncate': num_truncate,
        'num_sqrt': num_sqrt,
        'num_ceiling': num_ceiling,
        'num_floor': num_floor,
        'num_log': num_log,
        'num_exp': num_exp,
        'num_exact': num_exact,
        'num_is_integer': num_is_integer,
        'num_expt': num_expt,
        'num_tostring': num_tostring,

        'string_contains': string_contains,
        'string_append': string_append,
        'string_length': string_length,
        'string_tonumber': string_tonumber,
        'string_repeat': string_repeat,
        'string_substring': string_substring,
        'string_replace': string_replace,
        'string_split': string_split,
        'string_charat': string_charat,
        'string_toupper': string_toupper,
        'string_tolower': string_tolower,
        'string_explode': string_explode,
        'string_indexOf': string_indexOf,

        'raw_array_of': raw_array_of,
        'raw_array_get': raw_array_get,
        'raw_array_set': raw_array_set,
        'raw_array_length': raw_array_length,
        'raw_array_to_list': raw_array_to_list,


        'not': bool_not,

        'equiv': sameJSPy,
        'raise': raiseJSJS,

        'pyretTrue': pyretTrue,
        'pyretFalse': pyretFalse,

        'undefined': undefined,
        'create': Object.create,

        'hasField' : hasField.app,

        'toReprJS' : toReprJS,
        'toRepr' : function(val) { return toReprJS(val, "_torepr"); },

        'same' : same,
        'wrap' : wrap,
        'unwrap' : unwrap,

        'checkString' : checkString,
        'checkNumber' : checkNumber,
        'checkBoolean' : checkBoolean,
        'checkObject' : checkObject,
        'checkFunction' : checkFunction,
        'checkMethod' : checkMethod,
        'checkArray' : checkArray,
        'checkOpaque' : checkOpaque,
        'checkPyretVal' : checkPyretVal,
        'checkArity': checkArity,
        'makeCheckType' : makeCheckType,
        'checkIf'      : checkIf,
        'confirm'      : confirm,
        'makeMessageException'      : makeMessageException,
        'serial' : Math.random(),
        'log': log,

        'makeSrcloc': makeSrcloc,
        '_link': function(f, r) { return getField(list, "link").app(f, r); },

        'loadModule' : loadModule,
        'loadModules' : loadModules,
        'loadModulesNew' : loadModulesNew,
        'loadJSModules' : loadJSModules,
        'modules' : Object.create(null),
        'setStdout': function(newStdout) {
          theOutsideWorld.stdout = newStdout;
        },
        'getParam' : getParam,
        'setParam' : setParam,
        'hasParam' : hasParam
    };

    var ffi = {
      contractOk: true,
      isOk: function() { return true; }
    }


    var list;
    var srcloc;
    var ffi;
    loadModulesNew(thisRuntime.namespace,
      [require("trove/lists"), require("trove/srcloc")],
      function(listsLib, srclocLib) {
        list = getField(listsLib, "values");
        srcloc = getField(srclocLib, "values");
      });
    loadJSModules(thisRuntime.namespace, [require("js/ffi-helpers")], function(f) {
      ffi = f;
      thisRuntime["ffi"] = ffi;
    });

    // NOTE(joe): set a few of these explicitly to work with s-prim-app
    thisRuntime["throwMessageException"] = ffi.throwMessageException;
    thisRuntime["throwNoBranchesMatched"] = ffi.throwNoBranchesMatched;
    thisRuntime["throwNonBooleanCondition"] = ffi.throwNonBooleanCondition;
    thisRuntime["throwNonBooleanOp"] = ffi.throwNonBooleanOp;

    var ns = thisRuntime.namespace;
    var nsWithList = ns.set("_link", getField(list, "link"))
                       .set("_empty", getField(list, "empty"));
    thisRuntime.namespace = nsWithList;

    var checkList = makeCheckType(ffi.isList, "List");
    thisRuntime["checkList"] = checkList;

    return thisRuntime;
}

return  {'makeRuntime' : makeRuntime};

       });

define('js/runtime-util',[], function() {
  var gs = Math.floor(Math.random() * 10000);
  function gensym(name) {
    return name + String(gs++);
  }
  function memoModule(name, moduleFun) {
    var modname = gensym(name);
    return function(RUNTIME, NAMESPACE) {
      
      if(RUNTIME.modules[modname]) {
        return RUNTIME.modules[modname];
      }
      else {
        RUNTIME.modules[modname] = moduleFun(RUNTIME, NAMESPACE);
        return RUNTIME.modules[modname];
        // TODO(joe): We are *not* safe for deep calls on module loads.
        // If running the module blows the stack, then we fail to load
        // the module.
        /*
        return RUNTIME.safeCall(function() {
            return moduleFun(RUNTIME, NAMESPACE);
          }, function(moduleFunVal) {
            RUNTIME.modules[modname] = moduleFunVal;
            return moduleFunVal;
          });
        */
      }
    };
  }
  return {
      memoModule: memoModule
    };
});

define('trove/option',[],function() {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/base/option.arr7"]) {
return R.modules["$src/arr/base/option.arr7"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/base/option.arr";
var D = R.undefined;
var L = [[M,6,0,40,31,3,626],
[M,16,2,230,24,7,467],
[M,7,2,55,15,7,227],
[M,16,4,232,16,15,243],
[M,21,4,365,24,7,467],
[M,23,8,448,23,18,458],
[M,19,6,341,19,16,351],
[M,17,4,254,20,7,359],
[M,16,9,237,16,14,242],
[M,12,4,165,15,7,227],
[M,8,4,72,11,7,159]];
var _plus3 = NAMESPACE.get("_plus");
var builtins4 = NAMESPACE.get("builtins");
var nothing5 = NAMESPACE.get("nothing");
var torepr6 = NAMESPACE.get("torepr");
var $Hanf_bracket638 = function(anf_bracket509,Option110,provides4811,nothing5) {
var anf_fun5122 = G(anf_bracket509,"results",L[0]);
var $z1415 = D;
var $f2021 = function(_) {
return R.isFunction(anf_fun5122)?anf_fun5122.app():R.ffi.throwNonFunApp(L[0],anf_fun5122,[]);
};
try {
if(--R.GAS > 0) {
$z1415 = $f2021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2021,
"from":L[0]});
}
} catch($e1213) {
if(R.isCont($e1213)) {
var $ss1617 = {"from":L[0],
"go":function(checks5223) {
return $Hchecks6224(checks5223,Option110,provides4811,nothing5);
}};
$e1213.stack[R.EXN_STACKHEIGHT++] = $ss1617;
}
if(R.isPyretException($e1213)) {
$e1213.pyretStack.push(L[0]);
}
throw $e1213;
}
var $ret1819 = $Hchecks6224($z1415,Option110,provides4811,nothing5);
++R.GAS;
return $ret1819;
};
var $Hchecks6224 = function(checks5223,Option110,provides4811,nothing5) {
return R.makeObject({"answer":nothing5,
"provide-plus-types":R.makeObject({"values":provides4811,
"types":{"Option":Option110}}),
"checks":checks5223});
};
var $Hann_DASH_check_DASH_temp6125 = function(ann_DASH_check_DASH_temp3826) {
return ann_DASH_check_DASH_temp3826;
};
var $Hanf_arg6027 = function(anf_arg3228,_plus3) {
var $z3132 = D;
var $f3738 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg3228,(")")):R.ffi.throwNonFunApp(L[1],_plus3,[anf_arg3228,(")")]);
};
try {
if(--R.GAS > 0) {
$z3132 = $f3738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3738,
"from":L[1]});
}
} catch($e2930) {
if(R.isCont($e2930)) {
var $ss3334 = {"from":L[1],
"go":function(anf_arg3339) {
return $Hanf_arg5940(anf_arg3339,_plus3);
}};
$e2930.stack[R.EXN_STACKHEIGHT++] = $ss3334;
}
if(R.isPyretException($e2930)) {
$e2930.pyretStack.push(L[1]);
}
throw $e2930;
}
var $ret3536 = $Hanf_arg5940($z3132,_plus3);
++R.GAS;
return $ret3536;
};
var $Hanf_arg5940 = function(anf_arg3339,_plus3) {
var $z4344 = D;
var $f4950 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("("),anf_arg3339):R.ffi.throwNonFunApp(L[1],_plus3,[("("),anf_arg3339]);
};
try {
if(--R.GAS > 0) {
$z4344 = $f4950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4950,
"from":L[1]});
}
} catch($e4142) {
if(R.isCont($e4142)) {
var $ss4546 = {"from":L[1],
"go":function(anf_arg3451) {
return $Hanf_arg5852(anf_arg3451,_plus3);
}};
$e4142.stack[R.EXN_STACKHEIGHT++] = $ss4546;
}
if(R.isPyretException($e4142)) {
$e4142.pyretStack.push(L[1]);
}
throw $e4142;
}
var $ret4748 = $Hanf_arg5852($z4344,_plus3);
++R.GAS;
return $ret4748;
};
var $Hanf_arg5852 = function(anf_arg3451,_plus3) {
var $z5556 = D;
var $f6162 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("some"),anf_arg3451):R.ffi.throwNonFunApp(L[1],_plus3,[("some"),anf_arg3451]);
};
try {
if(--R.GAS > 0) {
$z5556 = $f6162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6162,
"from":L[1]});
}
} catch($e5354) {
if(R.isCont($e5354)) {
var $ss5758 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp3063) {
return $Hann_DASH_check_DASH_temp5764(ann_DASH_check_DASH_temp3063);
}};
$e5354.stack[R.EXN_STACKHEIGHT++] = $ss5758;
}
if(R.isPyretException($e5354)) {
$e5354.pyretStack.push(L[1]);
}
throw $e5354;
}
var $ret5960 = $Hann_DASH_check_DASH_temp5764($z5556);
++R.GAS;
return $ret5960;
};
var $Hann_DASH_check_DASH_temp5764 = function(ann_DASH_check_DASH_temp3063) {
return ann_DASH_check_DASH_temp3063;
};
var $Hcont_tail_arg5565 = function(cont_tail_arg2766,if_helper1967) {
if(--R.GAS > 0) {
$z6869 = R.isFunction(if_helper1967)?if_helper1967.app(cont_tail_arg2766):R.ffi.throwNonFunApp(L[1],if_helper1967,[cont_tail_arg2766]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored70) {
return R.isFunction(if_helper1967)?if_helper1967.app(cont_tail_arg2766):R.ffi.throwNonFunApp(L[1],if_helper1967,[cont_tail_arg2766]);
},
"from":L[1]});
}
++R.GAS;
return $z6869;
};
var $Hcont_tail_arg5671 = function(cont_tail_arg2472,if_helper1967) {
if(--R.GAS > 0) {
$z7374 = R.isFunction(if_helper1967)?if_helper1967.app(cont_tail_arg2472):R.ffi.throwNonFunApp(L[1],if_helper1967,[cont_tail_arg2472]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored70) {
return R.isFunction(if_helper1967)?if_helper1967.app(cont_tail_arg2472):R.ffi.throwNonFunApp(L[1],if_helper1967,[cont_tail_arg2472]);
},
"from":L[1]});
}
++R.GAS;
return $z7374;
};
var $Hcont_tail_arg5375 = function(cont_tail_arg976,if_helper277) {
if(--R.GAS > 0) {
$z7879 = R.isFunction(if_helper277)?if_helper277.app(cont_tail_arg976):R.ffi.throwNonFunApp(L[2],if_helper277,[cont_tail_arg976]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored70) {
return R.isFunction(if_helper277)?if_helper277.app(cont_tail_arg976):R.ffi.throwNonFunApp(L[2],if_helper277,[cont_tail_arg976]);
},
"from":L[2]});
}
++R.GAS;
return $z7879;
};
var $Hcont_tail_arg5480 = function(cont_tail_arg781,if_helper277) {
if(--R.GAS > 0) {
$z8283 = R.isFunction(if_helper277)?if_helper277.app(cont_tail_arg781):R.ffi.throwNonFunApp(L[2],if_helper277,[cont_tail_arg781]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored70) {
return R.isFunction(if_helper277)?if_helper277.app(cont_tail_arg781):R.ffi.throwNonFunApp(L[2],if_helper277,[cont_tail_arg781]);
},
"from":L[2]});
}
++R.GAS;
return $z8283;
};
return R.loadModulesNew(NAMESPACE,[],function() {
return R.safeCall(function() {
var OptionT1284 = R.namedBrander("Option");
var Option110 = R.makeBranderAnn(OptionT1284,"Option");
var Option2385 = {"$var":D,
"$name":"Option2"};
var Option487 = {"$var":D,
"$name":"Option"};
var is_DASH_Option589 = {"$var":D,
"$name":"is-Option"};
var is_DASH_none691 = {"$var":D,
"$name":"is-none"};
var none793 = {"$var":D,
"$name":"none"};
var is_DASH_some895 = {"$var":D,
"$name":"is-some"};
var some997 = {"$var":D,
"$name":"some"};
var anf_singleton_variant_member11115 = R.makeMethod(function(self2227) {
return function(cases_DASH_funs3208,else_DASH_clause4219) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2],2,arguments);
}
var if_DASH_6220 = R.hasField(cases_DASH_funs3208,("none"));
var if_helper277 = R.makeFunction(function(if_helper_arg3225) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
var ann_DASH_check_DASH_temp1226 = if_helper_arg3225;
return ann_DASH_check_DASH_temp1226;
});
var anf_if6224 = R.isBoolean(if_DASH_6220);
if(R.isPyretTrue(anf_if6224)) {
if(R.isPyretTrue(if_DASH_6220)) {
var call_DASH_none1207 = G(cases_DASH_funs3208,"none",L[2]);
var $z199200 = D;
var $f205206 = function(_) {
return R.isFunction(call_DASH_none1207)?call_DASH_none1207.app():R.ffi.throwNonFunApp(L[2],call_DASH_none1207,[]);
};
try {
if(--R.GAS > 0) {
$z199200 = $f205206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f205206,
"from":L[2]});
}
} catch($e197198) {
if(R.isCont($e197198)) {
var $ss201202 = {"from":L[2],
"go":function(cont_tail_arg976) {
return $Hcont_tail_arg5375(cont_tail_arg976,if_helper277);
}};
$e197198.stack[R.EXN_STACKHEIGHT++] = $ss201202;
}
if(R.isPyretException($e197198)) {
$e197198.pyretStack.push(L[2]);
}
throw $e197198;
}
var $ret203204 = $Hcont_tail_arg5375($z199200,if_helper277);
++R.GAS;
return $ret203204;
} else {
var $z211212 = D;
var $f217218 = function(_) {
return R.isFunction(else_DASH_clause4219)?else_DASH_clause4219.app():R.ffi.throwNonFunApp(L[2],else_DASH_clause4219,[]);
};
try {
if(--R.GAS > 0) {
$z211212 = $f217218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f217218,
"from":L[2]});
}
} catch($e209210) {
if(R.isCont($e209210)) {
var $ss213214 = {"from":L[2],
"go":function(cont_tail_arg781) {
return $Hcont_tail_arg5480(cont_tail_arg781,if_helper277);
}};
$e209210.stack[R.EXN_STACKHEIGHT++] = $ss213214;
}
if(R.isPyretException($e209210)) {
$e209210.pyretStack.push(L[2]);
}
throw $e209210;
}
var $ret215216 = $Hcont_tail_arg5480($z211212,if_helper277);
++R.GAS;
return $ret215216;
}
} else {
var cont_tail_arg4223 = R.throwNonBooleanCondition(L[2],("if"),if_DASH_6220);
if(--R.GAS > 0) {
$z221222 = R.isFunction(if_helper277)?if_helper277.app(cont_tail_arg4223):R.ffi.throwNonFunApp(L[2],if_helper277,[cont_tail_arg4223]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored70) {
return R.isFunction(if_helper277)?if_helper277.app(cont_tail_arg4223):R.ffi.throwNonFunApp(L[2],if_helper277,[cont_tail_arg4223]);
},
"from":L[2]});
}
++R.GAS;
return $z221222;
}
};
},{"length":3});
var anf_singleton_variant_member13116 = R.makeMethod(function(self5196) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2],0,arguments);
}
var ann_DASH_check_DASH_temp12195 = ("none");
return ann_DASH_check_DASH_temp12195;
};
},{"length":1});
var anf_singleton_variant_member15117 = R.makeMethod(function(self10194) {
return function(v11193) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[10],1,arguments);
}
var ann_DASH_check_DASH_temp14192 = v11193;
return ann_DASH_check_DASH_temp14192;
};
},{"length":2});
var anf_singleton_variant_member17118 = R.makeMethod(function(self12190) {
return function($underscore13191) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[9],1,arguments);
}
var ann_DASH_check_DASH_temp16189 = self12190;
return ann_DASH_check_DASH_temp16189;
};
},{"length":2});
var anf_variant_member29124 = R.makeMethod(function(self8169) {
return function(cases_DASH_funs9170,else_DASH_clause10181) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
var if_DASH_12182 = R.hasField(cases_DASH_funs9170,("some"));
var if_helper1967 = R.makeFunction(function(if_helper_arg20187) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
var ann_DASH_check_DASH_temp18188 = if_helper_arg20187;
return ann_DASH_check_DASH_temp18188;
});
var anf_if23186 = R.isBoolean(if_DASH_12182);
if(R.isPyretTrue(anf_if23186)) {
if(R.isPyretTrue(if_DASH_12182)) {
var call_DASH_some7167 = G(cases_DASH_funs9170,"some",L[1]);
var anf_arg26168 = G(self8169,"value",L[8]);
var $z159160 = D;
var $f165166 = function(_) {
return R.isFunction(call_DASH_some7167)?call_DASH_some7167.app(anf_arg26168):R.ffi.throwNonFunApp(L[1],call_DASH_some7167,[anf_arg26168]);
};
try {
if(--R.GAS > 0) {
$z159160 = $f165166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f165166,
"from":L[1]});
}
} catch($e157158) {
if(R.isCont($e157158)) {
var $ss161162 = {"from":L[1],
"go":function(cont_tail_arg2766) {
return $Hcont_tail_arg5565(cont_tail_arg2766,if_helper1967);
}};
$e157158.stack[R.EXN_STACKHEIGHT++] = $ss161162;
}
if(R.isPyretException($e157158)) {
$e157158.pyretStack.push(L[1]);
}
throw $e157158;
}
var $ret163164 = $Hcont_tail_arg5565($z159160,if_helper1967);
++R.GAS;
return $ret163164;
} else {
var $z173174 = D;
var $f179180 = function(_) {
return R.isFunction(else_DASH_clause10181)?else_DASH_clause10181.app():R.ffi.throwNonFunApp(L[1],else_DASH_clause10181,[]);
};
try {
if(--R.GAS > 0) {
$z173174 = $f179180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f179180,
"from":L[1]});
}
} catch($e171172) {
if(R.isCont($e171172)) {
var $ss175176 = {"from":L[1],
"go":function(cont_tail_arg2472) {
return $Hcont_tail_arg5671(cont_tail_arg2472,if_helper1967);
}};
$e171172.stack[R.EXN_STACKHEIGHT++] = $ss175176;
}
if(R.isPyretException($e171172)) {
$e171172.pyretStack.push(L[1]);
}
throw $e171172;
}
var $ret177178 = $Hcont_tail_arg5671($z173174,if_helper1967);
++R.GAS;
return $ret177178;
}
} else {
var cont_tail_arg21185 = R.throwNonBooleanCondition(L[1],("if"),if_DASH_12182);
if(--R.GAS > 0) {
$z183184 = R.isFunction(if_helper1967)?if_helper1967.app(cont_tail_arg21185):R.ffi.throwNonFunApp(L[1],if_helper1967,[cont_tail_arg21185]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored70) {
return R.isFunction(if_helper1967)?if_helper1967.app(cont_tail_arg21185):R.ffi.throwNonFunApp(L[1],if_helper1967,[cont_tail_arg21185]);
},
"from":L[1]});
}
++R.GAS;
return $z183184;
}
};
},{"length":3});
var anf_variant_member35125 = R.makeMethod(function(self11156) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1],0,arguments);
}
var anf_arg31155 = G(self11156,"value",L[1]);
var $z147148 = D;
var $f153154 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg31155):R.ffi.throwNonFunApp(L[1],torepr6,[anf_arg31155]);
};
try {
if(--R.GAS > 0) {
$z147148 = $f153154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f153154,
"from":L[1]});
}
} catch($e145146) {
if(R.isCont($e145146)) {
var $ss149150 = {"from":L[1],
"go":function(anf_arg3228) {
return $Hanf_arg6027(anf_arg3228,_plus3);
}};
$e145146.stack[R.EXN_STACKHEIGHT++] = $ss149150;
}
if(R.isPyretException($e145146)) {
$e145146.pyretStack.push(L[1]);
}
throw $e145146;
}
var $ret151152 = $Hanf_arg6027($z147148,_plus3);
++R.GAS;
return $ret151152;
};
},{"length":1});
var anf_variant_member37126 = R.makeMethod(function(self15143) {
return function(v16144) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
var ann_DASH_check_DASH_temp36142 = G(self15143,"value",L[6]);
return ann_DASH_check_DASH_temp36142;
};
},{"length":2});
var anf_variant_member40127 = R.makeMethod(function(self17141) {
return function(f18139) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
var anf_arg39140 = G(self17141,"value",L[5]);
var $z131132 = D;
var $f137138 = function(_) {
return R.isFunction(f18139)?f18139.app(anf_arg39140):R.ffi.throwNonFunApp(L[4],f18139,[anf_arg39140]);
};
try {
if(--R.GAS > 0) {
$z131132 = $f137138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f137138,
"from":L[4]});
}
} catch($e129130) {
if(R.isCont($e129130)) {
var $ss133134 = {"from":L[4],
"go":function(ann_DASH_check_DASH_temp3826) {
return $Hann_DASH_check_DASH_temp6125(ann_DASH_check_DASH_temp3826);
}};
$e129130.stack[R.EXN_STACKHEIGHT++] = $ss133134;
}
if(R.isPyretException($e129130)) {
$e129130.pyretStack.push(L[4]);
}
throw $e129130;
}
var $ret135136 = $Hann_DASH_check_DASH_temp6125($z131132);
++R.GAS;
return $ret135136;
};
},{"length":2});
var anf_assign4186 = (function() {
var $none_DASH_base110111 = {"_match":anf_singleton_variant_member11115,
"_torepr":anf_singleton_variant_member13116,
"or-else":anf_singleton_variant_member15117,
"and-then":anf_singleton_variant_member17118};
var $none_DASH_brands113114 = {"$brand-none112":true};
$none_DASH_brands113114[OptionT1284._brand] = true
var $some_DASH_base119120 = {"_match":anf_variant_member29124,
"_torepr":anf_variant_member35125,
"or-else":anf_variant_member37126,
"and-then":anf_variant_member40127};
var $some_DASH_brands122123 = {"$brand-some121":true};
$some_DASH_brands122123[OptionT1284._brand] = true
return R.makeObject({"Option":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,OptionT1284._brand));
}),
"is-none":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-none112"));
}),
"none":R.makeBrandedObject($none_DASH_base110111,$none_DASH_brands113114),
"is-some":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-some121"));
}),
"some":R.makeFunction(function(value14128) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
var dict = R.create($some_DASH_base119120);
dict["value"] = value14128
return R.makeBrandedObject(dict,$some_DASH_brands122123);
})});
})();
Option2385.$var = anf_assign4186;
var anf_assign4288 = G(Option2385.$var,"Option",L[0]);
Option487.$var = anf_assign4288;
var anf_assign4390 = G(Option2385.$var,"Option",L[0]);
is_DASH_Option589.$var = anf_assign4390;
var anf_assign4492 = G(Option2385.$var,"is-none",L[2]);
is_DASH_none691.$var = anf_assign4492;
var anf_assign4594 = G(Option2385.$var,"none",L[2]);
none793.$var = anf_assign4594;
var anf_assign4696 = G(Option2385.$var,"is-some",L[1]);
is_DASH_some895.$var = anf_assign4696;
var anf_assign4798 = G(Option2385.$var,"some",L[1]);
some997.$var = anf_assign4798;
var provides4811 = R.makeObject({"Option":Option487.$var,
"is-Option":is_DASH_Option589.$var,
"none":none793.$var,
"is-none":is_DASH_none691.$var,
"some":some997.$var,
"is-some":is_DASH_some895.$var});
var anf_fun49109 = G(builtins4,"current-checker",L[0]);
var $z101102 = D;
var $f107108 = function(_) {
return R.isFunction(anf_fun49109)?anf_fun49109.app():R.ffi.throwNonFunApp(L[0],anf_fun49109,[]);
};
try {
if(--R.GAS > 0) {
$z101102 = $f107108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f107108,
"from":L[0]});
}
} catch($e99100) {
if(R.isCont($e99100)) {
var $ss103104 = {"from":L[0],
"go":function(anf_bracket509) {
return $Hanf_bracket638(anf_bracket509,Option110,provides4811,nothing5);
}};
$e99100.stack[R.EXN_STACKHEIGHT++] = $ss103104;
}
if(R.isPyretException($e99100)) {
$e99100.pyretStack.push(L[0]);
}
throw $e99100;
}
var $ret105106 = $Hanf_bracket638($z101102,Option110,provides4811,nothing5);
++R.GAS;
return $ret105106;
},function(moduleVal) {
R.modules["$src/arr/base/option.arr7"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/either',[],function() {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/base/either.arr7"]) {
return R.modules["$src/arr/base/either.arr7"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/base/either.arr";
var D = R.undefined;
var L = [[M,6,0,40,9,3,96],
[M,8,2,77,8,17,92],
[M,7,2,60,7,16,74],
[M,7,4,62,7,16,74],
[M,8,4,79,8,17,92],
[M,8,10,85,8,16,91],
[M,7,9,67,7,15,73]];
var _plus3 = NAMESPACE.get("_plus");
var builtins4 = NAMESPACE.get("builtins");
var nothing5 = NAMESPACE.get("nothing");
var torepr6 = NAMESPACE.get("torepr");
var $Hanf_bracket628 = function(anf_bracket469,Either110,provides4411,nothing5) {
var anf_fun4722 = G(anf_bracket469,"results",L[0]);
var $z1415 = D;
var $f2021 = function(_) {
return R.isFunction(anf_fun4722)?anf_fun4722.app():R.ffi.throwNonFunApp(L[0],anf_fun4722,[]);
};
try {
if(--R.GAS > 0) {
$z1415 = $f2021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2021,
"from":L[0]});
}
} catch($e1213) {
if(R.isCont($e1213)) {
var $ss1617 = {"from":L[0],
"go":function(checks4823) {
return $Hchecks6124(checks4823,Either110,provides4411,nothing5);
}};
$e1213.stack[R.EXN_STACKHEIGHT++] = $ss1617;
}
if(R.isPyretException($e1213)) {
$e1213.pyretStack.push(L[0]);
}
throw $e1213;
}
var $ret1819 = $Hchecks6124($z1415,Either110,provides4411,nothing5);
++R.GAS;
return $ret1819;
};
var $Hchecks6124 = function(checks4823,Either110,provides4411,nothing5) {
return R.makeObject({"answer":nothing5,
"provide-plus-types":R.makeObject({"values":provides4411,
"types":{"Either":Either110}}),
"checks":checks4823});
};
var $Hanf_arg6025 = function(anf_arg3326,_plus3) {
var $z2930 = D;
var $f3536 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg3326,(")")):R.ffi.throwNonFunApp(L[1],_plus3,[anf_arg3326,(")")]);
};
try {
if(--R.GAS > 0) {
$z2930 = $f3536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3536,
"from":L[1]});
}
} catch($e2728) {
if(R.isCont($e2728)) {
var $ss3132 = {"from":L[1],
"go":function(anf_arg3437) {
return $Hanf_arg5938(anf_arg3437,_plus3);
}};
$e2728.stack[R.EXN_STACKHEIGHT++] = $ss3132;
}
if(R.isPyretException($e2728)) {
$e2728.pyretStack.push(L[1]);
}
throw $e2728;
}
var $ret3334 = $Hanf_arg5938($z2930,_plus3);
++R.GAS;
return $ret3334;
};
var $Hanf_arg5938 = function(anf_arg3437,_plus3) {
var $z4142 = D;
var $f4748 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("("),anf_arg3437):R.ffi.throwNonFunApp(L[1],_plus3,[("("),anf_arg3437]);
};
try {
if(--R.GAS > 0) {
$z4142 = $f4748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4748,
"from":L[1]});
}
} catch($e3940) {
if(R.isCont($e3940)) {
var $ss4344 = {"from":L[1],
"go":function(anf_arg3549) {
return $Hanf_arg5850(anf_arg3549,_plus3);
}};
$e3940.stack[R.EXN_STACKHEIGHT++] = $ss4344;
}
if(R.isPyretException($e3940)) {
$e3940.pyretStack.push(L[1]);
}
throw $e3940;
}
var $ret4546 = $Hanf_arg5850($z4142,_plus3);
++R.GAS;
return $ret4546;
};
var $Hanf_arg5850 = function(anf_arg3549,_plus3) {
var $z5354 = D;
var $f5960 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("right"),anf_arg3549):R.ffi.throwNonFunApp(L[1],_plus3,[("right"),anf_arg3549]);
};
try {
if(--R.GAS > 0) {
$z5354 = $f5960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5960,
"from":L[1]});
}
} catch($e5152) {
if(R.isCont($e5152)) {
var $ss5556 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp3161) {
return $Hann_DASH_check_DASH_temp5762(ann_DASH_check_DASH_temp3161);
}};
$e5152.stack[R.EXN_STACKHEIGHT++] = $ss5556;
}
if(R.isPyretException($e5152)) {
$e5152.pyretStack.push(L[1]);
}
throw $e5152;
}
var $ret5758 = $Hann_DASH_check_DASH_temp5762($z5354);
++R.GAS;
return $ret5758;
};
var $Hann_DASH_check_DASH_temp5762 = function(ann_DASH_check_DASH_temp3161) {
return ann_DASH_check_DASH_temp3161;
};
var $Hcont_tail_arg5563 = function(cont_tail_arg2864,if_helper2065) {
if(--R.GAS > 0) {
$z6667 = R.isFunction(if_helper2065)?if_helper2065.app(cont_tail_arg2864):R.ffi.throwNonFunApp(L[1],if_helper2065,[cont_tail_arg2864]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored68) {
return R.isFunction(if_helper2065)?if_helper2065.app(cont_tail_arg2864):R.ffi.throwNonFunApp(L[1],if_helper2065,[cont_tail_arg2864]);
},
"from":L[1]});
}
++R.GAS;
return $z6667;
};
var $Hcont_tail_arg5669 = function(cont_tail_arg2570,if_helper2065) {
if(--R.GAS > 0) {
$z7172 = R.isFunction(if_helper2065)?if_helper2065.app(cont_tail_arg2570):R.ffi.throwNonFunApp(L[1],if_helper2065,[cont_tail_arg2570]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored68) {
return R.isFunction(if_helper2065)?if_helper2065.app(cont_tail_arg2570):R.ffi.throwNonFunApp(L[1],if_helper2065,[cont_tail_arg2570]);
},
"from":L[1]});
}
++R.GAS;
return $z7172;
};
var $Hanf_arg5473 = function(anf_arg1574,_plus3) {
var $z7778 = D;
var $f8384 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg1574,(")")):R.ffi.throwNonFunApp(L[2],_plus3,[anf_arg1574,(")")]);
};
try {
if(--R.GAS > 0) {
$z7778 = $f8384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8384,
"from":L[2]});
}
} catch($e7576) {
if(R.isCont($e7576)) {
var $ss7980 = {"from":L[2],
"go":function(anf_arg1685) {
return $Hanf_arg5386(anf_arg1685,_plus3);
}};
$e7576.stack[R.EXN_STACKHEIGHT++] = $ss7980;
}
if(R.isPyretException($e7576)) {
$e7576.pyretStack.push(L[2]);
}
throw $e7576;
}
var $ret8182 = $Hanf_arg5386($z7778,_plus3);
++R.GAS;
return $ret8182;
};
var $Hanf_arg5386 = function(anf_arg1685,_plus3) {
var $z8990 = D;
var $f9596 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("("),anf_arg1685):R.ffi.throwNonFunApp(L[2],_plus3,[("("),anf_arg1685]);
};
try {
if(--R.GAS > 0) {
$z8990 = $f9596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9596,
"from":L[2]});
}
} catch($e8788) {
if(R.isCont($e8788)) {
var $ss9192 = {"from":L[2],
"go":function(anf_arg1797) {
return $Hanf_arg5298(anf_arg1797,_plus3);
}};
$e8788.stack[R.EXN_STACKHEIGHT++] = $ss9192;
}
if(R.isPyretException($e8788)) {
$e8788.pyretStack.push(L[2]);
}
throw $e8788;
}
var $ret9394 = $Hanf_arg5298($z8990,_plus3);
++R.GAS;
return $ret9394;
};
var $Hanf_arg5298 = function(anf_arg1797,_plus3) {
var $z101102 = D;
var $f107108 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("left"),anf_arg1797):R.ffi.throwNonFunApp(L[2],_plus3,[("left"),anf_arg1797]);
};
try {
if(--R.GAS > 0) {
$z101102 = $f107108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f107108,
"from":L[2]});
}
} catch($e99100) {
if(R.isCont($e99100)) {
var $ss103104 = {"from":L[2],
"go":function(ann_DASH_check_DASH_temp13109) {
return $Hann_DASH_check_DASH_temp51110(ann_DASH_check_DASH_temp13109);
}};
$e99100.stack[R.EXN_STACKHEIGHT++] = $ss103104;
}
if(R.isPyretException($e99100)) {
$e99100.pyretStack.push(L[2]);
}
throw $e99100;
}
var $ret105106 = $Hann_DASH_check_DASH_temp51110($z101102);
++R.GAS;
return $ret105106;
};
var $Hann_DASH_check_DASH_temp51110 = function(ann_DASH_check_DASH_temp13109) {
return ann_DASH_check_DASH_temp13109;
};
var $Hcont_tail_arg49111 = function(cont_tail_arg10112,if_helper2113) {
if(--R.GAS > 0) {
$z114115 = R.isFunction(if_helper2113)?if_helper2113.app(cont_tail_arg10112):R.ffi.throwNonFunApp(L[2],if_helper2113,[cont_tail_arg10112]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored68) {
return R.isFunction(if_helper2113)?if_helper2113.app(cont_tail_arg10112):R.ffi.throwNonFunApp(L[2],if_helper2113,[cont_tail_arg10112]);
},
"from":L[2]});
}
++R.GAS;
return $z114115;
};
var $Hcont_tail_arg50116 = function(cont_tail_arg7117,if_helper2113) {
if(--R.GAS > 0) {
$z118119 = R.isFunction(if_helper2113)?if_helper2113.app(cont_tail_arg7117):R.ffi.throwNonFunApp(L[2],if_helper2113,[cont_tail_arg7117]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored68) {
return R.isFunction(if_helper2113)?if_helper2113.app(cont_tail_arg7117):R.ffi.throwNonFunApp(L[2],if_helper2113,[cont_tail_arg7117]);
},
"from":L[2]});
}
++R.GAS;
return $z118119;
};
return R.loadModulesNew(NAMESPACE,[],function() {
return R.safeCall(function() {
var EitherT12120 = R.namedBrander("Either");
var Either110 = R.makeBranderAnn(EitherT12120,"Either");
var Either23121 = {"$var":D,
"$name":"Either2"};
var Either4123 = {"$var":D,
"$name":"Either"};
var is_DASH_Either5125 = {"$var":D,
"$name":"is-Either"};
var is_DASH_left6127 = {"$var":D,
"$name":"is-left"};
var left7129 = {"$var":D,
"$name":"left"};
var is_DASH_right8131 = {"$var":D,
"$name":"is-right"};
var right9133 = {"$var":D,
"$name":"right"};
var anf_variant_member12151 = R.makeMethod(function(self2230) {
return function(cases_DASH_funs3231,else_DASH_clause4242) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2],2,arguments);
}
var if_DASH_6243 = R.hasField(cases_DASH_funs3231,("left"));
var if_helper2113 = R.makeFunction(function(if_helper_arg3248) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
var ann_DASH_check_DASH_temp1249 = if_helper_arg3248;
return ann_DASH_check_DASH_temp1249;
});
var anf_if6247 = R.isBoolean(if_DASH_6243);
if(R.isPyretTrue(anf_if6247)) {
if(R.isPyretTrue(if_DASH_6243)) {
var call_DASH_left1228 = G(cases_DASH_funs3231,"left",L[2]);
var anf_arg9229 = G(self2230,"v",L[6]);
var $z220221 = D;
var $f226227 = function(_) {
return R.isFunction(call_DASH_left1228)?call_DASH_left1228.app(anf_arg9229):R.ffi.throwNonFunApp(L[2],call_DASH_left1228,[anf_arg9229]);
};
try {
if(--R.GAS > 0) {
$z220221 = $f226227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f226227,
"from":L[2]});
}
} catch($e218219) {
if(R.isCont($e218219)) {
var $ss222223 = {"from":L[2],
"go":function(cont_tail_arg10112) {
return $Hcont_tail_arg49111(cont_tail_arg10112,if_helper2113);
}};
$e218219.stack[R.EXN_STACKHEIGHT++] = $ss222223;
}
if(R.isPyretException($e218219)) {
$e218219.pyretStack.push(L[2]);
}
throw $e218219;
}
var $ret224225 = $Hcont_tail_arg49111($z220221,if_helper2113);
++R.GAS;
return $ret224225;
} else {
var $z234235 = D;
var $f240241 = function(_) {
return R.isFunction(else_DASH_clause4242)?else_DASH_clause4242.app():R.ffi.throwNonFunApp(L[2],else_DASH_clause4242,[]);
};
try {
if(--R.GAS > 0) {
$z234235 = $f240241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f240241,
"from":L[2]});
}
} catch($e232233) {
if(R.isCont($e232233)) {
var $ss236237 = {"from":L[2],
"go":function(cont_tail_arg7117) {
return $Hcont_tail_arg50116(cont_tail_arg7117,if_helper2113);
}};
$e232233.stack[R.EXN_STACKHEIGHT++] = $ss236237;
}
if(R.isPyretException($e232233)) {
$e232233.pyretStack.push(L[2]);
}
throw $e232233;
}
var $ret238239 = $Hcont_tail_arg50116($z234235,if_helper2113);
++R.GAS;
return $ret238239;
}
} else {
var cont_tail_arg4246 = R.throwNonBooleanCondition(L[2],("if"),if_DASH_6243);
if(--R.GAS > 0) {
$z244245 = R.isFunction(if_helper2113)?if_helper2113.app(cont_tail_arg4246):R.ffi.throwNonFunApp(L[2],if_helper2113,[cont_tail_arg4246]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored68) {
return R.isFunction(if_helper2113)?if_helper2113.app(cont_tail_arg4246):R.ffi.throwNonFunApp(L[2],if_helper2113,[cont_tail_arg4246]);
},
"from":L[2]});
}
++R.GAS;
return $z244245;
}
};
},{"length":3});
var anf_variant_member18152 = R.makeMethod(function(self5217) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2],0,arguments);
}
var anf_arg14216 = G(self5217,"v",L[2]);
var $z208209 = D;
var $f214215 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg14216):R.ffi.throwNonFunApp(L[2],torepr6,[anf_arg14216]);
};
try {
if(--R.GAS > 0) {
$z208209 = $f214215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f214215,
"from":L[2]});
}
} catch($e206207) {
if(R.isCont($e206207)) {
var $ss210211 = {"from":L[2],
"go":function(anf_arg1574) {
return $Hanf_arg5473(anf_arg1574,_plus3);
}};
$e206207.stack[R.EXN_STACKHEIGHT++] = $ss210211;
}
if(R.isPyretException($e206207)) {
$e206207.pyretStack.push(L[2]);
}
throw $e206207;
}
var $ret212213 = $Hanf_arg5473($z208209,_plus3);
++R.GAS;
return $ret212213;
};
},{"length":1});
var anf_variant_member30159 = R.makeMethod(function(self8186) {
return function(cases_DASH_funs9187,else_DASH_clause10198) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
var if_DASH_12199 = R.hasField(cases_DASH_funs9187,("right"));
var if_helper2065 = R.makeFunction(function(if_helper_arg21204) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
var ann_DASH_check_DASH_temp19205 = if_helper_arg21204;
return ann_DASH_check_DASH_temp19205;
});
var anf_if24203 = R.isBoolean(if_DASH_12199);
if(R.isPyretTrue(anf_if24203)) {
if(R.isPyretTrue(if_DASH_12199)) {
var call_DASH_right7184 = G(cases_DASH_funs9187,"right",L[1]);
var anf_arg27185 = G(self8186,"v",L[5]);
var $z176177 = D;
var $f182183 = function(_) {
return R.isFunction(call_DASH_right7184)?call_DASH_right7184.app(anf_arg27185):R.ffi.throwNonFunApp(L[1],call_DASH_right7184,[anf_arg27185]);
};
try {
if(--R.GAS > 0) {
$z176177 = $f182183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f182183,
"from":L[1]});
}
} catch($e174175) {
if(R.isCont($e174175)) {
var $ss178179 = {"from":L[1],
"go":function(cont_tail_arg2864) {
return $Hcont_tail_arg5563(cont_tail_arg2864,if_helper2065);
}};
$e174175.stack[R.EXN_STACKHEIGHT++] = $ss178179;
}
if(R.isPyretException($e174175)) {
$e174175.pyretStack.push(L[1]);
}
throw $e174175;
}
var $ret180181 = $Hcont_tail_arg5563($z176177,if_helper2065);
++R.GAS;
return $ret180181;
} else {
var $z190191 = D;
var $f196197 = function(_) {
return R.isFunction(else_DASH_clause10198)?else_DASH_clause10198.app():R.ffi.throwNonFunApp(L[1],else_DASH_clause10198,[]);
};
try {
if(--R.GAS > 0) {
$z190191 = $f196197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f196197,
"from":L[1]});
}
} catch($e188189) {
if(R.isCont($e188189)) {
var $ss192193 = {"from":L[1],
"go":function(cont_tail_arg2570) {
return $Hcont_tail_arg5669(cont_tail_arg2570,if_helper2065);
}};
$e188189.stack[R.EXN_STACKHEIGHT++] = $ss192193;
}
if(R.isPyretException($e188189)) {
$e188189.pyretStack.push(L[1]);
}
throw $e188189;
}
var $ret194195 = $Hcont_tail_arg5669($z190191,if_helper2065);
++R.GAS;
return $ret194195;
}
} else {
var cont_tail_arg22202 = R.throwNonBooleanCondition(L[1],("if"),if_DASH_12199);
if(--R.GAS > 0) {
$z200201 = R.isFunction(if_helper2065)?if_helper2065.app(cont_tail_arg22202):R.ffi.throwNonFunApp(L[1],if_helper2065,[cont_tail_arg22202]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored68) {
return R.isFunction(if_helper2065)?if_helper2065.app(cont_tail_arg22202):R.ffi.throwNonFunApp(L[1],if_helper2065,[cont_tail_arg22202]);
},
"from":L[1]});
}
++R.GAS;
return $z200201;
}
};
},{"length":3});
var anf_variant_member36160 = R.makeMethod(function(self11173) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1],0,arguments);
}
var anf_arg32172 = G(self11173,"v",L[1]);
var $z164165 = D;
var $f170171 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg32172):R.ffi.throwNonFunApp(L[1],torepr6,[anf_arg32172]);
};
try {
if(--R.GAS > 0) {
$z164165 = $f170171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f170171,
"from":L[1]});
}
} catch($e162163) {
if(R.isCont($e162163)) {
var $ss166167 = {"from":L[1],
"go":function(anf_arg3326) {
return $Hanf_arg6025(anf_arg3326,_plus3);
}};
$e162163.stack[R.EXN_STACKHEIGHT++] = $ss166167;
}
if(R.isPyretException($e162163)) {
$e162163.pyretStack.push(L[1]);
}
throw $e162163;
}
var $ret168169 = $Hanf_arg6025($z164165,_plus3);
++R.GAS;
return $ret168169;
};
},{"length":1});
var anf_assign37122 = (function() {
var $left_DASH_base146147 = {"_match":anf_variant_member12151,
"_torepr":anf_variant_member18152};
var $left_DASH_brands149150 = {"$brand-left148":true};
$left_DASH_brands149150[EitherT12120._brand] = true
var $right_DASH_base154155 = {"_match":anf_variant_member30159,
"_torepr":anf_variant_member36160};
var $right_DASH_brands157158 = {"$brand-right156":true};
$right_DASH_brands157158[EitherT12120._brand] = true
return R.makeObject({"Either":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,EitherT12120._brand));
}),
"is-left":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-left148"));
}),
"left":R.makeFunction(function(v12153) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
var dict = R.create($left_DASH_base146147);
dict["v"] = v12153
return R.makeBrandedObject(dict,$left_DASH_brands149150);
}),
"is-right":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-right156"));
}),
"right":R.makeFunction(function(v13161) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
var dict = R.create($right_DASH_base154155);
dict["v"] = v13161
return R.makeBrandedObject(dict,$right_DASH_brands157158);
})});
})();
Either23121.$var = anf_assign37122;
var anf_assign38124 = G(Either23121.$var,"Either",L[0]);
Either4123.$var = anf_assign38124;
var anf_assign39126 = G(Either23121.$var,"Either",L[0]);
is_DASH_Either5125.$var = anf_assign39126;
var anf_assign40128 = G(Either23121.$var,"is-left",L[2]);
is_DASH_left6127.$var = anf_assign40128;
var anf_assign41130 = G(Either23121.$var,"left",L[2]);
left7129.$var = anf_assign41130;
var anf_assign42132 = G(Either23121.$var,"is-right",L[1]);
is_DASH_right8131.$var = anf_assign42132;
var anf_assign43134 = G(Either23121.$var,"right",L[1]);
right9133.$var = anf_assign43134;
var provides4411 = R.makeObject({"Either":Either4123.$var,
"is-Either":is_DASH_Either5125.$var,
"left":left7129.$var,
"is-left":is_DASH_left6127.$var,
"right":right9133.$var,
"is-right":is_DASH_right8131.$var});
var anf_fun45145 = G(builtins4,"current-checker",L[0]);
var $z137138 = D;
var $f143144 = function(_) {
return R.isFunction(anf_fun45145)?anf_fun45145.app():R.ffi.throwNonFunApp(L[0],anf_fun45145,[]);
};
try {
if(--R.GAS > 0) {
$z137138 = $f143144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f143144,
"from":L[0]});
}
} catch($e135136) {
if(R.isCont($e135136)) {
var $ss139140 = {"from":L[0],
"go":function(anf_bracket469) {
return $Hanf_bracket628(anf_bracket469,Either110,provides4411,nothing5);
}};
$e135136.stack[R.EXN_STACKHEIGHT++] = $ss139140;
}
if(R.isPyretException($e135136)) {
$e135136.pyretStack.push(L[0]);
}
throw $e135136;
}
var $ret141142 = $Hanf_bracket628($z137138,Either110,provides4411,nothing5);
++R.GAS;
return $ret141142;
},function(moduleVal) {
R.modules["$src/arr/base/either.arr7"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/lists',["trove/option",
"trove/either"],function($O11621,$E31722) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/base/lists.arr20"]) {
return R.modules["$src/arr/base/lists.arr20"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/base/lists.arr";
var D = R.undefined;
var L = [[M,18,0,222,279,3,8882],
[M,748,6,24121,748,9,24124],
[M,750,11,24146,750,17,24152],
[M,747,7,24091,747,29,24113],
[M,750,18,24153,750,47,24182],
[M,750,28,24163,750,46,24181],
[M,750,6,24141,750,67,24202],
[M,750,49,24184,750,66,24201],
[M,736,5,23603,736,66,23664],
[M,736,5,23603,736,17,23615],
[M,737,4,23669,737,8,23673],
[M,739,13,23695,739,60,23742],
[M,739,51,23733,739,59,23741],
[M,739,41,23723,739,49,23731],
[M,739,31,23713,739,39,23721],
[M,739,21,23703,739,29,23711],
[M,736,21,23619,736,33,23631],
[M,736,37,23635,736,49,23647],
[M,736,53,23651,736,65,23663],
[M,739,4,23686,739,97,23779],
[M,739,89,23771,739,96,23778],
[M,739,80,23762,739,87,23769],
[M,739,71,23753,739,78,23760],
[M,739,62,23744,739,69,23751],
[M,726,5,23174,726,50,23219],
[M,726,5,23174,726,17,23186],
[M,727,4,23224,727,8,23228],
[M,729,13,23250,729,50,23287],
[M,729,41,23278,729,49,23286],
[M,729,31,23268,729,39,23276],
[M,729,21,23258,729,29,23266],
[M,726,21,23190,726,33,23202],
[M,726,37,23206,726,49,23218],
[M,729,4,23241,729,78,23315],
[M,729,70,23307,729,77,23314],
[M,729,61,23298,729,68,23305],
[M,729,52,23289,729,59,23296],
[M,716,5,22791,716,34,22820],
[M,716,5,22791,716,17,22803],
[M,717,4,22825,717,8,22829],
[M,719,13,22851,719,40,22878],
[M,719,31,22869,719,39,22877],
[M,719,21,22859,719,29,22867],
[M,716,21,22807,716,33,22819],
[M,719,4,22842,719,59,22897],
[M,719,51,22889,719,58,22896],
[M,719,42,22880,719,49,22887],
[M,703,4,22289,703,8,22293],
[M,705,12,22314,705,30,22332],
[M,705,20,22322,705,29,22331],
[M,702,5,22270,702,18,22283],
[M,705,4,22306,705,41,22343],
[M,705,32,22334,705,40,22342],
[M,691,4,21941,695,9,22069],
[M,692,6,21965,695,9,22069],
[M,694,8,22044,694,23,22059],
[M,693,8,22003,693,40,22035],
[M,675,7,21357,675,68,21418],
[M,675,7,21357,675,19,21369],
[M,676,6,21425,676,13,21432],
[M,678,6,21449,678,50,21493],
[M,678,41,21484,678,49,21492],
[M,678,31,21474,678,39,21482],
[M,678,21,21464,678,29,21472],
[M,678,11,21454,678,19,21462],
[M,675,23,21373,675,35,21385],
[M,675,39,21389,675,51,21401],
[M,675,55,21405,675,67,21417],
[M,679,11,21505,679,17,21511],
[M,679,6,21500,679,53,21547],
[M,679,45,21539,679,52,21546],
[M,679,36,21530,679,43,21537],
[M,679,27,21521,679,34,21528],
[M,679,18,21512,679,25,21519],
[M,662,7,20882,662,52,20927],
[M,662,7,20882,662,19,20894],
[M,663,6,20934,663,13,20941],
[M,665,6,20958,665,40,20992],
[M,665,31,20983,665,39,20991],
[M,665,21,20973,665,29,20981],
[M,665,11,20963,665,19,20971],
[M,662,23,20898,662,35,20910],
[M,662,39,20914,662,51,20926],
[M,666,11,21004,666,17,21010],
[M,666,6,20999,666,44,21037],
[M,666,36,21029,666,43,21036],
[M,666,27,21020,666,34,21027],
[M,666,18,21011,666,25,21018],
[M,649,7,20482,649,36,20511],
[M,649,7,20482,649,19,20494],
[M,650,6,20518,650,13,20525],
[M,652,6,20542,652,30,20566],
[M,652,21,20557,652,29,20565],
[M,652,11,20547,652,19,20555],
[M,649,23,20498,649,35,20510],
[M,653,11,20578,653,17,20584],
[M,653,6,20573,653,35,20602],
[M,653,27,20594,653,34,20601],
[M,653,18,20585,653,25,20592],
[M,637,6,20180,637,13,20187],
[M,639,6,20204,639,19,20217],
[M,639,11,20209,639,18,20216],
[M,636,7,20161,636,18,20172],
[M,640,11,20229,640,17,20235],
[M,640,6,20224,640,25,20243],
[M,640,18,20236,640,24,20242],
[M,623,7,19769,623,68,19830],
[M,623,7,19769,623,19,19781],
[M,624,6,19837,624,13,19844],
[M,626,6,19861,626,47,19902],
[M,626,38,19893,626,46,19901],
[M,626,28,19883,626,36,19891],
[M,626,18,19873,626,26,19881],
[M,626,8,19863,626,16,19871],
[M,623,23,19785,623,35,19797],
[M,623,39,19801,623,51,19813],
[M,623,55,19817,623,67,19829],
[M,627,6,19909,627,46,19949],
[M,627,38,19941,627,45,19948],
[M,627,29,19932,627,36,19939],
[M,627,20,19923,627,27,19930],
[M,627,11,19914,627,18,19921],
[M,610,7,19343,610,52,19388],
[M,610,7,19343,610,19,19355],
[M,611,6,19395,611,13,19402],
[M,613,6,19419,613,37,19450],
[M,613,28,19441,613,36,19449],
[M,613,18,19431,613,26,19439],
[M,613,8,19421,613,16,19429],
[M,610,23,19359,610,35,19371],
[M,610,39,19375,610,51,19387],
[M,614,6,19457,614,37,19488],
[M,614,29,19480,614,36,19487],
[M,614,20,19471,614,27,19478],
[M,614,11,19462,614,18,19469],
[M,597,7,18979,597,36,19008],
[M,597,7,18979,597,19,18991],
[M,598,6,19015,598,13,19022],
[M,600,6,19039,600,27,19060],
[M,600,18,19051,600,26,19059],
[M,600,8,19041,600,16,19049],
[M,597,23,18995,597,35,19007],
[M,601,6,19067,601,28,19089],
[M,601,20,19081,601,27,19088],
[M,601,11,19072,601,18,19079],
[M,571,6,18377,571,13,18384],
[M,573,6,18401,573,16,18411],
[M,573,8,18403,573,15,18410],
[M,570,7,18358,570,18,18369],
[M,574,6,18418,574,18,18430],
[M,574,11,18423,574,17,18429],
[M,560,5,18049,560,66,18110],
[M,560,5,18049,560,17,18061],
[M,561,4,18115,561,9,18120],
[M,563,4,18133,563,48,18177],
[M,563,39,18168,563,47,18176],
[M,563,29,18158,563,37,18166],
[M,563,19,18148,563,27,18156],
[M,563,9,18138,563,17,18146],
[M,563,51,18180,563,110,18239],
[M,563,67,18196,563,73,18202],
[M,560,21,18065,560,33,18077],
[M,560,37,18081,560,49,18093],
[M,560,53,18097,560,65,18109],
[M,563,59,18188,563,109,18238],
[M,563,101,18230,563,108,18237],
[M,563,92,18221,563,99,18228],
[M,563,83,18212,563,90,18219],
[M,563,74,18203,563,81,18210],
[M,551,5,17669,551,50,17714],
[M,551,5,17669,551,17,17681],
[M,552,4,17719,552,9,17724],
[M,554,4,17737,554,38,17771],
[M,554,29,17762,554,37,17770],
[M,554,19,17752,554,27,17760],
[M,554,9,17742,554,17,17750],
[M,554,41,17774,554,93,17826],
[M,554,59,17792,554,65,17798],
[M,551,21,17685,551,33,17697],
[M,551,37,17701,551,49,17713],
[M,554,49,17782,554,92,17825],
[M,554,84,17817,554,91,17824],
[M,554,75,17808,554,82,17815],
[M,554,66,17799,554,73,17806],
[M,542,5,17350,542,34,17379],
[M,542,5,17350,542,17,17362],
[M,543,4,17384,543,9,17389],
[M,545,4,17402,545,28,17426],
[M,545,19,17417,545,27,17425],
[M,545,9,17407,545,17,17415],
[M,545,31,17429,545,74,17472],
[M,545,49,17447,545,55,17453],
[M,542,21,17366,542,33,17378],
[M,545,39,17437,545,73,17471],
[M,545,65,17463,545,72,17470],
[M,545,56,17454,545,63,17461],
[M,532,4,17027,532,9,17032],
[M,534,4,17045,534,19,17060],
[M,534,9,17050,534,18,17059],
[M,534,22,17063,534,56,17097],
[M,534,39,17080,534,45,17086],
[M,531,5,17008,531,18,17021],
[M,534,30,17071,534,55,17096],
[M,534,46,17087,534,54,17095],
[M,522,5,16690,522,66,16751],
[M,522,5,16690,522,17,16702],
[M,523,4,16756,523,9,16761],
[M,525,4,16774,525,45,16815],
[M,525,36,16806,525,44,16814],
[M,525,26,16796,525,34,16804],
[M,525,16,16786,525,24,16794],
[M,525,6,16776,525,14,16784],
[M,525,48,16818,525,100,16870],
[M,525,56,16826,525,99,16869],
[M,525,91,16861,525,98,16868],
[M,525,82,16852,525,89,16859],
[M,525,73,16843,525,80,16850],
[M,525,64,16834,525,71,16841],
[M,522,21,16706,522,33,16718],
[M,522,37,16722,522,49,16734],
[M,522,53,16738,522,65,16750],
[M,513,5,16366,513,50,16411],
[M,513,5,16366,513,17,16378],
[M,514,4,16416,514,9,16421],
[M,516,4,16434,516,35,16465],
[M,516,26,16456,516,34,16464],
[M,516,16,16446,516,24,16454],
[M,516,6,16436,516,14,16444],
[M,516,38,16468,516,81,16511],
[M,516,46,16476,516,80,16510],
[M,516,72,16502,516,79,16509],
[M,516,63,16493,516,70,16500],
[M,516,54,16484,516,61,16491],
[M,513,21,16382,513,33,16394],
[M,513,37,16398,513,49,16410],
[M,501,5,15929,501,34,15958],
[M,501,5,15929,501,17,15941],
[M,502,4,15963,502,9,15968],
[M,504,4,15981,504,25,16002],
[M,504,16,15993,504,24,16001],
[M,504,6,15983,504,14,15991],
[M,504,28,16005,504,62,16039],
[M,504,36,16013,504,61,16038],
[M,504,53,16030,504,60,16037],
[M,504,44,16021,504,51,16028],
[M,501,21,15945,501,33,15957],
[M,489,4,15541,489,9,15546],
[M,491,4,15559,491,16,15571],
[M,491,6,15561,491,15,15570],
[M,491,19,15574,491,44,15599],
[M,491,27,15582,491,43,15598],
[M,491,34,15589,491,42,15597],
[M,488,5,15522,488,18,15535],
[M,472,7,14951,472,36,14980],
[M,472,7,14951,472,19,14963],
[M,472,37,14981,472,41,14985],
[M,473,10,14996,473,58,15044],
[M,473,22,15008,473,30,15016],
[M,473,12,14998,473,20,15006],
[M,472,23,14967,472,35,14979],
[M,473,50,15036,473,57,15043],
[M,473,41,15027,473,48,15034],
[M,473,10,14996,473,31,15017],
[M,473,36,15022,473,58,15044],
[M,456,20,14432,456,24,14436],
[M,457,10,14447,457,37,14474],
[M,457,12,14449,457,19,14456],
[M,456,7,14419,456,18,14430],
[M,457,30,14467,457,36,14473],
[M,457,10,14447,457,20,14457],
[M,457,25,14462,457,37,14474],
[M,443,0,13933,451,3,14272],
[M,416,4,13176,416,26,13198],
[M,415,2,13160,417,5,13204],
[M,415,7,13165,415,13,13171],
[M,431,2,13496,431,14,13508],
[M,420,2,13249,430,5,13493],
[M,421,17,13284,421,28,13295],
[M,423,6,13312,428,9,13479],
[M,425,8,13379,427,41,13469],
[M,426,15,13414,426,23,13422],
[M,424,8,13335,424,43,13370],
[M,421,7,13274,421,16,13283],
[M,413,42,13014,413,72,13044],
[M,413,44,13016,413,56,13028],
[M,413,58,13030,413,70,13042],
[M,426,10,13409,426,28,13427],
[M,427,26,13454,427,41,13469],
[M,396,4,12527,396,8,12531],
[M,398,7,12547,398,19,12559],
[M,398,9,12549,398,18,12558],
[M,395,5,12508,395,18,12521],
[M,392,48,12367,392,56,12375],
[M,399,6,12567,399,21,12582],
[M,399,11,12572,399,20,12581],
[M,401,6,12599,401,23,12616],
[M,401,14,12607,401,22,12615],
[M,374,28,11752,374,35,11759],
[M,376,6,11776,376,26,11796],
[M,376,11,11781,376,25,11795],
[M,374,7,11731,374,26,11750],
[M,377,9,11806,377,27,11824],
[M,377,11,11808,377,26,11823],
[M,378,37,11863,378,53,11879],
[M,378,19,11845,378,34,11860],
[M,380,38,11930,380,55,11947],
[M,380,20,11912,380,35,11927],
[M,378,8,11834,378,53,11879],
[M,380,8,11900,380,55,11947],
[M,356,4,11269,356,9,11274],
[M,358,7,11290,358,19,11302],
[M,358,9,11292,358,18,11301],
[M,355,5,11250,355,18,11263],
[M,359,18,11322,359,46,11350],
[M,359,6,11310,359,15,11319],
[M,359,26,11330,359,45,11349],
[M,359,36,11340,359,44,11348],
[M,361,6,11367,361,25,11386],
[M,361,16,11377,361,24,11385],
[M,343,33,10932,343,39,10938],
[M,344,18,10961,344,23,10966],
[M,345,18,10985,345,66,11033],
[M,344,10,10953,344,17,10960],
[M,343,5,10904,343,11,10910],
[M,341,37,10850,341,41,10854],
[M,343,26,10925,343,42,10941],
[M,343,18,10917,343,43,10942],
[M,327,43,10404,327,53,10414],
[M,328,25,10447,328,30,10452],
[M,330,35,10539,330,50,10554],
[M,328,10,10432,328,24,10446],
[M,327,5,10366,327,18,10379],
[M,327,37,10398,327,59,10420],
[M,327,25,10386,327,60,10421],
[M,329,15,10468,333,39,10684],
[M,332,35,10630,332,49,10644],
[M,329,9,10462,333,39,10684],
[M,318,4,10077,318,67,10140],
[M,306,46,9770,306,57,9781],
[M,307,8,9791,307,20,9803],
[M,306,5,9729,306,11,9735],
[M,306,18,9742,306,58,9782],
[M,306,12,9736,306,58,9782],
[M,301,48,9604,301,59,9615],
[M,302,26,9643,302,41,9658],
[M,302,34,9651,302,40,9657],
[M,303,20,9679,303,50,9709],
[M,303,10,9669,303,17,9676],
[M,303,41,9700,303,49,9708],
[M,303,33,9692,303,39,9698],
[M,302,12,9629,302,21,9638],
[M,301,7,9563,301,18,9574],
[M,301,26,9582,301,60,9616],
[M,301,20,9576,301,60,9616],
[M,303,28,9687,303,49,9708],
[M,289,46,9211,289,57,9222],
[M,290,8,9232,290,20,9244],
[M,289,5,9170,289,11,9176],
[M,289,18,9183,289,58,9223],
[M,289,12,9177,289,58,9223],
[M,284,48,9076,284,59,9087],
[M,285,22,9111,285,29,9118],
[M,286,23,9142,286,31,9150],
[M,286,15,9134,286,21,9140],
[M,285,12,9101,285,21,9110],
[M,284,7,9035,284,18,9046],
[M,284,26,9054,284,60,9088],
[M,284,20,9048,284,60,9088],
[M,286,10,9129,286,31,9150],
[M,230,9,7589,230,29,7609],
[M,230,18,7598,230,28,7608],
[M,232,9,7663,232,29,7683],
[M,232,18,7672,232,28,7682],
[M,229,9,7560,229,27,7578],
[M,230,9,7589,230,61,7641],
[M,230,38,7618,230,61,7641],
[M,230,38,7618,230,56,7636],
[M,230,38,7618,230,47,7627],
[M,214,6,6991,214,39,7024],
[M,214,16,7001,214,30,7015],
[M,216,6,7054,216,39,7087],
[M,216,16,7064,216,30,7078],
[M,217,18,7106,217,39,7127],
[M,217,18,7106,217,30,7118],
[M,217,6,7094,217,17,7105],
[M,195,4,6091,218,7,7136],
[M,209,46,6818,209,61,6833],
[M,209,46,6818,209,50,6822],
[M,210,10,6844,210,61,6895],
[M,209,13,6785,209,26,6798],
[M,209,32,6804,209,61,6833],
[M,210,46,6880,210,61,6895],
[M,210,46,6880,210,50,6884],
[M,211,46,6942,211,61,6957],
[M,211,46,6942,211,50,6946],
[M,210,18,6852,210,30,6864],
[M,210,32,6866,210,61,6895],
[M,211,32,6928,211,61,6957],
[M,189,12,5953,189,16,5957],
[M,189,8,5949,191,11,6064],
[M,189,60,6001,189,69,6010],
[M,188,6,5929,192,11,6076],
[M,187,4,5908,193,7,6084],
[M,190,28,6041,190,39,6052],
[M,181,12,5766,181,16,5770],
[M,181,8,5762,183,11,5881],
[M,181,62,5816,181,71,5825],
[M,180,6,5742,184,11,5893],
[M,179,4,5720,185,7,5901],
[M,182,28,5856,182,41,5869],
[M,169,30,5503,169,40,5513],
[M,170,12,5526,170,28,5542],
[M,170,12,5526,170,26,5540],
[M,170,12,5526,170,21,5535],
[M,169,9,5482,169,28,5501],
[M,164,19,5322,164,23,5326],
[M,164,19,5322,164,51,5354],
[M,156,4,4957,160,7,5185],
[M,150,4,4721,154,7,4950],
[M,146,82,4655,147,50,4706],
[M,147,29,4685,147,50,4706],
[M,128,37,3931,128,65,3959],
[M,128,24,3918,128,34,3928],
[M,128,45,3939,128,64,3958],
[M,128,45,3939,128,61,3955],
[M,128,45,3939,128,54,3948],
[M,129,24,3984,129,43,4003],
[M,129,24,3984,129,40,4000],
[M,129,24,3984,129,33,3993],
[M,128,9,3903,128,22,3916],
[M,128,37,3931,128,41,3935],
[M,121,4,3563,124,7,3748],
[M,123,22,3715,123,26,3719],
[M,123,22,3715,123,47,3740],
[M,115,4,3390,119,7,3556],
[M,118,6,3531,118,20,3545],
[M,118,6,3531,118,15,3540],
[M,110,4,3251,113,7,3383],
[M,108,2,3205,234,8,7702],
[M,19,2,235,106,7,3201],
[M,256,4,8256,256,28,8280],
[M,252,4,8142,252,28,8166],
[M,771,8,24880,773,5,24922],
[M,743,0,23791,766,3,24843],
[M,746,2,24052,752,5,24216],
[M,743,21,23812,743,27,23818],
[M,743,42,23833,743,46,23837],
[M,733,0,23327,741,3,23789],
[M,733,25,23352,733,29,23356],
[M,733,37,23364,733,41,23368],
[M,733,49,23376,733,53,23380],
[M,733,61,23388,733,65,23392],
[M,723,0,22909,731,3,23325],
[M,723,25,22934,723,29,22938],
[M,723,37,22946,723,41,22950],
[M,723,49,22958,723,53,22962],
[M,713,0,22537,721,3,22907],
[M,713,25,22562,713,29,22566],
[M,713,37,22574,713,41,22578],
[M,699,0,22081,711,3,22535],
[M,699,25,22106,699,29,22110],
[M,685,0,21603,697,3,22079],
[M,689,2,21900,696,5,22075],
[M,690,4,21921,690,19,21936],
[M,672,0,21087,683,3,21601],
[M,674,2,21321,681,5,21561],
[M,672,22,21109,672,28,21115],
[M,672,38,21125,672,42,21129],
[M,672,52,21139,672,56,21143],
[M,672,66,21153,672,70,21157],
[M,672,80,21167,672,84,21171],
[M,659,0,20646,670,3,21085],
[M,661,2,20850,668,5,21051],
[M,659,22,20668,659,28,20674],
[M,659,38,20684,659,42,20688],
[M,659,52,20698,659,56,20702],
[M,659,66,20712,659,70,20716],
[M,646,0,20280,657,3,20644],
[M,648,2,20454,655,5,20616],
[M,646,22,20302,646,28,20308],
[M,646,38,20318,646,42,20322],
[M,646,52,20332,646,56,20336],
[M,633,0,20000,644,3,20278],
[M,635,2,20138,642,5,20257],
[M,633,21,20021,633,27,20027],
[M,633,35,20035,633,39,20039],
[M,620,0,19533,631,3,19998],
[M,622,2,19736,629,5,19963],
[M,620,21,19554,620,25,19558],
[M,620,35,19568,620,39,19572],
[M,620,49,19582,620,53,19586],
[M,620,63,19596,620,67,19600],
[M,607,0,19128,618,3,19531],
[M,609,2,19314,616,5,19502],
[M,607,21,19149,607,25,19153],
[M,607,35,19163,607,39,19167],
[M,607,49,19177,607,53,19181],
[M,594,0,18788,605,3,19126],
[M,596,2,18954,603,5,19103],
[M,594,21,18809,594,25,18813],
[M,594,35,18823,594,39,18827],
[M,567,0,18251,592,3,18786],
[M,569,2,18338,576,5,18444],
[M,567,19,18270,567,23,18274],
[M,558,0,17838,565,3,18249],
[M,558,19,17857,558,25,17863],
[M,558,33,17871,558,37,17875],
[M,558,45,17883,558,49,17887],
[M,558,57,17895,558,61,17899],
[M,558,69,17907,558,73,17911],
[M,549,0,17484,556,3,17836],
[M,549,19,17503,549,25,17509],
[M,549,33,17517,549,37,17521],
[M,549,45,17529,549,49,17533],
[M,549,57,17541,549,61,17545],
[M,540,0,17191,547,3,17482],
[M,540,19,17210,540,25,17216],
[M,540,33,17224,540,37,17228],
[M,540,45,17236,540,49,17240],
[M,529,0,16882,538,3,17189],
[M,529,18,16900,529,24,16906],
[M,529,33,16915,529,37,16919],
[M,520,0,16523,527,3,16880],
[M,520,18,16541,520,22,16545],
[M,520,30,16553,520,34,16557],
[M,520,42,16565,520,46,16569],
[M,520,54,16577,520,58,16581],
[M,511,0,16225,518,3,16521],
[M,511,18,16243,511,22,16247],
[M,511,30,16255,511,34,16259],
[M,511,42,16267,511,46,16271],
[M,499,0,15802,509,3,16223],
[M,499,18,15820,499,22,15824],
[M,499,30,15832,499,34,15836],
[M,486,0,15428,497,3,15800],
[M,486,18,15446,486,22,15450],
[M,468,0,14695,483,3,15425],
[M,471,2,14926,475,5,15058],
[M,468,13,14708,468,35,14730],
[M,468,45,14740,468,49,14744],
[M,468,59,14754,468,63,14758],
[M,453,0,14274,466,3,14693],
[M,455,2,14399,459,5,14488],
[M,453,12,14286,453,29,14303],
[M,453,38,14312,453,42,14316],
[M,445,10,14065,445,22,14077],
[M,443,12,13945,443,29,13962],
[M,443,38,13971,443,42,13975],
[M,413,0,12972,441,3,13931],
[M,413,18,12990,413,24,12996],
[M,413,33,13005,413,37,13009],
[M,392,0,12319,411,3,12970],
[M,392,13,12332,392,30,12349],
[M,392,39,12358,392,43,12362],
[M,369,0,11518,390,3,12317],
[M,384,2,11974,384,11,11983],
[M,373,2,11703,383,5,11971],
[M,369,24,11542,369,28,11546],
[M,353,0,11156,367,3,11516],
[M,353,21,11177,353,25,11181],
[M,341,0,10813,351,3,11154],
[M,341,16,10829,341,22,10835],
[M,325,0,10261,339,3,10811],
[M,314,0,9919,323,3,10259],
[M,316,2,10037,319,5,10146],
[M,318,54,10127,318,66,10139],
[M,317,4,10058,317,18,10072],
[M,297,0,9333,312,3,9917],
[M,300,2,9538,305,5,9723],
[M,297,23,9356,297,29,9362],
[M,281,0,8884,295,3,9331],
[M,283,2,9010,288,5,9164],
[M,281,23,8907,281,29,8913],
[M,108,4,3207,108,36,3239],
[M,108,31,3234,108,35,3238],
[M,229,9,7560,229,16,7567],
[M,229,17,7568,229,26,7577],
[M,226,4,7382,234,7,7701],
[M,220,4,7143,224,7,7375],
[M,223,44,7342,223,68,7366],
[M,223,19,7317,223,42,7340],
[M,223,6,7304,223,18,7316],
[M,208,6,6754,213,12,6984],
[M,208,16,6764,213,11,6983],
[M,208,6,6754,208,15,6763],
[M,207,19,6742,207,24,6747],
[M,206,19,6717,206,24,6722],
[M,205,19,6692,205,24,6697],
[M,199,14,6392,199,24,6402],
[M,189,31,5972,189,49,5990],
[M,189,38,5979,189,48,5989],
[M,190,10,6023,190,39,6052],
[M,181,31,5785,181,51,5805],
[M,181,40,5794,181,50,5804],
[M,182,10,5838,182,41,5869],
[M,176,6,5680,176,18,5692],
[M,176,25,5699,176,30,5704],
[M,174,4,5567,177,7,5713],
[M,169,9,5482,169,17,5490],
[M,169,18,5491,169,27,5500],
[M,167,4,5369,172,7,5560],
[M,162,4,5192,165,7,5362],
[M,164,6,5309,164,16,5319],
[M,164,27,5330,164,50,5353],
[M,164,27,5330,164,43,5346],
[M,164,27,5330,164,36,5339],
[M,159,25,5157,159,44,5176],
[M,159,27,5159,159,37,5169],
[M,159,6,5138,159,21,5153],
[M,159,6,5138,159,15,5147],
[M,153,20,4917,153,44,4941],
[M,153,20,4917,153,35,4932],
[M,153,20,4917,153,29,4926],
[M,153,8,4905,153,18,4915],
[M,147,29,4685,147,45,4701],
[M,147,29,4685,147,38,4694],
[M,146,82,4655,147,25,4681],
[M,147,14,4670,147,24,4680],
[M,145,4,4554,148,7,4714],
[M,142,6,4526,142,10,4530],
[M,140,4,4371,143,7,4547],
[M,137,6,4338,137,15,4347],
[M,133,4,4028,138,7,4364],
[M,128,11,3905,128,21,3915],
[M,126,4,3755,131,7,4021],
[M,123,6,3699,123,19,3712],
[M,123,8,3701,123,18,3711],
[M,123,30,3723,123,46,3739],
[M,123,30,3723,123,43,3736],
[M,123,30,3723,123,39,3732],
[M,117,6,3511,117,19,3524],
[M,117,8,3513,117,18,3523],
[M,112,10,3357,112,28,3375],
[M,112,10,3357,112,26,3373],
[M,112,10,3357,112,19,3366],
[M,108,23,3226,108,35,3238],
[M,108,9,3212,108,21,3224],
[M,102,4,3016,106,7,3201],
[M,96,4,2836,100,7,3009],
[M,89,4,2524,94,7,2829],
[M,87,4,2488,87,33,2517],
[M,85,4,2451,85,34,2481],
[M,80,4,2319,83,7,2444],
[M,75,4,2156,78,7,2312],
[M,70,4,2019,73,7,2149],
[M,65,4,1891,68,7,2012],
[M,59,4,1694,63,7,1884],
[M,53,4,1496,57,7,1687],
[M,50,17,1457,50,22,1462],
[M,50,34,1474,50,39,1479],
[M,46,4,1135,51,7,1489],
[M,41,41,966,41,49,974],
[M,41,19,944,41,36,961],
[M,41,4,929,44,7,1128],
[M,38,6,909,38,11,914],
[M,36,43,775,36,47,779],
[M,36,21,753,36,38,770],
[M,36,4,736,39,7,922],
[M,33,6,716,33,11,721],
[M,31,36,588,31,40,592],
[M,31,18,570,31,31,583],
[M,31,4,556,34,7,729],
[M,26,41,419,26,48,426],
[M,26,19,397,26,36,414],
[M,26,4,382,29,7,549],
[M,21,20,270,21,26,276],
[M,21,4,254,24,7,375],
[M,265,4,8561,265,12,8569],
[M,263,2,8425,266,5,8587],
[M,261,4,8398,261,12,8406],
[M,259,2,8291,262,5,8421],
[M,256,4,8256,256,12,8264],
[M,256,4,8256,256,21,8273],
[M,254,2,8176,257,5,8286],
[M,252,4,8142,252,12,8150],
[M,252,4,8142,252,21,8159],
[M,250,2,8070,253,5,8172],
[M,248,4,8043,248,12,8051],
[M,246,2,7905,249,5,8066],
[M,244,4,7880,244,8,7884],
[M,242,2,7785,245,5,7901],
[M,238,2,7716,240,5,7780],
[M,239,4,7756,239,15,7767],
[M,238,16,7730,238,20,7734],
[M,238,31,7745,238,35,7749],
[M,16,9,212,16,17,220],
[M,15,8,195,15,15,202],
[M,14,7,180,14,13,186],
[M,12,9,163,12,17,171],
[M,11,10,144,11,19,153],
[M,10,7,127,10,13,133],
[M,9,10,110,9,19,119],
[M,8,7,93,8,13,99]];
var _greaterthan3 = NAMESPACE.get("_greaterthan");
var _lessthan4 = NAMESPACE.get("_lessthan");
var _minus5 = NAMESPACE.get("_minus");
var _plus6 = NAMESPACE.get("_plus");
var builtins7 = NAMESPACE.get("builtins");
var nothing8 = NAMESPACE.get("nothing");
var raise9 = NAMESPACE.get("raise");
var raw_DASH_array_DASH_to_DASH_list10 = NAMESPACE.get("raw-array-to-list");
var torepr11 = NAMESPACE.get("torepr");
var tostring12 = NAMESPACE.get("tostring");
var $type$Boolean13 = NAMESPACE.get("$type$Boolean");
var $type$Nothing14 = NAMESPACE.get("$type$Nothing");
var $type$Number15 = NAMESPACE.get("$type$Number");
var $Hanf_bracket155623 = function(anf_bracket115824,List525,provides115626,nothing8) {
var anf_fun115937 = G(anf_bracket115824,"results",L[0]);
var $z2930 = D;
var $f3536 = function(_) {
return R.isFunction(anf_fun115937)?anf_fun115937.app():R.ffi.throwNonFunApp(L[0],anf_fun115937,[]);
};
try {
if(--R.GAS > 0) {
$z2930 = $f3536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3536,
"from":L[0]});
}
} catch($e2728) {
if(R.isCont($e2728)) {
var $ss3132 = {"from":L[0],
"go":function(checks116038) {
return $Hchecks155539(checks116038,List525,provides115626,nothing8);
}};
$e2728.stack[R.EXN_STACKHEIGHT++] = $ss3132;
}
if(R.isPyretException($e2728)) {
$e2728.pyretStack.push(L[0]);
}
throw $e2728;
}
var $ret3334 = $Hchecks155539($z2930,List525,provides115626,nothing8);
++R.GAS;
return $ret3334;
};
var $Hchecks155539 = function(checks116038,List525,provides115626,nothing8) {
return R.makeObject({"answer":nothing8,
"provide-plus-types":R.makeObject({"values":provides115626,
"types":{"List":List525}}),
"checks":checks116038});
};
var $Hann_DASH_check_DASH_temp155440 = function(ann_DASH_check_DASH_temp115441) {
return ann_DASH_check_DASH_temp115441;
};
var $Hann_DASH_check_DASH_temp155342 = function(ann_DASH_check_DASH_temp113843) {
return ann_DASH_check_DASH_temp113843;
};
var $Hif_DASH_155244 = function(if_DASH_13645,acc37846,f37247,help37648,n37749,partial_DASH_list37950,_plus6) {
var if_helper114061 = R.makeFunction(function(if_helper_arg114181) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
var ann_DASH_check_DASH_temp113982 = if_helper_arg114181;
return ann_DASH_check_DASH_temp113982;
});
var anf_if114480 = R.isBoolean(if_DASH_13645);
if(R.isPyretTrue(anf_if114480)) {
if(R.isPyretTrue(if_DASH_13645)) {
var $z5354 = D;
var $f5960 = function(_) {
return R.isFunction(if_helper114061)?if_helper114061.app(acc37846):R.ffi.throwNonFunApp(L[1],if_helper114061,[acc37846]);
};
try {
if(--R.GAS > 0) {
$z5354 = $f5960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5960,
"from":L[1]});
}
} catch($e5152) {
if(R.isCont($e5152)) {
var $ss5556 = {"from":L[1],
"go":function(cont_tail_app115162) {
return $Hcont_tail_app154863(cont_tail_app115162);
}};
$e5152.stack[R.EXN_STACKHEIGHT++] = $ss5556;
}
if(R.isPyretException($e5152)) {
$e5152.pyretStack.push(L[1]);
}
throw $e5152;
}
var $ret5758 = $Hcont_tail_app154863($z5354);
++R.GAS;
return $ret5758;
} else {
var $z6667 = D;
var $f7273 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n37749,(1)):R.ffi.throwNonFunApp(L[2],_plus6,[n37749,(1)]);
};
try {
if(--R.GAS > 0) {
$z6667 = $f7273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7273,
"from":L[2]});
}
} catch($e6465) {
if(R.isCont($e6465)) {
var $ss6869 = {"from":L[2],
"go":function(anf_arg114574) {
return $Hanf_arg155175(anf_arg114574,acc37846,f37247,help37648,if_helper114061,n37749,partial_DASH_list37950);
}};
$e6465.stack[R.EXN_STACKHEIGHT++] = $ss6869;
}
if(R.isPyretException($e6465)) {
$e6465.pyretStack.push(L[2]);
}
throw $e6465;
}
var $ret7071 = $Hanf_arg155175($z6667,acc37846,f37247,help37648,if_helper114061,n37749,partial_DASH_list37950);
++R.GAS;
return $ret7071;
}
} else {
var cont_tail_arg114278 = R.throwNonBooleanCondition(L[3],("if"),if_DASH_13645);
if(--R.GAS > 0) {
$z7677 = R.isFunction(if_helper114061)?if_helper114061.app(cont_tail_arg114278):R.ffi.throwNonFunApp(L[3],if_helper114061,[cont_tail_arg114278]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper114061)?if_helper114061.app(cont_tail_arg114278):R.ffi.throwNonFunApp(L[3],if_helper114061,[cont_tail_arg114278]);
},
"from":L[3]});
}
++R.GAS;
return $z7677;
}
};
var $Hcont_tail_app154863 = function(cont_tail_app115162) {
return cont_tail_app115162;
};
var $Hanf_arg155175 = function(anf_arg114574,acc37846,f37247,help37648,if_helper114061,n37749,partial_DASH_list37950) {
var anf_arg114693 = G(partial_DASH_list37950,"first",L[5]);
var $z8586 = D;
var $f9192 = function(_) {
return R.isFunction(f37247)?f37247.app(n37749,acc37846,anf_arg114693):R.ffi.throwNonFunApp(L[4],f37247,[n37749,acc37846,anf_arg114693]);
};
try {
if(--R.GAS > 0) {
$z8586 = $f9192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9192,
"from":L[4]});
}
} catch($e8384) {
if(R.isCont($e8384)) {
var $ss8788 = {"from":L[4],
"go":function(anf_arg114794) {
return $Hanf_arg155095(anf_arg114794,anf_arg114574,help37648,if_helper114061,partial_DASH_list37950);
}};
$e8384.stack[R.EXN_STACKHEIGHT++] = $ss8788;
}
if(R.isPyretException($e8384)) {
$e8384.pyretStack.push(L[4]);
}
throw $e8384;
}
var $ret8990 = $Hanf_arg155095($z8586,anf_arg114574,help37648,if_helper114061,partial_DASH_list37950);
++R.GAS;
return $ret8990;
};
var $Hanf_arg155095 = function(anf_arg114794,anf_arg114574,help37648,if_helper114061,partial_DASH_list37950) {
var anf_arg1148106 = G(partial_DASH_list37950,"rest",L[7]);
var $z9899 = D;
var $f104105 = function(_) {
return R.isFunction(help37648.$var)?help37648.$var.app(anf_arg114574,anf_arg114794,anf_arg1148106):R.ffi.throwNonFunApp(L[6],help37648.$var,[anf_arg114574,anf_arg114794,anf_arg1148106]);
};
try {
if(--R.GAS > 0) {
$z9899 = $f104105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f104105,
"from":L[6]});
}
} catch($e9697) {
if(R.isCont($e9697)) {
var $ss100101 = {"from":L[6],
"go":function(cont_tail_arg1149107) {
return $Hcont_tail_arg1549108(cont_tail_arg1149107,if_helper114061);
}};
$e9697.stack[R.EXN_STACKHEIGHT++] = $ss100101;
}
if(R.isPyretException($e9697)) {
$e9697.pyretStack.push(L[6]);
}
throw $e9697;
}
var $ret102103 = $Hcont_tail_arg1549108($z9899,if_helper114061);
++R.GAS;
return $ret102103;
};
var $Hcont_tail_arg1549108 = function(cont_tail_arg1149107,if_helper114061) {
if(--R.GAS > 0) {
$z109110 = R.isFunction(if_helper114061)?if_helper114061.app(cont_tail_arg1149107):R.ffi.throwNonFunApp(L[6],if_helper114061,[cont_tail_arg1149107]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper114061)?if_helper114061.app(cont_tail_arg1149107):R.ffi.throwNonFunApp(L[6],if_helper114061,[cont_tail_arg1149107]);
},
"from":L[6]});
}
++R.GAS;
return $z109110;
};
var $Hor_DASH_oper_DASH_1547111 = function(or_DASH_oper_DASH_132112,base367113,f366114,fold454115,is_DASH_empty18116,l1368117,l2369118,l3370119,l4371120) {
var if_helper1102131 = R.makeFunction(function(if_helper_arg1103150) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
var if_DASH_131180 = if_helper_arg1103150;
var if_helper1104161 = R.makeFunction(function(if_helper_arg1105185) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
var ann_DASH_check_DASH_temp1101186 = if_helper_arg1105185;
return ann_DASH_check_DASH_temp1101186;
});
var anf_if1108184 = R.isBoolean(if_DASH_131180);
if(R.isPyretTrue(anf_if1108184)) {
if(R.isPyretTrue(if_DASH_131180)) {
var $z153154 = D;
var $f159160 = function(_) {
return R.isFunction(if_helper1104161)?if_helper1104161.app(base367113):R.ffi.throwNonFunApp(L[10],if_helper1104161,[base367113]);
};
try {
if(--R.GAS > 0) {
$z153154 = $f159160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f159160,
"from":L[10]});
}
} catch($e151152) {
if(R.isCont($e151152)) {
var $ss155156 = {"from":L[10],
"go":function(cont_tail_app1120162) {
return $Hcont_tail_app1537163(cont_tail_app1120162);
}};
$e151152.stack[R.EXN_STACKHEIGHT++] = $ss155156;
}
if(R.isPyretException($e151152)) {
$e151152.pyretStack.push(L[10]);
}
throw $e151152;
}
var $ret157158 = $Hcont_tail_app1537163($z153154);
++R.GAS;
return $ret157158;
} else {
var anf_arg1109174 = G(l1368117,"first",L[15]);
var anf_arg1110175 = G(l2369118,"first",L[14]);
var anf_arg1111176 = G(l3370119,"first",L[13]);
var anf_arg1112177 = G(l4371120,"first",L[12]);
var $z166167 = D;
var $f172173 = function(_) {
return R.isFunction(f366114)?f366114.app(base367113,anf_arg1109174,anf_arg1110175,anf_arg1111176,anf_arg1112177):R.ffi.throwNonFunApp(L[11],f366114,[base367113,anf_arg1109174,anf_arg1110175,anf_arg1111176,anf_arg1112177]);
};
try {
if(--R.GAS > 0) {
$z166167 = $f172173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f172173,
"from":L[11]});
}
} catch($e164165) {
if(R.isCont($e164165)) {
var $ss168169 = {"from":L[11],
"go":function(anf_arg1113178) {
return $Hanf_arg1539179(anf_arg1113178,f366114,fold454115,if_helper1104161,l1368117,l2369118,l3370119,l4371120);
}};
$e164165.stack[R.EXN_STACKHEIGHT++] = $ss168169;
}
if(R.isPyretException($e164165)) {
$e164165.pyretStack.push(L[11]);
}
throw $e164165;
}
var $ret170171 = $Hanf_arg1539179($z166167,f366114,fold454115,if_helper1104161,l1368117,l2369118,l3370119,l4371120);
++R.GAS;
return $ret170171;
}
} else {
var cont_tail_arg1106183 = R.throwNonBooleanCondition(L[8],("if"),if_DASH_131180);
if(--R.GAS > 0) {
$z181182 = R.isFunction(if_helper1104161)?if_helper1104161.app(cont_tail_arg1106183):R.ffi.throwNonFunApp(L[8],if_helper1104161,[cont_tail_arg1106183]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1104161)?if_helper1104161.app(cont_tail_arg1106183):R.ffi.throwNonFunApp(L[8],if_helper1104161,[cont_tail_arg1106183]);
},
"from":L[8]});
}
++R.GAS;
return $z181182;
}
});
var anf_if1123149 = R.isBoolean(or_DASH_oper_DASH_132112);
if(R.isPyretTrue(anf_if1123149)) {
if(R.isPyretTrue(or_DASH_oper_DASH_132112)) {
var $z123124 = D;
var $f129130 = function(_) {
return R.isFunction(if_helper1102131)?if_helper1102131.app((true)):R.ffi.throwNonFunApp(L[8],if_helper1102131,[(true)]);
};
try {
if(--R.GAS > 0) {
$z123124 = $f129130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f129130,
"from":L[8]});
}
} catch($e121122) {
if(R.isCont($e121122)) {
var $ss125126 = {"from":L[8],
"go":function(cont_tail_app1136132) {
return $Hcont_tail_app1540133(cont_tail_app1136132);
}};
$e121122.stack[R.EXN_STACKHEIGHT++] = $ss125126;
}
if(R.isPyretException($e121122)) {
$e121122.pyretStack.push(L[8]);
}
throw $e121122;
}
var $ret127128 = $Hcont_tail_app1540133($z123124);
++R.GAS;
return $ret127128;
} else {
var $z136137 = D;
var $f142143 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l2369118):R.ffi.throwNonFunApp(L[8],is_DASH_empty18116.$var,[l2369118]);
};
try {
if(--R.GAS > 0) {
$z136137 = $f142143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f142143,
"from":L[8]});
}
} catch($e134135) {
if(R.isCont($e134135)) {
var $ss138139 = {"from":L[8],
"go":function(or_DASH_oper_DASH_133144) {
return $Hor_DASH_oper_DASH_1546145(or_DASH_oper_DASH_133144,if_helper1102131,is_DASH_empty18116,l3370119,l4371120);
}};
$e134135.stack[R.EXN_STACKHEIGHT++] = $ss138139;
}
if(R.isPyretException($e134135)) {
$e134135.pyretStack.push(L[8]);
}
throw $e134135;
}
var $ret140141 = $Hor_DASH_oper_DASH_1546145($z136137,if_helper1102131,is_DASH_empty18116,l3370119,l4371120);
++R.GAS;
return $ret140141;
}
} else {
var cont_tail_arg1121148 = R.throwNonBooleanOp(L[9],("first"),("or"),or_DASH_oper_DASH_132112);
if(--R.GAS > 0) {
$z146147 = R.isFunction(if_helper1102131)?if_helper1102131.app(cont_tail_arg1121148):R.ffi.throwNonFunApp(L[9],if_helper1102131,[cont_tail_arg1121148]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1102131)?if_helper1102131.app(cont_tail_arg1121148):R.ffi.throwNonFunApp(L[9],if_helper1102131,[cont_tail_arg1121148]);
},
"from":L[9]});
}
++R.GAS;
return $z146147;
}
};
var $Hcont_tail_app1540133 = function(cont_tail_app1136132) {
return cont_tail_app1136132;
};
var $Hor_DASH_oper_DASH_1546145 = function(or_DASH_oper_DASH_133144,if_helper1102131,is_DASH_empty18116,l3370119,l4371120) {
var anf_if1126214 = R.isBoolean(or_DASH_oper_DASH_133144);
if(R.isPyretTrue(anf_if1126214)) {
if(R.isPyretTrue(or_DASH_oper_DASH_133144)) {
var $z189190 = D;
var $f195196 = function(_) {
return R.isFunction(if_helper1102131)?if_helper1102131.app((true)):R.ffi.throwNonFunApp(L[8],if_helper1102131,[(true)]);
};
try {
if(--R.GAS > 0) {
$z189190 = $f195196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f195196,
"from":L[8]});
}
} catch($e187188) {
if(R.isCont($e187188)) {
var $ss191192 = {"from":L[8],
"go":function(cont_tail_app1135197) {
return $Hcont_tail_app1541198(cont_tail_app1135197);
}};
$e187188.stack[R.EXN_STACKHEIGHT++] = $ss191192;
}
if(R.isPyretException($e187188)) {
$e187188.pyretStack.push(L[8]);
}
throw $e187188;
}
var $ret193194 = $Hcont_tail_app1541198($z189190);
++R.GAS;
return $ret193194;
} else {
var $z201202 = D;
var $f207208 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l3370119):R.ffi.throwNonFunApp(L[8],is_DASH_empty18116.$var,[l3370119]);
};
try {
if(--R.GAS > 0) {
$z201202 = $f207208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f207208,
"from":L[8]});
}
} catch($e199200) {
if(R.isCont($e199200)) {
var $ss203204 = {"from":L[8],
"go":function(or_DASH_oper_DASH_134209) {
return $Hor_DASH_oper_DASH_1545210(or_DASH_oper_DASH_134209,if_helper1102131,is_DASH_empty18116,l4371120);
}};
$e199200.stack[R.EXN_STACKHEIGHT++] = $ss203204;
}
if(R.isPyretException($e199200)) {
$e199200.pyretStack.push(L[8]);
}
throw $e199200;
}
var $ret205206 = $Hor_DASH_oper_DASH_1545210($z201202,if_helper1102131,is_DASH_empty18116,l4371120);
++R.GAS;
return $ret205206;
}
} else {
var cont_tail_arg1124213 = R.throwNonBooleanOp(L[16],("first"),("or"),or_DASH_oper_DASH_133144);
if(--R.GAS > 0) {
$z211212 = R.isFunction(if_helper1102131)?if_helper1102131.app(cont_tail_arg1124213):R.ffi.throwNonFunApp(L[16],if_helper1102131,[cont_tail_arg1124213]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1102131)?if_helper1102131.app(cont_tail_arg1124213):R.ffi.throwNonFunApp(L[16],if_helper1102131,[cont_tail_arg1124213]);
},
"from":L[16]});
}
++R.GAS;
return $z211212;
}
};
var $Hcont_tail_app1541198 = function(cont_tail_app1135197) {
return cont_tail_app1135197;
};
var $Hor_DASH_oper_DASH_1545210 = function(or_DASH_oper_DASH_134209,if_helper1102131,is_DASH_empty18116,l4371120) {
var anf_if1129242 = R.isBoolean(or_DASH_oper_DASH_134209);
if(R.isPyretTrue(anf_if1129242)) {
if(R.isPyretTrue(or_DASH_oper_DASH_134209)) {
var $z217218 = D;
var $f223224 = function(_) {
return R.isFunction(if_helper1102131)?if_helper1102131.app((true)):R.ffi.throwNonFunApp(L[8],if_helper1102131,[(true)]);
};
try {
if(--R.GAS > 0) {
$z217218 = $f223224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f223224,
"from":L[8]});
}
} catch($e215216) {
if(R.isCont($e215216)) {
var $ss219220 = {"from":L[8],
"go":function(cont_tail_app1134225) {
return $Hcont_tail_app1542226(cont_tail_app1134225);
}};
$e215216.stack[R.EXN_STACKHEIGHT++] = $ss219220;
}
if(R.isPyretException($e215216)) {
$e215216.pyretStack.push(L[8]);
}
throw $e215216;
}
var $ret221222 = $Hcont_tail_app1542226($z217218);
++R.GAS;
return $ret221222;
} else {
var $z229230 = D;
var $f235236 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l4371120):R.ffi.throwNonFunApp(L[8],is_DASH_empty18116.$var,[l4371120]);
};
try {
if(--R.GAS > 0) {
$z229230 = $f235236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f235236,
"from":L[8]});
}
} catch($e227228) {
if(R.isCont($e227228)) {
var $ss231232 = {"from":L[8],
"go":function(or_DASH_oper_DASH_135237) {
return $Hor_DASH_oper_DASH_1544238(or_DASH_oper_DASH_135237,if_helper1102131);
}};
$e227228.stack[R.EXN_STACKHEIGHT++] = $ss231232;
}
if(R.isPyretException($e227228)) {
$e227228.pyretStack.push(L[8]);
}
throw $e227228;
}
var $ret233234 = $Hor_DASH_oper_DASH_1544238($z229230,if_helper1102131);
++R.GAS;
return $ret233234;
}
} else {
var cont_tail_arg1127241 = R.throwNonBooleanOp(L[17],("first"),("or"),or_DASH_oper_DASH_134209);
if(--R.GAS > 0) {
$z239240 = R.isFunction(if_helper1102131)?if_helper1102131.app(cont_tail_arg1127241):R.ffi.throwNonFunApp(L[17],if_helper1102131,[cont_tail_arg1127241]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1102131)?if_helper1102131.app(cont_tail_arg1127241):R.ffi.throwNonFunApp(L[17],if_helper1102131,[cont_tail_arg1127241]);
},
"from":L[17]});
}
++R.GAS;
return $z239240;
}
};
var $Hcont_tail_app1542226 = function(cont_tail_app1134225) {
return cont_tail_app1134225;
};
var $Hor_DASH_oper_DASH_1544238 = function(or_DASH_oper_DASH_135237,if_helper1102131) {
var anf_if1132258 = R.isBoolean(or_DASH_oper_DASH_135237);
if(R.isPyretTrue(anf_if1132258)) {
var $z245246 = D;
var $f251252 = function(_) {
return R.isFunction(if_helper1102131)?if_helper1102131.app(or_DASH_oper_DASH_135237):R.ffi.throwNonFunApp(L[8],if_helper1102131,[or_DASH_oper_DASH_135237]);
};
try {
if(--R.GAS > 0) {
$z245246 = $f251252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f251252,
"from":L[8]});
}
} catch($e243244) {
if(R.isCont($e243244)) {
var $ss247248 = {"from":L[8],
"go":function(cont_tail_app1133253) {
return $Hcont_tail_app1543254(cont_tail_app1133253);
}};
$e243244.stack[R.EXN_STACKHEIGHT++] = $ss247248;
}
if(R.isPyretException($e243244)) {
$e243244.pyretStack.push(L[8]);
}
throw $e243244;
}
var $ret249250 = $Hcont_tail_app1543254($z245246);
++R.GAS;
return $ret249250;
} else {
var cont_tail_arg1130257 = R.throwNonBooleanOp(L[18],("second"),("or"),or_DASH_oper_DASH_135237);
if(--R.GAS > 0) {
$z255256 = R.isFunction(if_helper1102131)?if_helper1102131.app(cont_tail_arg1130257):R.ffi.throwNonFunApp(L[18],if_helper1102131,[cont_tail_arg1130257]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1102131)?if_helper1102131.app(cont_tail_arg1130257):R.ffi.throwNonFunApp(L[18],if_helper1102131,[cont_tail_arg1130257]);
},
"from":L[18]});
}
++R.GAS;
return $z255256;
}
};
var $Hcont_tail_app1543254 = function(cont_tail_app1133253) {
return cont_tail_app1133253;
};
var $Hcont_tail_app1537163 = function(cont_tail_app1120162) {
return cont_tail_app1120162;
};
var $Hanf_arg1539179 = function(anf_arg1113178,f366114,fold454115,if_helper1104161,l1368117,l2369118,l3370119,l4371120) {
var anf_arg1114269 = G(l1368117,"rest",L[23]);
var anf_arg1115270 = G(l2369118,"rest",L[22]);
var anf_arg1116271 = G(l3370119,"rest",L[21]);
var anf_arg1117272 = G(l4371120,"rest",L[20]);
var $z261262 = D;
var $f267268 = function(_) {
return R.isFunction(fold454115.$var)?fold454115.$var.app(f366114,anf_arg1113178,anf_arg1114269,anf_arg1115270,anf_arg1116271,anf_arg1117272):R.ffi.throwNonFunApp(L[19],fold454115.$var,[f366114,anf_arg1113178,anf_arg1114269,anf_arg1115270,anf_arg1116271,anf_arg1117272]);
};
try {
if(--R.GAS > 0) {
$z261262 = $f267268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f267268,
"from":L[19]});
}
} catch($e259260) {
if(R.isCont($e259260)) {
var $ss263264 = {"from":L[19],
"go":function(cont_tail_arg1118273) {
return $Hcont_tail_arg1538274(cont_tail_arg1118273,if_helper1104161);
}};
$e259260.stack[R.EXN_STACKHEIGHT++] = $ss263264;
}
if(R.isPyretException($e259260)) {
$e259260.pyretStack.push(L[19]);
}
throw $e259260;
}
var $ret265266 = $Hcont_tail_arg1538274($z261262,if_helper1104161);
++R.GAS;
return $ret265266;
};
var $Hcont_tail_arg1538274 = function(cont_tail_arg1118273,if_helper1104161) {
if(--R.GAS > 0) {
$z275276 = R.isFunction(if_helper1104161)?if_helper1104161.app(cont_tail_arg1118273):R.ffi.throwNonFunApp(L[19],if_helper1104161,[cont_tail_arg1118273]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1104161)?if_helper1104161.app(cont_tail_arg1118273):R.ffi.throwNonFunApp(L[19],if_helper1104161,[cont_tail_arg1118273]);
},
"from":L[19]});
}
++R.GAS;
return $z275276;
};
var $Hor_DASH_oper_DASH_1536277 = function(or_DASH_oper_DASH_128278,base362279,f361280,fold353281,is_DASH_empty18116,l1363282,l2364283,l3365284) {
var if_helper1071295 = R.makeFunction(function(if_helper_arg1072314) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[24],1,arguments);
}
var if_DASH_127343 = if_helper_arg1072314;
var if_helper1073325 = R.makeFunction(function(if_helper_arg1074348) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[24],1,arguments);
}
var ann_DASH_check_DASH_temp1070349 = if_helper_arg1074348;
return ann_DASH_check_DASH_temp1070349;
});
var anf_if1077347 = R.isBoolean(if_DASH_127343);
if(R.isPyretTrue(anf_if1077347)) {
if(R.isPyretTrue(if_DASH_127343)) {
var $z317318 = D;
var $f323324 = function(_) {
return R.isFunction(if_helper1073325)?if_helper1073325.app(base362279):R.ffi.throwNonFunApp(L[26],if_helper1073325,[base362279]);
};
try {
if(--R.GAS > 0) {
$z317318 = $f323324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f323324,
"from":L[26]});
}
} catch($e315316) {
if(R.isCont($e315316)) {
var $ss319320 = {"from":L[26],
"go":function(cont_tail_app1087326) {
return $Hcont_tail_app1528327(cont_tail_app1087326);
}};
$e315316.stack[R.EXN_STACKHEIGHT++] = $ss319320;
}
if(R.isPyretException($e315316)) {
$e315316.pyretStack.push(L[26]);
}
throw $e315316;
}
var $ret321322 = $Hcont_tail_app1528327($z317318);
++R.GAS;
return $ret321322;
} else {
var anf_arg1078338 = G(l1363282,"first",L[30]);
var anf_arg1079339 = G(l2364283,"first",L[29]);
var anf_arg1080340 = G(l3365284,"first",L[28]);
var $z330331 = D;
var $f336337 = function(_) {
return R.isFunction(f361280)?f361280.app(base362279,anf_arg1078338,anf_arg1079339,anf_arg1080340):R.ffi.throwNonFunApp(L[27],f361280,[base362279,anf_arg1078338,anf_arg1079339,anf_arg1080340]);
};
try {
if(--R.GAS > 0) {
$z330331 = $f336337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f336337,
"from":L[27]});
}
} catch($e328329) {
if(R.isCont($e328329)) {
var $ss332333 = {"from":L[27],
"go":function(anf_arg1081341) {
return $Hanf_arg1530342(anf_arg1081341,f361280,fold353281,if_helper1073325,l1363282,l2364283,l3365284);
}};
$e328329.stack[R.EXN_STACKHEIGHT++] = $ss332333;
}
if(R.isPyretException($e328329)) {
$e328329.pyretStack.push(L[27]);
}
throw $e328329;
}
var $ret334335 = $Hanf_arg1530342($z330331,f361280,fold353281,if_helper1073325,l1363282,l2364283,l3365284);
++R.GAS;
return $ret334335;
}
} else {
var cont_tail_arg1075346 = R.throwNonBooleanCondition(L[24],("if"),if_DASH_127343);
if(--R.GAS > 0) {
$z344345 = R.isFunction(if_helper1073325)?if_helper1073325.app(cont_tail_arg1075346):R.ffi.throwNonFunApp(L[24],if_helper1073325,[cont_tail_arg1075346]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1073325)?if_helper1073325.app(cont_tail_arg1075346):R.ffi.throwNonFunApp(L[24],if_helper1073325,[cont_tail_arg1075346]);
},
"from":L[24]});
}
++R.GAS;
return $z344345;
}
});
var anf_if1090313 = R.isBoolean(or_DASH_oper_DASH_128278);
if(R.isPyretTrue(anf_if1090313)) {
if(R.isPyretTrue(or_DASH_oper_DASH_128278)) {
var $z287288 = D;
var $f293294 = function(_) {
return R.isFunction(if_helper1071295)?if_helper1071295.app((true)):R.ffi.throwNonFunApp(L[24],if_helper1071295,[(true)]);
};
try {
if(--R.GAS > 0) {
$z287288 = $f293294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f293294,
"from":L[24]});
}
} catch($e285286) {
if(R.isCont($e285286)) {
var $ss289290 = {"from":L[24],
"go":function(cont_tail_app1099296) {
return $Hcont_tail_app1531297(cont_tail_app1099296);
}};
$e285286.stack[R.EXN_STACKHEIGHT++] = $ss289290;
}
if(R.isPyretException($e285286)) {
$e285286.pyretStack.push(L[24]);
}
throw $e285286;
}
var $ret291292 = $Hcont_tail_app1531297($z287288);
++R.GAS;
return $ret291292;
} else {
var $z300301 = D;
var $f306307 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l2364283):R.ffi.throwNonFunApp(L[24],is_DASH_empty18116.$var,[l2364283]);
};
try {
if(--R.GAS > 0) {
$z300301 = $f306307();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f306307,
"from":L[24]});
}
} catch($e298299) {
if(R.isCont($e298299)) {
var $ss302303 = {"from":L[24],
"go":function(or_DASH_oper_DASH_129308) {
return $Hor_DASH_oper_DASH_1535309(or_DASH_oper_DASH_129308,if_helper1071295,is_DASH_empty18116,l3365284);
}};
$e298299.stack[R.EXN_STACKHEIGHT++] = $ss302303;
}
if(R.isPyretException($e298299)) {
$e298299.pyretStack.push(L[24]);
}
throw $e298299;
}
var $ret304305 = $Hor_DASH_oper_DASH_1535309($z300301,if_helper1071295,is_DASH_empty18116,l3365284);
++R.GAS;
return $ret304305;
}
} else {
var cont_tail_arg1088312 = R.throwNonBooleanOp(L[25],("first"),("or"),or_DASH_oper_DASH_128278);
if(--R.GAS > 0) {
$z310311 = R.isFunction(if_helper1071295)?if_helper1071295.app(cont_tail_arg1088312):R.ffi.throwNonFunApp(L[25],if_helper1071295,[cont_tail_arg1088312]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1071295)?if_helper1071295.app(cont_tail_arg1088312):R.ffi.throwNonFunApp(L[25],if_helper1071295,[cont_tail_arg1088312]);
},
"from":L[25]});
}
++R.GAS;
return $z310311;
}
};
var $Hcont_tail_app1531297 = function(cont_tail_app1099296) {
return cont_tail_app1099296;
};
var $Hor_DASH_oper_DASH_1535309 = function(or_DASH_oper_DASH_129308,if_helper1071295,is_DASH_empty18116,l3365284) {
var anf_if1093377 = R.isBoolean(or_DASH_oper_DASH_129308);
if(R.isPyretTrue(anf_if1093377)) {
if(R.isPyretTrue(or_DASH_oper_DASH_129308)) {
var $z352353 = D;
var $f358359 = function(_) {
return R.isFunction(if_helper1071295)?if_helper1071295.app((true)):R.ffi.throwNonFunApp(L[24],if_helper1071295,[(true)]);
};
try {
if(--R.GAS > 0) {
$z352353 = $f358359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f358359,
"from":L[24]});
}
} catch($e350351) {
if(R.isCont($e350351)) {
var $ss354355 = {"from":L[24],
"go":function(cont_tail_app1098360) {
return $Hcont_tail_app1532361(cont_tail_app1098360);
}};
$e350351.stack[R.EXN_STACKHEIGHT++] = $ss354355;
}
if(R.isPyretException($e350351)) {
$e350351.pyretStack.push(L[24]);
}
throw $e350351;
}
var $ret356357 = $Hcont_tail_app1532361($z352353);
++R.GAS;
return $ret356357;
} else {
var $z364365 = D;
var $f370371 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l3365284):R.ffi.throwNonFunApp(L[24],is_DASH_empty18116.$var,[l3365284]);
};
try {
if(--R.GAS > 0) {
$z364365 = $f370371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f370371,
"from":L[24]});
}
} catch($e362363) {
if(R.isCont($e362363)) {
var $ss366367 = {"from":L[24],
"go":function(or_DASH_oper_DASH_130372) {
return $Hor_DASH_oper_DASH_1534373(or_DASH_oper_DASH_130372,if_helper1071295);
}};
$e362363.stack[R.EXN_STACKHEIGHT++] = $ss366367;
}
if(R.isPyretException($e362363)) {
$e362363.pyretStack.push(L[24]);
}
throw $e362363;
}
var $ret368369 = $Hor_DASH_oper_DASH_1534373($z364365,if_helper1071295);
++R.GAS;
return $ret368369;
}
} else {
var cont_tail_arg1091376 = R.throwNonBooleanOp(L[31],("first"),("or"),or_DASH_oper_DASH_129308);
if(--R.GAS > 0) {
$z374375 = R.isFunction(if_helper1071295)?if_helper1071295.app(cont_tail_arg1091376):R.ffi.throwNonFunApp(L[31],if_helper1071295,[cont_tail_arg1091376]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1071295)?if_helper1071295.app(cont_tail_arg1091376):R.ffi.throwNonFunApp(L[31],if_helper1071295,[cont_tail_arg1091376]);
},
"from":L[31]});
}
++R.GAS;
return $z374375;
}
};
var $Hcont_tail_app1532361 = function(cont_tail_app1098360) {
return cont_tail_app1098360;
};
var $Hor_DASH_oper_DASH_1534373 = function(or_DASH_oper_DASH_130372,if_helper1071295) {
var anf_if1096393 = R.isBoolean(or_DASH_oper_DASH_130372);
if(R.isPyretTrue(anf_if1096393)) {
var $z380381 = D;
var $f386387 = function(_) {
return R.isFunction(if_helper1071295)?if_helper1071295.app(or_DASH_oper_DASH_130372):R.ffi.throwNonFunApp(L[24],if_helper1071295,[or_DASH_oper_DASH_130372]);
};
try {
if(--R.GAS > 0) {
$z380381 = $f386387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f386387,
"from":L[24]});
}
} catch($e378379) {
if(R.isCont($e378379)) {
var $ss382383 = {"from":L[24],
"go":function(cont_tail_app1097388) {
return $Hcont_tail_app1533389(cont_tail_app1097388);
}};
$e378379.stack[R.EXN_STACKHEIGHT++] = $ss382383;
}
if(R.isPyretException($e378379)) {
$e378379.pyretStack.push(L[24]);
}
throw $e378379;
}
var $ret384385 = $Hcont_tail_app1533389($z380381);
++R.GAS;
return $ret384385;
} else {
var cont_tail_arg1094392 = R.throwNonBooleanOp(L[32],("second"),("or"),or_DASH_oper_DASH_130372);
if(--R.GAS > 0) {
$z390391 = R.isFunction(if_helper1071295)?if_helper1071295.app(cont_tail_arg1094392):R.ffi.throwNonFunApp(L[32],if_helper1071295,[cont_tail_arg1094392]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1071295)?if_helper1071295.app(cont_tail_arg1094392):R.ffi.throwNonFunApp(L[32],if_helper1071295,[cont_tail_arg1094392]);
},
"from":L[32]});
}
++R.GAS;
return $z390391;
}
};
var $Hcont_tail_app1533389 = function(cont_tail_app1097388) {
return cont_tail_app1097388;
};
var $Hcont_tail_app1528327 = function(cont_tail_app1087326) {
return cont_tail_app1087326;
};
var $Hanf_arg1530342 = function(anf_arg1081341,f361280,fold353281,if_helper1073325,l1363282,l2364283,l3365284) {
var anf_arg1082404 = G(l1363282,"rest",L[36]);
var anf_arg1083405 = G(l2364283,"rest",L[35]);
var anf_arg1084406 = G(l3365284,"rest",L[34]);
var $z396397 = D;
var $f402403 = function(_) {
return R.isFunction(fold353281.$var)?fold353281.$var.app(f361280,anf_arg1081341,anf_arg1082404,anf_arg1083405,anf_arg1084406):R.ffi.throwNonFunApp(L[33],fold353281.$var,[f361280,anf_arg1081341,anf_arg1082404,anf_arg1083405,anf_arg1084406]);
};
try {
if(--R.GAS > 0) {
$z396397 = $f402403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f402403,
"from":L[33]});
}
} catch($e394395) {
if(R.isCont($e394395)) {
var $ss398399 = {"from":L[33],
"go":function(cont_tail_arg1085407) {
return $Hcont_tail_arg1529408(cont_tail_arg1085407,if_helper1073325);
}};
$e394395.stack[R.EXN_STACKHEIGHT++] = $ss398399;
}
if(R.isPyretException($e394395)) {
$e394395.pyretStack.push(L[33]);
}
throw $e394395;
}
var $ret400401 = $Hcont_tail_arg1529408($z396397,if_helper1073325);
++R.GAS;
return $ret400401;
};
var $Hcont_tail_arg1529408 = function(cont_tail_arg1085407,if_helper1073325) {
if(--R.GAS > 0) {
$z409410 = R.isFunction(if_helper1073325)?if_helper1073325.app(cont_tail_arg1085407):R.ffi.throwNonFunApp(L[33],if_helper1073325,[cont_tail_arg1085407]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1073325)?if_helper1073325.app(cont_tail_arg1085407):R.ffi.throwNonFunApp(L[33],if_helper1073325,[cont_tail_arg1085407]);
},
"from":L[33]});
}
++R.GAS;
return $z409410;
};
var $Hor_DASH_oper_DASH_1527411 = function(or_DASH_oper_DASH_125412,base358413,f357414,fold252415,is_DASH_empty18116,l1359416,l2360417) {
var if_helper1046428 = R.makeFunction(function(if_helper_arg1047447) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[37],1,arguments);
}
var if_DASH_124475 = if_helper_arg1047447;
var if_helper1048458 = R.makeFunction(function(if_helper_arg1049480) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[37],1,arguments);
}
var ann_DASH_check_DASH_temp1045481 = if_helper_arg1049480;
return ann_DASH_check_DASH_temp1045481;
});
var anf_if1052479 = R.isBoolean(if_DASH_124475);
if(R.isPyretTrue(anf_if1052479)) {
if(R.isPyretTrue(if_DASH_124475)) {
var $z450451 = D;
var $f456457 = function(_) {
return R.isFunction(if_helper1048458)?if_helper1048458.app(base358413):R.ffi.throwNonFunApp(L[39],if_helper1048458,[base358413]);
};
try {
if(--R.GAS > 0) {
$z450451 = $f456457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f456457,
"from":L[39]});
}
} catch($e448449) {
if(R.isCont($e448449)) {
var $ss452453 = {"from":L[39],
"go":function(cont_tail_app1060459) {
return $Hcont_tail_app1521460(cont_tail_app1060459);
}};
$e448449.stack[R.EXN_STACKHEIGHT++] = $ss452453;
}
if(R.isPyretException($e448449)) {
$e448449.pyretStack.push(L[39]);
}
throw $e448449;
}
var $ret454455 = $Hcont_tail_app1521460($z450451);
++R.GAS;
return $ret454455;
} else {
var anf_arg1053471 = G(l1359416,"first",L[42]);
var anf_arg1054472 = G(l2360417,"first",L[41]);
var $z463464 = D;
var $f469470 = function(_) {
return R.isFunction(f357414)?f357414.app(base358413,anf_arg1053471,anf_arg1054472):R.ffi.throwNonFunApp(L[40],f357414,[base358413,anf_arg1053471,anf_arg1054472]);
};
try {
if(--R.GAS > 0) {
$z463464 = $f469470();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f469470,
"from":L[40]});
}
} catch($e461462) {
if(R.isCont($e461462)) {
var $ss465466 = {"from":L[40],
"go":function(anf_arg1055473) {
return $Hanf_arg1523474(anf_arg1055473,f357414,fold252415,if_helper1048458,l1359416,l2360417);
}};
$e461462.stack[R.EXN_STACKHEIGHT++] = $ss465466;
}
if(R.isPyretException($e461462)) {
$e461462.pyretStack.push(L[40]);
}
throw $e461462;
}
var $ret467468 = $Hanf_arg1523474($z463464,f357414,fold252415,if_helper1048458,l1359416,l2360417);
++R.GAS;
return $ret467468;
}
} else {
var cont_tail_arg1050478 = R.throwNonBooleanCondition(L[37],("if"),if_DASH_124475);
if(--R.GAS > 0) {
$z476477 = R.isFunction(if_helper1048458)?if_helper1048458.app(cont_tail_arg1050478):R.ffi.throwNonFunApp(L[37],if_helper1048458,[cont_tail_arg1050478]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1048458)?if_helper1048458.app(cont_tail_arg1050478):R.ffi.throwNonFunApp(L[37],if_helper1048458,[cont_tail_arg1050478]);
},
"from":L[37]});
}
++R.GAS;
return $z476477;
}
});
var anf_if1063446 = R.isBoolean(or_DASH_oper_DASH_125412);
if(R.isPyretTrue(anf_if1063446)) {
if(R.isPyretTrue(or_DASH_oper_DASH_125412)) {
var $z420421 = D;
var $f426427 = function(_) {
return R.isFunction(if_helper1046428)?if_helper1046428.app((true)):R.ffi.throwNonFunApp(L[37],if_helper1046428,[(true)]);
};
try {
if(--R.GAS > 0) {
$z420421 = $f426427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f426427,
"from":L[37]});
}
} catch($e418419) {
if(R.isCont($e418419)) {
var $ss422423 = {"from":L[37],
"go":function(cont_tail_app1068429) {
return $Hcont_tail_app1524430(cont_tail_app1068429);
}};
$e418419.stack[R.EXN_STACKHEIGHT++] = $ss422423;
}
if(R.isPyretException($e418419)) {
$e418419.pyretStack.push(L[37]);
}
throw $e418419;
}
var $ret424425 = $Hcont_tail_app1524430($z420421);
++R.GAS;
return $ret424425;
} else {
var $z433434 = D;
var $f439440 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l2360417):R.ffi.throwNonFunApp(L[37],is_DASH_empty18116.$var,[l2360417]);
};
try {
if(--R.GAS > 0) {
$z433434 = $f439440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f439440,
"from":L[37]});
}
} catch($e431432) {
if(R.isCont($e431432)) {
var $ss435436 = {"from":L[37],
"go":function(or_DASH_oper_DASH_126441) {
return $Hor_DASH_oper_DASH_1526442(or_DASH_oper_DASH_126441,if_helper1046428);
}};
$e431432.stack[R.EXN_STACKHEIGHT++] = $ss435436;
}
if(R.isPyretException($e431432)) {
$e431432.pyretStack.push(L[37]);
}
throw $e431432;
}
var $ret437438 = $Hor_DASH_oper_DASH_1526442($z433434,if_helper1046428);
++R.GAS;
return $ret437438;
}
} else {
var cont_tail_arg1061445 = R.throwNonBooleanOp(L[38],("first"),("or"),or_DASH_oper_DASH_125412);
if(--R.GAS > 0) {
$z443444 = R.isFunction(if_helper1046428)?if_helper1046428.app(cont_tail_arg1061445):R.ffi.throwNonFunApp(L[38],if_helper1046428,[cont_tail_arg1061445]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1046428)?if_helper1046428.app(cont_tail_arg1061445):R.ffi.throwNonFunApp(L[38],if_helper1046428,[cont_tail_arg1061445]);
},
"from":L[38]});
}
++R.GAS;
return $z443444;
}
};
var $Hcont_tail_app1524430 = function(cont_tail_app1068429) {
return cont_tail_app1068429;
};
var $Hor_DASH_oper_DASH_1526442 = function(or_DASH_oper_DASH_126441,if_helper1046428) {
var anf_if1066497 = R.isBoolean(or_DASH_oper_DASH_126441);
if(R.isPyretTrue(anf_if1066497)) {
var $z484485 = D;
var $f490491 = function(_) {
return R.isFunction(if_helper1046428)?if_helper1046428.app(or_DASH_oper_DASH_126441):R.ffi.throwNonFunApp(L[37],if_helper1046428,[or_DASH_oper_DASH_126441]);
};
try {
if(--R.GAS > 0) {
$z484485 = $f490491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f490491,
"from":L[37]});
}
} catch($e482483) {
if(R.isCont($e482483)) {
var $ss486487 = {"from":L[37],
"go":function(cont_tail_app1067492) {
return $Hcont_tail_app1525493(cont_tail_app1067492);
}};
$e482483.stack[R.EXN_STACKHEIGHT++] = $ss486487;
}
if(R.isPyretException($e482483)) {
$e482483.pyretStack.push(L[37]);
}
throw $e482483;
}
var $ret488489 = $Hcont_tail_app1525493($z484485);
++R.GAS;
return $ret488489;
} else {
var cont_tail_arg1064496 = R.throwNonBooleanOp(L[43],("second"),("or"),or_DASH_oper_DASH_126441);
if(--R.GAS > 0) {
$z494495 = R.isFunction(if_helper1046428)?if_helper1046428.app(cont_tail_arg1064496):R.ffi.throwNonFunApp(L[43],if_helper1046428,[cont_tail_arg1064496]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1046428)?if_helper1046428.app(cont_tail_arg1064496):R.ffi.throwNonFunApp(L[43],if_helper1046428,[cont_tail_arg1064496]);
},
"from":L[43]});
}
++R.GAS;
return $z494495;
}
};
var $Hcont_tail_app1525493 = function(cont_tail_app1067492) {
return cont_tail_app1067492;
};
var $Hcont_tail_app1521460 = function(cont_tail_app1060459) {
return cont_tail_app1060459;
};
var $Hanf_arg1523474 = function(anf_arg1055473,f357414,fold252415,if_helper1048458,l1359416,l2360417) {
var anf_arg1056508 = G(l1359416,"rest",L[46]);
var anf_arg1057509 = G(l2360417,"rest",L[45]);
var $z500501 = D;
var $f506507 = function(_) {
return R.isFunction(fold252415.$var)?fold252415.$var.app(f357414,anf_arg1055473,anf_arg1056508,anf_arg1057509):R.ffi.throwNonFunApp(L[44],fold252415.$var,[f357414,anf_arg1055473,anf_arg1056508,anf_arg1057509]);
};
try {
if(--R.GAS > 0) {
$z500501 = $f506507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f506507,
"from":L[44]});
}
} catch($e498499) {
if(R.isCont($e498499)) {
var $ss502503 = {"from":L[44],
"go":function(cont_tail_arg1058510) {
return $Hcont_tail_arg1522511(cont_tail_arg1058510,if_helper1048458);
}};
$e498499.stack[R.EXN_STACKHEIGHT++] = $ss502503;
}
if(R.isPyretException($e498499)) {
$e498499.pyretStack.push(L[44]);
}
throw $e498499;
}
var $ret504505 = $Hcont_tail_arg1522511($z500501,if_helper1048458);
++R.GAS;
return $ret504505;
};
var $Hcont_tail_arg1522511 = function(cont_tail_arg1058510,if_helper1048458) {
if(--R.GAS > 0) {
$z512513 = R.isFunction(if_helper1048458)?if_helper1048458.app(cont_tail_arg1058510):R.ffi.throwNonFunApp(L[44],if_helper1048458,[cont_tail_arg1058510]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1048458)?if_helper1048458.app(cont_tail_arg1058510):R.ffi.throwNonFunApp(L[44],if_helper1048458,[cont_tail_arg1058510]);
},
"from":L[44]});
}
++R.GAS;
return $z512513;
};
var $Hif_DASH_1520514 = function(if_DASH_123515,base349516,f348517,fold51518,lst350519) {
var if_helper1033530 = R.makeFunction(function(if_helper_arg1034550) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[50],1,arguments);
}
var ann_DASH_check_DASH_temp1032551 = if_helper_arg1034550;
return ann_DASH_check_DASH_temp1032551;
});
var anf_if1037549 = R.isBoolean(if_DASH_123515);
if(R.isPyretTrue(anf_if1037549)) {
if(R.isPyretTrue(if_DASH_123515)) {
var $z522523 = D;
var $f528529 = function(_) {
return R.isFunction(if_helper1033530)?if_helper1033530.app(base349516):R.ffi.throwNonFunApp(L[47],if_helper1033530,[base349516]);
};
try {
if(--R.GAS > 0) {
$z522523 = $f528529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f528529,
"from":L[47]});
}
} catch($e520521) {
if(R.isCont($e520521)) {
var $ss524525 = {"from":L[47],
"go":function(cont_tail_app1043531) {
return $Hcont_tail_app1517532(cont_tail_app1043531);
}};
$e520521.stack[R.EXN_STACKHEIGHT++] = $ss524525;
}
if(R.isPyretException($e520521)) {
$e520521.pyretStack.push(L[47]);
}
throw $e520521;
}
var $ret526527 = $Hcont_tail_app1517532($z522523);
++R.GAS;
return $ret526527;
} else {
var anf_arg1038543 = G(lst350519,"first",L[49]);
var $z535536 = D;
var $f541542 = function(_) {
return R.isFunction(f348517)?f348517.app(base349516,anf_arg1038543):R.ffi.throwNonFunApp(L[48],f348517,[base349516,anf_arg1038543]);
};
try {
if(--R.GAS > 0) {
$z535536 = $f541542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f541542,
"from":L[48]});
}
} catch($e533534) {
if(R.isCont($e533534)) {
var $ss537538 = {"from":L[48],
"go":function(anf_arg1039544) {
return $Hanf_arg1519545(anf_arg1039544,f348517,fold51518,if_helper1033530,lst350519);
}};
$e533534.stack[R.EXN_STACKHEIGHT++] = $ss537538;
}
if(R.isPyretException($e533534)) {
$e533534.pyretStack.push(L[48]);
}
throw $e533534;
}
var $ret539540 = $Hanf_arg1519545($z535536,f348517,fold51518,if_helper1033530,lst350519);
++R.GAS;
return $ret539540;
}
} else {
var cont_tail_arg1035548 = R.throwNonBooleanCondition(L[50],("if"),if_DASH_123515);
if(--R.GAS > 0) {
$z546547 = R.isFunction(if_helper1033530)?if_helper1033530.app(cont_tail_arg1035548):R.ffi.throwNonFunApp(L[50],if_helper1033530,[cont_tail_arg1035548]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1033530)?if_helper1033530.app(cont_tail_arg1035548):R.ffi.throwNonFunApp(L[50],if_helper1033530,[cont_tail_arg1035548]);
},
"from":L[50]});
}
++R.GAS;
return $z546547;
}
};
var $Hcont_tail_app1517532 = function(cont_tail_app1043531) {
return cont_tail_app1043531;
};
var $Hanf_arg1519545 = function(anf_arg1039544,f348517,fold51518,if_helper1033530,lst350519) {
var anf_arg1040562 = G(lst350519,"rest",L[52]);
var $z554555 = D;
var $f560561 = function(_) {
return R.isFunction(fold51518.$var)?fold51518.$var.app(f348517,anf_arg1039544,anf_arg1040562):R.ffi.throwNonFunApp(L[51],fold51518.$var,[f348517,anf_arg1039544,anf_arg1040562]);
};
try {
if(--R.GAS > 0) {
$z554555 = $f560561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f560561,
"from":L[51]});
}
} catch($e552553) {
if(R.isCont($e552553)) {
var $ss556557 = {"from":L[51],
"go":function(cont_tail_arg1041563) {
return $Hcont_tail_arg1518564(cont_tail_arg1041563,if_helper1033530);
}};
$e552553.stack[R.EXN_STACKHEIGHT++] = $ss556557;
}
if(R.isPyretException($e552553)) {
$e552553.pyretStack.push(L[51]);
}
throw $e552553;
}
var $ret558559 = $Hcont_tail_arg1518564($z554555,if_helper1033530);
++R.GAS;
return $ret558559;
};
var $Hcont_tail_arg1518564 = function(cont_tail_arg1041563,if_helper1033530) {
if(--R.GAS > 0) {
$z565566 = R.isFunction(if_helper1033530)?if_helper1033530.app(cont_tail_arg1041563):R.ffi.throwNonFunApp(L[51],if_helper1033530,[cont_tail_arg1041563]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1033530)?if_helper1033530.app(cont_tail_arg1041563):R.ffi.throwNonFunApp(L[51],if_helper1033530,[cont_tail_arg1041563]);
},
"from":L[51]});
}
++R.GAS;
return $z565566;
};
var $Hann_DASH_check_DASH_temp1516567 = function(ann_DASH_check_DASH_temp1014568) {
return ann_DASH_check_DASH_temp1014568;
};
var $Hcases_DASH_val1515569 = function(cases_DASH_val121570,f341571,fold_DASH_while50572,r345573) {
var anf_fun1019584 = G(cases_DASH_val121570,"_match",L[54]);
var anf_obj1021590 = R.makeFunction(function(v346594) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[56],1,arguments);
}
var $z597598 = D;
var $f603604 = function(_) {
return R.isFunction(fold_DASH_while50572.$var)?fold_DASH_while50572.$var.app(f341571,v346594,r345573):R.ffi.throwNonFunApp(L[56],fold_DASH_while50572.$var,[f341571,v346594,r345573]);
};
try {
if(--R.GAS > 0) {
$z597598 = $f603604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f603604,
"from":L[56]});
}
} catch($e595596) {
if(R.isCont($e595596)) {
var $ss599600 = {"from":L[56],
"go":function(ann_DASH_check_DASH_temp1020605) {
return $Hann_DASH_check_DASH_temp1513606(ann_DASH_check_DASH_temp1020605);
}};
$e595596.stack[R.EXN_STACKHEIGHT++] = $ss599600;
}
if(R.isPyretException($e595596)) {
$e595596.pyretStack.push(L[56]);
}
throw $e595596;
}
var $ret601602 = $Hann_DASH_check_DASH_temp1513606($z597598);
++R.GAS;
return $ret601602;
});
var anf_obj1023591 = R.makeFunction(function(v347592) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[55],1,arguments);
}
var ann_DASH_check_DASH_temp1022593 = v347592;
return ann_DASH_check_DASH_temp1022593;
});
var anf_arg1024585 = R.makeObject({"left":anf_obj1021590,
"right":anf_obj1023591});
var anf_arg1026586 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[54],0,arguments);
}
var ann_DASH_check_DASH_temp1025589 = R.throwNoBranchesMatched(L[54],("cases"));
return ann_DASH_check_DASH_temp1025589;
});
var $z576577 = D;
var $f582583 = function(_) {
return R.isFunction(anf_fun1019584)?anf_fun1019584.app(anf_arg1024585,anf_arg1026586):R.ffi.throwNonFunApp(L[53],anf_fun1019584,[anf_arg1024585,anf_arg1026586]);
};
try {
if(--R.GAS > 0) {
$z576577 = $f582583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f582583,
"from":L[53]});
}
} catch($e574575) {
if(R.isCont($e574575)) {
var $ss578579 = {"from":L[53],
"go":function(ann_DASH_check_DASH_temp1018587) {
return $Hann_DASH_check_DASH_temp1514588(ann_DASH_check_DASH_temp1018587);
}};
$e574575.stack[R.EXN_STACKHEIGHT++] = $ss578579;
}
if(R.isPyretException($e574575)) {
$e574575.pyretStack.push(L[53]);
}
throw $e574575;
}
var $ret580581 = $Hann_DASH_check_DASH_temp1514588($z576577);
++R.GAS;
return $ret580581;
};
var $Hann_DASH_check_DASH_temp1514588 = function(ann_DASH_check_DASH_temp1018587) {
return ann_DASH_check_DASH_temp1018587;
};
var $Hann_DASH_check_DASH_temp1513606 = function(ann_DASH_check_DASH_temp1020605) {
return ann_DASH_check_DASH_temp1020605;
};
var $Hann_DASH_check_DASH_temp1512607 = function(ann_DASH_check_DASH_temp975608) {
return ann_DASH_check_DASH_temp975608;
};
var $Hor_DASH_oper_DASH_1511609 = function(or_DASH_oper_DASH_117610,f329611,help335612,is_DASH_empty18116,l1337613,l2338614,l3339615,l4340616,n336617,_plus6,nothing8) {
var if_helper977628 = R.makeFunction(function(if_helper_arg978647) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[57],1,arguments);
}
var if_DASH_116677 = if_helper_arg978647;
var if_helper979658 = R.makeFunction(function(if_helper_arg980682) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[57],1,arguments);
}
var ann_DASH_check_DASH_temp976683 = if_helper_arg980682;
return ann_DASH_check_DASH_temp976683;
});
var anf_if983681 = R.isBoolean(if_DASH_116677);
if(R.isPyretTrue(anf_if983681)) {
if(R.isPyretTrue(if_DASH_116677)) {
var $z650651 = D;
var $f656657 = function(_) {
return R.isFunction(if_helper979658)?if_helper979658.app(nothing8):R.ffi.throwNonFunApp(L[59],if_helper979658,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z650651 = $f656657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f656657,
"from":L[59]});
}
} catch($e648649) {
if(R.isCont($e648649)) {
var $ss652653 = {"from":L[59],
"go":function(cont_tail_app995659) {
return $Hcont_tail_app1499660(cont_tail_app995659);
}};
$e648649.stack[R.EXN_STACKHEIGHT++] = $ss652653;
}
if(R.isPyretException($e648649)) {
$e648649.pyretStack.push(L[59]);
}
throw $e648649;
}
var $ret654655 = $Hcont_tail_app1499660($z650651);
++R.GAS;
return $ret654655;
} else {
var anf_arg984671 = G(l1337613,"first",L[64]);
var anf_arg985672 = G(l2338614,"first",L[63]);
var anf_arg986673 = G(l3339615,"first",L[62]);
var anf_arg987674 = G(l4340616,"first",L[61]);
var $z663664 = D;
var $f669670 = function(_) {
return R.isFunction(f329611)?f329611.app(n336617,anf_arg984671,anf_arg985672,anf_arg986673,anf_arg987674):R.ffi.throwNonFunApp(L[60],f329611,[n336617,anf_arg984671,anf_arg985672,anf_arg986673,anf_arg987674]);
};
try {
if(--R.GAS > 0) {
$z663664 = $f669670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f669670,
"from":L[60]});
}
} catch($e661662) {
if(R.isCont($e661662)) {
var $ss665666 = {"from":L[60],
"go":function(anf_begin_app_dropped1500675) {
return $Hanf_begin_app_dropped1503676(anf_begin_app_dropped1500675,help335612,if_helper979658,l1337613,l2338614,l3339615,l4340616,n336617,_plus6);
}};
$e661662.stack[R.EXN_STACKHEIGHT++] = $ss665666;
}
if(R.isPyretException($e661662)) {
$e661662.pyretStack.push(L[60]);
}
throw $e661662;
}
var $ret667668 = $Hanf_begin_app_dropped1503676($z663664,help335612,if_helper979658,l1337613,l2338614,l3339615,l4340616,n336617,_plus6);
++R.GAS;
return $ret667668;
}
} else {
var cont_tail_arg981680 = R.throwNonBooleanCondition(L[57],("if"),if_DASH_116677);
if(--R.GAS > 0) {
$z678679 = R.isFunction(if_helper979658)?if_helper979658.app(cont_tail_arg981680):R.ffi.throwNonFunApp(L[57],if_helper979658,[cont_tail_arg981680]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper979658)?if_helper979658.app(cont_tail_arg981680):R.ffi.throwNonFunApp(L[57],if_helper979658,[cont_tail_arg981680]);
},
"from":L[57]});
}
++R.GAS;
return $z678679;
}
});
var anf_if998646 = R.isBoolean(or_DASH_oper_DASH_117610);
if(R.isPyretTrue(anf_if998646)) {
if(R.isPyretTrue(or_DASH_oper_DASH_117610)) {
var $z620621 = D;
var $f626627 = function(_) {
return R.isFunction(if_helper977628)?if_helper977628.app((true)):R.ffi.throwNonFunApp(L[57],if_helper977628,[(true)]);
};
try {
if(--R.GAS > 0) {
$z620621 = $f626627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f626627,
"from":L[57]});
}
} catch($e618619) {
if(R.isCont($e618619)) {
var $ss622623 = {"from":L[57],
"go":function(cont_tail_app1011629) {
return $Hcont_tail_app1504630(cont_tail_app1011629);
}};
$e618619.stack[R.EXN_STACKHEIGHT++] = $ss622623;
}
if(R.isPyretException($e618619)) {
$e618619.pyretStack.push(L[57]);
}
throw $e618619;
}
var $ret624625 = $Hcont_tail_app1504630($z620621);
++R.GAS;
return $ret624625;
} else {
var $z633634 = D;
var $f639640 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l2338614):R.ffi.throwNonFunApp(L[57],is_DASH_empty18116.$var,[l2338614]);
};
try {
if(--R.GAS > 0) {
$z633634 = $f639640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f639640,
"from":L[57]});
}
} catch($e631632) {
if(R.isCont($e631632)) {
var $ss635636 = {"from":L[57],
"go":function(or_DASH_oper_DASH_118641) {
return $Hor_DASH_oper_DASH_1510642(or_DASH_oper_DASH_118641,if_helper977628,is_DASH_empty18116,l3339615,l4340616);
}};
$e631632.stack[R.EXN_STACKHEIGHT++] = $ss635636;
}
if(R.isPyretException($e631632)) {
$e631632.pyretStack.push(L[57]);
}
throw $e631632;
}
var $ret637638 = $Hor_DASH_oper_DASH_1510642($z633634,if_helper977628,is_DASH_empty18116,l3339615,l4340616);
++R.GAS;
return $ret637638;
}
} else {
var cont_tail_arg996645 = R.throwNonBooleanOp(L[58],("first"),("or"),or_DASH_oper_DASH_117610);
if(--R.GAS > 0) {
$z643644 = R.isFunction(if_helper977628)?if_helper977628.app(cont_tail_arg996645):R.ffi.throwNonFunApp(L[58],if_helper977628,[cont_tail_arg996645]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper977628)?if_helper977628.app(cont_tail_arg996645):R.ffi.throwNonFunApp(L[58],if_helper977628,[cont_tail_arg996645]);
},
"from":L[58]});
}
++R.GAS;
return $z643644;
}
};
var $Hcont_tail_app1504630 = function(cont_tail_app1011629) {
return cont_tail_app1011629;
};
var $Hor_DASH_oper_DASH_1510642 = function(or_DASH_oper_DASH_118641,if_helper977628,is_DASH_empty18116,l3339615,l4340616) {
var anf_if1001711 = R.isBoolean(or_DASH_oper_DASH_118641);
if(R.isPyretTrue(anf_if1001711)) {
if(R.isPyretTrue(or_DASH_oper_DASH_118641)) {
var $z686687 = D;
var $f692693 = function(_) {
return R.isFunction(if_helper977628)?if_helper977628.app((true)):R.ffi.throwNonFunApp(L[57],if_helper977628,[(true)]);
};
try {
if(--R.GAS > 0) {
$z686687 = $f692693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f692693,
"from":L[57]});
}
} catch($e684685) {
if(R.isCont($e684685)) {
var $ss688689 = {"from":L[57],
"go":function(cont_tail_app1010694) {
return $Hcont_tail_app1505695(cont_tail_app1010694);
}};
$e684685.stack[R.EXN_STACKHEIGHT++] = $ss688689;
}
if(R.isPyretException($e684685)) {
$e684685.pyretStack.push(L[57]);
}
throw $e684685;
}
var $ret690691 = $Hcont_tail_app1505695($z686687);
++R.GAS;
return $ret690691;
} else {
var $z698699 = D;
var $f704705 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l3339615):R.ffi.throwNonFunApp(L[57],is_DASH_empty18116.$var,[l3339615]);
};
try {
if(--R.GAS > 0) {
$z698699 = $f704705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f704705,
"from":L[57]});
}
} catch($e696697) {
if(R.isCont($e696697)) {
var $ss700701 = {"from":L[57],
"go":function(or_DASH_oper_DASH_119706) {
return $Hor_DASH_oper_DASH_1509707(or_DASH_oper_DASH_119706,if_helper977628,is_DASH_empty18116,l4340616);
}};
$e696697.stack[R.EXN_STACKHEIGHT++] = $ss700701;
}
if(R.isPyretException($e696697)) {
$e696697.pyretStack.push(L[57]);
}
throw $e696697;
}
var $ret702703 = $Hor_DASH_oper_DASH_1509707($z698699,if_helper977628,is_DASH_empty18116,l4340616);
++R.GAS;
return $ret702703;
}
} else {
var cont_tail_arg999710 = R.throwNonBooleanOp(L[65],("first"),("or"),or_DASH_oper_DASH_118641);
if(--R.GAS > 0) {
$z708709 = R.isFunction(if_helper977628)?if_helper977628.app(cont_tail_arg999710):R.ffi.throwNonFunApp(L[65],if_helper977628,[cont_tail_arg999710]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper977628)?if_helper977628.app(cont_tail_arg999710):R.ffi.throwNonFunApp(L[65],if_helper977628,[cont_tail_arg999710]);
},
"from":L[65]});
}
++R.GAS;
return $z708709;
}
};
var $Hcont_tail_app1505695 = function(cont_tail_app1010694) {
return cont_tail_app1010694;
};
var $Hor_DASH_oper_DASH_1509707 = function(or_DASH_oper_DASH_119706,if_helper977628,is_DASH_empty18116,l4340616) {
var anf_if1004739 = R.isBoolean(or_DASH_oper_DASH_119706);
if(R.isPyretTrue(anf_if1004739)) {
if(R.isPyretTrue(or_DASH_oper_DASH_119706)) {
var $z714715 = D;
var $f720721 = function(_) {
return R.isFunction(if_helper977628)?if_helper977628.app((true)):R.ffi.throwNonFunApp(L[57],if_helper977628,[(true)]);
};
try {
if(--R.GAS > 0) {
$z714715 = $f720721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f720721,
"from":L[57]});
}
} catch($e712713) {
if(R.isCont($e712713)) {
var $ss716717 = {"from":L[57],
"go":function(cont_tail_app1009722) {
return $Hcont_tail_app1506723(cont_tail_app1009722);
}};
$e712713.stack[R.EXN_STACKHEIGHT++] = $ss716717;
}
if(R.isPyretException($e712713)) {
$e712713.pyretStack.push(L[57]);
}
throw $e712713;
}
var $ret718719 = $Hcont_tail_app1506723($z714715);
++R.GAS;
return $ret718719;
} else {
var $z726727 = D;
var $f732733 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l4340616):R.ffi.throwNonFunApp(L[57],is_DASH_empty18116.$var,[l4340616]);
};
try {
if(--R.GAS > 0) {
$z726727 = $f732733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f732733,
"from":L[57]});
}
} catch($e724725) {
if(R.isCont($e724725)) {
var $ss728729 = {"from":L[57],
"go":function(or_DASH_oper_DASH_120734) {
return $Hor_DASH_oper_DASH_1508735(or_DASH_oper_DASH_120734,if_helper977628);
}};
$e724725.stack[R.EXN_STACKHEIGHT++] = $ss728729;
}
if(R.isPyretException($e724725)) {
$e724725.pyretStack.push(L[57]);
}
throw $e724725;
}
var $ret730731 = $Hor_DASH_oper_DASH_1508735($z726727,if_helper977628);
++R.GAS;
return $ret730731;
}
} else {
var cont_tail_arg1002738 = R.throwNonBooleanOp(L[66],("first"),("or"),or_DASH_oper_DASH_119706);
if(--R.GAS > 0) {
$z736737 = R.isFunction(if_helper977628)?if_helper977628.app(cont_tail_arg1002738):R.ffi.throwNonFunApp(L[66],if_helper977628,[cont_tail_arg1002738]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper977628)?if_helper977628.app(cont_tail_arg1002738):R.ffi.throwNonFunApp(L[66],if_helper977628,[cont_tail_arg1002738]);
},
"from":L[66]});
}
++R.GAS;
return $z736737;
}
};
var $Hcont_tail_app1506723 = function(cont_tail_app1009722) {
return cont_tail_app1009722;
};
var $Hor_DASH_oper_DASH_1508735 = function(or_DASH_oper_DASH_120734,if_helper977628) {
var anf_if1007755 = R.isBoolean(or_DASH_oper_DASH_120734);
if(R.isPyretTrue(anf_if1007755)) {
var $z742743 = D;
var $f748749 = function(_) {
return R.isFunction(if_helper977628)?if_helper977628.app(or_DASH_oper_DASH_120734):R.ffi.throwNonFunApp(L[57],if_helper977628,[or_DASH_oper_DASH_120734]);
};
try {
if(--R.GAS > 0) {
$z742743 = $f748749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f748749,
"from":L[57]});
}
} catch($e740741) {
if(R.isCont($e740741)) {
var $ss744745 = {"from":L[57],
"go":function(cont_tail_app1008750) {
return $Hcont_tail_app1507751(cont_tail_app1008750);
}};
$e740741.stack[R.EXN_STACKHEIGHT++] = $ss744745;
}
if(R.isPyretException($e740741)) {
$e740741.pyretStack.push(L[57]);
}
throw $e740741;
}
var $ret746747 = $Hcont_tail_app1507751($z742743);
++R.GAS;
return $ret746747;
} else {
var cont_tail_arg1005754 = R.throwNonBooleanOp(L[67],("second"),("or"),or_DASH_oper_DASH_120734);
if(--R.GAS > 0) {
$z752753 = R.isFunction(if_helper977628)?if_helper977628.app(cont_tail_arg1005754):R.ffi.throwNonFunApp(L[67],if_helper977628,[cont_tail_arg1005754]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper977628)?if_helper977628.app(cont_tail_arg1005754):R.ffi.throwNonFunApp(L[67],if_helper977628,[cont_tail_arg1005754]);
},
"from":L[67]});
}
++R.GAS;
return $z752753;
}
};
var $Hcont_tail_app1507751 = function(cont_tail_app1008750) {
return cont_tail_app1008750;
};
var $Hcont_tail_app1499660 = function(cont_tail_app995659) {
return cont_tail_app995659;
};
var $Hanf_begin_app_dropped1503676 = function(anf_begin_app_dropped1500675,help335612,if_helper979658,l1337613,l2338614,l3339615,l4340616,n336617,_plus6) {
var $z758759 = D;
var $f764765 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n336617,(1)):R.ffi.throwNonFunApp(L[68],_plus6,[n336617,(1)]);
};
try {
if(--R.GAS > 0) {
$z758759 = $f764765();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f764765,
"from":L[68]});
}
} catch($e756757) {
if(R.isCont($e756757)) {
var $ss760761 = {"from":L[68],
"go":function(anf_arg988766) {
return $Hanf_arg1502767(anf_arg988766,help335612,if_helper979658,l1337613,l2338614,l3339615,l4340616);
}};
$e756757.stack[R.EXN_STACKHEIGHT++] = $ss760761;
}
if(R.isPyretException($e756757)) {
$e756757.pyretStack.push(L[68]);
}
throw $e756757;
}
var $ret762763 = $Hanf_arg1502767($z758759,help335612,if_helper979658,l1337613,l2338614,l3339615,l4340616);
++R.GAS;
return $ret762763;
};
var $Hanf_arg1502767 = function(anf_arg988766,help335612,if_helper979658,l1337613,l2338614,l3339615,l4340616) {
var anf_arg989778 = G(l1337613,"rest",L[73]);
var anf_arg990779 = G(l2338614,"rest",L[72]);
var anf_arg991780 = G(l3339615,"rest",L[71]);
var anf_arg992781 = G(l4340616,"rest",L[70]);
var $z770771 = D;
var $f776777 = function(_) {
return R.isFunction(help335612.$var)?help335612.$var.app(anf_arg988766,anf_arg989778,anf_arg990779,anf_arg991780,anf_arg992781):R.ffi.throwNonFunApp(L[69],help335612.$var,[anf_arg988766,anf_arg989778,anf_arg990779,anf_arg991780,anf_arg992781]);
};
try {
if(--R.GAS > 0) {
$z770771 = $f776777();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f776777,
"from":L[69]});
}
} catch($e768769) {
if(R.isCont($e768769)) {
var $ss772773 = {"from":L[69],
"go":function(cont_tail_arg993782) {
return $Hcont_tail_arg1501783(cont_tail_arg993782,if_helper979658);
}};
$e768769.stack[R.EXN_STACKHEIGHT++] = $ss772773;
}
if(R.isPyretException($e768769)) {
$e768769.pyretStack.push(L[69]);
}
throw $e768769;
}
var $ret774775 = $Hcont_tail_arg1501783($z770771,if_helper979658);
++R.GAS;
return $ret774775;
};
var $Hcont_tail_arg1501783 = function(cont_tail_arg993782,if_helper979658) {
if(--R.GAS > 0) {
$z784785 = R.isFunction(if_helper979658)?if_helper979658.app(cont_tail_arg993782):R.ffi.throwNonFunApp(L[69],if_helper979658,[cont_tail_arg993782]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper979658)?if_helper979658.app(cont_tail_arg993782):R.ffi.throwNonFunApp(L[69],if_helper979658,[cont_tail_arg993782]);
},
"from":L[69]});
}
++R.GAS;
return $z784785;
};
var $Hann_DASH_check_DASH_temp1498786 = function(ann_DASH_check_DASH_temp942787) {
return ann_DASH_check_DASH_temp942787;
};
var $Hor_DASH_oper_DASH_1497788 = function(or_DASH_oper_DASH_113789,f319790,help324791,is_DASH_empty18116,l1326792,l2327793,l3328794,n325795,_plus6,nothing8) {
var if_helper944806 = R.makeFunction(function(if_helper_arg945825) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[74],1,arguments);
}
var if_DASH_112854 = if_helper_arg945825;
var if_helper946836 = R.makeFunction(function(if_helper_arg947859) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[74],1,arguments);
}
var ann_DASH_check_DASH_temp943860 = if_helper_arg947859;
return ann_DASH_check_DASH_temp943860;
});
var anf_if950858 = R.isBoolean(if_DASH_112854);
if(R.isPyretTrue(anf_if950858)) {
if(R.isPyretTrue(if_DASH_112854)) {
var $z828829 = D;
var $f834835 = function(_) {
return R.isFunction(if_helper946836)?if_helper946836.app(nothing8):R.ffi.throwNonFunApp(L[76],if_helper946836,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z828829 = $f834835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f834835,
"from":L[76]});
}
} catch($e826827) {
if(R.isCont($e826827)) {
var $ss830831 = {"from":L[76],
"go":function(cont_tail_app960837) {
return $Hcont_tail_app1487838(cont_tail_app960837);
}};
$e826827.stack[R.EXN_STACKHEIGHT++] = $ss830831;
}
if(R.isPyretException($e826827)) {
$e826827.pyretStack.push(L[76]);
}
throw $e826827;
}
var $ret832833 = $Hcont_tail_app1487838($z828829);
++R.GAS;
return $ret832833;
} else {
var anf_arg951849 = G(l1326792,"first",L[80]);
var anf_arg952850 = G(l2327793,"first",L[79]);
var anf_arg953851 = G(l3328794,"first",L[78]);
var $z841842 = D;
var $f847848 = function(_) {
return R.isFunction(f319790)?f319790.app(n325795,anf_arg951849,anf_arg952850,anf_arg953851):R.ffi.throwNonFunApp(L[77],f319790,[n325795,anf_arg951849,anf_arg952850,anf_arg953851]);
};
try {
if(--R.GAS > 0) {
$z841842 = $f847848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f847848,
"from":L[77]});
}
} catch($e839840) {
if(R.isCont($e839840)) {
var $ss843844 = {"from":L[77],
"go":function(anf_begin_app_dropped1488852) {
return $Hanf_begin_app_dropped1491853(anf_begin_app_dropped1488852,help324791,if_helper946836,l1326792,l2327793,l3328794,n325795,_plus6);
}};
$e839840.stack[R.EXN_STACKHEIGHT++] = $ss843844;
}
if(R.isPyretException($e839840)) {
$e839840.pyretStack.push(L[77]);
}
throw $e839840;
}
var $ret845846 = $Hanf_begin_app_dropped1491853($z841842,help324791,if_helper946836,l1326792,l2327793,l3328794,n325795,_plus6);
++R.GAS;
return $ret845846;
}
} else {
var cont_tail_arg948857 = R.throwNonBooleanCondition(L[74],("if"),if_DASH_112854);
if(--R.GAS > 0) {
$z855856 = R.isFunction(if_helper946836)?if_helper946836.app(cont_tail_arg948857):R.ffi.throwNonFunApp(L[74],if_helper946836,[cont_tail_arg948857]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper946836)?if_helper946836.app(cont_tail_arg948857):R.ffi.throwNonFunApp(L[74],if_helper946836,[cont_tail_arg948857]);
},
"from":L[74]});
}
++R.GAS;
return $z855856;
}
});
var anf_if963824 = R.isBoolean(or_DASH_oper_DASH_113789);
if(R.isPyretTrue(anf_if963824)) {
if(R.isPyretTrue(or_DASH_oper_DASH_113789)) {
var $z798799 = D;
var $f804805 = function(_) {
return R.isFunction(if_helper944806)?if_helper944806.app((true)):R.ffi.throwNonFunApp(L[74],if_helper944806,[(true)]);
};
try {
if(--R.GAS > 0) {
$z798799 = $f804805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f804805,
"from":L[74]});
}
} catch($e796797) {
if(R.isCont($e796797)) {
var $ss800801 = {"from":L[74],
"go":function(cont_tail_app972807) {
return $Hcont_tail_app1492808(cont_tail_app972807);
}};
$e796797.stack[R.EXN_STACKHEIGHT++] = $ss800801;
}
if(R.isPyretException($e796797)) {
$e796797.pyretStack.push(L[74]);
}
throw $e796797;
}
var $ret802803 = $Hcont_tail_app1492808($z798799);
++R.GAS;
return $ret802803;
} else {
var $z811812 = D;
var $f817818 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l2327793):R.ffi.throwNonFunApp(L[74],is_DASH_empty18116.$var,[l2327793]);
};
try {
if(--R.GAS > 0) {
$z811812 = $f817818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f817818,
"from":L[74]});
}
} catch($e809810) {
if(R.isCont($e809810)) {
var $ss813814 = {"from":L[74],
"go":function(or_DASH_oper_DASH_114819) {
return $Hor_DASH_oper_DASH_1496820(or_DASH_oper_DASH_114819,if_helper944806,is_DASH_empty18116,l3328794);
}};
$e809810.stack[R.EXN_STACKHEIGHT++] = $ss813814;
}
if(R.isPyretException($e809810)) {
$e809810.pyretStack.push(L[74]);
}
throw $e809810;
}
var $ret815816 = $Hor_DASH_oper_DASH_1496820($z811812,if_helper944806,is_DASH_empty18116,l3328794);
++R.GAS;
return $ret815816;
}
} else {
var cont_tail_arg961823 = R.throwNonBooleanOp(L[75],("first"),("or"),or_DASH_oper_DASH_113789);
if(--R.GAS > 0) {
$z821822 = R.isFunction(if_helper944806)?if_helper944806.app(cont_tail_arg961823):R.ffi.throwNonFunApp(L[75],if_helper944806,[cont_tail_arg961823]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper944806)?if_helper944806.app(cont_tail_arg961823):R.ffi.throwNonFunApp(L[75],if_helper944806,[cont_tail_arg961823]);
},
"from":L[75]});
}
++R.GAS;
return $z821822;
}
};
var $Hcont_tail_app1492808 = function(cont_tail_app972807) {
return cont_tail_app972807;
};
var $Hor_DASH_oper_DASH_1496820 = function(or_DASH_oper_DASH_114819,if_helper944806,is_DASH_empty18116,l3328794) {
var anf_if966888 = R.isBoolean(or_DASH_oper_DASH_114819);
if(R.isPyretTrue(anf_if966888)) {
if(R.isPyretTrue(or_DASH_oper_DASH_114819)) {
var $z863864 = D;
var $f869870 = function(_) {
return R.isFunction(if_helper944806)?if_helper944806.app((true)):R.ffi.throwNonFunApp(L[74],if_helper944806,[(true)]);
};
try {
if(--R.GAS > 0) {
$z863864 = $f869870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f869870,
"from":L[74]});
}
} catch($e861862) {
if(R.isCont($e861862)) {
var $ss865866 = {"from":L[74],
"go":function(cont_tail_app971871) {
return $Hcont_tail_app1493872(cont_tail_app971871);
}};
$e861862.stack[R.EXN_STACKHEIGHT++] = $ss865866;
}
if(R.isPyretException($e861862)) {
$e861862.pyretStack.push(L[74]);
}
throw $e861862;
}
var $ret867868 = $Hcont_tail_app1493872($z863864);
++R.GAS;
return $ret867868;
} else {
var $z875876 = D;
var $f881882 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l3328794):R.ffi.throwNonFunApp(L[74],is_DASH_empty18116.$var,[l3328794]);
};
try {
if(--R.GAS > 0) {
$z875876 = $f881882();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f881882,
"from":L[74]});
}
} catch($e873874) {
if(R.isCont($e873874)) {
var $ss877878 = {"from":L[74],
"go":function(or_DASH_oper_DASH_115883) {
return $Hor_DASH_oper_DASH_1495884(or_DASH_oper_DASH_115883,if_helper944806);
}};
$e873874.stack[R.EXN_STACKHEIGHT++] = $ss877878;
}
if(R.isPyretException($e873874)) {
$e873874.pyretStack.push(L[74]);
}
throw $e873874;
}
var $ret879880 = $Hor_DASH_oper_DASH_1495884($z875876,if_helper944806);
++R.GAS;
return $ret879880;
}
} else {
var cont_tail_arg964887 = R.throwNonBooleanOp(L[81],("first"),("or"),or_DASH_oper_DASH_114819);
if(--R.GAS > 0) {
$z885886 = R.isFunction(if_helper944806)?if_helper944806.app(cont_tail_arg964887):R.ffi.throwNonFunApp(L[81],if_helper944806,[cont_tail_arg964887]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper944806)?if_helper944806.app(cont_tail_arg964887):R.ffi.throwNonFunApp(L[81],if_helper944806,[cont_tail_arg964887]);
},
"from":L[81]});
}
++R.GAS;
return $z885886;
}
};
var $Hcont_tail_app1493872 = function(cont_tail_app971871) {
return cont_tail_app971871;
};
var $Hor_DASH_oper_DASH_1495884 = function(or_DASH_oper_DASH_115883,if_helper944806) {
var anf_if969904 = R.isBoolean(or_DASH_oper_DASH_115883);
if(R.isPyretTrue(anf_if969904)) {
var $z891892 = D;
var $f897898 = function(_) {
return R.isFunction(if_helper944806)?if_helper944806.app(or_DASH_oper_DASH_115883):R.ffi.throwNonFunApp(L[74],if_helper944806,[or_DASH_oper_DASH_115883]);
};
try {
if(--R.GAS > 0) {
$z891892 = $f897898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f897898,
"from":L[74]});
}
} catch($e889890) {
if(R.isCont($e889890)) {
var $ss893894 = {"from":L[74],
"go":function(cont_tail_app970899) {
return $Hcont_tail_app1494900(cont_tail_app970899);
}};
$e889890.stack[R.EXN_STACKHEIGHT++] = $ss893894;
}
if(R.isPyretException($e889890)) {
$e889890.pyretStack.push(L[74]);
}
throw $e889890;
}
var $ret895896 = $Hcont_tail_app1494900($z891892);
++R.GAS;
return $ret895896;
} else {
var cont_tail_arg967903 = R.throwNonBooleanOp(L[82],("second"),("or"),or_DASH_oper_DASH_115883);
if(--R.GAS > 0) {
$z901902 = R.isFunction(if_helper944806)?if_helper944806.app(cont_tail_arg967903):R.ffi.throwNonFunApp(L[82],if_helper944806,[cont_tail_arg967903]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper944806)?if_helper944806.app(cont_tail_arg967903):R.ffi.throwNonFunApp(L[82],if_helper944806,[cont_tail_arg967903]);
},
"from":L[82]});
}
++R.GAS;
return $z901902;
}
};
var $Hcont_tail_app1494900 = function(cont_tail_app970899) {
return cont_tail_app970899;
};
var $Hcont_tail_app1487838 = function(cont_tail_app960837) {
return cont_tail_app960837;
};
var $Hanf_begin_app_dropped1491853 = function(anf_begin_app_dropped1488852,help324791,if_helper946836,l1326792,l2327793,l3328794,n325795,_plus6) {
var $z907908 = D;
var $f913914 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n325795,(1)):R.ffi.throwNonFunApp(L[83],_plus6,[n325795,(1)]);
};
try {
if(--R.GAS > 0) {
$z907908 = $f913914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f913914,
"from":L[83]});
}
} catch($e905906) {
if(R.isCont($e905906)) {
var $ss909910 = {"from":L[83],
"go":function(anf_arg954915) {
return $Hanf_arg1490916(anf_arg954915,help324791,if_helper946836,l1326792,l2327793,l3328794);
}};
$e905906.stack[R.EXN_STACKHEIGHT++] = $ss909910;
}
if(R.isPyretException($e905906)) {
$e905906.pyretStack.push(L[83]);
}
throw $e905906;
}
var $ret911912 = $Hanf_arg1490916($z907908,help324791,if_helper946836,l1326792,l2327793,l3328794);
++R.GAS;
return $ret911912;
};
var $Hanf_arg1490916 = function(anf_arg954915,help324791,if_helper946836,l1326792,l2327793,l3328794) {
var anf_arg955927 = G(l1326792,"rest",L[87]);
var anf_arg956928 = G(l2327793,"rest",L[86]);
var anf_arg957929 = G(l3328794,"rest",L[85]);
var $z919920 = D;
var $f925926 = function(_) {
return R.isFunction(help324791.$var)?help324791.$var.app(anf_arg954915,anf_arg955927,anf_arg956928,anf_arg957929):R.ffi.throwNonFunApp(L[84],help324791.$var,[anf_arg954915,anf_arg955927,anf_arg956928,anf_arg957929]);
};
try {
if(--R.GAS > 0) {
$z919920 = $f925926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f925926,
"from":L[84]});
}
} catch($e917918) {
if(R.isCont($e917918)) {
var $ss921922 = {"from":L[84],
"go":function(cont_tail_arg958930) {
return $Hcont_tail_arg1489931(cont_tail_arg958930,if_helper946836);
}};
$e917918.stack[R.EXN_STACKHEIGHT++] = $ss921922;
}
if(R.isPyretException($e917918)) {
$e917918.pyretStack.push(L[84]);
}
throw $e917918;
}
var $ret923924 = $Hcont_tail_arg1489931($z919920,if_helper946836);
++R.GAS;
return $ret923924;
};
var $Hcont_tail_arg1489931 = function(cont_tail_arg958930,if_helper946836) {
if(--R.GAS > 0) {
$z932933 = R.isFunction(if_helper946836)?if_helper946836.app(cont_tail_arg958930):R.ffi.throwNonFunApp(L[84],if_helper946836,[cont_tail_arg958930]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper946836)?if_helper946836.app(cont_tail_arg958930):R.ffi.throwNonFunApp(L[84],if_helper946836,[cont_tail_arg958930]);
},
"from":L[84]});
}
++R.GAS;
return $z932933;
};
var $Hann_DASH_check_DASH_temp1486934 = function(ann_DASH_check_DASH_temp915935) {
return ann_DASH_check_DASH_temp915935;
};
var $Hor_DASH_oper_DASH_1485936 = function(or_DASH_oper_DASH_110937,f311938,help315939,is_DASH_empty18116,l1317940,l2318941,n316942,_plus6,nothing8) {
var if_helper917953 = R.makeFunction(function(if_helper_arg918972) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[88],1,arguments);
}
var if_DASH_1091000 = if_helper_arg918972;
var if_helper919983 = R.makeFunction(function(if_helper_arg9201005) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[88],1,arguments);
}
var ann_DASH_check_DASH_temp9161006 = if_helper_arg9201005;
return ann_DASH_check_DASH_temp9161006;
});
var anf_if9231004 = R.isBoolean(if_DASH_1091000);
if(R.isPyretTrue(anf_if9231004)) {
if(R.isPyretTrue(if_DASH_1091000)) {
var $z975976 = D;
var $f981982 = function(_) {
return R.isFunction(if_helper919983)?if_helper919983.app(nothing8):R.ffi.throwNonFunApp(L[90],if_helper919983,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z975976 = $f981982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f981982,
"from":L[90]});
}
} catch($e973974) {
if(R.isCont($e973974)) {
var $ss977978 = {"from":L[90],
"go":function(cont_tail_app931984) {
return $Hcont_tail_app1477985(cont_tail_app931984);
}};
$e973974.stack[R.EXN_STACKHEIGHT++] = $ss977978;
}
if(R.isPyretException($e973974)) {
$e973974.pyretStack.push(L[90]);
}
throw $e973974;
}
var $ret979980 = $Hcont_tail_app1477985($z975976);
++R.GAS;
return $ret979980;
} else {
var anf_arg924996 = G(l1317940,"first",L[93]);
var anf_arg925997 = G(l2318941,"first",L[92]);
var $z988989 = D;
var $f994995 = function(_) {
return R.isFunction(f311938)?f311938.app(n316942,anf_arg924996,anf_arg925997):R.ffi.throwNonFunApp(L[91],f311938,[n316942,anf_arg924996,anf_arg925997]);
};
try {
if(--R.GAS > 0) {
$z988989 = $f994995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f994995,
"from":L[91]});
}
} catch($e986987) {
if(R.isCont($e986987)) {
var $ss990991 = {"from":L[91],
"go":function(anf_begin_app_dropped1478998) {
return $Hanf_begin_app_dropped1481999(anf_begin_app_dropped1478998,help315939,if_helper919983,l1317940,l2318941,n316942,_plus6);
}};
$e986987.stack[R.EXN_STACKHEIGHT++] = $ss990991;
}
if(R.isPyretException($e986987)) {
$e986987.pyretStack.push(L[91]);
}
throw $e986987;
}
var $ret992993 = $Hanf_begin_app_dropped1481999($z988989,help315939,if_helper919983,l1317940,l2318941,n316942,_plus6);
++R.GAS;
return $ret992993;
}
} else {
var cont_tail_arg9211003 = R.throwNonBooleanCondition(L[88],("if"),if_DASH_1091000);
if(--R.GAS > 0) {
$z10011002 = R.isFunction(if_helper919983)?if_helper919983.app(cont_tail_arg9211003):R.ffi.throwNonFunApp(L[88],if_helper919983,[cont_tail_arg9211003]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper919983)?if_helper919983.app(cont_tail_arg9211003):R.ffi.throwNonFunApp(L[88],if_helper919983,[cont_tail_arg9211003]);
},
"from":L[88]});
}
++R.GAS;
return $z10011002;
}
});
var anf_if934971 = R.isBoolean(or_DASH_oper_DASH_110937);
if(R.isPyretTrue(anf_if934971)) {
if(R.isPyretTrue(or_DASH_oper_DASH_110937)) {
var $z945946 = D;
var $f951952 = function(_) {
return R.isFunction(if_helper917953)?if_helper917953.app((true)):R.ffi.throwNonFunApp(L[88],if_helper917953,[(true)]);
};
try {
if(--R.GAS > 0) {
$z945946 = $f951952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f951952,
"from":L[88]});
}
} catch($e943944) {
if(R.isCont($e943944)) {
var $ss947948 = {"from":L[88],
"go":function(cont_tail_app939954) {
return $Hcont_tail_app1482955(cont_tail_app939954);
}};
$e943944.stack[R.EXN_STACKHEIGHT++] = $ss947948;
}
if(R.isPyretException($e943944)) {
$e943944.pyretStack.push(L[88]);
}
throw $e943944;
}
var $ret949950 = $Hcont_tail_app1482955($z945946);
++R.GAS;
return $ret949950;
} else {
var $z958959 = D;
var $f964965 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l2318941):R.ffi.throwNonFunApp(L[88],is_DASH_empty18116.$var,[l2318941]);
};
try {
if(--R.GAS > 0) {
$z958959 = $f964965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f964965,
"from":L[88]});
}
} catch($e956957) {
if(R.isCont($e956957)) {
var $ss960961 = {"from":L[88],
"go":function(or_DASH_oper_DASH_111966) {
return $Hor_DASH_oper_DASH_1484967(or_DASH_oper_DASH_111966,if_helper917953);
}};
$e956957.stack[R.EXN_STACKHEIGHT++] = $ss960961;
}
if(R.isPyretException($e956957)) {
$e956957.pyretStack.push(L[88]);
}
throw $e956957;
}
var $ret962963 = $Hor_DASH_oper_DASH_1484967($z958959,if_helper917953);
++R.GAS;
return $ret962963;
}
} else {
var cont_tail_arg932970 = R.throwNonBooleanOp(L[89],("first"),("or"),or_DASH_oper_DASH_110937);
if(--R.GAS > 0) {
$z968969 = R.isFunction(if_helper917953)?if_helper917953.app(cont_tail_arg932970):R.ffi.throwNonFunApp(L[89],if_helper917953,[cont_tail_arg932970]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper917953)?if_helper917953.app(cont_tail_arg932970):R.ffi.throwNonFunApp(L[89],if_helper917953,[cont_tail_arg932970]);
},
"from":L[89]});
}
++R.GAS;
return $z968969;
}
};
var $Hcont_tail_app1482955 = function(cont_tail_app939954) {
return cont_tail_app939954;
};
var $Hor_DASH_oper_DASH_1484967 = function(or_DASH_oper_DASH_111966,if_helper917953) {
var anf_if9371022 = R.isBoolean(or_DASH_oper_DASH_111966);
if(R.isPyretTrue(anf_if9371022)) {
var $z10091010 = D;
var $f10151016 = function(_) {
return R.isFunction(if_helper917953)?if_helper917953.app(or_DASH_oper_DASH_111966):R.ffi.throwNonFunApp(L[88],if_helper917953,[or_DASH_oper_DASH_111966]);
};
try {
if(--R.GAS > 0) {
$z10091010 = $f10151016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10151016,
"from":L[88]});
}
} catch($e10071008) {
if(R.isCont($e10071008)) {
var $ss10111012 = {"from":L[88],
"go":function(cont_tail_app9381017) {
return $Hcont_tail_app14831018(cont_tail_app9381017);
}};
$e10071008.stack[R.EXN_STACKHEIGHT++] = $ss10111012;
}
if(R.isPyretException($e10071008)) {
$e10071008.pyretStack.push(L[88]);
}
throw $e10071008;
}
var $ret10131014 = $Hcont_tail_app14831018($z10091010);
++R.GAS;
return $ret10131014;
} else {
var cont_tail_arg9351021 = R.throwNonBooleanOp(L[94],("second"),("or"),or_DASH_oper_DASH_111966);
if(--R.GAS > 0) {
$z10191020 = R.isFunction(if_helper917953)?if_helper917953.app(cont_tail_arg9351021):R.ffi.throwNonFunApp(L[94],if_helper917953,[cont_tail_arg9351021]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper917953)?if_helper917953.app(cont_tail_arg9351021):R.ffi.throwNonFunApp(L[94],if_helper917953,[cont_tail_arg9351021]);
},
"from":L[94]});
}
++R.GAS;
return $z10191020;
}
};
var $Hcont_tail_app14831018 = function(cont_tail_app9381017) {
return cont_tail_app9381017;
};
var $Hcont_tail_app1477985 = function(cont_tail_app931984) {
return cont_tail_app931984;
};
var $Hanf_begin_app_dropped1481999 = function(anf_begin_app_dropped1478998,help315939,if_helper919983,l1317940,l2318941,n316942,_plus6) {
var $z10251026 = D;
var $f10311032 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n316942,(1)):R.ffi.throwNonFunApp(L[95],_plus6,[n316942,(1)]);
};
try {
if(--R.GAS > 0) {
$z10251026 = $f10311032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10311032,
"from":L[95]});
}
} catch($e10231024) {
if(R.isCont($e10231024)) {
var $ss10271028 = {"from":L[95],
"go":function(anf_arg9261033) {
return $Hanf_arg14801034(anf_arg9261033,help315939,if_helper919983,l1317940,l2318941);
}};
$e10231024.stack[R.EXN_STACKHEIGHT++] = $ss10271028;
}
if(R.isPyretException($e10231024)) {
$e10231024.pyretStack.push(L[95]);
}
throw $e10231024;
}
var $ret10291030 = $Hanf_arg14801034($z10251026,help315939,if_helper919983,l1317940,l2318941);
++R.GAS;
return $ret10291030;
};
var $Hanf_arg14801034 = function(anf_arg9261033,help315939,if_helper919983,l1317940,l2318941) {
var anf_arg9271045 = G(l1317940,"rest",L[98]);
var anf_arg9281046 = G(l2318941,"rest",L[97]);
var $z10371038 = D;
var $f10431044 = function(_) {
return R.isFunction(help315939.$var)?help315939.$var.app(anf_arg9261033,anf_arg9271045,anf_arg9281046):R.ffi.throwNonFunApp(L[96],help315939.$var,[anf_arg9261033,anf_arg9271045,anf_arg9281046]);
};
try {
if(--R.GAS > 0) {
$z10371038 = $f10431044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10431044,
"from":L[96]});
}
} catch($e10351036) {
if(R.isCont($e10351036)) {
var $ss10391040 = {"from":L[96],
"go":function(cont_tail_arg9291047) {
return $Hcont_tail_arg14791048(cont_tail_arg9291047,if_helper919983);
}};
$e10351036.stack[R.EXN_STACKHEIGHT++] = $ss10391040;
}
if(R.isPyretException($e10351036)) {
$e10351036.pyretStack.push(L[96]);
}
throw $e10351036;
}
var $ret10411042 = $Hcont_tail_arg14791048($z10371038,if_helper919983);
++R.GAS;
return $ret10411042;
};
var $Hcont_tail_arg14791048 = function(cont_tail_arg9291047,if_helper919983) {
if(--R.GAS > 0) {
$z10491050 = R.isFunction(if_helper919983)?if_helper919983.app(cont_tail_arg9291047):R.ffi.throwNonFunApp(L[96],if_helper919983,[cont_tail_arg9291047]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper919983)?if_helper919983.app(cont_tail_arg9291047):R.ffi.throwNonFunApp(L[96],if_helper919983,[cont_tail_arg9291047]);
},
"from":L[96]});
}
++R.GAS;
return $z10491050;
};
var $Hann_DASH_check_DASH_temp14761051 = function(ann_DASH_check_DASH_temp9001052) {
return ann_DASH_check_DASH_temp9001052;
};
var $Hif_DASH_14751053 = function(if_DASH_1081054,f3051055,help3081056,l3101057,n3091058,_plus6,nothing8) {
var if_helper9021069 = R.makeFunction(function(if_helper_arg9031089) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[102],1,arguments);
}
var ann_DASH_check_DASH_temp9011090 = if_helper_arg9031089;
return ann_DASH_check_DASH_temp9011090;
});
var anf_if9061088 = R.isBoolean(if_DASH_1081054);
if(R.isPyretTrue(anf_if9061088)) {
if(R.isPyretTrue(if_DASH_1081054)) {
var $z10611062 = D;
var $f10671068 = function(_) {
return R.isFunction(if_helper9021069)?if_helper9021069.app(nothing8):R.ffi.throwNonFunApp(L[99],if_helper9021069,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z10611062 = $f10671068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10671068,
"from":L[99]});
}
} catch($e10591060) {
if(R.isCont($e10591060)) {
var $ss10631064 = {"from":L[99],
"go":function(cont_tail_app9121070) {
return $Hcont_tail_app14701071(cont_tail_app9121070);
}};
$e10591060.stack[R.EXN_STACKHEIGHT++] = $ss10631064;
}
if(R.isPyretException($e10591060)) {
$e10591060.pyretStack.push(L[99]);
}
throw $e10591060;
}
var $ret10651066 = $Hcont_tail_app14701071($z10611062);
++R.GAS;
return $ret10651066;
} else {
var anf_arg9071082 = G(l3101057,"first",L[101]);
var $z10741075 = D;
var $f10801081 = function(_) {
return R.isFunction(f3051055)?f3051055.app(n3091058,anf_arg9071082):R.ffi.throwNonFunApp(L[100],f3051055,[n3091058,anf_arg9071082]);
};
try {
if(--R.GAS > 0) {
$z10741075 = $f10801081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10801081,
"from":L[100]});
}
} catch($e10721073) {
if(R.isCont($e10721073)) {
var $ss10761077 = {"from":L[100],
"go":function(anf_begin_app_dropped14711083) {
return $Hanf_begin_app_dropped14741084(anf_begin_app_dropped14711083,help3081056,if_helper9021069,l3101057,n3091058,_plus6);
}};
$e10721073.stack[R.EXN_STACKHEIGHT++] = $ss10761077;
}
if(R.isPyretException($e10721073)) {
$e10721073.pyretStack.push(L[100]);
}
throw $e10721073;
}
var $ret10781079 = $Hanf_begin_app_dropped14741084($z10741075,help3081056,if_helper9021069,l3101057,n3091058,_plus6);
++R.GAS;
return $ret10781079;
}
} else {
var cont_tail_arg9041087 = R.throwNonBooleanCondition(L[102],("if"),if_DASH_1081054);
if(--R.GAS > 0) {
$z10851086 = R.isFunction(if_helper9021069)?if_helper9021069.app(cont_tail_arg9041087):R.ffi.throwNonFunApp(L[102],if_helper9021069,[cont_tail_arg9041087]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper9021069)?if_helper9021069.app(cont_tail_arg9041087):R.ffi.throwNonFunApp(L[102],if_helper9021069,[cont_tail_arg9041087]);
},
"from":L[102]});
}
++R.GAS;
return $z10851086;
}
};
var $Hcont_tail_app14701071 = function(cont_tail_app9121070) {
return cont_tail_app9121070;
};
var $Hanf_begin_app_dropped14741084 = function(anf_begin_app_dropped14711083,help3081056,if_helper9021069,l3101057,n3091058,_plus6) {
var $z10931094 = D;
var $f10991100 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n3091058,(1)):R.ffi.throwNonFunApp(L[103],_plus6,[n3091058,(1)]);
};
try {
if(--R.GAS > 0) {
$z10931094 = $f10991100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10991100,
"from":L[103]});
}
} catch($e10911092) {
if(R.isCont($e10911092)) {
var $ss10951096 = {"from":L[103],
"go":function(anf_arg9081101) {
return $Hanf_arg14731102(anf_arg9081101,help3081056,if_helper9021069,l3101057);
}};
$e10911092.stack[R.EXN_STACKHEIGHT++] = $ss10951096;
}
if(R.isPyretException($e10911092)) {
$e10911092.pyretStack.push(L[103]);
}
throw $e10911092;
}
var $ret10971098 = $Hanf_arg14731102($z10931094,help3081056,if_helper9021069,l3101057);
++R.GAS;
return $ret10971098;
};
var $Hanf_arg14731102 = function(anf_arg9081101,help3081056,if_helper9021069,l3101057) {
var anf_arg9091113 = G(l3101057,"rest",L[105]);
var $z11051106 = D;
var $f11111112 = function(_) {
return R.isFunction(help3081056.$var)?help3081056.$var.app(anf_arg9081101,anf_arg9091113):R.ffi.throwNonFunApp(L[104],help3081056.$var,[anf_arg9081101,anf_arg9091113]);
};
try {
if(--R.GAS > 0) {
$z11051106 = $f11111112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11111112,
"from":L[104]});
}
} catch($e11031104) {
if(R.isCont($e11031104)) {
var $ss11071108 = {"from":L[104],
"go":function(cont_tail_arg9101114) {
return $Hcont_tail_arg14721115(cont_tail_arg9101114,if_helper9021069);
}};
$e11031104.stack[R.EXN_STACKHEIGHT++] = $ss11071108;
}
if(R.isPyretException($e11031104)) {
$e11031104.pyretStack.push(L[104]);
}
throw $e11031104;
}
var $ret11091110 = $Hcont_tail_arg14721115($z11051106,if_helper9021069);
++R.GAS;
return $ret11091110;
};
var $Hcont_tail_arg14721115 = function(cont_tail_arg9101114,if_helper9021069) {
if(--R.GAS > 0) {
$z11161117 = R.isFunction(if_helper9021069)?if_helper9021069.app(cont_tail_arg9101114):R.ffi.throwNonFunApp(L[104],if_helper9021069,[cont_tail_arg9101114]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper9021069)?if_helper9021069.app(cont_tail_arg9101114):R.ffi.throwNonFunApp(L[104],if_helper9021069,[cont_tail_arg9101114]);
},
"from":L[104]});
}
++R.GAS;
return $z11161117;
};
var $Hann_DASH_check_DASH_temp14691118 = function(ann_DASH_check_DASH_temp8621119) {
return ann_DASH_check_DASH_temp8621119;
};
var $Hor_DASH_oper_DASH_14681120 = function(or_DASH_oper_DASH_1041121,f2951122,help3001123,is_DASH_empty18116,l13011124,l23021125,l33031126,l43041127,nothing8) {
var if_helper8641138 = R.makeFunction(function(if_helper_arg8651157) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[106],1,arguments);
}
var if_DASH_1031187 = if_helper_arg8651157;
var if_helper8661168 = R.makeFunction(function(if_helper_arg8671192) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[106],1,arguments);
}
var ann_DASH_check_DASH_temp8631193 = if_helper_arg8671192;
return ann_DASH_check_DASH_temp8631193;
});
var anf_if8701191 = R.isBoolean(if_DASH_1031187);
if(R.isPyretTrue(anf_if8701191)) {
if(R.isPyretTrue(if_DASH_1031187)) {
var $z11601161 = D;
var $f11661167 = function(_) {
return R.isFunction(if_helper8661168)?if_helper8661168.app(nothing8):R.ffi.throwNonFunApp(L[108],if_helper8661168,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z11601161 = $f11661167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11661167,
"from":L[108]});
}
} catch($e11581159) {
if(R.isCont($e11581159)) {
var $ss11621163 = {"from":L[108],
"go":function(cont_tail_app8811169) {
return $Hcont_tail_app14571170(cont_tail_app8811169);
}};
$e11581159.stack[R.EXN_STACKHEIGHT++] = $ss11621163;
}
if(R.isPyretException($e11581159)) {
$e11581159.pyretStack.push(L[108]);
}
throw $e11581159;
}
var $ret11641165 = $Hcont_tail_app14571170($z11601161);
++R.GAS;
return $ret11641165;
} else {
var anf_arg8711181 = G(l13011124,"first",L[113]);
var anf_arg8721182 = G(l23021125,"first",L[112]);
var anf_arg8731183 = G(l33031126,"first",L[111]);
var anf_arg8741184 = G(l43041127,"first",L[110]);
var $z11731174 = D;
var $f11791180 = function(_) {
return R.isFunction(f2951122)?f2951122.app(anf_arg8711181,anf_arg8721182,anf_arg8731183,anf_arg8741184):R.ffi.throwNonFunApp(L[109],f2951122,[anf_arg8711181,anf_arg8721182,anf_arg8731183,anf_arg8741184]);
};
try {
if(--R.GAS > 0) {
$z11731174 = $f11791180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11791180,
"from":L[109]});
}
} catch($e11711172) {
if(R.isCont($e11711172)) {
var $ss11751176 = {"from":L[109],
"go":function(anf_begin_app_dropped14581185) {
return $Hanf_begin_app_dropped14601186(anf_begin_app_dropped14581185,help3001123,if_helper8661168,l13011124,l23021125,l33031126,l43041127);
}};
$e11711172.stack[R.EXN_STACKHEIGHT++] = $ss11751176;
}
if(R.isPyretException($e11711172)) {
$e11711172.pyretStack.push(L[109]);
}
throw $e11711172;
}
var $ret11771178 = $Hanf_begin_app_dropped14601186($z11731174,help3001123,if_helper8661168,l13011124,l23021125,l33031126,l43041127);
++R.GAS;
return $ret11771178;
}
} else {
var cont_tail_arg8681190 = R.throwNonBooleanCondition(L[106],("if"),if_DASH_1031187);
if(--R.GAS > 0) {
$z11881189 = R.isFunction(if_helper8661168)?if_helper8661168.app(cont_tail_arg8681190):R.ffi.throwNonFunApp(L[106],if_helper8661168,[cont_tail_arg8681190]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8661168)?if_helper8661168.app(cont_tail_arg8681190):R.ffi.throwNonFunApp(L[106],if_helper8661168,[cont_tail_arg8681190]);
},
"from":L[106]});
}
++R.GAS;
return $z11881189;
}
});
var anf_if8841156 = R.isBoolean(or_DASH_oper_DASH_1041121);
if(R.isPyretTrue(anf_if8841156)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1041121)) {
var $z11301131 = D;
var $f11361137 = function(_) {
return R.isFunction(if_helper8641138)?if_helper8641138.app((true)):R.ffi.throwNonFunApp(L[106],if_helper8641138,[(true)]);
};
try {
if(--R.GAS > 0) {
$z11301131 = $f11361137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11361137,
"from":L[106]});
}
} catch($e11281129) {
if(R.isCont($e11281129)) {
var $ss11321133 = {"from":L[106],
"go":function(cont_tail_app8971139) {
return $Hcont_tail_app14611140(cont_tail_app8971139);
}};
$e11281129.stack[R.EXN_STACKHEIGHT++] = $ss11321133;
}
if(R.isPyretException($e11281129)) {
$e11281129.pyretStack.push(L[106]);
}
throw $e11281129;
}
var $ret11341135 = $Hcont_tail_app14611140($z11301131);
++R.GAS;
return $ret11341135;
} else {
var $z11431144 = D;
var $f11491150 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l23021125):R.ffi.throwNonFunApp(L[106],is_DASH_empty18116.$var,[l23021125]);
};
try {
if(--R.GAS > 0) {
$z11431144 = $f11491150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11491150,
"from":L[106]});
}
} catch($e11411142) {
if(R.isCont($e11411142)) {
var $ss11451146 = {"from":L[106],
"go":function(or_DASH_oper_DASH_1051151) {
return $Hor_DASH_oper_DASH_14671152(or_DASH_oper_DASH_1051151,if_helper8641138,is_DASH_empty18116,l33031126,l43041127);
}};
$e11411142.stack[R.EXN_STACKHEIGHT++] = $ss11451146;
}
if(R.isPyretException($e11411142)) {
$e11411142.pyretStack.push(L[106]);
}
throw $e11411142;
}
var $ret11471148 = $Hor_DASH_oper_DASH_14671152($z11431144,if_helper8641138,is_DASH_empty18116,l33031126,l43041127);
++R.GAS;
return $ret11471148;
}
} else {
var cont_tail_arg8821155 = R.throwNonBooleanOp(L[107],("first"),("or"),or_DASH_oper_DASH_1041121);
if(--R.GAS > 0) {
$z11531154 = R.isFunction(if_helper8641138)?if_helper8641138.app(cont_tail_arg8821155):R.ffi.throwNonFunApp(L[107],if_helper8641138,[cont_tail_arg8821155]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8641138)?if_helper8641138.app(cont_tail_arg8821155):R.ffi.throwNonFunApp(L[107],if_helper8641138,[cont_tail_arg8821155]);
},
"from":L[107]});
}
++R.GAS;
return $z11531154;
}
};
var $Hcont_tail_app14611140 = function(cont_tail_app8971139) {
return cont_tail_app8971139;
};
var $Hor_DASH_oper_DASH_14671152 = function(or_DASH_oper_DASH_1051151,if_helper8641138,is_DASH_empty18116,l33031126,l43041127) {
var anf_if8871221 = R.isBoolean(or_DASH_oper_DASH_1051151);
if(R.isPyretTrue(anf_if8871221)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1051151)) {
var $z11961197 = D;
var $f12021203 = function(_) {
return R.isFunction(if_helper8641138)?if_helper8641138.app((true)):R.ffi.throwNonFunApp(L[106],if_helper8641138,[(true)]);
};
try {
if(--R.GAS > 0) {
$z11961197 = $f12021203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12021203,
"from":L[106]});
}
} catch($e11941195) {
if(R.isCont($e11941195)) {
var $ss11981199 = {"from":L[106],
"go":function(cont_tail_app8961204) {
return $Hcont_tail_app14621205(cont_tail_app8961204);
}};
$e11941195.stack[R.EXN_STACKHEIGHT++] = $ss11981199;
}
if(R.isPyretException($e11941195)) {
$e11941195.pyretStack.push(L[106]);
}
throw $e11941195;
}
var $ret12001201 = $Hcont_tail_app14621205($z11961197);
++R.GAS;
return $ret12001201;
} else {
var $z12081209 = D;
var $f12141215 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l33031126):R.ffi.throwNonFunApp(L[106],is_DASH_empty18116.$var,[l33031126]);
};
try {
if(--R.GAS > 0) {
$z12081209 = $f12141215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12141215,
"from":L[106]});
}
} catch($e12061207) {
if(R.isCont($e12061207)) {
var $ss12101211 = {"from":L[106],
"go":function(or_DASH_oper_DASH_1061216) {
return $Hor_DASH_oper_DASH_14661217(or_DASH_oper_DASH_1061216,if_helper8641138,is_DASH_empty18116,l43041127);
}};
$e12061207.stack[R.EXN_STACKHEIGHT++] = $ss12101211;
}
if(R.isPyretException($e12061207)) {
$e12061207.pyretStack.push(L[106]);
}
throw $e12061207;
}
var $ret12121213 = $Hor_DASH_oper_DASH_14661217($z12081209,if_helper8641138,is_DASH_empty18116,l43041127);
++R.GAS;
return $ret12121213;
}
} else {
var cont_tail_arg8851220 = R.throwNonBooleanOp(L[114],("first"),("or"),or_DASH_oper_DASH_1051151);
if(--R.GAS > 0) {
$z12181219 = R.isFunction(if_helper8641138)?if_helper8641138.app(cont_tail_arg8851220):R.ffi.throwNonFunApp(L[114],if_helper8641138,[cont_tail_arg8851220]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8641138)?if_helper8641138.app(cont_tail_arg8851220):R.ffi.throwNonFunApp(L[114],if_helper8641138,[cont_tail_arg8851220]);
},
"from":L[114]});
}
++R.GAS;
return $z12181219;
}
};
var $Hcont_tail_app14621205 = function(cont_tail_app8961204) {
return cont_tail_app8961204;
};
var $Hor_DASH_oper_DASH_14661217 = function(or_DASH_oper_DASH_1061216,if_helper8641138,is_DASH_empty18116,l43041127) {
var anf_if8901249 = R.isBoolean(or_DASH_oper_DASH_1061216);
if(R.isPyretTrue(anf_if8901249)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1061216)) {
var $z12241225 = D;
var $f12301231 = function(_) {
return R.isFunction(if_helper8641138)?if_helper8641138.app((true)):R.ffi.throwNonFunApp(L[106],if_helper8641138,[(true)]);
};
try {
if(--R.GAS > 0) {
$z12241225 = $f12301231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12301231,
"from":L[106]});
}
} catch($e12221223) {
if(R.isCont($e12221223)) {
var $ss12261227 = {"from":L[106],
"go":function(cont_tail_app8951232) {
return $Hcont_tail_app14631233(cont_tail_app8951232);
}};
$e12221223.stack[R.EXN_STACKHEIGHT++] = $ss12261227;
}
if(R.isPyretException($e12221223)) {
$e12221223.pyretStack.push(L[106]);
}
throw $e12221223;
}
var $ret12281229 = $Hcont_tail_app14631233($z12241225);
++R.GAS;
return $ret12281229;
} else {
var $z12361237 = D;
var $f12421243 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l43041127):R.ffi.throwNonFunApp(L[106],is_DASH_empty18116.$var,[l43041127]);
};
try {
if(--R.GAS > 0) {
$z12361237 = $f12421243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12421243,
"from":L[106]});
}
} catch($e12341235) {
if(R.isCont($e12341235)) {
var $ss12381239 = {"from":L[106],
"go":function(or_DASH_oper_DASH_1071244) {
return $Hor_DASH_oper_DASH_14651245(or_DASH_oper_DASH_1071244,if_helper8641138);
}};
$e12341235.stack[R.EXN_STACKHEIGHT++] = $ss12381239;
}
if(R.isPyretException($e12341235)) {
$e12341235.pyretStack.push(L[106]);
}
throw $e12341235;
}
var $ret12401241 = $Hor_DASH_oper_DASH_14651245($z12361237,if_helper8641138);
++R.GAS;
return $ret12401241;
}
} else {
var cont_tail_arg8881248 = R.throwNonBooleanOp(L[115],("first"),("or"),or_DASH_oper_DASH_1061216);
if(--R.GAS > 0) {
$z12461247 = R.isFunction(if_helper8641138)?if_helper8641138.app(cont_tail_arg8881248):R.ffi.throwNonFunApp(L[115],if_helper8641138,[cont_tail_arg8881248]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8641138)?if_helper8641138.app(cont_tail_arg8881248):R.ffi.throwNonFunApp(L[115],if_helper8641138,[cont_tail_arg8881248]);
},
"from":L[115]});
}
++R.GAS;
return $z12461247;
}
};
var $Hcont_tail_app14631233 = function(cont_tail_app8951232) {
return cont_tail_app8951232;
};
var $Hor_DASH_oper_DASH_14651245 = function(or_DASH_oper_DASH_1071244,if_helper8641138) {
var anf_if8931265 = R.isBoolean(or_DASH_oper_DASH_1071244);
if(R.isPyretTrue(anf_if8931265)) {
var $z12521253 = D;
var $f12581259 = function(_) {
return R.isFunction(if_helper8641138)?if_helper8641138.app(or_DASH_oper_DASH_1071244):R.ffi.throwNonFunApp(L[106],if_helper8641138,[or_DASH_oper_DASH_1071244]);
};
try {
if(--R.GAS > 0) {
$z12521253 = $f12581259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12581259,
"from":L[106]});
}
} catch($e12501251) {
if(R.isCont($e12501251)) {
var $ss12541255 = {"from":L[106],
"go":function(cont_tail_app8941260) {
return $Hcont_tail_app14641261(cont_tail_app8941260);
}};
$e12501251.stack[R.EXN_STACKHEIGHT++] = $ss12541255;
}
if(R.isPyretException($e12501251)) {
$e12501251.pyretStack.push(L[106]);
}
throw $e12501251;
}
var $ret12561257 = $Hcont_tail_app14641261($z12521253);
++R.GAS;
return $ret12561257;
} else {
var cont_tail_arg8911264 = R.throwNonBooleanOp(L[116],("second"),("or"),or_DASH_oper_DASH_1071244);
if(--R.GAS > 0) {
$z12621263 = R.isFunction(if_helper8641138)?if_helper8641138.app(cont_tail_arg8911264):R.ffi.throwNonFunApp(L[116],if_helper8641138,[cont_tail_arg8911264]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8641138)?if_helper8641138.app(cont_tail_arg8911264):R.ffi.throwNonFunApp(L[116],if_helper8641138,[cont_tail_arg8911264]);
},
"from":L[116]});
}
++R.GAS;
return $z12621263;
}
};
var $Hcont_tail_app14641261 = function(cont_tail_app8941260) {
return cont_tail_app8941260;
};
var $Hcont_tail_app14571170 = function(cont_tail_app8811169) {
return cont_tail_app8811169;
};
var $Hanf_begin_app_dropped14601186 = function(anf_begin_app_dropped14581185,help3001123,if_helper8661168,l13011124,l23021125,l33031126,l43041127) {
var anf_arg8751276 = G(l13011124,"rest",L[121]);
var anf_arg8761277 = G(l23021125,"rest",L[120]);
var anf_arg8771278 = G(l33031126,"rest",L[119]);
var anf_arg8781279 = G(l43041127,"rest",L[118]);
var $z12681269 = D;
var $f12741275 = function(_) {
return R.isFunction(help3001123.$var)?help3001123.$var.app(anf_arg8751276,anf_arg8761277,anf_arg8771278,anf_arg8781279):R.ffi.throwNonFunApp(L[117],help3001123.$var,[anf_arg8751276,anf_arg8761277,anf_arg8771278,anf_arg8781279]);
};
try {
if(--R.GAS > 0) {
$z12681269 = $f12741275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12741275,
"from":L[117]});
}
} catch($e12661267) {
if(R.isCont($e12661267)) {
var $ss12701271 = {"from":L[117],
"go":function(cont_tail_arg8791280) {
return $Hcont_tail_arg14591281(cont_tail_arg8791280,if_helper8661168);
}};
$e12661267.stack[R.EXN_STACKHEIGHT++] = $ss12701271;
}
if(R.isPyretException($e12661267)) {
$e12661267.pyretStack.push(L[117]);
}
throw $e12661267;
}
var $ret12721273 = $Hcont_tail_arg14591281($z12681269,if_helper8661168);
++R.GAS;
return $ret12721273;
};
var $Hcont_tail_arg14591281 = function(cont_tail_arg8791280,if_helper8661168) {
if(--R.GAS > 0) {
$z12821283 = R.isFunction(if_helper8661168)?if_helper8661168.app(cont_tail_arg8791280):R.ffi.throwNonFunApp(L[117],if_helper8661168,[cont_tail_arg8791280]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8661168)?if_helper8661168.app(cont_tail_arg8791280):R.ffi.throwNonFunApp(L[117],if_helper8661168,[cont_tail_arg8791280]);
},
"from":L[117]});
}
++R.GAS;
return $z12821283;
};
var $Hann_DASH_check_DASH_temp14561284 = function(ann_DASH_check_DASH_temp8301285) {
return ann_DASH_check_DASH_temp8301285;
};
var $Hor_DASH_oper_DASH_14551286 = function(or_DASH_oper_DASH_1001287,f2871288,help2911289,is_DASH_empty18116,l12921290,l22931291,l32941292,nothing8) {
var if_helper8321303 = R.makeFunction(function(if_helper_arg8331322) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[122],1,arguments);
}
var if_DASH_991351 = if_helper_arg8331322;
var if_helper8341333 = R.makeFunction(function(if_helper_arg8351356) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[122],1,arguments);
}
var ann_DASH_check_DASH_temp8311357 = if_helper_arg8351356;
return ann_DASH_check_DASH_temp8311357;
});
var anf_if8381355 = R.isBoolean(if_DASH_991351);
if(R.isPyretTrue(anf_if8381355)) {
if(R.isPyretTrue(if_DASH_991351)) {
var $z13251326 = D;
var $f13311332 = function(_) {
return R.isFunction(if_helper8341333)?if_helper8341333.app(nothing8):R.ffi.throwNonFunApp(L[124],if_helper8341333,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z13251326 = $f13311332();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13311332,
"from":L[124]});
}
} catch($e13231324) {
if(R.isCont($e13231324)) {
var $ss13271328 = {"from":L[124],
"go":function(cont_tail_app8471334) {
return $Hcont_tail_app14461335(cont_tail_app8471334);
}};
$e13231324.stack[R.EXN_STACKHEIGHT++] = $ss13271328;
}
if(R.isPyretException($e13231324)) {
$e13231324.pyretStack.push(L[124]);
}
throw $e13231324;
}
var $ret13291330 = $Hcont_tail_app14461335($z13251326);
++R.GAS;
return $ret13291330;
} else {
var anf_arg8391346 = G(l12921290,"first",L[128]);
var anf_arg8401347 = G(l22931291,"first",L[127]);
var anf_arg8411348 = G(l32941292,"first",L[126]);
var $z13381339 = D;
var $f13441345 = function(_) {
return R.isFunction(f2871288)?f2871288.app(anf_arg8391346,anf_arg8401347,anf_arg8411348):R.ffi.throwNonFunApp(L[125],f2871288,[anf_arg8391346,anf_arg8401347,anf_arg8411348]);
};
try {
if(--R.GAS > 0) {
$z13381339 = $f13441345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13441345,
"from":L[125]});
}
} catch($e13361337) {
if(R.isCont($e13361337)) {
var $ss13401341 = {"from":L[125],
"go":function(anf_begin_app_dropped14471349) {
return $Hanf_begin_app_dropped14491350(anf_begin_app_dropped14471349,help2911289,if_helper8341333,l12921290,l22931291,l32941292);
}};
$e13361337.stack[R.EXN_STACKHEIGHT++] = $ss13401341;
}
if(R.isPyretException($e13361337)) {
$e13361337.pyretStack.push(L[125]);
}
throw $e13361337;
}
var $ret13421343 = $Hanf_begin_app_dropped14491350($z13381339,help2911289,if_helper8341333,l12921290,l22931291,l32941292);
++R.GAS;
return $ret13421343;
}
} else {
var cont_tail_arg8361354 = R.throwNonBooleanCondition(L[122],("if"),if_DASH_991351);
if(--R.GAS > 0) {
$z13521353 = R.isFunction(if_helper8341333)?if_helper8341333.app(cont_tail_arg8361354):R.ffi.throwNonFunApp(L[122],if_helper8341333,[cont_tail_arg8361354]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8341333)?if_helper8341333.app(cont_tail_arg8361354):R.ffi.throwNonFunApp(L[122],if_helper8341333,[cont_tail_arg8361354]);
},
"from":L[122]});
}
++R.GAS;
return $z13521353;
}
});
var anf_if8501321 = R.isBoolean(or_DASH_oper_DASH_1001287);
if(R.isPyretTrue(anf_if8501321)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1001287)) {
var $z12951296 = D;
var $f13011302 = function(_) {
return R.isFunction(if_helper8321303)?if_helper8321303.app((true)):R.ffi.throwNonFunApp(L[122],if_helper8321303,[(true)]);
};
try {
if(--R.GAS > 0) {
$z12951296 = $f13011302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13011302,
"from":L[122]});
}
} catch($e12931294) {
if(R.isCont($e12931294)) {
var $ss12971298 = {"from":L[122],
"go":function(cont_tail_app8591304) {
return $Hcont_tail_app14501305(cont_tail_app8591304);
}};
$e12931294.stack[R.EXN_STACKHEIGHT++] = $ss12971298;
}
if(R.isPyretException($e12931294)) {
$e12931294.pyretStack.push(L[122]);
}
throw $e12931294;
}
var $ret12991300 = $Hcont_tail_app14501305($z12951296);
++R.GAS;
return $ret12991300;
} else {
var $z13081309 = D;
var $f13141315 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22931291):R.ffi.throwNonFunApp(L[122],is_DASH_empty18116.$var,[l22931291]);
};
try {
if(--R.GAS > 0) {
$z13081309 = $f13141315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13141315,
"from":L[122]});
}
} catch($e13061307) {
if(R.isCont($e13061307)) {
var $ss13101311 = {"from":L[122],
"go":function(or_DASH_oper_DASH_1011316) {
return $Hor_DASH_oper_DASH_14541317(or_DASH_oper_DASH_1011316,if_helper8321303,is_DASH_empty18116,l32941292);
}};
$e13061307.stack[R.EXN_STACKHEIGHT++] = $ss13101311;
}
if(R.isPyretException($e13061307)) {
$e13061307.pyretStack.push(L[122]);
}
throw $e13061307;
}
var $ret13121313 = $Hor_DASH_oper_DASH_14541317($z13081309,if_helper8321303,is_DASH_empty18116,l32941292);
++R.GAS;
return $ret13121313;
}
} else {
var cont_tail_arg8481320 = R.throwNonBooleanOp(L[123],("first"),("or"),or_DASH_oper_DASH_1001287);
if(--R.GAS > 0) {
$z13181319 = R.isFunction(if_helper8321303)?if_helper8321303.app(cont_tail_arg8481320):R.ffi.throwNonFunApp(L[123],if_helper8321303,[cont_tail_arg8481320]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8321303)?if_helper8321303.app(cont_tail_arg8481320):R.ffi.throwNonFunApp(L[123],if_helper8321303,[cont_tail_arg8481320]);
},
"from":L[123]});
}
++R.GAS;
return $z13181319;
}
};
var $Hcont_tail_app14501305 = function(cont_tail_app8591304) {
return cont_tail_app8591304;
};
var $Hor_DASH_oper_DASH_14541317 = function(or_DASH_oper_DASH_1011316,if_helper8321303,is_DASH_empty18116,l32941292) {
var anf_if8531385 = R.isBoolean(or_DASH_oper_DASH_1011316);
if(R.isPyretTrue(anf_if8531385)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1011316)) {
var $z13601361 = D;
var $f13661367 = function(_) {
return R.isFunction(if_helper8321303)?if_helper8321303.app((true)):R.ffi.throwNonFunApp(L[122],if_helper8321303,[(true)]);
};
try {
if(--R.GAS > 0) {
$z13601361 = $f13661367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13661367,
"from":L[122]});
}
} catch($e13581359) {
if(R.isCont($e13581359)) {
var $ss13621363 = {"from":L[122],
"go":function(cont_tail_app8581368) {
return $Hcont_tail_app14511369(cont_tail_app8581368);
}};
$e13581359.stack[R.EXN_STACKHEIGHT++] = $ss13621363;
}
if(R.isPyretException($e13581359)) {
$e13581359.pyretStack.push(L[122]);
}
throw $e13581359;
}
var $ret13641365 = $Hcont_tail_app14511369($z13601361);
++R.GAS;
return $ret13641365;
} else {
var $z13721373 = D;
var $f13781379 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l32941292):R.ffi.throwNonFunApp(L[122],is_DASH_empty18116.$var,[l32941292]);
};
try {
if(--R.GAS > 0) {
$z13721373 = $f13781379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13781379,
"from":L[122]});
}
} catch($e13701371) {
if(R.isCont($e13701371)) {
var $ss13741375 = {"from":L[122],
"go":function(or_DASH_oper_DASH_1021380) {
return $Hor_DASH_oper_DASH_14531381(or_DASH_oper_DASH_1021380,if_helper8321303);
}};
$e13701371.stack[R.EXN_STACKHEIGHT++] = $ss13741375;
}
if(R.isPyretException($e13701371)) {
$e13701371.pyretStack.push(L[122]);
}
throw $e13701371;
}
var $ret13761377 = $Hor_DASH_oper_DASH_14531381($z13721373,if_helper8321303);
++R.GAS;
return $ret13761377;
}
} else {
var cont_tail_arg8511384 = R.throwNonBooleanOp(L[129],("first"),("or"),or_DASH_oper_DASH_1011316);
if(--R.GAS > 0) {
$z13821383 = R.isFunction(if_helper8321303)?if_helper8321303.app(cont_tail_arg8511384):R.ffi.throwNonFunApp(L[129],if_helper8321303,[cont_tail_arg8511384]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8321303)?if_helper8321303.app(cont_tail_arg8511384):R.ffi.throwNonFunApp(L[129],if_helper8321303,[cont_tail_arg8511384]);
},
"from":L[129]});
}
++R.GAS;
return $z13821383;
}
};
var $Hcont_tail_app14511369 = function(cont_tail_app8581368) {
return cont_tail_app8581368;
};
var $Hor_DASH_oper_DASH_14531381 = function(or_DASH_oper_DASH_1021380,if_helper8321303) {
var anf_if8561401 = R.isBoolean(or_DASH_oper_DASH_1021380);
if(R.isPyretTrue(anf_if8561401)) {
var $z13881389 = D;
var $f13941395 = function(_) {
return R.isFunction(if_helper8321303)?if_helper8321303.app(or_DASH_oper_DASH_1021380):R.ffi.throwNonFunApp(L[122],if_helper8321303,[or_DASH_oper_DASH_1021380]);
};
try {
if(--R.GAS > 0) {
$z13881389 = $f13941395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13941395,
"from":L[122]});
}
} catch($e13861387) {
if(R.isCont($e13861387)) {
var $ss13901391 = {"from":L[122],
"go":function(cont_tail_app8571396) {
return $Hcont_tail_app14521397(cont_tail_app8571396);
}};
$e13861387.stack[R.EXN_STACKHEIGHT++] = $ss13901391;
}
if(R.isPyretException($e13861387)) {
$e13861387.pyretStack.push(L[122]);
}
throw $e13861387;
}
var $ret13921393 = $Hcont_tail_app14521397($z13881389);
++R.GAS;
return $ret13921393;
} else {
var cont_tail_arg8541400 = R.throwNonBooleanOp(L[130],("second"),("or"),or_DASH_oper_DASH_1021380);
if(--R.GAS > 0) {
$z13981399 = R.isFunction(if_helper8321303)?if_helper8321303.app(cont_tail_arg8541400):R.ffi.throwNonFunApp(L[130],if_helper8321303,[cont_tail_arg8541400]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8321303)?if_helper8321303.app(cont_tail_arg8541400):R.ffi.throwNonFunApp(L[130],if_helper8321303,[cont_tail_arg8541400]);
},
"from":L[130]});
}
++R.GAS;
return $z13981399;
}
};
var $Hcont_tail_app14521397 = function(cont_tail_app8571396) {
return cont_tail_app8571396;
};
var $Hcont_tail_app14461335 = function(cont_tail_app8471334) {
return cont_tail_app8471334;
};
var $Hanf_begin_app_dropped14491350 = function(anf_begin_app_dropped14471349,help2911289,if_helper8341333,l12921290,l22931291,l32941292) {
var anf_arg8421412 = G(l12921290,"rest",L[134]);
var anf_arg8431413 = G(l22931291,"rest",L[133]);
var anf_arg8441414 = G(l32941292,"rest",L[132]);
var $z14041405 = D;
var $f14101411 = function(_) {
return R.isFunction(help2911289.$var)?help2911289.$var.app(anf_arg8421412,anf_arg8431413,anf_arg8441414):R.ffi.throwNonFunApp(L[131],help2911289.$var,[anf_arg8421412,anf_arg8431413,anf_arg8441414]);
};
try {
if(--R.GAS > 0) {
$z14041405 = $f14101411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14101411,
"from":L[131]});
}
} catch($e14021403) {
if(R.isCont($e14021403)) {
var $ss14061407 = {"from":L[131],
"go":function(cont_tail_arg8451415) {
return $Hcont_tail_arg14481416(cont_tail_arg8451415,if_helper8341333);
}};
$e14021403.stack[R.EXN_STACKHEIGHT++] = $ss14061407;
}
if(R.isPyretException($e14021403)) {
$e14021403.pyretStack.push(L[131]);
}
throw $e14021403;
}
var $ret14081409 = $Hcont_tail_arg14481416($z14041405,if_helper8341333);
++R.GAS;
return $ret14081409;
};
var $Hcont_tail_arg14481416 = function(cont_tail_arg8451415,if_helper8341333) {
if(--R.GAS > 0) {
$z14171418 = R.isFunction(if_helper8341333)?if_helper8341333.app(cont_tail_arg8451415):R.ffi.throwNonFunApp(L[131],if_helper8341333,[cont_tail_arg8451415]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8341333)?if_helper8341333.app(cont_tail_arg8451415):R.ffi.throwNonFunApp(L[131],if_helper8341333,[cont_tail_arg8451415]);
},
"from":L[131]});
}
++R.GAS;
return $z14171418;
};
var $Hann_DASH_check_DASH_temp14451419 = function(ann_DASH_check_DASH_temp8041420) {
return ann_DASH_check_DASH_temp8041420;
};
var $Hor_DASH_oper_DASH_14441421 = function(or_DASH_oper_DASH_971422,f2811423,help2841424,is_DASH_empty18116,l12851425,l22861426,nothing8) {
var if_helper8061437 = R.makeFunction(function(if_helper_arg8071456) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[135],1,arguments);
}
var if_DASH_961484 = if_helper_arg8071456;
var if_helper8081467 = R.makeFunction(function(if_helper_arg8091489) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[135],1,arguments);
}
var ann_DASH_check_DASH_temp8051490 = if_helper_arg8091489;
return ann_DASH_check_DASH_temp8051490;
});
var anf_if8121488 = R.isBoolean(if_DASH_961484);
if(R.isPyretTrue(anf_if8121488)) {
if(R.isPyretTrue(if_DASH_961484)) {
var $z14591460 = D;
var $f14651466 = function(_) {
return R.isFunction(if_helper8081467)?if_helper8081467.app(nothing8):R.ffi.throwNonFunApp(L[137],if_helper8081467,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z14591460 = $f14651466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14651466,
"from":L[137]});
}
} catch($e14571458) {
if(R.isCont($e14571458)) {
var $ss14611462 = {"from":L[137],
"go":function(cont_tail_app8191468) {
return $Hcont_tail_app14371469(cont_tail_app8191468);
}};
$e14571458.stack[R.EXN_STACKHEIGHT++] = $ss14611462;
}
if(R.isPyretException($e14571458)) {
$e14571458.pyretStack.push(L[137]);
}
throw $e14571458;
}
var $ret14631464 = $Hcont_tail_app14371469($z14591460);
++R.GAS;
return $ret14631464;
} else {
var anf_arg8131480 = G(l12851425,"first",L[140]);
var anf_arg8141481 = G(l22861426,"first",L[139]);
var $z14721473 = D;
var $f14781479 = function(_) {
return R.isFunction(f2811423)?f2811423.app(anf_arg8131480,anf_arg8141481):R.ffi.throwNonFunApp(L[138],f2811423,[anf_arg8131480,anf_arg8141481]);
};
try {
if(--R.GAS > 0) {
$z14721473 = $f14781479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14781479,
"from":L[138]});
}
} catch($e14701471) {
if(R.isCont($e14701471)) {
var $ss14741475 = {"from":L[138],
"go":function(anf_begin_app_dropped14381482) {
return $Hanf_begin_app_dropped14401483(anf_begin_app_dropped14381482,help2841424,if_helper8081467,l12851425,l22861426);
}};
$e14701471.stack[R.EXN_STACKHEIGHT++] = $ss14741475;
}
if(R.isPyretException($e14701471)) {
$e14701471.pyretStack.push(L[138]);
}
throw $e14701471;
}
var $ret14761477 = $Hanf_begin_app_dropped14401483($z14721473,help2841424,if_helper8081467,l12851425,l22861426);
++R.GAS;
return $ret14761477;
}
} else {
var cont_tail_arg8101487 = R.throwNonBooleanCondition(L[135],("if"),if_DASH_961484);
if(--R.GAS > 0) {
$z14851486 = R.isFunction(if_helper8081467)?if_helper8081467.app(cont_tail_arg8101487):R.ffi.throwNonFunApp(L[135],if_helper8081467,[cont_tail_arg8101487]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8081467)?if_helper8081467.app(cont_tail_arg8101487):R.ffi.throwNonFunApp(L[135],if_helper8081467,[cont_tail_arg8101487]);
},
"from":L[135]});
}
++R.GAS;
return $z14851486;
}
});
var anf_if8221455 = R.isBoolean(or_DASH_oper_DASH_971422);
if(R.isPyretTrue(anf_if8221455)) {
if(R.isPyretTrue(or_DASH_oper_DASH_971422)) {
var $z14291430 = D;
var $f14351436 = function(_) {
return R.isFunction(if_helper8061437)?if_helper8061437.app((true)):R.ffi.throwNonFunApp(L[135],if_helper8061437,[(true)]);
};
try {
if(--R.GAS > 0) {
$z14291430 = $f14351436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14351436,
"from":L[135]});
}
} catch($e14271428) {
if(R.isCont($e14271428)) {
var $ss14311432 = {"from":L[135],
"go":function(cont_tail_app8271438) {
return $Hcont_tail_app14411439(cont_tail_app8271438);
}};
$e14271428.stack[R.EXN_STACKHEIGHT++] = $ss14311432;
}
if(R.isPyretException($e14271428)) {
$e14271428.pyretStack.push(L[135]);
}
throw $e14271428;
}
var $ret14331434 = $Hcont_tail_app14411439($z14291430);
++R.GAS;
return $ret14331434;
} else {
var $z14421443 = D;
var $f14481449 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22861426):R.ffi.throwNonFunApp(L[135],is_DASH_empty18116.$var,[l22861426]);
};
try {
if(--R.GAS > 0) {
$z14421443 = $f14481449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14481449,
"from":L[135]});
}
} catch($e14401441) {
if(R.isCont($e14401441)) {
var $ss14441445 = {"from":L[135],
"go":function(or_DASH_oper_DASH_981450) {
return $Hor_DASH_oper_DASH_14431451(or_DASH_oper_DASH_981450,if_helper8061437);
}};
$e14401441.stack[R.EXN_STACKHEIGHT++] = $ss14441445;
}
if(R.isPyretException($e14401441)) {
$e14401441.pyretStack.push(L[135]);
}
throw $e14401441;
}
var $ret14461447 = $Hor_DASH_oper_DASH_14431451($z14421443,if_helper8061437);
++R.GAS;
return $ret14461447;
}
} else {
var cont_tail_arg8201454 = R.throwNonBooleanOp(L[136],("first"),("or"),or_DASH_oper_DASH_971422);
if(--R.GAS > 0) {
$z14521453 = R.isFunction(if_helper8061437)?if_helper8061437.app(cont_tail_arg8201454):R.ffi.throwNonFunApp(L[136],if_helper8061437,[cont_tail_arg8201454]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8061437)?if_helper8061437.app(cont_tail_arg8201454):R.ffi.throwNonFunApp(L[136],if_helper8061437,[cont_tail_arg8201454]);
},
"from":L[136]});
}
++R.GAS;
return $z14521453;
}
};
var $Hcont_tail_app14411439 = function(cont_tail_app8271438) {
return cont_tail_app8271438;
};
var $Hor_DASH_oper_DASH_14431451 = function(or_DASH_oper_DASH_981450,if_helper8061437) {
var anf_if8251506 = R.isBoolean(or_DASH_oper_DASH_981450);
if(R.isPyretTrue(anf_if8251506)) {
var $z14931494 = D;
var $f14991500 = function(_) {
return R.isFunction(if_helper8061437)?if_helper8061437.app(or_DASH_oper_DASH_981450):R.ffi.throwNonFunApp(L[135],if_helper8061437,[or_DASH_oper_DASH_981450]);
};
try {
if(--R.GAS > 0) {
$z14931494 = $f14991500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14991500,
"from":L[135]});
}
} catch($e14911492) {
if(R.isCont($e14911492)) {
var $ss14951496 = {"from":L[135],
"go":function(cont_tail_app8261501) {
return $Hcont_tail_app14421502(cont_tail_app8261501);
}};
$e14911492.stack[R.EXN_STACKHEIGHT++] = $ss14951496;
}
if(R.isPyretException($e14911492)) {
$e14911492.pyretStack.push(L[135]);
}
throw $e14911492;
}
var $ret14971498 = $Hcont_tail_app14421502($z14931494);
++R.GAS;
return $ret14971498;
} else {
var cont_tail_arg8231505 = R.throwNonBooleanOp(L[141],("second"),("or"),or_DASH_oper_DASH_981450);
if(--R.GAS > 0) {
$z15031504 = R.isFunction(if_helper8061437)?if_helper8061437.app(cont_tail_arg8231505):R.ffi.throwNonFunApp(L[141],if_helper8061437,[cont_tail_arg8231505]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8061437)?if_helper8061437.app(cont_tail_arg8231505):R.ffi.throwNonFunApp(L[141],if_helper8061437,[cont_tail_arg8231505]);
},
"from":L[141]});
}
++R.GAS;
return $z15031504;
}
};
var $Hcont_tail_app14421502 = function(cont_tail_app8261501) {
return cont_tail_app8261501;
};
var $Hcont_tail_app14371469 = function(cont_tail_app8191468) {
return cont_tail_app8191468;
};
var $Hanf_begin_app_dropped14401483 = function(anf_begin_app_dropped14381482,help2841424,if_helper8081467,l12851425,l22861426) {
var anf_arg8151517 = G(l12851425,"rest",L[144]);
var anf_arg8161518 = G(l22861426,"rest",L[143]);
var $z15091510 = D;
var $f15151516 = function(_) {
return R.isFunction(help2841424.$var)?help2841424.$var.app(anf_arg8151517,anf_arg8161518):R.ffi.throwNonFunApp(L[142],help2841424.$var,[anf_arg8151517,anf_arg8161518]);
};
try {
if(--R.GAS > 0) {
$z15091510 = $f15151516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15151516,
"from":L[142]});
}
} catch($e15071508) {
if(R.isCont($e15071508)) {
var $ss15111512 = {"from":L[142],
"go":function(cont_tail_arg8171519) {
return $Hcont_tail_arg14391520(cont_tail_arg8171519,if_helper8081467);
}};
$e15071508.stack[R.EXN_STACKHEIGHT++] = $ss15111512;
}
if(R.isPyretException($e15071508)) {
$e15071508.pyretStack.push(L[142]);
}
throw $e15071508;
}
var $ret15131514 = $Hcont_tail_arg14391520($z15091510,if_helper8081467);
++R.GAS;
return $ret15131514;
};
var $Hcont_tail_arg14391520 = function(cont_tail_arg8171519,if_helper8081467) {
if(--R.GAS > 0) {
$z15211522 = R.isFunction(if_helper8081467)?if_helper8081467.app(cont_tail_arg8171519):R.ffi.throwNonFunApp(L[142],if_helper8081467,[cont_tail_arg8171519]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper8081467)?if_helper8081467.app(cont_tail_arg8171519):R.ffi.throwNonFunApp(L[142],if_helper8081467,[cont_tail_arg8171519]);
},
"from":L[142]});
}
++R.GAS;
return $z15211522;
};
var $Hann_DASH_check_DASH_temp14361523 = function(ann_DASH_check_DASH_temp7901524) {
return ann_DASH_check_DASH_temp7901524;
};
var $Hif_DASH_14351525 = function(if_DASH_951526,f2721527,help2741528,l2751529,nothing8) {
var if_helper7921540 = R.makeFunction(function(if_helper_arg7931560) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[148],1,arguments);
}
var ann_DASH_check_DASH_temp7911561 = if_helper_arg7931560;
return ann_DASH_check_DASH_temp7911561;
});
var anf_if7961559 = R.isBoolean(if_DASH_951526);
if(R.isPyretTrue(anf_if7961559)) {
if(R.isPyretTrue(if_DASH_951526)) {
var $z15321533 = D;
var $f15381539 = function(_) {
return R.isFunction(if_helper7921540)?if_helper7921540.app(nothing8):R.ffi.throwNonFunApp(L[145],if_helper7921540,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z15321533 = $f15381539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15381539,
"from":L[145]});
}
} catch($e15301531) {
if(R.isCont($e15301531)) {
var $ss15341535 = {"from":L[145],
"go":function(cont_tail_app8011541) {
return $Hcont_tail_app14311542(cont_tail_app8011541);
}};
$e15301531.stack[R.EXN_STACKHEIGHT++] = $ss15341535;
}
if(R.isPyretException($e15301531)) {
$e15301531.pyretStack.push(L[145]);
}
throw $e15301531;
}
var $ret15361537 = $Hcont_tail_app14311542($z15321533);
++R.GAS;
return $ret15361537;
} else {
var anf_arg7971553 = G(l2751529,"first",L[147]);
var $z15451546 = D;
var $f15511552 = function(_) {
return R.isFunction(f2721527)?f2721527.app(anf_arg7971553):R.ffi.throwNonFunApp(L[146],f2721527,[anf_arg7971553]);
};
try {
if(--R.GAS > 0) {
$z15451546 = $f15511552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15511552,
"from":L[146]});
}
} catch($e15431544) {
if(R.isCont($e15431544)) {
var $ss15471548 = {"from":L[146],
"go":function(anf_begin_app_dropped14321554) {
return $Hanf_begin_app_dropped14341555(anf_begin_app_dropped14321554,help2741528,if_helper7921540,l2751529);
}};
$e15431544.stack[R.EXN_STACKHEIGHT++] = $ss15471548;
}
if(R.isPyretException($e15431544)) {
$e15431544.pyretStack.push(L[146]);
}
throw $e15431544;
}
var $ret15491550 = $Hanf_begin_app_dropped14341555($z15451546,help2741528,if_helper7921540,l2751529);
++R.GAS;
return $ret15491550;
}
} else {
var cont_tail_arg7941558 = R.throwNonBooleanCondition(L[148],("if"),if_DASH_951526);
if(--R.GAS > 0) {
$z15561557 = R.isFunction(if_helper7921540)?if_helper7921540.app(cont_tail_arg7941558):R.ffi.throwNonFunApp(L[148],if_helper7921540,[cont_tail_arg7941558]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7921540)?if_helper7921540.app(cont_tail_arg7941558):R.ffi.throwNonFunApp(L[148],if_helper7921540,[cont_tail_arg7941558]);
},
"from":L[148]});
}
++R.GAS;
return $z15561557;
}
};
var $Hcont_tail_app14311542 = function(cont_tail_app8011541) {
return cont_tail_app8011541;
};
var $Hanf_begin_app_dropped14341555 = function(anf_begin_app_dropped14321554,help2741528,if_helper7921540,l2751529) {
var anf_arg7981572 = G(l2751529,"rest",L[150]);
var $z15641565 = D;
var $f15701571 = function(_) {
return R.isFunction(help2741528.$var)?help2741528.$var.app(anf_arg7981572):R.ffi.throwNonFunApp(L[149],help2741528.$var,[anf_arg7981572]);
};
try {
if(--R.GAS > 0) {
$z15641565 = $f15701571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15701571,
"from":L[149]});
}
} catch($e15621563) {
if(R.isCont($e15621563)) {
var $ss15661567 = {"from":L[149],
"go":function(cont_tail_arg7991573) {
return $Hcont_tail_arg14331574(cont_tail_arg7991573,if_helper7921540);
}};
$e15621563.stack[R.EXN_STACKHEIGHT++] = $ss15661567;
}
if(R.isPyretException($e15621563)) {
$e15621563.pyretStack.push(L[149]);
}
throw $e15621563;
}
var $ret15681569 = $Hcont_tail_arg14331574($z15641565,if_helper7921540);
++R.GAS;
return $ret15681569;
};
var $Hcont_tail_arg14331574 = function(cont_tail_arg7991573,if_helper7921540) {
if(--R.GAS > 0) {
$z15751576 = R.isFunction(if_helper7921540)?if_helper7921540.app(cont_tail_arg7991573):R.ffi.throwNonFunApp(L[149],if_helper7921540,[cont_tail_arg7991573]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7921540)?if_helper7921540.app(cont_tail_arg7991573):R.ffi.throwNonFunApp(L[149],if_helper7921540,[cont_tail_arg7991573]);
},
"from":L[149]});
}
++R.GAS;
return $z15751576;
};
var $Hor_DASH_oper_DASH_14301577 = function(or_DASH_oper_DASH_911578,empty191579,f2661580,is_DASH_empty18116,l12681581,l22691582,l32701583,l42711584,link211585,map4371586,n2671587,_plus6) {
var if_helper7501598 = R.makeFunction(function(if_helper_arg7511617) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[151],1,arguments);
}
var if_DASH_901661 = if_helper_arg7511617;
var if_helper7521628 = R.makeFunction(function(if_helper_arg7531666) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[151],1,arguments);
}
var ann_DASH_check_DASH_temp7491667 = if_helper_arg7531666;
return ann_DASH_check_DASH_temp7491667;
});
var anf_if7561665 = R.isBoolean(if_DASH_901661);
if(R.isPyretTrue(anf_if7561665)) {
if(R.isPyretTrue(if_DASH_901661)) {
var $z16201621 = D;
var $f16261627 = function(_) {
return R.isFunction(if_helper7521628)?if_helper7521628.app(empty191579.$var):R.ffi.throwNonFunApp(L[153],if_helper7521628,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z16201621 = $f16261627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16261627,
"from":L[153]});
}
} catch($e16181619) {
if(R.isCont($e16181619)) {
var $ss16221623 = {"from":L[153],
"go":function(cont_tail_app7721629) {
return $Hcont_tail_app14171630(cont_tail_app7721629);
}};
$e16181619.stack[R.EXN_STACKHEIGHT++] = $ss16221623;
}
if(R.isPyretException($e16181619)) {
$e16181619.pyretStack.push(L[153]);
}
throw $e16181619;
}
var $ret16241625 = $Hcont_tail_app14171630($z16201621);
++R.GAS;
return $ret16241625;
} else {
var anf_fun7641646 = R.makeFunction(function(arg_DASH_891648) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[159],1,arguments);
}
var $z16511652 = D;
var $f16571658 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n2671587,(1)):R.ffi.throwNonFunApp(L[160],_plus6,[n2671587,(1)]);
};
try {
if(--R.GAS > 0) {
$z16511652 = $f16571658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16571658,
"from":L[160]});
}
} catch($e16491650) {
if(R.isCont($e16491650)) {
var $ss16531654 = {"from":L[160],
"go":function(anf_arg7581659) {
return $Hanf_arg14201660(anf_arg7581659,arg_DASH_891648,f2661580,l12681581,l22691582,l32701583,l42711584,link211585,map4371586);
}};
$e16491650.stack[R.EXN_STACKHEIGHT++] = $ss16531654;
}
if(R.isPyretException($e16491650)) {
$e16491650.pyretStack.push(L[160]);
}
throw $e16491650;
}
var $ret16551656 = $Hanf_arg14201660($z16511652,arg_DASH_891648,f2661580,l12681581,l22691582,l32701583,l42711584,link211585,map4371586);
++R.GAS;
return $ret16551656;
});
var anf_arg7651641 = G(l12681581,"first",L[158]);
var anf_arg7661642 = G(l22691582,"first",L[157]);
var anf_arg7671643 = G(l32701583,"first",L[156]);
var anf_arg7681644 = G(l42711584,"first",L[155]);
var $z16331634 = D;
var $f16391640 = function(_) {
return R.isFunction(f2661580)?f2661580.app(n2671587,anf_arg7651641,anf_arg7661642,anf_arg7671643,anf_arg7681644):R.ffi.throwNonFunApp(L[154],f2661580,[n2671587,anf_arg7651641,anf_arg7661642,anf_arg7671643,anf_arg7681644]);
};
try {
if(--R.GAS > 0) {
$z16331634 = $f16391640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16391640,
"from":L[154]});
}
} catch($e16311632) {
if(R.isCont($e16311632)) {
var $ss16351636 = {"from":L[154],
"go":function(anf_arg7691645) {
return $Hanf_arg14221647(anf_arg7691645,anf_fun7641646,if_helper7521628);
}};
$e16311632.stack[R.EXN_STACKHEIGHT++] = $ss16351636;
}
if(R.isPyretException($e16311632)) {
$e16311632.pyretStack.push(L[154]);
}
throw $e16311632;
}
var $ret16371638 = $Hanf_arg14221647($z16331634,anf_fun7641646,if_helper7521628);
++R.GAS;
return $ret16371638;
}
} else {
var cont_tail_arg7541664 = R.throwNonBooleanCondition(L[151],("if"),if_DASH_901661);
if(--R.GAS > 0) {
$z16621663 = R.isFunction(if_helper7521628)?if_helper7521628.app(cont_tail_arg7541664):R.ffi.throwNonFunApp(L[151],if_helper7521628,[cont_tail_arg7541664]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7521628)?if_helper7521628.app(cont_tail_arg7541664):R.ffi.throwNonFunApp(L[151],if_helper7521628,[cont_tail_arg7541664]);
},
"from":L[151]});
}
++R.GAS;
return $z16621663;
}
});
var anf_if7751616 = R.isBoolean(or_DASH_oper_DASH_911578);
if(R.isPyretTrue(anf_if7751616)) {
if(R.isPyretTrue(or_DASH_oper_DASH_911578)) {
var $z15901591 = D;
var $f15961597 = function(_) {
return R.isFunction(if_helper7501598)?if_helper7501598.app((true)):R.ffi.throwNonFunApp(L[151],if_helper7501598,[(true)]);
};
try {
if(--R.GAS > 0) {
$z15901591 = $f15961597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15961597,
"from":L[151]});
}
} catch($e15881589) {
if(R.isCont($e15881589)) {
var $ss15921593 = {"from":L[151],
"go":function(cont_tail_app7881599) {
return $Hcont_tail_app14231600(cont_tail_app7881599);
}};
$e15881589.stack[R.EXN_STACKHEIGHT++] = $ss15921593;
}
if(R.isPyretException($e15881589)) {
$e15881589.pyretStack.push(L[151]);
}
throw $e15881589;
}
var $ret15941595 = $Hcont_tail_app14231600($z15901591);
++R.GAS;
return $ret15941595;
} else {
var $z16031604 = D;
var $f16091610 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22691582):R.ffi.throwNonFunApp(L[151],is_DASH_empty18116.$var,[l22691582]);
};
try {
if(--R.GAS > 0) {
$z16031604 = $f16091610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16091610,
"from":L[151]});
}
} catch($e16011602) {
if(R.isCont($e16011602)) {
var $ss16051606 = {"from":L[151],
"go":function(or_DASH_oper_DASH_921611) {
return $Hor_DASH_oper_DASH_14291612(or_DASH_oper_DASH_921611,if_helper7501598,is_DASH_empty18116,l32701583,l42711584);
}};
$e16011602.stack[R.EXN_STACKHEIGHT++] = $ss16051606;
}
if(R.isPyretException($e16011602)) {
$e16011602.pyretStack.push(L[151]);
}
throw $e16011602;
}
var $ret16071608 = $Hor_DASH_oper_DASH_14291612($z16031604,if_helper7501598,is_DASH_empty18116,l32701583,l42711584);
++R.GAS;
return $ret16071608;
}
} else {
var cont_tail_arg7731615 = R.throwNonBooleanOp(L[152],("first"),("or"),or_DASH_oper_DASH_911578);
if(--R.GAS > 0) {
$z16131614 = R.isFunction(if_helper7501598)?if_helper7501598.app(cont_tail_arg7731615):R.ffi.throwNonFunApp(L[152],if_helper7501598,[cont_tail_arg7731615]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7501598)?if_helper7501598.app(cont_tail_arg7731615):R.ffi.throwNonFunApp(L[152],if_helper7501598,[cont_tail_arg7731615]);
},
"from":L[152]});
}
++R.GAS;
return $z16131614;
}
};
var $Hcont_tail_app14231600 = function(cont_tail_app7881599) {
return cont_tail_app7881599;
};
var $Hor_DASH_oper_DASH_14291612 = function(or_DASH_oper_DASH_921611,if_helper7501598,is_DASH_empty18116,l32701583,l42711584) {
var anf_if7781695 = R.isBoolean(or_DASH_oper_DASH_921611);
if(R.isPyretTrue(anf_if7781695)) {
if(R.isPyretTrue(or_DASH_oper_DASH_921611)) {
var $z16701671 = D;
var $f16761677 = function(_) {
return R.isFunction(if_helper7501598)?if_helper7501598.app((true)):R.ffi.throwNonFunApp(L[151],if_helper7501598,[(true)]);
};
try {
if(--R.GAS > 0) {
$z16701671 = $f16761677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16761677,
"from":L[151]});
}
} catch($e16681669) {
if(R.isCont($e16681669)) {
var $ss16721673 = {"from":L[151],
"go":function(cont_tail_app7871678) {
return $Hcont_tail_app14241679(cont_tail_app7871678);
}};
$e16681669.stack[R.EXN_STACKHEIGHT++] = $ss16721673;
}
if(R.isPyretException($e16681669)) {
$e16681669.pyretStack.push(L[151]);
}
throw $e16681669;
}
var $ret16741675 = $Hcont_tail_app14241679($z16701671);
++R.GAS;
return $ret16741675;
} else {
var $z16821683 = D;
var $f16881689 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l32701583):R.ffi.throwNonFunApp(L[151],is_DASH_empty18116.$var,[l32701583]);
};
try {
if(--R.GAS > 0) {
$z16821683 = $f16881689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16881689,
"from":L[151]});
}
} catch($e16801681) {
if(R.isCont($e16801681)) {
var $ss16841685 = {"from":L[151],
"go":function(or_DASH_oper_DASH_931690) {
return $Hor_DASH_oper_DASH_14281691(or_DASH_oper_DASH_931690,if_helper7501598,is_DASH_empty18116,l42711584);
}};
$e16801681.stack[R.EXN_STACKHEIGHT++] = $ss16841685;
}
if(R.isPyretException($e16801681)) {
$e16801681.pyretStack.push(L[151]);
}
throw $e16801681;
}
var $ret16861687 = $Hor_DASH_oper_DASH_14281691($z16821683,if_helper7501598,is_DASH_empty18116,l42711584);
++R.GAS;
return $ret16861687;
}
} else {
var cont_tail_arg7761694 = R.throwNonBooleanOp(L[161],("first"),("or"),or_DASH_oper_DASH_921611);
if(--R.GAS > 0) {
$z16921693 = R.isFunction(if_helper7501598)?if_helper7501598.app(cont_tail_arg7761694):R.ffi.throwNonFunApp(L[161],if_helper7501598,[cont_tail_arg7761694]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7501598)?if_helper7501598.app(cont_tail_arg7761694):R.ffi.throwNonFunApp(L[161],if_helper7501598,[cont_tail_arg7761694]);
},
"from":L[161]});
}
++R.GAS;
return $z16921693;
}
};
var $Hcont_tail_app14241679 = function(cont_tail_app7871678) {
return cont_tail_app7871678;
};
var $Hor_DASH_oper_DASH_14281691 = function(or_DASH_oper_DASH_931690,if_helper7501598,is_DASH_empty18116,l42711584) {
var anf_if7811723 = R.isBoolean(or_DASH_oper_DASH_931690);
if(R.isPyretTrue(anf_if7811723)) {
if(R.isPyretTrue(or_DASH_oper_DASH_931690)) {
var $z16981699 = D;
var $f17041705 = function(_) {
return R.isFunction(if_helper7501598)?if_helper7501598.app((true)):R.ffi.throwNonFunApp(L[151],if_helper7501598,[(true)]);
};
try {
if(--R.GAS > 0) {
$z16981699 = $f17041705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17041705,
"from":L[151]});
}
} catch($e16961697) {
if(R.isCont($e16961697)) {
var $ss17001701 = {"from":L[151],
"go":function(cont_tail_app7861706) {
return $Hcont_tail_app14251707(cont_tail_app7861706);
}};
$e16961697.stack[R.EXN_STACKHEIGHT++] = $ss17001701;
}
if(R.isPyretException($e16961697)) {
$e16961697.pyretStack.push(L[151]);
}
throw $e16961697;
}
var $ret17021703 = $Hcont_tail_app14251707($z16981699);
++R.GAS;
return $ret17021703;
} else {
var $z17101711 = D;
var $f17161717 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l42711584):R.ffi.throwNonFunApp(L[151],is_DASH_empty18116.$var,[l42711584]);
};
try {
if(--R.GAS > 0) {
$z17101711 = $f17161717();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17161717,
"from":L[151]});
}
} catch($e17081709) {
if(R.isCont($e17081709)) {
var $ss17121713 = {"from":L[151],
"go":function(or_DASH_oper_DASH_941718) {
return $Hor_DASH_oper_DASH_14271719(or_DASH_oper_DASH_941718,if_helper7501598);
}};
$e17081709.stack[R.EXN_STACKHEIGHT++] = $ss17121713;
}
if(R.isPyretException($e17081709)) {
$e17081709.pyretStack.push(L[151]);
}
throw $e17081709;
}
var $ret17141715 = $Hor_DASH_oper_DASH_14271719($z17101711,if_helper7501598);
++R.GAS;
return $ret17141715;
}
} else {
var cont_tail_arg7791722 = R.throwNonBooleanOp(L[162],("first"),("or"),or_DASH_oper_DASH_931690);
if(--R.GAS > 0) {
$z17201721 = R.isFunction(if_helper7501598)?if_helper7501598.app(cont_tail_arg7791722):R.ffi.throwNonFunApp(L[162],if_helper7501598,[cont_tail_arg7791722]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7501598)?if_helper7501598.app(cont_tail_arg7791722):R.ffi.throwNonFunApp(L[162],if_helper7501598,[cont_tail_arg7791722]);
},
"from":L[162]});
}
++R.GAS;
return $z17201721;
}
};
var $Hcont_tail_app14251707 = function(cont_tail_app7861706) {
return cont_tail_app7861706;
};
var $Hor_DASH_oper_DASH_14271719 = function(or_DASH_oper_DASH_941718,if_helper7501598) {
var anf_if7841739 = R.isBoolean(or_DASH_oper_DASH_941718);
if(R.isPyretTrue(anf_if7841739)) {
var $z17261727 = D;
var $f17321733 = function(_) {
return R.isFunction(if_helper7501598)?if_helper7501598.app(or_DASH_oper_DASH_941718):R.ffi.throwNonFunApp(L[151],if_helper7501598,[or_DASH_oper_DASH_941718]);
};
try {
if(--R.GAS > 0) {
$z17261727 = $f17321733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17321733,
"from":L[151]});
}
} catch($e17241725) {
if(R.isCont($e17241725)) {
var $ss17281729 = {"from":L[151],
"go":function(cont_tail_app7851734) {
return $Hcont_tail_app14261735(cont_tail_app7851734);
}};
$e17241725.stack[R.EXN_STACKHEIGHT++] = $ss17281729;
}
if(R.isPyretException($e17241725)) {
$e17241725.pyretStack.push(L[151]);
}
throw $e17241725;
}
var $ret17301731 = $Hcont_tail_app14261735($z17261727);
++R.GAS;
return $ret17301731;
} else {
var cont_tail_arg7821738 = R.throwNonBooleanOp(L[163],("second"),("or"),or_DASH_oper_DASH_941718);
if(--R.GAS > 0) {
$z17361737 = R.isFunction(if_helper7501598)?if_helper7501598.app(cont_tail_arg7821738):R.ffi.throwNonFunApp(L[163],if_helper7501598,[cont_tail_arg7821738]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7501598)?if_helper7501598.app(cont_tail_arg7821738):R.ffi.throwNonFunApp(L[163],if_helper7501598,[cont_tail_arg7821738]);
},
"from":L[163]});
}
++R.GAS;
return $z17361737;
}
};
var $Hcont_tail_app14261735 = function(cont_tail_app7851734) {
return cont_tail_app7851734;
};
var $Hcont_tail_app14171630 = function(cont_tail_app7721629) {
return cont_tail_app7721629;
};
var $Hanf_arg14221647 = function(anf_arg7691645,anf_fun7641646,if_helper7521628) {
var $z17421743 = D;
var $f17481749 = function(_) {
return R.isFunction(anf_fun7641646)?anf_fun7641646.app(anf_arg7691645):R.ffi.throwNonFunApp(L[159],anf_fun7641646,[anf_arg7691645]);
};
try {
if(--R.GAS > 0) {
$z17421743 = $f17481749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17481749,
"from":L[159]});
}
} catch($e17401741) {
if(R.isCont($e17401741)) {
var $ss17441745 = {"from":L[159],
"go":function(cont_tail_arg7701750) {
return $Hcont_tail_arg14211751(cont_tail_arg7701750,if_helper7521628);
}};
$e17401741.stack[R.EXN_STACKHEIGHT++] = $ss17441745;
}
if(R.isPyretException($e17401741)) {
$e17401741.pyretStack.push(L[159]);
}
throw $e17401741;
}
var $ret17461747 = $Hcont_tail_arg14211751($z17421743,if_helper7521628);
++R.GAS;
return $ret17461747;
};
var $Hcont_tail_arg14211751 = function(cont_tail_arg7701750,if_helper7521628) {
if(--R.GAS > 0) {
$z17521753 = R.isFunction(if_helper7521628)?if_helper7521628.app(cont_tail_arg7701750):R.ffi.throwNonFunApp(L[159],if_helper7521628,[cont_tail_arg7701750]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7521628)?if_helper7521628.app(cont_tail_arg7701750):R.ffi.throwNonFunApp(L[159],if_helper7521628,[cont_tail_arg7701750]);
},
"from":L[159]});
}
++R.GAS;
return $z17521753;
};
var $Hanf_arg14201660 = function(anf_arg7581659,arg_DASH_891648,f2661580,l12681581,l22691582,l32701583,l42711584,link211585,map4371586) {
var anf_arg7591764 = G(l12681581,"rest",L[168]);
var anf_arg7601765 = G(l22691582,"rest",L[167]);
var anf_arg7611766 = G(l32701583,"rest",L[166]);
var anf_arg7621767 = G(l42711584,"rest",L[165]);
var $z17561757 = D;
var $f17621763 = function(_) {
return R.isFunction(map4371586.$var)?map4371586.$var.app(f2661580,anf_arg7581659,anf_arg7591764,anf_arg7601765,anf_arg7611766,anf_arg7621767):R.ffi.throwNonFunApp(L[164],map4371586.$var,[f2661580,anf_arg7581659,anf_arg7591764,anf_arg7601765,anf_arg7611766,anf_arg7621767]);
};
try {
if(--R.GAS > 0) {
$z17561757 = $f17621763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17621763,
"from":L[164]});
}
} catch($e17541755) {
if(R.isCont($e17541755)) {
var $ss17581759 = {"from":L[164],
"go":function(anf_arg7631768) {
return $Hanf_arg14191769(anf_arg7631768,arg_DASH_891648,link211585);
}};
$e17541755.stack[R.EXN_STACKHEIGHT++] = $ss17581759;
}
if(R.isPyretException($e17541755)) {
$e17541755.pyretStack.push(L[164]);
}
throw $e17541755;
}
var $ret17601761 = $Hanf_arg14191769($z17561757,arg_DASH_891648,link211585);
++R.GAS;
return $ret17601761;
};
var $Hanf_arg14191769 = function(anf_arg7631768,arg_DASH_891648,link211585) {
var $z17721773 = D;
var $f17781779 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_891648,anf_arg7631768):R.ffi.throwNonFunApp(L[159],link211585.$var,[arg_DASH_891648,anf_arg7631768]);
};
try {
if(--R.GAS > 0) {
$z17721773 = $f17781779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17781779,
"from":L[159]});
}
} catch($e17701771) {
if(R.isCont($e17701771)) {
var $ss17741775 = {"from":L[159],
"go":function(ann_DASH_check_DASH_temp7571780) {
return $Hann_DASH_check_DASH_temp14181781(ann_DASH_check_DASH_temp7571780);
}};
$e17701771.stack[R.EXN_STACKHEIGHT++] = $ss17741775;
}
if(R.isPyretException($e17701771)) {
$e17701771.pyretStack.push(L[159]);
}
throw $e17701771;
}
var $ret17761777 = $Hann_DASH_check_DASH_temp14181781($z17721773);
++R.GAS;
return $ret17761777;
};
var $Hann_DASH_check_DASH_temp14181781 = function(ann_DASH_check_DASH_temp7571780) {
return ann_DASH_check_DASH_temp7571780;
};
var $Hor_DASH_oper_DASH_14161782 = function(or_DASH_oper_DASH_861783,empty191579,f2611784,is_DASH_empty18116,l12631785,l22641786,l32651787,link211585,map3_n401788,n2621789,_plus6) {
var if_helper7151800 = R.makeFunction(function(if_helper_arg7161819) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[169],1,arguments);
}
var if_DASH_851862 = if_helper_arg7161819;
var if_helper7171830 = R.makeFunction(function(if_helper_arg7181867) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[169],1,arguments);
}
var ann_DASH_check_DASH_temp7141868 = if_helper_arg7181867;
return ann_DASH_check_DASH_temp7141868;
});
var anf_if7211866 = R.isBoolean(if_DASH_851862);
if(R.isPyretTrue(anf_if7211866)) {
if(R.isPyretTrue(if_DASH_851862)) {
var $z18221823 = D;
var $f18281829 = function(_) {
return R.isFunction(if_helper7171830)?if_helper7171830.app(empty191579.$var):R.ffi.throwNonFunApp(L[171],if_helper7171830,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z18221823 = $f18281829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18281829,
"from":L[171]});
}
} catch($e18201821) {
if(R.isCont($e18201821)) {
var $ss18241825 = {"from":L[171],
"go":function(cont_tail_app7351831) {
return $Hcont_tail_app14051832(cont_tail_app7351831);
}};
$e18201821.stack[R.EXN_STACKHEIGHT++] = $ss18241825;
}
if(R.isPyretException($e18201821)) {
$e18201821.pyretStack.push(L[171]);
}
throw $e18201821;
}
var $ret18261827 = $Hcont_tail_app14051832($z18221823);
++R.GAS;
return $ret18261827;
} else {
var anf_fun7281847 = R.makeFunction(function(arg_DASH_841849) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[176],1,arguments);
}
var $z18521853 = D;
var $f18581859 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n2621789,(1)):R.ffi.throwNonFunApp(L[177],_plus6,[n2621789,(1)]);
};
try {
if(--R.GAS > 0) {
$z18521853 = $f18581859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18581859,
"from":L[177]});
}
} catch($e18501851) {
if(R.isCont($e18501851)) {
var $ss18541855 = {"from":L[177],
"go":function(anf_arg7231860) {
return $Hanf_arg14081861(anf_arg7231860,arg_DASH_841849,f2611784,l12631785,l22641786,l32651787,link211585,map3_n401788);
}};
$e18501851.stack[R.EXN_STACKHEIGHT++] = $ss18541855;
}
if(R.isPyretException($e18501851)) {
$e18501851.pyretStack.push(L[177]);
}
throw $e18501851;
}
var $ret18561857 = $Hanf_arg14081861($z18521853,arg_DASH_841849,f2611784,l12631785,l22641786,l32651787,link211585,map3_n401788);
++R.GAS;
return $ret18561857;
});
var anf_arg7291843 = G(l12631785,"first",L[175]);
var anf_arg7301844 = G(l22641786,"first",L[174]);
var anf_arg7311845 = G(l32651787,"first",L[173]);
var $z18351836 = D;
var $f18411842 = function(_) {
return R.isFunction(f2611784)?f2611784.app(n2621789,anf_arg7291843,anf_arg7301844,anf_arg7311845):R.ffi.throwNonFunApp(L[172],f2611784,[n2621789,anf_arg7291843,anf_arg7301844,anf_arg7311845]);
};
try {
if(--R.GAS > 0) {
$z18351836 = $f18411842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18411842,
"from":L[172]});
}
} catch($e18331834) {
if(R.isCont($e18331834)) {
var $ss18371838 = {"from":L[172],
"go":function(anf_arg7321846) {
return $Hanf_arg14101848(anf_arg7321846,anf_fun7281847,if_helper7171830);
}};
$e18331834.stack[R.EXN_STACKHEIGHT++] = $ss18371838;
}
if(R.isPyretException($e18331834)) {
$e18331834.pyretStack.push(L[172]);
}
throw $e18331834;
}
var $ret18391840 = $Hanf_arg14101848($z18351836,anf_fun7281847,if_helper7171830);
++R.GAS;
return $ret18391840;
}
} else {
var cont_tail_arg7191865 = R.throwNonBooleanCondition(L[169],("if"),if_DASH_851862);
if(--R.GAS > 0) {
$z18631864 = R.isFunction(if_helper7171830)?if_helper7171830.app(cont_tail_arg7191865):R.ffi.throwNonFunApp(L[169],if_helper7171830,[cont_tail_arg7191865]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7171830)?if_helper7171830.app(cont_tail_arg7191865):R.ffi.throwNonFunApp(L[169],if_helper7171830,[cont_tail_arg7191865]);
},
"from":L[169]});
}
++R.GAS;
return $z18631864;
}
});
var anf_if7381818 = R.isBoolean(or_DASH_oper_DASH_861783);
if(R.isPyretTrue(anf_if7381818)) {
if(R.isPyretTrue(or_DASH_oper_DASH_861783)) {
var $z17921793 = D;
var $f17981799 = function(_) {
return R.isFunction(if_helper7151800)?if_helper7151800.app((true)):R.ffi.throwNonFunApp(L[169],if_helper7151800,[(true)]);
};
try {
if(--R.GAS > 0) {
$z17921793 = $f17981799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17981799,
"from":L[169]});
}
} catch($e17901791) {
if(R.isCont($e17901791)) {
var $ss17941795 = {"from":L[169],
"go":function(cont_tail_app7471801) {
return $Hcont_tail_app14111802(cont_tail_app7471801);
}};
$e17901791.stack[R.EXN_STACKHEIGHT++] = $ss17941795;
}
if(R.isPyretException($e17901791)) {
$e17901791.pyretStack.push(L[169]);
}
throw $e17901791;
}
var $ret17961797 = $Hcont_tail_app14111802($z17921793);
++R.GAS;
return $ret17961797;
} else {
var $z18051806 = D;
var $f18111812 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22641786):R.ffi.throwNonFunApp(L[169],is_DASH_empty18116.$var,[l22641786]);
};
try {
if(--R.GAS > 0) {
$z18051806 = $f18111812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18111812,
"from":L[169]});
}
} catch($e18031804) {
if(R.isCont($e18031804)) {
var $ss18071808 = {"from":L[169],
"go":function(or_DASH_oper_DASH_871813) {
return $Hor_DASH_oper_DASH_14151814(or_DASH_oper_DASH_871813,if_helper7151800,is_DASH_empty18116,l32651787);
}};
$e18031804.stack[R.EXN_STACKHEIGHT++] = $ss18071808;
}
if(R.isPyretException($e18031804)) {
$e18031804.pyretStack.push(L[169]);
}
throw $e18031804;
}
var $ret18091810 = $Hor_DASH_oper_DASH_14151814($z18051806,if_helper7151800,is_DASH_empty18116,l32651787);
++R.GAS;
return $ret18091810;
}
} else {
var cont_tail_arg7361817 = R.throwNonBooleanOp(L[170],("first"),("or"),or_DASH_oper_DASH_861783);
if(--R.GAS > 0) {
$z18151816 = R.isFunction(if_helper7151800)?if_helper7151800.app(cont_tail_arg7361817):R.ffi.throwNonFunApp(L[170],if_helper7151800,[cont_tail_arg7361817]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7151800)?if_helper7151800.app(cont_tail_arg7361817):R.ffi.throwNonFunApp(L[170],if_helper7151800,[cont_tail_arg7361817]);
},
"from":L[170]});
}
++R.GAS;
return $z18151816;
}
};
var $Hcont_tail_app14111802 = function(cont_tail_app7471801) {
return cont_tail_app7471801;
};
var $Hor_DASH_oper_DASH_14151814 = function(or_DASH_oper_DASH_871813,if_helper7151800,is_DASH_empty18116,l32651787) {
var anf_if7411896 = R.isBoolean(or_DASH_oper_DASH_871813);
if(R.isPyretTrue(anf_if7411896)) {
if(R.isPyretTrue(or_DASH_oper_DASH_871813)) {
var $z18711872 = D;
var $f18771878 = function(_) {
return R.isFunction(if_helper7151800)?if_helper7151800.app((true)):R.ffi.throwNonFunApp(L[169],if_helper7151800,[(true)]);
};
try {
if(--R.GAS > 0) {
$z18711872 = $f18771878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18771878,
"from":L[169]});
}
} catch($e18691870) {
if(R.isCont($e18691870)) {
var $ss18731874 = {"from":L[169],
"go":function(cont_tail_app7461879) {
return $Hcont_tail_app14121880(cont_tail_app7461879);
}};
$e18691870.stack[R.EXN_STACKHEIGHT++] = $ss18731874;
}
if(R.isPyretException($e18691870)) {
$e18691870.pyretStack.push(L[169]);
}
throw $e18691870;
}
var $ret18751876 = $Hcont_tail_app14121880($z18711872);
++R.GAS;
return $ret18751876;
} else {
var $z18831884 = D;
var $f18891890 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l32651787):R.ffi.throwNonFunApp(L[169],is_DASH_empty18116.$var,[l32651787]);
};
try {
if(--R.GAS > 0) {
$z18831884 = $f18891890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18891890,
"from":L[169]});
}
} catch($e18811882) {
if(R.isCont($e18811882)) {
var $ss18851886 = {"from":L[169],
"go":function(or_DASH_oper_DASH_881891) {
return $Hor_DASH_oper_DASH_14141892(or_DASH_oper_DASH_881891,if_helper7151800);
}};
$e18811882.stack[R.EXN_STACKHEIGHT++] = $ss18851886;
}
if(R.isPyretException($e18811882)) {
$e18811882.pyretStack.push(L[169]);
}
throw $e18811882;
}
var $ret18871888 = $Hor_DASH_oper_DASH_14141892($z18831884,if_helper7151800);
++R.GAS;
return $ret18871888;
}
} else {
var cont_tail_arg7391895 = R.throwNonBooleanOp(L[178],("first"),("or"),or_DASH_oper_DASH_871813);
if(--R.GAS > 0) {
$z18931894 = R.isFunction(if_helper7151800)?if_helper7151800.app(cont_tail_arg7391895):R.ffi.throwNonFunApp(L[178],if_helper7151800,[cont_tail_arg7391895]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7151800)?if_helper7151800.app(cont_tail_arg7391895):R.ffi.throwNonFunApp(L[178],if_helper7151800,[cont_tail_arg7391895]);
},
"from":L[178]});
}
++R.GAS;
return $z18931894;
}
};
var $Hcont_tail_app14121880 = function(cont_tail_app7461879) {
return cont_tail_app7461879;
};
var $Hor_DASH_oper_DASH_14141892 = function(or_DASH_oper_DASH_881891,if_helper7151800) {
var anf_if7441912 = R.isBoolean(or_DASH_oper_DASH_881891);
if(R.isPyretTrue(anf_if7441912)) {
var $z18991900 = D;
var $f19051906 = function(_) {
return R.isFunction(if_helper7151800)?if_helper7151800.app(or_DASH_oper_DASH_881891):R.ffi.throwNonFunApp(L[169],if_helper7151800,[or_DASH_oper_DASH_881891]);
};
try {
if(--R.GAS > 0) {
$z18991900 = $f19051906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19051906,
"from":L[169]});
}
} catch($e18971898) {
if(R.isCont($e18971898)) {
var $ss19011902 = {"from":L[169],
"go":function(cont_tail_app7451907) {
return $Hcont_tail_app14131908(cont_tail_app7451907);
}};
$e18971898.stack[R.EXN_STACKHEIGHT++] = $ss19011902;
}
if(R.isPyretException($e18971898)) {
$e18971898.pyretStack.push(L[169]);
}
throw $e18971898;
}
var $ret19031904 = $Hcont_tail_app14131908($z18991900);
++R.GAS;
return $ret19031904;
} else {
var cont_tail_arg7421911 = R.throwNonBooleanOp(L[179],("second"),("or"),or_DASH_oper_DASH_881891);
if(--R.GAS > 0) {
$z19091910 = R.isFunction(if_helper7151800)?if_helper7151800.app(cont_tail_arg7421911):R.ffi.throwNonFunApp(L[179],if_helper7151800,[cont_tail_arg7421911]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7151800)?if_helper7151800.app(cont_tail_arg7421911):R.ffi.throwNonFunApp(L[179],if_helper7151800,[cont_tail_arg7421911]);
},
"from":L[179]});
}
++R.GAS;
return $z19091910;
}
};
var $Hcont_tail_app14131908 = function(cont_tail_app7451907) {
return cont_tail_app7451907;
};
var $Hcont_tail_app14051832 = function(cont_tail_app7351831) {
return cont_tail_app7351831;
};
var $Hanf_arg14101848 = function(anf_arg7321846,anf_fun7281847,if_helper7171830) {
var $z19151916 = D;
var $f19211922 = function(_) {
return R.isFunction(anf_fun7281847)?anf_fun7281847.app(anf_arg7321846):R.ffi.throwNonFunApp(L[176],anf_fun7281847,[anf_arg7321846]);
};
try {
if(--R.GAS > 0) {
$z19151916 = $f19211922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19211922,
"from":L[176]});
}
} catch($e19131914) {
if(R.isCont($e19131914)) {
var $ss19171918 = {"from":L[176],
"go":function(cont_tail_arg7331923) {
return $Hcont_tail_arg14091924(cont_tail_arg7331923,if_helper7171830);
}};
$e19131914.stack[R.EXN_STACKHEIGHT++] = $ss19171918;
}
if(R.isPyretException($e19131914)) {
$e19131914.pyretStack.push(L[176]);
}
throw $e19131914;
}
var $ret19191920 = $Hcont_tail_arg14091924($z19151916,if_helper7171830);
++R.GAS;
return $ret19191920;
};
var $Hcont_tail_arg14091924 = function(cont_tail_arg7331923,if_helper7171830) {
if(--R.GAS > 0) {
$z19251926 = R.isFunction(if_helper7171830)?if_helper7171830.app(cont_tail_arg7331923):R.ffi.throwNonFunApp(L[176],if_helper7171830,[cont_tail_arg7331923]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper7171830)?if_helper7171830.app(cont_tail_arg7331923):R.ffi.throwNonFunApp(L[176],if_helper7171830,[cont_tail_arg7331923]);
},
"from":L[176]});
}
++R.GAS;
return $z19251926;
};
var $Hanf_arg14081861 = function(anf_arg7231860,arg_DASH_841849,f2611784,l12631785,l22641786,l32651787,link211585,map3_n401788) {
var anf_arg7241937 = G(l12631785,"rest",L[183]);
var anf_arg7251938 = G(l22641786,"rest",L[182]);
var anf_arg7261939 = G(l32651787,"rest",L[181]);
var $z19291930 = D;
var $f19351936 = function(_) {
return R.isFunction(map3_n401788.$var)?map3_n401788.$var.app(f2611784,anf_arg7231860,anf_arg7241937,anf_arg7251938,anf_arg7261939):R.ffi.throwNonFunApp(L[180],map3_n401788.$var,[f2611784,anf_arg7231860,anf_arg7241937,anf_arg7251938,anf_arg7261939]);
};
try {
if(--R.GAS > 0) {
$z19291930 = $f19351936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19351936,
"from":L[180]});
}
} catch($e19271928) {
if(R.isCont($e19271928)) {
var $ss19311932 = {"from":L[180],
"go":function(anf_arg7271940) {
return $Hanf_arg14071941(anf_arg7271940,arg_DASH_841849,link211585);
}};
$e19271928.stack[R.EXN_STACKHEIGHT++] = $ss19311932;
}
if(R.isPyretException($e19271928)) {
$e19271928.pyretStack.push(L[180]);
}
throw $e19271928;
}
var $ret19331934 = $Hanf_arg14071941($z19291930,arg_DASH_841849,link211585);
++R.GAS;
return $ret19331934;
};
var $Hanf_arg14071941 = function(anf_arg7271940,arg_DASH_841849,link211585) {
var $z19441945 = D;
var $f19501951 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_841849,anf_arg7271940):R.ffi.throwNonFunApp(L[176],link211585.$var,[arg_DASH_841849,anf_arg7271940]);
};
try {
if(--R.GAS > 0) {
$z19441945 = $f19501951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19501951,
"from":L[176]});
}
} catch($e19421943) {
if(R.isCont($e19421943)) {
var $ss19461947 = {"from":L[176],
"go":function(ann_DASH_check_DASH_temp7221952) {
return $Hann_DASH_check_DASH_temp14061953(ann_DASH_check_DASH_temp7221952);
}};
$e19421943.stack[R.EXN_STACKHEIGHT++] = $ss19461947;
}
if(R.isPyretException($e19421943)) {
$e19421943.pyretStack.push(L[176]);
}
throw $e19421943;
}
var $ret19481949 = $Hann_DASH_check_DASH_temp14061953($z19441945);
++R.GAS;
return $ret19481949;
};
var $Hann_DASH_check_DASH_temp14061953 = function(ann_DASH_check_DASH_temp7221952) {
return ann_DASH_check_DASH_temp7221952;
};
var $Hor_DASH_oper_DASH_14041954 = function(or_DASH_oper_DASH_821955,empty191579,f2571956,is_DASH_empty18116,l12591957,l22601958,link211585,map2_n391959,n2581960,_plus6) {
var if_helper6861971 = R.makeFunction(function(if_helper_arg6871990) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[184],1,arguments);
}
var if_DASH_812032 = if_helper_arg6871990;
var if_helper6882001 = R.makeFunction(function(if_helper_arg6892037) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[184],1,arguments);
}
var ann_DASH_check_DASH_temp6852038 = if_helper_arg6892037;
return ann_DASH_check_DASH_temp6852038;
});
var anf_if6922036 = R.isBoolean(if_DASH_812032);
if(R.isPyretTrue(anf_if6922036)) {
if(R.isPyretTrue(if_DASH_812032)) {
var $z19931994 = D;
var $f19992000 = function(_) {
return R.isFunction(if_helper6882001)?if_helper6882001.app(empty191579.$var):R.ffi.throwNonFunApp(L[186],if_helper6882001,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z19931994 = $f19992000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19992000,
"from":L[186]});
}
} catch($e19911992) {
if(R.isCont($e19911992)) {
var $ss19951996 = {"from":L[186],
"go":function(cont_tail_app7042002) {
return $Hcont_tail_app13952003(cont_tail_app7042002);
}};
$e19911992.stack[R.EXN_STACKHEIGHT++] = $ss19951996;
}
if(R.isPyretException($e19911992)) {
$e19911992.pyretStack.push(L[186]);
}
throw $e19911992;
}
var $ret19971998 = $Hcont_tail_app13952003($z19931994);
++R.GAS;
return $ret19971998;
} else {
var anf_fun6982017 = R.makeFunction(function(arg_DASH_802019) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[190],1,arguments);
}
var $z20222023 = D;
var $f20282029 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n2581960,(1)):R.ffi.throwNonFunApp(L[191],_plus6,[n2581960,(1)]);
};
try {
if(--R.GAS > 0) {
$z20222023 = $f20282029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20282029,
"from":L[191]});
}
} catch($e20202021) {
if(R.isCont($e20202021)) {
var $ss20242025 = {"from":L[191],
"go":function(anf_arg6942030) {
return $Hanf_arg13982031(anf_arg6942030,arg_DASH_802019,f2571956,l12591957,l22601958,link211585,map2_n391959);
}};
$e20202021.stack[R.EXN_STACKHEIGHT++] = $ss20242025;
}
if(R.isPyretException($e20202021)) {
$e20202021.pyretStack.push(L[191]);
}
throw $e20202021;
}
var $ret20262027 = $Hanf_arg13982031($z20222023,arg_DASH_802019,f2571956,l12591957,l22601958,link211585,map2_n391959);
++R.GAS;
return $ret20262027;
});
var anf_arg6992014 = G(l12591957,"first",L[189]);
var anf_arg7002015 = G(l22601958,"first",L[188]);
var $z20062007 = D;
var $f20122013 = function(_) {
return R.isFunction(f2571956)?f2571956.app(n2581960,anf_arg6992014,anf_arg7002015):R.ffi.throwNonFunApp(L[187],f2571956,[n2581960,anf_arg6992014,anf_arg7002015]);
};
try {
if(--R.GAS > 0) {
$z20062007 = $f20122013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20122013,
"from":L[187]});
}
} catch($e20042005) {
if(R.isCont($e20042005)) {
var $ss20082009 = {"from":L[187],
"go":function(anf_arg7012016) {
return $Hanf_arg14002018(anf_arg7012016,anf_fun6982017,if_helper6882001);
}};
$e20042005.stack[R.EXN_STACKHEIGHT++] = $ss20082009;
}
if(R.isPyretException($e20042005)) {
$e20042005.pyretStack.push(L[187]);
}
throw $e20042005;
}
var $ret20102011 = $Hanf_arg14002018($z20062007,anf_fun6982017,if_helper6882001);
++R.GAS;
return $ret20102011;
}
} else {
var cont_tail_arg6902035 = R.throwNonBooleanCondition(L[184],("if"),if_DASH_812032);
if(--R.GAS > 0) {
$z20332034 = R.isFunction(if_helper6882001)?if_helper6882001.app(cont_tail_arg6902035):R.ffi.throwNonFunApp(L[184],if_helper6882001,[cont_tail_arg6902035]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6882001)?if_helper6882001.app(cont_tail_arg6902035):R.ffi.throwNonFunApp(L[184],if_helper6882001,[cont_tail_arg6902035]);
},
"from":L[184]});
}
++R.GAS;
return $z20332034;
}
});
var anf_if7071989 = R.isBoolean(or_DASH_oper_DASH_821955);
if(R.isPyretTrue(anf_if7071989)) {
if(R.isPyretTrue(or_DASH_oper_DASH_821955)) {
var $z19631964 = D;
var $f19691970 = function(_) {
return R.isFunction(if_helper6861971)?if_helper6861971.app((true)):R.ffi.throwNonFunApp(L[184],if_helper6861971,[(true)]);
};
try {
if(--R.GAS > 0) {
$z19631964 = $f19691970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19691970,
"from":L[184]});
}
} catch($e19611962) {
if(R.isCont($e19611962)) {
var $ss19651966 = {"from":L[184],
"go":function(cont_tail_app7121972) {
return $Hcont_tail_app14011973(cont_tail_app7121972);
}};
$e19611962.stack[R.EXN_STACKHEIGHT++] = $ss19651966;
}
if(R.isPyretException($e19611962)) {
$e19611962.pyretStack.push(L[184]);
}
throw $e19611962;
}
var $ret19671968 = $Hcont_tail_app14011973($z19631964);
++R.GAS;
return $ret19671968;
} else {
var $z19761977 = D;
var $f19821983 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22601958):R.ffi.throwNonFunApp(L[184],is_DASH_empty18116.$var,[l22601958]);
};
try {
if(--R.GAS > 0) {
$z19761977 = $f19821983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19821983,
"from":L[184]});
}
} catch($e19741975) {
if(R.isCont($e19741975)) {
var $ss19781979 = {"from":L[184],
"go":function(or_DASH_oper_DASH_831984) {
return $Hor_DASH_oper_DASH_14031985(or_DASH_oper_DASH_831984,if_helper6861971);
}};
$e19741975.stack[R.EXN_STACKHEIGHT++] = $ss19781979;
}
if(R.isPyretException($e19741975)) {
$e19741975.pyretStack.push(L[184]);
}
throw $e19741975;
}
var $ret19801981 = $Hor_DASH_oper_DASH_14031985($z19761977,if_helper6861971);
++R.GAS;
return $ret19801981;
}
} else {
var cont_tail_arg7051988 = R.throwNonBooleanOp(L[185],("first"),("or"),or_DASH_oper_DASH_821955);
if(--R.GAS > 0) {
$z19861987 = R.isFunction(if_helper6861971)?if_helper6861971.app(cont_tail_arg7051988):R.ffi.throwNonFunApp(L[185],if_helper6861971,[cont_tail_arg7051988]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6861971)?if_helper6861971.app(cont_tail_arg7051988):R.ffi.throwNonFunApp(L[185],if_helper6861971,[cont_tail_arg7051988]);
},
"from":L[185]});
}
++R.GAS;
return $z19861987;
}
};
var $Hcont_tail_app14011973 = function(cont_tail_app7121972) {
return cont_tail_app7121972;
};
var $Hor_DASH_oper_DASH_14031985 = function(or_DASH_oper_DASH_831984,if_helper6861971) {
var anf_if7102054 = R.isBoolean(or_DASH_oper_DASH_831984);
if(R.isPyretTrue(anf_if7102054)) {
var $z20412042 = D;
var $f20472048 = function(_) {
return R.isFunction(if_helper6861971)?if_helper6861971.app(or_DASH_oper_DASH_831984):R.ffi.throwNonFunApp(L[184],if_helper6861971,[or_DASH_oper_DASH_831984]);
};
try {
if(--R.GAS > 0) {
$z20412042 = $f20472048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20472048,
"from":L[184]});
}
} catch($e20392040) {
if(R.isCont($e20392040)) {
var $ss20432044 = {"from":L[184],
"go":function(cont_tail_app7112049) {
return $Hcont_tail_app14022050(cont_tail_app7112049);
}};
$e20392040.stack[R.EXN_STACKHEIGHT++] = $ss20432044;
}
if(R.isPyretException($e20392040)) {
$e20392040.pyretStack.push(L[184]);
}
throw $e20392040;
}
var $ret20452046 = $Hcont_tail_app14022050($z20412042);
++R.GAS;
return $ret20452046;
} else {
var cont_tail_arg7082053 = R.throwNonBooleanOp(L[192],("second"),("or"),or_DASH_oper_DASH_831984);
if(--R.GAS > 0) {
$z20512052 = R.isFunction(if_helper6861971)?if_helper6861971.app(cont_tail_arg7082053):R.ffi.throwNonFunApp(L[192],if_helper6861971,[cont_tail_arg7082053]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6861971)?if_helper6861971.app(cont_tail_arg7082053):R.ffi.throwNonFunApp(L[192],if_helper6861971,[cont_tail_arg7082053]);
},
"from":L[192]});
}
++R.GAS;
return $z20512052;
}
};
var $Hcont_tail_app14022050 = function(cont_tail_app7112049) {
return cont_tail_app7112049;
};
var $Hcont_tail_app13952003 = function(cont_tail_app7042002) {
return cont_tail_app7042002;
};
var $Hanf_arg14002018 = function(anf_arg7012016,anf_fun6982017,if_helper6882001) {
var $z20572058 = D;
var $f20632064 = function(_) {
return R.isFunction(anf_fun6982017)?anf_fun6982017.app(anf_arg7012016):R.ffi.throwNonFunApp(L[190],anf_fun6982017,[anf_arg7012016]);
};
try {
if(--R.GAS > 0) {
$z20572058 = $f20632064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20632064,
"from":L[190]});
}
} catch($e20552056) {
if(R.isCont($e20552056)) {
var $ss20592060 = {"from":L[190],
"go":function(cont_tail_arg7022065) {
return $Hcont_tail_arg13992066(cont_tail_arg7022065,if_helper6882001);
}};
$e20552056.stack[R.EXN_STACKHEIGHT++] = $ss20592060;
}
if(R.isPyretException($e20552056)) {
$e20552056.pyretStack.push(L[190]);
}
throw $e20552056;
}
var $ret20612062 = $Hcont_tail_arg13992066($z20572058,if_helper6882001);
++R.GAS;
return $ret20612062;
};
var $Hcont_tail_arg13992066 = function(cont_tail_arg7022065,if_helper6882001) {
if(--R.GAS > 0) {
$z20672068 = R.isFunction(if_helper6882001)?if_helper6882001.app(cont_tail_arg7022065):R.ffi.throwNonFunApp(L[190],if_helper6882001,[cont_tail_arg7022065]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6882001)?if_helper6882001.app(cont_tail_arg7022065):R.ffi.throwNonFunApp(L[190],if_helper6882001,[cont_tail_arg7022065]);
},
"from":L[190]});
}
++R.GAS;
return $z20672068;
};
var $Hanf_arg13982031 = function(anf_arg6942030,arg_DASH_802019,f2571956,l12591957,l22601958,link211585,map2_n391959) {
var anf_arg6952079 = G(l12591957,"rest",L[195]);
var anf_arg6962080 = G(l22601958,"rest",L[194]);
var $z20712072 = D;
var $f20772078 = function(_) {
return R.isFunction(map2_n391959.$var)?map2_n391959.$var.app(f2571956,anf_arg6942030,anf_arg6952079,anf_arg6962080):R.ffi.throwNonFunApp(L[193],map2_n391959.$var,[f2571956,anf_arg6942030,anf_arg6952079,anf_arg6962080]);
};
try {
if(--R.GAS > 0) {
$z20712072 = $f20772078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20772078,
"from":L[193]});
}
} catch($e20692070) {
if(R.isCont($e20692070)) {
var $ss20732074 = {"from":L[193],
"go":function(anf_arg6972081) {
return $Hanf_arg13972082(anf_arg6972081,arg_DASH_802019,link211585);
}};
$e20692070.stack[R.EXN_STACKHEIGHT++] = $ss20732074;
}
if(R.isPyretException($e20692070)) {
$e20692070.pyretStack.push(L[193]);
}
throw $e20692070;
}
var $ret20752076 = $Hanf_arg13972082($z20712072,arg_DASH_802019,link211585);
++R.GAS;
return $ret20752076;
};
var $Hanf_arg13972082 = function(anf_arg6972081,arg_DASH_802019,link211585) {
var $z20852086 = D;
var $f20912092 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_802019,anf_arg6972081):R.ffi.throwNonFunApp(L[190],link211585.$var,[arg_DASH_802019,anf_arg6972081]);
};
try {
if(--R.GAS > 0) {
$z20852086 = $f20912092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20912092,
"from":L[190]});
}
} catch($e20832084) {
if(R.isCont($e20832084)) {
var $ss20872088 = {"from":L[190],
"go":function(ann_DASH_check_DASH_temp6932093) {
return $Hann_DASH_check_DASH_temp13962094(ann_DASH_check_DASH_temp6932093);
}};
$e20832084.stack[R.EXN_STACKHEIGHT++] = $ss20872088;
}
if(R.isPyretException($e20832084)) {
$e20832084.pyretStack.push(L[190]);
}
throw $e20832084;
}
var $ret20892090 = $Hann_DASH_check_DASH_temp13962094($z20852086);
++R.GAS;
return $ret20892090;
};
var $Hann_DASH_check_DASH_temp13962094 = function(ann_DASH_check_DASH_temp6932093) {
return ann_DASH_check_DASH_temp6932093;
};
var $Hif_DASH_13942095 = function(if_DASH_792096,empty191579,f2522097,link211585,lst2542098,map_n382099,n2532100,_plus6) {
var if_helper6692111 = R.makeFunction(function(if_helper_arg6702145) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[201],1,arguments);
}
var ann_DASH_check_DASH_temp6682146 = if_helper_arg6702145;
return ann_DASH_check_DASH_temp6682146;
});
var anf_if6732144 = R.isBoolean(if_DASH_792096);
if(R.isPyretTrue(anf_if6732144)) {
if(R.isPyretTrue(if_DASH_792096)) {
var $z21032104 = D;
var $f21092110 = function(_) {
return R.isFunction(if_helper6692111)?if_helper6692111.app(empty191579.$var):R.ffi.throwNonFunApp(L[196],if_helper6692111,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z21032104 = $f21092110();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21092110,
"from":L[196]});
}
} catch($e21012102) {
if(R.isCont($e21012102)) {
var $ss21052106 = {"from":L[196],
"go":function(cont_tail_app6832112) {
return $Hcont_tail_app13882113(cont_tail_app6832112);
}};
$e21012102.stack[R.EXN_STACKHEIGHT++] = $ss21052106;
}
if(R.isPyretException($e21012102)) {
$e21012102.pyretStack.push(L[196]);
}
throw $e21012102;
}
var $ret21072108 = $Hcont_tail_app13882113($z21032104);
++R.GAS;
return $ret21072108;
} else {
var anf_fun6782126 = R.makeFunction(function(arg_DASH_782128) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[199],1,arguments);
}
var $z21312132 = D;
var $f21372138 = function(_) {
return R.isFunction(_plus6)?_plus6.app(n2532100,(1)):R.ffi.throwNonFunApp(L[200],_plus6,[n2532100,(1)]);
};
try {
if(--R.GAS > 0) {
$z21312132 = $f21372138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21372138,
"from":L[200]});
}
} catch($e21292130) {
if(R.isCont($e21292130)) {
var $ss21332134 = {"from":L[200],
"go":function(anf_arg6752139) {
return $Hanf_arg13912140(anf_arg6752139,arg_DASH_782128,f2522097,link211585,lst2542098,map_n382099);
}};
$e21292130.stack[R.EXN_STACKHEIGHT++] = $ss21332134;
}
if(R.isPyretException($e21292130)) {
$e21292130.pyretStack.push(L[200]);
}
throw $e21292130;
}
var $ret21352136 = $Hanf_arg13912140($z21312132,arg_DASH_782128,f2522097,link211585,lst2542098,map_n382099);
++R.GAS;
return $ret21352136;
});
var anf_arg6792124 = G(lst2542098,"first",L[198]);
var $z21162117 = D;
var $f21222123 = function(_) {
return R.isFunction(f2522097)?f2522097.app(n2532100,anf_arg6792124):R.ffi.throwNonFunApp(L[197],f2522097,[n2532100,anf_arg6792124]);
};
try {
if(--R.GAS > 0) {
$z21162117 = $f21222123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21222123,
"from":L[197]});
}
} catch($e21142115) {
if(R.isCont($e21142115)) {
var $ss21182119 = {"from":L[197],
"go":function(anf_arg6802125) {
return $Hanf_arg13932127(anf_arg6802125,anf_fun6782126,if_helper6692111);
}};
$e21142115.stack[R.EXN_STACKHEIGHT++] = $ss21182119;
}
if(R.isPyretException($e21142115)) {
$e21142115.pyretStack.push(L[197]);
}
throw $e21142115;
}
var $ret21202121 = $Hanf_arg13932127($z21162117,anf_fun6782126,if_helper6692111);
++R.GAS;
return $ret21202121;
}
} else {
var cont_tail_arg6712143 = R.throwNonBooleanCondition(L[201],("if"),if_DASH_792096);
if(--R.GAS > 0) {
$z21412142 = R.isFunction(if_helper6692111)?if_helper6692111.app(cont_tail_arg6712143):R.ffi.throwNonFunApp(L[201],if_helper6692111,[cont_tail_arg6712143]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6692111)?if_helper6692111.app(cont_tail_arg6712143):R.ffi.throwNonFunApp(L[201],if_helper6692111,[cont_tail_arg6712143]);
},
"from":L[201]});
}
++R.GAS;
return $z21412142;
}
};
var $Hcont_tail_app13882113 = function(cont_tail_app6832112) {
return cont_tail_app6832112;
};
var $Hanf_arg13932127 = function(anf_arg6802125,anf_fun6782126,if_helper6692111) {
var $z21492150 = D;
var $f21552156 = function(_) {
return R.isFunction(anf_fun6782126)?anf_fun6782126.app(anf_arg6802125):R.ffi.throwNonFunApp(L[199],anf_fun6782126,[anf_arg6802125]);
};
try {
if(--R.GAS > 0) {
$z21492150 = $f21552156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21552156,
"from":L[199]});
}
} catch($e21472148) {
if(R.isCont($e21472148)) {
var $ss21512152 = {"from":L[199],
"go":function(cont_tail_arg6812157) {
return $Hcont_tail_arg13922158(cont_tail_arg6812157,if_helper6692111);
}};
$e21472148.stack[R.EXN_STACKHEIGHT++] = $ss21512152;
}
if(R.isPyretException($e21472148)) {
$e21472148.pyretStack.push(L[199]);
}
throw $e21472148;
}
var $ret21532154 = $Hcont_tail_arg13922158($z21492150,if_helper6692111);
++R.GAS;
return $ret21532154;
};
var $Hcont_tail_arg13922158 = function(cont_tail_arg6812157,if_helper6692111) {
if(--R.GAS > 0) {
$z21592160 = R.isFunction(if_helper6692111)?if_helper6692111.app(cont_tail_arg6812157):R.ffi.throwNonFunApp(L[199],if_helper6692111,[cont_tail_arg6812157]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6692111)?if_helper6692111.app(cont_tail_arg6812157):R.ffi.throwNonFunApp(L[199],if_helper6692111,[cont_tail_arg6812157]);
},
"from":L[199]});
}
++R.GAS;
return $z21592160;
};
var $Hanf_arg13912140 = function(anf_arg6752139,arg_DASH_782128,f2522097,link211585,lst2542098,map_n382099) {
var anf_arg6762171 = G(lst2542098,"rest",L[203]);
var $z21632164 = D;
var $f21692170 = function(_) {
return R.isFunction(map_n382099.$var)?map_n382099.$var.app(f2522097,anf_arg6752139,anf_arg6762171):R.ffi.throwNonFunApp(L[202],map_n382099.$var,[f2522097,anf_arg6752139,anf_arg6762171]);
};
try {
if(--R.GAS > 0) {
$z21632164 = $f21692170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21692170,
"from":L[202]});
}
} catch($e21612162) {
if(R.isCont($e21612162)) {
var $ss21652166 = {"from":L[202],
"go":function(anf_arg6772172) {
return $Hanf_arg13902173(anf_arg6772172,arg_DASH_782128,link211585);
}};
$e21612162.stack[R.EXN_STACKHEIGHT++] = $ss21652166;
}
if(R.isPyretException($e21612162)) {
$e21612162.pyretStack.push(L[202]);
}
throw $e21612162;
}
var $ret21672168 = $Hanf_arg13902173($z21632164,arg_DASH_782128,link211585);
++R.GAS;
return $ret21672168;
};
var $Hanf_arg13902173 = function(anf_arg6772172,arg_DASH_782128,link211585) {
var $z21762177 = D;
var $f21822183 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_782128,anf_arg6772172):R.ffi.throwNonFunApp(L[199],link211585.$var,[arg_DASH_782128,anf_arg6772172]);
};
try {
if(--R.GAS > 0) {
$z21762177 = $f21822183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21822183,
"from":L[199]});
}
} catch($e21742175) {
if(R.isCont($e21742175)) {
var $ss21782179 = {"from":L[199],
"go":function(ann_DASH_check_DASH_temp6742184) {
return $Hann_DASH_check_DASH_temp13892185(ann_DASH_check_DASH_temp6742184);
}};
$e21742175.stack[R.EXN_STACKHEIGHT++] = $ss21782179;
}
if(R.isPyretException($e21742175)) {
$e21742175.pyretStack.push(L[199]);
}
throw $e21742175;
}
var $ret21802181 = $Hann_DASH_check_DASH_temp13892185($z21762177);
++R.GAS;
return $ret21802181;
};
var $Hann_DASH_check_DASH_temp13892185 = function(ann_DASH_check_DASH_temp6742184) {
return ann_DASH_check_DASH_temp6742184;
};
var $Hor_DASH_oper_DASH_13872186 = function(or_DASH_oper_DASH_742187,empty191579,f2472188,is_DASH_empty18116,l12482189,l22492190,l32502191,l42512192,link211585,map4371586) {
var if_helper6292203 = R.makeFunction(function(if_helper_arg6302222) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[204],1,arguments);
}
var if_DASH_732270 = if_helper_arg6302222;
var if_helper6312233 = R.makeFunction(function(if_helper_arg6322275) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[204],1,arguments);
}
var ann_DASH_check_DASH_temp6282276 = if_helper_arg6322275;
return ann_DASH_check_DASH_temp6282276;
});
var anf_if6352274 = R.isBoolean(if_DASH_732270);
if(R.isPyretTrue(anf_if6352274)) {
if(R.isPyretTrue(if_DASH_732270)) {
var $z22252226 = D;
var $f22312232 = function(_) {
return R.isFunction(if_helper6312233)?if_helper6312233.app(empty191579.$var):R.ffi.throwNonFunApp(L[206],if_helper6312233,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z22252226 = $f22312232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22312232,
"from":L[206]});
}
} catch($e22232224) {
if(R.isCont($e22232224)) {
var $ss22272228 = {"from":L[206],
"go":function(cont_tail_app6502234) {
return $Hcont_tail_app13752235(cont_tail_app6502234);
}};
$e22232224.stack[R.EXN_STACKHEIGHT++] = $ss22272228;
}
if(R.isPyretException($e22232224)) {
$e22232224.pyretStack.push(L[206]);
}
throw $e22232224;
}
var $ret22292230 = $Hcont_tail_app13752235($z22252226);
++R.GAS;
return $ret22292230;
} else {
var anf_fun6422251 = R.makeFunction(function(arg_DASH_722253) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[212],1,arguments);
}
var anf_arg6372264 = G(l12482189,"rest",L[217]);
var anf_arg6382265 = G(l22492190,"rest",L[216]);
var anf_arg6392266 = G(l32502191,"rest",L[215]);
var anf_arg6402267 = G(l42512192,"rest",L[214]);
var $z22562257 = D;
var $f22622263 = function(_) {
return R.isFunction(map4371586.$var)?map4371586.$var.app(f2472188,anf_arg6372264,anf_arg6382265,anf_arg6392266,anf_arg6402267):R.ffi.throwNonFunApp(L[213],map4371586.$var,[f2472188,anf_arg6372264,anf_arg6382265,anf_arg6392266,anf_arg6402267]);
};
try {
if(--R.GAS > 0) {
$z22562257 = $f22622263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22622263,
"from":L[213]});
}
} catch($e22542255) {
if(R.isCont($e22542255)) {
var $ss22582259 = {"from":L[213],
"go":function(anf_arg6412268) {
return $Hanf_arg13772269(anf_arg6412268,arg_DASH_722253,link211585);
}};
$e22542255.stack[R.EXN_STACKHEIGHT++] = $ss22582259;
}
if(R.isPyretException($e22542255)) {
$e22542255.pyretStack.push(L[213]);
}
throw $e22542255;
}
var $ret22602261 = $Hanf_arg13772269($z22562257,arg_DASH_722253,link211585);
++R.GAS;
return $ret22602261;
});
var anf_arg6432246 = G(l12482189,"first",L[211]);
var anf_arg6442247 = G(l22492190,"first",L[210]);
var anf_arg6452248 = G(l32502191,"first",L[209]);
var anf_arg6462249 = G(l42512192,"first",L[208]);
var $z22382239 = D;
var $f22442245 = function(_) {
return R.isFunction(f2472188)?f2472188.app(anf_arg6432246,anf_arg6442247,anf_arg6452248,anf_arg6462249):R.ffi.throwNonFunApp(L[207],f2472188,[anf_arg6432246,anf_arg6442247,anf_arg6452248,anf_arg6462249]);
};
try {
if(--R.GAS > 0) {
$z22382239 = $f22442245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22442245,
"from":L[207]});
}
} catch($e22362237) {
if(R.isCont($e22362237)) {
var $ss22402241 = {"from":L[207],
"go":function(anf_arg6472250) {
return $Hanf_arg13792252(anf_arg6472250,anf_fun6422251,if_helper6312233);
}};
$e22362237.stack[R.EXN_STACKHEIGHT++] = $ss22402241;
}
if(R.isPyretException($e22362237)) {
$e22362237.pyretStack.push(L[207]);
}
throw $e22362237;
}
var $ret22422243 = $Hanf_arg13792252($z22382239,anf_fun6422251,if_helper6312233);
++R.GAS;
return $ret22422243;
}
} else {
var cont_tail_arg6332273 = R.throwNonBooleanCondition(L[204],("if"),if_DASH_732270);
if(--R.GAS > 0) {
$z22712272 = R.isFunction(if_helper6312233)?if_helper6312233.app(cont_tail_arg6332273):R.ffi.throwNonFunApp(L[204],if_helper6312233,[cont_tail_arg6332273]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6312233)?if_helper6312233.app(cont_tail_arg6332273):R.ffi.throwNonFunApp(L[204],if_helper6312233,[cont_tail_arg6332273]);
},
"from":L[204]});
}
++R.GAS;
return $z22712272;
}
});
var anf_if6532221 = R.isBoolean(or_DASH_oper_DASH_742187);
if(R.isPyretTrue(anf_if6532221)) {
if(R.isPyretTrue(or_DASH_oper_DASH_742187)) {
var $z21952196 = D;
var $f22012202 = function(_) {
return R.isFunction(if_helper6292203)?if_helper6292203.app((true)):R.ffi.throwNonFunApp(L[204],if_helper6292203,[(true)]);
};
try {
if(--R.GAS > 0) {
$z21952196 = $f22012202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22012202,
"from":L[204]});
}
} catch($e21932194) {
if(R.isCont($e21932194)) {
var $ss21972198 = {"from":L[204],
"go":function(cont_tail_app6662204) {
return $Hcont_tail_app13802205(cont_tail_app6662204);
}};
$e21932194.stack[R.EXN_STACKHEIGHT++] = $ss21972198;
}
if(R.isPyretException($e21932194)) {
$e21932194.pyretStack.push(L[204]);
}
throw $e21932194;
}
var $ret21992200 = $Hcont_tail_app13802205($z21952196);
++R.GAS;
return $ret21992200;
} else {
var $z22082209 = D;
var $f22142215 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22492190):R.ffi.throwNonFunApp(L[204],is_DASH_empty18116.$var,[l22492190]);
};
try {
if(--R.GAS > 0) {
$z22082209 = $f22142215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22142215,
"from":L[204]});
}
} catch($e22062207) {
if(R.isCont($e22062207)) {
var $ss22102211 = {"from":L[204],
"go":function(or_DASH_oper_DASH_752216) {
return $Hor_DASH_oper_DASH_13862217(or_DASH_oper_DASH_752216,if_helper6292203,is_DASH_empty18116,l32502191,l42512192);
}};
$e22062207.stack[R.EXN_STACKHEIGHT++] = $ss22102211;
}
if(R.isPyretException($e22062207)) {
$e22062207.pyretStack.push(L[204]);
}
throw $e22062207;
}
var $ret22122213 = $Hor_DASH_oper_DASH_13862217($z22082209,if_helper6292203,is_DASH_empty18116,l32502191,l42512192);
++R.GAS;
return $ret22122213;
}
} else {
var cont_tail_arg6512220 = R.throwNonBooleanOp(L[205],("first"),("or"),or_DASH_oper_DASH_742187);
if(--R.GAS > 0) {
$z22182219 = R.isFunction(if_helper6292203)?if_helper6292203.app(cont_tail_arg6512220):R.ffi.throwNonFunApp(L[205],if_helper6292203,[cont_tail_arg6512220]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6292203)?if_helper6292203.app(cont_tail_arg6512220):R.ffi.throwNonFunApp(L[205],if_helper6292203,[cont_tail_arg6512220]);
},
"from":L[205]});
}
++R.GAS;
return $z22182219;
}
};
var $Hcont_tail_app13802205 = function(cont_tail_app6662204) {
return cont_tail_app6662204;
};
var $Hor_DASH_oper_DASH_13862217 = function(or_DASH_oper_DASH_752216,if_helper6292203,is_DASH_empty18116,l32502191,l42512192) {
var anf_if6562304 = R.isBoolean(or_DASH_oper_DASH_752216);
if(R.isPyretTrue(anf_if6562304)) {
if(R.isPyretTrue(or_DASH_oper_DASH_752216)) {
var $z22792280 = D;
var $f22852286 = function(_) {
return R.isFunction(if_helper6292203)?if_helper6292203.app((true)):R.ffi.throwNonFunApp(L[204],if_helper6292203,[(true)]);
};
try {
if(--R.GAS > 0) {
$z22792280 = $f22852286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22852286,
"from":L[204]});
}
} catch($e22772278) {
if(R.isCont($e22772278)) {
var $ss22812282 = {"from":L[204],
"go":function(cont_tail_app6652287) {
return $Hcont_tail_app13812288(cont_tail_app6652287);
}};
$e22772278.stack[R.EXN_STACKHEIGHT++] = $ss22812282;
}
if(R.isPyretException($e22772278)) {
$e22772278.pyretStack.push(L[204]);
}
throw $e22772278;
}
var $ret22832284 = $Hcont_tail_app13812288($z22792280);
++R.GAS;
return $ret22832284;
} else {
var $z22912292 = D;
var $f22972298 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l32502191):R.ffi.throwNonFunApp(L[204],is_DASH_empty18116.$var,[l32502191]);
};
try {
if(--R.GAS > 0) {
$z22912292 = $f22972298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22972298,
"from":L[204]});
}
} catch($e22892290) {
if(R.isCont($e22892290)) {
var $ss22932294 = {"from":L[204],
"go":function(or_DASH_oper_DASH_762299) {
return $Hor_DASH_oper_DASH_13852300(or_DASH_oper_DASH_762299,if_helper6292203,is_DASH_empty18116,l42512192);
}};
$e22892290.stack[R.EXN_STACKHEIGHT++] = $ss22932294;
}
if(R.isPyretException($e22892290)) {
$e22892290.pyretStack.push(L[204]);
}
throw $e22892290;
}
var $ret22952296 = $Hor_DASH_oper_DASH_13852300($z22912292,if_helper6292203,is_DASH_empty18116,l42512192);
++R.GAS;
return $ret22952296;
}
} else {
var cont_tail_arg6542303 = R.throwNonBooleanOp(L[218],("first"),("or"),or_DASH_oper_DASH_752216);
if(--R.GAS > 0) {
$z23012302 = R.isFunction(if_helper6292203)?if_helper6292203.app(cont_tail_arg6542303):R.ffi.throwNonFunApp(L[218],if_helper6292203,[cont_tail_arg6542303]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6292203)?if_helper6292203.app(cont_tail_arg6542303):R.ffi.throwNonFunApp(L[218],if_helper6292203,[cont_tail_arg6542303]);
},
"from":L[218]});
}
++R.GAS;
return $z23012302;
}
};
var $Hcont_tail_app13812288 = function(cont_tail_app6652287) {
return cont_tail_app6652287;
};
var $Hor_DASH_oper_DASH_13852300 = function(or_DASH_oper_DASH_762299,if_helper6292203,is_DASH_empty18116,l42512192) {
var anf_if6592332 = R.isBoolean(or_DASH_oper_DASH_762299);
if(R.isPyretTrue(anf_if6592332)) {
if(R.isPyretTrue(or_DASH_oper_DASH_762299)) {
var $z23072308 = D;
var $f23132314 = function(_) {
return R.isFunction(if_helper6292203)?if_helper6292203.app((true)):R.ffi.throwNonFunApp(L[204],if_helper6292203,[(true)]);
};
try {
if(--R.GAS > 0) {
$z23072308 = $f23132314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23132314,
"from":L[204]});
}
} catch($e23052306) {
if(R.isCont($e23052306)) {
var $ss23092310 = {"from":L[204],
"go":function(cont_tail_app6642315) {
return $Hcont_tail_app13822316(cont_tail_app6642315);
}};
$e23052306.stack[R.EXN_STACKHEIGHT++] = $ss23092310;
}
if(R.isPyretException($e23052306)) {
$e23052306.pyretStack.push(L[204]);
}
throw $e23052306;
}
var $ret23112312 = $Hcont_tail_app13822316($z23072308);
++R.GAS;
return $ret23112312;
} else {
var $z23192320 = D;
var $f23252326 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l42512192):R.ffi.throwNonFunApp(L[204],is_DASH_empty18116.$var,[l42512192]);
};
try {
if(--R.GAS > 0) {
$z23192320 = $f23252326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23252326,
"from":L[204]});
}
} catch($e23172318) {
if(R.isCont($e23172318)) {
var $ss23212322 = {"from":L[204],
"go":function(or_DASH_oper_DASH_772327) {
return $Hor_DASH_oper_DASH_13842328(or_DASH_oper_DASH_772327,if_helper6292203);
}};
$e23172318.stack[R.EXN_STACKHEIGHT++] = $ss23212322;
}
if(R.isPyretException($e23172318)) {
$e23172318.pyretStack.push(L[204]);
}
throw $e23172318;
}
var $ret23232324 = $Hor_DASH_oper_DASH_13842328($z23192320,if_helper6292203);
++R.GAS;
return $ret23232324;
}
} else {
var cont_tail_arg6572331 = R.throwNonBooleanOp(L[219],("first"),("or"),or_DASH_oper_DASH_762299);
if(--R.GAS > 0) {
$z23292330 = R.isFunction(if_helper6292203)?if_helper6292203.app(cont_tail_arg6572331):R.ffi.throwNonFunApp(L[219],if_helper6292203,[cont_tail_arg6572331]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6292203)?if_helper6292203.app(cont_tail_arg6572331):R.ffi.throwNonFunApp(L[219],if_helper6292203,[cont_tail_arg6572331]);
},
"from":L[219]});
}
++R.GAS;
return $z23292330;
}
};
var $Hcont_tail_app13822316 = function(cont_tail_app6642315) {
return cont_tail_app6642315;
};
var $Hor_DASH_oper_DASH_13842328 = function(or_DASH_oper_DASH_772327,if_helper6292203) {
var anf_if6622348 = R.isBoolean(or_DASH_oper_DASH_772327);
if(R.isPyretTrue(anf_if6622348)) {
var $z23352336 = D;
var $f23412342 = function(_) {
return R.isFunction(if_helper6292203)?if_helper6292203.app(or_DASH_oper_DASH_772327):R.ffi.throwNonFunApp(L[204],if_helper6292203,[or_DASH_oper_DASH_772327]);
};
try {
if(--R.GAS > 0) {
$z23352336 = $f23412342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23412342,
"from":L[204]});
}
} catch($e23332334) {
if(R.isCont($e23332334)) {
var $ss23372338 = {"from":L[204],
"go":function(cont_tail_app6632343) {
return $Hcont_tail_app13832344(cont_tail_app6632343);
}};
$e23332334.stack[R.EXN_STACKHEIGHT++] = $ss23372338;
}
if(R.isPyretException($e23332334)) {
$e23332334.pyretStack.push(L[204]);
}
throw $e23332334;
}
var $ret23392340 = $Hcont_tail_app13832344($z23352336);
++R.GAS;
return $ret23392340;
} else {
var cont_tail_arg6602347 = R.throwNonBooleanOp(L[220],("second"),("or"),or_DASH_oper_DASH_772327);
if(--R.GAS > 0) {
$z23452346 = R.isFunction(if_helper6292203)?if_helper6292203.app(cont_tail_arg6602347):R.ffi.throwNonFunApp(L[220],if_helper6292203,[cont_tail_arg6602347]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6292203)?if_helper6292203.app(cont_tail_arg6602347):R.ffi.throwNonFunApp(L[220],if_helper6292203,[cont_tail_arg6602347]);
},
"from":L[220]});
}
++R.GAS;
return $z23452346;
}
};
var $Hcont_tail_app13832344 = function(cont_tail_app6632343) {
return cont_tail_app6632343;
};
var $Hcont_tail_app13752235 = function(cont_tail_app6502234) {
return cont_tail_app6502234;
};
var $Hanf_arg13792252 = function(anf_arg6472250,anf_fun6422251,if_helper6312233) {
var $z23512352 = D;
var $f23572358 = function(_) {
return R.isFunction(anf_fun6422251)?anf_fun6422251.app(anf_arg6472250):R.ffi.throwNonFunApp(L[212],anf_fun6422251,[anf_arg6472250]);
};
try {
if(--R.GAS > 0) {
$z23512352 = $f23572358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23572358,
"from":L[212]});
}
} catch($e23492350) {
if(R.isCont($e23492350)) {
var $ss23532354 = {"from":L[212],
"go":function(cont_tail_arg6482359) {
return $Hcont_tail_arg13782360(cont_tail_arg6482359,if_helper6312233);
}};
$e23492350.stack[R.EXN_STACKHEIGHT++] = $ss23532354;
}
if(R.isPyretException($e23492350)) {
$e23492350.pyretStack.push(L[212]);
}
throw $e23492350;
}
var $ret23552356 = $Hcont_tail_arg13782360($z23512352,if_helper6312233);
++R.GAS;
return $ret23552356;
};
var $Hcont_tail_arg13782360 = function(cont_tail_arg6482359,if_helper6312233) {
if(--R.GAS > 0) {
$z23612362 = R.isFunction(if_helper6312233)?if_helper6312233.app(cont_tail_arg6482359):R.ffi.throwNonFunApp(L[212],if_helper6312233,[cont_tail_arg6482359]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper6312233)?if_helper6312233.app(cont_tail_arg6482359):R.ffi.throwNonFunApp(L[212],if_helper6312233,[cont_tail_arg6482359]);
},
"from":L[212]});
}
++R.GAS;
return $z23612362;
};
var $Hanf_arg13772269 = function(anf_arg6412268,arg_DASH_722253,link211585) {
var $z23652366 = D;
var $f23712372 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_722253,anf_arg6412268):R.ffi.throwNonFunApp(L[212],link211585.$var,[arg_DASH_722253,anf_arg6412268]);
};
try {
if(--R.GAS > 0) {
$z23652366 = $f23712372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23712372,
"from":L[212]});
}
} catch($e23632364) {
if(R.isCont($e23632364)) {
var $ss23672368 = {"from":L[212],
"go":function(ann_DASH_check_DASH_temp6362373) {
return $Hann_DASH_check_DASH_temp13762374(ann_DASH_check_DASH_temp6362373);
}};
$e23632364.stack[R.EXN_STACKHEIGHT++] = $ss23672368;
}
if(R.isPyretException($e23632364)) {
$e23632364.pyretStack.push(L[212]);
}
throw $e23632364;
}
var $ret23692370 = $Hann_DASH_check_DASH_temp13762374($z23652366);
++R.GAS;
return $ret23692370;
};
var $Hann_DASH_check_DASH_temp13762374 = function(ann_DASH_check_DASH_temp6362373) {
return ann_DASH_check_DASH_temp6362373;
};
var $Hor_DASH_oper_DASH_13742375 = function(or_DASH_oper_DASH_692376,empty191579,f2432377,is_DASH_empty18116,l12442378,l22452379,l32462380,link211585,map3362381) {
var if_helper5952392 = R.makeFunction(function(if_helper_arg5962411) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[221],1,arguments);
}
var if_DASH_682457 = if_helper_arg5962411;
var if_helper5972422 = R.makeFunction(function(if_helper_arg5982462) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[221],1,arguments);
}
var ann_DASH_check_DASH_temp5942463 = if_helper_arg5982462;
return ann_DASH_check_DASH_temp5942463;
});
var anf_if6012461 = R.isBoolean(if_DASH_682457);
if(R.isPyretTrue(anf_if6012461)) {
if(R.isPyretTrue(if_DASH_682457)) {
var $z24142415 = D;
var $f24202421 = function(_) {
return R.isFunction(if_helper5972422)?if_helper5972422.app(empty191579.$var):R.ffi.throwNonFunApp(L[223],if_helper5972422,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z24142415 = $f24202421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24202421,
"from":L[223]});
}
} catch($e24122413) {
if(R.isCont($e24122413)) {
var $ss24162417 = {"from":L[223],
"go":function(cont_tail_app6142423) {
return $Hcont_tail_app13642424(cont_tail_app6142423);
}};
$e24122413.stack[R.EXN_STACKHEIGHT++] = $ss24162417;
}
if(R.isPyretException($e24122413)) {
$e24122413.pyretStack.push(L[223]);
}
throw $e24122413;
}
var $ret24182419 = $Hcont_tail_app13642424($z24142415);
++R.GAS;
return $ret24182419;
} else {
var anf_fun6072439 = R.makeFunction(function(arg_DASH_672441) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[228],1,arguments);
}
var anf_arg6032452 = G(l12442378,"rest",L[232]);
var anf_arg6042453 = G(l22452379,"rest",L[231]);
var anf_arg6052454 = G(l32462380,"rest",L[230]);
var $z24442445 = D;
var $f24502451 = function(_) {
return R.isFunction(map3362381.$var)?map3362381.$var.app(f2432377,anf_arg6032452,anf_arg6042453,anf_arg6052454):R.ffi.throwNonFunApp(L[229],map3362381.$var,[f2432377,anf_arg6032452,anf_arg6042453,anf_arg6052454]);
};
try {
if(--R.GAS > 0) {
$z24442445 = $f24502451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24502451,
"from":L[229]});
}
} catch($e24422443) {
if(R.isCont($e24422443)) {
var $ss24462447 = {"from":L[229],
"go":function(anf_arg6062455) {
return $Hanf_arg13662456(anf_arg6062455,arg_DASH_672441,link211585);
}};
$e24422443.stack[R.EXN_STACKHEIGHT++] = $ss24462447;
}
if(R.isPyretException($e24422443)) {
$e24422443.pyretStack.push(L[229]);
}
throw $e24422443;
}
var $ret24482449 = $Hanf_arg13662456($z24442445,arg_DASH_672441,link211585);
++R.GAS;
return $ret24482449;
});
var anf_arg6082435 = G(l12442378,"first",L[227]);
var anf_arg6092436 = G(l22452379,"first",L[226]);
var anf_arg6102437 = G(l32462380,"first",L[225]);
var $z24272428 = D;
var $f24332434 = function(_) {
return R.isFunction(f2432377)?f2432377.app(anf_arg6082435,anf_arg6092436,anf_arg6102437):R.ffi.throwNonFunApp(L[224],f2432377,[anf_arg6082435,anf_arg6092436,anf_arg6102437]);
};
try {
if(--R.GAS > 0) {
$z24272428 = $f24332434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24332434,
"from":L[224]});
}
} catch($e24252426) {
if(R.isCont($e24252426)) {
var $ss24292430 = {"from":L[224],
"go":function(anf_arg6112438) {
return $Hanf_arg13682440(anf_arg6112438,anf_fun6072439,if_helper5972422);
}};
$e24252426.stack[R.EXN_STACKHEIGHT++] = $ss24292430;
}
if(R.isPyretException($e24252426)) {
$e24252426.pyretStack.push(L[224]);
}
throw $e24252426;
}
var $ret24312432 = $Hanf_arg13682440($z24272428,anf_fun6072439,if_helper5972422);
++R.GAS;
return $ret24312432;
}
} else {
var cont_tail_arg5992460 = R.throwNonBooleanCondition(L[221],("if"),if_DASH_682457);
if(--R.GAS > 0) {
$z24582459 = R.isFunction(if_helper5972422)?if_helper5972422.app(cont_tail_arg5992460):R.ffi.throwNonFunApp(L[221],if_helper5972422,[cont_tail_arg5992460]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5972422)?if_helper5972422.app(cont_tail_arg5992460):R.ffi.throwNonFunApp(L[221],if_helper5972422,[cont_tail_arg5992460]);
},
"from":L[221]});
}
++R.GAS;
return $z24582459;
}
});
var anf_if6172410 = R.isBoolean(or_DASH_oper_DASH_692376);
if(R.isPyretTrue(anf_if6172410)) {
if(R.isPyretTrue(or_DASH_oper_DASH_692376)) {
var $z23842385 = D;
var $f23902391 = function(_) {
return R.isFunction(if_helper5952392)?if_helper5952392.app((true)):R.ffi.throwNonFunApp(L[221],if_helper5952392,[(true)]);
};
try {
if(--R.GAS > 0) {
$z23842385 = $f23902391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23902391,
"from":L[221]});
}
} catch($e23822383) {
if(R.isCont($e23822383)) {
var $ss23862387 = {"from":L[221],
"go":function(cont_tail_app6262393) {
return $Hcont_tail_app13692394(cont_tail_app6262393);
}};
$e23822383.stack[R.EXN_STACKHEIGHT++] = $ss23862387;
}
if(R.isPyretException($e23822383)) {
$e23822383.pyretStack.push(L[221]);
}
throw $e23822383;
}
var $ret23882389 = $Hcont_tail_app13692394($z23842385);
++R.GAS;
return $ret23882389;
} else {
var $z23972398 = D;
var $f24032404 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22452379):R.ffi.throwNonFunApp(L[221],is_DASH_empty18116.$var,[l22452379]);
};
try {
if(--R.GAS > 0) {
$z23972398 = $f24032404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24032404,
"from":L[221]});
}
} catch($e23952396) {
if(R.isCont($e23952396)) {
var $ss23992400 = {"from":L[221],
"go":function(or_DASH_oper_DASH_702405) {
return $Hor_DASH_oper_DASH_13732406(or_DASH_oper_DASH_702405,if_helper5952392,is_DASH_empty18116,l32462380);
}};
$e23952396.stack[R.EXN_STACKHEIGHT++] = $ss23992400;
}
if(R.isPyretException($e23952396)) {
$e23952396.pyretStack.push(L[221]);
}
throw $e23952396;
}
var $ret24012402 = $Hor_DASH_oper_DASH_13732406($z23972398,if_helper5952392,is_DASH_empty18116,l32462380);
++R.GAS;
return $ret24012402;
}
} else {
var cont_tail_arg6152409 = R.throwNonBooleanOp(L[222],("first"),("or"),or_DASH_oper_DASH_692376);
if(--R.GAS > 0) {
$z24072408 = R.isFunction(if_helper5952392)?if_helper5952392.app(cont_tail_arg6152409):R.ffi.throwNonFunApp(L[222],if_helper5952392,[cont_tail_arg6152409]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5952392)?if_helper5952392.app(cont_tail_arg6152409):R.ffi.throwNonFunApp(L[222],if_helper5952392,[cont_tail_arg6152409]);
},
"from":L[222]});
}
++R.GAS;
return $z24072408;
}
};
var $Hcont_tail_app13692394 = function(cont_tail_app6262393) {
return cont_tail_app6262393;
};
var $Hor_DASH_oper_DASH_13732406 = function(or_DASH_oper_DASH_702405,if_helper5952392,is_DASH_empty18116,l32462380) {
var anf_if6202491 = R.isBoolean(or_DASH_oper_DASH_702405);
if(R.isPyretTrue(anf_if6202491)) {
if(R.isPyretTrue(or_DASH_oper_DASH_702405)) {
var $z24662467 = D;
var $f24722473 = function(_) {
return R.isFunction(if_helper5952392)?if_helper5952392.app((true)):R.ffi.throwNonFunApp(L[221],if_helper5952392,[(true)]);
};
try {
if(--R.GAS > 0) {
$z24662467 = $f24722473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24722473,
"from":L[221]});
}
} catch($e24642465) {
if(R.isCont($e24642465)) {
var $ss24682469 = {"from":L[221],
"go":function(cont_tail_app6252474) {
return $Hcont_tail_app13702475(cont_tail_app6252474);
}};
$e24642465.stack[R.EXN_STACKHEIGHT++] = $ss24682469;
}
if(R.isPyretException($e24642465)) {
$e24642465.pyretStack.push(L[221]);
}
throw $e24642465;
}
var $ret24702471 = $Hcont_tail_app13702475($z24662467);
++R.GAS;
return $ret24702471;
} else {
var $z24782479 = D;
var $f24842485 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l32462380):R.ffi.throwNonFunApp(L[221],is_DASH_empty18116.$var,[l32462380]);
};
try {
if(--R.GAS > 0) {
$z24782479 = $f24842485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24842485,
"from":L[221]});
}
} catch($e24762477) {
if(R.isCont($e24762477)) {
var $ss24802481 = {"from":L[221],
"go":function(or_DASH_oper_DASH_712486) {
return $Hor_DASH_oper_DASH_13722487(or_DASH_oper_DASH_712486,if_helper5952392);
}};
$e24762477.stack[R.EXN_STACKHEIGHT++] = $ss24802481;
}
if(R.isPyretException($e24762477)) {
$e24762477.pyretStack.push(L[221]);
}
throw $e24762477;
}
var $ret24822483 = $Hor_DASH_oper_DASH_13722487($z24782479,if_helper5952392);
++R.GAS;
return $ret24822483;
}
} else {
var cont_tail_arg6182490 = R.throwNonBooleanOp(L[233],("first"),("or"),or_DASH_oper_DASH_702405);
if(--R.GAS > 0) {
$z24882489 = R.isFunction(if_helper5952392)?if_helper5952392.app(cont_tail_arg6182490):R.ffi.throwNonFunApp(L[233],if_helper5952392,[cont_tail_arg6182490]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5952392)?if_helper5952392.app(cont_tail_arg6182490):R.ffi.throwNonFunApp(L[233],if_helper5952392,[cont_tail_arg6182490]);
},
"from":L[233]});
}
++R.GAS;
return $z24882489;
}
};
var $Hcont_tail_app13702475 = function(cont_tail_app6252474) {
return cont_tail_app6252474;
};
var $Hor_DASH_oper_DASH_13722487 = function(or_DASH_oper_DASH_712486,if_helper5952392) {
var anf_if6232507 = R.isBoolean(or_DASH_oper_DASH_712486);
if(R.isPyretTrue(anf_if6232507)) {
var $z24942495 = D;
var $f25002501 = function(_) {
return R.isFunction(if_helper5952392)?if_helper5952392.app(or_DASH_oper_DASH_712486):R.ffi.throwNonFunApp(L[221],if_helper5952392,[or_DASH_oper_DASH_712486]);
};
try {
if(--R.GAS > 0) {
$z24942495 = $f25002501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25002501,
"from":L[221]});
}
} catch($e24922493) {
if(R.isCont($e24922493)) {
var $ss24962497 = {"from":L[221],
"go":function(cont_tail_app6242502) {
return $Hcont_tail_app13712503(cont_tail_app6242502);
}};
$e24922493.stack[R.EXN_STACKHEIGHT++] = $ss24962497;
}
if(R.isPyretException($e24922493)) {
$e24922493.pyretStack.push(L[221]);
}
throw $e24922493;
}
var $ret24982499 = $Hcont_tail_app13712503($z24942495);
++R.GAS;
return $ret24982499;
} else {
var cont_tail_arg6212506 = R.throwNonBooleanOp(L[234],("second"),("or"),or_DASH_oper_DASH_712486);
if(--R.GAS > 0) {
$z25042505 = R.isFunction(if_helper5952392)?if_helper5952392.app(cont_tail_arg6212506):R.ffi.throwNonFunApp(L[234],if_helper5952392,[cont_tail_arg6212506]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5952392)?if_helper5952392.app(cont_tail_arg6212506):R.ffi.throwNonFunApp(L[234],if_helper5952392,[cont_tail_arg6212506]);
},
"from":L[234]});
}
++R.GAS;
return $z25042505;
}
};
var $Hcont_tail_app13712503 = function(cont_tail_app6242502) {
return cont_tail_app6242502;
};
var $Hcont_tail_app13642424 = function(cont_tail_app6142423) {
return cont_tail_app6142423;
};
var $Hanf_arg13682440 = function(anf_arg6112438,anf_fun6072439,if_helper5972422) {
var $z25102511 = D;
var $f25162517 = function(_) {
return R.isFunction(anf_fun6072439)?anf_fun6072439.app(anf_arg6112438):R.ffi.throwNonFunApp(L[228],anf_fun6072439,[anf_arg6112438]);
};
try {
if(--R.GAS > 0) {
$z25102511 = $f25162517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25162517,
"from":L[228]});
}
} catch($e25082509) {
if(R.isCont($e25082509)) {
var $ss25122513 = {"from":L[228],
"go":function(cont_tail_arg6122518) {
return $Hcont_tail_arg13672519(cont_tail_arg6122518,if_helper5972422);
}};
$e25082509.stack[R.EXN_STACKHEIGHT++] = $ss25122513;
}
if(R.isPyretException($e25082509)) {
$e25082509.pyretStack.push(L[228]);
}
throw $e25082509;
}
var $ret25142515 = $Hcont_tail_arg13672519($z25102511,if_helper5972422);
++R.GAS;
return $ret25142515;
};
var $Hcont_tail_arg13672519 = function(cont_tail_arg6122518,if_helper5972422) {
if(--R.GAS > 0) {
$z25202521 = R.isFunction(if_helper5972422)?if_helper5972422.app(cont_tail_arg6122518):R.ffi.throwNonFunApp(L[228],if_helper5972422,[cont_tail_arg6122518]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5972422)?if_helper5972422.app(cont_tail_arg6122518):R.ffi.throwNonFunApp(L[228],if_helper5972422,[cont_tail_arg6122518]);
},
"from":L[228]});
}
++R.GAS;
return $z25202521;
};
var $Hanf_arg13662456 = function(anf_arg6062455,arg_DASH_672441,link211585) {
var $z25242525 = D;
var $f25302531 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_672441,anf_arg6062455):R.ffi.throwNonFunApp(L[228],link211585.$var,[arg_DASH_672441,anf_arg6062455]);
};
try {
if(--R.GAS > 0) {
$z25242525 = $f25302531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25302531,
"from":L[228]});
}
} catch($e25222523) {
if(R.isCont($e25222523)) {
var $ss25262527 = {"from":L[228],
"go":function(ann_DASH_check_DASH_temp6022532) {
return $Hann_DASH_check_DASH_temp13652533(ann_DASH_check_DASH_temp6022532);
}};
$e25222523.stack[R.EXN_STACKHEIGHT++] = $ss25262527;
}
if(R.isPyretException($e25222523)) {
$e25222523.pyretStack.push(L[228]);
}
throw $e25222523;
}
var $ret25282529 = $Hann_DASH_check_DASH_temp13652533($z25242525);
++R.GAS;
return $ret25282529;
};
var $Hann_DASH_check_DASH_temp13652533 = function(ann_DASH_check_DASH_temp6022532) {
return ann_DASH_check_DASH_temp6022532;
};
var $Hor_DASH_oper_DASH_13632534 = function(or_DASH_oper_DASH_652535,empty191579,f2362536,is_DASH_empty18116,l12372537,l22382538,link211585,map2352539) {
var if_helper5672550 = R.makeFunction(function(if_helper_arg5682569) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[235],1,arguments);
}
var if_DASH_642613 = if_helper_arg5682569;
var if_helper5692580 = R.makeFunction(function(if_helper_arg5702618) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[235],1,arguments);
}
var ann_DASH_check_DASH_temp5662619 = if_helper_arg5702618;
return ann_DASH_check_DASH_temp5662619;
});
var anf_if5732617 = R.isBoolean(if_DASH_642613);
if(R.isPyretTrue(anf_if5732617)) {
if(R.isPyretTrue(if_DASH_642613)) {
var $z25722573 = D;
var $f25782579 = function(_) {
return R.isFunction(if_helper5692580)?if_helper5692580.app(empty191579.$var):R.ffi.throwNonFunApp(L[237],if_helper5692580,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z25722573 = $f25782579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25782579,
"from":L[237]});
}
} catch($e25702571) {
if(R.isCont($e25702571)) {
var $ss25742575 = {"from":L[237],
"go":function(cont_tail_app5842581) {
return $Hcont_tail_app13552582(cont_tail_app5842581);
}};
$e25702571.stack[R.EXN_STACKHEIGHT++] = $ss25742575;
}
if(R.isPyretException($e25702571)) {
$e25702571.pyretStack.push(L[237]);
}
throw $e25702571;
}
var $ret25762577 = $Hcont_tail_app13552582($z25722573);
++R.GAS;
return $ret25762577;
} else {
var anf_fun5782596 = R.makeFunction(function(arg_DASH_632598) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[241],1,arguments);
}
var anf_arg5752609 = G(l12372537,"rest",L[244]);
var anf_arg5762610 = G(l22382538,"rest",L[243]);
var $z26012602 = D;
var $f26072608 = function(_) {
return R.isFunction(map2352539.$var)?map2352539.$var.app(f2362536,anf_arg5752609,anf_arg5762610):R.ffi.throwNonFunApp(L[242],map2352539.$var,[f2362536,anf_arg5752609,anf_arg5762610]);
};
try {
if(--R.GAS > 0) {
$z26012602 = $f26072608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26072608,
"from":L[242]});
}
} catch($e25992600) {
if(R.isCont($e25992600)) {
var $ss26032604 = {"from":L[242],
"go":function(anf_arg5772611) {
return $Hanf_arg13572612(anf_arg5772611,arg_DASH_632598,link211585);
}};
$e25992600.stack[R.EXN_STACKHEIGHT++] = $ss26032604;
}
if(R.isPyretException($e25992600)) {
$e25992600.pyretStack.push(L[242]);
}
throw $e25992600;
}
var $ret26052606 = $Hanf_arg13572612($z26012602,arg_DASH_632598,link211585);
++R.GAS;
return $ret26052606;
});
var anf_arg5792593 = G(l12372537,"first",L[240]);
var anf_arg5802594 = G(l22382538,"first",L[239]);
var $z25852586 = D;
var $f25912592 = function(_) {
return R.isFunction(f2362536)?f2362536.app(anf_arg5792593,anf_arg5802594):R.ffi.throwNonFunApp(L[238],f2362536,[anf_arg5792593,anf_arg5802594]);
};
try {
if(--R.GAS > 0) {
$z25852586 = $f25912592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25912592,
"from":L[238]});
}
} catch($e25832584) {
if(R.isCont($e25832584)) {
var $ss25872588 = {"from":L[238],
"go":function(anf_arg5812595) {
return $Hanf_arg13592597(anf_arg5812595,anf_fun5782596,if_helper5692580);
}};
$e25832584.stack[R.EXN_STACKHEIGHT++] = $ss25872588;
}
if(R.isPyretException($e25832584)) {
$e25832584.pyretStack.push(L[238]);
}
throw $e25832584;
}
var $ret25892590 = $Hanf_arg13592597($z25852586,anf_fun5782596,if_helper5692580);
++R.GAS;
return $ret25892590;
}
} else {
var cont_tail_arg5712616 = R.throwNonBooleanCondition(L[235],("if"),if_DASH_642613);
if(--R.GAS > 0) {
$z26142615 = R.isFunction(if_helper5692580)?if_helper5692580.app(cont_tail_arg5712616):R.ffi.throwNonFunApp(L[235],if_helper5692580,[cont_tail_arg5712616]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5692580)?if_helper5692580.app(cont_tail_arg5712616):R.ffi.throwNonFunApp(L[235],if_helper5692580,[cont_tail_arg5712616]);
},
"from":L[235]});
}
++R.GAS;
return $z26142615;
}
});
var anf_if5872568 = R.isBoolean(or_DASH_oper_DASH_652535);
if(R.isPyretTrue(anf_if5872568)) {
if(R.isPyretTrue(or_DASH_oper_DASH_652535)) {
var $z25422543 = D;
var $f25482549 = function(_) {
return R.isFunction(if_helper5672550)?if_helper5672550.app((true)):R.ffi.throwNonFunApp(L[235],if_helper5672550,[(true)]);
};
try {
if(--R.GAS > 0) {
$z25422543 = $f25482549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25482549,
"from":L[235]});
}
} catch($e25402541) {
if(R.isCont($e25402541)) {
var $ss25442545 = {"from":L[235],
"go":function(cont_tail_app5922551) {
return $Hcont_tail_app13602552(cont_tail_app5922551);
}};
$e25402541.stack[R.EXN_STACKHEIGHT++] = $ss25442545;
}
if(R.isPyretException($e25402541)) {
$e25402541.pyretStack.push(L[235]);
}
throw $e25402541;
}
var $ret25462547 = $Hcont_tail_app13602552($z25422543);
++R.GAS;
return $ret25462547;
} else {
var $z25552556 = D;
var $f25612562 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22382538):R.ffi.throwNonFunApp(L[235],is_DASH_empty18116.$var,[l22382538]);
};
try {
if(--R.GAS > 0) {
$z25552556 = $f25612562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25612562,
"from":L[235]});
}
} catch($e25532554) {
if(R.isCont($e25532554)) {
var $ss25572558 = {"from":L[235],
"go":function(or_DASH_oper_DASH_662563) {
return $Hor_DASH_oper_DASH_13622564(or_DASH_oper_DASH_662563,if_helper5672550);
}};
$e25532554.stack[R.EXN_STACKHEIGHT++] = $ss25572558;
}
if(R.isPyretException($e25532554)) {
$e25532554.pyretStack.push(L[235]);
}
throw $e25532554;
}
var $ret25592560 = $Hor_DASH_oper_DASH_13622564($z25552556,if_helper5672550);
++R.GAS;
return $ret25592560;
}
} else {
var cont_tail_arg5852567 = R.throwNonBooleanOp(L[236],("first"),("or"),or_DASH_oper_DASH_652535);
if(--R.GAS > 0) {
$z25652566 = R.isFunction(if_helper5672550)?if_helper5672550.app(cont_tail_arg5852567):R.ffi.throwNonFunApp(L[236],if_helper5672550,[cont_tail_arg5852567]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5672550)?if_helper5672550.app(cont_tail_arg5852567):R.ffi.throwNonFunApp(L[236],if_helper5672550,[cont_tail_arg5852567]);
},
"from":L[236]});
}
++R.GAS;
return $z25652566;
}
};
var $Hcont_tail_app13602552 = function(cont_tail_app5922551) {
return cont_tail_app5922551;
};
var $Hor_DASH_oper_DASH_13622564 = function(or_DASH_oper_DASH_662563,if_helper5672550) {
var anf_if5902635 = R.isBoolean(or_DASH_oper_DASH_662563);
if(R.isPyretTrue(anf_if5902635)) {
var $z26222623 = D;
var $f26282629 = function(_) {
return R.isFunction(if_helper5672550)?if_helper5672550.app(or_DASH_oper_DASH_662563):R.ffi.throwNonFunApp(L[235],if_helper5672550,[or_DASH_oper_DASH_662563]);
};
try {
if(--R.GAS > 0) {
$z26222623 = $f26282629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26282629,
"from":L[235]});
}
} catch($e26202621) {
if(R.isCont($e26202621)) {
var $ss26242625 = {"from":L[235],
"go":function(cont_tail_app5912630) {
return $Hcont_tail_app13612631(cont_tail_app5912630);
}};
$e26202621.stack[R.EXN_STACKHEIGHT++] = $ss26242625;
}
if(R.isPyretException($e26202621)) {
$e26202621.pyretStack.push(L[235]);
}
throw $e26202621;
}
var $ret26262627 = $Hcont_tail_app13612631($z26222623);
++R.GAS;
return $ret26262627;
} else {
var cont_tail_arg5882634 = R.throwNonBooleanOp(L[245],("second"),("or"),or_DASH_oper_DASH_662563);
if(--R.GAS > 0) {
$z26322633 = R.isFunction(if_helper5672550)?if_helper5672550.app(cont_tail_arg5882634):R.ffi.throwNonFunApp(L[245],if_helper5672550,[cont_tail_arg5882634]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5672550)?if_helper5672550.app(cont_tail_arg5882634):R.ffi.throwNonFunApp(L[245],if_helper5672550,[cont_tail_arg5882634]);
},
"from":L[245]});
}
++R.GAS;
return $z26322633;
}
};
var $Hcont_tail_app13612631 = function(cont_tail_app5912630) {
return cont_tail_app5912630;
};
var $Hcont_tail_app13552582 = function(cont_tail_app5842581) {
return cont_tail_app5842581;
};
var $Hanf_arg13592597 = function(anf_arg5812595,anf_fun5782596,if_helper5692580) {
var $z26382639 = D;
var $f26442645 = function(_) {
return R.isFunction(anf_fun5782596)?anf_fun5782596.app(anf_arg5812595):R.ffi.throwNonFunApp(L[241],anf_fun5782596,[anf_arg5812595]);
};
try {
if(--R.GAS > 0) {
$z26382639 = $f26442645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26442645,
"from":L[241]});
}
} catch($e26362637) {
if(R.isCont($e26362637)) {
var $ss26402641 = {"from":L[241],
"go":function(cont_tail_arg5822646) {
return $Hcont_tail_arg13582647(cont_tail_arg5822646,if_helper5692580);
}};
$e26362637.stack[R.EXN_STACKHEIGHT++] = $ss26402641;
}
if(R.isPyretException($e26362637)) {
$e26362637.pyretStack.push(L[241]);
}
throw $e26362637;
}
var $ret26422643 = $Hcont_tail_arg13582647($z26382639,if_helper5692580);
++R.GAS;
return $ret26422643;
};
var $Hcont_tail_arg13582647 = function(cont_tail_arg5822646,if_helper5692580) {
if(--R.GAS > 0) {
$z26482649 = R.isFunction(if_helper5692580)?if_helper5692580.app(cont_tail_arg5822646):R.ffi.throwNonFunApp(L[241],if_helper5692580,[cont_tail_arg5822646]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5692580)?if_helper5692580.app(cont_tail_arg5822646):R.ffi.throwNonFunApp(L[241],if_helper5692580,[cont_tail_arg5822646]);
},
"from":L[241]});
}
++R.GAS;
return $z26482649;
};
var $Hanf_arg13572612 = function(anf_arg5772611,arg_DASH_632598,link211585) {
var $z26522653 = D;
var $f26582659 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_632598,anf_arg5772611):R.ffi.throwNonFunApp(L[241],link211585.$var,[arg_DASH_632598,anf_arg5772611]);
};
try {
if(--R.GAS > 0) {
$z26522653 = $f26582659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26582659,
"from":L[241]});
}
} catch($e26502651) {
if(R.isCont($e26502651)) {
var $ss26542655 = {"from":L[241],
"go":function(ann_DASH_check_DASH_temp5742660) {
return $Hann_DASH_check_DASH_temp13562661(ann_DASH_check_DASH_temp5742660);
}};
$e26502651.stack[R.EXN_STACKHEIGHT++] = $ss26542655;
}
if(R.isPyretException($e26502651)) {
$e26502651.pyretStack.push(L[241]);
}
throw $e26502651;
}
var $ret26562657 = $Hann_DASH_check_DASH_temp13562661($z26522653);
++R.GAS;
return $ret26562657;
};
var $Hann_DASH_check_DASH_temp13562661 = function(ann_DASH_check_DASH_temp5742660) {
return ann_DASH_check_DASH_temp5742660;
};
var $Hif_DASH_13542662 = function(if_DASH_622663,empty191579,f2312664,link211585,lst2322665,map342666) {
var if_helper5512677 = R.makeFunction(function(if_helper_arg5522712) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[252],1,arguments);
}
var ann_DASH_check_DASH_temp5502713 = if_helper_arg5522712;
return ann_DASH_check_DASH_temp5502713;
});
var anf_if5552711 = R.isBoolean(if_DASH_622663);
if(R.isPyretTrue(anf_if5552711)) {
if(R.isPyretTrue(if_DASH_622663)) {
var $z26692670 = D;
var $f26752676 = function(_) {
return R.isFunction(if_helper5512677)?if_helper5512677.app(empty191579.$var):R.ffi.throwNonFunApp(L[246],if_helper5512677,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z26692670 = $f26752676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26752676,
"from":L[246]});
}
} catch($e26672668) {
if(R.isCont($e26672668)) {
var $ss26712672 = {"from":L[246],
"go":function(cont_tail_app5642678) {
return $Hcont_tail_app13492679(cont_tail_app5642678);
}};
$e26672668.stack[R.EXN_STACKHEIGHT++] = $ss26712672;
}
if(R.isPyretException($e26672668)) {
$e26672668.pyretStack.push(L[246]);
}
throw $e26672668;
}
var $ret26732674 = $Hcont_tail_app13492679($z26692670);
++R.GAS;
return $ret26732674;
} else {
var anf_fun5592692 = R.makeFunction(function(arg_DASH_612694) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[249],1,arguments);
}
var anf_arg5572705 = G(lst2322665,"rest",L[251]);
var $z26972698 = D;
var $f27032704 = function(_) {
return R.isFunction(map342666.$var)?map342666.$var.app(f2312664,anf_arg5572705):R.ffi.throwNonFunApp(L[250],map342666.$var,[f2312664,anf_arg5572705]);
};
try {
if(--R.GAS > 0) {
$z26972698 = $f27032704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27032704,
"from":L[250]});
}
} catch($e26952696) {
if(R.isCont($e26952696)) {
var $ss26992700 = {"from":L[250],
"go":function(anf_arg5582706) {
return $Hanf_arg13512707(anf_arg5582706,arg_DASH_612694,link211585);
}};
$e26952696.stack[R.EXN_STACKHEIGHT++] = $ss26992700;
}
if(R.isPyretException($e26952696)) {
$e26952696.pyretStack.push(L[250]);
}
throw $e26952696;
}
var $ret27012702 = $Hanf_arg13512707($z26972698,arg_DASH_612694,link211585);
++R.GAS;
return $ret27012702;
});
var anf_arg5602690 = G(lst2322665,"first",L[248]);
var $z26822683 = D;
var $f26882689 = function(_) {
return R.isFunction(f2312664)?f2312664.app(anf_arg5602690):R.ffi.throwNonFunApp(L[247],f2312664,[anf_arg5602690]);
};
try {
if(--R.GAS > 0) {
$z26822683 = $f26882689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26882689,
"from":L[247]});
}
} catch($e26802681) {
if(R.isCont($e26802681)) {
var $ss26842685 = {"from":L[247],
"go":function(anf_arg5612691) {
return $Hanf_arg13532693(anf_arg5612691,anf_fun5592692,if_helper5512677);
}};
$e26802681.stack[R.EXN_STACKHEIGHT++] = $ss26842685;
}
if(R.isPyretException($e26802681)) {
$e26802681.pyretStack.push(L[247]);
}
throw $e26802681;
}
var $ret26862687 = $Hanf_arg13532693($z26822683,anf_fun5592692,if_helper5512677);
++R.GAS;
return $ret26862687;
}
} else {
var cont_tail_arg5532710 = R.throwNonBooleanCondition(L[252],("if"),if_DASH_622663);
if(--R.GAS > 0) {
$z27082709 = R.isFunction(if_helper5512677)?if_helper5512677.app(cont_tail_arg5532710):R.ffi.throwNonFunApp(L[252],if_helper5512677,[cont_tail_arg5532710]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5512677)?if_helper5512677.app(cont_tail_arg5532710):R.ffi.throwNonFunApp(L[252],if_helper5512677,[cont_tail_arg5532710]);
},
"from":L[252]});
}
++R.GAS;
return $z27082709;
}
};
var $Hcont_tail_app13492679 = function(cont_tail_app5642678) {
return cont_tail_app5642678;
};
var $Hanf_arg13532693 = function(anf_arg5612691,anf_fun5592692,if_helper5512677) {
var $z27162717 = D;
var $f27222723 = function(_) {
return R.isFunction(anf_fun5592692)?anf_fun5592692.app(anf_arg5612691):R.ffi.throwNonFunApp(L[249],anf_fun5592692,[anf_arg5612691]);
};
try {
if(--R.GAS > 0) {
$z27162717 = $f27222723();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27222723,
"from":L[249]});
}
} catch($e27142715) {
if(R.isCont($e27142715)) {
var $ss27182719 = {"from":L[249],
"go":function(cont_tail_arg5622724) {
return $Hcont_tail_arg13522725(cont_tail_arg5622724,if_helper5512677);
}};
$e27142715.stack[R.EXN_STACKHEIGHT++] = $ss27182719;
}
if(R.isPyretException($e27142715)) {
$e27142715.pyretStack.push(L[249]);
}
throw $e27142715;
}
var $ret27202721 = $Hcont_tail_arg13522725($z27162717,if_helper5512677);
++R.GAS;
return $ret27202721;
};
var $Hcont_tail_arg13522725 = function(cont_tail_arg5622724,if_helper5512677) {
if(--R.GAS > 0) {
$z27262727 = R.isFunction(if_helper5512677)?if_helper5512677.app(cont_tail_arg5622724):R.ffi.throwNonFunApp(L[249],if_helper5512677,[cont_tail_arg5622724]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5512677)?if_helper5512677.app(cont_tail_arg5622724):R.ffi.throwNonFunApp(L[249],if_helper5512677,[cont_tail_arg5622724]);
},
"from":L[249]});
}
++R.GAS;
return $z27262727;
};
var $Hanf_arg13512707 = function(anf_arg5582706,arg_DASH_612694,link211585) {
var $z27302731 = D;
var $f27362737 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_612694,anf_arg5582706):R.ffi.throwNonFunApp(L[249],link211585.$var,[arg_DASH_612694,anf_arg5582706]);
};
try {
if(--R.GAS > 0) {
$z27302731 = $f27362737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27362737,
"from":L[249]});
}
} catch($e27282729) {
if(R.isCont($e27282729)) {
var $ss27322733 = {"from":L[249],
"go":function(ann_DASH_check_DASH_temp5562738) {
return $Hann_DASH_check_DASH_temp13502739(ann_DASH_check_DASH_temp5562738);
}};
$e27282729.stack[R.EXN_STACKHEIGHT++] = $ss27322733;
}
if(R.isPyretException($e27282729)) {
$e27282729.pyretStack.push(L[249]);
}
throw $e27282729;
}
var $ret27342735 = $Hann_DASH_check_DASH_temp13502739($z27302731);
++R.GAS;
return $ret27342735;
};
var $Hann_DASH_check_DASH_temp13502739 = function(ann_DASH_check_DASH_temp5562738) {
return ann_DASH_check_DASH_temp5562738;
};
var $Hann_DASH_check_DASH_temp13482740 = function(ann_DASH_check_DASH_temp5182741,$type$Boolean13) {
return ann_DASH_check_DASH_temp5182741;
};
var $Hor_DASH_oper_DASH_13472742 = function(or_DASH_oper_DASH_592743,f2152744,help2182745,is_DASH_empty18116,l12192746,l22202747) {
var if_helper5202758 = R.makeFunction(function(if_helper_arg5212777) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[253],1,arguments);
}
var if_DASH_582805 = if_helper_arg5212777;
var if_helper5222788 = R.makeFunction(function(if_helper_arg5232810) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[253],1,arguments);
}
var ann_DASH_check_DASH_temp5192811 = if_helper_arg5232810;
return ann_DASH_check_DASH_temp5192811;
});
var anf_if5262809 = R.isBoolean(if_DASH_582805);
if(R.isPyretTrue(anf_if5262809)) {
if(R.isPyretTrue(if_DASH_582805)) {
var $z27802781 = D;
var $f27862787 = function(_) {
return R.isFunction(if_helper5222788)?if_helper5222788.app((true)):R.ffi.throwNonFunApp(L[255],if_helper5222788,[(true)]);
};
try {
if(--R.GAS > 0) {
$z27802781 = $f27862787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27862787,
"from":L[255]});
}
} catch($e27782779) {
if(R.isCont($e27782779)) {
var $ss27822783 = {"from":L[255],
"go":function(cont_tail_app5392789) {
return $Hcont_tail_app13392790(cont_tail_app5392789);
}};
$e27782779.stack[R.EXN_STACKHEIGHT++] = $ss27822783;
}
if(R.isPyretException($e27782779)) {
$e27782779.pyretStack.push(L[255]);
}
throw $e27782779;
}
var $ret27842785 = $Hcont_tail_app13392790($z27802781);
++R.GAS;
return $ret27842785;
} else {
var anf_arg5272801 = G(l12192746,"first",L[258]);
var anf_arg5282802 = G(l22202747,"first",L[257]);
var $z27932794 = D;
var $f27992800 = function(_) {
return R.isFunction(f2152744)?f2152744.app(anf_arg5272801,anf_arg5282802):R.ffi.throwNonFunApp(L[256],f2152744,[anf_arg5272801,anf_arg5282802]);
};
try {
if(--R.GAS > 0) {
$z27932794 = $f27992800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27992800,
"from":L[256]});
}
} catch($e27912792) {
if(R.isCont($e27912792)) {
var $ss27952796 = {"from":L[256],
"go":function(and_DASH_oper_DASH_562803) {
return $Hand_DASH_oper_DASH_13432804(and_DASH_oper_DASH_562803,help2182745,if_helper5222788,l12192746,l22202747);
}};
$e27912792.stack[R.EXN_STACKHEIGHT++] = $ss27952796;
}
if(R.isPyretException($e27912792)) {
$e27912792.pyretStack.push(L[256]);
}
throw $e27912792;
}
var $ret27972798 = $Hand_DASH_oper_DASH_13432804($z27932794,help2182745,if_helper5222788,l12192746,l22202747);
++R.GAS;
return $ret27972798;
}
} else {
var cont_tail_arg5242808 = R.throwNonBooleanCondition(L[253],("if"),if_DASH_582805);
if(--R.GAS > 0) {
$z28062807 = R.isFunction(if_helper5222788)?if_helper5222788.app(cont_tail_arg5242808):R.ffi.throwNonFunApp(L[253],if_helper5222788,[cont_tail_arg5242808]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5222788)?if_helper5222788.app(cont_tail_arg5242808):R.ffi.throwNonFunApp(L[253],if_helper5222788,[cont_tail_arg5242808]);
},
"from":L[253]});
}
++R.GAS;
return $z28062807;
}
});
var anf_if5422776 = R.isBoolean(or_DASH_oper_DASH_592743);
if(R.isPyretTrue(anf_if5422776)) {
if(R.isPyretTrue(or_DASH_oper_DASH_592743)) {
var $z27502751 = D;
var $f27562757 = function(_) {
return R.isFunction(if_helper5202758)?if_helper5202758.app((true)):R.ffi.throwNonFunApp(L[253],if_helper5202758,[(true)]);
};
try {
if(--R.GAS > 0) {
$z27502751 = $f27562757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27562757,
"from":L[253]});
}
} catch($e27482749) {
if(R.isCont($e27482749)) {
var $ss27522753 = {"from":L[253],
"go":function(cont_tail_app5472759) {
return $Hcont_tail_app13442760(cont_tail_app5472759);
}};
$e27482749.stack[R.EXN_STACKHEIGHT++] = $ss27522753;
}
if(R.isPyretException($e27482749)) {
$e27482749.pyretStack.push(L[253]);
}
throw $e27482749;
}
var $ret27542755 = $Hcont_tail_app13442760($z27502751);
++R.GAS;
return $ret27542755;
} else {
var $z27632764 = D;
var $f27692770 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l22202747):R.ffi.throwNonFunApp(L[253],is_DASH_empty18116.$var,[l22202747]);
};
try {
if(--R.GAS > 0) {
$z27632764 = $f27692770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27692770,
"from":L[253]});
}
} catch($e27612762) {
if(R.isCont($e27612762)) {
var $ss27652766 = {"from":L[253],
"go":function(or_DASH_oper_DASH_602771) {
return $Hor_DASH_oper_DASH_13462772(or_DASH_oper_DASH_602771,if_helper5202758);
}};
$e27612762.stack[R.EXN_STACKHEIGHT++] = $ss27652766;
}
if(R.isPyretException($e27612762)) {
$e27612762.pyretStack.push(L[253]);
}
throw $e27612762;
}
var $ret27672768 = $Hor_DASH_oper_DASH_13462772($z27632764,if_helper5202758);
++R.GAS;
return $ret27672768;
}
} else {
var cont_tail_arg5402775 = R.throwNonBooleanOp(L[254],("first"),("or"),or_DASH_oper_DASH_592743);
if(--R.GAS > 0) {
$z27732774 = R.isFunction(if_helper5202758)?if_helper5202758.app(cont_tail_arg5402775):R.ffi.throwNonFunApp(L[254],if_helper5202758,[cont_tail_arg5402775]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5202758)?if_helper5202758.app(cont_tail_arg5402775):R.ffi.throwNonFunApp(L[254],if_helper5202758,[cont_tail_arg5402775]);
},
"from":L[254]});
}
++R.GAS;
return $z27732774;
}
};
var $Hcont_tail_app13442760 = function(cont_tail_app5472759) {
return cont_tail_app5472759;
};
var $Hor_DASH_oper_DASH_13462772 = function(or_DASH_oper_DASH_602771,if_helper5202758) {
var anf_if5452827 = R.isBoolean(or_DASH_oper_DASH_602771);
if(R.isPyretTrue(anf_if5452827)) {
var $z28142815 = D;
var $f28202821 = function(_) {
return R.isFunction(if_helper5202758)?if_helper5202758.app(or_DASH_oper_DASH_602771):R.ffi.throwNonFunApp(L[253],if_helper5202758,[or_DASH_oper_DASH_602771]);
};
try {
if(--R.GAS > 0) {
$z28142815 = $f28202821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28202821,
"from":L[253]});
}
} catch($e28122813) {
if(R.isCont($e28122813)) {
var $ss28162817 = {"from":L[253],
"go":function(cont_tail_app5462822) {
return $Hcont_tail_app13452823(cont_tail_app5462822);
}};
$e28122813.stack[R.EXN_STACKHEIGHT++] = $ss28162817;
}
if(R.isPyretException($e28122813)) {
$e28122813.pyretStack.push(L[253]);
}
throw $e28122813;
}
var $ret28182819 = $Hcont_tail_app13452823($z28142815);
++R.GAS;
return $ret28182819;
} else {
var cont_tail_arg5432826 = R.throwNonBooleanOp(L[259],("second"),("or"),or_DASH_oper_DASH_602771);
if(--R.GAS > 0) {
$z28242825 = R.isFunction(if_helper5202758)?if_helper5202758.app(cont_tail_arg5432826):R.ffi.throwNonFunApp(L[259],if_helper5202758,[cont_tail_arg5432826]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5202758)?if_helper5202758.app(cont_tail_arg5432826):R.ffi.throwNonFunApp(L[259],if_helper5202758,[cont_tail_arg5432826]);
},
"from":L[259]});
}
++R.GAS;
return $z28242825;
}
};
var $Hcont_tail_app13452823 = function(cont_tail_app5462822) {
return cont_tail_app5462822;
};
var $Hcont_tail_app13392790 = function(cont_tail_app5392789) {
return cont_tail_app5392789;
};
var $Hand_DASH_oper_DASH_13432804 = function(and_DASH_oper_DASH_562803,help2182745,if_helper5222788,l12192746,l22202747) {
var anf_if5312857 = R.isBoolean(and_DASH_oper_DASH_562803);
if(R.isPyretTrue(anf_if5312857)) {
if(R.isPyretTrue(and_DASH_oper_DASH_562803)) {
var anf_arg5332838 = G(l12192746,"rest",L[261]);
var anf_arg5342839 = G(l22202747,"rest",L[260]);
var $z28302831 = D;
var $f28362837 = function(_) {
return R.isFunction(help2182745.$var)?help2182745.$var.app(anf_arg5332838,anf_arg5342839):R.ffi.throwNonFunApp(L[256],help2182745.$var,[anf_arg5332838,anf_arg5342839]);
};
try {
if(--R.GAS > 0) {
$z28302831 = $f28362837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28362837,
"from":L[256]});
}
} catch($e28282829) {
if(R.isCont($e28282829)) {
var $ss28322833 = {"from":L[256],
"go":function(and_DASH_oper_DASH_572840) {
return $Hand_DASH_oper_DASH_13412841(and_DASH_oper_DASH_572840,if_helper5222788);
}};
$e28282829.stack[R.EXN_STACKHEIGHT++] = $ss28322833;
}
if(R.isPyretException($e28282829)) {
$e28282829.pyretStack.push(L[256]);
}
throw $e28282829;
}
var $ret28342835 = $Hand_DASH_oper_DASH_13412841($z28302831,if_helper5222788);
++R.GAS;
return $ret28342835;
} else {
var $z28442845 = D;
var $f28502851 = function(_) {
return R.isFunction(if_helper5222788)?if_helper5222788.app((false)):R.ffi.throwNonFunApp(L[256],if_helper5222788,[(false)]);
};
try {
if(--R.GAS > 0) {
$z28442845 = $f28502851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28502851,
"from":L[256]});
}
} catch($e28422843) {
if(R.isCont($e28422843)) {
var $ss28462847 = {"from":L[256],
"go":function(cont_tail_app5322852) {
return $Hcont_tail_app13422853(cont_tail_app5322852);
}};
$e28422843.stack[R.EXN_STACKHEIGHT++] = $ss28462847;
}
if(R.isPyretException($e28422843)) {
$e28422843.pyretStack.push(L[256]);
}
throw $e28422843;
}
var $ret28482849 = $Hcont_tail_app13422853($z28442845);
++R.GAS;
return $ret28482849;
}
} else {
var cont_tail_arg5292856 = R.throwNonBooleanOp(L[262],("first"),("and"),and_DASH_oper_DASH_562803);
if(--R.GAS > 0) {
$z28542855 = R.isFunction(if_helper5222788)?if_helper5222788.app(cont_tail_arg5292856):R.ffi.throwNonFunApp(L[262],if_helper5222788,[cont_tail_arg5292856]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5222788)?if_helper5222788.app(cont_tail_arg5292856):R.ffi.throwNonFunApp(L[262],if_helper5222788,[cont_tail_arg5292856]);
},
"from":L[262]});
}
++R.GAS;
return $z28542855;
}
};
var $Hand_DASH_oper_DASH_13412841 = function(and_DASH_oper_DASH_572840,if_helper5222788) {
var anf_if5372873 = R.isBoolean(and_DASH_oper_DASH_572840);
if(R.isPyretTrue(anf_if5372873)) {
var $z28602861 = D;
var $f28662867 = function(_) {
return R.isFunction(if_helper5222788)?if_helper5222788.app(and_DASH_oper_DASH_572840):R.ffi.throwNonFunApp(L[256],if_helper5222788,[and_DASH_oper_DASH_572840]);
};
try {
if(--R.GAS > 0) {
$z28602861 = $f28662867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28662867,
"from":L[256]});
}
} catch($e28582859) {
if(R.isCont($e28582859)) {
var $ss28622863 = {"from":L[256],
"go":function(cont_tail_app5382868) {
return $Hcont_tail_app13402869(cont_tail_app5382868);
}};
$e28582859.stack[R.EXN_STACKHEIGHT++] = $ss28622863;
}
if(R.isPyretException($e28582859)) {
$e28582859.pyretStack.push(L[256]);
}
throw $e28582859;
}
var $ret28642865 = $Hcont_tail_app13402869($z28602861);
++R.GAS;
return $ret28642865;
} else {
var cont_tail_arg5352872 = R.throwNonBooleanOp(L[263],("second"),("and"),and_DASH_oper_DASH_572840);
if(--R.GAS > 0) {
$z28702871 = R.isFunction(if_helper5222788)?if_helper5222788.app(cont_tail_arg5352872):R.ffi.throwNonFunApp(L[263],if_helper5222788,[cont_tail_arg5352872]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5222788)?if_helper5222788.app(cont_tail_arg5352872):R.ffi.throwNonFunApp(L[263],if_helper5222788,[cont_tail_arg5352872]);
},
"from":L[263]});
}
++R.GAS;
return $z28702871;
}
};
var $Hcont_tail_app13402869 = function(cont_tail_app5382868) {
return cont_tail_app5382868;
};
var $Hcont_tail_app13422853 = function(cont_tail_app5322852) {
return cont_tail_app5322852;
};
var $Hann_DASH_check_DASH_temp13382874 = function(ann_DASH_check_DASH_temp4982875,$type$Boolean13) {
return ann_DASH_check_DASH_temp4982875;
};
var $Hif_DASH_13372876 = function(if_DASH_552877,f2072878,help2092879,l2102880) {
var if_helper5002891 = R.makeFunction(function(if_helper_arg5012911) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[267],1,arguments);
}
var ann_DASH_check_DASH_temp4992912 = if_helper_arg5012911;
return ann_DASH_check_DASH_temp4992912;
});
var anf_if5042910 = R.isBoolean(if_DASH_552877);
if(R.isPyretTrue(anf_if5042910)) {
if(R.isPyretTrue(if_DASH_552877)) {
var $z28832884 = D;
var $f28892890 = function(_) {
return R.isFunction(if_helper5002891)?if_helper5002891.app((true)):R.ffi.throwNonFunApp(L[264],if_helper5002891,[(true)]);
};
try {
if(--R.GAS > 0) {
$z28832884 = $f28892890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28892890,
"from":L[264]});
}
} catch($e28812882) {
if(R.isCont($e28812882)) {
var $ss28852886 = {"from":L[264],
"go":function(cont_tail_app5152892) {
return $Hcont_tail_app13322893(cont_tail_app5152892);
}};
$e28812882.stack[R.EXN_STACKHEIGHT++] = $ss28852886;
}
if(R.isPyretException($e28812882)) {
$e28812882.pyretStack.push(L[264]);
}
throw $e28812882;
}
var $ret28872888 = $Hcont_tail_app13322893($z28832884);
++R.GAS;
return $ret28872888;
} else {
var anf_arg5052904 = G(l2102880,"first",L[266]);
var $z28962897 = D;
var $f29022903 = function(_) {
return R.isFunction(f2072878)?f2072878.app(anf_arg5052904):R.ffi.throwNonFunApp(L[265],f2072878,[anf_arg5052904]);
};
try {
if(--R.GAS > 0) {
$z28962897 = $f29022903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29022903,
"from":L[265]});
}
} catch($e28942895) {
if(R.isCont($e28942895)) {
var $ss28982899 = {"from":L[265],
"go":function(and_DASH_oper_DASH_532905) {
return $Hand_DASH_oper_DASH_13362906(and_DASH_oper_DASH_532905,help2092879,if_helper5002891,l2102880);
}};
$e28942895.stack[R.EXN_STACKHEIGHT++] = $ss28982899;
}
if(R.isPyretException($e28942895)) {
$e28942895.pyretStack.push(L[265]);
}
throw $e28942895;
}
var $ret29002901 = $Hand_DASH_oper_DASH_13362906($z28962897,help2092879,if_helper5002891,l2102880);
++R.GAS;
return $ret29002901;
}
} else {
var cont_tail_arg5022909 = R.throwNonBooleanCondition(L[267],("if"),if_DASH_552877);
if(--R.GAS > 0) {
$z29072908 = R.isFunction(if_helper5002891)?if_helper5002891.app(cont_tail_arg5022909):R.ffi.throwNonFunApp(L[267],if_helper5002891,[cont_tail_arg5022909]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5002891)?if_helper5002891.app(cont_tail_arg5022909):R.ffi.throwNonFunApp(L[267],if_helper5002891,[cont_tail_arg5022909]);
},
"from":L[267]});
}
++R.GAS;
return $z29072908;
}
};
var $Hcont_tail_app13322893 = function(cont_tail_app5152892) {
return cont_tail_app5152892;
};
var $Hand_DASH_oper_DASH_13362906 = function(and_DASH_oper_DASH_532905,help2092879,if_helper5002891,l2102880) {
var anf_if5082941 = R.isBoolean(and_DASH_oper_DASH_532905);
if(R.isPyretTrue(anf_if5082941)) {
if(R.isPyretTrue(and_DASH_oper_DASH_532905)) {
var anf_arg5102923 = G(l2102880,"rest",L[268]);
var $z29152916 = D;
var $f29212922 = function(_) {
return R.isFunction(help2092879.$var)?help2092879.$var.app(anf_arg5102923):R.ffi.throwNonFunApp(L[265],help2092879.$var,[anf_arg5102923]);
};
try {
if(--R.GAS > 0) {
$z29152916 = $f29212922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29212922,
"from":L[265]});
}
} catch($e29132914) {
if(R.isCont($e29132914)) {
var $ss29172918 = {"from":L[265],
"go":function(and_DASH_oper_DASH_542924) {
return $Hand_DASH_oper_DASH_13342925(and_DASH_oper_DASH_542924,if_helper5002891);
}};
$e29132914.stack[R.EXN_STACKHEIGHT++] = $ss29172918;
}
if(R.isPyretException($e29132914)) {
$e29132914.pyretStack.push(L[265]);
}
throw $e29132914;
}
var $ret29192920 = $Hand_DASH_oper_DASH_13342925($z29152916,if_helper5002891);
++R.GAS;
return $ret29192920;
} else {
var $z29282929 = D;
var $f29342935 = function(_) {
return R.isFunction(if_helper5002891)?if_helper5002891.app((false)):R.ffi.throwNonFunApp(L[265],if_helper5002891,[(false)]);
};
try {
if(--R.GAS > 0) {
$z29282929 = $f29342935();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29342935,
"from":L[265]});
}
} catch($e29262927) {
if(R.isCont($e29262927)) {
var $ss29302931 = {"from":L[265],
"go":function(cont_tail_app5092936) {
return $Hcont_tail_app13352937(cont_tail_app5092936);
}};
$e29262927.stack[R.EXN_STACKHEIGHT++] = $ss29302931;
}
if(R.isPyretException($e29262927)) {
$e29262927.pyretStack.push(L[265]);
}
throw $e29262927;
}
var $ret29322933 = $Hcont_tail_app13352937($z29282929);
++R.GAS;
return $ret29322933;
}
} else {
var cont_tail_arg5062940 = R.throwNonBooleanOp(L[269],("first"),("and"),and_DASH_oper_DASH_532905);
if(--R.GAS > 0) {
$z29382939 = R.isFunction(if_helper5002891)?if_helper5002891.app(cont_tail_arg5062940):R.ffi.throwNonFunApp(L[269],if_helper5002891,[cont_tail_arg5062940]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5002891)?if_helper5002891.app(cont_tail_arg5062940):R.ffi.throwNonFunApp(L[269],if_helper5002891,[cont_tail_arg5062940]);
},
"from":L[269]});
}
++R.GAS;
return $z29382939;
}
};
var $Hand_DASH_oper_DASH_13342925 = function(and_DASH_oper_DASH_542924,if_helper5002891) {
var anf_if5132957 = R.isBoolean(and_DASH_oper_DASH_542924);
if(R.isPyretTrue(anf_if5132957)) {
var $z29442945 = D;
var $f29502951 = function(_) {
return R.isFunction(if_helper5002891)?if_helper5002891.app(and_DASH_oper_DASH_542924):R.ffi.throwNonFunApp(L[265],if_helper5002891,[and_DASH_oper_DASH_542924]);
};
try {
if(--R.GAS > 0) {
$z29442945 = $f29502951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29502951,
"from":L[265]});
}
} catch($e29422943) {
if(R.isCont($e29422943)) {
var $ss29462947 = {"from":L[265],
"go":function(cont_tail_app5142952) {
return $Hcont_tail_app13332953(cont_tail_app5142952);
}};
$e29422943.stack[R.EXN_STACKHEIGHT++] = $ss29462947;
}
if(R.isPyretException($e29422943)) {
$e29422943.pyretStack.push(L[265]);
}
throw $e29422943;
}
var $ret29482949 = $Hcont_tail_app13332953($z29442945);
++R.GAS;
return $ret29482949;
} else {
var cont_tail_arg5112956 = R.throwNonBooleanOp(L[270],("second"),("and"),and_DASH_oper_DASH_542924);
if(--R.GAS > 0) {
$z29542955 = R.isFunction(if_helper5002891)?if_helper5002891.app(cont_tail_arg5112956):R.ffi.throwNonFunApp(L[270],if_helper5002891,[cont_tail_arg5112956]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper5002891)?if_helper5002891.app(cont_tail_arg5112956):R.ffi.throwNonFunApp(L[270],if_helper5002891,[cont_tail_arg5112956]);
},
"from":L[270]});
}
++R.GAS;
return $z29542955;
}
};
var $Hcont_tail_app13332953 = function(cont_tail_app5142952) {
return cont_tail_app5142952;
};
var $Hcont_tail_app13352937 = function(cont_tail_app5092936) {
return cont_tail_app5092936;
};
var $Hanf_arg13312958 = function(anf_arg4962959,is_DASH_some102960,$type$Boolean13) {
var $z29632964 = D;
var $f29692970 = function(_) {
return R.isFunction(is_DASH_some102960)?is_DASH_some102960.app(anf_arg4962959):R.ffi.throwNonFunApp(L[271],is_DASH_some102960,[anf_arg4962959]);
};
try {
if(--R.GAS > 0) {
$z29632964 = $f29692970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29692970,
"from":L[271]});
}
} catch($e29612962) {
if(R.isCont($e29612962)) {
var $ss29652966 = {"from":L[271],
"go":function(ann_DASH_check_DASH_temp4952971) {
return $Hann_DASH_check_DASH_temp13302972(ann_DASH_check_DASH_temp4952971,$type$Boolean13);
}};
$e29612962.stack[R.EXN_STACKHEIGHT++] = $ss29652966;
}
if(R.isPyretException($e29612962)) {
$e29612962.pyretStack.push(L[271]);
}
throw $e29612962;
}
var $ret29672968 = $Hann_DASH_check_DASH_temp13302972($z29632964,$type$Boolean13);
++R.GAS;
return $ret29672968;
};
var $Hann_DASH_check_DASH_temp13302972 = function(ann_DASH_check_DASH_temp4952971,$type$Boolean13) {
return ann_DASH_check_DASH_temp4952971;
};
var $Hwhen_DASH_13292973 = function(when_DASH_492974,List525,empty191579,link211585,lst1922975,n1912976,_minus5,nothing8,raise9) {
var if_helper4642988 = R.makeFunction(function(if_helper_arg4653006) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[273],1,arguments);
}
if_helper_arg4653006;
var prefix1933020 = {"$var":empty191579.$var,
"$name":"prefix"};
var suffix1943021 = {"$var":empty191579.$var,
"$name":"suffix"};
var help1953007 = {"$var":D,
"$name":"help"};
var anf_assign4883008 = R.makeFunction(function(ind1963023,l1973024) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[276],2,arguments);
}
var if_DASH_523074 = R.equiv(ind1963023,(0));
var if_helper4673027 = R.makeFunction(function(if_helper_arg4683079) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[282],1,arguments);
}
var ann_DASH_check_DASH_temp4663080 = if_helper_arg4683079;
return ann_DASH_check_DASH_temp4663080;
});
var anf_if4713078 = R.isBoolean(if_DASH_523074);
if(R.isPyretTrue(anf_if4713078)) {
if(R.isPyretTrue(if_DASH_523074)) {
var cont_tail_arg4863028 = suffix1943021.$var = l1973024;
if(--R.GAS > 0) {
$z30253026 = R.isFunction(if_helper4673027)?if_helper4673027.app(cont_tail_arg4863028):R.ffi.throwNonFunApp(L[277],if_helper4673027,[cont_tail_arg4863028]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4673027)?if_helper4673027.app(cont_tail_arg4863028):R.ffi.throwNonFunApp(L[277],if_helper4673027,[cont_tail_arg4863028]);
},
"from":L[277]});
}
++R.GAS;
return $z30253026;
} else {
var cases_DASH_val513073 = l1973024;
var anf_fun4723039 = G(cases_DASH_val513073,"_match",L[278]);
var anf_obj4743045 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[281],0,arguments);
}
var $z30633064 = D;
var $f30693070 = function(_) {
return R.isFunction(raise9)?raise9.app(("Index too large")):R.ffi.throwNonFunApp(L[281],raise9,[("Index too large")]);
};
try {
if(--R.GAS > 0) {
$z30633064 = $f30693070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30693070,
"from":L[281]});
}
} catch($e30613062) {
if(R.isCont($e30613062)) {
var $ss30653066 = {"from":L[281],
"go":function(ann_DASH_check_DASH_temp4733071) {
return $Hann_DASH_check_DASH_temp13163072(ann_DASH_check_DASH_temp4733071);
}};
$e30613062.stack[R.EXN_STACKHEIGHT++] = $ss30653066;
}
if(R.isPyretException($e30613062)) {
$e30613062.pyretStack.push(L[281]);
}
throw $e30613062;
}
var $ret30673068 = $Hann_DASH_check_DASH_temp13163072($z30633064);
++R.GAS;
return $ret30673068;
});
var anf_obj4803046 = R.makeFunction(function(fst1983047,rst1993048) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[279],2,arguments);
}
var $z30513052 = D;
var $f30573058 = function(_) {
return R.isFunction(_minus5)?_minus5.app(ind1963023,(1)):R.ffi.throwNonFunApp(L[280],_minus5,[ind1963023,(1)]);
};
try {
if(--R.GAS > 0) {
$z30513052 = $f30573058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30573058,
"from":L[280]});
}
} catch($e30493050) {
if(R.isCont($e30493050)) {
var $ss30533054 = {"from":L[280],
"go":function(anf_arg4763059) {
return $Hanf_arg13213060(anf_arg4763059,fst1983047,help1953007,link211585,prefix1933020,rst1993048);
}};
$e30493050.stack[R.EXN_STACKHEIGHT++] = $ss30533054;
}
if(R.isPyretException($e30493050)) {
$e30493050.pyretStack.push(L[280]);
}
throw $e30493050;
}
var $ret30553056 = $Hanf_arg13213060($z30513052,fst1983047,help1953007,link211585,prefix1933020,rst1993048);
++R.GAS;
return $ret30553056;
});
var anf_arg4813040 = R.makeObject({"empty":anf_obj4743045,
"link":anf_obj4803046});
var anf_arg4833041 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[278],0,arguments);
}
var ann_DASH_check_DASH_temp4823044 = R.throwNoBranchesMatched(L[278],("cases"));
return ann_DASH_check_DASH_temp4823044;
});
var $z30313032 = D;
var $f30373038 = function(_) {
return R.isFunction(anf_fun4723039)?anf_fun4723039.app(anf_arg4813040,anf_arg4833041):R.ffi.throwNonFunApp(L[278],anf_fun4723039,[anf_arg4813040,anf_arg4833041]);
};
try {
if(--R.GAS > 0) {
$z30313032 = $f30373038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30373038,
"from":L[278]});
}
} catch($e30293030) {
if(R.isCont($e30293030)) {
var $ss30333034 = {"from":L[278],
"go":function(cont_tail_arg4843042) {
return $Hcont_tail_arg13223043(cont_tail_arg4843042,if_helper4673027);
}};
$e30293030.stack[R.EXN_STACKHEIGHT++] = $ss30333034;
}
if(R.isPyretException($e30293030)) {
$e30293030.pyretStack.push(L[278]);
}
throw $e30293030;
}
var $ret30353036 = $Hcont_tail_arg13223043($z30313032,if_helper4673027);
++R.GAS;
return $ret30353036;
}
} else {
var cont_tail_arg4693077 = R.throwNonBooleanCondition(L[282],("if"),if_DASH_523074);
if(--R.GAS > 0) {
$z30753076 = R.isFunction(if_helper4673027)?if_helper4673027.app(cont_tail_arg4693077):R.ffi.throwNonFunApp(L[282],if_helper4673027,[cont_tail_arg4693077]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4673027)?if_helper4673027.app(cont_tail_arg4693077):R.ffi.throwNonFunApp(L[282],if_helper4673027,[cont_tail_arg4693077]);
},
"from":L[282]});
}
++R.GAS;
return $z30753076;
}
});
help1953007.$var = anf_assign4883008;
var $z30113012 = D;
var $f30173018 = function(_) {
return R.isFunction(help1953007.$var)?help1953007.$var.app(n1912976,lst1922975):R.ffi.throwNonFunApp(L[275],help1953007.$var,[n1912976,lst1922975]);
};
try {
if(--R.GAS > 0) {
$z30113012 = $f30173018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30173018,
"from":L[275]});
}
} catch($e30093010) {
if(R.isCont($e30093010)) {
var $ss30133014 = {"from":L[275],
"go":function(anf_begin_app_dropped13233019) {
return $Hanf_begin_app_dropped13243022(anf_begin_app_dropped13233019,List525,prefix1933020,suffix1943021);
}};
$e30093010.stack[R.EXN_STACKHEIGHT++] = $ss30133014;
}
if(R.isPyretException($e30093010)) {
$e30093010.pyretStack.push(L[275]);
}
throw $e30093010;
}
var $ret30153016 = $Hanf_begin_app_dropped13243022($z30113012,List525,prefix1933020,suffix1943021);
++R.GAS;
return $ret30153016;
});
var anf_if4913005 = R.isBoolean(when_DASH_492974);
if(R.isPyretTrue(anf_if4913005)) {
if(R.isPyretTrue(when_DASH_492974)) {
var $z29792980 = D;
var $f29852986 = function(_) {
return R.isFunction(raise9)?raise9.app(("Invalid index")):R.ffi.throwNonFunApp(L[272],raise9,[("Invalid index")]);
};
try {
if(--R.GAS > 0) {
$z29792980 = $f29852986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29852986,
"from":L[272]});
}
} catch($e29772978) {
if(R.isCont($e29772978)) {
var $ss29812982 = {"from":L[272],
"go":function(anf_begin_app_dropped13252987) {
return $Hanf_begin_app_dropped13272989(anf_begin_app_dropped13252987,if_helper4642988,nothing8);
}};
$e29772978.stack[R.EXN_STACKHEIGHT++] = $ss29812982;
}
if(R.isPyretException($e29772978)) {
$e29772978.pyretStack.push(L[272]);
}
throw $e29772978;
}
var $ret29832984 = $Hanf_begin_app_dropped13272989($z29792980,if_helper4642988,nothing8);
++R.GAS;
return $ret29832984;
} else {
var $z29922993 = D;
var $f29982999 = function(_) {
return R.isFunction(if_helper4642988)?if_helper4642988.app(nothing8):R.ffi.throwNonFunApp(L[273],if_helper4642988,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z29922993 = $f29982999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29982999,
"from":L[273]});
}
} catch($e29902991) {
if(R.isCont($e29902991)) {
var $ss29942995 = {"from":L[273],
"go":function(cont_tail_app4923000) {
return $Hcont_tail_app13283001(cont_tail_app4923000);
}};
$e29902991.stack[R.EXN_STACKHEIGHT++] = $ss29942995;
}
if(R.isPyretException($e29902991)) {
$e29902991.pyretStack.push(L[273]);
}
throw $e29902991;
}
var $ret29962997 = $Hcont_tail_app13283001($z29922993);
++R.GAS;
return $ret29962997;
}
} else {
var cont_tail_arg4893004 = R.throwNonBooleanCondition(L[274],("when"),when_DASH_492974);
if(--R.GAS > 0) {
$z30023003 = R.isFunction(if_helper4642988)?if_helper4642988.app(cont_tail_arg4893004):R.ffi.throwNonFunApp(L[274],if_helper4642988,[cont_tail_arg4893004]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4642988)?if_helper4642988.app(cont_tail_arg4893004):R.ffi.throwNonFunApp(L[274],if_helper4642988,[cont_tail_arg4893004]);
},
"from":L[274]});
}
++R.GAS;
return $z30023003;
}
};
var $Hanf_begin_app_dropped13272989 = function(anf_begin_app_dropped13252987,if_helper4642988,nothing8) {
var $z30833084 = D;
var $f30893090 = function(_) {
return R.isFunction(if_helper4642988)?if_helper4642988.app(nothing8):R.ffi.throwNonFunApp(L[273],if_helper4642988,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z30833084 = $f30893090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30893090,
"from":L[273]});
}
} catch($e30813082) {
if(R.isCont($e30813082)) {
var $ss30853086 = {"from":L[273],
"go":function(cont_tail_app4933091) {
return $Hcont_tail_app13263092(cont_tail_app4933091);
}};
$e30813082.stack[R.EXN_STACKHEIGHT++] = $ss30853086;
}
if(R.isPyretException($e30813082)) {
$e30813082.pyretStack.push(L[273]);
}
throw $e30813082;
}
var $ret30873088 = $Hcont_tail_app13263092($z30833084);
++R.GAS;
return $ret30873088;
};
var $Hcont_tail_app13263092 = function(cont_tail_app4933091) {
return cont_tail_app4933091;
};
var $Hcont_tail_app13283001 = function(cont_tail_app4923000) {
return cont_tail_app4923000;
};
var $Hanf_begin_app_dropped13243022 = function(anf_begin_app_dropped13233019,List525,prefix1933020,suffix1943021) {
var ann_DASH_check_DASH_temp4633093 = R.makeObject({"prefix":prefix1933020.$var,
"suffix":suffix1943021.$var});
return R.checkAnn(L[283],R.makeRecordAnn(["prefix","suffix"],[L[284],L[285]],{"prefix":List525,
"suffix":List525}),ann_DASH_check_DASH_temp4633093,function() {
return ann_DASH_check_DASH_temp4633093;
});
};
var $Hcont_tail_arg13223043 = function(cont_tail_arg4843042,if_helper4673027) {
if(--R.GAS > 0) {
$z30943095 = R.isFunction(if_helper4673027)?if_helper4673027.app(cont_tail_arg4843042):R.ffi.throwNonFunApp(L[278],if_helper4673027,[cont_tail_arg4843042]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4673027)?if_helper4673027.app(cont_tail_arg4843042):R.ffi.throwNonFunApp(L[278],if_helper4673027,[cont_tail_arg4843042]);
},
"from":L[278]});
}
++R.GAS;
return $z30943095;
};
var $Hanf_arg13213060 = function(anf_arg4763059,fst1983047,help1953007,link211585,prefix1933020,rst1993048) {
var $z30983099 = D;
var $f31043105 = function(_) {
return R.isFunction(help1953007.$var)?help1953007.$var.app(anf_arg4763059,rst1993048):R.ffi.throwNonFunApp(L[286],help1953007.$var,[anf_arg4763059,rst1993048]);
};
try {
if(--R.GAS > 0) {
$z30983099 = $f31043105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31043105,
"from":L[286]});
}
} catch($e30963097) {
if(R.isCont($e30963097)) {
var $ss31003101 = {"from":L[286],
"go":function(anf_begin_app_dropped13173106) {
return $Hanf_begin_app_dropped13203107(anf_begin_app_dropped13173106,fst1983047,link211585,prefix1933020);
}};
$e30963097.stack[R.EXN_STACKHEIGHT++] = $ss31003101;
}
if(R.isPyretException($e30963097)) {
$e30963097.pyretStack.push(L[286]);
}
throw $e30963097;
}
var $ret31023103 = $Hanf_begin_app_dropped13203107($z30983099,fst1983047,link211585,prefix1933020);
++R.GAS;
return $ret31023103;
};
var $Hanf_begin_app_dropped13203107 = function(anf_begin_app_dropped13173106,fst1983047,link211585,prefix1933020) {
var anf_fun4783118 = R.makeFunction(function(arg_DASH_503121) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[287],1,arguments);
}
var $z31243125 = D;
var $f31303131 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_503121,prefix1933020.$var):R.ffi.throwNonFunApp(L[287],link211585.$var,[arg_DASH_503121,prefix1933020.$var]);
};
try {
if(--R.GAS > 0) {
$z31243125 = $f31303131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31303131,
"from":L[287]});
}
} catch($e31223123) {
if(R.isCont($e31223123)) {
var $ss31263127 = {"from":L[287],
"go":function(ann_DASH_check_DASH_temp4773132) {
return $Hann_DASH_check_DASH_temp13183133(ann_DASH_check_DASH_temp4773132);
}};
$e31223123.stack[R.EXN_STACKHEIGHT++] = $ss31263127;
}
if(R.isPyretException($e31223123)) {
$e31223123.pyretStack.push(L[287]);
}
throw $e31223123;
}
var $ret31283129 = $Hann_DASH_check_DASH_temp13183133($z31243125);
++R.GAS;
return $ret31283129;
});
var $z31103111 = D;
var $f31163117 = function(_) {
return R.isFunction(anf_fun4783118)?anf_fun4783118.app(fst1983047):R.ffi.throwNonFunApp(L[287],anf_fun4783118,[fst1983047]);
};
try {
if(--R.GAS > 0) {
$z31103111 = $f31163117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31163117,
"from":L[287]});
}
} catch($e31083109) {
if(R.isCont($e31083109)) {
var $ss31123113 = {"from":L[287],
"go":function(anf_assign4793119) {
return $Hanf_assign13193120(anf_assign4793119,prefix1933020);
}};
$e31083109.stack[R.EXN_STACKHEIGHT++] = $ss31123113;
}
if(R.isPyretException($e31083109)) {
$e31083109.pyretStack.push(L[287]);
}
throw $e31083109;
}
var $ret31143115 = $Hanf_assign13193120($z31103111,prefix1933020);
++R.GAS;
return $ret31143115;
};
var $Hanf_assign13193120 = function(anf_assign4793119,prefix1933020) {
var ann_DASH_check_DASH_temp4753134 = prefix1933020.$var = anf_assign4793119;
return ann_DASH_check_DASH_temp4753134;
};
var $Hann_DASH_check_DASH_temp13183133 = function(ann_DASH_check_DASH_temp4773132) {
return ann_DASH_check_DASH_temp4773132;
};
var $Hann_DASH_check_DASH_temp13163072 = function(ann_DASH_check_DASH_temp4733071) {
return ann_DASH_check_DASH_temp4733071;
};
var $Hif_DASH_13153135 = function(if_DASH_483136,O218,f1833137,find293138,lst1843139,none73140,some93141) {
var if_helper4463152 = R.makeFunction(function(if_helper_arg4473172) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[291],1,arguments);
}
var ann_DASH_check_DASH_temp4453173 = if_helper_arg4473172;
return R.checkAnn(L[292],R.getDotAnn(L[292],"O",O218,"Option"),ann_DASH_check_DASH_temp4453173,function() {
return ann_DASH_check_DASH_temp4453173;
});
});
var anf_if4503171 = R.isBoolean(if_DASH_483136);
if(R.isPyretTrue(anf_if4503171)) {
if(R.isPyretTrue(if_DASH_483136)) {
var $z31443145 = D;
var $f31503151 = function(_) {
return R.isFunction(if_helper4463152)?if_helper4463152.app(none73140):R.ffi.throwNonFunApp(L[288],if_helper4463152,[none73140]);
};
try {
if(--R.GAS > 0) {
$z31443145 = $f31503151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31503151,
"from":L[288]});
}
} catch($e31423143) {
if(R.isCont($e31423143)) {
var $ss31463147 = {"from":L[288],
"go":function(cont_tail_app4613153) {
return $Hcont_tail_app13113154(cont_tail_app4613153);
}};
$e31423143.stack[R.EXN_STACKHEIGHT++] = $ss31463147;
}
if(R.isPyretException($e31423143)) {
$e31423143.pyretStack.push(L[288]);
}
throw $e31423143;
}
var $ret31483149 = $Hcont_tail_app13113154($z31443145);
++R.GAS;
return $ret31483149;
} else {
var anf_arg4513165 = G(lst1843139,"first",L[290]);
var $z31573158 = D;
var $f31633164 = function(_) {
return R.isFunction(f1833137)?f1833137.app(anf_arg4513165):R.ffi.throwNonFunApp(L[289],f1833137,[anf_arg4513165]);
};
try {
if(--R.GAS > 0) {
$z31573158 = $f31633164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31633164,
"from":L[289]});
}
} catch($e31553156) {
if(R.isCont($e31553156)) {
var $ss31593160 = {"from":L[289],
"go":function(if_DASH_473166) {
return $Hif_DASH_13143167(if_DASH_473166,f1833137,find293138,if_helper4463152,lst1843139,some93141);
}};
$e31553156.stack[R.EXN_STACKHEIGHT++] = $ss31593160;
}
if(R.isPyretException($e31553156)) {
$e31553156.pyretStack.push(L[289]);
}
throw $e31553156;
}
var $ret31613162 = $Hif_DASH_13143167($z31573158,f1833137,find293138,if_helper4463152,lst1843139,some93141);
++R.GAS;
return $ret31613162;
}
} else {
var cont_tail_arg4483170 = R.throwNonBooleanCondition(L[291],("if"),if_DASH_483136);
if(--R.GAS > 0) {
$z31683169 = R.isFunction(if_helper4463152)?if_helper4463152.app(cont_tail_arg4483170):R.ffi.throwNonFunApp(L[291],if_helper4463152,[cont_tail_arg4483170]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4463152)?if_helper4463152.app(cont_tail_arg4483170):R.ffi.throwNonFunApp(L[291],if_helper4463152,[cont_tail_arg4483170]);
},
"from":L[291]});
}
++R.GAS;
return $z31683169;
}
};
var $Hcont_tail_app13113154 = function(cont_tail_app4613153) {
return cont_tail_app4613153;
};
var $Hif_DASH_13143167 = function(if_DASH_473166,f1833137,find293138,if_helper4463152,lst1843139,some93141) {
var anf_if4543203 = R.isBoolean(if_DASH_473166);
if(R.isPyretTrue(anf_if4543203)) {
if(R.isPyretTrue(if_DASH_473166)) {
var anf_arg4583184 = G(lst1843139,"first",L[294]);
var $z31763177 = D;
var $f31823183 = function(_) {
return R.isFunction(some93141)?some93141.app(anf_arg4583184):R.ffi.throwNonFunApp(L[293],some93141,[anf_arg4583184]);
};
try {
if(--R.GAS > 0) {
$z31763177 = $f31823183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31823183,
"from":L[293]});
}
} catch($e31743175) {
if(R.isCont($e31743175)) {
var $ss31783179 = {"from":L[293],
"go":function(cont_tail_arg4593185) {
return $Hcont_tail_arg13123186(cont_tail_arg4593185,if_helper4463152);
}};
$e31743175.stack[R.EXN_STACKHEIGHT++] = $ss31783179;
}
if(R.isPyretException($e31743175)) {
$e31743175.pyretStack.push(L[293]);
}
throw $e31743175;
}
var $ret31803181 = $Hcont_tail_arg13123186($z31763177,if_helper4463152);
++R.GAS;
return $ret31803181;
} else {
var anf_arg4553197 = G(lst1843139,"rest",L[296]);
var $z31893190 = D;
var $f31953196 = function(_) {
return R.isFunction(find293138.$var)?find293138.$var.app(f1833137,anf_arg4553197):R.ffi.throwNonFunApp(L[295],find293138.$var,[f1833137,anf_arg4553197]);
};
try {
if(--R.GAS > 0) {
$z31893190 = $f31953196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31953196,
"from":L[295]});
}
} catch($e31873188) {
if(R.isCont($e31873188)) {
var $ss31913192 = {"from":L[295],
"go":function(cont_tail_arg4563198) {
return $Hcont_tail_arg13133199(cont_tail_arg4563198,if_helper4463152);
}};
$e31873188.stack[R.EXN_STACKHEIGHT++] = $ss31913192;
}
if(R.isPyretException($e31873188)) {
$e31873188.pyretStack.push(L[295]);
}
throw $e31873188;
}
var $ret31933194 = $Hcont_tail_arg13133199($z31893190,if_helper4463152);
++R.GAS;
return $ret31933194;
}
} else {
var cont_tail_arg4523202 = R.throwNonBooleanCondition(L[289],("if"),if_DASH_473166);
if(--R.GAS > 0) {
$z32003201 = R.isFunction(if_helper4463152)?if_helper4463152.app(cont_tail_arg4523202):R.ffi.throwNonFunApp(L[289],if_helper4463152,[cont_tail_arg4523202]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4463152)?if_helper4463152.app(cont_tail_arg4523202):R.ffi.throwNonFunApp(L[289],if_helper4463152,[cont_tail_arg4523202]);
},
"from":L[289]});
}
++R.GAS;
return $z32003201;
}
};
var $Hcont_tail_arg13123186 = function(cont_tail_arg4593185,if_helper4463152) {
if(--R.GAS > 0) {
$z32043205 = R.isFunction(if_helper4463152)?if_helper4463152.app(cont_tail_arg4593185):R.ffi.throwNonFunApp(L[293],if_helper4463152,[cont_tail_arg4593185]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4463152)?if_helper4463152.app(cont_tail_arg4593185):R.ffi.throwNonFunApp(L[293],if_helper4463152,[cont_tail_arg4593185]);
},
"from":L[293]});
}
++R.GAS;
return $z32043205;
};
var $Hcont_tail_arg13133199 = function(cont_tail_arg4563198,if_helper4463152) {
if(--R.GAS > 0) {
$z32063207 = R.isFunction(if_helper4463152)?if_helper4463152.app(cont_tail_arg4563198):R.ffi.throwNonFunApp(L[295],if_helper4463152,[cont_tail_arg4563198]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4463152)?if_helper4463152.app(cont_tail_arg4563198):R.ffi.throwNonFunApp(L[295],if_helper4463152,[cont_tail_arg4563198]);
},
"from":L[295]});
}
++R.GAS;
return $z32063207;
};
var $Hanf_begin_app_dropped13103208 = function(anf_begin_app_dropped13093209,is_DASH_false1773210,is_DASH_true1763211) {
var ann_DASH_check_DASH_temp4183212 = R.makeObject({"is-true":is_DASH_true1763211.$var,
"is-false":is_DASH_false1773210.$var});
return ann_DASH_check_DASH_temp4183212;
};
var $Hif_DASH_13083213 = function(if_DASH_463214,f1743215,help1783216,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585,nothing8) {
var if_helper4203228 = R.makeFunction(function(if_helper_arg4213248) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[300],1,arguments);
}
var ann_DASH_check_DASH_temp4193249 = if_helper_arg4213248;
return ann_DASH_check_DASH_temp4193249;
});
var anf_if4243247 = R.isBoolean(if_DASH_463214);
if(R.isPyretTrue(anf_if4243247)) {
if(R.isPyretTrue(if_DASH_463214)) {
var $z32203221 = D;
var $f32263227 = function(_) {
return R.isFunction(if_helper4203228)?if_helper4203228.app(nothing8):R.ffi.throwNonFunApp(L[297],if_helper4203228,[nothing8]);
};
try {
if(--R.GAS > 0) {
$z32203221 = $f32263227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32263227,
"from":L[297]});
}
} catch($e32183219) {
if(R.isCont($e32183219)) {
var $ss32223223 = {"from":L[297],
"go":function(cont_tail_app4423229) {
return $Hcont_tail_app13003230(cont_tail_app4423229);
}};
$e32183219.stack[R.EXN_STACKHEIGHT++] = $ss32223223;
}
if(R.isPyretException($e32183219)) {
$e32183219.pyretStack.push(L[297]);
}
throw $e32183219;
}
var $ret32243225 = $Hcont_tail_app13003230($z32203221);
++R.GAS;
return $ret32243225;
} else {
var anf_arg4253241 = G(inner_DASH_lst1793217,"rest",L[299]);
var $z32333234 = D;
var $f32393240 = function(_) {
return R.isFunction(help1783216.$var)?help1783216.$var.app(anf_arg4253241):R.ffi.throwNonFunApp(L[298],help1783216.$var,[anf_arg4253241]);
};
try {
if(--R.GAS > 0) {
$z32333234 = $f32393240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32393240,
"from":L[298]});
}
} catch($e32313232) {
if(R.isCont($e32313232)) {
var $ss32353236 = {"from":L[298],
"go":function(anf_begin_app_dropped13013242) {
return $Hanf_begin_app_dropped13073243(anf_begin_app_dropped13013242,f1743215,if_helper4203228,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585);
}};
$e32313232.stack[R.EXN_STACKHEIGHT++] = $ss32353236;
}
if(R.isPyretException($e32313232)) {
$e32313232.pyretStack.push(L[298]);
}
throw $e32313232;
}
var $ret32373238 = $Hanf_begin_app_dropped13073243($z32333234,f1743215,if_helper4203228,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585);
++R.GAS;
return $ret32373238;
}
} else {
var cont_tail_arg4223246 = R.throwNonBooleanCondition(L[300],("if"),if_DASH_463214);
if(--R.GAS > 0) {
$z32443245 = R.isFunction(if_helper4203228)?if_helper4203228.app(cont_tail_arg4223246):R.ffi.throwNonFunApp(L[300],if_helper4203228,[cont_tail_arg4223246]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4203228)?if_helper4203228.app(cont_tail_arg4223246):R.ffi.throwNonFunApp(L[300],if_helper4203228,[cont_tail_arg4223246]);
},
"from":L[300]});
}
++R.GAS;
return $z32443245;
}
};
var $Hcont_tail_app13003230 = function(cont_tail_app4423229) {
return cont_tail_app4423229;
};
var $Hanf_begin_app_dropped13073243 = function(anf_begin_app_dropped13013242,f1743215,if_helper4203228,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585) {
var anf_arg4263260 = G(inner_DASH_lst1793217,"first",L[302]);
var $z32523253 = D;
var $f32583259 = function(_) {
return R.isFunction(f1743215)?f1743215.app(anf_arg4263260):R.ffi.throwNonFunApp(L[301],f1743215,[anf_arg4263260]);
};
try {
if(--R.GAS > 0) {
$z32523253 = $f32583259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32583259,
"from":L[301]});
}
} catch($e32503251) {
if(R.isCont($e32503251)) {
var $ss32543255 = {"from":L[301],
"go":function(if_DASH_443261) {
return $Hif_DASH_13063262(if_DASH_443261,if_helper4203228,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585);
}};
$e32503251.stack[R.EXN_STACKHEIGHT++] = $ss32543255;
}
if(R.isPyretException($e32503251)) {
$e32503251.pyretStack.push(L[301]);
}
throw $e32503251;
}
var $ret32563257 = $Hif_DASH_13063262($z32523253,if_helper4203228,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585);
++R.GAS;
return $ret32563257;
};
var $Hif_DASH_13063262 = function(if_DASH_443261,if_helper4203228,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585) {
var anf_if4293320 = R.isBoolean(if_DASH_443261);
if(R.isPyretTrue(anf_if4293320)) {
if(R.isPyretTrue(if_DASH_443261)) {
var anf_fun4373273 = R.makeFunction(function(arg_DASH_453277) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[303],1,arguments);
}
var $z32803281 = D;
var $f32863287 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_453277,is_DASH_true1763211.$var):R.ffi.throwNonFunApp(L[303],link211585.$var,[arg_DASH_453277,is_DASH_true1763211.$var]);
};
try {
if(--R.GAS > 0) {
$z32803281 = $f32863287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32863287,
"from":L[303]});
}
} catch($e32783279) {
if(R.isCont($e32783279)) {
var $ss32823283 = {"from":L[303],
"go":function(ann_DASH_check_DASH_temp4363288) {
return $Hann_DASH_check_DASH_temp13023289(ann_DASH_check_DASH_temp4363288);
}};
$e32783279.stack[R.EXN_STACKHEIGHT++] = $ss32823283;
}
if(R.isPyretException($e32783279)) {
$e32783279.pyretStack.push(L[303]);
}
throw $e32783279;
}
var $ret32843285 = $Hann_DASH_check_DASH_temp13023289($z32803281);
++R.GAS;
return $ret32843285;
});
var anf_arg4383274 = G(inner_DASH_lst1793217,"first",L[304]);
var $z32653266 = D;
var $f32713272 = function(_) {
return R.isFunction(anf_fun4373273)?anf_fun4373273.app(anf_arg4383274):R.ffi.throwNonFunApp(L[303],anf_fun4373273,[anf_arg4383274]);
};
try {
if(--R.GAS > 0) {
$z32653266 = $f32713272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32713272,
"from":L[303]});
}
} catch($e32633264) {
if(R.isCont($e32633264)) {
var $ss32673268 = {"from":L[303],
"go":function(anf_assign4393275) {
return $Hanf_assign13033276(anf_assign4393275,if_helper4203228,is_DASH_true1763211);
}};
$e32633264.stack[R.EXN_STACKHEIGHT++] = $ss32673268;
}
if(R.isPyretException($e32633264)) {
$e32633264.pyretStack.push(L[303]);
}
throw $e32633264;
}
var $ret32693270 = $Hanf_assign13033276($z32653266,if_helper4203228,is_DASH_true1763211);
++R.GAS;
return $ret32693270;
} else {
var anf_fun4313300 = R.makeFunction(function(arg_DASH_433304) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[305],1,arguments);
}
var $z33073308 = D;
var $f33133314 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_433304,is_DASH_false1773210.$var):R.ffi.throwNonFunApp(L[305],link211585.$var,[arg_DASH_433304,is_DASH_false1773210.$var]);
};
try {
if(--R.GAS > 0) {
$z33073308 = $f33133314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33133314,
"from":L[305]});
}
} catch($e33053306) {
if(R.isCont($e33053306)) {
var $ss33093310 = {"from":L[305],
"go":function(ann_DASH_check_DASH_temp4303315) {
return $Hann_DASH_check_DASH_temp13043316(ann_DASH_check_DASH_temp4303315);
}};
$e33053306.stack[R.EXN_STACKHEIGHT++] = $ss33093310;
}
if(R.isPyretException($e33053306)) {
$e33053306.pyretStack.push(L[305]);
}
throw $e33053306;
}
var $ret33113312 = $Hann_DASH_check_DASH_temp13043316($z33073308);
++R.GAS;
return $ret33113312;
});
var anf_arg4323301 = G(inner_DASH_lst1793217,"first",L[306]);
var $z32923293 = D;
var $f32983299 = function(_) {
return R.isFunction(anf_fun4313300)?anf_fun4313300.app(anf_arg4323301):R.ffi.throwNonFunApp(L[305],anf_fun4313300,[anf_arg4323301]);
};
try {
if(--R.GAS > 0) {
$z32923293 = $f32983299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32983299,
"from":L[305]});
}
} catch($e32903291) {
if(R.isCont($e32903291)) {
var $ss32943295 = {"from":L[305],
"go":function(anf_assign4333302) {
return $Hanf_assign13053303(anf_assign4333302,if_helper4203228,is_DASH_false1773210);
}};
$e32903291.stack[R.EXN_STACKHEIGHT++] = $ss32943295;
}
if(R.isPyretException($e32903291)) {
$e32903291.pyretStack.push(L[305]);
}
throw $e32903291;
}
var $ret32963297 = $Hanf_assign13053303($z32923293,if_helper4203228,is_DASH_false1773210);
++R.GAS;
return $ret32963297;
}
} else {
var cont_tail_arg4273319 = R.throwNonBooleanCondition(L[301],("if"),if_DASH_443261);
if(--R.GAS > 0) {
$z33173318 = R.isFunction(if_helper4203228)?if_helper4203228.app(cont_tail_arg4273319):R.ffi.throwNonFunApp(L[301],if_helper4203228,[cont_tail_arg4273319]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4203228)?if_helper4203228.app(cont_tail_arg4273319):R.ffi.throwNonFunApp(L[301],if_helper4203228,[cont_tail_arg4273319]);
},
"from":L[301]});
}
++R.GAS;
return $z33173318;
}
};
var $Hanf_assign13033276 = function(anf_assign4393275,if_helper4203228,is_DASH_true1763211) {
var cont_tail_arg4403323 = is_DASH_true1763211.$var = anf_assign4393275;
if(--R.GAS > 0) {
$z33213322 = R.isFunction(if_helper4203228)?if_helper4203228.app(cont_tail_arg4403323):R.ffi.throwNonFunApp(L[307],if_helper4203228,[cont_tail_arg4403323]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4203228)?if_helper4203228.app(cont_tail_arg4403323):R.ffi.throwNonFunApp(L[307],if_helper4203228,[cont_tail_arg4403323]);
},
"from":L[307]});
}
++R.GAS;
return $z33213322;
};
var $Hann_DASH_check_DASH_temp13023289 = function(ann_DASH_check_DASH_temp4363288) {
return ann_DASH_check_DASH_temp4363288;
};
var $Hanf_assign13053303 = function(anf_assign4333302,if_helper4203228,is_DASH_false1773210) {
var cont_tail_arg4343326 = is_DASH_false1773210.$var = anf_assign4333302;
if(--R.GAS > 0) {
$z33243325 = R.isFunction(if_helper4203228)?if_helper4203228.app(cont_tail_arg4343326):R.ffi.throwNonFunApp(L[308],if_helper4203228,[cont_tail_arg4343326]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper4203228)?if_helper4203228.app(cont_tail_arg4343326):R.ffi.throwNonFunApp(L[308],if_helper4203228,[cont_tail_arg4343326]);
},
"from":L[308]});
}
++R.GAS;
return $z33243325;
};
var $Hann_DASH_check_DASH_temp13043316 = function(ann_DASH_check_DASH_temp4303315) {
return ann_DASH_check_DASH_temp4303315;
};
var $Hif_DASH_12993327 = function(if_DASH_423328,empty191579,f1703329,filter273330,link211585,lst1713331) {
var if_helper3973342 = R.makeFunction(function(if_helper_arg3983362) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[312],1,arguments);
}
var ann_DASH_check_DASH_temp3963363 = if_helper_arg3983362;
return ann_DASH_check_DASH_temp3963363;
});
var anf_if4013361 = R.isBoolean(if_DASH_423328);
if(R.isPyretTrue(anf_if4013361)) {
if(R.isPyretTrue(if_DASH_423328)) {
var $z33343335 = D;
var $f33403341 = function(_) {
return R.isFunction(if_helper3973342)?if_helper3973342.app(empty191579.$var):R.ffi.throwNonFunApp(L[309],if_helper3973342,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z33343335 = $f33403341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33403341,
"from":L[309]});
}
} catch($e33323333) {
if(R.isCont($e33323333)) {
var $ss33363337 = {"from":L[309],
"go":function(cont_tail_app4163343) {
return $Hcont_tail_app12933344(cont_tail_app4163343);
}};
$e33323333.stack[R.EXN_STACKHEIGHT++] = $ss33363337;
}
if(R.isPyretException($e33323333)) {
$e33323333.pyretStack.push(L[309]);
}
throw $e33323333;
}
var $ret33383339 = $Hcont_tail_app12933344($z33343335);
++R.GAS;
return $ret33383339;
} else {
var anf_arg4023355 = G(lst1713331,"first",L[311]);
var $z33473348 = D;
var $f33533354 = function(_) {
return R.isFunction(f1703329)?f1703329.app(anf_arg4023355):R.ffi.throwNonFunApp(L[310],f1703329,[anf_arg4023355]);
};
try {
if(--R.GAS > 0) {
$z33473348 = $f33533354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33533354,
"from":L[310]});
}
} catch($e33453346) {
if(R.isCont($e33453346)) {
var $ss33493350 = {"from":L[310],
"go":function(if_DASH_403356) {
return $Hif_DASH_12983357(if_DASH_403356,f1703329,filter273330,if_helper3973342,link211585,lst1713331);
}};
$e33453346.stack[R.EXN_STACKHEIGHT++] = $ss33493350;
}
if(R.isPyretException($e33453346)) {
$e33453346.pyretStack.push(L[310]);
}
throw $e33453346;
}
var $ret33513352 = $Hif_DASH_12983357($z33473348,f1703329,filter273330,if_helper3973342,link211585,lst1713331);
++R.GAS;
return $ret33513352;
}
} else {
var cont_tail_arg3993360 = R.throwNonBooleanCondition(L[312],("if"),if_DASH_423328);
if(--R.GAS > 0) {
$z33583359 = R.isFunction(if_helper3973342)?if_helper3973342.app(cont_tail_arg3993360):R.ffi.throwNonFunApp(L[312],if_helper3973342,[cont_tail_arg3993360]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3973342)?if_helper3973342.app(cont_tail_arg3993360):R.ffi.throwNonFunApp(L[312],if_helper3973342,[cont_tail_arg3993360]);
},
"from":L[312]});
}
++R.GAS;
return $z33583359;
}
};
var $Hcont_tail_app12933344 = function(cont_tail_app4163343) {
return cont_tail_app4163343;
};
var $Hif_DASH_12983357 = function(if_DASH_403356,f1703329,filter273330,if_helper3973342,link211585,lst1713331) {
var anf_if4053408 = R.isBoolean(if_DASH_403356);
if(R.isPyretTrue(anf_if4053408)) {
if(R.isPyretTrue(if_DASH_403356)) {
var anf_fun4123374 = R.makeFunction(function(arg_DASH_413378) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[313],1,arguments);
}
var anf_arg4103389 = G(lst1713331,"rest",L[316]);
var $z33813382 = D;
var $f33873388 = function(_) {
return R.isFunction(filter273330.$var)?filter273330.$var.app(f1703329,anf_arg4103389):R.ffi.throwNonFunApp(L[315],filter273330.$var,[f1703329,anf_arg4103389]);
};
try {
if(--R.GAS > 0) {
$z33813382 = $f33873388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33873388,
"from":L[315]});
}
} catch($e33793380) {
if(R.isCont($e33793380)) {
var $ss33833384 = {"from":L[315],
"go":function(anf_arg4113390) {
return $Hanf_arg12953391(anf_arg4113390,arg_DASH_413378,link211585);
}};
$e33793380.stack[R.EXN_STACKHEIGHT++] = $ss33833384;
}
if(R.isPyretException($e33793380)) {
$e33793380.pyretStack.push(L[315]);
}
throw $e33793380;
}
var $ret33853386 = $Hanf_arg12953391($z33813382,arg_DASH_413378,link211585);
++R.GAS;
return $ret33853386;
});
var anf_arg4133375 = G(lst1713331,"first",L[314]);
var $z33663367 = D;
var $f33723373 = function(_) {
return R.isFunction(anf_fun4123374)?anf_fun4123374.app(anf_arg4133375):R.ffi.throwNonFunApp(L[313],anf_fun4123374,[anf_arg4133375]);
};
try {
if(--R.GAS > 0) {
$z33663367 = $f33723373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33723373,
"from":L[313]});
}
} catch($e33643365) {
if(R.isCont($e33643365)) {
var $ss33683369 = {"from":L[313],
"go":function(cont_tail_arg4143376) {
return $Hcont_tail_arg12963377(cont_tail_arg4143376,if_helper3973342);
}};
$e33643365.stack[R.EXN_STACKHEIGHT++] = $ss33683369;
}
if(R.isPyretException($e33643365)) {
$e33643365.pyretStack.push(L[313]);
}
throw $e33643365;
}
var $ret33703371 = $Hcont_tail_arg12963377($z33663367,if_helper3973342);
++R.GAS;
return $ret33703371;
} else {
var anf_arg4063402 = G(lst1713331,"rest",L[318]);
var $z33943395 = D;
var $f34003401 = function(_) {
return R.isFunction(filter273330.$var)?filter273330.$var.app(f1703329,anf_arg4063402):R.ffi.throwNonFunApp(L[317],filter273330.$var,[f1703329,anf_arg4063402]);
};
try {
if(--R.GAS > 0) {
$z33943395 = $f34003401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34003401,
"from":L[317]});
}
} catch($e33923393) {
if(R.isCont($e33923393)) {
var $ss33963397 = {"from":L[317],
"go":function(cont_tail_arg4073403) {
return $Hcont_tail_arg12973404(cont_tail_arg4073403,if_helper3973342);
}};
$e33923393.stack[R.EXN_STACKHEIGHT++] = $ss33963397;
}
if(R.isPyretException($e33923393)) {
$e33923393.pyretStack.push(L[317]);
}
throw $e33923393;
}
var $ret33983399 = $Hcont_tail_arg12973404($z33943395,if_helper3973342);
++R.GAS;
return $ret33983399;
}
} else {
var cont_tail_arg4033407 = R.throwNonBooleanCondition(L[310],("if"),if_DASH_403356);
if(--R.GAS > 0) {
$z34053406 = R.isFunction(if_helper3973342)?if_helper3973342.app(cont_tail_arg4033407):R.ffi.throwNonFunApp(L[310],if_helper3973342,[cont_tail_arg4033407]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3973342)?if_helper3973342.app(cont_tail_arg4033407):R.ffi.throwNonFunApp(L[310],if_helper3973342,[cont_tail_arg4033407]);
},
"from":L[310]});
}
++R.GAS;
return $z34053406;
}
};
var $Hcont_tail_arg12963377 = function(cont_tail_arg4143376,if_helper3973342) {
if(--R.GAS > 0) {
$z34093410 = R.isFunction(if_helper3973342)?if_helper3973342.app(cont_tail_arg4143376):R.ffi.throwNonFunApp(L[313],if_helper3973342,[cont_tail_arg4143376]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3973342)?if_helper3973342.app(cont_tail_arg4143376):R.ffi.throwNonFunApp(L[313],if_helper3973342,[cont_tail_arg4143376]);
},
"from":L[313]});
}
++R.GAS;
return $z34093410;
};
var $Hanf_arg12953391 = function(anf_arg4113390,arg_DASH_413378,link211585) {
var $z34133414 = D;
var $f34193420 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_413378,anf_arg4113390):R.ffi.throwNonFunApp(L[313],link211585.$var,[arg_DASH_413378,anf_arg4113390]);
};
try {
if(--R.GAS > 0) {
$z34133414 = $f34193420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34193420,
"from":L[313]});
}
} catch($e34113412) {
if(R.isCont($e34113412)) {
var $ss34153416 = {"from":L[313],
"go":function(ann_DASH_check_DASH_temp4093421) {
return $Hann_DASH_check_DASH_temp12943422(ann_DASH_check_DASH_temp4093421);
}};
$e34113412.stack[R.EXN_STACKHEIGHT++] = $ss34153416;
}
if(R.isPyretException($e34113412)) {
$e34113412.pyretStack.push(L[313]);
}
throw $e34113412;
}
var $ret34173418 = $Hann_DASH_check_DASH_temp12943422($z34133414);
++R.GAS;
return $ret34173418;
};
var $Hann_DASH_check_DASH_temp12943422 = function(ann_DASH_check_DASH_temp4093421) {
return ann_DASH_check_DASH_temp4093421;
};
var $Hcont_tail_arg12973404 = function(cont_tail_arg4073403,if_helper3973342) {
if(--R.GAS > 0) {
$z34233424 = R.isFunction(if_helper3973342)?if_helper3973342.app(cont_tail_arg4073403):R.ffi.throwNonFunApp(L[317],if_helper3973342,[cont_tail_arg4073403]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3973342)?if_helper3973342.app(cont_tail_arg4073403):R.ffi.throwNonFunApp(L[317],if_helper3973342,[cont_tail_arg4073403]);
},
"from":L[317]});
}
++R.GAS;
return $z34233424;
};
var $Hif_DASH_12923425 = function(if_DASH_393426,List525,e1693427,empty191579,link211585,n1683428,repeat263429,_minus5,raise9) {
var if_helper3803441 = R.makeFunction(function(if_helper_arg3813476) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[323],1,arguments);
}
var ann_DASH_check_DASH_temp3793477 = if_helper_arg3813476;
return R.checkAnn(L[324],List525,ann_DASH_check_DASH_temp3793477,function() {
return ann_DASH_check_DASH_temp3793477;
});
});
var anf_if3843475 = R.isBoolean(if_DASH_393426);
if(R.isPyretTrue(anf_if3843475)) {
if(R.isPyretTrue(if_DASH_393426)) {
var $z34323433 = D;
var $f34383439 = function(_) {
return R.isFunction(_minus5)?_minus5.app(n1683428,(1)):R.ffi.throwNonFunApp(L[319],_minus5,[n1683428,(1)]);
};
try {
if(--R.GAS > 0) {
$z34323433 = $f34383439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34383439,
"from":L[319]});
}
} catch($e34303431) {
if(R.isCont($e34303431)) {
var $ss34343435 = {"from":L[319],
"go":function(anf_arg3913440) {
return $Hanf_arg12893442(anf_arg3913440,e1693427,if_helper3803441,link211585,repeat263429);
}};
$e34303431.stack[R.EXN_STACKHEIGHT++] = $ss34343435;
}
if(R.isPyretException($e34303431)) {
$e34303431.pyretStack.push(L[319]);
}
throw $e34303431;
}
var $ret34363437 = $Hanf_arg12893442($z34323433,e1693427,if_helper3803441,link211585,repeat263429);
++R.GAS;
return $ret34363437;
} else {
var if_DASH_383467 = R.equiv(n1683428,(0));
var anf_if3873471 = R.isBoolean(if_DASH_383467);
if(R.isPyretTrue(anf_if3873471)) {
if(R.isPyretTrue(if_DASH_383467)) {
var $z34453446 = D;
var $f34513452 = function(_) {
return R.isFunction(if_helper3803441)?if_helper3803441.app(empty191579.$var):R.ffi.throwNonFunApp(L[320],if_helper3803441,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z34453446 = $f34513452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34513452,
"from":L[320]});
}
} catch($e34433444) {
if(R.isCont($e34433444)) {
var $ss34473448 = {"from":L[320],
"go":function(cont_tail_app3903453) {
return $Hcont_tail_app12903454(cont_tail_app3903453);
}};
$e34433444.stack[R.EXN_STACKHEIGHT++] = $ss34473448;
}
if(R.isPyretException($e34433444)) {
$e34433444.pyretStack.push(L[320]);
}
throw $e34433444;
}
var $ret34493450 = $Hcont_tail_app12903454($z34453446);
++R.GAS;
return $ret34493450;
} else {
var $z34573458 = D;
var $f34633464 = function(_) {
return R.isFunction(raise9)?raise9.app(("repeat: can't have a negative argument'")):R.ffi.throwNonFunApp(L[321],raise9,[("repeat: can't have a negative argument'")]);
};
try {
if(--R.GAS > 0) {
$z34573458 = $f34633464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34633464,
"from":L[321]});
}
} catch($e34553456) {
if(R.isCont($e34553456)) {
var $ss34593460 = {"from":L[321],
"go":function(cont_tail_arg3883465) {
return $Hcont_tail_arg12913466(cont_tail_arg3883465,if_helper3803441);
}};
$e34553456.stack[R.EXN_STACKHEIGHT++] = $ss34593460;
}
if(R.isPyretException($e34553456)) {
$e34553456.pyretStack.push(L[321]);
}
throw $e34553456;
}
var $ret34613462 = $Hcont_tail_arg12913466($z34573458,if_helper3803441);
++R.GAS;
return $ret34613462;
}
} else {
var cont_tail_arg3853470 = R.throwNonBooleanCondition(L[322],("if"),if_DASH_383467);
if(--R.GAS > 0) {
$z34683469 = R.isFunction(if_helper3803441)?if_helper3803441.app(cont_tail_arg3853470):R.ffi.throwNonFunApp(L[322],if_helper3803441,[cont_tail_arg3853470]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3803441)?if_helper3803441.app(cont_tail_arg3853470):R.ffi.throwNonFunApp(L[322],if_helper3803441,[cont_tail_arg3853470]);
},
"from":L[322]});
}
++R.GAS;
return $z34683469;
}
}
} else {
var cont_tail_arg3823474 = R.throwNonBooleanCondition(L[323],("if"),if_DASH_393426);
if(--R.GAS > 0) {
$z34723473 = R.isFunction(if_helper3803441)?if_helper3803441.app(cont_tail_arg3823474):R.ffi.throwNonFunApp(L[323],if_helper3803441,[cont_tail_arg3823474]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3803441)?if_helper3803441.app(cont_tail_arg3823474):R.ffi.throwNonFunApp(L[323],if_helper3803441,[cont_tail_arg3823474]);
},
"from":L[323]});
}
++R.GAS;
return $z34723473;
}
};
var $Hanf_arg12893442 = function(anf_arg3913440,e1693427,if_helper3803441,link211585,repeat263429) {
var $z34803481 = D;
var $f34863487 = function(_) {
return R.isFunction(repeat263429.$var)?repeat263429.$var.app(anf_arg3913440,e1693427):R.ffi.throwNonFunApp(L[325],repeat263429.$var,[anf_arg3913440,e1693427]);
};
try {
if(--R.GAS > 0) {
$z34803481 = $f34863487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34863487,
"from":L[325]});
}
} catch($e34783479) {
if(R.isCont($e34783479)) {
var $ss34823483 = {"from":L[325],
"go":function(anf_arg3923488) {
return $Hanf_arg12883489(anf_arg3923488,e1693427,if_helper3803441,link211585);
}};
$e34783479.stack[R.EXN_STACKHEIGHT++] = $ss34823483;
}
if(R.isPyretException($e34783479)) {
$e34783479.pyretStack.push(L[325]);
}
throw $e34783479;
}
var $ret34843485 = $Hanf_arg12883489($z34803481,e1693427,if_helper3803441,link211585);
++R.GAS;
return $ret34843485;
};
var $Hanf_arg12883489 = function(anf_arg3923488,e1693427,if_helper3803441,link211585) {
var $z34923493 = D;
var $f34983499 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(e1693427,anf_arg3923488):R.ffi.throwNonFunApp(L[326],link211585.$var,[e1693427,anf_arg3923488]);
};
try {
if(--R.GAS > 0) {
$z34923493 = $f34983499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34983499,
"from":L[326]});
}
} catch($e34903491) {
if(R.isCont($e34903491)) {
var $ss34943495 = {"from":L[326],
"go":function(cont_tail_arg3933500) {
return $Hcont_tail_arg12873501(cont_tail_arg3933500,if_helper3803441);
}};
$e34903491.stack[R.EXN_STACKHEIGHT++] = $ss34943495;
}
if(R.isPyretException($e34903491)) {
$e34903491.pyretStack.push(L[326]);
}
throw $e34903491;
}
var $ret34963497 = $Hcont_tail_arg12873501($z34923493,if_helper3803441);
++R.GAS;
return $ret34963497;
};
var $Hcont_tail_arg12873501 = function(cont_tail_arg3933500,if_helper3803441) {
if(--R.GAS > 0) {
$z35023503 = R.isFunction(if_helper3803441)?if_helper3803441.app(cont_tail_arg3933500):R.ffi.throwNonFunApp(L[326],if_helper3803441,[cont_tail_arg3933500]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3803441)?if_helper3803441.app(cont_tail_arg3933500):R.ffi.throwNonFunApp(L[326],if_helper3803441,[cont_tail_arg3933500]);
},
"from":L[326]});
}
++R.GAS;
return $z35023503;
};
var $Hcont_tail_app12903454 = function(cont_tail_app3903453) {
return cont_tail_app3903453;
};
var $Hcont_tail_arg12913466 = function(cont_tail_arg3883465,if_helper3803441) {
if(--R.GAS > 0) {
$z35043505 = R.isFunction(if_helper3803441)?if_helper3803441.app(cont_tail_arg3883465):R.ffi.throwNonFunApp(L[321],if_helper3803441,[cont_tail_arg3883465]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3803441)?if_helper3803441.app(cont_tail_arg3883465):R.ffi.throwNonFunApp(L[321],if_helper3803441,[cont_tail_arg3883465]);
},
"from":L[321]});
}
++R.GAS;
return $z35043505;
};
var $Hif_DASH_12863506 = function(if_DASH_373507,empty191579,link211585,range253508,start1663509,stop1673510,_plus6,raise9,tostring12) {
var if_helper3573522 = R.makeFunction(function(if_helper_arg3583557) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[331],1,arguments);
}
var ann_DASH_check_DASH_temp3563558 = if_helper_arg3583557;
return ann_DASH_check_DASH_temp3563558;
});
var anf_if3613556 = R.isBoolean(if_DASH_373507);
if(R.isPyretTrue(anf_if3613556)) {
if(R.isPyretTrue(if_DASH_373507)) {
var $z35133514 = D;
var $f35193520 = function(_) {
return R.isFunction(_plus6)?_plus6.app(start1663509,(1)):R.ffi.throwNonFunApp(L[327],_plus6,[start1663509,(1)]);
};
try {
if(--R.GAS > 0) {
$z35133514 = $f35193520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35193520,
"from":L[327]});
}
} catch($e35113512) {
if(R.isCont($e35113512)) {
var $ss35153516 = {"from":L[327],
"go":function(anf_arg3743521) {
return $Hanf_arg12773523(anf_arg3743521,if_helper3573522,link211585,range253508,start1663509,stop1673510);
}};
$e35113512.stack[R.EXN_STACKHEIGHT++] = $ss35153516;
}
if(R.isPyretException($e35113512)) {
$e35113512.pyretStack.push(L[327]);
}
throw $e35113512;
}
var $ret35173518 = $Hanf_arg12773523($z35133514,if_helper3573522,link211585,range253508,start1663509,stop1673510);
++R.GAS;
return $ret35173518;
} else {
var if_DASH_363548 = R.equiv(start1663509,stop1673510);
var anf_if3643552 = R.isBoolean(if_DASH_363548);
if(R.isPyretTrue(anf_if3643552)) {
if(R.isPyretTrue(if_DASH_363548)) {
var $z35263527 = D;
var $f35323533 = function(_) {
return R.isFunction(if_helper3573522)?if_helper3573522.app(empty191579.$var):R.ffi.throwNonFunApp(L[328],if_helper3573522,[empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z35263527 = $f35323533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35323533,
"from":L[328]});
}
} catch($e35243525) {
if(R.isCont($e35243525)) {
var $ss35283529 = {"from":L[328],
"go":function(cont_tail_app3733534) {
return $Hcont_tail_app12783535(cont_tail_app3733534);
}};
$e35243525.stack[R.EXN_STACKHEIGHT++] = $ss35283529;
}
if(R.isPyretException($e35243525)) {
$e35243525.pyretStack.push(L[328]);
}
throw $e35243525;
}
var $ret35303531 = $Hcont_tail_app12783535($z35263527);
++R.GAS;
return $ret35303531;
} else {
var $z35383539 = D;
var $f35443545 = function(_) {
return R.isFunction(tostring12)?tostring12.app(start1663509):R.ffi.throwNonFunApp(L[329],tostring12,[start1663509]);
};
try {
if(--R.GAS > 0) {
$z35383539 = $f35443545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35443545,
"from":L[329]});
}
} catch($e35363537) {
if(R.isCont($e35363537)) {
var $ss35403541 = {"from":L[329],
"go":function(anf_arg3653546) {
return $Hanf_arg12853547(anf_arg3653546,if_helper3573522,stop1673510,_plus6,raise9,tostring12);
}};
$e35363537.stack[R.EXN_STACKHEIGHT++] = $ss35403541;
}
if(R.isPyretException($e35363537)) {
$e35363537.pyretStack.push(L[329]);
}
throw $e35363537;
}
var $ret35423543 = $Hanf_arg12853547($z35383539,if_helper3573522,stop1673510,_plus6,raise9,tostring12);
++R.GAS;
return $ret35423543;
}
} else {
var cont_tail_arg3623551 = R.throwNonBooleanCondition(L[330],("if"),if_DASH_363548);
if(--R.GAS > 0) {
$z35493550 = R.isFunction(if_helper3573522)?if_helper3573522.app(cont_tail_arg3623551):R.ffi.throwNonFunApp(L[330],if_helper3573522,[cont_tail_arg3623551]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3573522)?if_helper3573522.app(cont_tail_arg3623551):R.ffi.throwNonFunApp(L[330],if_helper3573522,[cont_tail_arg3623551]);
},
"from":L[330]});
}
++R.GAS;
return $z35493550;
}
}
} else {
var cont_tail_arg3593555 = R.throwNonBooleanCondition(L[331],("if"),if_DASH_373507);
if(--R.GAS > 0) {
$z35533554 = R.isFunction(if_helper3573522)?if_helper3573522.app(cont_tail_arg3593555):R.ffi.throwNonFunApp(L[331],if_helper3573522,[cont_tail_arg3593555]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3573522)?if_helper3573522.app(cont_tail_arg3593555):R.ffi.throwNonFunApp(L[331],if_helper3573522,[cont_tail_arg3593555]);
},
"from":L[331]});
}
++R.GAS;
return $z35533554;
}
};
var $Hanf_arg12773523 = function(anf_arg3743521,if_helper3573522,link211585,range253508,start1663509,stop1673510) {
var $z35613562 = D;
var $f35673568 = function(_) {
return R.isFunction(range253508.$var)?range253508.$var.app(anf_arg3743521,stop1673510):R.ffi.throwNonFunApp(L[332],range253508.$var,[anf_arg3743521,stop1673510]);
};
try {
if(--R.GAS > 0) {
$z35613562 = $f35673568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35673568,
"from":L[332]});
}
} catch($e35593560) {
if(R.isCont($e35593560)) {
var $ss35633564 = {"from":L[332],
"go":function(anf_arg3753569) {
return $Hanf_arg12763570(anf_arg3753569,if_helper3573522,link211585,start1663509);
}};
$e35593560.stack[R.EXN_STACKHEIGHT++] = $ss35633564;
}
if(R.isPyretException($e35593560)) {
$e35593560.pyretStack.push(L[332]);
}
throw $e35593560;
}
var $ret35653566 = $Hanf_arg12763570($z35613562,if_helper3573522,link211585,start1663509);
++R.GAS;
return $ret35653566;
};
var $Hanf_arg12763570 = function(anf_arg3753569,if_helper3573522,link211585,start1663509) {
var $z35733574 = D;
var $f35793580 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(start1663509,anf_arg3753569):R.ffi.throwNonFunApp(L[333],link211585.$var,[start1663509,anf_arg3753569]);
};
try {
if(--R.GAS > 0) {
$z35733574 = $f35793580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35793580,
"from":L[333]});
}
} catch($e35713572) {
if(R.isCont($e35713572)) {
var $ss35753576 = {"from":L[333],
"go":function(cont_tail_arg3763581) {
return $Hcont_tail_arg12753582(cont_tail_arg3763581,if_helper3573522);
}};
$e35713572.stack[R.EXN_STACKHEIGHT++] = $ss35753576;
}
if(R.isPyretException($e35713572)) {
$e35713572.pyretStack.push(L[333]);
}
throw $e35713572;
}
var $ret35773578 = $Hcont_tail_arg12753582($z35733574,if_helper3573522);
++R.GAS;
return $ret35773578;
};
var $Hcont_tail_arg12753582 = function(cont_tail_arg3763581,if_helper3573522) {
if(--R.GAS > 0) {
$z35833584 = R.isFunction(if_helper3573522)?if_helper3573522.app(cont_tail_arg3763581):R.ffi.throwNonFunApp(L[333],if_helper3573522,[cont_tail_arg3763581]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3573522)?if_helper3573522.app(cont_tail_arg3763581):R.ffi.throwNonFunApp(L[333],if_helper3573522,[cont_tail_arg3763581]);
},
"from":L[333]});
}
++R.GAS;
return $z35833584;
};
var $Hcont_tail_app12783535 = function(cont_tail_app3733534) {
return cont_tail_app3733534;
};
var $Hanf_arg12853547 = function(anf_arg3653546,if_helper3573522,stop1673510,_plus6,raise9,tostring12) {
var $z35873588 = D;
var $f35933594 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("range: start greater than stop: ("),anf_arg3653546):R.ffi.throwNonFunApp(L[334],_plus6,[("range: start greater than stop: ("),anf_arg3653546]);
};
try {
if(--R.GAS > 0) {
$z35873588 = $f35933594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35933594,
"from":L[334]});
}
} catch($e35853586) {
if(R.isCont($e35853586)) {
var $ss35893590 = {"from":L[334],
"go":function(anf_arg3663595) {
return $Hanf_arg12843596(anf_arg3663595,if_helper3573522,stop1673510,_plus6,raise9,tostring12);
}};
$e35853586.stack[R.EXN_STACKHEIGHT++] = $ss35893590;
}
if(R.isPyretException($e35853586)) {
$e35853586.pyretStack.push(L[334]);
}
throw $e35853586;
}
var $ret35913592 = $Hanf_arg12843596($z35873588,if_helper3573522,stop1673510,_plus6,raise9,tostring12);
++R.GAS;
return $ret35913592;
};
var $Hanf_arg12843596 = function(anf_arg3663595,if_helper3573522,stop1673510,_plus6,raise9,tostring12) {
var $z35993600 = D;
var $f36053606 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg3663595,(", ")):R.ffi.throwNonFunApp(L[334],_plus6,[anf_arg3663595,(", ")]);
};
try {
if(--R.GAS > 0) {
$z35993600 = $f36053606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36053606,
"from":L[334]});
}
} catch($e35973598) {
if(R.isCont($e35973598)) {
var $ss36013602 = {"from":L[334],
"go":function(anf_arg3673607) {
return $Hanf_arg12833608(anf_arg3673607,if_helper3573522,stop1673510,_plus6,raise9,tostring12);
}};
$e35973598.stack[R.EXN_STACKHEIGHT++] = $ss36013602;
}
if(R.isPyretException($e35973598)) {
$e35973598.pyretStack.push(L[334]);
}
throw $e35973598;
}
var $ret36033604 = $Hanf_arg12833608($z35993600,if_helper3573522,stop1673510,_plus6,raise9,tostring12);
++R.GAS;
return $ret36033604;
};
var $Hanf_arg12833608 = function(anf_arg3673607,if_helper3573522,stop1673510,_plus6,raise9,tostring12) {
var $z36113612 = D;
var $f36173618 = function(_) {
return R.isFunction(tostring12)?tostring12.app(stop1673510):R.ffi.throwNonFunApp(L[335],tostring12,[stop1673510]);
};
try {
if(--R.GAS > 0) {
$z36113612 = $f36173618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36173618,
"from":L[335]});
}
} catch($e36093610) {
if(R.isCont($e36093610)) {
var $ss36133614 = {"from":L[335],
"go":function(anf_arg3683619) {
return $Hanf_arg12823620(anf_arg3683619,anf_arg3673607,if_helper3573522,_plus6,raise9);
}};
$e36093610.stack[R.EXN_STACKHEIGHT++] = $ss36133614;
}
if(R.isPyretException($e36093610)) {
$e36093610.pyretStack.push(L[335]);
}
throw $e36093610;
}
var $ret36153616 = $Hanf_arg12823620($z36113612,anf_arg3673607,if_helper3573522,_plus6,raise9);
++R.GAS;
return $ret36153616;
};
var $Hanf_arg12823620 = function(anf_arg3683619,anf_arg3673607,if_helper3573522,_plus6,raise9) {
var $z36233624 = D;
var $f36293630 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg3673607,anf_arg3683619):R.ffi.throwNonFunApp(L[334],_plus6,[anf_arg3673607,anf_arg3683619]);
};
try {
if(--R.GAS > 0) {
$z36233624 = $f36293630();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36293630,
"from":L[334]});
}
} catch($e36213622) {
if(R.isCont($e36213622)) {
var $ss36253626 = {"from":L[334],
"go":function(anf_arg3693631) {
return $Hanf_arg12813632(anf_arg3693631,if_helper3573522,_plus6,raise9);
}};
$e36213622.stack[R.EXN_STACKHEIGHT++] = $ss36253626;
}
if(R.isPyretException($e36213622)) {
$e36213622.pyretStack.push(L[334]);
}
throw $e36213622;
}
var $ret36273628 = $Hanf_arg12813632($z36233624,if_helper3573522,_plus6,raise9);
++R.GAS;
return $ret36273628;
};
var $Hanf_arg12813632 = function(anf_arg3693631,if_helper3573522,_plus6,raise9) {
var $z36353636 = D;
var $f36413642 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg3693631,(")")):R.ffi.throwNonFunApp(L[334],_plus6,[anf_arg3693631,(")")]);
};
try {
if(--R.GAS > 0) {
$z36353636 = $f36413642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36413642,
"from":L[334]});
}
} catch($e36333634) {
if(R.isCont($e36333634)) {
var $ss36373638 = {"from":L[334],
"go":function(anf_arg3703643) {
return $Hanf_arg12803644(anf_arg3703643,if_helper3573522,raise9);
}};
$e36333634.stack[R.EXN_STACKHEIGHT++] = $ss36373638;
}
if(R.isPyretException($e36333634)) {
$e36333634.pyretStack.push(L[334]);
}
throw $e36333634;
}
var $ret36393640 = $Hanf_arg12803644($z36353636,if_helper3573522,raise9);
++R.GAS;
return $ret36393640;
};
var $Hanf_arg12803644 = function(anf_arg3703643,if_helper3573522,raise9) {
var $z36473648 = D;
var $f36533654 = function(_) {
return R.isFunction(raise9)?raise9.app(anf_arg3703643):R.ffi.throwNonFunApp(L[336],raise9,[anf_arg3703643]);
};
try {
if(--R.GAS > 0) {
$z36473648 = $f36533654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36533654,
"from":L[336]});
}
} catch($e36453646) {
if(R.isCont($e36453646)) {
var $ss36493650 = {"from":L[336],
"go":function(cont_tail_arg3713655) {
return $Hcont_tail_arg12793656(cont_tail_arg3713655,if_helper3573522);
}};
$e36453646.stack[R.EXN_STACKHEIGHT++] = $ss36493650;
}
if(R.isPyretException($e36453646)) {
$e36453646.pyretStack.push(L[336]);
}
throw $e36453646;
}
var $ret36513652 = $Hcont_tail_arg12793656($z36473648,if_helper3573522);
++R.GAS;
return $ret36513652;
};
var $Hcont_tail_arg12793656 = function(cont_tail_arg3713655,if_helper3573522) {
if(--R.GAS > 0) {
$z36573658 = R.isFunction(if_helper3573522)?if_helper3573522.app(cont_tail_arg3713655):R.ffi.throwNonFunApp(L[336],if_helper3573522,[cont_tail_arg3713655]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3573522)?if_helper3573522.app(cont_tail_arg3713655):R.ffi.throwNonFunApp(L[336],if_helper3573522,[cont_tail_arg3713655]);
},
"from":L[336]});
}
++R.GAS;
return $z36573658;
};
var $Hann_DASH_check_DASH_temp12743659 = function(ann_DASH_check_DASH_temp3433660) {
return ann_DASH_check_DASH_temp3433660;
};
var $Hanf_arg12733661 = function(anf_arg3503662,rest1653663,reverse_DASH_help243664) {
var $z36673668 = D;
var $f36733674 = function(_) {
return R.isFunction(reverse_DASH_help243664.$var)?reverse_DASH_help243664.$var.app(rest1653663,anf_arg3503662):R.ffi.throwNonFunApp(L[337],reverse_DASH_help243664.$var,[rest1653663,anf_arg3503662]);
};
try {
if(--R.GAS > 0) {
$z36673668 = $f36733674();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36733674,
"from":L[337]});
}
} catch($e36653666) {
if(R.isCont($e36653666)) {
var $ss36693670 = {"from":L[337],
"go":function(ann_DASH_check_DASH_temp3473675) {
return $Hann_DASH_check_DASH_temp12723676(ann_DASH_check_DASH_temp3473675);
}};
$e36653666.stack[R.EXN_STACKHEIGHT++] = $ss36693670;
}
if(R.isPyretException($e36653666)) {
$e36653666.pyretStack.push(L[337]);
}
throw $e36653666;
}
var $ret36713672 = $Hann_DASH_check_DASH_temp12723676($z36673668);
++R.GAS;
return $ret36713672;
};
var $Hann_DASH_check_DASH_temp12723676 = function(ann_DASH_check_DASH_temp3473675) {
return ann_DASH_check_DASH_temp3473675;
};
var $Hann_DASH_check_DASH_temp12713677 = function(ann_DASH_check_DASH_temp3483678) {
return ann_DASH_check_DASH_temp3483678;
};
var $Hif_DASH_12703679 = function(if_DASH_333680,help1593681,lst1563682,n1573683,_plus6,raise9,tostring12) {
var if_helper3313695 = R.makeFunction(function(if_helper_arg3323713) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[340],1,arguments);
}
var ann_DASH_check_DASH_temp3033714 = if_helper_arg3323713;
return ann_DASH_check_DASH_temp3033714;
});
var anf_if3353712 = R.isBoolean(if_DASH_333680);
if(R.isPyretTrue(anf_if3353712)) {
if(R.isPyretTrue(if_DASH_333680)) {
var $z36863687 = D;
var $f36923693 = function(_) {
return R.isFunction(tostring12)?tostring12.app(n1573683):R.ffi.throwNonFunApp(L[338],tostring12,[n1573683]);
};
try {
if(--R.GAS > 0) {
$z36863687 = $f36923693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36923693,
"from":L[338]});
}
} catch($e36843685) {
if(R.isCont($e36843685)) {
var $ss36883689 = {"from":L[338],
"go":function(anf_arg3383694) {
return $Hanf_arg12683696(anf_arg3383694,if_helper3313695,_plus6,raise9);
}};
$e36843685.stack[R.EXN_STACKHEIGHT++] = $ss36883689;
}
if(R.isPyretException($e36843685)) {
$e36843685.pyretStack.push(L[338]);
}
throw $e36843685;
}
var $ret36903691 = $Hanf_arg12683696($z36863687,if_helper3313695,_plus6,raise9);
++R.GAS;
return $ret36903691;
} else {
var $z36993700 = D;
var $f37053706 = function(_) {
return R.isFunction(help1593681.$var)?help1593681.$var.app(lst1563682,n1573683):R.ffi.throwNonFunApp(L[339],help1593681.$var,[lst1563682,n1573683]);
};
try {
if(--R.GAS > 0) {
$z36993700 = $f37053706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37053706,
"from":L[339]});
}
} catch($e36973698) {
if(R.isCont($e36973698)) {
var $ss37013702 = {"from":L[339],
"go":function(cont_tail_arg3363707) {
return $Hcont_tail_arg12693708(cont_tail_arg3363707,if_helper3313695);
}};
$e36973698.stack[R.EXN_STACKHEIGHT++] = $ss37013702;
}
if(R.isPyretException($e36973698)) {
$e36973698.pyretStack.push(L[339]);
}
throw $e36973698;
}
var $ret37033704 = $Hcont_tail_arg12693708($z36993700,if_helper3313695);
++R.GAS;
return $ret37033704;
}
} else {
var cont_tail_arg3333711 = R.throwNonBooleanCondition(L[340],("if"),if_DASH_333680);
if(--R.GAS > 0) {
$z37093710 = R.isFunction(if_helper3313695)?if_helper3313695.app(cont_tail_arg3333711):R.ffi.throwNonFunApp(L[340],if_helper3313695,[cont_tail_arg3333711]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3313695)?if_helper3313695.app(cont_tail_arg3333711):R.ffi.throwNonFunApp(L[340],if_helper3313695,[cont_tail_arg3333711]);
},
"from":L[340]});
}
++R.GAS;
return $z37093710;
}
};
var $Hanf_arg12683696 = function(anf_arg3383694,if_helper3313695,_plus6,raise9) {
var $z37173718 = D;
var $f37233724 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("set: invalid argument: "),anf_arg3383694):R.ffi.throwNonFunApp(L[341],_plus6,[("set: invalid argument: "),anf_arg3383694]);
};
try {
if(--R.GAS > 0) {
$z37173718 = $f37233724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37233724,
"from":L[341]});
}
} catch($e37153716) {
if(R.isCont($e37153716)) {
var $ss37193720 = {"from":L[341],
"go":function(anf_arg3393725) {
return $Hanf_arg12673726(anf_arg3393725,if_helper3313695,raise9);
}};
$e37153716.stack[R.EXN_STACKHEIGHT++] = $ss37193720;
}
if(R.isPyretException($e37153716)) {
$e37153716.pyretStack.push(L[341]);
}
throw $e37153716;
}
var $ret37213722 = $Hanf_arg12673726($z37173718,if_helper3313695,raise9);
++R.GAS;
return $ret37213722;
};
var $Hanf_arg12673726 = function(anf_arg3393725,if_helper3313695,raise9) {
var $z37293730 = D;
var $f37353736 = function(_) {
return R.isFunction(raise9)?raise9.app(anf_arg3393725):R.ffi.throwNonFunApp(L[342],raise9,[anf_arg3393725]);
};
try {
if(--R.GAS > 0) {
$z37293730 = $f37353736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37353736,
"from":L[342]});
}
} catch($e37273728) {
if(R.isCont($e37273728)) {
var $ss37313732 = {"from":L[342],
"go":function(cont_tail_arg3403737) {
return $Hcont_tail_arg12663738(cont_tail_arg3403737,if_helper3313695);
}};
$e37273728.stack[R.EXN_STACKHEIGHT++] = $ss37313732;
}
if(R.isPyretException($e37273728)) {
$e37273728.pyretStack.push(L[342]);
}
throw $e37273728;
}
var $ret37333734 = $Hcont_tail_arg12663738($z37293730,if_helper3313695);
++R.GAS;
return $ret37333734;
};
var $Hcont_tail_arg12663738 = function(cont_tail_arg3403737,if_helper3313695) {
if(--R.GAS > 0) {
$z37393740 = R.isFunction(if_helper3313695)?if_helper3313695.app(cont_tail_arg3403737):R.ffi.throwNonFunApp(L[342],if_helper3313695,[cont_tail_arg3403737]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3313695)?if_helper3313695.app(cont_tail_arg3403737):R.ffi.throwNonFunApp(L[342],if_helper3313695,[cont_tail_arg3403737]);
},
"from":L[342]});
}
++R.GAS;
return $z37393740;
};
var $Hcont_tail_arg12693708 = function(cont_tail_arg3363707,if_helper3313695) {
if(--R.GAS > 0) {
$z37413742 = R.isFunction(if_helper3313695)?if_helper3313695.app(cont_tail_arg3363707):R.ffi.throwNonFunApp(L[339],if_helper3313695,[cont_tail_arg3363707]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3313695)?if_helper3313695.app(cont_tail_arg3363707):R.ffi.throwNonFunApp(L[339],if_helper3313695,[cont_tail_arg3363707]);
},
"from":L[339]});
}
++R.GAS;
return $z37413742;
};
var $Hif_DASH_12653743 = function(if_DASH_323744,cur1613745,help1593681,l1603746,link211585,n1573683,v1583747,_minus5,_plus6,raise9,tostring12) {
var if_helper3053759 = R.makeFunction(function(if_helper_arg3063825) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[351],1,arguments);
}
var ann_DASH_check_DASH_temp3043826 = if_helper_arg3063825;
return ann_DASH_check_DASH_temp3043826;
});
var anf_if3093824 = R.isBoolean(if_DASH_323744);
if(R.isPyretTrue(anf_if3093824)) {
if(R.isPyretTrue(if_DASH_323744)) {
var $z37503751 = D;
var $f37563757 = function(_) {
return R.isFunction(tostring12)?tostring12.app(n1573683):R.ffi.throwNonFunApp(L[343],tostring12,[n1573683]);
};
try {
if(--R.GAS > 0) {
$z37503751 = $f37563757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37563757,
"from":L[343]});
}
} catch($e37483749) {
if(R.isCont($e37483749)) {
var $ss37523753 = {"from":L[343],
"go":function(anf_arg3263758) {
return $Hanf_arg12583760(anf_arg3263758,if_helper3053759,_plus6,raise9);
}};
$e37483749.stack[R.EXN_STACKHEIGHT++] = $ss37523753;
}
if(R.isPyretException($e37483749)) {
$e37483749.pyretStack.push(L[343]);
}
throw $e37483749;
}
var $ret37543755 = $Hanf_arg12583760($z37503751,if_helper3053759,_plus6,raise9);
++R.GAS;
return $ret37543755;
} else {
var if_DASH_303816 = R.equiv(cur1613745,(0));
var anf_if3123820 = R.isBoolean(if_DASH_303816);
if(R.isPyretTrue(anf_if3123820)) {
if(R.isPyretTrue(if_DASH_303816)) {
var anf_fun3233771 = R.makeFunction(function(arg_DASH_313774) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[344],1,arguments);
}
var anf_arg3223785 = G(l1603746,"rest",L[345]);
var $z37773778 = D;
var $f37833784 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_313774,anf_arg3223785):R.ffi.throwNonFunApp(L[344],link211585.$var,[arg_DASH_313774,anf_arg3223785]);
};
try {
if(--R.GAS > 0) {
$z37773778 = $f37833784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37833784,
"from":L[344]});
}
} catch($e37753776) {
if(R.isCont($e37753776)) {
var $ss37793780 = {"from":L[344],
"go":function(ann_DASH_check_DASH_temp3213786) {
return $Hann_DASH_check_DASH_temp12593787(ann_DASH_check_DASH_temp3213786);
}};
$e37753776.stack[R.EXN_STACKHEIGHT++] = $ss37793780;
}
if(R.isPyretException($e37753776)) {
$e37753776.pyretStack.push(L[344]);
}
throw $e37753776;
}
var $ret37813782 = $Hann_DASH_check_DASH_temp12593787($z37773778);
++R.GAS;
return $ret37813782;
});
var $z37633764 = D;
var $f37693770 = function(_) {
return R.isFunction(anf_fun3233771)?anf_fun3233771.app(v1583747):R.ffi.throwNonFunApp(L[344],anf_fun3233771,[v1583747]);
};
try {
if(--R.GAS > 0) {
$z37633764 = $f37693770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37693770,
"from":L[344]});
}
} catch($e37613762) {
if(R.isCont($e37613762)) {
var $ss37653766 = {"from":L[344],
"go":function(cont_tail_arg3243772) {
return $Hcont_tail_arg12603773(cont_tail_arg3243772,if_helper3053759);
}};
$e37613762.stack[R.EXN_STACKHEIGHT++] = $ss37653766;
}
if(R.isPyretException($e37613762)) {
$e37613762.pyretStack.push(L[344]);
}
throw $e37613762;
}
var $ret37673768 = $Hcont_tail_arg12603773($z37633764,if_helper3053759);
++R.GAS;
return $ret37673768;
} else {
var anf_fun3173798 = R.makeFunction(function(arg_DASH_293802) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[346],1,arguments);
}
var anf_arg3143814 = G(l1603746,"rest",L[349]);
var $z38053806 = D;
var $f38113812 = function(_) {
return R.isFunction(_minus5)?_minus5.app(cur1613745,(1)):R.ffi.throwNonFunApp(L[348],_minus5,[cur1613745,(1)]);
};
try {
if(--R.GAS > 0) {
$z38053806 = $f38113812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38113812,
"from":L[348]});
}
} catch($e38033804) {
if(R.isCont($e38033804)) {
var $ss38073808 = {"from":L[348],
"go":function(anf_arg3153813) {
return $Hanf_arg12633815(anf_arg3153813,anf_arg3143814,arg_DASH_293802,help1593681,link211585);
}};
$e38033804.stack[R.EXN_STACKHEIGHT++] = $ss38073808;
}
if(R.isPyretException($e38033804)) {
$e38033804.pyretStack.push(L[348]);
}
throw $e38033804;
}
var $ret38093810 = $Hanf_arg12633815($z38053806,anf_arg3143814,arg_DASH_293802,help1593681,link211585);
++R.GAS;
return $ret38093810;
});
var anf_arg3183799 = G(l1603746,"first",L[347]);
var $z37903791 = D;
var $f37963797 = function(_) {
return R.isFunction(anf_fun3173798)?anf_fun3173798.app(anf_arg3183799):R.ffi.throwNonFunApp(L[346],anf_fun3173798,[anf_arg3183799]);
};
try {
if(--R.GAS > 0) {
$z37903791 = $f37963797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37963797,
"from":L[346]});
}
} catch($e37883789) {
if(R.isCont($e37883789)) {
var $ss37923793 = {"from":L[346],
"go":function(cont_tail_arg3193800) {
return $Hcont_tail_arg12643801(cont_tail_arg3193800,if_helper3053759);
}};
$e37883789.stack[R.EXN_STACKHEIGHT++] = $ss37923793;
}
if(R.isPyretException($e37883789)) {
$e37883789.pyretStack.push(L[346]);
}
throw $e37883789;
}
var $ret37943795 = $Hcont_tail_arg12643801($z37903791,if_helper3053759);
++R.GAS;
return $ret37943795;
}
} else {
var cont_tail_arg3103819 = R.throwNonBooleanCondition(L[350],("if"),if_DASH_303816);
if(--R.GAS > 0) {
$z38173818 = R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3103819):R.ffi.throwNonFunApp(L[350],if_helper3053759,[cont_tail_arg3103819]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3103819):R.ffi.throwNonFunApp(L[350],if_helper3053759,[cont_tail_arg3103819]);
},
"from":L[350]});
}
++R.GAS;
return $z38173818;
}
}
} else {
var cont_tail_arg3073823 = R.throwNonBooleanCondition(L[351],("if"),if_DASH_323744);
if(--R.GAS > 0) {
$z38213822 = R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3073823):R.ffi.throwNonFunApp(L[351],if_helper3053759,[cont_tail_arg3073823]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3073823):R.ffi.throwNonFunApp(L[351],if_helper3053759,[cont_tail_arg3073823]);
},
"from":L[351]});
}
++R.GAS;
return $z38213822;
}
};
var $Hanf_arg12583760 = function(anf_arg3263758,if_helper3053759,_plus6,raise9) {
var $z38293830 = D;
var $f38353836 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("set: n too large "),anf_arg3263758):R.ffi.throwNonFunApp(L[352],_plus6,[("set: n too large "),anf_arg3263758]);
};
try {
if(--R.GAS > 0) {
$z38293830 = $f38353836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38353836,
"from":L[352]});
}
} catch($e38273828) {
if(R.isCont($e38273828)) {
var $ss38313832 = {"from":L[352],
"go":function(anf_arg3273837) {
return $Hanf_arg12573838(anf_arg3273837,if_helper3053759,raise9);
}};
$e38273828.stack[R.EXN_STACKHEIGHT++] = $ss38313832;
}
if(R.isPyretException($e38273828)) {
$e38273828.pyretStack.push(L[352]);
}
throw $e38273828;
}
var $ret38333834 = $Hanf_arg12573838($z38293830,if_helper3053759,raise9);
++R.GAS;
return $ret38333834;
};
var $Hanf_arg12573838 = function(anf_arg3273837,if_helper3053759,raise9) {
var $z38413842 = D;
var $f38473848 = function(_) {
return R.isFunction(raise9)?raise9.app(anf_arg3273837):R.ffi.throwNonFunApp(L[353],raise9,[anf_arg3273837]);
};
try {
if(--R.GAS > 0) {
$z38413842 = $f38473848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38473848,
"from":L[353]});
}
} catch($e38393840) {
if(R.isCont($e38393840)) {
var $ss38433844 = {"from":L[353],
"go":function(cont_tail_arg3283849) {
return $Hcont_tail_arg12563850(cont_tail_arg3283849,if_helper3053759);
}};
$e38393840.stack[R.EXN_STACKHEIGHT++] = $ss38433844;
}
if(R.isPyretException($e38393840)) {
$e38393840.pyretStack.push(L[353]);
}
throw $e38393840;
}
var $ret38453846 = $Hcont_tail_arg12563850($z38413842,if_helper3053759);
++R.GAS;
return $ret38453846;
};
var $Hcont_tail_arg12563850 = function(cont_tail_arg3283849,if_helper3053759) {
if(--R.GAS > 0) {
$z38513852 = R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3283849):R.ffi.throwNonFunApp(L[353],if_helper3053759,[cont_tail_arg3283849]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3283849):R.ffi.throwNonFunApp(L[353],if_helper3053759,[cont_tail_arg3283849]);
},
"from":L[353]});
}
++R.GAS;
return $z38513852;
};
var $Hcont_tail_arg12603773 = function(cont_tail_arg3243772,if_helper3053759) {
if(--R.GAS > 0) {
$z38533854 = R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3243772):R.ffi.throwNonFunApp(L[344],if_helper3053759,[cont_tail_arg3243772]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3243772):R.ffi.throwNonFunApp(L[344],if_helper3053759,[cont_tail_arg3243772]);
},
"from":L[344]});
}
++R.GAS;
return $z38533854;
};
var $Hann_DASH_check_DASH_temp12593787 = function(ann_DASH_check_DASH_temp3213786) {
return ann_DASH_check_DASH_temp3213786;
};
var $Hcont_tail_arg12643801 = function(cont_tail_arg3193800,if_helper3053759) {
if(--R.GAS > 0) {
$z38553856 = R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3193800):R.ffi.throwNonFunApp(L[346],if_helper3053759,[cont_tail_arg3193800]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper3053759)?if_helper3053759.app(cont_tail_arg3193800):R.ffi.throwNonFunApp(L[346],if_helper3053759,[cont_tail_arg3193800]);
},
"from":L[346]});
}
++R.GAS;
return $z38553856;
};
var $Hanf_arg12633815 = function(anf_arg3153813,anf_arg3143814,arg_DASH_293802,help1593681,link211585) {
var $z38593860 = D;
var $f38653866 = function(_) {
return R.isFunction(help1593681.$var)?help1593681.$var.app(anf_arg3143814,anf_arg3153813):R.ffi.throwNonFunApp(L[354],help1593681.$var,[anf_arg3143814,anf_arg3153813]);
};
try {
if(--R.GAS > 0) {
$z38593860 = $f38653866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38653866,
"from":L[354]});
}
} catch($e38573858) {
if(R.isCont($e38573858)) {
var $ss38613862 = {"from":L[354],
"go":function(anf_arg3163867) {
return $Hanf_arg12623868(anf_arg3163867,arg_DASH_293802,link211585);
}};
$e38573858.stack[R.EXN_STACKHEIGHT++] = $ss38613862;
}
if(R.isPyretException($e38573858)) {
$e38573858.pyretStack.push(L[354]);
}
throw $e38573858;
}
var $ret38633864 = $Hanf_arg12623868($z38593860,arg_DASH_293802,link211585);
++R.GAS;
return $ret38633864;
};
var $Hanf_arg12623868 = function(anf_arg3163867,arg_DASH_293802,link211585) {
var $z38713872 = D;
var $f38773878 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_293802,anf_arg3163867):R.ffi.throwNonFunApp(L[346],link211585.$var,[arg_DASH_293802,anf_arg3163867]);
};
try {
if(--R.GAS > 0) {
$z38713872 = $f38773878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38773878,
"from":L[346]});
}
} catch($e38693870) {
if(R.isCont($e38693870)) {
var $ss38733874 = {"from":L[346],
"go":function(ann_DASH_check_DASH_temp3133879) {
return $Hann_DASH_check_DASH_temp12613880(ann_DASH_check_DASH_temp3133879);
}};
$e38693870.stack[R.EXN_STACKHEIGHT++] = $ss38733874;
}
if(R.isPyretException($e38693870)) {
$e38693870.pyretStack.push(L[346]);
}
throw $e38693870;
}
var $ret38753876 = $Hann_DASH_check_DASH_temp12613880($z38713872);
++R.GAS;
return $ret38753876;
};
var $Hann_DASH_check_DASH_temp12613880 = function(ann_DASH_check_DASH_temp3133879) {
return ann_DASH_check_DASH_temp3133879;
};
var $Hif_DASH_12553881 = function(if_DASH_283882,help1533883,lst1513884,n1523885,_plus6,raise9,tostring12) {
var if_helper2913897 = R.makeFunction(function(if_helper_arg2923915) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[357],1,arguments);
}
var ann_DASH_check_DASH_temp2703916 = if_helper_arg2923915;
return ann_DASH_check_DASH_temp2703916;
});
var anf_if2953914 = R.isBoolean(if_DASH_283882);
if(R.isPyretTrue(anf_if2953914)) {
if(R.isPyretTrue(if_DASH_283882)) {
var $z38883889 = D;
var $f38943895 = function(_) {
return R.isFunction(tostring12)?tostring12.app(n1523885):R.ffi.throwNonFunApp(L[355],tostring12,[n1523885]);
};
try {
if(--R.GAS > 0) {
$z38883889 = $f38943895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38943895,
"from":L[355]});
}
} catch($e38863887) {
if(R.isCont($e38863887)) {
var $ss38903891 = {"from":L[355],
"go":function(anf_arg2983896) {
return $Hanf_arg12533898(anf_arg2983896,if_helper2913897,_plus6,raise9);
}};
$e38863887.stack[R.EXN_STACKHEIGHT++] = $ss38903891;
}
if(R.isPyretException($e38863887)) {
$e38863887.pyretStack.push(L[355]);
}
throw $e38863887;
}
var $ret38923893 = $Hanf_arg12533898($z38883889,if_helper2913897,_plus6,raise9);
++R.GAS;
return $ret38923893;
} else {
var $z39013902 = D;
var $f39073908 = function(_) {
return R.isFunction(help1533883.$var)?help1533883.$var.app(lst1513884,n1523885):R.ffi.throwNonFunApp(L[356],help1533883.$var,[lst1513884,n1523885]);
};
try {
if(--R.GAS > 0) {
$z39013902 = $f39073908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39073908,
"from":L[356]});
}
} catch($e38993900) {
if(R.isCont($e38993900)) {
var $ss39033904 = {"from":L[356],
"go":function(cont_tail_arg2963909) {
return $Hcont_tail_arg12543910(cont_tail_arg2963909,if_helper2913897);
}};
$e38993900.stack[R.EXN_STACKHEIGHT++] = $ss39033904;
}
if(R.isPyretException($e38993900)) {
$e38993900.pyretStack.push(L[356]);
}
throw $e38993900;
}
var $ret39053906 = $Hcont_tail_arg12543910($z39013902,if_helper2913897);
++R.GAS;
return $ret39053906;
}
} else {
var cont_tail_arg2933913 = R.throwNonBooleanCondition(L[357],("if"),if_DASH_283882);
if(--R.GAS > 0) {
$z39113912 = R.isFunction(if_helper2913897)?if_helper2913897.app(cont_tail_arg2933913):R.ffi.throwNonFunApp(L[357],if_helper2913897,[cont_tail_arg2933913]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2913897)?if_helper2913897.app(cont_tail_arg2933913):R.ffi.throwNonFunApp(L[357],if_helper2913897,[cont_tail_arg2933913]);
},
"from":L[357]});
}
++R.GAS;
return $z39113912;
}
};
var $Hanf_arg12533898 = function(anf_arg2983896,if_helper2913897,_plus6,raise9) {
var $z39193920 = D;
var $f39253926 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("get: invalid argument: "),anf_arg2983896):R.ffi.throwNonFunApp(L[358],_plus6,[("get: invalid argument: "),anf_arg2983896]);
};
try {
if(--R.GAS > 0) {
$z39193920 = $f39253926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39253926,
"from":L[358]});
}
} catch($e39173918) {
if(R.isCont($e39173918)) {
var $ss39213922 = {"from":L[358],
"go":function(anf_arg2993927) {
return $Hanf_arg12523928(anf_arg2993927,if_helper2913897,raise9);
}};
$e39173918.stack[R.EXN_STACKHEIGHT++] = $ss39213922;
}
if(R.isPyretException($e39173918)) {
$e39173918.pyretStack.push(L[358]);
}
throw $e39173918;
}
var $ret39233924 = $Hanf_arg12523928($z39193920,if_helper2913897,raise9);
++R.GAS;
return $ret39233924;
};
var $Hanf_arg12523928 = function(anf_arg2993927,if_helper2913897,raise9) {
var $z39313932 = D;
var $f39373938 = function(_) {
return R.isFunction(raise9)?raise9.app(anf_arg2993927):R.ffi.throwNonFunApp(L[359],raise9,[anf_arg2993927]);
};
try {
if(--R.GAS > 0) {
$z39313932 = $f39373938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39373938,
"from":L[359]});
}
} catch($e39293930) {
if(R.isCont($e39293930)) {
var $ss39333934 = {"from":L[359],
"go":function(cont_tail_arg3003939) {
return $Hcont_tail_arg12513940(cont_tail_arg3003939,if_helper2913897);
}};
$e39293930.stack[R.EXN_STACKHEIGHT++] = $ss39333934;
}
if(R.isPyretException($e39293930)) {
$e39293930.pyretStack.push(L[359]);
}
throw $e39293930;
}
var $ret39353936 = $Hcont_tail_arg12513940($z39313932,if_helper2913897);
++R.GAS;
return $ret39353936;
};
var $Hcont_tail_arg12513940 = function(cont_tail_arg3003939,if_helper2913897) {
if(--R.GAS > 0) {
$z39413942 = R.isFunction(if_helper2913897)?if_helper2913897.app(cont_tail_arg3003939):R.ffi.throwNonFunApp(L[359],if_helper2913897,[cont_tail_arg3003939]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2913897)?if_helper2913897.app(cont_tail_arg3003939):R.ffi.throwNonFunApp(L[359],if_helper2913897,[cont_tail_arg3003939]);
},
"from":L[359]});
}
++R.GAS;
return $z39413942;
};
var $Hcont_tail_arg12543910 = function(cont_tail_arg2963909,if_helper2913897) {
if(--R.GAS > 0) {
$z39433944 = R.isFunction(if_helper2913897)?if_helper2913897.app(cont_tail_arg2963909):R.ffi.throwNonFunApp(L[356],if_helper2913897,[cont_tail_arg2963909]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2913897)?if_helper2913897.app(cont_tail_arg2963909):R.ffi.throwNonFunApp(L[356],if_helper2913897,[cont_tail_arg2963909]);
},
"from":L[356]});
}
++R.GAS;
return $z39433944;
};
var $Hif_DASH_12503945 = function(if_DASH_273946,cur1553947,help1533883,l1543948,n1523885,_minus5,_plus6,raise9,tostring12) {
var if_helper2723960 = R.makeFunction(function(if_helper_arg2733987) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[365],1,arguments);
}
var ann_DASH_check_DASH_temp2713988 = if_helper_arg2733987;
return ann_DASH_check_DASH_temp2713988;
});
var anf_if2763986 = R.isBoolean(if_DASH_273946);
if(R.isPyretTrue(anf_if2763986)) {
if(R.isPyretTrue(if_DASH_273946)) {
var $z39513952 = D;
var $f39573958 = function(_) {
return R.isFunction(tostring12)?tostring12.app(n1523885):R.ffi.throwNonFunApp(L[360],tostring12,[n1523885]);
};
try {
if(--R.GAS > 0) {
$z39513952 = $f39573958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39573958,
"from":L[360]});
}
} catch($e39493950) {
if(R.isCont($e39493950)) {
var $ss39533954 = {"from":L[360],
"go":function(anf_arg2863959) {
return $Hanf_arg12473961(anf_arg2863959,if_helper2723960,_plus6,raise9);
}};
$e39493950.stack[R.EXN_STACKHEIGHT++] = $ss39533954;
}
if(R.isPyretException($e39493950)) {
$e39493950.pyretStack.push(L[360]);
}
throw $e39493950;
}
var $ret39553956 = $Hanf_arg12473961($z39513952,if_helper2723960,_plus6,raise9);
++R.GAS;
return $ret39553956;
} else {
var if_DASH_263978 = R.equiv(cur1553947,(0));
var anf_if2793982 = R.isBoolean(if_DASH_263978);
if(R.isPyretTrue(anf_if2793982)) {
if(R.isPyretTrue(if_DASH_263978)) {
var cont_tail_arg2843964 = G(l1543948,"first",L[361]);
if(--R.GAS > 0) {
$z39623963 = R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2843964):R.ffi.throwNonFunApp(L[361],if_helper2723960,[cont_tail_arg2843964]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2843964):R.ffi.throwNonFunApp(L[361],if_helper2723960,[cont_tail_arg2843964]);
},
"from":L[361]});
}
++R.GAS;
return $z39623963;
} else {
var anf_arg2803976 = G(l1543948,"rest",L[363]);
var $z39673968 = D;
var $f39733974 = function(_) {
return R.isFunction(_minus5)?_minus5.app(cur1553947,(1)):R.ffi.throwNonFunApp(L[362],_minus5,[cur1553947,(1)]);
};
try {
if(--R.GAS > 0) {
$z39673968 = $f39733974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39733974,
"from":L[362]});
}
} catch($e39653966) {
if(R.isCont($e39653966)) {
var $ss39693970 = {"from":L[362],
"go":function(anf_arg2813975) {
return $Hanf_arg12493977(anf_arg2813975,anf_arg2803976,help1533883,if_helper2723960);
}};
$e39653966.stack[R.EXN_STACKHEIGHT++] = $ss39693970;
}
if(R.isPyretException($e39653966)) {
$e39653966.pyretStack.push(L[362]);
}
throw $e39653966;
}
var $ret39713972 = $Hanf_arg12493977($z39673968,anf_arg2803976,help1533883,if_helper2723960);
++R.GAS;
return $ret39713972;
}
} else {
var cont_tail_arg2773981 = R.throwNonBooleanCondition(L[364],("if"),if_DASH_263978);
if(--R.GAS > 0) {
$z39793980 = R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2773981):R.ffi.throwNonFunApp(L[364],if_helper2723960,[cont_tail_arg2773981]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2773981):R.ffi.throwNonFunApp(L[364],if_helper2723960,[cont_tail_arg2773981]);
},
"from":L[364]});
}
++R.GAS;
return $z39793980;
}
}
} else {
var cont_tail_arg2743985 = R.throwNonBooleanCondition(L[365],("if"),if_DASH_273946);
if(--R.GAS > 0) {
$z39833984 = R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2743985):R.ffi.throwNonFunApp(L[365],if_helper2723960,[cont_tail_arg2743985]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2743985):R.ffi.throwNonFunApp(L[365],if_helper2723960,[cont_tail_arg2743985]);
},
"from":L[365]});
}
++R.GAS;
return $z39833984;
}
};
var $Hanf_arg12473961 = function(anf_arg2863959,if_helper2723960,_plus6,raise9) {
var $z39913992 = D;
var $f39973998 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("get: n too large "),anf_arg2863959):R.ffi.throwNonFunApp(L[366],_plus6,[("get: n too large "),anf_arg2863959]);
};
try {
if(--R.GAS > 0) {
$z39913992 = $f39973998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39973998,
"from":L[366]});
}
} catch($e39893990) {
if(R.isCont($e39893990)) {
var $ss39933994 = {"from":L[366],
"go":function(anf_arg2873999) {
return $Hanf_arg12464000(anf_arg2873999,if_helper2723960,raise9);
}};
$e39893990.stack[R.EXN_STACKHEIGHT++] = $ss39933994;
}
if(R.isPyretException($e39893990)) {
$e39893990.pyretStack.push(L[366]);
}
throw $e39893990;
}
var $ret39953996 = $Hanf_arg12464000($z39913992,if_helper2723960,raise9);
++R.GAS;
return $ret39953996;
};
var $Hanf_arg12464000 = function(anf_arg2873999,if_helper2723960,raise9) {
var $z40034004 = D;
var $f40094010 = function(_) {
return R.isFunction(raise9)?raise9.app(anf_arg2873999):R.ffi.throwNonFunApp(L[367],raise9,[anf_arg2873999]);
};
try {
if(--R.GAS > 0) {
$z40034004 = $f40094010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40094010,
"from":L[367]});
}
} catch($e40014002) {
if(R.isCont($e40014002)) {
var $ss40054006 = {"from":L[367],
"go":function(cont_tail_arg2884011) {
return $Hcont_tail_arg12454012(cont_tail_arg2884011,if_helper2723960);
}};
$e40014002.stack[R.EXN_STACKHEIGHT++] = $ss40054006;
}
if(R.isPyretException($e40014002)) {
$e40014002.pyretStack.push(L[367]);
}
throw $e40014002;
}
var $ret40074008 = $Hcont_tail_arg12454012($z40034004,if_helper2723960);
++R.GAS;
return $ret40074008;
};
var $Hcont_tail_arg12454012 = function(cont_tail_arg2884011,if_helper2723960) {
if(--R.GAS > 0) {
$z40134014 = R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2884011):R.ffi.throwNonFunApp(L[367],if_helper2723960,[cont_tail_arg2884011]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2884011):R.ffi.throwNonFunApp(L[367],if_helper2723960,[cont_tail_arg2884011]);
},
"from":L[367]});
}
++R.GAS;
return $z40134014;
};
var $Hanf_arg12493977 = function(anf_arg2813975,anf_arg2803976,help1533883,if_helper2723960) {
var $z40174018 = D;
var $f40234024 = function(_) {
return R.isFunction(help1533883.$var)?help1533883.$var.app(anf_arg2803976,anf_arg2813975):R.ffi.throwNonFunApp(L[368],help1533883.$var,[anf_arg2803976,anf_arg2813975]);
};
try {
if(--R.GAS > 0) {
$z40174018 = $f40234024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40234024,
"from":L[368]});
}
} catch($e40154016) {
if(R.isCont($e40154016)) {
var $ss40194020 = {"from":L[368],
"go":function(cont_tail_arg2824025) {
return $Hcont_tail_arg12484026(cont_tail_arg2824025,if_helper2723960);
}};
$e40154016.stack[R.EXN_STACKHEIGHT++] = $ss40194020;
}
if(R.isPyretException($e40154016)) {
$e40154016.pyretStack.push(L[368]);
}
throw $e40154016;
}
var $ret40214022 = $Hcont_tail_arg12484026($z40174018,if_helper2723960);
++R.GAS;
return $ret40214022;
};
var $Hcont_tail_arg12484026 = function(cont_tail_arg2824025,if_helper2723960) {
if(--R.GAS > 0) {
$z40274028 = R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2824025):R.ffi.throwNonFunApp(L[368],if_helper2723960,[cont_tail_arg2824025]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2723960)?if_helper2723960.app(cont_tail_arg2824025):R.ffi.throwNonFunApp(L[368],if_helper2723960,[cont_tail_arg2824025]);
},
"from":L[368]});
}
++R.GAS;
return $z40274028;
};
var $Hif_DASH_12444029 = function(if_DASH_254030,self1344031,str1354032,_plus6,tostring12) {
var if_helper2464045 = R.makeFunction(function(if_helper_arg2474064) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[373],1,arguments);
}
var ann_DASH_check_DASH_temp2444065 = if_helper_arg2474064;
return ann_DASH_check_DASH_temp2444065;
});
var anf_if2504063 = R.isBoolean(if_DASH_254030);
if(R.isPyretTrue(anf_if2504063)) {
if(R.isPyretTrue(if_DASH_254030)) {
var anf_arg2544043 = G(self1344031,"first",L[370]);
var $z40354036 = D;
var $f40414042 = function(_) {
return R.isFunction(tostring12)?tostring12.app(anf_arg2544043):R.ffi.throwNonFunApp(L[369],tostring12,[anf_arg2544043]);
};
try {
if(--R.GAS > 0) {
$z40354036 = $f40414042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40414042,
"from":L[369]});
}
} catch($e40334034) {
if(R.isCont($e40334034)) {
var $ss40374038 = {"from":L[369],
"go":function(anf_arg2554044) {
return $Hanf_arg12424046(anf_arg2554044,if_helper2464045,self1344031,str1354032,_plus6);
}};
$e40334034.stack[R.EXN_STACKHEIGHT++] = $ss40374038;
}
if(R.isPyretException($e40334034)) {
$e40334034.pyretStack.push(L[369]);
}
throw $e40334034;
}
var $ret40394040 = $Hanf_arg12424046($z40354036,if_helper2464045,self1344031,str1354032,_plus6);
++R.GAS;
return $ret40394040;
} else {
var anf_arg2514057 = G(self1344031,"first",L[372]);
var $z40494050 = D;
var $f40554056 = function(_) {
return R.isFunction(tostring12)?tostring12.app(anf_arg2514057):R.ffi.throwNonFunApp(L[371],tostring12,[anf_arg2514057]);
};
try {
if(--R.GAS > 0) {
$z40494050 = $f40554056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40554056,
"from":L[371]});
}
} catch($e40474048) {
if(R.isCont($e40474048)) {
var $ss40514052 = {"from":L[371],
"go":function(cont_tail_arg2524058) {
return $Hcont_tail_arg12434059(cont_tail_arg2524058,if_helper2464045);
}};
$e40474048.stack[R.EXN_STACKHEIGHT++] = $ss40514052;
}
if(R.isPyretException($e40474048)) {
$e40474048.pyretStack.push(L[371]);
}
throw $e40474048;
}
var $ret40534054 = $Hcont_tail_arg12434059($z40494050,if_helper2464045);
++R.GAS;
return $ret40534054;
}
} else {
var cont_tail_arg2484062 = R.throwNonBooleanCondition(L[373],("if"),if_DASH_254030);
if(--R.GAS > 0) {
$z40604061 = R.isFunction(if_helper2464045)?if_helper2464045.app(cont_tail_arg2484062):R.ffi.throwNonFunApp(L[373],if_helper2464045,[cont_tail_arg2484062]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2464045)?if_helper2464045.app(cont_tail_arg2484062):R.ffi.throwNonFunApp(L[373],if_helper2464045,[cont_tail_arg2484062]);
},
"from":L[373]});
}
++R.GAS;
return $z40604061;
}
};
var $Hanf_arg12424046 = function(anf_arg2554044,if_helper2464045,self1344031,str1354032,_plus6) {
var $z40684069 = D;
var $f40744075 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg2554044,str1354032):R.ffi.throwNonFunApp(L[374],_plus6,[anf_arg2554044,str1354032]);
};
try {
if(--R.GAS > 0) {
$z40684069 = $f40744075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40744075,
"from":L[374]});
}
} catch($e40664067) {
if(R.isCont($e40664067)) {
var $ss40704071 = {"from":L[374],
"go":function(anf_arg2564076) {
return $Hanf_arg12414077(anf_arg2564076,if_helper2464045,self1344031,str1354032,_plus6);
}};
$e40664067.stack[R.EXN_STACKHEIGHT++] = $ss40704071;
}
if(R.isPyretException($e40664067)) {
$e40664067.pyretStack.push(L[374]);
}
throw $e40664067;
}
var $ret40724073 = $Hanf_arg12414077($z40684069,if_helper2464045,self1344031,str1354032,_plus6);
++R.GAS;
return $ret40724073;
};
var $Hanf_arg12414077 = function(anf_arg2564076,if_helper2464045,self1344031,str1354032,_plus6) {
var anf_bracket2574091 = G(self1344031,"rest",L[377]);
var anf_fun2584088 = G(anf_bracket2574091,"join-str",L[376]);
var $z40804081 = D;
var $f40864087 = function(_) {
return R.isFunction(anf_fun2584088)?anf_fun2584088.app(str1354032):R.ffi.throwNonFunApp(L[375],anf_fun2584088,[str1354032]);
};
try {
if(--R.GAS > 0) {
$z40804081 = $f40864087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40864087,
"from":L[375]});
}
} catch($e40784079) {
if(R.isCont($e40784079)) {
var $ss40824083 = {"from":L[375],
"go":function(anf_arg2594089) {
return $Hanf_arg12404090(anf_arg2594089,anf_arg2564076,if_helper2464045,_plus6);
}};
$e40784079.stack[R.EXN_STACKHEIGHT++] = $ss40824083;
}
if(R.isPyretException($e40784079)) {
$e40784079.pyretStack.push(L[375]);
}
throw $e40784079;
}
var $ret40844085 = $Hanf_arg12404090($z40804081,anf_arg2564076,if_helper2464045,_plus6);
++R.GAS;
return $ret40844085;
};
var $Hanf_arg12404090 = function(anf_arg2594089,anf_arg2564076,if_helper2464045,_plus6) {
var $z40944095 = D;
var $f41004101 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg2564076,anf_arg2594089):R.ffi.throwNonFunApp(L[374],_plus6,[anf_arg2564076,anf_arg2594089]);
};
try {
if(--R.GAS > 0) {
$z40944095 = $f41004101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41004101,
"from":L[374]});
}
} catch($e40924093) {
if(R.isCont($e40924093)) {
var $ss40964097 = {"from":L[374],
"go":function(cont_tail_arg2604102) {
return $Hcont_tail_arg12394103(cont_tail_arg2604102,if_helper2464045);
}};
$e40924093.stack[R.EXN_STACKHEIGHT++] = $ss40964097;
}
if(R.isPyretException($e40924093)) {
$e40924093.pyretStack.push(L[374]);
}
throw $e40924093;
}
var $ret40984099 = $Hcont_tail_arg12394103($z40944095,if_helper2464045);
++R.GAS;
return $ret40984099;
};
var $Hcont_tail_arg12394103 = function(cont_tail_arg2604102,if_helper2464045) {
if(--R.GAS > 0) {
$z41044105 = R.isFunction(if_helper2464045)?if_helper2464045.app(cont_tail_arg2604102):R.ffi.throwNonFunApp(L[374],if_helper2464045,[cont_tail_arg2604102]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2464045)?if_helper2464045.app(cont_tail_arg2604102):R.ffi.throwNonFunApp(L[374],if_helper2464045,[cont_tail_arg2604102]);
},
"from":L[374]});
}
++R.GAS;
return $z41044105;
};
var $Hcont_tail_arg12434059 = function(cont_tail_arg2524058,if_helper2464045) {
if(--R.GAS > 0) {
$z41064107 = R.isFunction(if_helper2464045)?if_helper2464045.app(cont_tail_arg2524058):R.ffi.throwNonFunApp(L[371],if_helper2464045,[cont_tail_arg2524058]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2464045)?if_helper2464045.app(cont_tail_arg2524058):R.ffi.throwNonFunApp(L[371],if_helper2464045,[cont_tail_arg2524058]);
},
"from":L[371]});
}
++R.GAS;
return $z41064107;
};
var $Hann_DASH_check_DASH_temp12384108 = function(ann_DASH_check_DASH_temp2374109) {
return ann_DASH_check_DASH_temp2374109;
};
var $Hann_DASH_check_DASH_temp12374110 = function(ann_DASH_check_DASH_temp2394111) {
return ann_DASH_check_DASH_temp2394111;
};
var $Hanf_begin_app_dropped12364112 = function(anf_begin_app_dropped12314113,are_DASH_eq1234114,are_DASH_gt1244115,are_DASH_lt1224116,cmp1194117,eq1204118) {
var anf_fun2314129 = G(are_DASH_lt1224116.$var,"sort-by",L[379]);
var $z41214122 = D;
var $f41274128 = function(_) {
return R.isFunction(anf_fun2314129)?anf_fun2314129.app(cmp1194117,eq1204118):R.ffi.throwNonFunApp(L[378],anf_fun2314129,[cmp1194117,eq1204118]);
};
try {
if(--R.GAS > 0) {
$z41214122 = $f41274128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41274128,
"from":L[378]});
}
} catch($e41194120) {
if(R.isCont($e41194120)) {
var $ss41234124 = {"from":L[378],
"go":function(less1264130) {
return $Hless12354131(less1264130,are_DASH_eq1234114,are_DASH_gt1244115,cmp1194117,eq1204118);
}};
$e41194120.stack[R.EXN_STACKHEIGHT++] = $ss41234124;
}
if(R.isPyretException($e41194120)) {
$e41194120.pyretStack.push(L[378]);
}
throw $e41194120;
}
var $ret41254126 = $Hless12354131($z41214122,are_DASH_eq1234114,are_DASH_gt1244115,cmp1194117,eq1204118);
++R.GAS;
return $ret41254126;
};
var $Hless12354131 = function(less1264130,are_DASH_eq1234114,are_DASH_gt1244115,cmp1194117,eq1204118) {
var equal1274144 = are_DASH_eq1234114.$var;
var anf_fun2324142 = G(are_DASH_gt1244115.$var,"sort-by",L[381]);
var $z41344135 = D;
var $f41404141 = function(_) {
return R.isFunction(anf_fun2324142)?anf_fun2324142.app(cmp1194117,eq1204118):R.ffi.throwNonFunApp(L[380],anf_fun2324142,[cmp1194117,eq1204118]);
};
try {
if(--R.GAS > 0) {
$z41344135 = $f41404141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41404141,
"from":L[380]});
}
} catch($e41324133) {
if(R.isCont($e41324133)) {
var $ss41364137 = {"from":L[380],
"go":function(greater1284143) {
return $Hgreater12344145(greater1284143,equal1274144,less1264130);
}};
$e41324133.stack[R.EXN_STACKHEIGHT++] = $ss41364137;
}
if(R.isPyretException($e41324133)) {
$e41324133.pyretStack.push(L[380]);
}
throw $e41324133;
}
var $ret41384139 = $Hgreater12344145($z41344135,equal1274144,less1264130);
++R.GAS;
return $ret41384139;
};
var $Hgreater12344145 = function(greater1284143,equal1274144,less1264130) {
var anf_fun2334158 = G(less1264130,"append",L[384]);
var anf_fun2344156 = G(equal1274144,"append",L[383]);
var $z41484149 = D;
var $f41544155 = function(_) {
return R.isFunction(anf_fun2344156)?anf_fun2344156.app(greater1284143):R.ffi.throwNonFunApp(L[382],anf_fun2344156,[greater1284143]);
};
try {
if(--R.GAS > 0) {
$z41484149 = $f41544155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41544155,
"from":L[382]});
}
} catch($e41464147) {
if(R.isCont($e41464147)) {
var $ss41504151 = {"from":L[382],
"go":function(anf_arg2354157) {
return $Hanf_arg12334159(anf_arg2354157,anf_fun2334158);
}};
$e41464147.stack[R.EXN_STACKHEIGHT++] = $ss41504151;
}
if(R.isPyretException($e41464147)) {
$e41464147.pyretStack.push(L[382]);
}
throw $e41464147;
}
var $ret41524153 = $Hanf_arg12334159($z41484149,anf_fun2334158);
++R.GAS;
return $ret41524153;
};
var $Hanf_arg12334159 = function(anf_arg2354157,anf_fun2334158) {
var $z41624163 = D;
var $f41684169 = function(_) {
return R.isFunction(anf_fun2334158)?anf_fun2334158.app(anf_arg2354157):R.ffi.throwNonFunApp(L[385],anf_fun2334158,[anf_arg2354157]);
};
try {
if(--R.GAS > 0) {
$z41624163 = $f41684169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41684169,
"from":L[385]});
}
} catch($e41604161) {
if(R.isCont($e41604161)) {
var $ss41644165 = {"from":L[385],
"go":function(ann_DASH_check_DASH_temp2044170) {
return $Hann_DASH_check_DASH_temp12324171(ann_DASH_check_DASH_temp2044170);
}};
$e41604161.stack[R.EXN_STACKHEIGHT++] = $ss41644165;
}
if(R.isPyretException($e41604161)) {
$e41604161.pyretStack.push(L[385]);
}
throw $e41604161;
}
var $ret41664167 = $Hann_DASH_check_DASH_temp12324171($z41624163);
++R.GAS;
return $ret41664167;
};
var $Hann_DASH_check_DASH_temp12324171 = function(ann_DASH_check_DASH_temp2044170) {
return ann_DASH_check_DASH_temp2044170;
};
var $Hif_DASH_12304172 = function(if_DASH_234173,are_DASH_eq1234114,are_DASH_gt1244115,are_DASH_lt1224116,e1254174,eq1204118,link211585,pivot1214175) {
var if_helper2074188 = R.makeFunction(function(if_helper_arg2084219) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[389],1,arguments);
}
var ann_DASH_check_DASH_temp2064220 = if_helper_arg2084219;
return ann_DASH_check_DASH_temp2064220;
});
var anf_if2114218 = R.isBoolean(if_DASH_234173);
if(R.isPyretTrue(anf_if2114218)) {
if(R.isPyretTrue(if_DASH_234173)) {
var anf_fun2264186 = R.makeFunction(function(arg_DASH_244190) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[386],1,arguments);
}
var $z41934194 = D;
var $f41994200 = function(_) {
return R.isFunction(link211585.$var === D?U(L[387],"link"):link211585.$var)?link211585.$var === D?U(L[387],"link"):link211585.$var.app(arg_DASH_244190,are_DASH_lt1224116.$var):R.ffi.throwNonFunApp(L[386],link211585.$var === D?U(L[387],"link"):link211585.$var,[arg_DASH_244190,are_DASH_lt1224116.$var]);
};
try {
if(--R.GAS > 0) {
$z41934194 = $f41994200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41994200,
"from":L[386]});
}
} catch($e41914192) {
if(R.isCont($e41914192)) {
var $ss41954196 = {"from":L[386],
"go":function(ann_DASH_check_DASH_temp2254201) {
return $Hann_DASH_check_DASH_temp12234202(ann_DASH_check_DASH_temp2254201);
}};
$e41914192.stack[R.EXN_STACKHEIGHT++] = $ss41954196;
}
if(R.isPyretException($e41914192)) {
$e41914192.pyretStack.push(L[386]);
}
throw $e41914192;
}
var $ret41974198 = $Hann_DASH_check_DASH_temp12234202($z41934194);
++R.GAS;
return $ret41974198;
});
var $z41784179 = D;
var $f41844185 = function(_) {
return R.isFunction(anf_fun2264186)?anf_fun2264186.app(e1254174):R.ffi.throwNonFunApp(L[386],anf_fun2264186,[e1254174]);
};
try {
if(--R.GAS > 0) {
$z41784179 = $f41844185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41844185,
"from":L[386]});
}
} catch($e41764177) {
if(R.isCont($e41764177)) {
var $ss41804181 = {"from":L[386],
"go":function(anf_assign2274187) {
return $Hanf_assign12244189(anf_assign2274187,are_DASH_lt1224116,if_helper2074188);
}};
$e41764177.stack[R.EXN_STACKHEIGHT++] = $ss41804181;
}
if(R.isPyretException($e41764177)) {
$e41764177.pyretStack.push(L[386]);
}
throw $e41764177;
}
var $ret41824183 = $Hanf_assign12244189($z41784179,are_DASH_lt1224116,if_helper2074188);
++R.GAS;
return $ret41824183;
} else {
var $z42054206 = D;
var $f42114212 = function(_) {
return R.isFunction(eq1204118)?eq1204118.app(e1254174,pivot1214175):R.ffi.throwNonFunApp(L[388],eq1204118,[e1254174,pivot1214175]);
};
try {
if(--R.GAS > 0) {
$z42054206 = $f42114212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42114212,
"from":L[388]});
}
} catch($e42034204) {
if(R.isCont($e42034204)) {
var $ss42074208 = {"from":L[388],
"go":function(if_DASH_214213) {
return $Hif_DASH_12294214(if_DASH_214213,are_DASH_eq1234114,are_DASH_gt1244115,e1254174,if_helper2074188,link211585);
}};
$e42034204.stack[R.EXN_STACKHEIGHT++] = $ss42074208;
}
if(R.isPyretException($e42034204)) {
$e42034204.pyretStack.push(L[388]);
}
throw $e42034204;
}
var $ret42094210 = $Hif_DASH_12294214($z42054206,are_DASH_eq1234114,are_DASH_gt1244115,e1254174,if_helper2074188,link211585);
++R.GAS;
return $ret42094210;
}
} else {
var cont_tail_arg2094217 = R.throwNonBooleanCondition(L[389],("if"),if_DASH_234173);
if(--R.GAS > 0) {
$z42154216 = R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2094217):R.ffi.throwNonFunApp(L[389],if_helper2074188,[cont_tail_arg2094217]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2094217):R.ffi.throwNonFunApp(L[389],if_helper2074188,[cont_tail_arg2094217]);
},
"from":L[389]});
}
++R.GAS;
return $z42154216;
}
};
var $Hanf_assign12244189 = function(anf_assign2274187,are_DASH_lt1224116,if_helper2074188) {
var cont_tail_arg2284223 = are_DASH_lt1224116.$var = anf_assign2274187;
if(--R.GAS > 0) {
$z42214222 = R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2284223):R.ffi.throwNonFunApp(L[390],if_helper2074188,[cont_tail_arg2284223]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2284223):R.ffi.throwNonFunApp(L[390],if_helper2074188,[cont_tail_arg2284223]);
},
"from":L[390]});
}
++R.GAS;
return $z42214222;
};
var $Hann_DASH_check_DASH_temp12234202 = function(ann_DASH_check_DASH_temp2254201) {
return ann_DASH_check_DASH_temp2254201;
};
var $Hif_DASH_12294214 = function(if_DASH_214213,are_DASH_eq1234114,are_DASH_gt1244115,e1254174,if_helper2074188,link211585) {
var anf_if2144279 = R.isBoolean(if_DASH_214213);
if(R.isPyretTrue(anf_if2144279)) {
if(R.isPyretTrue(if_DASH_214213)) {
var anf_fun2214234 = R.makeFunction(function(arg_DASH_224237) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[391],1,arguments);
}
var $z42404241 = D;
var $f42464247 = function(_) {
return R.isFunction(link211585.$var === D?U(L[392],"link"):link211585.$var)?link211585.$var === D?U(L[392],"link"):link211585.$var.app(arg_DASH_224237,are_DASH_eq1234114.$var):R.ffi.throwNonFunApp(L[391],link211585.$var === D?U(L[392],"link"):link211585.$var,[arg_DASH_224237,are_DASH_eq1234114.$var]);
};
try {
if(--R.GAS > 0) {
$z42404241 = $f42464247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42464247,
"from":L[391]});
}
} catch($e42384239) {
if(R.isCont($e42384239)) {
var $ss42424243 = {"from":L[391],
"go":function(ann_DASH_check_DASH_temp2204248) {
return $Hann_DASH_check_DASH_temp12254249(ann_DASH_check_DASH_temp2204248);
}};
$e42384239.stack[R.EXN_STACKHEIGHT++] = $ss42424243;
}
if(R.isPyretException($e42384239)) {
$e42384239.pyretStack.push(L[391]);
}
throw $e42384239;
}
var $ret42444245 = $Hann_DASH_check_DASH_temp12254249($z42404241);
++R.GAS;
return $ret42444245;
});
var $z42264227 = D;
var $f42324233 = function(_) {
return R.isFunction(anf_fun2214234)?anf_fun2214234.app(e1254174):R.ffi.throwNonFunApp(L[391],anf_fun2214234,[e1254174]);
};
try {
if(--R.GAS > 0) {
$z42264227 = $f42324233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42324233,
"from":L[391]});
}
} catch($e42244225) {
if(R.isCont($e42244225)) {
var $ss42284229 = {"from":L[391],
"go":function(anf_assign2224235) {
return $Hanf_assign12264236(anf_assign2224235,are_DASH_eq1234114,if_helper2074188);
}};
$e42244225.stack[R.EXN_STACKHEIGHT++] = $ss42284229;
}
if(R.isPyretException($e42244225)) {
$e42244225.pyretStack.push(L[391]);
}
throw $e42244225;
}
var $ret42304231 = $Hanf_assign12264236($z42264227,are_DASH_eq1234114,if_helper2074188);
++R.GAS;
return $ret42304231;
} else {
var anf_fun2164260 = R.makeFunction(function(arg_DASH_204263) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[393],1,arguments);
}
var $z42664267 = D;
var $f42724273 = function(_) {
return R.isFunction(link211585.$var === D?U(L[394],"link"):link211585.$var)?link211585.$var === D?U(L[394],"link"):link211585.$var.app(arg_DASH_204263,are_DASH_gt1244115.$var):R.ffi.throwNonFunApp(L[393],link211585.$var === D?U(L[394],"link"):link211585.$var,[arg_DASH_204263,are_DASH_gt1244115.$var]);
};
try {
if(--R.GAS > 0) {
$z42664267 = $f42724273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42724273,
"from":L[393]});
}
} catch($e42644265) {
if(R.isCont($e42644265)) {
var $ss42684269 = {"from":L[393],
"go":function(ann_DASH_check_DASH_temp2154274) {
return $Hann_DASH_check_DASH_temp12274275(ann_DASH_check_DASH_temp2154274);
}};
$e42644265.stack[R.EXN_STACKHEIGHT++] = $ss42684269;
}
if(R.isPyretException($e42644265)) {
$e42644265.pyretStack.push(L[393]);
}
throw $e42644265;
}
var $ret42704271 = $Hann_DASH_check_DASH_temp12274275($z42664267);
++R.GAS;
return $ret42704271;
});
var $z42524253 = D;
var $f42584259 = function(_) {
return R.isFunction(anf_fun2164260)?anf_fun2164260.app(e1254174):R.ffi.throwNonFunApp(L[393],anf_fun2164260,[e1254174]);
};
try {
if(--R.GAS > 0) {
$z42524253 = $f42584259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42584259,
"from":L[393]});
}
} catch($e42504251) {
if(R.isCont($e42504251)) {
var $ss42544255 = {"from":L[393],
"go":function(anf_assign2174261) {
return $Hanf_assign12284262(anf_assign2174261,are_DASH_gt1244115,if_helper2074188);
}};
$e42504251.stack[R.EXN_STACKHEIGHT++] = $ss42544255;
}
if(R.isPyretException($e42504251)) {
$e42504251.pyretStack.push(L[393]);
}
throw $e42504251;
}
var $ret42564257 = $Hanf_assign12284262($z42524253,are_DASH_gt1244115,if_helper2074188);
++R.GAS;
return $ret42564257;
}
} else {
var cont_tail_arg2124278 = R.throwNonBooleanCondition(L[395],("if"),if_DASH_214213);
if(--R.GAS > 0) {
$z42764277 = R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2124278):R.ffi.throwNonFunApp(L[395],if_helper2074188,[cont_tail_arg2124278]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2124278):R.ffi.throwNonFunApp(L[395],if_helper2074188,[cont_tail_arg2124278]);
},
"from":L[395]});
}
++R.GAS;
return $z42764277;
}
};
var $Hanf_assign12264236 = function(anf_assign2224235,are_DASH_eq1234114,if_helper2074188) {
var cont_tail_arg2234282 = are_DASH_eq1234114.$var = anf_assign2224235;
if(--R.GAS > 0) {
$z42804281 = R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2234282):R.ffi.throwNonFunApp(L[396],if_helper2074188,[cont_tail_arg2234282]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2234282):R.ffi.throwNonFunApp(L[396],if_helper2074188,[cont_tail_arg2234282]);
},
"from":L[396]});
}
++R.GAS;
return $z42804281;
};
var $Hann_DASH_check_DASH_temp12254249 = function(ann_DASH_check_DASH_temp2204248) {
return ann_DASH_check_DASH_temp2204248;
};
var $Hanf_assign12284262 = function(anf_assign2174261,are_DASH_gt1244115,if_helper2074188) {
var cont_tail_arg2184285 = are_DASH_gt1244115.$var = anf_assign2174261;
if(--R.GAS > 0) {
$z42834284 = R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2184285):R.ffi.throwNonFunApp(L[397],if_helper2074188,[cont_tail_arg2184285]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper2074188)?if_helper2074188.app(cont_tail_arg2184285):R.ffi.throwNonFunApp(L[397],if_helper2074188,[cont_tail_arg2184285]);
},
"from":L[397]});
}
++R.GAS;
return $z42834284;
};
var $Hann_DASH_check_DASH_temp12274275 = function(ann_DASH_check_DASH_temp2154274) {
return ann_DASH_check_DASH_temp2154274;
};
var $Hanf_arg12224286 = function(anf_arg1994287,anf_arg1974288,fold51518,self1154289,_plus6) {
var anf_arg2004300 = G(self1154289,"rest",L[400]);
var $z42924293 = D;
var $f42984299 = function(_) {
return R.isFunction(fold51518.$var === D?U(L[398],"fold"):fold51518.$var)?fold51518.$var === D?U(L[398],"fold"):fold51518.$var.app(anf_arg1974288,anf_arg1994287,anf_arg2004300):R.ffi.throwNonFunApp(L[399],fold51518.$var === D?U(L[398],"fold"):fold51518.$var,[anf_arg1974288,anf_arg1994287,anf_arg2004300]);
};
try {
if(--R.GAS > 0) {
$z42924293 = $f42984299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42984299,
"from":L[399]});
}
} catch($e42904291) {
if(R.isCont($e42904291)) {
var $ss42944295 = {"from":L[399],
"go":function(anf_arg2014301) {
return $Hanf_arg12214302(anf_arg2014301,_plus6);
}};
$e42904291.stack[R.EXN_STACKHEIGHT++] = $ss42944295;
}
if(R.isPyretException($e42904291)) {
$e42904291.pyretStack.push(L[399]);
}
throw $e42904291;
}
var $ret42964297 = $Hanf_arg12214302($z42924293,_plus6);
++R.GAS;
return $ret42964297;
};
var $Hanf_arg12214302 = function(anf_arg2014301,_plus6) {
var $z43054306 = D;
var $f43114312 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("[list: "),anf_arg2014301):R.ffi.throwNonFunApp(L[401],_plus6,[("[list: "),anf_arg2014301]);
};
try {
if(--R.GAS > 0) {
$z43054306 = $f43114312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43114312,
"from":L[401]});
}
} catch($e43034304) {
if(R.isCont($e43034304)) {
var $ss43074308 = {"from":L[401],
"go":function(anf_arg2024313) {
return $Hanf_arg12204314(anf_arg2024313,_plus6);
}};
$e43034304.stack[R.EXN_STACKHEIGHT++] = $ss43074308;
}
if(R.isPyretException($e43034304)) {
$e43034304.pyretStack.push(L[401]);
}
throw $e43034304;
}
var $ret43094310 = $Hanf_arg12204314($z43054306,_plus6);
++R.GAS;
return $ret43094310;
};
var $Hanf_arg12204314 = function(anf_arg2024313,_plus6) {
var $z43174318 = D;
var $f43234324 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg2024313,("]")):R.ffi.throwNonFunApp(L[402],_plus6,[anf_arg2024313,("]")]);
};
try {
if(--R.GAS > 0) {
$z43174318 = $f43234324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43234324,
"from":L[402]});
}
} catch($e43154316) {
if(R.isCont($e43154316)) {
var $ss43194320 = {"from":L[402],
"go":function(ann_DASH_check_DASH_temp1934325) {
return $Hann_DASH_check_DASH_temp12194326(ann_DASH_check_DASH_temp1934325);
}};
$e43154316.stack[R.EXN_STACKHEIGHT++] = $ss43194320;
}
if(R.isPyretException($e43154316)) {
$e43154316.pyretStack.push(L[402]);
}
throw $e43154316;
}
var $ret43214322 = $Hann_DASH_check_DASH_temp12194326($z43174318);
++R.GAS;
return $ret43214322;
};
var $Hann_DASH_check_DASH_temp12194326 = function(ann_DASH_check_DASH_temp1934325) {
return ann_DASH_check_DASH_temp1934325;
};
var $Hanf_arg12184327 = function(anf_arg1954328,elt1174329,_plus6,torepr11) {
var $z43324333 = D;
var $f43384339 = function(_) {
return R.isFunction(torepr11)?torepr11.app(elt1174329):R.ffi.throwNonFunApp(L[403],torepr11,[elt1174329]);
};
try {
if(--R.GAS > 0) {
$z43324333 = $f43384339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43384339,
"from":L[403]});
}
} catch($e43304331) {
if(R.isCont($e43304331)) {
var $ss43344335 = {"from":L[403],
"go":function(anf_arg1964340) {
return $Hanf_arg12174341(anf_arg1964340,anf_arg1954328,_plus6);
}};
$e43304331.stack[R.EXN_STACKHEIGHT++] = $ss43344335;
}
if(R.isPyretException($e43304331)) {
$e43304331.pyretStack.push(L[403]);
}
throw $e43304331;
}
var $ret43364337 = $Hanf_arg12174341($z43324333,anf_arg1954328,_plus6);
++R.GAS;
return $ret43364337;
};
var $Hanf_arg12174341 = function(anf_arg1964340,anf_arg1954328,_plus6) {
var $z43444345 = D;
var $f43504351 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg1954328,anf_arg1964340):R.ffi.throwNonFunApp(L[399],_plus6,[anf_arg1954328,anf_arg1964340]);
};
try {
if(--R.GAS > 0) {
$z43444345 = $f43504351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43504351,
"from":L[399]});
}
} catch($e43424343) {
if(R.isCont($e43424343)) {
var $ss43464347 = {"from":L[399],
"go":function(ann_DASH_check_DASH_temp1944352) {
return $Hann_DASH_check_DASH_temp12164353(ann_DASH_check_DASH_temp1944352);
}};
$e43424343.stack[R.EXN_STACKHEIGHT++] = $ss43464347;
}
if(R.isPyretException($e43424343)) {
$e43424343.pyretStack.push(L[399]);
}
throw $e43424343;
}
var $ret43484349 = $Hann_DASH_check_DASH_temp12164353($z43444345);
++R.GAS;
return $ret43484349;
};
var $Hann_DASH_check_DASH_temp12164353 = function(ann_DASH_check_DASH_temp1944352) {
return ann_DASH_check_DASH_temp1944352;
};
var $Hanf_arg12154354 = function(anf_arg1884355,anf_arg1864356,fold51518,self1124357,_plus6) {
var anf_arg1894368 = G(self1124357,"rest",L[406]);
var $z43604361 = D;
var $f43664367 = function(_) {
return R.isFunction(fold51518.$var === D?U(L[404],"fold"):fold51518.$var)?fold51518.$var === D?U(L[404],"fold"):fold51518.$var.app(anf_arg1864356,anf_arg1884355,anf_arg1894368):R.ffi.throwNonFunApp(L[405],fold51518.$var === D?U(L[404],"fold"):fold51518.$var,[anf_arg1864356,anf_arg1884355,anf_arg1894368]);
};
try {
if(--R.GAS > 0) {
$z43604361 = $f43664367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43664367,
"from":L[405]});
}
} catch($e43584359) {
if(R.isCont($e43584359)) {
var $ss43624363 = {"from":L[405],
"go":function(anf_arg1904369) {
return $Hanf_arg12144370(anf_arg1904369,_plus6);
}};
$e43584359.stack[R.EXN_STACKHEIGHT++] = $ss43624363;
}
if(R.isPyretException($e43584359)) {
$e43584359.pyretStack.push(L[405]);
}
throw $e43584359;
}
var $ret43644365 = $Hanf_arg12144370($z43604361,_plus6);
++R.GAS;
return $ret43644365;
};
var $Hanf_arg12144370 = function(anf_arg1904369,_plus6) {
var $z43734374 = D;
var $f43794380 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("[list: "),anf_arg1904369):R.ffi.throwNonFunApp(L[407],_plus6,[("[list: "),anf_arg1904369]);
};
try {
if(--R.GAS > 0) {
$z43734374 = $f43794380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43794380,
"from":L[407]});
}
} catch($e43714372) {
if(R.isCont($e43714372)) {
var $ss43754376 = {"from":L[407],
"go":function(anf_arg1914381) {
return $Hanf_arg12134382(anf_arg1914381,_plus6);
}};
$e43714372.stack[R.EXN_STACKHEIGHT++] = $ss43754376;
}
if(R.isPyretException($e43714372)) {
$e43714372.pyretStack.push(L[407]);
}
throw $e43714372;
}
var $ret43774378 = $Hanf_arg12134382($z43734374,_plus6);
++R.GAS;
return $ret43774378;
};
var $Hanf_arg12134382 = function(anf_arg1914381,_plus6) {
var $z43854386 = D;
var $f43914392 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg1914381,("]")):R.ffi.throwNonFunApp(L[408],_plus6,[anf_arg1914381,("]")]);
};
try {
if(--R.GAS > 0) {
$z43854386 = $f43914392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43914392,
"from":L[408]});
}
} catch($e43834384) {
if(R.isCont($e43834384)) {
var $ss43874388 = {"from":L[408],
"go":function(ann_DASH_check_DASH_temp1824393) {
return $Hann_DASH_check_DASH_temp12124394(ann_DASH_check_DASH_temp1824393);
}};
$e43834384.stack[R.EXN_STACKHEIGHT++] = $ss43874388;
}
if(R.isPyretException($e43834384)) {
$e43834384.pyretStack.push(L[408]);
}
throw $e43834384;
}
var $ret43894390 = $Hann_DASH_check_DASH_temp12124394($z43854386);
++R.GAS;
return $ret43894390;
};
var $Hann_DASH_check_DASH_temp12124394 = function(ann_DASH_check_DASH_temp1824393) {
return ann_DASH_check_DASH_temp1824393;
};
var $Hanf_arg12114395 = function(anf_arg1844396,elt1144397,_plus6,tostring12) {
var $z44004401 = D;
var $f44064407 = function(_) {
return R.isFunction(tostring12)?tostring12.app(elt1144397):R.ffi.throwNonFunApp(L[409],tostring12,[elt1144397]);
};
try {
if(--R.GAS > 0) {
$z44004401 = $f44064407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44064407,
"from":L[409]});
}
} catch($e43984399) {
if(R.isCont($e43984399)) {
var $ss44024403 = {"from":L[409],
"go":function(anf_arg1854408) {
return $Hanf_arg12104409(anf_arg1854408,anf_arg1844396,_plus6);
}};
$e43984399.stack[R.EXN_STACKHEIGHT++] = $ss44024403;
}
if(R.isPyretException($e43984399)) {
$e43984399.pyretStack.push(L[409]);
}
throw $e43984399;
}
var $ret44044405 = $Hanf_arg12104409($z44004401,anf_arg1844396,_plus6);
++R.GAS;
return $ret44044405;
};
var $Hanf_arg12104409 = function(anf_arg1854408,anf_arg1844396,_plus6) {
var $z44124413 = D;
var $f44184419 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg1844396,anf_arg1854408):R.ffi.throwNonFunApp(L[405],_plus6,[anf_arg1844396,anf_arg1854408]);
};
try {
if(--R.GAS > 0) {
$z44124413 = $f44184419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44184419,
"from":L[405]});
}
} catch($e44104411) {
if(R.isCont($e44104411)) {
var $ss44144415 = {"from":L[405],
"go":function(ann_DASH_check_DASH_temp1834420) {
return $Hann_DASH_check_DASH_temp12094421(ann_DASH_check_DASH_temp1834420);
}};
$e44104411.stack[R.EXN_STACKHEIGHT++] = $ss44144415;
}
if(R.isPyretException($e44104411)) {
$e44104411.pyretStack.push(L[405]);
}
throw $e44104411;
}
var $ret44164417 = $Hann_DASH_check_DASH_temp12094421($z44124413);
++R.GAS;
return $ret44164417;
};
var $Hann_DASH_check_DASH_temp12094421 = function(ann_DASH_check_DASH_temp1834420) {
return ann_DASH_check_DASH_temp1834420;
};
var $Hann_DASH_check_DASH_temp12084422 = function(ann_DASH_check_DASH_temp1804423) {
return ann_DASH_check_DASH_temp1804423;
};
var $Hif_DASH_12074424 = function(if_DASH_194425,self1104426) {
var if_helper1684429 = R.makeFunction(function(if_helper_arg1694449) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[414],1,arguments);
}
var ann_DASH_check_DASH_temp1664450 = if_helper_arg1694449;
return ann_DASH_check_DASH_temp1664450;
});
var anf_if1724448 = R.isBoolean(if_DASH_194425);
if(R.isPyretTrue(anf_if1724448)) {
if(R.isPyretTrue(if_DASH_194425)) {
var cont_tail_arg1774430 = G(self1104426,"first",L[410]);
if(--R.GAS > 0) {
$z44274428 = R.isFunction(if_helper1684429)?if_helper1684429.app(cont_tail_arg1774430):R.ffi.throwNonFunApp(L[410],if_helper1684429,[cont_tail_arg1774430]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1684429)?if_helper1684429.app(cont_tail_arg1774430):R.ffi.throwNonFunApp(L[410],if_helper1684429,[cont_tail_arg1774430]);
},
"from":L[410]});
}
++R.GAS;
return $z44274428;
} else {
var anf_bracket1734444 = G(self1104426,"rest",L[413]);
var anf_fun1744441 = G(anf_bracket1734444,"last",L[412]);
var $z44334434 = D;
var $f44394440 = function(_) {
return R.isFunction(anf_fun1744441)?anf_fun1744441.app():R.ffi.throwNonFunApp(L[411],anf_fun1744441,[]);
};
try {
if(--R.GAS > 0) {
$z44334434 = $f44394440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44394440,
"from":L[411]});
}
} catch($e44314432) {
if(R.isCont($e44314432)) {
var $ss44354436 = {"from":L[411],
"go":function(cont_tail_arg1754442) {
return $Hcont_tail_arg12064443(cont_tail_arg1754442,if_helper1684429);
}};
$e44314432.stack[R.EXN_STACKHEIGHT++] = $ss44354436;
}
if(R.isPyretException($e44314432)) {
$e44314432.pyretStack.push(L[411]);
}
throw $e44314432;
}
var $ret44374438 = $Hcont_tail_arg12064443($z44334434,if_helper1684429);
++R.GAS;
return $ret44374438;
}
} else {
var cont_tail_arg1704447 = R.throwNonBooleanCondition(L[414],("if"),if_DASH_194425);
if(--R.GAS > 0) {
$z44454446 = R.isFunction(if_helper1684429)?if_helper1684429.app(cont_tail_arg1704447):R.ffi.throwNonFunApp(L[414],if_helper1684429,[cont_tail_arg1704447]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1684429)?if_helper1684429.app(cont_tail_arg1704447):R.ffi.throwNonFunApp(L[414],if_helper1684429,[cont_tail_arg1704447]);
},
"from":L[414]});
}
++R.GAS;
return $z44454446;
}
};
var $Hcont_tail_arg12064443 = function(cont_tail_arg1754442,if_helper1684429) {
if(--R.GAS > 0) {
$z44514452 = R.isFunction(if_helper1684429)?if_helper1684429.app(cont_tail_arg1754442):R.ffi.throwNonFunApp(L[411],if_helper1684429,[cont_tail_arg1754442]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1684429)?if_helper1684429.app(cont_tail_arg1754442):R.ffi.throwNonFunApp(L[411],if_helper1684429,[cont_tail_arg1754442]);
},
"from":L[411]});
}
++R.GAS;
return $z44514452;
};
var $Hann_DASH_check_DASH_temp12054453 = function(ann_DASH_check_DASH_temp1584454) {
return ann_DASH_check_DASH_temp1584454;
};
var $Hanf_arg12044455 = function(anf_arg1624456,arg_DASH_184457,link211585) {
var $z44604461 = D;
var $f44664467 = function(_) {
return R.isFunction(link211585.$var === D?U(L[415],"link"):link211585.$var)?link211585.$var === D?U(L[415],"link"):link211585.$var.app(arg_DASH_184457,anf_arg1624456):R.ffi.throwNonFunApp(L[416],link211585.$var === D?U(L[415],"link"):link211585.$var,[arg_DASH_184457,anf_arg1624456]);
};
try {
if(--R.GAS > 0) {
$z44604461 = $f44664467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44664467,
"from":L[416]});
}
} catch($e44584459) {
if(R.isCont($e44584459)) {
var $ss44624463 = {"from":L[416],
"go":function(ann_DASH_check_DASH_temp1594468) {
return $Hann_DASH_check_DASH_temp12034469(ann_DASH_check_DASH_temp1594468);
}};
$e44584459.stack[R.EXN_STACKHEIGHT++] = $ss44624463;
}
if(R.isPyretException($e44584459)) {
$e44584459.pyretStack.push(L[416]);
}
throw $e44584459;
}
var $ret44644465 = $Hann_DASH_check_DASH_temp12034469($z44604461);
++R.GAS;
return $ret44644465;
};
var $Hann_DASH_check_DASH_temp12034469 = function(ann_DASH_check_DASH_temp1594468) {
return ann_DASH_check_DASH_temp1594468;
};
var $Hanf_arg12024470 = function(anf_arg1564471,anf_fun1544472,f1064473) {
var $z44764477 = D;
var $f44824483 = function(_) {
return R.isFunction(anf_fun1544472)?anf_fun1544472.app(f1064473,anf_arg1564471):R.ffi.throwNonFunApp(L[417],anf_fun1544472,[f1064473,anf_arg1564471]);
};
try {
if(--R.GAS > 0) {
$z44764477 = $f44824483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44824483,
"from":L[417]});
}
} catch($e44744475) {
if(R.isCont($e44744475)) {
var $ss44784479 = {"from":L[417],
"go":function(ann_DASH_check_DASH_temp1524484) {
return $Hann_DASH_check_DASH_temp12014485(ann_DASH_check_DASH_temp1524484);
}};
$e44744475.stack[R.EXN_STACKHEIGHT++] = $ss44784479;
}
if(R.isPyretException($e44744475)) {
$e44744475.pyretStack.push(L[417]);
}
throw $e44744475;
}
var $ret44804481 = $Hann_DASH_check_DASH_temp12014485($z44764477);
++R.GAS;
return $ret44804481;
};
var $Hann_DASH_check_DASH_temp12014485 = function(ann_DASH_check_DASH_temp1524484) {
return ann_DASH_check_DASH_temp1524484;
};
var $Hanf_arg12004486 = function(anf_arg1504487,anf_arg1474488,f1034489) {
var $z44924493 = D;
var $f44984499 = function(_) {
return R.isFunction(f1034489)?f1034489.app(anf_arg1474488,anf_arg1504487):R.ffi.throwNonFunApp(L[418],f1034489,[anf_arg1474488,anf_arg1504487]);
};
try {
if(--R.GAS > 0) {
$z44924493 = $f44984499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44984499,
"from":L[418]});
}
} catch($e44904491) {
if(R.isCont($e44904491)) {
var $ss44944495 = {"from":L[418],
"go":function(ann_DASH_check_DASH_temp1464500) {
return $Hann_DASH_check_DASH_temp11994501(ann_DASH_check_DASH_temp1464500);
}};
$e44904491.stack[R.EXN_STACKHEIGHT++] = $ss44944495;
}
if(R.isPyretException($e44904491)) {
$e44904491.pyretStack.push(L[418]);
}
throw $e44904491;
}
var $ret44964497 = $Hann_DASH_check_DASH_temp11994501($z44924493);
++R.GAS;
return $ret44964497;
};
var $Hann_DASH_check_DASH_temp11994501 = function(ann_DASH_check_DASH_temp1464500) {
return ann_DASH_check_DASH_temp1464500;
};
var $Hcont_tail_app11964502 = function(cont_tail_app1444503) {
return cont_tail_app1444503;
};
var $Hor_DASH_oper_DASH_11984504 = function(or_DASH_oper_DASH_174505,if_helper1334506) {
var anf_if1424522 = R.isBoolean(or_DASH_oper_DASH_174505);
if(R.isPyretTrue(anf_if1424522)) {
var $z45094510 = D;
var $f45154516 = function(_) {
return R.isFunction(if_helper1334506)?if_helper1334506.app(or_DASH_oper_DASH_174505):R.ffi.throwNonFunApp(L[419],if_helper1334506,[or_DASH_oper_DASH_174505]);
};
try {
if(--R.GAS > 0) {
$z45094510 = $f45154516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45154516,
"from":L[419]});
}
} catch($e45074508) {
if(R.isCont($e45074508)) {
var $ss45114512 = {"from":L[419],
"go":function(cont_tail_app1434517) {
return $Hcont_tail_app11974518(cont_tail_app1434517);
}};
$e45074508.stack[R.EXN_STACKHEIGHT++] = $ss45114512;
}
if(R.isPyretException($e45074508)) {
$e45074508.pyretStack.push(L[419]);
}
throw $e45074508;
}
var $ret45134514 = $Hcont_tail_app11974518($z45094510);
++R.GAS;
return $ret45134514;
} else {
var cont_tail_arg1404521 = R.throwNonBooleanOp(L[420],("second"),("or"),or_DASH_oper_DASH_174505);
if(--R.GAS > 0) {
$z45194520 = R.isFunction(if_helper1334506)?if_helper1334506.app(cont_tail_arg1404521):R.ffi.throwNonFunApp(L[420],if_helper1334506,[cont_tail_arg1404521]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1334506)?if_helper1334506.app(cont_tail_arg1404521):R.ffi.throwNonFunApp(L[420],if_helper1334506,[cont_tail_arg1404521]);
},
"from":L[420]});
}
++R.GAS;
return $z45194520;
}
};
var $Hcont_tail_app11974518 = function(cont_tail_app1434517) {
return cont_tail_app1434517;
};
var $Hann_DASH_check_DASH_temp11954523 = function(ann_DASH_check_DASH_temp1294524) {
return ann_DASH_check_DASH_temp1294524;
};
var $Hann_DASH_check_DASH_temp11944525 = function(ann_DASH_check_DASH_temp1274526) {
return ann_DASH_check_DASH_temp1274526;
};
var $Hif_DASH_11934527 = function(if_DASH_144528,f954529,link211585,self944530) {
var if_helper1094544 = R.makeFunction(function(if_helper_arg1104579) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[429],1,arguments);
}
var ann_DASH_check_DASH_temp1074580 = if_helper_arg1104579;
return ann_DASH_check_DASH_temp1074580;
});
var anf_if1134578 = R.isBoolean(if_DASH_144528);
if(R.isPyretTrue(anf_if1134578)) {
if(R.isPyretTrue(if_DASH_144528)) {
var anf_fun1224541 = R.makeFunction(function(arg_DASH_154546) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[421],1,arguments);
}
var anf_bracket1194560 = G(self944530,"rest",L[425]);
var anf_fun1204557 = G(anf_bracket1194560,"filter",L[424]);
var $z45494550 = D;
var $f45554556 = function(_) {
return R.isFunction(anf_fun1204557)?anf_fun1204557.app(f954529):R.ffi.throwNonFunApp(L[423],anf_fun1204557,[f954529]);
};
try {
if(--R.GAS > 0) {
$z45494550 = $f45554556();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45554556,
"from":L[423]});
}
} catch($e45474548) {
if(R.isCont($e45474548)) {
var $ss45514552 = {"from":L[423],
"go":function(anf_arg1214558) {
return $Hanf_arg11904559(anf_arg1214558,arg_DASH_154546,link211585);
}};
$e45474548.stack[R.EXN_STACKHEIGHT++] = $ss45514552;
}
if(R.isPyretException($e45474548)) {
$e45474548.pyretStack.push(L[423]);
}
throw $e45474548;
}
var $ret45534554 = $Hanf_arg11904559($z45494550,arg_DASH_154546,link211585);
++R.GAS;
return $ret45534554;
});
var anf_arg1234542 = G(self944530,"first",L[422]);
var $z45334534 = D;
var $f45394540 = function(_) {
return R.isFunction(anf_fun1224541)?anf_fun1224541.app(anf_arg1234542):R.ffi.throwNonFunApp(L[421],anf_fun1224541,[anf_arg1234542]);
};
try {
if(--R.GAS > 0) {
$z45334534 = $f45394540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45394540,
"from":L[421]});
}
} catch($e45314532) {
if(R.isCont($e45314532)) {
var $ss45354536 = {"from":L[421],
"go":function(cont_tail_arg1244543) {
return $Hcont_tail_arg11914545(cont_tail_arg1244543,if_helper1094544);
}};
$e45314532.stack[R.EXN_STACKHEIGHT++] = $ss45354536;
}
if(R.isPyretException($e45314532)) {
$e45314532.pyretStack.push(L[421]);
}
throw $e45314532;
}
var $ret45374538 = $Hcont_tail_arg11914545($z45334534,if_helper1094544);
++R.GAS;
return $ret45374538;
} else {
var anf_bracket1144574 = G(self944530,"rest",L[428]);
var anf_fun1154571 = G(anf_bracket1144574,"filter",L[427]);
var $z45634564 = D;
var $f45694570 = function(_) {
return R.isFunction(anf_fun1154571)?anf_fun1154571.app(f954529):R.ffi.throwNonFunApp(L[426],anf_fun1154571,[f954529]);
};
try {
if(--R.GAS > 0) {
$z45634564 = $f45694570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45694570,
"from":L[426]});
}
} catch($e45614562) {
if(R.isCont($e45614562)) {
var $ss45654566 = {"from":L[426],
"go":function(cont_tail_arg1164572) {
return $Hcont_tail_arg11924573(cont_tail_arg1164572,if_helper1094544);
}};
$e45614562.stack[R.EXN_STACKHEIGHT++] = $ss45654566;
}
if(R.isPyretException($e45614562)) {
$e45614562.pyretStack.push(L[426]);
}
throw $e45614562;
}
var $ret45674568 = $Hcont_tail_arg11924573($z45634564,if_helper1094544);
++R.GAS;
return $ret45674568;
}
} else {
var cont_tail_arg1114577 = R.throwNonBooleanCondition(L[429],("if"),if_DASH_144528);
if(--R.GAS > 0) {
$z45754576 = R.isFunction(if_helper1094544)?if_helper1094544.app(cont_tail_arg1114577):R.ffi.throwNonFunApp(L[429],if_helper1094544,[cont_tail_arg1114577]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1094544)?if_helper1094544.app(cont_tail_arg1114577):R.ffi.throwNonFunApp(L[429],if_helper1094544,[cont_tail_arg1114577]);
},
"from":L[429]});
}
++R.GAS;
return $z45754576;
}
};
var $Hcont_tail_arg11914545 = function(cont_tail_arg1244543,if_helper1094544) {
if(--R.GAS > 0) {
$z45814582 = R.isFunction(if_helper1094544)?if_helper1094544.app(cont_tail_arg1244543):R.ffi.throwNonFunApp(L[421],if_helper1094544,[cont_tail_arg1244543]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1094544)?if_helper1094544.app(cont_tail_arg1244543):R.ffi.throwNonFunApp(L[421],if_helper1094544,[cont_tail_arg1244543]);
},
"from":L[421]});
}
++R.GAS;
return $z45814582;
};
var $Hanf_arg11904559 = function(anf_arg1214558,arg_DASH_154546,link211585) {
var $z45854586 = D;
var $f45914592 = function(_) {
return R.isFunction(link211585.$var === D?U(L[430],"link"):link211585.$var)?link211585.$var === D?U(L[430],"link"):link211585.$var.app(arg_DASH_154546,anf_arg1214558):R.ffi.throwNonFunApp(L[421],link211585.$var === D?U(L[430],"link"):link211585.$var,[arg_DASH_154546,anf_arg1214558]);
};
try {
if(--R.GAS > 0) {
$z45854586 = $f45914592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45914592,
"from":L[421]});
}
} catch($e45834584) {
if(R.isCont($e45834584)) {
var $ss45874588 = {"from":L[421],
"go":function(ann_DASH_check_DASH_temp1184593) {
return $Hann_DASH_check_DASH_temp11894594(ann_DASH_check_DASH_temp1184593);
}};
$e45834584.stack[R.EXN_STACKHEIGHT++] = $ss45874588;
}
if(R.isPyretException($e45834584)) {
$e45834584.pyretStack.push(L[421]);
}
throw $e45834584;
}
var $ret45894590 = $Hann_DASH_check_DASH_temp11894594($z45854586);
++R.GAS;
return $ret45894590;
};
var $Hann_DASH_check_DASH_temp11894594 = function(ann_DASH_check_DASH_temp1184593) {
return ann_DASH_check_DASH_temp1184593;
};
var $Hcont_tail_arg11924573 = function(cont_tail_arg1164572,if_helper1094544) {
if(--R.GAS > 0) {
$z45954596 = R.isFunction(if_helper1094544)?if_helper1094544.app(cont_tail_arg1164572):R.ffi.throwNonFunApp(L[426],if_helper1094544,[cont_tail_arg1164572]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1094544)?if_helper1094544.app(cont_tail_arg1164572):R.ffi.throwNonFunApp(L[426],if_helper1094544,[cont_tail_arg1164572]);
},
"from":L[426]});
}
++R.GAS;
return $z45954596;
};
var $Hanf_arg11884597 = function(anf_arg1054598,anf_fun1034599) {
var $z46024603 = D;
var $f46084609 = function(_) {
return R.isFunction(anf_fun1034599)?anf_fun1034599.app(anf_arg1054598):R.ffi.throwNonFunApp(L[431],anf_fun1034599,[anf_arg1054598]);
};
try {
if(--R.GAS > 0) {
$z46024603 = $f46084609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46084609,
"from":L[431]});
}
} catch($e46004601) {
if(R.isCont($e46004601)) {
var $ss46044605 = {"from":L[431],
"go":function(ann_DASH_check_DASH_temp984610) {
return $Hann_DASH_check_DASH_temp11874611(ann_DASH_check_DASH_temp984610);
}};
$e46004601.stack[R.EXN_STACKHEIGHT++] = $ss46044605;
}
if(R.isPyretException($e46004601)) {
$e46004601.pyretStack.push(L[431]);
}
throw $e46004601;
}
var $ret46064607 = $Hann_DASH_check_DASH_temp11874611($z46024603);
++R.GAS;
return $ret46064607;
};
var $Hann_DASH_check_DASH_temp11874611 = function(ann_DASH_check_DASH_temp984610) {
return ann_DASH_check_DASH_temp984610;
};
var $Hanf_arg11864612 = function(anf_arg1024613,arg_DASH_134614,link211585) {
var $z46174618 = D;
var $f46234624 = function(_) {
return R.isFunction(link211585.$var === D?U(L[432],"link"):link211585.$var)?link211585.$var === D?U(L[432],"link"):link211585.$var.app(arg_DASH_134614,anf_arg1024613):R.ffi.throwNonFunApp(L[433],link211585.$var === D?U(L[432],"link"):link211585.$var,[arg_DASH_134614,anf_arg1024613]);
};
try {
if(--R.GAS > 0) {
$z46174618 = $f46234624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46234624,
"from":L[433]});
}
} catch($e46154616) {
if(R.isCont($e46154616)) {
var $ss46194620 = {"from":L[433],
"go":function(ann_DASH_check_DASH_temp994625) {
return $Hann_DASH_check_DASH_temp11854626(ann_DASH_check_DASH_temp994625);
}};
$e46154616.stack[R.EXN_STACKHEIGHT++] = $ss46194620;
}
if(R.isPyretException($e46154616)) {
$e46154616.pyretStack.push(L[433]);
}
throw $e46154616;
}
var $ret46214622 = $Hann_DASH_check_DASH_temp11854626($z46174618);
++R.GAS;
return $ret46214622;
};
var $Hann_DASH_check_DASH_temp11854626 = function(ann_DASH_check_DASH_temp994625) {
return ann_DASH_check_DASH_temp994625;
};
var $Hanf_begin_app_dropped11844627 = function(anf_begin_app_dropped11824628,f914629,self904630) {
var anf_bracket954644 = G(self904630,"rest",L[436]);
var anf_fun964641 = G(anf_bracket954644,"each",L[435]);
var $z46334634 = D;
var $f46394640 = function(_) {
return R.isFunction(anf_fun964641)?anf_fun964641.app(f914629):R.ffi.throwNonFunApp(L[434],anf_fun964641,[f914629]);
};
try {
if(--R.GAS > 0) {
$z46334634 = $f46394640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46394640,
"from":L[434]});
}
} catch($e46314632) {
if(R.isCont($e46314632)) {
var $ss46354636 = {"from":L[434],
"go":function(ann_DASH_check_DASH_temp934642) {
return $Hann_DASH_check_DASH_temp11834643(ann_DASH_check_DASH_temp934642);
}};
$e46314632.stack[R.EXN_STACKHEIGHT++] = $ss46354636;
}
if(R.isPyretException($e46314632)) {
$e46314632.pyretStack.push(L[434]);
}
throw $e46314632;
}
var $ret46374638 = $Hann_DASH_check_DASH_temp11834643($z46334634);
++R.GAS;
return $ret46374638;
};
var $Hann_DASH_check_DASH_temp11834643 = function(ann_DASH_check_DASH_temp934642) {
return ann_DASH_check_DASH_temp934642;
};
var $Hanf_arg11814645 = function(anf_arg914646,_plus6) {
var $z46494650 = D;
var $f46554656 = function(_) {
return R.isFunction(_plus6)?_plus6.app((1),anf_arg914646):R.ffi.throwNonFunApp(L[437],_plus6,[(1),anf_arg914646]);
};
try {
if(--R.GAS > 0) {
$z46494650 = $f46554656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46554656,
"from":L[437]});
}
} catch($e46474648) {
if(R.isCont($e46474648)) {
var $ss46514652 = {"from":L[437],
"go":function(ann_DASH_check_DASH_temp884657) {
return $Hann_DASH_check_DASH_temp11804658(ann_DASH_check_DASH_temp884657);
}};
$e46474648.stack[R.EXN_STACKHEIGHT++] = $ss46514652;
}
if(R.isPyretException($e46474648)) {
$e46474648.pyretStack.push(L[437]);
}
throw $e46474648;
}
var $ret46534654 = $Hann_DASH_check_DASH_temp11804658($z46494650);
++R.GAS;
return $ret46534654;
};
var $Hann_DASH_check_DASH_temp11804658 = function(ann_DASH_check_DASH_temp884657) {
return ann_DASH_check_DASH_temp884657;
};
var $Hanf_arg11794659 = function(anf_arg804660,self114661,_plus6,torepr11) {
var anf_arg814672 = G(self114661,"rest",L[438]);
var $z46644665 = D;
var $f46704671 = function(_) {
return R.isFunction(torepr11)?torepr11.app(anf_arg814672):R.ffi.throwNonFunApp(L[438],torepr11,[anf_arg814672]);
};
try {
if(--R.GAS > 0) {
$z46644665 = $f46704671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46704671,
"from":L[438]});
}
} catch($e46624663) {
if(R.isCont($e46624663)) {
var $ss46664667 = {"from":L[438],
"go":function(anf_arg824673) {
return $Hanf_arg11784674(anf_arg824673,anf_arg804660,_plus6);
}};
$e46624663.stack[R.EXN_STACKHEIGHT++] = $ss46664667;
}
if(R.isPyretException($e46624663)) {
$e46624663.pyretStack.push(L[438]);
}
throw $e46624663;
}
var $ret46684669 = $Hanf_arg11784674($z46644665,anf_arg804660,_plus6);
++R.GAS;
return $ret46684669;
};
var $Hanf_arg11784674 = function(anf_arg824673,anf_arg804660,_plus6) {
var $z46774678 = D;
var $f46834684 = function(_) {
return R.isFunction(_plus6)?_plus6.app((", "),anf_arg824673):R.ffi.throwNonFunApp(L[438],_plus6,[(", "),anf_arg824673]);
};
try {
if(--R.GAS > 0) {
$z46774678 = $f46834684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46834684,
"from":L[438]});
}
} catch($e46754676) {
if(R.isCont($e46754676)) {
var $ss46794680 = {"from":L[438],
"go":function(anf_arg834685) {
return $Hanf_arg11774686(anf_arg834685,anf_arg804660,_plus6);
}};
$e46754676.stack[R.EXN_STACKHEIGHT++] = $ss46794680;
}
if(R.isPyretException($e46754676)) {
$e46754676.pyretStack.push(L[438]);
}
throw $e46754676;
}
var $ret46814682 = $Hanf_arg11774686($z46774678,anf_arg804660,_plus6);
++R.GAS;
return $ret46814682;
};
var $Hanf_arg11774686 = function(anf_arg834685,anf_arg804660,_plus6) {
var $z46894690 = D;
var $f46954696 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg804660,anf_arg834685):R.ffi.throwNonFunApp(L[438],_plus6,[anf_arg804660,anf_arg834685]);
};
try {
if(--R.GAS > 0) {
$z46894690 = $f46954696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46954696,
"from":L[438]});
}
} catch($e46874688) {
if(R.isCont($e46874688)) {
var $ss46914692 = {"from":L[438],
"go":function(anf_arg844697) {
return $Hanf_arg11764698(anf_arg844697,_plus6);
}};
$e46874688.stack[R.EXN_STACKHEIGHT++] = $ss46914692;
}
if(R.isPyretException($e46874688)) {
$e46874688.pyretStack.push(L[438]);
}
throw $e46874688;
}
var $ret46934694 = $Hanf_arg11764698($z46894690,_plus6);
++R.GAS;
return $ret46934694;
};
var $Hanf_arg11764698 = function(anf_arg844697,_plus6) {
var $z47014702 = D;
var $f47074708 = function(_) {
return R.isFunction(_plus6)?_plus6.app(anf_arg844697,(")")):R.ffi.throwNonFunApp(L[438],_plus6,[anf_arg844697,(")")]);
};
try {
if(--R.GAS > 0) {
$z47014702 = $f47074708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47074708,
"from":L[438]});
}
} catch($e46994700) {
if(R.isCont($e46994700)) {
var $ss47034704 = {"from":L[438],
"go":function(anf_arg854709) {
return $Hanf_arg11754710(anf_arg854709,_plus6);
}};
$e46994700.stack[R.EXN_STACKHEIGHT++] = $ss47034704;
}
if(R.isPyretException($e46994700)) {
$e46994700.pyretStack.push(L[438]);
}
throw $e46994700;
}
var $ret47054706 = $Hanf_arg11754710($z47014702,_plus6);
++R.GAS;
return $ret47054706;
};
var $Hanf_arg11754710 = function(anf_arg854709,_plus6) {
var $z47134714 = D;
var $f47194720 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("("),anf_arg854709):R.ffi.throwNonFunApp(L[438],_plus6,[("("),anf_arg854709]);
};
try {
if(--R.GAS > 0) {
$z47134714 = $f47194720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47194720,
"from":L[438]});
}
} catch($e47114712) {
if(R.isCont($e47114712)) {
var $ss47154716 = {"from":L[438],
"go":function(anf_arg864721) {
return $Hanf_arg11744722(anf_arg864721,_plus6);
}};
$e47114712.stack[R.EXN_STACKHEIGHT++] = $ss47154716;
}
if(R.isPyretException($e47114712)) {
$e47114712.pyretStack.push(L[438]);
}
throw $e47114712;
}
var $ret47174718 = $Hanf_arg11744722($z47134714,_plus6);
++R.GAS;
return $ret47174718;
};
var $Hanf_arg11744722 = function(anf_arg864721,_plus6) {
var $z47254726 = D;
var $f47314732 = function(_) {
return R.isFunction(_plus6)?_plus6.app(("link"),anf_arg864721):R.ffi.throwNonFunApp(L[438],_plus6,[("link"),anf_arg864721]);
};
try {
if(--R.GAS > 0) {
$z47254726 = $f47314732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47314732,
"from":L[438]});
}
} catch($e47234724) {
if(R.isCont($e47234724)) {
var $ss47274728 = {"from":L[438],
"go":function(ann_DASH_check_DASH_temp784733) {
return $Hann_DASH_check_DASH_temp11734734(ann_DASH_check_DASH_temp784733);
}};
$e47234724.stack[R.EXN_STACKHEIGHT++] = $ss47274728;
}
if(R.isPyretException($e47234724)) {
$e47234724.pyretStack.push(L[438]);
}
throw $e47234724;
}
var $ret47294730 = $Hann_DASH_check_DASH_temp11734734($z47254726);
++R.GAS;
return $ret47294730;
};
var $Hann_DASH_check_DASH_temp11734734 = function(ann_DASH_check_DASH_temp784733) {
return ann_DASH_check_DASH_temp784733;
};
var $Hcont_tail_arg11714735 = function(cont_tail_arg754736,if_helper664737) {
if(--R.GAS > 0) {
$z47384739 = R.isFunction(if_helper664737)?if_helper664737.app(cont_tail_arg754736):R.ffi.throwNonFunApp(L[438],if_helper664737,[cont_tail_arg754736]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper664737)?if_helper664737.app(cont_tail_arg754736):R.ffi.throwNonFunApp(L[438],if_helper664737,[cont_tail_arg754736]);
},
"from":L[438]});
}
++R.GAS;
return $z47384739;
};
var $Hcont_tail_arg11724740 = function(cont_tail_arg714741,if_helper664737) {
if(--R.GAS > 0) {
$z47424743 = R.isFunction(if_helper664737)?if_helper664737.app(cont_tail_arg714741):R.ffi.throwNonFunApp(L[438],if_helper664737,[cont_tail_arg714741]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper664737)?if_helper664737.app(cont_tail_arg714741):R.ffi.throwNonFunApp(L[438],if_helper664737,[cont_tail_arg714741]);
},
"from":L[438]});
}
++R.GAS;
return $z47424743;
};
var $Hann_DASH_check_DASH_temp11704744 = function(ann_DASH_check_DASH_temp514745) {
return ann_DASH_check_DASH_temp514745;
};
var $Hcont_tail_arg11684746 = function(cont_tail_arg264747,if_helper194748) {
if(--R.GAS > 0) {
$z47494750 = R.isFunction(if_helper194748)?if_helper194748.app(cont_tail_arg264747):R.ffi.throwNonFunApp(L[439],if_helper194748,[cont_tail_arg264747]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper194748)?if_helper194748.app(cont_tail_arg264747):R.ffi.throwNonFunApp(L[439],if_helper194748,[cont_tail_arg264747]);
},
"from":L[439]});
}
++R.GAS;
return $z47494750;
};
var $Hcont_tail_arg11694751 = function(cont_tail_arg244752,if_helper194748) {
if(--R.GAS > 0) {
$z47534754 = R.isFunction(if_helper194748)?if_helper194748.app(cont_tail_arg244752):R.ffi.throwNonFunApp(L[439],if_helper194748,[cont_tail_arg244752]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper194748)?if_helper194748.app(cont_tail_arg244752):R.ffi.throwNonFunApp(L[439],if_helper194748,[cont_tail_arg244752]);
},
"from":L[439]});
}
++R.GAS;
return $z47534754;
};
var $Hann_DASH_check_DASH_temp11674755 = function(ann_DASH_check_DASH_temp164756) {
return ann_DASH_check_DASH_temp164756;
};
var $Hann_DASH_check_DASH_temp11664757 = function(ann_DASH_check_DASH_temp144758) {
return ann_DASH_check_DASH_temp144758;
};
var $Hanf_bracket11654759 = function(anf_bracket124760) {
var ann_DASH_check_DASH_temp114761 = G(anf_bracket124760,"suffix",L[440]);
return ann_DASH_check_DASH_temp114761;
};
var $Hanf_bracket11644762 = function(anf_bracket94763) {
var ann_DASH_check_DASH_temp84764 = G(anf_bracket94763,"prefix",L[441]);
return ann_DASH_check_DASH_temp84764;
};
var $Hann_DASH_check_DASH_temp11634765 = function(ann_DASH_check_DASH_temp64766) {
return ann_DASH_check_DASH_temp64766;
};
var $Hann_DASH_check_DASH_temp11624767 = function(ann_DASH_check_DASH_temp44768) {
return ann_DASH_check_DASH_temp44768;
};
var $Hann_DASH_check_DASH_temp11614769 = function(ann_DASH_check_DASH_temp14770) {
return ann_DASH_check_DASH_temp14770;
};
return R.loadModulesNew(NAMESPACE,[$O11621,$E31722],function($O11621,$E31722) {
var O116 = R.getField($O11621,"values");
var E317 = R.getField($E31722,"values");
var O218 = R.getField($O11621,"types");
var E419 = R.getField($E31722,"types");
return R.safeCall(function() {
var ListT164771 = R.namedBrander("List");
var List525 = R.makeBranderAnn(ListT164771,"List");
var none73140 = G(O116,"none",L[692]);
var is_DASH_none84845 = G(O116,"is-none",L[691]);
var some93141 = G(O116,"some",L[690]);
var is_DASH_some102960 = G(O116,"is-some",L[689]);
var Option114846 = G(O116,"Option",L[688]);
var left124847 = G(E317,"left",L[687]);
var right134848 = G(E317,"right",L[686]);
var Either144849 = G(E317,"Either",L[685]);
var List2154772 = {"$var":D,
"$name":"List2"};
var List164774 = {"$var":D,
"$name":"List"};
var is_DASH_List174776 = {"$var":D,
"$name":"is-List"};
var is_DASH_empty18116 = {"$var":D,
"$name":"is-empty"};
var empty191579 = {"$var":D,
"$name":"empty"};
var is_DASH_link204780 = {"$var":D,
"$name":"is-link"};
var link211585 = {"$var":D,
"$name":"link"};
var get_DASH_help224783 = {"$var":D,
"$name":"get-help"};
var set_DASH_help234785 = {"$var":D,
"$name":"set-help"};
var reverse_DASH_help243664 = {"$var":D,
"$name":"reverse-help"};
var range253508 = {"$var":D,
"$name":"range"};
var repeat263429 = {"$var":D,
"$name":"repeat"};
var filter273330 = {"$var":D,
"$name":"filter"};
var partition284791 = {"$var":D,
"$name":"partition"};
var find293138 = {"$var":D,
"$name":"find"};
var split_DASH_at304794 = {"$var":D,
"$name":"split-at"};
var any314796 = {"$var":D,
"$name":"any"};
var all324798 = {"$var":D,
"$name":"all"};
var all2334800 = {"$var":D,
"$name":"all2"};
var map342666 = {"$var":D,
"$name":"map"};
var map2352539 = {"$var":D,
"$name":"map2"};
var map3362381 = {"$var":D,
"$name":"map3"};
var map4371586 = {"$var":D,
"$name":"map4"};
var map_n382099 = {"$var":D,
"$name":"map_n"};
var map2_n391959 = {"$var":D,
"$name":"map2_n"};
var map3_n401788 = {"$var":D,
"$name":"map3_n"};
var map4_n414809 = {"$var":D,
"$name":"map4_n"};
var each424811 = {"$var":D,
"$name":"each"};
var each2434813 = {"$var":D,
"$name":"each2"};
var each3444815 = {"$var":D,
"$name":"each3"};
var each4454817 = {"$var":D,
"$name":"each4"};
var each_n464819 = {"$var":D,
"$name":"each_n"};
var each2_n474821 = {"$var":D,
"$name":"each2_n"};
var each3_n484823 = {"$var":D,
"$name":"each3_n"};
var each4_n494825 = {"$var":D,
"$name":"each4_n"};
var fold_DASH_while50572 = {"$var":D,
"$name":"fold-while"};
var fold51518 = {"$var":D,
"$name":"fold"};
var fold252415 = {"$var":D,
"$name":"fold2"};
var fold353281 = {"$var":D,
"$name":"fold3"};
var fold454115 = {"$var":D,
"$name":"fold4"};
var fold_n554832 = {"$var":D,
"$name":"fold_n"};
var anf_shared35445 = R.makeMethod(function(self1366020) {
return function(other1376019) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[681],1,arguments);
}
return R.checkAnnArgs([List525,List525],[self1366020,other1376019],[L[683],L[684]],function() {
var anf_fun26018 = G(self1366020,"append",L[682]);
var $z60106011 = D;
var $f60166017 = function(_) {
return R.isFunction(anf_fun26018)?anf_fun26018.app(other1376019):R.ffi.throwNonFunApp(L[681],anf_fun26018,[other1376019]);
};
try {
if(--R.GAS > 0) {
$z60106011 = $f60166017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60166017,
"from":L[681]});
}
} catch($e60086009) {
if(R.isCont($e60086009)) {
var $ss60126013 = {"from":L[681],
"go":function(ann_DASH_check_DASH_temp14770) {
return $Hann_DASH_check_DASH_temp11614769(ann_DASH_check_DASH_temp14770);
}};
$e60086009.stack[R.EXN_STACKHEIGHT++] = $ss60126013;
}
if(R.isPyretException($e60086009)) {
$e60086009.pyretStack.push(L[681]);
}
throw $e60086009;
}
var $ret60146015 = $Hann_DASH_check_DASH_temp11614769($z60106011);
++R.GAS;
return $ret60146015;
});
};
},{"length":2});
var anf_shared55446 = R.makeMethod(function(self1386007) {
return function(elt1396006) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[680],1,arguments);
}
var $z59985999 = D;
var $f60046005 = function(_) {
return R.isFunction(link211585.$var === D?U(L[679],"link"):link211585.$var)?link211585.$var === D?U(L[679],"link"):link211585.$var.app(elt1396006,self1386007):R.ffi.throwNonFunApp(L[680],link211585.$var === D?U(L[679],"link"):link211585.$var,[elt1396006,self1386007]);
};
try {
if(--R.GAS > 0) {
$z59985999 = $f60046005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60046005,
"from":L[680]});
}
} catch($e59965997) {
if(R.isCont($e59965997)) {
var $ss60006001 = {"from":L[680],
"go":function(ann_DASH_check_DASH_temp44768) {
return $Hann_DASH_check_DASH_temp11624767(ann_DASH_check_DASH_temp44768);
}};
$e59965997.stack[R.EXN_STACKHEIGHT++] = $ss60006001;
}
if(R.isPyretException($e59965997)) {
$e59965997.pyretStack.push(L[680]);
}
throw $e59965997;
}
var $ret60026003 = $Hann_DASH_check_DASH_temp11624767($z59985999);
++R.GAS;
return $ret60026003;
};
},{"length":2});
var anf_shared75447 = R.makeMethod(function(self1405995) {
return function(n1415994) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[678],1,arguments);
}
var $z59865987 = D;
var $f59925993 = function(_) {
return R.isFunction(split_DASH_at304794.$var === D?U(L[677],"split-at"):split_DASH_at304794.$var)?split_DASH_at304794.$var === D?U(L[677],"split-at"):split_DASH_at304794.$var.app(n1415994,self1405995):R.ffi.throwNonFunApp(L[678],split_DASH_at304794.$var === D?U(L[677],"split-at"):split_DASH_at304794.$var,[n1415994,self1405995]);
};
try {
if(--R.GAS > 0) {
$z59865987 = $f59925993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59925993,
"from":L[678]});
}
} catch($e59845985) {
if(R.isCont($e59845985)) {
var $ss59885989 = {"from":L[678],
"go":function(ann_DASH_check_DASH_temp64766) {
return $Hann_DASH_check_DASH_temp11634765(ann_DASH_check_DASH_temp64766);
}};
$e59845985.stack[R.EXN_STACKHEIGHT++] = $ss59885989;
}
if(R.isPyretException($e59845985)) {
$e59845985.pyretStack.push(L[678]);
}
throw $e59845985;
}
var $ret59905991 = $Hann_DASH_check_DASH_temp11634765($z59865987);
++R.GAS;
return $ret59905991;
};
},{"length":2});
var anf_shared105448 = R.makeMethod(function(self1425983) {
return function(n1435982) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[676],1,arguments);
}
var $z59745975 = D;
var $f59805981 = function(_) {
return R.isFunction(split_DASH_at304794.$var === D?U(L[674],"split-at"):split_DASH_at304794.$var)?split_DASH_at304794.$var === D?U(L[674],"split-at"):split_DASH_at304794.$var.app(n1435982,self1425983):R.ffi.throwNonFunApp(L[675],split_DASH_at304794.$var === D?U(L[674],"split-at"):split_DASH_at304794.$var,[n1435982,self1425983]);
};
try {
if(--R.GAS > 0) {
$z59745975 = $f59805981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59805981,
"from":L[675]});
}
} catch($e59725973) {
if(R.isCont($e59725973)) {
var $ss59765977 = {"from":L[675],
"go":function(anf_bracket94763) {
return $Hanf_bracket11644762(anf_bracket94763);
}};
$e59725973.stack[R.EXN_STACKHEIGHT++] = $ss59765977;
}
if(R.isPyretException($e59725973)) {
$e59725973.pyretStack.push(L[675]);
}
throw $e59725973;
}
var $ret59785979 = $Hanf_bracket11644762($z59745975);
++R.GAS;
return $ret59785979;
};
},{"length":2});
var anf_shared135449 = R.makeMethod(function(self1445971) {
return function(n1455970) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[673],1,arguments);
}
var $z59625963 = D;
var $f59685969 = function(_) {
return R.isFunction(split_DASH_at304794.$var === D?U(L[671],"split-at"):split_DASH_at304794.$var)?split_DASH_at304794.$var === D?U(L[671],"split-at"):split_DASH_at304794.$var.app(n1455970,self1445971):R.ffi.throwNonFunApp(L[672],split_DASH_at304794.$var === D?U(L[671],"split-at"):split_DASH_at304794.$var,[n1455970,self1445971]);
};
try {
if(--R.GAS > 0) {
$z59625963 = $f59685969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59685969,
"from":L[672]});
}
} catch($e59605961) {
if(R.isCont($e59605961)) {
var $ss59645965 = {"from":L[672],
"go":function(anf_bracket124760) {
return $Hanf_bracket11654759(anf_bracket124760);
}};
$e59605961.stack[R.EXN_STACKHEIGHT++] = $ss59645965;
}
if(R.isPyretException($e59605961)) {
$e59605961.pyretStack.push(L[672]);
}
throw $e59605961;
}
var $ret59665967 = $Hanf_bracket11654759($z59625963);
++R.GAS;
return $ret59665967;
};
},{"length":2});
var anf_shared155450 = R.makeMethod(function(self1465958) {
return function(n1475959) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[670],1,arguments);
}
var $z59505951 = D;
var $f59565957 = function(_) {
return R.isFunction(get_DASH_help224783.$var === D?U(L[669],"get-help"):get_DASH_help224783.$var)?get_DASH_help224783.$var === D?U(L[669],"get-help"):get_DASH_help224783.$var.app(self1465958,n1475959):R.ffi.throwNonFunApp(L[670],get_DASH_help224783.$var === D?U(L[669],"get-help"):get_DASH_help224783.$var,[self1465958,n1475959]);
};
try {
if(--R.GAS > 0) {
$z59505951 = $f59565957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59565957,
"from":L[670]});
}
} catch($e59485949) {
if(R.isCont($e59485949)) {
var $ss59525953 = {"from":L[670],
"go":function(ann_DASH_check_DASH_temp144758) {
return $Hann_DASH_check_DASH_temp11664757(ann_DASH_check_DASH_temp144758);
}};
$e59485949.stack[R.EXN_STACKHEIGHT++] = $ss59525953;
}
if(R.isPyretException($e59485949)) {
$e59485949.pyretStack.push(L[670]);
}
throw $e59485949;
}
var $ret59545955 = $Hann_DASH_check_DASH_temp11664757($z59505951);
++R.GAS;
return $ret59545955;
};
},{"length":2});
var anf_shared175451 = R.makeMethod(function(self1485945) {
return function(n1495946,e1505947) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[668],2,arguments);
}
var $z59375938 = D;
var $f59435944 = function(_) {
return R.isFunction(set_DASH_help234785.$var === D?U(L[667],"set-help"):set_DASH_help234785.$var)?set_DASH_help234785.$var === D?U(L[667],"set-help"):set_DASH_help234785.$var.app(self1485945,n1495946,e1505947):R.ffi.throwNonFunApp(L[668],set_DASH_help234785.$var === D?U(L[667],"set-help"):set_DASH_help234785.$var,[self1485945,n1495946,e1505947]);
};
try {
if(--R.GAS > 0) {
$z59375938 = $f59435944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59435944,
"from":L[668]});
}
} catch($e59355936) {
if(R.isCont($e59355936)) {
var $ss59395940 = {"from":L[668],
"go":function(ann_DASH_check_DASH_temp164756) {
return $Hann_DASH_check_DASH_temp11674755(ann_DASH_check_DASH_temp164756);
}};
$e59355936.stack[R.EXN_STACKHEIGHT++] = $ss59395940;
}
if(R.isPyretException($e59355936)) {
$e59355936.pyretStack.push(L[668]);
}
throw $e59355936;
}
var $ret59415942 = $Hann_DASH_check_DASH_temp11674755($z59375938);
++R.GAS;
return $ret59415942;
};
},{"length":3});
var anf_singleton_variant_member285457 = R.makeMethod(function(self25934) {
return function(cases_DASH_funs35915,else_DASH_clause45926) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[439],2,arguments);
}
var if_DASH_65927 = R.hasField(cases_DASH_funs35915,("empty"));
var if_helper194748 = R.makeFunction(function(if_helper_arg205932) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[439],1,arguments);
}
var ann_DASH_check_DASH_temp185933 = if_helper_arg205932;
return ann_DASH_check_DASH_temp185933;
});
var anf_if235931 = R.isBoolean(if_DASH_65927);
if(R.isPyretTrue(anf_if235931)) {
if(R.isPyretTrue(if_DASH_65927)) {
var call_DASH_empty15914 = G(cases_DASH_funs35915,"empty",L[439]);
var $z59065907 = D;
var $f59125913 = function(_) {
return R.isFunction(call_DASH_empty15914)?call_DASH_empty15914.app():R.ffi.throwNonFunApp(L[439],call_DASH_empty15914,[]);
};
try {
if(--R.GAS > 0) {
$z59065907 = $f59125913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59125913,
"from":L[439]});
}
} catch($e59045905) {
if(R.isCont($e59045905)) {
var $ss59085909 = {"from":L[439],
"go":function(cont_tail_arg264747) {
return $Hcont_tail_arg11684746(cont_tail_arg264747,if_helper194748);
}};
$e59045905.stack[R.EXN_STACKHEIGHT++] = $ss59085909;
}
if(R.isPyretException($e59045905)) {
$e59045905.pyretStack.push(L[439]);
}
throw $e59045905;
}
var $ret59105911 = $Hcont_tail_arg11684746($z59065907,if_helper194748);
++R.GAS;
return $ret59105911;
} else {
var $z59185919 = D;
var $f59245925 = function(_) {
return R.isFunction(else_DASH_clause45926)?else_DASH_clause45926.app():R.ffi.throwNonFunApp(L[439],else_DASH_clause45926,[]);
};
try {
if(--R.GAS > 0) {
$z59185919 = $f59245925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59245925,
"from":L[439]});
}
} catch($e59165917) {
if(R.isCont($e59165917)) {
var $ss59205921 = {"from":L[439],
"go":function(cont_tail_arg244752) {
return $Hcont_tail_arg11694751(cont_tail_arg244752,if_helper194748);
}};
$e59165917.stack[R.EXN_STACKHEIGHT++] = $ss59205921;
}
if(R.isPyretException($e59165917)) {
$e59165917.pyretStack.push(L[439]);
}
throw $e59165917;
}
var $ret59225923 = $Hcont_tail_arg11694751($z59185919,if_helper194748);
++R.GAS;
return $ret59225923;
}
} else {
var cont_tail_arg215930 = R.throwNonBooleanCondition(L[439],("if"),if_DASH_65927);
if(--R.GAS > 0) {
$z59285929 = R.isFunction(if_helper194748)?if_helper194748.app(cont_tail_arg215930):R.ffi.throwNonFunApp(L[439],if_helper194748,[cont_tail_arg215930]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper194748)?if_helper194748.app(cont_tail_arg215930):R.ffi.throwNonFunApp(L[439],if_helper194748,[cont_tail_arg215930]);
},
"from":L[439]});
}
++R.GAS;
return $z59285929;
}
};
},{"length":3});
var anf_singleton_variant_member305458 = R.makeMethod(function(self55903) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[439],0,arguments);
}
var ann_DASH_check_DASH_temp295902 = ("empty");
return ann_DASH_check_DASH_temp295902;
};
},{"length":1});
var anf_singleton_variant_member325459 = R.makeMethod(function(self565901) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[666],0,arguments);
}
var ann_DASH_check_DASH_temp315900 = (0);
return R.checkAnn(L[665],$type$Number15,ann_DASH_check_DASH_temp315900,function() {
return ann_DASH_check_DASH_temp315900;
});
};
},{"length":1});
var anf_singleton_variant_member345460 = R.makeMethod(function(self575899) {
return function(f585898) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[664],1,arguments);
}
return R.checkAnnArgs([R.Function],[f585898],[L[663]],function() {
var ann_DASH_check_DASH_temp335897 = nothing8;
return R.checkAnn(L[662],$type$Nothing14,ann_DASH_check_DASH_temp335897,function() {
return ann_DASH_check_DASH_temp335897;
});
});
};
},{"length":2});
var anf_singleton_variant_member365461 = R.makeMethod(function(self595896) {
return function(f605895) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[661],1,arguments);
}
return R.checkAnnArgs([R.Function],[f605895],[L[660]],function() {
var ann_DASH_check_DASH_temp355894 = empty191579.$var === D?U(L[658],"empty"):empty191579.$var;
return R.checkAnn(L[659],List525,ann_DASH_check_DASH_temp355894,function() {
return ann_DASH_check_DASH_temp355894;
});
});
};
},{"length":2});
var anf_singleton_variant_member385462 = R.makeMethod(function(self615893) {
return function(f625892) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[657],1,arguments);
}
return R.checkAnnArgs([R.Function],[f625892],[L[656]],function() {
var ann_DASH_check_DASH_temp375891 = empty191579.$var === D?U(L[654],"empty"):empty191579.$var;
return R.checkAnn(L[655],List525,ann_DASH_check_DASH_temp375891,function() {
return ann_DASH_check_DASH_temp375891;
});
});
};
},{"length":2});
var anf_singleton_variant_member405463 = R.makeMethod(function(self635890) {
return function(f645889) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[653],1,arguments);
}
return R.checkAnnArgs([R.Function],[f645889],[L[652]],function() {
var ann_DASH_check_DASH_temp395888 = none73140;
return R.checkAnn(L[651],R.getDotAnn(L[651],"O",O218,"Option"),ann_DASH_check_DASH_temp395888,function() {
return ann_DASH_check_DASH_temp395888;
});
});
};
},{"length":2});
var anf_singleton_variant_member425464 = R.makeMethod(function(self655886) {
return function(f665887) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[650],1,arguments);
}
var ann_DASH_check_DASH_temp415885 = R.makeObject({"is-true":empty191579.$var === D?U(L[648],"empty"):empty191579.$var,
"is-false":empty191579.$var === D?U(L[649],"empty"):empty191579.$var});
return ann_DASH_check_DASH_temp415885;
};
},{"length":2});
var anf_singleton_variant_member445465 = R.makeMethod(function(self675883) {
return function(f685884,base695882) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[647],2,arguments);
}
var ann_DASH_check_DASH_temp435881 = base695882;
return ann_DASH_check_DASH_temp435881;
};
},{"length":3});
var anf_singleton_variant_member465466 = R.makeMethod(function(self705879) {
return function(f715880,base725878) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[646],2,arguments);
}
var ann_DASH_check_DASH_temp455877 = base725878;
return ann_DASH_check_DASH_temp455877;
};
},{"length":3});
var anf_singleton_variant_member485467 = R.makeMethod(function(self735875) {
return function(elt745876) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[645],1,arguments);
}
var ann_DASH_check_DASH_temp475874 = (false);
return ann_DASH_check_DASH_temp475874;
};
},{"length":2});
var anf_singleton_variant_member505468 = R.makeMethod(function(self755873) {
return function(other765872) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[644],1,arguments);
}
var ann_DASH_check_DASH_temp495871 = other765872;
return ann_DASH_check_DASH_temp495871;
};
},{"length":2});
var anf_singleton_variant_member525469 = R.makeMethod(function(self775870) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[643],0,arguments);
}
var $z58625863 = D;
var $f58685869 = function(_) {
return R.isFunction(raise9)?raise9.app(("last: took last of empty list")):R.ffi.throwNonFunApp(L[643],raise9,[("last: took last of empty list")]);
};
try {
if(--R.GAS > 0) {
$z58625863 = $f58685869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58685869,
"from":L[643]});
}
} catch($e58605861) {
if(R.isCont($e58605861)) {
var $ss58645865 = {"from":L[643],
"go":function(ann_DASH_check_DASH_temp514745) {
return $Hann_DASH_check_DASH_temp11704744(ann_DASH_check_DASH_temp514745);
}};
$e58605861.stack[R.EXN_STACKHEIGHT++] = $ss58645865;
}
if(R.isPyretException($e58605861)) {
$e58605861.pyretStack.push(L[643]);
}
throw $e58605861;
}
var $ret58665867 = $Hann_DASH_check_DASH_temp11704744($z58625863);
++R.GAS;
return $ret58665867;
};
},{"length":1});
var anf_singleton_variant_member545470 = R.makeMethod(function(self785859) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[642],0,arguments);
}
var ann_DASH_check_DASH_temp535858 = self785859;
return ann_DASH_check_DASH_temp535858;
};
},{"length":1});
var anf_singleton_variant_member565471 = R.makeMethod(function(self795857) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[641],0,arguments);
}
var ann_DASH_check_DASH_temp555856 = ("[list: ]");
return ann_DASH_check_DASH_temp555856;
};
},{"length":1});
var anf_singleton_variant_member585472 = R.makeMethod(function(self805855) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[640],0,arguments);
}
var ann_DASH_check_DASH_temp575854 = ("[list: ]");
return ann_DASH_check_DASH_temp575854;
};
},{"length":1});
var anf_singleton_variant_member605473 = R.makeMethod(function(self815851) {
return function(cmp825852,eq835853) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[639],2,arguments);
}
var ann_DASH_check_DASH_temp595850 = self815851;
return ann_DASH_check_DASH_temp595850;
};
},{"length":3});
var anf_singleton_variant_member625474 = R.makeMethod(function(self845849) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[638],0,arguments);
}
var ann_DASH_check_DASH_temp615848 = self845849;
return ann_DASH_check_DASH_temp615848;
};
},{"length":1});
var anf_singleton_variant_member645475 = R.makeMethod(function(self855846) {
return function(str865847) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[637],1,arguments);
}
var ann_DASH_check_DASH_temp635845 = ("");
return ann_DASH_check_DASH_temp635845;
};
},{"length":2});
var anf_variant_member775481 = R.makeMethod(function(self85825) {
return function(cases_DASH_funs95826,else_DASH_clause105837) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[438],2,arguments);
}
var if_DASH_125838 = R.hasField(cases_DASH_funs95826,("link"));
var if_helper664737 = R.makeFunction(function(if_helper_arg675843) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[438],1,arguments);
}
var ann_DASH_check_DASH_temp655844 = if_helper_arg675843;
return ann_DASH_check_DASH_temp655844;
});
var anf_if705842 = R.isBoolean(if_DASH_125838);
if(R.isPyretTrue(anf_if705842)) {
if(R.isPyretTrue(if_DASH_125838)) {
var call_DASH_link75822 = G(cases_DASH_funs95826,"link",L[438]);
var anf_arg735823 = G(self85825,"first",L[636]);
var anf_arg745824 = G(self85825,"rest",L[635]);
var $z58145815 = D;
var $f58205821 = function(_) {
return R.isFunction(call_DASH_link75822)?call_DASH_link75822.app(anf_arg735823,anf_arg745824):R.ffi.throwNonFunApp(L[438],call_DASH_link75822,[anf_arg735823,anf_arg745824]);
};
try {
if(--R.GAS > 0) {
$z58145815 = $f58205821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58205821,
"from":L[438]});
}
} catch($e58125813) {
if(R.isCont($e58125813)) {
var $ss58165817 = {"from":L[438],
"go":function(cont_tail_arg754736) {
return $Hcont_tail_arg11714735(cont_tail_arg754736,if_helper664737);
}};
$e58125813.stack[R.EXN_STACKHEIGHT++] = $ss58165817;
}
if(R.isPyretException($e58125813)) {
$e58125813.pyretStack.push(L[438]);
}
throw $e58125813;
}
var $ret58185819 = $Hcont_tail_arg11714735($z58145815,if_helper664737);
++R.GAS;
return $ret58185819;
} else {
var $z58295830 = D;
var $f58355836 = function(_) {
return R.isFunction(else_DASH_clause105837)?else_DASH_clause105837.app():R.ffi.throwNonFunApp(L[438],else_DASH_clause105837,[]);
};
try {
if(--R.GAS > 0) {
$z58295830 = $f58355836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58355836,
"from":L[438]});
}
} catch($e58275828) {
if(R.isCont($e58275828)) {
var $ss58315832 = {"from":L[438],
"go":function(cont_tail_arg714741) {
return $Hcont_tail_arg11724740(cont_tail_arg714741,if_helper664737);
}};
$e58275828.stack[R.EXN_STACKHEIGHT++] = $ss58315832;
}
if(R.isPyretException($e58275828)) {
$e58275828.pyretStack.push(L[438]);
}
throw $e58275828;
}
var $ret58335834 = $Hcont_tail_arg11724740($z58295830,if_helper664737);
++R.GAS;
return $ret58335834;
}
} else {
var cont_tail_arg685841 = R.throwNonBooleanCondition(L[438],("if"),if_DASH_125838);
if(--R.GAS > 0) {
$z58395840 = R.isFunction(if_helper664737)?if_helper664737.app(cont_tail_arg685841):R.ffi.throwNonFunApp(L[438],if_helper664737,[cont_tail_arg685841]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper664737)?if_helper664737.app(cont_tail_arg685841):R.ffi.throwNonFunApp(L[438],if_helper664737,[cont_tail_arg685841]);
},
"from":L[438]});
}
++R.GAS;
return $z58395840;
}
};
},{"length":3});
var anf_variant_member875482 = R.makeMethod(function(self114661) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[438],0,arguments);
}
var anf_arg795811 = G(self114661,"first",L[438]);
var $z58035804 = D;
var $f58095810 = function(_) {
return R.isFunction(torepr11)?torepr11.app(anf_arg795811):R.ffi.throwNonFunApp(L[438],torepr11,[anf_arg795811]);
};
try {
if(--R.GAS > 0) {
$z58035804 = $f58095810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58095810,
"from":L[438]});
}
} catch($e58015802) {
if(R.isCont($e58015802)) {
var $ss58055806 = {"from":L[438],
"go":function(anf_arg804660) {
return $Hanf_arg11794659(anf_arg804660,self114661,_plus6,torepr11);
}};
$e58015802.stack[R.EXN_STACKHEIGHT++] = $ss58055806;
}
if(R.isPyretException($e58015802)) {
$e58015802.pyretStack.push(L[438]);
}
throw $e58015802;
}
var $ret58075808 = $Hanf_arg11794659($z58035804,self114661,_plus6,torepr11);
++R.GAS;
return $ret58075808;
};
},{"length":1});
var anf_variant_member925483 = R.makeMethod(function(self895800) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[437],0,arguments);
}
var anf_bracket895799 = G(self895800,"rest",L[634]);
var anf_fun905798 = G(anf_bracket895799,"length",L[633]);
var $z57905791 = D;
var $f57965797 = function(_) {
return R.isFunction(anf_fun905798)?anf_fun905798.app():R.ffi.throwNonFunApp(L[632],anf_fun905798,[]);
};
try {
if(--R.GAS > 0) {
$z57905791 = $f57965797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57965797,
"from":L[632]});
}
} catch($e57885789) {
if(R.isCont($e57885789)) {
var $ss57925793 = {"from":L[632],
"go":function(anf_arg914646) {
return $Hanf_arg11814645(anf_arg914646,_plus6);
}};
$e57885789.stack[R.EXN_STACKHEIGHT++] = $ss57925793;
}
if(R.isPyretException($e57885789)) {
$e57885789.pyretStack.push(L[632]);
}
throw $e57885789;
}
var $ret57945795 = $Hanf_arg11814645($z57905791,_plus6);
++R.GAS;
return $ret57945795;
};
},{"length":1});
var anf_variant_member975484 = R.makeMethod(function(self904630) {
return function(f914629) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[434],1,arguments);
}
var anf_arg945787 = G(self904630,"first",L[631]);
var $z57795780 = D;
var $f57855786 = function(_) {
return R.isFunction(f914629)?f914629.app(anf_arg945787):R.ffi.throwNonFunApp(L[630],f914629,[anf_arg945787]);
};
try {
if(--R.GAS > 0) {
$z57795780 = $f57855786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57855786,
"from":L[630]});
}
} catch($e57775778) {
if(R.isCont($e57775778)) {
var $ss57815782 = {"from":L[630],
"go":function(anf_begin_app_dropped11824628) {
return $Hanf_begin_app_dropped11844627(anf_begin_app_dropped11824628,f914629,self904630);
}};
$e57775778.stack[R.EXN_STACKHEIGHT++] = $ss57815782;
}
if(R.isPyretException($e57775778)) {
$e57775778.pyretStack.push(L[630]);
}
throw $e57775778;
}
var $ret57835784 = $Hanf_begin_app_dropped11844627($z57795780,f914629,self904630);
++R.GAS;
return $ret57835784;
};
},{"length":2});
var anf_variant_member1065485 = R.makeMethod(function(self925764) {
return function(f935762) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[431],1,arguments);
}
var anf_fun1034599 = R.makeFunction(function(arg_DASH_134614) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[433],1,arguments);
}
var anf_bracket1005776 = G(self925764,"rest",L[629]);
var anf_fun1015775 = G(anf_bracket1005776,"map",L[628]);
var $z57675768 = D;
var $f57735774 = function(_) {
return R.isFunction(anf_fun1015775)?anf_fun1015775.app(f935762):R.ffi.throwNonFunApp(L[627],anf_fun1015775,[f935762]);
};
try {
if(--R.GAS > 0) {
$z57675768 = $f57735774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57735774,
"from":L[627]});
}
} catch($e57655766) {
if(R.isCont($e57655766)) {
var $ss57695770 = {"from":L[627],
"go":function(anf_arg1024613) {
return $Hanf_arg11864612(anf_arg1024613,arg_DASH_134614,link211585);
}};
$e57655766.stack[R.EXN_STACKHEIGHT++] = $ss57695770;
}
if(R.isPyretException($e57655766)) {
$e57655766.pyretStack.push(L[627]);
}
throw $e57655766;
}
var $ret57715772 = $Hanf_arg11864612($z57675768,arg_DASH_134614,link211585);
++R.GAS;
return $ret57715772;
});
var anf_arg1045763 = G(self925764,"first",L[626]);
var $z57545755 = D;
var $f57605761 = function(_) {
return R.isFunction(f935762)?f935762.app(anf_arg1045763):R.ffi.throwNonFunApp(L[625],f935762,[anf_arg1045763]);
};
try {
if(--R.GAS > 0) {
$z57545755 = $f57605761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57605761,
"from":L[625]});
}
} catch($e57525753) {
if(R.isCont($e57525753)) {
var $ss57565757 = {"from":L[625],
"go":function(anf_arg1054598) {
return $Hanf_arg11884597(anf_arg1054598,anf_fun1034599);
}};
$e57525753.stack[R.EXN_STACKHEIGHT++] = $ss57565757;
}
if(R.isPyretException($e57525753)) {
$e57525753.pyretStack.push(L[625]);
}
throw $e57525753;
}
var $ret57585759 = $Hanf_arg11884597($z57545755,anf_fun1034599);
++R.GAS;
return $ret57585759;
};
},{"length":2});
var anf_variant_member1265486 = R.makeMethod(function(self944530) {
return function(f954529) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[624],1,arguments);
}
var anf_arg1085751 = G(self944530,"first",L[623]);
var $z57435744 = D;
var $f57495750 = function(_) {
return R.isFunction(f954529)?f954529.app(anf_arg1085751):R.ffi.throwNonFunApp(L[429],f954529,[anf_arg1085751]);
};
try {
if(--R.GAS > 0) {
$z57435744 = $f57495750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57495750,
"from":L[429]});
}
} catch($e57415742) {
if(R.isCont($e57415742)) {
var $ss57455746 = {"from":L[429],
"go":function(if_DASH_144528) {
return $Hif_DASH_11934527(if_DASH_144528,f954529,link211585,self944530);
}};
$e57415742.stack[R.EXN_STACKHEIGHT++] = $ss57455746;
}
if(R.isPyretException($e57415742)) {
$e57415742.pyretStack.push(L[429]);
}
throw $e57415742;
}
var $ret57475748 = $Hif_DASH_11934527($z57435744,f954529,link211585,self944530);
++R.GAS;
return $ret57475748;
};
},{"length":2});
var anf_variant_member1285487 = R.makeMethod(function(self965740) {
return function(f975739) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[622],1,arguments);
}
var $z57315732 = D;
var $f57375738 = function(_) {
return R.isFunction(partition284791.$var === D?U(L[621],"partition"):partition284791.$var)?partition284791.$var === D?U(L[621],"partition"):partition284791.$var.app(f975739,self965740):R.ffi.throwNonFunApp(L[622],partition284791.$var === D?U(L[621],"partition"):partition284791.$var,[f975739,self965740]);
};
try {
if(--R.GAS > 0) {
$z57315732 = $f57375738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57375738,
"from":L[622]});
}
} catch($e57295730) {
if(R.isCont($e57295730)) {
var $ss57335734 = {"from":L[622],
"go":function(ann_DASH_check_DASH_temp1274526) {
return $Hann_DASH_check_DASH_temp11944525(ann_DASH_check_DASH_temp1274526);
}};
$e57295730.stack[R.EXN_STACKHEIGHT++] = $ss57335734;
}
if(R.isPyretException($e57295730)) {
$e57295730.pyretStack.push(L[622]);
}
throw $e57295730;
}
var $ret57355736 = $Hann_DASH_check_DASH_temp11944525($z57315732);
++R.GAS;
return $ret57355736;
};
},{"length":2});
var anf_variant_member1305488 = R.makeMethod(function(self985728) {
return function(f995727) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[620],1,arguments);
}
var $z57195720 = D;
var $f57255726 = function(_) {
return R.isFunction(find293138.$var === D?U(L[619],"find"):find293138.$var)?find293138.$var === D?U(L[619],"find"):find293138.$var.app(f995727,self985728):R.ffi.throwNonFunApp(L[620],find293138.$var === D?U(L[619],"find"):find293138.$var,[f995727,self985728]);
};
try {
if(--R.GAS > 0) {
$z57195720 = $f57255726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57255726,
"from":L[620]});
}
} catch($e57175718) {
if(R.isCont($e57175718)) {
var $ss57215722 = {"from":L[620],
"go":function(ann_DASH_check_DASH_temp1294524) {
return $Hann_DASH_check_DASH_temp11954523(ann_DASH_check_DASH_temp1294524);
}};
$e57175718.stack[R.EXN_STACKHEIGHT++] = $ss57215722;
}
if(R.isPyretException($e57175718)) {
$e57175718.pyretStack.push(L[620]);
}
throw $e57175718;
}
var $ret57235724 = $Hann_DASH_check_DASH_temp11954523($z57195720);
++R.GAS;
return $ret57235724;
};
},{"length":2});
var anf_variant_member1455489 = R.makeMethod(function(self1005708) {
return function(elt1015706) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[618],1,arguments);
}
var anf_arg1325716 = G(self1005708,"first",L[617]);
var or_DASH_oper_DASH_165709 = R.equiv(elt1015706,anf_arg1325716);
var if_helper1334506 = R.makeFunction(function(if_helper_arg1345714) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[419],1,arguments);
}
var ann_DASH_check_DASH_temp1315715 = if_helper_arg1345714;
return ann_DASH_check_DASH_temp1315715;
});
var anf_if1375713 = R.isBoolean(or_DASH_oper_DASH_165709);
if(R.isPyretTrue(anf_if1375713)) {
if(R.isPyretTrue(or_DASH_oper_DASH_165709)) {
var $z56875688 = D;
var $f56935694 = function(_) {
return R.isFunction(if_helper1334506)?if_helper1334506.app((true)):R.ffi.throwNonFunApp(L[419],if_helper1334506,[(true)]);
};
try {
if(--R.GAS > 0) {
$z56875688 = $f56935694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56935694,
"from":L[419]});
}
} catch($e56855686) {
if(R.isCont($e56855686)) {
var $ss56895690 = {"from":L[419],
"go":function(cont_tail_app1444503) {
return $Hcont_tail_app11964502(cont_tail_app1444503);
}};
$e56855686.stack[R.EXN_STACKHEIGHT++] = $ss56895690;
}
if(R.isPyretException($e56855686)) {
$e56855686.pyretStack.push(L[419]);
}
throw $e56855686;
}
var $ret56915692 = $Hcont_tail_app11964502($z56875688);
++R.GAS;
return $ret56915692;
} else {
var anf_bracket1385707 = G(self1005708,"rest",L[615]);
var anf_fun1395705 = G(anf_bracket1385707,"member",L[614]);
var $z56975698 = D;
var $f57035704 = function(_) {
return R.isFunction(anf_fun1395705)?anf_fun1395705.app(elt1015706):R.ffi.throwNonFunApp(L[419],anf_fun1395705,[elt1015706]);
};
try {
if(--R.GAS > 0) {
$z56975698 = $f57035704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57035704,
"from":L[419]});
}
} catch($e56955696) {
if(R.isCont($e56955696)) {
var $ss56995700 = {"from":L[419],
"go":function(or_DASH_oper_DASH_174505) {
return $Hor_DASH_oper_DASH_11984504(or_DASH_oper_DASH_174505,if_helper1334506);
}};
$e56955696.stack[R.EXN_STACKHEIGHT++] = $ss56995700;
}
if(R.isPyretException($e56955696)) {
$e56955696.pyretStack.push(L[419]);
}
throw $e56955696;
}
var $ret57015702 = $Hor_DASH_oper_DASH_11984504($z56975698,if_helper1334506);
++R.GAS;
return $ret57015702;
}
} else {
var cont_tail_arg1355712 = R.throwNonBooleanOp(L[616],("first"),("or"),or_DASH_oper_DASH_165709);
if(--R.GAS > 0) {
$z57105711 = R.isFunction(if_helper1334506)?if_helper1334506.app(cont_tail_arg1355712):R.ffi.throwNonFunApp(L[616],if_helper1334506,[cont_tail_arg1355712]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored79) {
return R.isFunction(if_helper1334506)?if_helper1334506.app(cont_tail_arg1355712):R.ffi.throwNonFunApp(L[616],if_helper1334506,[cont_tail_arg1355712]);
},
"from":L[616]});
}
++R.GAS;
return $z57105711;
}
};
},{"length":2});
var anf_variant_member1515490 = R.makeMethod(function(self1025684) {
return function(f1034489,base1045682) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[418],2,arguments);
}
var anf_arg1474488 = G(self1025684,"first",L[613]);
var anf_bracket1485683 = G(self1025684,"rest",L[612]);
var anf_fun1495681 = G(anf_bracket1485683,"foldr",L[611]);
var $z56735674 = D;
var $f56795680 = function(_) {
return R.isFunction(anf_fun1495681)?anf_fun1495681.app(f1034489,base1045682):R.ffi.throwNonFunApp(L[610],anf_fun1495681,[f1034489,base1045682]);
};
try {
if(--R.GAS > 0) {
$z56735674 = $f56795680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56795680,
"from":L[610]});
}
} catch($e56715672) {
if(R.isCont($e56715672)) {
var $ss56755676 = {"from":L[610],
"go":function(anf_arg1504487) {
return $Hanf_arg12004486(anf_arg1504487,anf_arg1474488,f1034489);
}};
$e56715672.stack[R.EXN_STACKHEIGHT++] = $ss56755676;
}
if(R.isPyretException($e56715672)) {
$e56715672.pyretStack.push(L[610]);
}
throw $e56715672;
}
var $ret56775678 = $Hanf_arg12004486($z56735674,anf_arg1474488,f1034489);
++R.GAS;
return $ret56775678;
};
},{"length":3});
var anf_variant_member1575491 = R.makeMethod(function(self1055669) {
return function(f1064473,base1075668) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[417],2,arguments);
}
var anf_bracket1535670 = G(self1055669,"rest",L[609]);
var anf_fun1544472 = G(anf_bracket1535670,"foldl",L[608]);
var anf_arg1555667 = G(self1055669,"first",L[607]);
var $z56595660 = D;
var $f56655666 = function(_) {
return R.isFunction(f1064473)?f1064473.app(anf_arg1555667,base1075668):R.ffi.throwNonFunApp(L[606],f1064473,[anf_arg1555667,base1075668]);
};
try {
if(--R.GAS > 0) {
$z56595660 = $f56655666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56655666,
"from":L[606]});
}
} catch($e56575658) {
if(R.isCont($e56575658)) {
var $ss56615662 = {"from":L[606],
"go":function(anf_arg1564471) {
return $Hanf_arg12024470(anf_arg1564471,anf_fun1544472,f1064473);
}};
$e56575658.stack[R.EXN_STACKHEIGHT++] = $ss56615662;
}
if(R.isPyretException($e56575658)) {
$e56575658.pyretStack.push(L[606]);
}
throw $e56575658;
}
var $ret56635664 = $Hanf_arg12024470($z56595660,anf_fun1544472,f1064473);
++R.GAS;
return $ret56635664;
};
},{"length":3});
var anf_variant_member1655492 = R.makeMethod(function(self1085643) {
return function(other1095655) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[601],1,arguments);
}
var anf_fun1635641 = R.makeFunction(function(arg_DASH_184457) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[416],1,arguments);
}
var anf_bracket1605656 = G(self1085643,"rest",L[605]);
var anf_fun1615654 = G(anf_bracket1605656,"append",L[604]);
var $z56465647 = D;
var $f56525653 = function(_) {
return R.isFunction(anf_fun1615654)?anf_fun1615654.app(other1095655):R.ffi.throwNonFunApp(L[603],anf_fun1615654,[other1095655]);
};
try {
if(--R.GAS > 0) {
$z56465647 = $f56525653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56525653,
"from":L[603]});
}
} catch($e56445645) {
if(R.isCont($e56445645)) {
var $ss56485649 = {"from":L[603],
"go":function(anf_arg1624456) {
return $Hanf_arg12044455(anf_arg1624456,arg_DASH_184457,link211585);
}};
$e56445645.stack[R.EXN_STACKHEIGHT++] = $ss56485649;
}
if(R.isPyretException($e56445645)) {
$e56445645.pyretStack.push(L[603]);
}
throw $e56445645;
}
var $ret56505651 = $Hanf_arg12044455($z56465647,arg_DASH_184457,link211585);
++R.GAS;
return $ret56505651;
});
var anf_arg1645642 = G(self1085643,"first",L[602]);
var $z56335634 = D;
var $f56395640 = function(_) {
return R.isFunction(anf_fun1635641)?anf_fun1635641.app(anf_arg1645642):R.ffi.throwNonFunApp(L[601],anf_fun1635641,[anf_arg1645642]);
};
try {
if(--R.GAS > 0) {
$z56335634 = $f56395640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56395640,
"from":L[601]});
}
} catch($e56315632) {
if(R.isCont($e56315632)) {
var $ss56355636 = {"from":L[601],
"go":function(ann_DASH_check_DASH_temp1584454) {
return $Hann_DASH_check_DASH_temp12054453(ann_DASH_check_DASH_temp1584454);
}};
$e56315632.stack[R.EXN_STACKHEIGHT++] = $ss56355636;
}
if(R.isPyretException($e56315632)) {
$e56315632.pyretStack.push(L[601]);
}
throw $e56315632;
}
var $ret56375638 = $Hann_DASH_check_DASH_temp12054453($z56335634);
++R.GAS;
return $ret56375638;
};
},{"length":2});
var anf_variant_member1795493 = R.makeMethod(function(self1104426) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[600],0,arguments);
}
var anf_arg1675630 = G(self1104426,"rest",L[599]);
var $z56225623 = D;
var $f56285629 = function(_) {
return R.isFunction(is_DASH_empty18116.$var === D?U(L[598],"is-empty"):is_DASH_empty18116.$var)?is_DASH_empty18116.$var === D?U(L[598],"is-empty"):is_DASH_empty18116.$var.app(anf_arg1675630):R.ffi.throwNonFunApp(L[414],is_DASH_empty18116.$var === D?U(L[598],"is-empty"):is_DASH_empty18116.$var,[anf_arg1675630]);
};
try {
if(--R.GAS > 0) {
$z56225623 = $f56285629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56285629,
"from":L[414]});
}
} catch($e56205621) {
if(R.isCont($e56205621)) {
var $ss56245625 = {"from":L[414],
"go":function(if_DASH_194425) {
return $Hif_DASH_12074424(if_DASH_194425,self1104426);
}};
$e56205621.stack[R.EXN_STACKHEIGHT++] = $ss56245625;
}
if(R.isPyretException($e56205621)) {
$e56205621.pyretStack.push(L[414]);
}
throw $e56205621;
}
var $ret56265627 = $Hif_DASH_12074424($z56225623,self1104426);
++R.GAS;
return $ret56265627;
};
},{"length":1});
var anf_variant_member1815494 = R.makeMethod(function(self1115619) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[597],0,arguments);
}
var $z56115612 = D;
var $f56175618 = function(_) {
return R.isFunction(reverse_DASH_help243664.$var === D?U(L[595],"reverse-help"):reverse_DASH_help243664.$var)?reverse_DASH_help243664.$var === D?U(L[595],"reverse-help"):reverse_DASH_help243664.$var.app(self1115619,empty191579.$var === D?U(L[596],"empty"):empty191579.$var):R.ffi.throwNonFunApp(L[597],reverse_DASH_help243664.$var === D?U(L[595],"reverse-help"):reverse_DASH_help243664.$var,[self1115619,empty191579.$var === D?U(L[596],"empty"):empty191579.$var]);
};
try {
if(--R.GAS > 0) {
$z56115612 = $f56175618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56175618,
"from":L[597]});
}
} catch($e56095610) {
if(R.isCont($e56095610)) {
var $ss56135614 = {"from":L[597],
"go":function(ann_DASH_check_DASH_temp1804423) {
return $Hann_DASH_check_DASH_temp12084422(ann_DASH_check_DASH_temp1804423);
}};
$e56095610.stack[R.EXN_STACKHEIGHT++] = $ss56135614;
}
if(R.isPyretException($e56095610)) {
$e56095610.pyretStack.push(L[597]);
}
throw $e56095610;
}
var $ret56155616 = $Hann_DASH_check_DASH_temp12084422($z56115612);
++R.GAS;
return $ret56155616;
};
},{"length":1});
var anf_variant_member1925495 = R.makeMethod(function(self1124357) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[408],0,arguments);
}
var anf_arg1864356 = R.makeFunction(function(combined1135598,elt1144397) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[405],2,arguments);
}
var $z56015602 = D;
var $f56075608 = function(_) {
return R.isFunction(_plus6)?_plus6.app(combined1135598,(", ")):R.ffi.throwNonFunApp(L[594],_plus6,[combined1135598,(", ")]);
};
try {
if(--R.GAS > 0) {
$z56015602 = $f56075608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56075608,
"from":L[594]});
}
} catch($e55995600) {
if(R.isCont($e55995600)) {
var $ss56035604 = {"from":L[594],
"go":function(anf_arg1844396) {
return $Hanf_arg12114395(anf_arg1844396,elt1144397,_plus6,tostring12);
}};
$e55995600.stack[R.EXN_STACKHEIGHT++] = $ss56035604;
}
if(R.isPyretException($e55995600)) {
$e55995600.pyretStack.push(L[594]);
}
throw $e55995600;
}
var $ret56055606 = $Hanf_arg12114395($z56015602,elt1144397,_plus6,tostring12);
++R.GAS;
return $ret56055606;
});
var anf_arg1875597 = G(self1124357,"first",L[593]);
var $z55895590 = D;
var $f55955596 = function(_) {
return R.isFunction(tostring12)?tostring12.app(anf_arg1875597):R.ffi.throwNonFunApp(L[592],tostring12,[anf_arg1875597]);
};
try {
if(--R.GAS > 0) {
$z55895590 = $f55955596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55955596,
"from":L[592]});
}
} catch($e55875588) {
if(R.isCont($e55875588)) {
var $ss55915592 = {"from":L[592],
"go":function(anf_arg1884355) {
return $Hanf_arg12154354(anf_arg1884355,anf_arg1864356,fold51518,self1124357,_plus6);
}};
$e55875588.stack[R.EXN_STACKHEIGHT++] = $ss55915592;
}
if(R.isPyretException($e55875588)) {
$e55875588.pyretStack.push(L[592]);
}
throw $e55875588;
}
var $ret55935594 = $Hanf_arg12154354($z55895590,anf_arg1864356,fold51518,self1124357,_plus6);
++R.GAS;
return $ret55935594;
};
},{"length":1});
var anf_variant_member2035496 = R.makeMethod(function(self1154289) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[402],0,arguments);
}
var anf_arg1974288 = R.makeFunction(function(combined1165576,elt1174329) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[399],2,arguments);
}
var $z55795580 = D;
var $f55855586 = function(_) {
return R.isFunction(_plus6)?_plus6.app(combined1165576,(", ")):R.ffi.throwNonFunApp(L[591],_plus6,[combined1165576,(", ")]);
};
try {
if(--R.GAS > 0) {
$z55795580 = $f55855586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55855586,
"from":L[591]});
}
} catch($e55775578) {
if(R.isCont($e55775578)) {
var $ss55815582 = {"from":L[591],
"go":function(anf_arg1954328) {
return $Hanf_arg12184327(anf_arg1954328,elt1174329,_plus6,torepr11);
}};
$e55775578.stack[R.EXN_STACKHEIGHT++] = $ss55815582;
}
if(R.isPyretException($e55775578)) {
$e55775578.pyretStack.push(L[591]);
}
throw $e55775578;
}
var $ret55835584 = $Hanf_arg12184327($z55795580,elt1174329,_plus6,torepr11);
++R.GAS;
return $ret55835584;
});
var anf_arg1985575 = G(self1154289,"first",L[590]);
var $z55675568 = D;
var $f55735574 = function(_) {
return R.isFunction(torepr11)?torepr11.app(anf_arg1985575):R.ffi.throwNonFunApp(L[589],torepr11,[anf_arg1985575]);
};
try {
if(--R.GAS > 0) {
$z55675568 = $f55735574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55735574,
"from":L[589]});
}
} catch($e55655566) {
if(R.isCont($e55655566)) {
var $ss55695570 = {"from":L[589],
"go":function(anf_arg1994287) {
return $Hanf_arg12224286(anf_arg1994287,anf_arg1974288,fold51518,self1154289,_plus6);
}};
$e55655566.stack[R.EXN_STACKHEIGHT++] = $ss55695570;
}
if(R.isPyretException($e55655566)) {
$e55655566.pyretStack.push(L[589]);
}
throw $e55655566;
}
var $ret55715572 = $Hanf_arg12224286($z55675568,anf_arg1974288,fold51518,self1154289,_plus6);
++R.GAS;
return $ret55715572;
};
},{"length":1});
var anf_variant_member2365497 = R.makeMethod(function(self1185564) {
return function(cmp1194117,eq1204118) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[385],2,arguments);
}
var pivot1214175 = G(self1185564,"first",L[588]);
var are_DASH_lt1224116 = {"$var":empty191579.$var === D?U(L[587],"empty"):empty191579.$var,
"$name":"are-lt"};
var are_DASH_eq1234114 = {"$var":empty191579.$var === D?U(L[586],"empty"):empty191579.$var,
"$name":"are-eq"};
var are_DASH_gt1244115 = {"$var":empty191579.$var === D?U(L[585],"empty"):empty191579.$var,
"$name":"are-gt"};
var anf_fun2055552 = G(self1185564,"each",L[584]);
var anf_arg2305553 = R.makeFunction(function(e1254174) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[583],1,arguments);
}
var $z55565557 = D;
var $f55625563 = function(_) {
return R.isFunction(cmp1194117)?cmp1194117.app(e1254174,pivot1214175):R.ffi.throwNonFunApp(L[389],cmp1194117,[e1254174,pivot1214175]);
};
try {
if(--R.GAS > 0) {
$z55565557 = $f55625563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55625563,
"from":L[389]});
}
} catch($e55545555) {
if(R.isCont($e55545555)) {
var $ss55585559 = {"from":L[389],
"go":function(if_DASH_234173) {
return $Hif_DASH_12304172(if_DASH_234173,are_DASH_eq1234114,are_DASH_gt1244115,are_DASH_lt1224116,e1254174,eq1204118,link211585,pivot1214175);
}};
$e55545555.stack[R.EXN_STACKHEIGHT++] = $ss55585559;
}
if(R.isPyretException($e55545555)) {
$e55545555.pyretStack.push(L[389]);
}
throw $e55545555;
}
var $ret55605561 = $Hif_DASH_12304172($z55565557,are_DASH_eq1234114,are_DASH_gt1244115,are_DASH_lt1224116,e1254174,eq1204118,link211585,pivot1214175);
++R.GAS;
return $ret55605561;
});
var $z55445545 = D;
var $f55505551 = function(_) {
return R.isFunction(anf_fun2055552)?anf_fun2055552.app(anf_arg2305553):R.ffi.throwNonFunApp(L[582],anf_fun2055552,[anf_arg2305553]);
};
try {
if(--R.GAS > 0) {
$z55445545 = $f55505551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55505551,
"from":L[582]});
}
} catch($e55425543) {
if(R.isCont($e55425543)) {
var $ss55465547 = {"from":L[582],
"go":function(anf_begin_app_dropped12314113) {
return $Hanf_begin_app_dropped12364112(anf_begin_app_dropped12314113,are_DASH_eq1234114,are_DASH_gt1244115,are_DASH_lt1224116,cmp1194117,eq1204118);
}};
$e55425543.stack[R.EXN_STACKHEIGHT++] = $ss55465547;
}
if(R.isPyretException($e55425543)) {
$e55425543.pyretStack.push(L[582]);
}
throw $e55425543;
}
var $ret55485549 = $Hanf_begin_app_dropped12364112($z55445545,are_DASH_eq1234114,are_DASH_gt1244115,are_DASH_lt1224116,cmp1194117,eq1204118);
++R.GAS;
return $ret55485549;
};
},{"length":3});
var anf_variant_member2435498 = R.makeMethod(function(self1295541) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[578],0,arguments);
}
var anf_fun2385523 = G(self1295541,"sort-by",L[581]);
var anf_arg2405524 = R.makeFunction(function(e11305529,e21315530) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[580],2,arguments);
}
var $z55335534 = D;
var $f55395540 = function(_) {
return R.isFunction(_lessthan4)?_lessthan4.app(e11305529,e21315530):R.ffi.throwNonFunApp(L[580],_lessthan4,[e11305529,e21315530]);
};
try {
if(--R.GAS > 0) {
$z55335534 = $f55395540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55395540,
"from":L[580]});
}
} catch($e55315532) {
if(R.isCont($e55315532)) {
var $ss55355536 = {"from":L[580],
"go":function(ann_DASH_check_DASH_temp2394111) {
return $Hann_DASH_check_DASH_temp12374110(ann_DASH_check_DASH_temp2394111);
}};
$e55315532.stack[R.EXN_STACKHEIGHT++] = $ss55355536;
}
if(R.isPyretException($e55315532)) {
$e55315532.pyretStack.push(L[580]);
}
throw $e55315532;
}
var $ret55375538 = $Hann_DASH_check_DASH_temp12374110($z55335534);
++R.GAS;
return $ret55375538;
});
var anf_arg2425525 = R.makeFunction(function(e11325526,e21335527) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[579],2,arguments);
}
var ann_DASH_check_DASH_temp2415528 = R.equiv(e11325526,e21335527);
return ann_DASH_check_DASH_temp2415528;
});
var $z55155516 = D;
var $f55215522 = function(_) {
return R.isFunction(anf_fun2385523)?anf_fun2385523.app(anf_arg2405524,anf_arg2425525):R.ffi.throwNonFunApp(L[578],anf_fun2385523,[anf_arg2405524,anf_arg2425525]);
};
try {
if(--R.GAS > 0) {
$z55155516 = $f55215522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55215522,
"from":L[578]});
}
} catch($e55135514) {
if(R.isCont($e55135514)) {
var $ss55175518 = {"from":L[578],
"go":function(ann_DASH_check_DASH_temp2374109) {
return $Hann_DASH_check_DASH_temp12384108(ann_DASH_check_DASH_temp2374109);
}};
$e55135514.stack[R.EXN_STACKHEIGHT++] = $ss55175518;
}
if(R.isPyretException($e55135514)) {
$e55135514.pyretStack.push(L[578]);
}
throw $e55135514;
}
var $ret55195520 = $Hann_DASH_check_DASH_temp12384108($z55155516);
++R.GAS;
return $ret55195520;
};
},{"length":1});
var anf_variant_member2625499 = R.makeMethod(function(self1344031) {
return function(str1354032) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[577],1,arguments);
}
var anf_arg2455512 = G(self1344031,"rest",L[576]);
var $z55045505 = D;
var $f55105511 = function(_) {
return R.isFunction(is_DASH_link204780.$var === D?U(L[575],"is-link"):is_DASH_link204780.$var)?is_DASH_link204780.$var === D?U(L[575],"is-link"):is_DASH_link204780.$var.app(anf_arg2455512):R.ffi.throwNonFunApp(L[373],is_DASH_link204780.$var === D?U(L[575],"is-link"):is_DASH_link204780.$var,[anf_arg2455512]);
};
try {
if(--R.GAS > 0) {
$z55045505 = $f55105511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55105511,
"from":L[373]});
}
} catch($e55025503) {
if(R.isCont($e55025503)) {
var $ss55065507 = {"from":L[373],
"go":function(if_DASH_254030) {
return $Hif_DASH_12444029(if_DASH_254030,self1344031,str1354032,_plus6,tostring12);
}};
$e55025503.stack[R.EXN_STACKHEIGHT++] = $ss55065507;
}
if(R.isPyretException($e55025503)) {
$e55025503.pyretStack.push(L[373]);
}
throw $e55025503;
}
var $ret55085509 = $Hif_DASH_12444029($z55045505,self1344031,str1354032,_plus6,tostring12);
++R.GAS;
return $ret55085509;
};
},{"length":2});
var anf_assign2634773 = (function() {
var $empty_DASH_base54525453 = {"_plus":anf_shared35445,
"push":anf_shared55446,
"split-at":anf_shared75447,
"take":anf_shared105448,
"drop":anf_shared135449,
"get":anf_shared155450,
"set":anf_shared175451,
"_match":anf_singleton_variant_member285457,
"_torepr":anf_singleton_variant_member305458,
"length":anf_singleton_variant_member325459,
"each":anf_singleton_variant_member345460,
"map":anf_singleton_variant_member365461,
"filter":anf_singleton_variant_member385462,
"find":anf_singleton_variant_member405463,
"partition":anf_singleton_variant_member425464,
"foldr":anf_singleton_variant_member445465,
"foldl":anf_singleton_variant_member465466,
"member":anf_singleton_variant_member485467,
"append":anf_singleton_variant_member505468,
"last":anf_singleton_variant_member525469,
"reverse":anf_singleton_variant_member545470,
"tostring":anf_singleton_variant_member565471,
"_torepr":anf_singleton_variant_member585472,
"sort-by":anf_singleton_variant_member605473,
"sort":anf_singleton_variant_member625474,
"join-str":anf_singleton_variant_member645475};
var $empty_DASH_brands54555456 = {"$brand-empty5454":true};
$empty_DASH_brands54555456[ListT164771._brand] = true
var $link_DASH_base54765477 = {"_plus":anf_shared35445,
"push":anf_shared55446,
"split-at":anf_shared75447,
"take":anf_shared105448,
"drop":anf_shared135449,
"get":anf_shared155450,
"set":anf_shared175451,
"_match":anf_variant_member775481,
"_torepr":anf_variant_member875482,
"length":anf_variant_member925483,
"each":anf_variant_member975484,
"map":anf_variant_member1065485,
"filter":anf_variant_member1265486,
"partition":anf_variant_member1285487,
"find":anf_variant_member1305488,
"member":anf_variant_member1455489,
"foldr":anf_variant_member1515490,
"foldl":anf_variant_member1575491,
"append":anf_variant_member1655492,
"last":anf_variant_member1795493,
"reverse":anf_variant_member1815494,
"tostring":anf_variant_member1925495,
"_torepr":anf_variant_member2035496,
"sort-by":anf_variant_member2365497,
"sort":anf_variant_member2435498,
"join-str":anf_variant_member2625499};
var $link_DASH_brands54795480 = {"$brand-link5478":true};
$link_DASH_brands54795480[ListT164771._brand] = true
return R.makeObject({"List":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ListT164771._brand));
}),
"is-empty":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[439],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-empty5454"));
}),
"empty":R.makeBrandedObject($empty_DASH_base54525453,$empty_DASH_brands54555456),
"is-link":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[438],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-link5478"));
}),
"link":R.makeFunction(function(first875500,rest885501) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[573],2,arguments);
}
return R.checkAnnArgs([List525],[rest885501],[L[574]],function() {
var dict = R.create($link_DASH_base54765477);
dict["first"] = first875500
dict["rest"] = rest885501
return R.makeBrandedObject(dict,$link_DASH_brands54795480);
});
})});
})();
List2154772.$var = anf_assign2634773;
var anf_assign2644775 = G(List2154772.$var,"List",L[0]);
List164774.$var = anf_assign2644775;
var anf_assign2654777 = G(List2154772.$var,"List",L[0]);
is_DASH_List174776.$var = anf_assign2654777;
var anf_assign2664778 = G(List2154772.$var,"is-empty",L[439]);
is_DASH_empty18116.$var = anf_assign2664778;
var anf_assign2674779 = G(List2154772.$var,"empty",L[439]);
empty191579.$var = anf_assign2674779;
var anf_assign2684781 = G(List2154772.$var,"is-link",L[438]);
is_DASH_link204780.$var = anf_assign2684781;
var anf_assign2694782 = G(List2154772.$var,"link",L[438]);
link211585.$var = anf_assign2694782;
var anf_assign3024784 = R.makeFunction(function(lst1513884,n1523885) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[570],2,arguments);
}
return R.checkAnnArgs([$type$Number15],[n1523885],[L[572]],function() {
var help1533883 = {"$var":D,
"$name":"help"};
var anf_assign2905424 = R.makeFunction(function(l1543948,cur1553947) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[571],2,arguments);
}
var $z54375438 = D;
var $f54435444 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l1543948):R.ffi.throwNonFunApp(L[365],is_DASH_empty18116.$var,[l1543948]);
};
try {
if(--R.GAS > 0) {
$z54375438 = $f54435444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54435444,
"from":L[365]});
}
} catch($e54355436) {
if(R.isCont($e54355436)) {
var $ss54395440 = {"from":L[365],
"go":function(if_DASH_273946) {
return $Hif_DASH_12503945(if_DASH_273946,cur1553947,help1533883,l1543948,n1523885,_minus5,_plus6,raise9,tostring12);
}};
$e54355436.stack[R.EXN_STACKHEIGHT++] = $ss54395440;
}
if(R.isPyretException($e54355436)) {
$e54355436.pyretStack.push(L[365]);
}
throw $e54355436;
}
var $ret54415442 = $Hif_DASH_12503945($z54375438,cur1553947,help1533883,l1543948,n1523885,_minus5,_plus6,raise9,tostring12);
++R.GAS;
return $ret54415442;
});
help1533883.$var = anf_assign2905424;
var $z54275428 = D;
var $f54335434 = function(_) {
return R.isFunction(_lessthan4)?_lessthan4.app(n1523885,(0)):R.ffi.throwNonFunApp(L[357],_lessthan4,[n1523885,(0)]);
};
try {
if(--R.GAS > 0) {
$z54275428 = $f54335434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54335434,
"from":L[357]});
}
} catch($e54255426) {
if(R.isCont($e54255426)) {
var $ss54295430 = {"from":L[357],
"go":function(if_DASH_283882) {
return $Hif_DASH_12553881(if_DASH_283882,help1533883,lst1513884,n1523885,_plus6,raise9,tostring12);
}};
$e54255426.stack[R.EXN_STACKHEIGHT++] = $ss54295430;
}
if(R.isPyretException($e54255426)) {
$e54255426.pyretStack.push(L[357]);
}
throw $e54255426;
}
var $ret54315432 = $Hif_DASH_12553881($z54275428,help1533883,lst1513884,n1523885,_plus6,raise9,tostring12);
++R.GAS;
return $ret54315432;
});
});
get_DASH_help224783.$var = anf_assign3024784;
var anf_assign3424786 = R.makeFunction(function(lst1563682,n1573683,v1583747) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[567],3,arguments);
}
return R.checkAnnArgs([$type$Number15],[n1573683],[L[569]],function() {
var help1593681 = {"$var":D,
"$name":"help"};
var anf_assign3305403 = R.makeFunction(function(l1603746,cur1613745) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[568],2,arguments);
}
var $z54165417 = D;
var $f54225423 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l1603746):R.ffi.throwNonFunApp(L[351],is_DASH_empty18116.$var,[l1603746]);
};
try {
if(--R.GAS > 0) {
$z54165417 = $f54225423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54225423,
"from":L[351]});
}
} catch($e54145415) {
if(R.isCont($e54145415)) {
var $ss54185419 = {"from":L[351],
"go":function(if_DASH_323744) {
return $Hif_DASH_12653743(if_DASH_323744,cur1613745,help1593681,l1603746,link211585,n1573683,v1583747,_minus5,_plus6,raise9,tostring12);
}};
$e54145415.stack[R.EXN_STACKHEIGHT++] = $ss54185419;
}
if(R.isPyretException($e54145415)) {
$e54145415.pyretStack.push(L[351]);
}
throw $e54145415;
}
var $ret54205421 = $Hif_DASH_12653743($z54165417,cur1613745,help1593681,l1603746,link211585,n1573683,v1583747,_minus5,_plus6,raise9,tostring12);
++R.GAS;
return $ret54205421;
});
help1593681.$var = anf_assign3305403;
var $z54065407 = D;
var $f54125413 = function(_) {
return R.isFunction(_lessthan4)?_lessthan4.app(n1573683,(0)):R.ffi.throwNonFunApp(L[340],_lessthan4,[n1573683,(0)]);
};
try {
if(--R.GAS > 0) {
$z54065407 = $f54125413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54125413,
"from":L[340]});
}
} catch($e54045405) {
if(R.isCont($e54045405)) {
var $ss54085409 = {"from":L[340],
"go":function(if_DASH_333680) {
return $Hif_DASH_12703679(if_DASH_333680,help1593681,lst1563682,n1573683,_plus6,raise9,tostring12);
}};
$e54045405.stack[R.EXN_STACKHEIGHT++] = $ss54085409;
}
if(R.isPyretException($e54045405)) {
$e54045405.pyretStack.push(L[340]);
}
throw $e54045405;
}
var $ret54105411 = $Hif_DASH_12703679($z54065407,help1593681,lst1563682,n1573683,_plus6,raise9,tostring12);
++R.GAS;
return $ret54105411;
});
});
set_DASH_help234785.$var = anf_assign3424786;
var anf_assign3554787 = R.makeFunction(function(lst1625360,acc1635361) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[563],2,arguments);
}
var cases_DASH_val355402 = lst1625360;
var anf_fun3445372 = G(cases_DASH_val355402,"_match",L[564]);
var anf_obj3465376 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[566],0,arguments);
}
var ann_DASH_check_DASH_temp3455401 = acc1635361;
return ann_DASH_check_DASH_temp3455401;
});
var anf_obj3515377 = R.makeFunction(function(first1645378,rest1653663) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[337],2,arguments);
}
var anf_fun3495389 = R.makeFunction(function(arg_DASH_345390) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[565],1,arguments);
}
var $z53935394 = D;
var $f53995400 = function(_) {
return R.isFunction(link211585.$var)?link211585.$var.app(arg_DASH_345390,acc1635361):R.ffi.throwNonFunApp(L[565],link211585.$var,[arg_DASH_345390,acc1635361]);
};
try {
if(--R.GAS > 0) {
$z53935394 = $f53995400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53995400,
"from":L[565]});
}
} catch($e53915392) {
if(R.isCont($e53915392)) {
var $ss53955396 = {"from":L[565],
"go":function(ann_DASH_check_DASH_temp3483678) {
return $Hann_DASH_check_DASH_temp12713677(ann_DASH_check_DASH_temp3483678);
}};
$e53915392.stack[R.EXN_STACKHEIGHT++] = $ss53955396;
}
if(R.isPyretException($e53915392)) {
$e53915392.pyretStack.push(L[565]);
}
throw $e53915392;
}
var $ret53975398 = $Hann_DASH_check_DASH_temp12713677($z53935394);
++R.GAS;
return $ret53975398;
});
var $z53815382 = D;
var $f53875388 = function(_) {
return R.isFunction(anf_fun3495389)?anf_fun3495389.app(first1645378):R.ffi.throwNonFunApp(L[565],anf_fun3495389,[first1645378]);
};
try {
if(--R.GAS > 0) {
$z53815382 = $f53875388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53875388,
"from":L[565]});
}
} catch($e53795380) {
if(R.isCont($e53795380)) {
var $ss53835384 = {"from":L[565],
"go":function(anf_arg3503662) {
return $Hanf_arg12733661(anf_arg3503662,rest1653663,reverse_DASH_help243664);
}};
$e53795380.stack[R.EXN_STACKHEIGHT++] = $ss53835384;
}
if(R.isPyretException($e53795380)) {
$e53795380.pyretStack.push(L[565]);
}
throw $e53795380;
}
var $ret53855386 = $Hanf_arg12733661($z53815382,rest1653663,reverse_DASH_help243664);
++R.GAS;
return $ret53855386;
});
var anf_arg3525373 = R.makeObject({"empty":anf_obj3465376,
"link":anf_obj3515377});
var anf_arg3545374 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[564],0,arguments);
}
var ann_DASH_check_DASH_temp3535375 = R.throwNoBranchesMatched(L[564],("cases"));
return ann_DASH_check_DASH_temp3535375;
});
var $z53645365 = D;
var $f53705371 = function(_) {
return R.isFunction(anf_fun3445372)?anf_fun3445372.app(anf_arg3525373,anf_arg3545374):R.ffi.throwNonFunApp(L[563],anf_fun3445372,[anf_arg3525373,anf_arg3545374]);
};
try {
if(--R.GAS > 0) {
$z53645365 = $f53705371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53705371,
"from":L[563]});
}
} catch($e53625363) {
if(R.isCont($e53625363)) {
var $ss53665367 = {"from":L[563],
"go":function(ann_DASH_check_DASH_temp3433660) {
return $Hann_DASH_check_DASH_temp12743659(ann_DASH_check_DASH_temp3433660);
}};
$e53625363.stack[R.EXN_STACKHEIGHT++] = $ss53665367;
}
if(R.isPyretException($e53625363)) {
$e53625363.pyretStack.push(L[563]);
}
throw $e53625363;
}
var $ret53685369 = $Hann_DASH_check_DASH_temp12743659($z53645365);
++R.GAS;
return $ret53685369;
});
reverse_DASH_help243664.$var = anf_assign3554787;
var anf_assign3784788 = R.makeFunction(function(start1663509,stop1673510) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[562],2,arguments);
}
var $z53525353 = D;
var $f53585359 = function(_) {
return R.isFunction(_lessthan4)?_lessthan4.app(start1663509,stop1673510):R.ffi.throwNonFunApp(L[331],_lessthan4,[start1663509,stop1673510]);
};
try {
if(--R.GAS > 0) {
$z53525353 = $f53585359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53585359,
"from":L[331]});
}
} catch($e53505351) {
if(R.isCont($e53505351)) {
var $ss53545355 = {"from":L[331],
"go":function(if_DASH_373507) {
return $Hif_DASH_12863506(if_DASH_373507,empty191579,link211585,range253508,start1663509,stop1673510,_plus6,raise9,tostring12);
}};
$e53505351.stack[R.EXN_STACKHEIGHT++] = $ss53545355;
}
if(R.isPyretException($e53505351)) {
$e53505351.pyretStack.push(L[331]);
}
throw $e53505351;
}
var $ret53565357 = $Hif_DASH_12863506($z53525353,empty191579,link211585,range253508,start1663509,stop1673510,_plus6,raise9,tostring12);
++R.GAS;
return $ret53565357;
});
range253508.$var = anf_assign3784788;
var anf_assign3954789 = R.makeFunction(function(n1683428,e1693427) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[560],2,arguments);
}
return R.checkAnnArgs([$type$Number15],[n1683428],[L[561]],function() {
var $z53425343 = D;
var $f53485349 = function(_) {
return R.isFunction(_greaterthan3)?_greaterthan3.app(n1683428,(0)):R.ffi.throwNonFunApp(L[323],_greaterthan3,[n1683428,(0)]);
};
try {
if(--R.GAS > 0) {
$z53425343 = $f53485349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53485349,
"from":L[323]});
}
} catch($e53405341) {
if(R.isCont($e53405341)) {
var $ss53445345 = {"from":L[323],
"go":function(if_DASH_393426) {
return $Hif_DASH_12923425(if_DASH_393426,List525,e1693427,empty191579,link211585,n1683428,repeat263429,_minus5,raise9);
}};
$e53405341.stack[R.EXN_STACKHEIGHT++] = $ss53445345;
}
if(R.isPyretException($e53405341)) {
$e53405341.pyretStack.push(L[323]);
}
throw $e53405341;
}
var $ret53465347 = $Hif_DASH_12923425($z53425343,List525,e1693427,empty191579,link211585,n1683428,repeat263429,_minus5,raise9);
++R.GAS;
return $ret53465347;
});
});
repeat263429.$var = anf_assign3954789;
var anf_assign4174790 = R.makeFunction(function(f1703329,lst1713331) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[558],2,arguments);
}
return R.checkAnnArgs([List525],[lst1713331],[L[559]],function() {
var $z53325333 = D;
var $f53385339 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(lst1713331):R.ffi.throwNonFunApp(L[312],is_DASH_empty18116.$var,[lst1713331]);
};
try {
if(--R.GAS > 0) {
$z53325333 = $f53385339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53385339,
"from":L[312]});
}
} catch($e53305331) {
if(R.isCont($e53305331)) {
var $ss53345335 = {"from":L[312],
"go":function(if_DASH_423328) {
return $Hif_DASH_12993327(if_DASH_423328,empty191579,f1703329,filter273330,link211585,lst1713331);
}};
$e53305331.stack[R.EXN_STACKHEIGHT++] = $ss53345335;
}
if(R.isPyretException($e53305331)) {
$e53305331.pyretStack.push(L[312]);
}
throw $e53305331;
}
var $ret53365337 = $Hif_DASH_12993327($z53325333,empty191579,f1703329,filter273330,link211585,lst1713331);
++R.GAS;
return $ret53365337;
});
});
filter273330.$var = anf_assign4174790;
var anf_assign4444792 = R.makeFunction(function(f1743215,lst1755308) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[554],2,arguments);
}
return R.checkAnnArgs([List525],[lst1755308],[L[557]],function() {
var is_DASH_true1763211 = {"$var":empty191579.$var,
"$name":"is-true"};
var is_DASH_false1773210 = {"$var":empty191579.$var,
"$name":"is-false"};
var help1783216 = {"$var":D,
"$name":"help"};
var anf_assign4435309 = R.makeFunction(function(inner_DASH_lst1793217) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[556],1,arguments);
}
var $z53225323 = D;
var $f53285329 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(inner_DASH_lst1793217):R.ffi.throwNonFunApp(L[300],is_DASH_empty18116.$var,[inner_DASH_lst1793217]);
};
try {
if(--R.GAS > 0) {
$z53225323 = $f53285329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53285329,
"from":L[300]});
}
} catch($e53205321) {
if(R.isCont($e53205321)) {
var $ss53245325 = {"from":L[300],
"go":function(if_DASH_463214) {
return $Hif_DASH_13083213(if_DASH_463214,f1743215,help1783216,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585,nothing8);
}};
$e53205321.stack[R.EXN_STACKHEIGHT++] = $ss53245325;
}
if(R.isPyretException($e53205321)) {
$e53205321.pyretStack.push(L[300]);
}
throw $e53205321;
}
var $ret53265327 = $Hif_DASH_13083213($z53225323,f1743215,help1783216,inner_DASH_lst1793217,is_DASH_false1773210,is_DASH_true1763211,link211585,nothing8);
++R.GAS;
return $ret53265327;
});
help1783216.$var = anf_assign4435309;
var $z53125313 = D;
var $f53185319 = function(_) {
return R.isFunction(help1783216.$var)?help1783216.$var.app(lst1755308):R.ffi.throwNonFunApp(L[555],help1783216.$var,[lst1755308]);
};
try {
if(--R.GAS > 0) {
$z53125313 = $f53185319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53185319,
"from":L[555]});
}
} catch($e53105311) {
if(R.isCont($e53105311)) {
var $ss53145315 = {"from":L[555],
"go":function(anf_begin_app_dropped13093209) {
return $Hanf_begin_app_dropped13103208(anf_begin_app_dropped13093209,is_DASH_false1773210,is_DASH_true1763211);
}};
$e53105311.stack[R.EXN_STACKHEIGHT++] = $ss53145315;
}
if(R.isPyretException($e53105311)) {
$e53105311.pyretStack.push(L[555]);
}
throw $e53105311;
}
var $ret53165317 = $Hanf_begin_app_dropped13103208($z53125313,is_DASH_false1773210,is_DASH_true1763211);
++R.GAS;
return $ret53165317;
});
});
partition284791.$var = anf_assign4444792;
var anf_assign4624793 = R.makeFunction(function(f1833137,lst1843139) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[551],2,arguments);
}
return R.checkAnnArgs([R.Function,List525],[f1833137,lst1843139],[L[552],L[553]],function() {
var $z53005301 = D;
var $f53065307 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(lst1843139):R.ffi.throwNonFunApp(L[291],is_DASH_empty18116.$var,[lst1843139]);
};
try {
if(--R.GAS > 0) {
$z53005301 = $f53065307();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53065307,
"from":L[291]});
}
} catch($e52985299) {
if(R.isCont($e52985299)) {
var $ss53025303 = {"from":L[291],
"go":function(if_DASH_483136) {
return $Hif_DASH_13153135(if_DASH_483136,O218,f1833137,find293138,lst1843139,none73140,some93141);
}};
$e52985299.stack[R.EXN_STACKHEIGHT++] = $ss53025303;
}
if(R.isPyretException($e52985299)) {
$e52985299.pyretStack.push(L[291]);
}
throw $e52985299;
}
var $ret53045305 = $Hif_DASH_13153135($z53005301,O218,f1833137,find293138,lst1843139,none73140,some93141);
++R.GAS;
return $ret53045305;
});
});
find293138.$var = anf_assign4624793;
var anf_assign4944795 = R.makeFunction(function(n1912976,lst1922975) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[548],2,arguments);
}
return R.checkAnnArgs([$type$Number15,List525],[n1912976,lst1922975],[L[549],L[550]],function() {
var $z52905291 = D;
var $f52965297 = function(_) {
return R.isFunction(_lessthan4)?_lessthan4.app(n1912976,(0)):R.ffi.throwNonFunApp(L[273],_lessthan4,[n1912976,(0)]);
};
try {
if(--R.GAS > 0) {
$z52905291 = $f52965297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52965297,
"from":L[273]});
}
} catch($e52885289) {
if(R.isCont($e52885289)) {
var $ss52925293 = {"from":L[273],
"go":function(when_DASH_492974) {
return $Hwhen_DASH_13292973(when_DASH_492974,List525,empty191579,link211585,lst1922975,n1912976,_minus5,nothing8,raise9);
}};
$e52885289.stack[R.EXN_STACKHEIGHT++] = $ss52925293;
}
if(R.isPyretException($e52885289)) {
$e52885289.pyretStack.push(L[273]);
}
throw $e52885289;
}
var $ret52945295 = $Hwhen_DASH_13292973($z52905291,List525,empty191579,link211585,lst1922975,n1912976,_minus5,nothing8,raise9);
++R.GAS;
return $ret52945295;
});
});
split_DASH_at304794.$var = anf_assign4944795;
var anf_assign4974797 = R.makeFunction(function(f2015276,lst2025277) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[271],2,arguments);
}
return R.checkAnnArgs([R.Function,List525],[f2015276,lst2025277],[L[546],L[547]],function() {
var $z52805281 = D;
var $f52865287 = function(_) {
return R.isFunction(find293138.$var)?find293138.$var.app(f2015276,lst2025277):R.ffi.throwNonFunApp(L[545],find293138.$var,[f2015276,lst2025277]);
};
try {
if(--R.GAS > 0) {
$z52805281 = $f52865287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52865287,
"from":L[545]});
}
} catch($e52785279) {
if(R.isCont($e52785279)) {
var $ss52825283 = {"from":L[545],
"go":function(anf_arg4962959) {
return $Hanf_arg13312958(anf_arg4962959,is_DASH_some102960,$type$Boolean13);
}};
$e52785279.stack[R.EXN_STACKHEIGHT++] = $ss52825283;
}
if(R.isPyretException($e52785279)) {
$e52785279.pyretStack.push(L[545]);
}
throw $e52785279;
}
var $ret52845285 = $Hanf_arg13312958($z52805281,is_DASH_some102960,$type$Boolean13);
++R.GAS;
return $ret52845285;
});
});
any314796.$var = anf_assign4974797;
var anf_assign5174799 = R.makeFunction(function(f2072878,lst2085254) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[541],2,arguments);
}
return R.checkAnnArgs([R.Function,List525],[f2072878,lst2085254],[L[543],L[544]],function() {
var help2092879 = {"$var":D,
"$name":"help"};
var anf_assign5165255 = R.makeFunction(function(l2102880) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[542],1,arguments);
}
var $z52685269 = D;
var $f52745275 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l2102880):R.ffi.throwNonFunApp(L[267],is_DASH_empty18116.$var,[l2102880]);
};
try {
if(--R.GAS > 0) {
$z52685269 = $f52745275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52745275,
"from":L[267]});
}
} catch($e52665267) {
if(R.isCont($e52665267)) {
var $ss52705271 = {"from":L[267],
"go":function(if_DASH_552877) {
return $Hif_DASH_13372876(if_DASH_552877,f2072878,help2092879,l2102880);
}};
$e52665267.stack[R.EXN_STACKHEIGHT++] = $ss52705271;
}
if(R.isPyretException($e52665267)) {
$e52665267.pyretStack.push(L[267]);
}
throw $e52665267;
}
var $ret52725273 = $Hif_DASH_13372876($z52685269,f2072878,help2092879,l2102880);
++R.GAS;
return $ret52725273;
});
help2092879.$var = anf_assign5165255;
var $z52585259 = D;
var $f52645265 = function(_) {
return R.isFunction(help2092879.$var)?help2092879.$var.app(lst2085254):R.ffi.throwNonFunApp(L[541],help2092879.$var,[lst2085254]);
};
try {
if(--R.GAS > 0) {
$z52585259 = $f52645265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52645265,
"from":L[541]});
}
} catch($e52565257) {
if(R.isCont($e52565257)) {
var $ss52605261 = {"from":L[541],
"go":function(ann_DASH_check_DASH_temp4982875) {
return $Hann_DASH_check_DASH_temp13382874(ann_DASH_check_DASH_temp4982875,$type$Boolean13);
}};
$e52565257.stack[R.EXN_STACKHEIGHT++] = $ss52605261;
}
if(R.isPyretException($e52565257)) {
$e52565257.pyretStack.push(L[541]);
}
throw $e52565257;
}
var $ret52625263 = $Hann_DASH_check_DASH_temp13382874($z52585259,$type$Boolean13);
++R.GAS;
return $ret52625263;
});
});
all324798.$var = anf_assign5174799;
var anf_assign5494801 = R.makeFunction(function(f2152744,lst12165231,lst22175232) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[536],3,arguments);
}
return R.checkAnnArgs([R.Function,List525,List525],[f2152744,lst12165231,lst22175232],[L[538],L[539],L[540]],function() {
var help2182745 = {"$var":D,
"$name":"help"};
var anf_assign5485233 = R.makeFunction(function(l12192746,l22202747) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[537],2,arguments);
}
var $z52465247 = D;
var $f52525253 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12192746):R.ffi.throwNonFunApp(L[253],is_DASH_empty18116.$var,[l12192746]);
};
try {
if(--R.GAS > 0) {
$z52465247 = $f52525253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52525253,
"from":L[253]});
}
} catch($e52445245) {
if(R.isCont($e52445245)) {
var $ss52485249 = {"from":L[253],
"go":function(or_DASH_oper_DASH_592743) {
return $Hor_DASH_oper_DASH_13472742(or_DASH_oper_DASH_592743,f2152744,help2182745,is_DASH_empty18116,l12192746,l22202747);
}};
$e52445245.stack[R.EXN_STACKHEIGHT++] = $ss52485249;
}
if(R.isPyretException($e52445245)) {
$e52445245.pyretStack.push(L[253]);
}
throw $e52445245;
}
var $ret52505251 = $Hor_DASH_oper_DASH_13472742($z52465247,f2152744,help2182745,is_DASH_empty18116,l12192746,l22202747);
++R.GAS;
return $ret52505251;
});
help2182745.$var = anf_assign5485233;
var $z52365237 = D;
var $f52425243 = function(_) {
return R.isFunction(help2182745.$var)?help2182745.$var.app(lst12165231,lst22175232):R.ffi.throwNonFunApp(L[536],help2182745.$var,[lst12165231,lst22175232]);
};
try {
if(--R.GAS > 0) {
$z52365237 = $f52425243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52425243,
"from":L[536]});
}
} catch($e52345235) {
if(R.isCont($e52345235)) {
var $ss52385239 = {"from":L[536],
"go":function(ann_DASH_check_DASH_temp5182741) {
return $Hann_DASH_check_DASH_temp13482740(ann_DASH_check_DASH_temp5182741,$type$Boolean13);
}};
$e52345235.stack[R.EXN_STACKHEIGHT++] = $ss52385239;
}
if(R.isPyretException($e52345235)) {
$e52345235.pyretStack.push(L[536]);
}
throw $e52345235;
}
var $ret52405241 = $Hann_DASH_check_DASH_temp13482740($z52365237,$type$Boolean13);
++R.GAS;
return $ret52405241;
});
});
all2334800.$var = anf_assign5494801;
var anf_assign5654802 = R.makeFunction(function(f2312664,lst2322665) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[534],2,arguments);
}
return R.checkAnnArgs([List525],[lst2322665],[L[535]],function() {
var $z52235224 = D;
var $f52295230 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(lst2322665):R.ffi.throwNonFunApp(L[252],is_DASH_empty18116.$var,[lst2322665]);
};
try {
if(--R.GAS > 0) {
$z52235224 = $f52295230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52295230,
"from":L[252]});
}
} catch($e52215222) {
if(R.isCont($e52215222)) {
var $ss52255226 = {"from":L[252],
"go":function(if_DASH_622663) {
return $Hif_DASH_13542662(if_DASH_622663,empty191579,f2312664,link211585,lst2322665,map342666);
}};
$e52215222.stack[R.EXN_STACKHEIGHT++] = $ss52255226;
}
if(R.isPyretException($e52215222)) {
$e52215222.pyretStack.push(L[252]);
}
throw $e52215222;
}
var $ret52275228 = $Hif_DASH_13542662($z52235224,empty191579,f2312664,link211585,lst2322665,map342666);
++R.GAS;
return $ret52275228;
});
});
map342666.$var = anf_assign5654802;
var anf_assign5934803 = R.makeFunction(function(f2362536,l12372537,l22382538) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[531],3,arguments);
}
return R.checkAnnArgs([List525,List525],[l12372537,l22382538],[L[532],L[533]],function() {
var $z52135214 = D;
var $f52195220 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12372537):R.ffi.throwNonFunApp(L[235],is_DASH_empty18116.$var,[l12372537]);
};
try {
if(--R.GAS > 0) {
$z52135214 = $f52195220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52195220,
"from":L[235]});
}
} catch($e52115212) {
if(R.isCont($e52115212)) {
var $ss52155216 = {"from":L[235],
"go":function(or_DASH_oper_DASH_652535) {
return $Hor_DASH_oper_DASH_13632534(or_DASH_oper_DASH_652535,empty191579,f2362536,is_DASH_empty18116,l12372537,l22382538,link211585,map2352539);
}};
$e52115212.stack[R.EXN_STACKHEIGHT++] = $ss52155216;
}
if(R.isPyretException($e52115212)) {
$e52115212.pyretStack.push(L[235]);
}
throw $e52115212;
}
var $ret52175218 = $Hor_DASH_oper_DASH_13632534($z52135214,empty191579,f2362536,is_DASH_empty18116,l12372537,l22382538,link211585,map2352539);
++R.GAS;
return $ret52175218;
});
});
map2352539.$var = anf_assign5934803;
var anf_assign6274804 = R.makeFunction(function(f2432377,l12442378,l22452379,l32462380) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[527],4,arguments);
}
return R.checkAnnArgs([List525,List525,List525],[l12442378,l22452379,l32462380],[L[528],L[529],L[530]],function() {
var $z52035204 = D;
var $f52095210 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12442378):R.ffi.throwNonFunApp(L[221],is_DASH_empty18116.$var,[l12442378]);
};
try {
if(--R.GAS > 0) {
$z52035204 = $f52095210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52095210,
"from":L[221]});
}
} catch($e52015202) {
if(R.isCont($e52015202)) {
var $ss52055206 = {"from":L[221],
"go":function(or_DASH_oper_DASH_692376) {
return $Hor_DASH_oper_DASH_13742375(or_DASH_oper_DASH_692376,empty191579,f2432377,is_DASH_empty18116,l12442378,l22452379,l32462380,link211585,map3362381);
}};
$e52015202.stack[R.EXN_STACKHEIGHT++] = $ss52055206;
}
if(R.isPyretException($e52015202)) {
$e52015202.pyretStack.push(L[221]);
}
throw $e52015202;
}
var $ret52075208 = $Hor_DASH_oper_DASH_13742375($z52035204,empty191579,f2432377,is_DASH_empty18116,l12442378,l22452379,l32462380,link211585,map3362381);
++R.GAS;
return $ret52075208;
});
});
map3362381.$var = anf_assign6274804;
var anf_assign6674805 = R.makeFunction(function(f2472188,l12482189,l22492190,l32502191,l42512192) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[522],5,arguments);
}
return R.checkAnnArgs([List525,List525,List525,List525],[l12482189,l22492190,l32502191,l42512192],[L[523],L[524],L[525],L[526]],function() {
var $z51935194 = D;
var $f51995200 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12482189):R.ffi.throwNonFunApp(L[204],is_DASH_empty18116.$var,[l12482189]);
};
try {
if(--R.GAS > 0) {
$z51935194 = $f51995200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51995200,
"from":L[204]});
}
} catch($e51915192) {
if(R.isCont($e51915192)) {
var $ss51955196 = {"from":L[204],
"go":function(or_DASH_oper_DASH_742187) {
return $Hor_DASH_oper_DASH_13872186(or_DASH_oper_DASH_742187,empty191579,f2472188,is_DASH_empty18116,l12482189,l22492190,l32502191,l42512192,link211585,map4371586);
}};
$e51915192.stack[R.EXN_STACKHEIGHT++] = $ss51955196;
}
if(R.isPyretException($e51915192)) {
$e51915192.pyretStack.push(L[204]);
}
throw $e51915192;
}
var $ret51975198 = $Hor_DASH_oper_DASH_13872186($z51935194,empty191579,f2472188,is_DASH_empty18116,l12482189,l22492190,l32502191,l42512192,link211585,map4371586);
++R.GAS;
return $ret51975198;
});
});
map4371586.$var = anf_assign6674805;
var anf_assign6844806 = R.makeFunction(function(f2522097,n2532100,lst2542098) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[519],3,arguments);
}
return R.checkAnnArgs([$type$Number15,List525],[n2532100,lst2542098],[L[520],L[521]],function() {
var $z51835184 = D;
var $f51895190 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(lst2542098):R.ffi.throwNonFunApp(L[201],is_DASH_empty18116.$var,[lst2542098]);
};
try {
if(--R.GAS > 0) {
$z51835184 = $f51895190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51895190,
"from":L[201]});
}
} catch($e51815182) {
if(R.isCont($e51815182)) {
var $ss51855186 = {"from":L[201],
"go":function(if_DASH_792096) {
return $Hif_DASH_13942095(if_DASH_792096,empty191579,f2522097,link211585,lst2542098,map_n382099,n2532100,_plus6);
}};
$e51815182.stack[R.EXN_STACKHEIGHT++] = $ss51855186;
}
if(R.isPyretException($e51815182)) {
$e51815182.pyretStack.push(L[201]);
}
throw $e51815182;
}
var $ret51875188 = $Hif_DASH_13942095($z51835184,empty191579,f2522097,link211585,lst2542098,map_n382099,n2532100,_plus6);
++R.GAS;
return $ret51875188;
});
});
map_n382099.$var = anf_assign6844806;
var anf_assign7134807 = R.makeFunction(function(f2571956,n2581960,l12591957,l22601958) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[515],4,arguments);
}
return R.checkAnnArgs([$type$Number15,List525,List525],[n2581960,l12591957,l22601958],[L[516],L[517],L[518]],function() {
var $z51735174 = D;
var $f51795180 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12591957):R.ffi.throwNonFunApp(L[184],is_DASH_empty18116.$var,[l12591957]);
};
try {
if(--R.GAS > 0) {
$z51735174 = $f51795180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51795180,
"from":L[184]});
}
} catch($e51715172) {
if(R.isCont($e51715172)) {
var $ss51755176 = {"from":L[184],
"go":function(or_DASH_oper_DASH_821955) {
return $Hor_DASH_oper_DASH_14041954(or_DASH_oper_DASH_821955,empty191579,f2571956,is_DASH_empty18116,l12591957,l22601958,link211585,map2_n391959,n2581960,_plus6);
}};
$e51715172.stack[R.EXN_STACKHEIGHT++] = $ss51755176;
}
if(R.isPyretException($e51715172)) {
$e51715172.pyretStack.push(L[184]);
}
throw $e51715172;
}
var $ret51775178 = $Hor_DASH_oper_DASH_14041954($z51735174,empty191579,f2571956,is_DASH_empty18116,l12591957,l22601958,link211585,map2_n391959,n2581960,_plus6);
++R.GAS;
return $ret51775178;
});
});
map2_n391959.$var = anf_assign7134807;
var anf_assign7484808 = R.makeFunction(function(f2611784,n2621789,l12631785,l22641786,l32651787) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[510],5,arguments);
}
return R.checkAnnArgs([$type$Number15,List525,List525,List525],[n2621789,l12631785,l22641786,l32651787],[L[511],L[512],L[513],L[514]],function() {
var $z51635164 = D;
var $f51695170 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12631785):R.ffi.throwNonFunApp(L[169],is_DASH_empty18116.$var,[l12631785]);
};
try {
if(--R.GAS > 0) {
$z51635164 = $f51695170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51695170,
"from":L[169]});
}
} catch($e51615162) {
if(R.isCont($e51615162)) {
var $ss51655166 = {"from":L[169],
"go":function(or_DASH_oper_DASH_861783) {
return $Hor_DASH_oper_DASH_14161782(or_DASH_oper_DASH_861783,empty191579,f2611784,is_DASH_empty18116,l12631785,l22641786,l32651787,link211585,map3_n401788,n2621789,_plus6);
}};
$e51615162.stack[R.EXN_STACKHEIGHT++] = $ss51655166;
}
if(R.isPyretException($e51615162)) {
$e51615162.pyretStack.push(L[169]);
}
throw $e51615162;
}
var $ret51675168 = $Hor_DASH_oper_DASH_14161782($z51635164,empty191579,f2611784,is_DASH_empty18116,l12631785,l22641786,l32651787,link211585,map3_n401788,n2621789,_plus6);
++R.GAS;
return $ret51675168;
});
});
map3_n401788.$var = anf_assign7484808;
var anf_assign7894810 = R.makeFunction(function(f2661580,n2671587,l12681581,l22691582,l32701583,l42711584) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[504],6,arguments);
}
return R.checkAnnArgs([$type$Number15,List525,List525,List525,List525],[n2671587,l12681581,l22691582,l32701583,l42711584],[L[505],L[506],L[507],L[508],L[509]],function() {
var $z51535154 = D;
var $f51595160 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12681581):R.ffi.throwNonFunApp(L[151],is_DASH_empty18116.$var,[l12681581]);
};
try {
if(--R.GAS > 0) {
$z51535154 = $f51595160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51595160,
"from":L[151]});
}
} catch($e51515152) {
if(R.isCont($e51515152)) {
var $ss51555156 = {"from":L[151],
"go":function(or_DASH_oper_DASH_911578) {
return $Hor_DASH_oper_DASH_14301577(or_DASH_oper_DASH_911578,empty191579,f2661580,is_DASH_empty18116,l12681581,l22691582,l32701583,l42711584,link211585,map4371586,n2671587,_plus6);
}};
$e51515152.stack[R.EXN_STACKHEIGHT++] = $ss51555156;
}
if(R.isPyretException($e51515152)) {
$e51515152.pyretStack.push(L[151]);
}
throw $e51515152;
}
var $ret51575158 = $Hor_DASH_oper_DASH_14301577($z51535154,empty191579,f2661580,is_DASH_empty18116,l12681581,l22691582,l32701583,l42711584,link211585,map4371586,n2671587,_plus6);
++R.GAS;
return $ret51575158;
});
});
map4_n414809.$var = anf_assign7894810;
var anf_assign8034812 = R.makeFunction(function(f2721527,lst2735129) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[501],2,arguments);
}
return R.checkAnnArgs([List525],[lst2735129],[L[503]],function() {
var help2741528 = {"$var":D,
"$name":"help"};
var anf_assign8025130 = R.makeFunction(function(l2751529) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[502],1,arguments);
}
var $z51435144 = D;
var $f51495150 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l2751529):R.ffi.throwNonFunApp(L[148],is_DASH_empty18116.$var,[l2751529]);
};
try {
if(--R.GAS > 0) {
$z51435144 = $f51495150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51495150,
"from":L[148]});
}
} catch($e51415142) {
if(R.isCont($e51415142)) {
var $ss51455146 = {"from":L[148],
"go":function(if_DASH_951526) {
return $Hif_DASH_14351525(if_DASH_951526,f2721527,help2741528,l2751529,nothing8);
}};
$e51415142.stack[R.EXN_STACKHEIGHT++] = $ss51455146;
}
if(R.isPyretException($e51415142)) {
$e51415142.pyretStack.push(L[148]);
}
throw $e51415142;
}
var $ret51475148 = $Hif_DASH_14351525($z51435144,f2721527,help2741528,l2751529,nothing8);
++R.GAS;
return $ret51475148;
});
help2741528.$var = anf_assign8025130;
var $z51335134 = D;
var $f51395140 = function(_) {
return R.isFunction(help2741528.$var)?help2741528.$var.app(lst2735129):R.ffi.throwNonFunApp(L[501],help2741528.$var,[lst2735129]);
};
try {
if(--R.GAS > 0) {
$z51335134 = $f51395140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51395140,
"from":L[501]});
}
} catch($e51315132) {
if(R.isCont($e51315132)) {
var $ss51355136 = {"from":L[501],
"go":function(ann_DASH_check_DASH_temp7901524) {
return $Hann_DASH_check_DASH_temp14361523(ann_DASH_check_DASH_temp7901524);
}};
$e51315132.stack[R.EXN_STACKHEIGHT++] = $ss51355136;
}
if(R.isPyretException($e51315132)) {
$e51315132.pyretStack.push(L[501]);
}
throw $e51315132;
}
var $ret51375138 = $Hann_DASH_check_DASH_temp14361523($z51335134);
++R.GAS;
return $ret51375138;
});
});
each424811.$var = anf_assign8034812;
var anf_assign8294814 = R.makeFunction(function(f2811423,lst12825106,lst22835107) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[497],3,arguments);
}
return R.checkAnnArgs([List525,List525],[lst12825106,lst22835107],[L[499],L[500]],function() {
var help2841424 = {"$var":D,
"$name":"help"};
var anf_assign8285108 = R.makeFunction(function(l12851425,l22861426) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[498],2,arguments);
}
var $z51215122 = D;
var $f51275128 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12851425):R.ffi.throwNonFunApp(L[135],is_DASH_empty18116.$var,[l12851425]);
};
try {
if(--R.GAS > 0) {
$z51215122 = $f51275128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51275128,
"from":L[135]});
}
} catch($e51195120) {
if(R.isCont($e51195120)) {
var $ss51235124 = {"from":L[135],
"go":function(or_DASH_oper_DASH_971422) {
return $Hor_DASH_oper_DASH_14441421(or_DASH_oper_DASH_971422,f2811423,help2841424,is_DASH_empty18116,l12851425,l22861426,nothing8);
}};
$e51195120.stack[R.EXN_STACKHEIGHT++] = $ss51235124;
}
if(R.isPyretException($e51195120)) {
$e51195120.pyretStack.push(L[135]);
}
throw $e51195120;
}
var $ret51255126 = $Hor_DASH_oper_DASH_14441421($z51215122,f2811423,help2841424,is_DASH_empty18116,l12851425,l22861426,nothing8);
++R.GAS;
return $ret51255126;
});
help2841424.$var = anf_assign8285108;
var $z51115112 = D;
var $f51175118 = function(_) {
return R.isFunction(help2841424.$var)?help2841424.$var.app(lst12825106,lst22835107):R.ffi.throwNonFunApp(L[497],help2841424.$var,[lst12825106,lst22835107]);
};
try {
if(--R.GAS > 0) {
$z51115112 = $f51175118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51175118,
"from":L[497]});
}
} catch($e51095110) {
if(R.isCont($e51095110)) {
var $ss51135114 = {"from":L[497],
"go":function(ann_DASH_check_DASH_temp8041420) {
return $Hann_DASH_check_DASH_temp14451419(ann_DASH_check_DASH_temp8041420);
}};
$e51095110.stack[R.EXN_STACKHEIGHT++] = $ss51135114;
}
if(R.isPyretException($e51095110)) {
$e51095110.pyretStack.push(L[497]);
}
throw $e51095110;
}
var $ret51155116 = $Hann_DASH_check_DASH_temp14451419($z51115112);
++R.GAS;
return $ret51155116;
});
});
each2434813.$var = anf_assign8294814;
var anf_assign8614816 = R.makeFunction(function(f2871288,lst12885082,lst22895083,lst32905084) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[492],4,arguments);
}
return R.checkAnnArgs([List525,List525,List525],[lst12885082,lst22895083,lst32905084],[L[494],L[495],L[496]],function() {
var help2911289 = {"$var":D,
"$name":"help"};
var anf_assign8605085 = R.makeFunction(function(l12921290,l22931291,l32941292) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[493],3,arguments);
}
var $z50985099 = D;
var $f51045105 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l12921290):R.ffi.throwNonFunApp(L[122],is_DASH_empty18116.$var,[l12921290]);
};
try {
if(--R.GAS > 0) {
$z50985099 = $f51045105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51045105,
"from":L[122]});
}
} catch($e50965097) {
if(R.isCont($e50965097)) {
var $ss51005101 = {"from":L[122],
"go":function(or_DASH_oper_DASH_1001287) {
return $Hor_DASH_oper_DASH_14551286(or_DASH_oper_DASH_1001287,f2871288,help2911289,is_DASH_empty18116,l12921290,l22931291,l32941292,nothing8);
}};
$e50965097.stack[R.EXN_STACKHEIGHT++] = $ss51005101;
}
if(R.isPyretException($e50965097)) {
$e50965097.pyretStack.push(L[122]);
}
throw $e50965097;
}
var $ret51025103 = $Hor_DASH_oper_DASH_14551286($z50985099,f2871288,help2911289,is_DASH_empty18116,l12921290,l22931291,l32941292,nothing8);
++R.GAS;
return $ret51025103;
});
help2911289.$var = anf_assign8605085;
var $z50885089 = D;
var $f50945095 = function(_) {
return R.isFunction(help2911289.$var)?help2911289.$var.app(lst12885082,lst22895083,lst32905084):R.ffi.throwNonFunApp(L[492],help2911289.$var,[lst12885082,lst22895083,lst32905084]);
};
try {
if(--R.GAS > 0) {
$z50885089 = $f50945095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50945095,
"from":L[492]});
}
} catch($e50865087) {
if(R.isCont($e50865087)) {
var $ss50905091 = {"from":L[492],
"go":function(ann_DASH_check_DASH_temp8301285) {
return $Hann_DASH_check_DASH_temp14561284(ann_DASH_check_DASH_temp8301285);
}};
$e50865087.stack[R.EXN_STACKHEIGHT++] = $ss50905091;
}
if(R.isPyretException($e50865087)) {
$e50865087.pyretStack.push(L[492]);
}
throw $e50865087;
}
var $ret50925093 = $Hann_DASH_check_DASH_temp14561284($z50885089);
++R.GAS;
return $ret50925093;
});
});
each3444815.$var = anf_assign8614816;
var anf_assign8994818 = R.makeFunction(function(f2951122,lst12965057,lst22975058,lst32985059,lst42995060) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[486],5,arguments);
}
return R.checkAnnArgs([List525,List525,List525,List525],[lst12965057,lst22975058,lst32985059,lst42995060],[L[488],L[489],L[490],L[491]],function() {
var help3001123 = {"$var":D,
"$name":"help"};
var anf_assign8985061 = R.makeFunction(function(l13011124,l23021125,l33031126,l43041127) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[487],4,arguments);
}
var $z50745075 = D;
var $f50805081 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l13011124):R.ffi.throwNonFunApp(L[106],is_DASH_empty18116.$var,[l13011124]);
};
try {
if(--R.GAS > 0) {
$z50745075 = $f50805081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50805081,
"from":L[106]});
}
} catch($e50725073) {
if(R.isCont($e50725073)) {
var $ss50765077 = {"from":L[106],
"go":function(or_DASH_oper_DASH_1041121) {
return $Hor_DASH_oper_DASH_14681120(or_DASH_oper_DASH_1041121,f2951122,help3001123,is_DASH_empty18116,l13011124,l23021125,l33031126,l43041127,nothing8);
}};
$e50725073.stack[R.EXN_STACKHEIGHT++] = $ss50765077;
}
if(R.isPyretException($e50725073)) {
$e50725073.pyretStack.push(L[106]);
}
throw $e50725073;
}
var $ret50785079 = $Hor_DASH_oper_DASH_14681120($z50745075,f2951122,help3001123,is_DASH_empty18116,l13011124,l23021125,l33031126,l43041127,nothing8);
++R.GAS;
return $ret50785079;
});
help3001123.$var = anf_assign8985061;
var $z50645065 = D;
var $f50705071 = function(_) {
return R.isFunction(help3001123.$var)?help3001123.$var.app(lst12965057,lst22975058,lst32985059,lst42995060):R.ffi.throwNonFunApp(L[486],help3001123.$var,[lst12965057,lst22975058,lst32985059,lst42995060]);
};
try {
if(--R.GAS > 0) {
$z50645065 = $f50705071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50705071,
"from":L[486]});
}
} catch($e50625063) {
if(R.isCont($e50625063)) {
var $ss50665067 = {"from":L[486],
"go":function(ann_DASH_check_DASH_temp8621119) {
return $Hann_DASH_check_DASH_temp14691118(ann_DASH_check_DASH_temp8621119);
}};
$e50625063.stack[R.EXN_STACKHEIGHT++] = $ss50665067;
}
if(R.isPyretException($e50625063)) {
$e50625063.pyretStack.push(L[486]);
}
throw $e50625063;
}
var $ret50685069 = $Hann_DASH_check_DASH_temp14691118($z50645065);
++R.GAS;
return $ret50685069;
});
});
each4454817.$var = anf_assign8994818;
var anf_assign9144820 = R.makeFunction(function(f3051055,num3065034,lst3075035) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[482],3,arguments);
}
return R.checkAnnArgs([$type$Number15,List525],[num3065034,lst3075035],[L[484],L[485]],function() {
var help3081056 = {"$var":D,
"$name":"help"};
var anf_assign9135036 = R.makeFunction(function(n3091058,l3101057) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[483],2,arguments);
}
var $z50495050 = D;
var $f50555056 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l3101057):R.ffi.throwNonFunApp(L[102],is_DASH_empty18116.$var,[l3101057]);
};
try {
if(--R.GAS > 0) {
$z50495050 = $f50555056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50555056,
"from":L[102]});
}
} catch($e50475048) {
if(R.isCont($e50475048)) {
var $ss50515052 = {"from":L[102],
"go":function(if_DASH_1081054) {
return $Hif_DASH_14751053(if_DASH_1081054,f3051055,help3081056,l3101057,n3091058,_plus6,nothing8);
}};
$e50475048.stack[R.EXN_STACKHEIGHT++] = $ss50515052;
}
if(R.isPyretException($e50475048)) {
$e50475048.pyretStack.push(L[102]);
}
throw $e50475048;
}
var $ret50535054 = $Hif_DASH_14751053($z50495050,f3051055,help3081056,l3101057,n3091058,_plus6,nothing8);
++R.GAS;
return $ret50535054;
});
help3081056.$var = anf_assign9135036;
var $z50395040 = D;
var $f50455046 = function(_) {
return R.isFunction(help3081056.$var)?help3081056.$var.app(num3065034,lst3075035):R.ffi.throwNonFunApp(L[482],help3081056.$var,[num3065034,lst3075035]);
};
try {
if(--R.GAS > 0) {
$z50395040 = $f50455046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50455046,
"from":L[482]});
}
} catch($e50375038) {
if(R.isCont($e50375038)) {
var $ss50415042 = {"from":L[482],
"go":function(ann_DASH_check_DASH_temp9001052) {
return $Hann_DASH_check_DASH_temp14761051(ann_DASH_check_DASH_temp9001052);
}};
$e50375038.stack[R.EXN_STACKHEIGHT++] = $ss50415042;
}
if(R.isPyretException($e50375038)) {
$e50375038.pyretStack.push(L[482]);
}
throw $e50375038;
}
var $ret50435044 = $Hann_DASH_check_DASH_temp14761051($z50395040);
++R.GAS;
return $ret50435044;
});
});
each_n464819.$var = anf_assign9144820;
var anf_assign9414822 = R.makeFunction(function(f311938,num3125010,lst13135011,lst23145012) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[477],4,arguments);
}
return R.checkAnnArgs([$type$Number15,List525,List525],[num3125010,lst13135011,lst23145012],[L[479],L[480],L[481]],function() {
var help315939 = {"$var":D,
"$name":"help"};
var anf_assign9405013 = R.makeFunction(function(n316942,l1317940,l2318941) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[478],3,arguments);
}
var $z50265027 = D;
var $f50325033 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l1317940):R.ffi.throwNonFunApp(L[88],is_DASH_empty18116.$var,[l1317940]);
};
try {
if(--R.GAS > 0) {
$z50265027 = $f50325033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50325033,
"from":L[88]});
}
} catch($e50245025) {
if(R.isCont($e50245025)) {
var $ss50285029 = {"from":L[88],
"go":function(or_DASH_oper_DASH_110937) {
return $Hor_DASH_oper_DASH_1485936(or_DASH_oper_DASH_110937,f311938,help315939,is_DASH_empty18116,l1317940,l2318941,n316942,_plus6,nothing8);
}};
$e50245025.stack[R.EXN_STACKHEIGHT++] = $ss50285029;
}
if(R.isPyretException($e50245025)) {
$e50245025.pyretStack.push(L[88]);
}
throw $e50245025;
}
var $ret50305031 = $Hor_DASH_oper_DASH_1485936($z50265027,f311938,help315939,is_DASH_empty18116,l1317940,l2318941,n316942,_plus6,nothing8);
++R.GAS;
return $ret50305031;
});
help315939.$var = anf_assign9405013;
var $z50165017 = D;
var $f50225023 = function(_) {
return R.isFunction(help315939.$var)?help315939.$var.app(num3125010,lst13135011,lst23145012):R.ffi.throwNonFunApp(L[477],help315939.$var,[num3125010,lst13135011,lst23145012]);
};
try {
if(--R.GAS > 0) {
$z50165017 = $f50225023();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50225023,
"from":L[477]});
}
} catch($e50145015) {
if(R.isCont($e50145015)) {
var $ss50185019 = {"from":L[477],
"go":function(ann_DASH_check_DASH_temp915935) {
return $Hann_DASH_check_DASH_temp1486934(ann_DASH_check_DASH_temp915935);
}};
$e50145015.stack[R.EXN_STACKHEIGHT++] = $ss50185019;
}
if(R.isPyretException($e50145015)) {
$e50145015.pyretStack.push(L[477]);
}
throw $e50145015;
}
var $ret50205021 = $Hann_DASH_check_DASH_temp1486934($z50165017);
++R.GAS;
return $ret50205021;
});
});
each2_n474821.$var = anf_assign9414822;
var anf_assign9744824 = R.makeFunction(function(f319790,num3204985,lst13214986,lst23224987,lst33234988) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[471],5,arguments);
}
return R.checkAnnArgs([$type$Number15,List525,List525,List525],[num3204985,lst13214986,lst23224987,lst33234988],[L[473],L[474],L[475],L[476]],function() {
var help324791 = {"$var":D,
"$name":"help"};
var anf_assign9734989 = R.makeFunction(function(n325795,l1326792,l2327793,l3328794) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[472],4,arguments);
}
var $z50025003 = D;
var $f50085009 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l1326792):R.ffi.throwNonFunApp(L[74],is_DASH_empty18116.$var,[l1326792]);
};
try {
if(--R.GAS > 0) {
$z50025003 = $f50085009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50085009,
"from":L[74]});
}
} catch($e50005001) {
if(R.isCont($e50005001)) {
var $ss50045005 = {"from":L[74],
"go":function(or_DASH_oper_DASH_113789) {
return $Hor_DASH_oper_DASH_1497788(or_DASH_oper_DASH_113789,f319790,help324791,is_DASH_empty18116,l1326792,l2327793,l3328794,n325795,_plus6,nothing8);
}};
$e50005001.stack[R.EXN_STACKHEIGHT++] = $ss50045005;
}
if(R.isPyretException($e50005001)) {
$e50005001.pyretStack.push(L[74]);
}
throw $e50005001;
}
var $ret50065007 = $Hor_DASH_oper_DASH_1497788($z50025003,f319790,help324791,is_DASH_empty18116,l1326792,l2327793,l3328794,n325795,_plus6,nothing8);
++R.GAS;
return $ret50065007;
});
help324791.$var = anf_assign9734989;
var $z49924993 = D;
var $f49984999 = function(_) {
return R.isFunction(help324791.$var)?help324791.$var.app(num3204985,lst13214986,lst23224987,lst33234988):R.ffi.throwNonFunApp(L[471],help324791.$var,[num3204985,lst13214986,lst23224987,lst33234988]);
};
try {
if(--R.GAS > 0) {
$z49924993 = $f49984999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49984999,
"from":L[471]});
}
} catch($e49904991) {
if(R.isCont($e49904991)) {
var $ss49944995 = {"from":L[471],
"go":function(ann_DASH_check_DASH_temp942787) {
return $Hann_DASH_check_DASH_temp1498786(ann_DASH_check_DASH_temp942787);
}};
$e49904991.stack[R.EXN_STACKHEIGHT++] = $ss49944995;
}
if(R.isPyretException($e49904991)) {
$e49904991.pyretStack.push(L[471]);
}
throw $e49904991;
}
var $ret49964997 = $Hann_DASH_check_DASH_temp1498786($z49924993);
++R.GAS;
return $ret49964997;
});
});
each3_n484823.$var = anf_assign9744824;
var anf_assign10134826 = R.makeFunction(function(f329611,num3304959,lst13314960,lst23324961,lst33334962,lst43344963) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[464],6,arguments);
}
return R.checkAnnArgs([$type$Number15,List525,List525,List525,List525],[num3304959,lst13314960,lst23324961,lst33334962,lst43344963],[L[466],L[467],L[468],L[469],L[470]],function() {
var help335612 = {"$var":D,
"$name":"help"};
var anf_assign10124964 = R.makeFunction(function(n336617,l1337613,l2338614,l3339615,l4340616) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[465],5,arguments);
}
var $z49774978 = D;
var $f49834984 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l1337613):R.ffi.throwNonFunApp(L[57],is_DASH_empty18116.$var,[l1337613]);
};
try {
if(--R.GAS > 0) {
$z49774978 = $f49834984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49834984,
"from":L[57]});
}
} catch($e49754976) {
if(R.isCont($e49754976)) {
var $ss49794980 = {"from":L[57],
"go":function(or_DASH_oper_DASH_117610) {
return $Hor_DASH_oper_DASH_1511609(or_DASH_oper_DASH_117610,f329611,help335612,is_DASH_empty18116,l1337613,l2338614,l3339615,l4340616,n336617,_plus6,nothing8);
}};
$e49754976.stack[R.EXN_STACKHEIGHT++] = $ss49794980;
}
if(R.isPyretException($e49754976)) {
$e49754976.pyretStack.push(L[57]);
}
throw $e49754976;
}
var $ret49814982 = $Hor_DASH_oper_DASH_1511609($z49774978,f329611,help335612,is_DASH_empty18116,l1337613,l2338614,l3339615,l4340616,n336617,_plus6,nothing8);
++R.GAS;
return $ret49814982;
});
help335612.$var = anf_assign10124964;
var $z49674968 = D;
var $f49734974 = function(_) {
return R.isFunction(help335612.$var)?help335612.$var.app(num3304959,lst13314960,lst23324961,lst33334962,lst43344963):R.ffi.throwNonFunApp(L[464],help335612.$var,[num3304959,lst13314960,lst23324961,lst33334962,lst43344963]);
};
try {
if(--R.GAS > 0) {
$z49674968 = $f49734974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49734974,
"from":L[464]});
}
} catch($e49654966) {
if(R.isCont($e49654966)) {
var $ss49694970 = {"from":L[464],
"go":function(ann_DASH_check_DASH_temp975608) {
return $Hann_DASH_check_DASH_temp1512607(ann_DASH_check_DASH_temp975608);
}};
$e49654966.stack[R.EXN_STACKHEIGHT++] = $ss49694970;
}
if(R.isPyretException($e49654966)) {
$e49654966.pyretStack.push(L[464]);
}
throw $e49654966;
}
var $ret49714972 = $Hann_DASH_check_DASH_temp1512607($z49674968);
++R.GAS;
return $ret49714972;
});
});
each4_n494825.$var = anf_assign10134826;
var anf_assign10314827 = R.makeFunction(function(f341571,base3424928,lst3434929) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[461],3,arguments);
}
var cases_DASH_val1224958 = lst3434929;
var anf_fun10154940 = G(cases_DASH_val1224958,"_match",L[462]);
var anf_obj10174944 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[463],0,arguments);
}
var ann_DASH_check_DASH_temp10164957 = base3424928;
return ann_DASH_check_DASH_temp10164957;
});
var anf_obj10274945 = R.makeFunction(function(elt3444946,r345573) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[53],2,arguments);
}
var $z49494950 = D;
var $f49554956 = function(_) {
return R.isFunction(f341571)?f341571.app(base3424928,elt3444946):R.ffi.throwNonFunApp(L[54],f341571,[base3424928,elt3444946]);
};
try {
if(--R.GAS > 0) {
$z49494950 = $f49554956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49554956,
"from":L[54]});
}
} catch($e49474948) {
if(R.isCont($e49474948)) {
var $ss49514952 = {"from":L[54],
"go":function(cases_DASH_val121570) {
return $Hcases_DASH_val1515569(cases_DASH_val121570,f341571,fold_DASH_while50572,r345573);
}};
$e49474948.stack[R.EXN_STACKHEIGHT++] = $ss49514952;
}
if(R.isPyretException($e49474948)) {
$e49474948.pyretStack.push(L[54]);
}
throw $e49474948;
}
var $ret49534954 = $Hcases_DASH_val1515569($z49494950,f341571,fold_DASH_while50572,r345573);
++R.GAS;
return $ret49534954;
});
var anf_arg10284941 = R.makeObject({"empty":anf_obj10174944,
"link":anf_obj10274945});
var anf_arg10304942 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[462],0,arguments);
}
var ann_DASH_check_DASH_temp10294943 = R.throwNoBranchesMatched(L[462],("cases"));
return ann_DASH_check_DASH_temp10294943;
});
var $z49324933 = D;
var $f49384939 = function(_) {
return R.isFunction(anf_fun10154940)?anf_fun10154940.app(anf_arg10284941,anf_arg10304942):R.ffi.throwNonFunApp(L[461],anf_fun10154940,[anf_arg10284941,anf_arg10304942]);
};
try {
if(--R.GAS > 0) {
$z49324933 = $f49384939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49384939,
"from":L[461]});
}
} catch($e49304931) {
if(R.isCont($e49304931)) {
var $ss49344935 = {"from":L[461],
"go":function(ann_DASH_check_DASH_temp1014568) {
return $Hann_DASH_check_DASH_temp1516567(ann_DASH_check_DASH_temp1014568);
}};
$e49304931.stack[R.EXN_STACKHEIGHT++] = $ss49344935;
}
if(R.isPyretException($e49304931)) {
$e49304931.pyretStack.push(L[461]);
}
throw $e49304931;
}
var $ret49364937 = $Hann_DASH_check_DASH_temp1516567($z49324933);
++R.GAS;
return $ret49364937;
});
fold_DASH_while50572.$var = anf_assign10314827;
var anf_assign10444828 = R.makeFunction(function(f348517,base349516,lst350519) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[459],3,arguments);
}
return R.checkAnnArgs([List525],[lst350519],[L[460]],function() {
var $z49204921 = D;
var $f49264927 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(lst350519):R.ffi.throwNonFunApp(L[50],is_DASH_empty18116.$var,[lst350519]);
};
try {
if(--R.GAS > 0) {
$z49204921 = $f49264927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49264927,
"from":L[50]});
}
} catch($e49184919) {
if(R.isCont($e49184919)) {
var $ss49224923 = {"from":L[50],
"go":function(if_DASH_123515) {
return $Hif_DASH_1520514(if_DASH_123515,base349516,f348517,fold51518,lst350519);
}};
$e49184919.stack[R.EXN_STACKHEIGHT++] = $ss49224923;
}
if(R.isPyretException($e49184919)) {
$e49184919.pyretStack.push(L[50]);
}
throw $e49184919;
}
var $ret49244925 = $Hif_DASH_1520514($z49204921,base349516,f348517,fold51518,lst350519);
++R.GAS;
return $ret49244925;
});
});
fold51518.$var = anf_assign10444828;
var anf_assign10694829 = R.makeFunction(function(f357414,base358413,l1359416,l2360417) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[456],4,arguments);
}
return R.checkAnnArgs([List525,List525],[l1359416,l2360417],[L[457],L[458]],function() {
var $z49104911 = D;
var $f49164917 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l1359416):R.ffi.throwNonFunApp(L[37],is_DASH_empty18116.$var,[l1359416]);
};
try {
if(--R.GAS > 0) {
$z49104911 = $f49164917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49164917,
"from":L[37]});
}
} catch($e49084909) {
if(R.isCont($e49084909)) {
var $ss49124913 = {"from":L[37],
"go":function(or_DASH_oper_DASH_125412) {
return $Hor_DASH_oper_DASH_1527411(or_DASH_oper_DASH_125412,base358413,f357414,fold252415,is_DASH_empty18116,l1359416,l2360417);
}};
$e49084909.stack[R.EXN_STACKHEIGHT++] = $ss49124913;
}
if(R.isPyretException($e49084909)) {
$e49084909.pyretStack.push(L[37]);
}
throw $e49084909;
}
var $ret49144915 = $Hor_DASH_oper_DASH_1527411($z49104911,base358413,f357414,fold252415,is_DASH_empty18116,l1359416,l2360417);
++R.GAS;
return $ret49144915;
});
});
fold252415.$var = anf_assign10694829;
var anf_assign11004830 = R.makeFunction(function(f361280,base362279,l1363282,l2364283,l3365284) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[452],5,arguments);
}
return R.checkAnnArgs([List525,List525,List525],[l1363282,l2364283,l3365284],[L[453],L[454],L[455]],function() {
var $z49004901 = D;
var $f49064907 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l1363282):R.ffi.throwNonFunApp(L[24],is_DASH_empty18116.$var,[l1363282]);
};
try {
if(--R.GAS > 0) {
$z49004901 = $f49064907();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49064907,
"from":L[24]});
}
} catch($e48984899) {
if(R.isCont($e48984899)) {
var $ss49024903 = {"from":L[24],
"go":function(or_DASH_oper_DASH_128278) {
return $Hor_DASH_oper_DASH_1536277(or_DASH_oper_DASH_128278,base362279,f361280,fold353281,is_DASH_empty18116,l1363282,l2364283,l3365284);
}};
$e48984899.stack[R.EXN_STACKHEIGHT++] = $ss49024903;
}
if(R.isPyretException($e48984899)) {
$e48984899.pyretStack.push(L[24]);
}
throw $e48984899;
}
var $ret49044905 = $Hor_DASH_oper_DASH_1536277($z49004901,base362279,f361280,fold353281,is_DASH_empty18116,l1363282,l2364283,l3365284);
++R.GAS;
return $ret49044905;
});
});
fold353281.$var = anf_assign11004830;
var anf_assign11374831 = R.makeFunction(function(f366114,base367113,l1368117,l2369118,l3370119,l4371120) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[447],6,arguments);
}
return R.checkAnnArgs([List525,List525,List525,List525],[l1368117,l2369118,l3370119,l4371120],[L[448],L[449],L[450],L[451]],function() {
var $z48904891 = D;
var $f48964897 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(l1368117):R.ffi.throwNonFunApp(L[8],is_DASH_empty18116.$var,[l1368117]);
};
try {
if(--R.GAS > 0) {
$z48904891 = $f48964897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48964897,
"from":L[8]});
}
} catch($e48884889) {
if(R.isCont($e48884889)) {
var $ss48924893 = {"from":L[8],
"go":function(or_DASH_oper_DASH_132112) {
return $Hor_DASH_oper_DASH_1547111(or_DASH_oper_DASH_132112,base367113,f366114,fold454115,is_DASH_empty18116,l1368117,l2369118,l3370119,l4371120);
}};
$e48884889.stack[R.EXN_STACKHEIGHT++] = $ss48924893;
}
if(R.isPyretException($e48884889)) {
$e48884889.pyretStack.push(L[8]);
}
throw $e48884889;
}
var $ret48944895 = $Hor_DASH_oper_DASH_1547111($z48904891,base367113,f366114,fold454115,is_DASH_empty18116,l1368117,l2369118,l3370119,l4371120);
++R.GAS;
return $ret48944895;
});
});
fold454115.$var = anf_assign11374831;
var anf_assign11534833 = R.makeFunction(function(f37247,num3734864,base3744865,lst3754866) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[443],4,arguments);
}
return R.checkAnnArgs([$type$Number15,List525],[num3734864,lst3754866],[L[445],L[446]],function() {
var help37648 = {"$var":D,
"$name":"help"};
var anf_assign11524867 = R.makeFunction(function(n37749,acc37846,partial_DASH_list37950) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[444],3,arguments);
}
var $z48804881 = D;
var $f48864887 = function(_) {
return R.isFunction(is_DASH_empty18116.$var)?is_DASH_empty18116.$var.app(partial_DASH_list37950):R.ffi.throwNonFunApp(L[3],is_DASH_empty18116.$var,[partial_DASH_list37950]);
};
try {
if(--R.GAS > 0) {
$z48804881 = $f48864887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48864887,
"from":L[3]});
}
} catch($e48784879) {
if(R.isCont($e48784879)) {
var $ss48824883 = {"from":L[3],
"go":function(if_DASH_13645) {
return $Hif_DASH_155244(if_DASH_13645,acc37846,f37247,help37648,n37749,partial_DASH_list37950,_plus6);
}};
$e48784879.stack[R.EXN_STACKHEIGHT++] = $ss48824883;
}
if(R.isPyretException($e48784879)) {
$e48784879.pyretStack.push(L[3]);
}
throw $e48784879;
}
var $ret48844885 = $Hif_DASH_155244($z48804881,acc37846,f37247,help37648,n37749,partial_DASH_list37950,_plus6);
++R.GAS;
return $ret48844885;
});
help37648.$var = anf_assign11524867;
var $z48704871 = D;
var $f48764877 = function(_) {
return R.isFunction(help37648.$var)?help37648.$var.app(num3734864,base3744865,lst3754866):R.ffi.throwNonFunApp(L[443],help37648.$var,[num3734864,base3744865,lst3754866]);
};
try {
if(--R.GAS > 0) {
$z48704871 = $f48764877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48764877,
"from":L[443]});
}
} catch($e48684869) {
if(R.isCont($e48684869)) {
var $ss48724873 = {"from":L[443],
"go":function(ann_DASH_check_DASH_temp113843) {
return $Hann_DASH_check_DASH_temp155342(ann_DASH_check_DASH_temp113843);
}};
$e48684869.stack[R.EXN_STACKHEIGHT++] = $ss48724873;
}
if(R.isPyretException($e48684869)) {
$e48684869.pyretStack.push(L[443]);
}
throw $e48684869;
}
var $ret48744875 = $Hann_DASH_check_DASH_temp155342($z48704871);
++R.GAS;
return $ret48744875;
});
});
fold_n554832.$var = anf_assign11534833;
var index3894850 = get_DASH_help224783.$var;
var anf_obj11554852 = R.makeFunction(function(arr3914853) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[442],1,arguments);
}
var $z48564857 = D;
var $f48624863 = function(_) {
return R.isFunction(raw_DASH_array_DASH_to_DASH_list10)?raw_DASH_array_DASH_to_DASH_list10.app(arr3914853):R.ffi.throwNonFunApp(L[442],raw_DASH_array_DASH_to_DASH_list10,[arr3914853]);
};
try {
if(--R.GAS > 0) {
$z48564857 = $f48624863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48624863,
"from":L[442]});
}
} catch($e48544855) {
if(R.isCont($e48544855)) {
var $ss48584859 = {"from":L[442],
"go":function(ann_DASH_check_DASH_temp115441) {
return $Hann_DASH_check_DASH_temp155440(ann_DASH_check_DASH_temp115441);
}};
$e48544855.stack[R.EXN_STACKHEIGHT++] = $ss48584859;
}
if(R.isPyretException($e48544855)) {
$e48544855.pyretStack.push(L[442]);
}
throw $e48544855;
}
var $ret48604861 = $Hann_DASH_check_DASH_temp155440($z48564857);
++R.GAS;
return $ret48604861;
});
var list3904851 = R.makeObject({"make":anf_obj11554852});
var provides115626 = R.makeObject({"none":none73140,
"is-none":is_DASH_none84845,
"some":some93141,
"is-some":is_DASH_some102960,
"Option":Option114846,
"left":left124847,
"right":right134848,
"Either":Either144849,
"List":List164774.$var,
"is-List":is_DASH_List174776.$var,
"empty":empty191579.$var,
"is-empty":is_DASH_empty18116.$var,
"link":link211585.$var,
"is-link":is_DASH_link204780.$var,
"get-help":get_DASH_help224783.$var,
"set-help":set_DASH_help234785.$var,
"reverse-help":reverse_DASH_help243664.$var,
"range":range253508.$var,
"repeat":repeat263429.$var,
"filter":filter273330.$var,
"partition":partition284791.$var,
"find":find293138.$var,
"split-at":split_DASH_at304794.$var,
"any":any314796.$var,
"all":all324798.$var,
"all2":all2334800.$var,
"map":map342666.$var,
"map2":map2352539.$var,
"map3":map3362381.$var,
"map4":map4371586.$var,
"map_n":map_n382099.$var,
"map2_n":map2_n391959.$var,
"map3_n":map3_n401788.$var,
"map4_n":map4_n414809.$var,
"each":each424811.$var,
"each2":each2434813.$var,
"each3":each3444815.$var,
"each4":each4454817.$var,
"each_n":each_n464819.$var,
"each2_n":each2_n474821.$var,
"each3_n":each3_n484823.$var,
"each4_n":each4_n494825.$var,
"fold-while":fold_DASH_while50572.$var,
"fold":fold51518.$var,
"fold2":fold252415.$var,
"fold3":fold353281.$var,
"fold4":fold454115.$var,
"fold_n":fold_n554832.$var,
"index":index3894850,
"list":list3904851});
var anf_fun11574844 = G(builtins7,"current-checker",L[0]);
var $z48364837 = D;
var $f48424843 = function(_) {
return R.isFunction(anf_fun11574844)?anf_fun11574844.app():R.ffi.throwNonFunApp(L[0],anf_fun11574844,[]);
};
try {
if(--R.GAS > 0) {
$z48364837 = $f48424843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48424843,
"from":L[0]});
}
} catch($e48344835) {
if(R.isCont($e48344835)) {
var $ss48384839 = {"from":L[0],
"go":function(anf_bracket115824) {
return $Hanf_bracket155623(anf_bracket115824,List525,provides115626,nothing8);
}};
$e48344835.stack[R.EXN_STACKHEIGHT++] = $ss48384839;
}
if(R.isPyretException($e48344835)) {
$e48344835.pyretStack.push(L[0]);
}
throw $e48344835;
}
var $ret48404841 = $Hanf_bracket155623($z48364837,List525,provides115626,nothing8);
++R.GAS;
return $ret48404841;
},function(moduleVal) {
R.modules["$src/arr/base/lists.arr20"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/error',[],function() {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/base/error.arr12"]) {
return R.modules["$src/arr/base/error.arr12"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/base/error.arr";
var D = R.undefined;
var L = [[M,6,0,68,73,3,3436],
[M,105,2,4619,105,22,4639],
[M,104,2,4598,104,20,4616],
[M,103,4,4525,103,74,4595],
[M,102,2,4485,103,74,4595],
[M,101,4,4416,101,70,4482],
[M,100,2,4380,101,70,4482],
[M,99,4,4314,99,67,4377],
[M,98,2,4281,99,67,4377],
[M,97,4,4213,97,69,4278],
[M,96,2,4178,97,69,4278],
[M,93,4,4055,95,7,4175],
[M,92,2,4017,95,7,4175],
[M,89,4,3894,91,7,4014],
[M,88,2,3862,91,7,4014],
[M,85,4,3788,87,7,3859],
[M,84,2,3759,87,7,3859],
[M,81,4,3670,83,7,3756],
[M,80,2,3637,83,7,3756],
[M,78,6,3541,78,91,3626],
[M,77,4,3519,79,7,3634],
[M,78,76,3611,78,91,3626],
[M,76,2,3457,79,7,3634],
[M,72,2,3420,72,14,3432],
[M,70,6,3312,70,103,3409],
[M,70,66,3372,70,82,3388],
[M,69,4,3290,71,7,3417],
[M,70,92,3398,70,103,3409],
[M,68,2,3176,71,7,3417],
[M,65,4,3075,67,7,3173],
[M,64,2,3012,67,7,3173],
[M,62,6,2895,62,112,3001],
[M,62,63,2952,62,84,2973],
[M,62,63,2952,62,78,2967],
[M,62,63,2952,62,71,2960],
[M,61,4,2873,63,7,3009],
[M,60,2,2823,63,7,3009],
[M,59,2,2734,59,88,2820],
[M,57,6,2625,57,104,2723],
[M,57,80,2699,57,104,2723],
[M,57,87,2706,57,103,2722],
[M,56,4,2603,58,7,2731],
[M,55,2,2550,58,7,2731],
[M,53,6,2384,53,161,2539],
[M,53,76,2454,53,105,2483],
[M,53,85,2463,53,104,2482],
[M,53,142,2520,53,160,2538],
[M,53,142,2520,53,158,2536],
[M,53,142,2520,53,151,2529],
[M,53,133,2511,53,161,2539],
[M,52,4,2362,54,7,2547],
[M,51,2,2304,54,7,2547],
[M,49,6,2083,49,216,2293],
[M,49,126,2203,49,141,2218],
[M,49,166,2243,49,183,2260],
[M,49,173,2250,49,182,2259],
[M,49,199,2276,49,216,2293],
[M,49,206,2283,49,215,2292],
[M,48,4,2061,50,7,2301],
[M,47,2,1997,50,7,2301],
[M,45,6,1791,45,201,1986],
[M,45,184,1969,45,201,1986],
[M,45,191,1976,45,200,1985],
[M,44,4,1769,46,7,1994],
[M,43,2,1734,46,7,1994],
[M,41,6,1605,41,124,1723],
[M,41,73,1672,41,90,1689],
[M,41,80,1679,41,89,1688],
[M,41,108,1707,41,124,1723],
[M,41,115,1714,41,123,1722],
[M,40,4,1583,42,7,1731],
[M,39,2,1533,42,7,1731],
[M,37,6,1459,37,69,1522],
[M,37,53,1506,37,69,1522],
[M,37,60,1513,37,68,1521],
[M,36,4,1437,38,7,1530],
[M,35,2,1383,38,7,1530],
[M,33,6,1222,33,156,1372],
[M,33,79,1295,33,87,1303],
[M,33,99,1315,33,120,1336],
[M,33,99,1315,33,114,1330],
[M,33,99,1315,33,107,1323],
[M,33,138,1354,33,156,1372],
[M,33,145,1361,33,155,1371],
[M,32,4,1200,34,7,1380],
[M,31,2,1146,34,7,1380],
[M,29,6,1004,29,137,1135],
[M,29,80,1078,29,101,1099],
[M,29,80,1078,29,95,1093],
[M,29,80,1078,29,88,1086],
[M,29,119,1117,29,137,1135],
[M,29,126,1124,29,136,1134],
[M,28,4,982,30,7,1143],
[M,27,2,931,30,7,1143],
[M,25,6,776,25,150,920],
[M,25,74,844,25,84,854],
[M,25,96,866,25,116,886],
[M,25,103,873,25,115,885],
[M,24,4,754,26,7,928],
[M,23,2,693,26,7,928],
[M,21,6,583,21,105,682],
[M,21,57,634,21,67,644],
[M,21,89,666,21,105,682],
[M,21,96,673,21,104,681],
[M,20,4,561,22,7,690],
[M,19,2,506,22,7,690],
[M,17,6,410,17,91,495],
[M,17,69,473,17,91,495],
[M,17,76,480,17,90,494],
[M,16,4,388,18,7,503],
[M,15,2,341,18,7,503],
[M,12,4,242,14,7,338],
[M,11,2,183,14,7,338],
[M,7,2,89,10,7,180],
[M,75,0,3438,106,3,4643],
[M,76,4,3459,76,53,3508],
[M,76,46,3501,76,52,3507],
[M,80,4,3639,80,24,3659],
[M,84,4,3761,84,20,3777],
[M,88,4,3864,88,23,3883],
[M,92,4,4019,92,29,4044],
[M,96,4,4180,96,26,4202],
[M,98,4,4283,98,24,4303],
[M,100,4,4382,100,27,4405],
[M,102,4,4487,102,31,4514],
[M,104,4,4600,104,20,4616],
[M,105,4,4621,105,22,4639],
[M,105,18,4635,105,21,4638],
[M,104,16,4612,104,19,4615],
[M,103,49,4570,103,70,4591],
[M,103,49,4570,103,64,4585],
[M,103,49,4570,103,57,4578],
[M,102,27,4510,102,30,4513],
[M,101,45,4457,101,66,4478],
[M,101,45,4457,101,60,4472],
[M,101,45,4457,101,53,4465],
[M,100,23,4401,100,26,4404],
[M,99,42,4352,99,63,4373],
[M,99,42,4352,99,57,4367],
[M,99,42,4352,99,50,4360],
[M,98,20,4299,98,23,4302],
[M,97,44,4253,97,65,4274],
[M,97,44,4253,97,59,4268],
[M,97,44,4253,97,52,4261],
[M,96,22,4198,96,25,4201],
[M,94,75,4146,94,96,4167],
[M,94,75,4146,94,90,4161],
[M,94,75,4146,94,83,4154],
[M,92,25,4040,92,28,4043],
[M,90,75,3985,90,96,4006],
[M,90,75,3985,90,90,4000],
[M,90,75,3985,90,83,3993],
[M,88,19,3879,88,22,3882],
[M,86,26,3830,86,47,3851],
[M,86,26,3830,86,41,3845],
[M,86,26,3830,86,34,3838],
[M,84,16,3773,84,19,3776],
[M,82,41,3727,82,62,3748],
[M,82,41,3727,82,56,3742],
[M,82,41,3727,82,49,3735],
[M,80,20,3655,80,23,3658],
[M,78,30,3565,78,51,3586],
[M,78,30,3565,78,45,3580],
[M,78,30,3565,78,38,3573],
[M,76,32,3487,76,52,3507],
[M,76,27,3482,76,30,3485],
[M,7,4,91,7,40,127],
[M,7,33,120,7,39,126],
[M,11,4,185,11,50,231],
[M,11,43,224,11,49,230],
[M,15,4,343,15,38,377],
[M,19,4,508,19,46,550],
[M,19,39,543,19,45,549],
[M,23,4,695,23,52,743],
[M,23,45,736,23,51,742],
[M,27,4,933,27,42,971],
[M,31,4,1148,31,45,1189],
[M,35,4,1385,35,45,1426],
[M,35,38,1419,35,44,1425],
[M,39,4,1535,39,41,1572],
[M,43,4,1736,43,26,1758],
[M,47,4,1999,47,55,2050],
[M,51,4,2306,51,49,2351],
[M,55,4,2552,55,44,2592],
[M,59,4,2736,59,88,2820],
[M,59,29,2761,59,35,2767],
[M,59,48,2780,59,54,2786],
[M,59,72,2804,59,78,2810],
[M,60,4,2825,60,41,2862],
[M,60,34,2855,60,40,2861],
[M,64,4,3014,64,30,3040],
[M,68,4,3178,68,88,3262],
[M,68,39,3213,68,45,3219],
[M,68,63,3237,68,69,3243],
[M,68,81,3255,68,87,3261],
[M,70,34,3340,70,54,3360],
[M,70,43,3349,70,53,3359],
[M,68,71,3245,68,87,3261],
[M,68,54,3228,68,69,3243],
[M,68,47,3221,68,52,3226],
[M,68,24,3198,68,45,3219],
[M,66,56,3147,66,74,3165],
[M,66,63,3154,66,73,3164],
[M,64,24,3034,64,29,3039],
[M,62,33,2922,62,42,2931],
[M,60,26,2847,60,40,2861],
[M,60,21,2842,60,24,2845],
[M,59,80,2812,59,87,2819],
[M,59,56,2788,59,78,2810],
[M,59,37,2769,59,54,2786],
[M,59,17,2749,59,35,2767],
[M,59,12,2744,59,15,2747],
[M,57,41,2660,57,62,2681],
[M,57,41,2660,57,56,2675],
[M,57,41,2660,57,49,2668],
[M,55,39,2587,55,43,2591],
[M,55,26,2574,55,37,2585],
[M,55,21,2569,55,24,2572],
[M,53,34,2412,53,59,2437],
[M,53,34,2412,53,53,2431],
[M,53,34,2412,53,46,2424],
[M,51,44,2346,51,48,2350],
[M,51,28,2330,51,42,2344],
[M,51,19,2321,51,26,2328],
[M,49,33,2110,49,44,2121],
[M,47,44,2039,47,54,2049],
[M,47,36,2031,47,42,2037],
[M,47,30,2025,47,34,2029],
[M,47,24,2019,47,28,2023],
[M,45,151,1936,45,168,1953],
[M,45,158,1943,45,167,1952],
[M,43,21,1753,43,25,1757],
[M,43,15,1747,43,19,1751],
[M,41,44,1643,41,60,1659],
[M,41,51,1650,41,59,1658],
[M,39,36,1567,39,40,1571],
[M,39,31,1562,39,34,1565],
[M,39,26,1557,39,29,1560],
[M,37,27,1480,37,35,1488],
[M,35,31,1412,35,44,1425],
[M,35,26,1407,35,29,1410],
[M,33,45,1261,33,58,1274],
[M,31,39,1183,31,44,1188],
[M,31,34,1178,31,37,1181],
[M,31,24,1168,31,32,1176],
[M,31,19,1163,31,22,1166],
[M,29,60,1058,29,68,1066],
[M,27,36,965,27,41,970],
[M,27,31,960,27,34,963],
[M,27,26,955,27,29,958],
[M,25,20,790,25,41,811],
[M,25,20,790,25,35,805],
[M,25,20,790,25,28,798],
[M,23,36,727,23,51,742],
[M,23,27,718,23,34,725],
[M,23,22,713,23,25,716],
[M,21,20,597,21,41,618],
[M,21,20,597,21,35,612],
[M,21,20,597,21,28,605],
[M,19,30,534,19,45,549],
[M,19,25,529,19,28,532],
[M,19,20,524,19,23,527],
[M,17,27,431,17,39,443],
[M,15,28,367,15,37,376],
[M,15,19,358,15,26,365],
[M,13,6,264,13,72,330],
[M,13,40,298,13,55,313],
[M,11,29,210,11,49,230],
[M,11,24,205,11,27,208],
[M,9,6,160,9,18,172],
[M,8,4,138,10,7,180],
[M,7,22,109,7,39,126]];
var _plus5 = NAMESPACE.get("_plus");
var builtins6 = NAMESPACE.get("builtins");
var nothing7 = NAMESPACE.get("nothing");
var torepr8 = NAMESPACE.get("torepr");
var tostring9 = NAMESPACE.get("tostring");
var $type$Number10 = NAMESPACE.get("$type$Number");
var $type$String11 = NAMESPACE.get("$type$String");
var $Hanf_bracket131713 = function(anf_bracket94014,ParseError315,RuntimeError116,provides93817,nothing7) {
var anf_fun94128 = G(anf_bracket94014,"results",L[0]);
var $z2021 = D;
var $f2627 = function(_) {
return R.isFunction(anf_fun94128)?anf_fun94128.app():R.ffi.throwNonFunApp(L[0],anf_fun94128,[]);
};
try {
if(--R.GAS > 0) {
$z2021 = $f2627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2627,
"from":L[0]});
}
} catch($e1819) {
if(R.isCont($e1819)) {
var $ss2223 = {"from":L[0],
"go":function(checks94229) {
return $Hchecks131630(checks94229,ParseError315,RuntimeError116,provides93817,nothing7);
}};
$e1819.stack[R.EXN_STACKHEIGHT++] = $ss2223;
}
if(R.isPyretException($e1819)) {
$e1819.pyretStack.push(L[0]);
}
throw $e1819;
}
var $ret2425 = $Hchecks131630($z2021,ParseError315,RuntimeError116,provides93817,nothing7);
++R.GAS;
return $ret2425;
};
var $Hchecks131630 = function(checks94229,ParseError315,RuntimeError116,provides93817,nothing7) {
return R.makeObject({"answer":nothing7,
"provide-plus-types":R.makeObject({"values":provides93817,
"types":{"RuntimeError":RuntimeError116,
"ParseError":ParseError315}}),
"checks":checks94229});
};
var $Hanf_arg131531 = function(anf_arg90932,_plus5) {
var $z3536 = D;
var $f4142 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg90932,(")")):R.ffi.throwNonFunApp(L[1],_plus5,[anf_arg90932,(")")]);
};
try {
if(--R.GAS > 0) {
$z3536 = $f4142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4142,
"from":L[1]});
}
} catch($e3334) {
if(R.isCont($e3334)) {
var $ss3738 = {"from":L[1],
"go":function(anf_arg91043) {
return $Hanf_arg131444(anf_arg91043,_plus5);
}};
$e3334.stack[R.EXN_STACKHEIGHT++] = $ss3738;
}
if(R.isPyretException($e3334)) {
$e3334.pyretStack.push(L[1]);
}
throw $e3334;
}
var $ret3940 = $Hanf_arg131444($z3536,_plus5);
++R.GAS;
return $ret3940;
};
var $Hanf_arg131444 = function(anf_arg91043,_plus5) {
var $z4748 = D;
var $f5354 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg91043):R.ffi.throwNonFunApp(L[1],_plus5,[("("),anf_arg91043]);
};
try {
if(--R.GAS > 0) {
$z4748 = $f5354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5354,
"from":L[1]});
}
} catch($e4546) {
if(R.isCont($e4546)) {
var $ss4950 = {"from":L[1],
"go":function(anf_arg91155) {
return $Hanf_arg131356(anf_arg91155,_plus5);
}};
$e4546.stack[R.EXN_STACKHEIGHT++] = $ss4950;
}
if(R.isPyretException($e4546)) {
$e4546.pyretStack.push(L[1]);
}
throw $e4546;
}
var $ret5152 = $Hanf_arg131356($z4748,_plus5);
++R.GAS;
return $ret5152;
};
var $Hanf_arg131356 = function(anf_arg91155,_plus5) {
var $z5960 = D;
var $f6566 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("missing-comma"),anf_arg91155):R.ffi.throwNonFunApp(L[1],_plus5,[("missing-comma"),anf_arg91155]);
};
try {
if(--R.GAS > 0) {
$z5960 = $f6566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6566,
"from":L[1]});
}
} catch($e5758) {
if(R.isCont($e5758)) {
var $ss6162 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp90767) {
return $Hann_DASH_check_DASH_temp131268(ann_DASH_check_DASH_temp90767);
}};
$e5758.stack[R.EXN_STACKHEIGHT++] = $ss6162;
}
if(R.isPyretException($e5758)) {
$e5758.pyretStack.push(L[1]);
}
throw $e5758;
}
var $ret6364 = $Hann_DASH_check_DASH_temp131268($z5960);
++R.GAS;
return $ret6364;
};
var $Hann_DASH_check_DASH_temp131268 = function(ann_DASH_check_DASH_temp90767) {
return ann_DASH_check_DASH_temp90767;
};
var $Hcont_tail_arg131069 = function(cont_tail_arg90470,if_helper89671) {
if(--R.GAS > 0) {
$z7273 = R.isFunction(if_helper89671)?if_helper89671.app(cont_tail_arg90470):R.ffi.throwNonFunApp(L[1],if_helper89671,[cont_tail_arg90470]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper89671)?if_helper89671.app(cont_tail_arg90470):R.ffi.throwNonFunApp(L[1],if_helper89671,[cont_tail_arg90470]);
},
"from":L[1]});
}
++R.GAS;
return $z7273;
};
var $Hcont_tail_arg131175 = function(cont_tail_arg90176,if_helper89671) {
if(--R.GAS > 0) {
$z7778 = R.isFunction(if_helper89671)?if_helper89671.app(cont_tail_arg90176):R.ffi.throwNonFunApp(L[1],if_helper89671,[cont_tail_arg90176]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper89671)?if_helper89671.app(cont_tail_arg90176):R.ffi.throwNonFunApp(L[1],if_helper89671,[cont_tail_arg90176]);
},
"from":L[1]});
}
++R.GAS;
return $z7778;
};
var $Hanf_arg130979 = function(anf_arg89180,_plus5) {
var $z8384 = D;
var $f8990 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg89180,(")")):R.ffi.throwNonFunApp(L[2],_plus5,[anf_arg89180,(")")]);
};
try {
if(--R.GAS > 0) {
$z8384 = $f8990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8990,
"from":L[2]});
}
} catch($e8182) {
if(R.isCont($e8182)) {
var $ss8586 = {"from":L[2],
"go":function(anf_arg89291) {
return $Hanf_arg130892(anf_arg89291,_plus5);
}};
$e8182.stack[R.EXN_STACKHEIGHT++] = $ss8586;
}
if(R.isPyretException($e8182)) {
$e8182.pyretStack.push(L[2]);
}
throw $e8182;
}
var $ret8788 = $Hanf_arg130892($z8384,_plus5);
++R.GAS;
return $ret8788;
};
var $Hanf_arg130892 = function(anf_arg89291,_plus5) {
var $z9596 = D;
var $f101102 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg89291):R.ffi.throwNonFunApp(L[2],_plus5,[("("),anf_arg89291]);
};
try {
if(--R.GAS > 0) {
$z9596 = $f101102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f101102,
"from":L[2]});
}
} catch($e9394) {
if(R.isCont($e9394)) {
var $ss9798 = {"from":L[2],
"go":function(anf_arg893103) {
return $Hanf_arg1307104(anf_arg893103,_plus5);
}};
$e9394.stack[R.EXN_STACKHEIGHT++] = $ss9798;
}
if(R.isPyretException($e9394)) {
$e9394.pyretStack.push(L[2]);
}
throw $e9394;
}
var $ret99100 = $Hanf_arg1307104($z9596,_plus5);
++R.GAS;
return $ret99100;
};
var $Hanf_arg1307104 = function(anf_arg893103,_plus5) {
var $z107108 = D;
var $f113114 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("missing-end"),anf_arg893103):R.ffi.throwNonFunApp(L[2],_plus5,[("missing-end"),anf_arg893103]);
};
try {
if(--R.GAS > 0) {
$z107108 = $f113114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f113114,
"from":L[2]});
}
} catch($e105106) {
if(R.isCont($e105106)) {
var $ss109110 = {"from":L[2],
"go":function(ann_DASH_check_DASH_temp889115) {
return $Hann_DASH_check_DASH_temp1306116(ann_DASH_check_DASH_temp889115);
}};
$e105106.stack[R.EXN_STACKHEIGHT++] = $ss109110;
}
if(R.isPyretException($e105106)) {
$e105106.pyretStack.push(L[2]);
}
throw $e105106;
}
var $ret111112 = $Hann_DASH_check_DASH_temp1306116($z107108);
++R.GAS;
return $ret111112;
};
var $Hann_DASH_check_DASH_temp1306116 = function(ann_DASH_check_DASH_temp889115) {
return ann_DASH_check_DASH_temp889115;
};
var $Hcont_tail_arg1304117 = function(cont_tail_arg886118,if_helper878119) {
if(--R.GAS > 0) {
$z120121 = R.isFunction(if_helper878119)?if_helper878119.app(cont_tail_arg886118):R.ffi.throwNonFunApp(L[2],if_helper878119,[cont_tail_arg886118]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper878119)?if_helper878119.app(cont_tail_arg886118):R.ffi.throwNonFunApp(L[2],if_helper878119,[cont_tail_arg886118]);
},
"from":L[2]});
}
++R.GAS;
return $z120121;
};
var $Hcont_tail_arg1305122 = function(cont_tail_arg883123,if_helper878119) {
if(--R.GAS > 0) {
$z124125 = R.isFunction(if_helper878119)?if_helper878119.app(cont_tail_arg883123):R.ffi.throwNonFunApp(L[2],if_helper878119,[cont_tail_arg883123]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper878119)?if_helper878119.app(cont_tail_arg883123):R.ffi.throwNonFunApp(L[2],if_helper878119,[cont_tail_arg883123]);
},
"from":L[2]});
}
++R.GAS;
return $z124125;
};
var $Hanf_arg1303126 = function(anf_arg875127,_plus5) {
var $z130131 = D;
var $f136137 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("app-args-missing-comma: "),anf_arg875127):R.ffi.throwNonFunApp(L[3],_plus5,[("app-args-missing-comma: "),anf_arg875127]);
};
try {
if(--R.GAS > 0) {
$z130131 = $f136137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f136137,
"from":L[3]});
}
} catch($e128129) {
if(R.isCont($e128129)) {
var $ss132133 = {"from":L[3],
"go":function(ann_DASH_check_DASH_temp872138) {
return $Hann_DASH_check_DASH_temp1302139(ann_DASH_check_DASH_temp872138);
}};
$e128129.stack[R.EXN_STACKHEIGHT++] = $ss132133;
}
if(R.isPyretException($e128129)) {
$e128129.pyretStack.push(L[3]);
}
throw $e128129;
}
var $ret134135 = $Hann_DASH_check_DASH_temp1302139($z130131);
++R.GAS;
return $ret134135;
};
var $Hann_DASH_check_DASH_temp1302139 = function(ann_DASH_check_DASH_temp872138) {
return ann_DASH_check_DASH_temp872138;
};
var $Hanf_arg1301140 = function(anf_arg868141,_plus5) {
var $z144145 = D;
var $f150151 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg868141,(")")):R.ffi.throwNonFunApp(L[4],_plus5,[anf_arg868141,(")")]);
};
try {
if(--R.GAS > 0) {
$z144145 = $f150151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f150151,
"from":L[4]});
}
} catch($e142143) {
if(R.isCont($e142143)) {
var $ss146147 = {"from":L[4],
"go":function(anf_arg869152) {
return $Hanf_arg1300153(anf_arg869152,_plus5);
}};
$e142143.stack[R.EXN_STACKHEIGHT++] = $ss146147;
}
if(R.isPyretException($e142143)) {
$e142143.pyretStack.push(L[4]);
}
throw $e142143;
}
var $ret148149 = $Hanf_arg1300153($z144145,_plus5);
++R.GAS;
return $ret148149;
};
var $Hanf_arg1300153 = function(anf_arg869152,_plus5) {
var $z156157 = D;
var $f162163 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg869152):R.ffi.throwNonFunApp(L[4],_plus5,[("("),anf_arg869152]);
};
try {
if(--R.GAS > 0) {
$z156157 = $f162163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f162163,
"from":L[4]});
}
} catch($e154155) {
if(R.isCont($e154155)) {
var $ss158159 = {"from":L[4],
"go":function(anf_arg870164) {
return $Hanf_arg1299165(anf_arg870164,_plus5);
}};
$e154155.stack[R.EXN_STACKHEIGHT++] = $ss158159;
}
if(R.isPyretException($e154155)) {
$e154155.pyretStack.push(L[4]);
}
throw $e154155;
}
var $ret160161 = $Hanf_arg1299165($z156157,_plus5);
++R.GAS;
return $ret160161;
};
var $Hanf_arg1299165 = function(anf_arg870164,_plus5) {
var $z168169 = D;
var $f174175 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("app-args-missing-comma"),anf_arg870164):R.ffi.throwNonFunApp(L[4],_plus5,[("app-args-missing-comma"),anf_arg870164]);
};
try {
if(--R.GAS > 0) {
$z168169 = $f174175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f174175,
"from":L[4]});
}
} catch($e166167) {
if(R.isCont($e166167)) {
var $ss170171 = {"from":L[4],
"go":function(ann_DASH_check_DASH_temp866176) {
return $Hann_DASH_check_DASH_temp1298177(ann_DASH_check_DASH_temp866176);
}};
$e166167.stack[R.EXN_STACKHEIGHT++] = $ss170171;
}
if(R.isPyretException($e166167)) {
$e166167.pyretStack.push(L[4]);
}
throw $e166167;
}
var $ret172173 = $Hann_DASH_check_DASH_temp1298177($z168169);
++R.GAS;
return $ret172173;
};
var $Hann_DASH_check_DASH_temp1298177 = function(ann_DASH_check_DASH_temp866176) {
return ann_DASH_check_DASH_temp866176;
};
var $Hcont_tail_arg1296178 = function(cont_tail_arg863179,if_helper855180) {
if(--R.GAS > 0) {
$z181182 = R.isFunction(if_helper855180)?if_helper855180.app(cont_tail_arg863179):R.ffi.throwNonFunApp(L[4],if_helper855180,[cont_tail_arg863179]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper855180)?if_helper855180.app(cont_tail_arg863179):R.ffi.throwNonFunApp(L[4],if_helper855180,[cont_tail_arg863179]);
},
"from":L[4]});
}
++R.GAS;
return $z181182;
};
var $Hcont_tail_arg1297183 = function(cont_tail_arg860184,if_helper855180) {
if(--R.GAS > 0) {
$z185186 = R.isFunction(if_helper855180)?if_helper855180.app(cont_tail_arg860184):R.ffi.throwNonFunApp(L[4],if_helper855180,[cont_tail_arg860184]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper855180)?if_helper855180.app(cont_tail_arg860184):R.ffi.throwNonFunApp(L[4],if_helper855180,[cont_tail_arg860184]);
},
"from":L[4]});
}
++R.GAS;
return $z185186;
};
var $Hanf_arg1295187 = function(anf_arg852188,_plus5) {
var $z191192 = D;
var $f197198 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("args-missing-comma: "),anf_arg852188):R.ffi.throwNonFunApp(L[5],_plus5,[("args-missing-comma: "),anf_arg852188]);
};
try {
if(--R.GAS > 0) {
$z191192 = $f197198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f197198,
"from":L[5]});
}
} catch($e189190) {
if(R.isCont($e189190)) {
var $ss193194 = {"from":L[5],
"go":function(ann_DASH_check_DASH_temp849199) {
return $Hann_DASH_check_DASH_temp1294200(ann_DASH_check_DASH_temp849199);
}};
$e189190.stack[R.EXN_STACKHEIGHT++] = $ss193194;
}
if(R.isPyretException($e189190)) {
$e189190.pyretStack.push(L[5]);
}
throw $e189190;
}
var $ret195196 = $Hann_DASH_check_DASH_temp1294200($z191192);
++R.GAS;
return $ret195196;
};
var $Hann_DASH_check_DASH_temp1294200 = function(ann_DASH_check_DASH_temp849199) {
return ann_DASH_check_DASH_temp849199;
};
var $Hanf_arg1293201 = function(anf_arg845202,_plus5) {
var $z205206 = D;
var $f211212 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg845202,(")")):R.ffi.throwNonFunApp(L[6],_plus5,[anf_arg845202,(")")]);
};
try {
if(--R.GAS > 0) {
$z205206 = $f211212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f211212,
"from":L[6]});
}
} catch($e203204) {
if(R.isCont($e203204)) {
var $ss207208 = {"from":L[6],
"go":function(anf_arg846213) {
return $Hanf_arg1292214(anf_arg846213,_plus5);
}};
$e203204.stack[R.EXN_STACKHEIGHT++] = $ss207208;
}
if(R.isPyretException($e203204)) {
$e203204.pyretStack.push(L[6]);
}
throw $e203204;
}
var $ret209210 = $Hanf_arg1292214($z205206,_plus5);
++R.GAS;
return $ret209210;
};
var $Hanf_arg1292214 = function(anf_arg846213,_plus5) {
var $z217218 = D;
var $f223224 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg846213):R.ffi.throwNonFunApp(L[6],_plus5,[("("),anf_arg846213]);
};
try {
if(--R.GAS > 0) {
$z217218 = $f223224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f223224,
"from":L[6]});
}
} catch($e215216) {
if(R.isCont($e215216)) {
var $ss219220 = {"from":L[6],
"go":function(anf_arg847225) {
return $Hanf_arg1291226(anf_arg847225,_plus5);
}};
$e215216.stack[R.EXN_STACKHEIGHT++] = $ss219220;
}
if(R.isPyretException($e215216)) {
$e215216.pyretStack.push(L[6]);
}
throw $e215216;
}
var $ret221222 = $Hanf_arg1291226($z217218,_plus5);
++R.GAS;
return $ret221222;
};
var $Hanf_arg1291226 = function(anf_arg847225,_plus5) {
var $z229230 = D;
var $f235236 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("args-missing-comma"),anf_arg847225):R.ffi.throwNonFunApp(L[6],_plus5,[("args-missing-comma"),anf_arg847225]);
};
try {
if(--R.GAS > 0) {
$z229230 = $f235236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f235236,
"from":L[6]});
}
} catch($e227228) {
if(R.isCont($e227228)) {
var $ss231232 = {"from":L[6],
"go":function(ann_DASH_check_DASH_temp843237) {
return $Hann_DASH_check_DASH_temp1290238(ann_DASH_check_DASH_temp843237);
}};
$e227228.stack[R.EXN_STACKHEIGHT++] = $ss231232;
}
if(R.isPyretException($e227228)) {
$e227228.pyretStack.push(L[6]);
}
throw $e227228;
}
var $ret233234 = $Hann_DASH_check_DASH_temp1290238($z229230);
++R.GAS;
return $ret233234;
};
var $Hann_DASH_check_DASH_temp1290238 = function(ann_DASH_check_DASH_temp843237) {
return ann_DASH_check_DASH_temp843237;
};
var $Hcont_tail_arg1288239 = function(cont_tail_arg840240,if_helper832241) {
if(--R.GAS > 0) {
$z242243 = R.isFunction(if_helper832241)?if_helper832241.app(cont_tail_arg840240):R.ffi.throwNonFunApp(L[6],if_helper832241,[cont_tail_arg840240]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper832241)?if_helper832241.app(cont_tail_arg840240):R.ffi.throwNonFunApp(L[6],if_helper832241,[cont_tail_arg840240]);
},
"from":L[6]});
}
++R.GAS;
return $z242243;
};
var $Hcont_tail_arg1289244 = function(cont_tail_arg837245,if_helper832241) {
if(--R.GAS > 0) {
$z246247 = R.isFunction(if_helper832241)?if_helper832241.app(cont_tail_arg837245):R.ffi.throwNonFunApp(L[6],if_helper832241,[cont_tail_arg837245]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper832241)?if_helper832241.app(cont_tail_arg837245):R.ffi.throwNonFunApp(L[6],if_helper832241,[cont_tail_arg837245]);
},
"from":L[6]});
}
++R.GAS;
return $z246247;
};
var $Hanf_arg1287248 = function(anf_arg829249,_plus5) {
var $z252253 = D;
var $f258259 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("fun-missing-end: "),anf_arg829249):R.ffi.throwNonFunApp(L[7],_plus5,[("fun-missing-end: "),anf_arg829249]);
};
try {
if(--R.GAS > 0) {
$z252253 = $f258259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f258259,
"from":L[7]});
}
} catch($e250251) {
if(R.isCont($e250251)) {
var $ss254255 = {"from":L[7],
"go":function(ann_DASH_check_DASH_temp826260) {
return $Hann_DASH_check_DASH_temp1286261(ann_DASH_check_DASH_temp826260);
}};
$e250251.stack[R.EXN_STACKHEIGHT++] = $ss254255;
}
if(R.isPyretException($e250251)) {
$e250251.pyretStack.push(L[7]);
}
throw $e250251;
}
var $ret256257 = $Hann_DASH_check_DASH_temp1286261($z252253);
++R.GAS;
return $ret256257;
};
var $Hann_DASH_check_DASH_temp1286261 = function(ann_DASH_check_DASH_temp826260) {
return ann_DASH_check_DASH_temp826260;
};
var $Hanf_arg1285262 = function(anf_arg822263,_plus5) {
var $z266267 = D;
var $f272273 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg822263,(")")):R.ffi.throwNonFunApp(L[8],_plus5,[anf_arg822263,(")")]);
};
try {
if(--R.GAS > 0) {
$z266267 = $f272273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f272273,
"from":L[8]});
}
} catch($e264265) {
if(R.isCont($e264265)) {
var $ss268269 = {"from":L[8],
"go":function(anf_arg823274) {
return $Hanf_arg1284275(anf_arg823274,_plus5);
}};
$e264265.stack[R.EXN_STACKHEIGHT++] = $ss268269;
}
if(R.isPyretException($e264265)) {
$e264265.pyretStack.push(L[8]);
}
throw $e264265;
}
var $ret270271 = $Hanf_arg1284275($z266267,_plus5);
++R.GAS;
return $ret270271;
};
var $Hanf_arg1284275 = function(anf_arg823274,_plus5) {
var $z278279 = D;
var $f284285 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg823274):R.ffi.throwNonFunApp(L[8],_plus5,[("("),anf_arg823274]);
};
try {
if(--R.GAS > 0) {
$z278279 = $f284285();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f284285,
"from":L[8]});
}
} catch($e276277) {
if(R.isCont($e276277)) {
var $ss280281 = {"from":L[8],
"go":function(anf_arg824286) {
return $Hanf_arg1283287(anf_arg824286,_plus5);
}};
$e276277.stack[R.EXN_STACKHEIGHT++] = $ss280281;
}
if(R.isPyretException($e276277)) {
$e276277.pyretStack.push(L[8]);
}
throw $e276277;
}
var $ret282283 = $Hanf_arg1283287($z278279,_plus5);
++R.GAS;
return $ret282283;
};
var $Hanf_arg1283287 = function(anf_arg824286,_plus5) {
var $z290291 = D;
var $f296297 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("fun-missing-end"),anf_arg824286):R.ffi.throwNonFunApp(L[8],_plus5,[("fun-missing-end"),anf_arg824286]);
};
try {
if(--R.GAS > 0) {
$z290291 = $f296297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f296297,
"from":L[8]});
}
} catch($e288289) {
if(R.isCont($e288289)) {
var $ss292293 = {"from":L[8],
"go":function(ann_DASH_check_DASH_temp820298) {
return $Hann_DASH_check_DASH_temp1282299(ann_DASH_check_DASH_temp820298);
}};
$e288289.stack[R.EXN_STACKHEIGHT++] = $ss292293;
}
if(R.isPyretException($e288289)) {
$e288289.pyretStack.push(L[8]);
}
throw $e288289;
}
var $ret294295 = $Hann_DASH_check_DASH_temp1282299($z290291);
++R.GAS;
return $ret294295;
};
var $Hann_DASH_check_DASH_temp1282299 = function(ann_DASH_check_DASH_temp820298) {
return ann_DASH_check_DASH_temp820298;
};
var $Hcont_tail_arg1280300 = function(cont_tail_arg817301,if_helper809302) {
if(--R.GAS > 0) {
$z303304 = R.isFunction(if_helper809302)?if_helper809302.app(cont_tail_arg817301):R.ffi.throwNonFunApp(L[8],if_helper809302,[cont_tail_arg817301]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper809302)?if_helper809302.app(cont_tail_arg817301):R.ffi.throwNonFunApp(L[8],if_helper809302,[cont_tail_arg817301]);
},
"from":L[8]});
}
++R.GAS;
return $z303304;
};
var $Hcont_tail_arg1281305 = function(cont_tail_arg814306,if_helper809302) {
if(--R.GAS > 0) {
$z307308 = R.isFunction(if_helper809302)?if_helper809302.app(cont_tail_arg814306):R.ffi.throwNonFunApp(L[8],if_helper809302,[cont_tail_arg814306]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper809302)?if_helper809302.app(cont_tail_arg814306):R.ffi.throwNonFunApp(L[8],if_helper809302,[cont_tail_arg814306]);
},
"from":L[8]});
}
++R.GAS;
return $z307308;
};
var $Hanf_arg1279309 = function(anf_arg806310,_plus5) {
var $z313314 = D;
var $f319320 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("fun-missing-colon: "),anf_arg806310):R.ffi.throwNonFunApp(L[9],_plus5,[("fun-missing-colon: "),anf_arg806310]);
};
try {
if(--R.GAS > 0) {
$z313314 = $f319320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f319320,
"from":L[9]});
}
} catch($e311312) {
if(R.isCont($e311312)) {
var $ss315316 = {"from":L[9],
"go":function(ann_DASH_check_DASH_temp803321) {
return $Hann_DASH_check_DASH_temp1278322(ann_DASH_check_DASH_temp803321);
}};
$e311312.stack[R.EXN_STACKHEIGHT++] = $ss315316;
}
if(R.isPyretException($e311312)) {
$e311312.pyretStack.push(L[9]);
}
throw $e311312;
}
var $ret317318 = $Hann_DASH_check_DASH_temp1278322($z313314);
++R.GAS;
return $ret317318;
};
var $Hann_DASH_check_DASH_temp1278322 = function(ann_DASH_check_DASH_temp803321) {
return ann_DASH_check_DASH_temp803321;
};
var $Hanf_arg1277323 = function(anf_arg799324,_plus5) {
var $z327328 = D;
var $f333334 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg799324,(")")):R.ffi.throwNonFunApp(L[10],_plus5,[anf_arg799324,(")")]);
};
try {
if(--R.GAS > 0) {
$z327328 = $f333334();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f333334,
"from":L[10]});
}
} catch($e325326) {
if(R.isCont($e325326)) {
var $ss329330 = {"from":L[10],
"go":function(anf_arg800335) {
return $Hanf_arg1276336(anf_arg800335,_plus5);
}};
$e325326.stack[R.EXN_STACKHEIGHT++] = $ss329330;
}
if(R.isPyretException($e325326)) {
$e325326.pyretStack.push(L[10]);
}
throw $e325326;
}
var $ret331332 = $Hanf_arg1276336($z327328,_plus5);
++R.GAS;
return $ret331332;
};
var $Hanf_arg1276336 = function(anf_arg800335,_plus5) {
var $z339340 = D;
var $f345346 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg800335):R.ffi.throwNonFunApp(L[10],_plus5,[("("),anf_arg800335]);
};
try {
if(--R.GAS > 0) {
$z339340 = $f345346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f345346,
"from":L[10]});
}
} catch($e337338) {
if(R.isCont($e337338)) {
var $ss341342 = {"from":L[10],
"go":function(anf_arg801347) {
return $Hanf_arg1275348(anf_arg801347,_plus5);
}};
$e337338.stack[R.EXN_STACKHEIGHT++] = $ss341342;
}
if(R.isPyretException($e337338)) {
$e337338.pyretStack.push(L[10]);
}
throw $e337338;
}
var $ret343344 = $Hanf_arg1275348($z339340,_plus5);
++R.GAS;
return $ret343344;
};
var $Hanf_arg1275348 = function(anf_arg801347,_plus5) {
var $z351352 = D;
var $f357358 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("fun-missing-colon"),anf_arg801347):R.ffi.throwNonFunApp(L[10],_plus5,[("fun-missing-colon"),anf_arg801347]);
};
try {
if(--R.GAS > 0) {
$z351352 = $f357358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f357358,
"from":L[10]});
}
} catch($e349350) {
if(R.isCont($e349350)) {
var $ss353354 = {"from":L[10],
"go":function(ann_DASH_check_DASH_temp797359) {
return $Hann_DASH_check_DASH_temp1274360(ann_DASH_check_DASH_temp797359);
}};
$e349350.stack[R.EXN_STACKHEIGHT++] = $ss353354;
}
if(R.isPyretException($e349350)) {
$e349350.pyretStack.push(L[10]);
}
throw $e349350;
}
var $ret355356 = $Hann_DASH_check_DASH_temp1274360($z351352);
++R.GAS;
return $ret355356;
};
var $Hann_DASH_check_DASH_temp1274360 = function(ann_DASH_check_DASH_temp797359) {
return ann_DASH_check_DASH_temp797359;
};
var $Hcont_tail_arg1272361 = function(cont_tail_arg794362,if_helper786363) {
if(--R.GAS > 0) {
$z364365 = R.isFunction(if_helper786363)?if_helper786363.app(cont_tail_arg794362):R.ffi.throwNonFunApp(L[10],if_helper786363,[cont_tail_arg794362]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper786363)?if_helper786363.app(cont_tail_arg794362):R.ffi.throwNonFunApp(L[10],if_helper786363,[cont_tail_arg794362]);
},
"from":L[10]});
}
++R.GAS;
return $z364365;
};
var $Hcont_tail_arg1273366 = function(cont_tail_arg791367,if_helper786363) {
if(--R.GAS > 0) {
$z368369 = R.isFunction(if_helper786363)?if_helper786363.app(cont_tail_arg791367):R.ffi.throwNonFunApp(L[10],if_helper786363,[cont_tail_arg791367]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper786363)?if_helper786363.app(cont_tail_arg791367):R.ffi.throwNonFunApp(L[10],if_helper786363,[cont_tail_arg791367]);
},
"from":L[10]});
}
++R.GAS;
return $z368369;
};
var $Hanf_arg1271370 = function(anf_arg783371,_plus5) {
var $z374375 = D;
var $f380381 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Expected a val binding or an expression, but got something else "),anf_arg783371):R.ffi.throwNonFunApp(L[11],_plus5,[("Expected a val binding or an expression, but got something else "),anf_arg783371]);
};
try {
if(--R.GAS > 0) {
$z374375 = $f380381();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f380381,
"from":L[11]});
}
} catch($e372373) {
if(R.isCont($e372373)) {
var $ss376377 = {"from":L[11],
"go":function(ann_DASH_check_DASH_temp780382) {
return $Hann_DASH_check_DASH_temp1270383(ann_DASH_check_DASH_temp780382);
}};
$e372373.stack[R.EXN_STACKHEIGHT++] = $ss376377;
}
if(R.isPyretException($e372373)) {
$e372373.pyretStack.push(L[11]);
}
throw $e372373;
}
var $ret378379 = $Hann_DASH_check_DASH_temp1270383($z374375);
++R.GAS;
return $ret378379;
};
var $Hann_DASH_check_DASH_temp1270383 = function(ann_DASH_check_DASH_temp780382) {
return ann_DASH_check_DASH_temp780382;
};
var $Hanf_arg1269384 = function(anf_arg776385,_plus5) {
var $z388389 = D;
var $f394395 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg776385,(")")):R.ffi.throwNonFunApp(L[12],_plus5,[anf_arg776385,(")")]);
};
try {
if(--R.GAS > 0) {
$z388389 = $f394395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f394395,
"from":L[12]});
}
} catch($e386387) {
if(R.isCont($e386387)) {
var $ss390391 = {"from":L[12],
"go":function(anf_arg777396) {
return $Hanf_arg1268397(anf_arg777396,_plus5);
}};
$e386387.stack[R.EXN_STACKHEIGHT++] = $ss390391;
}
if(R.isPyretException($e386387)) {
$e386387.pyretStack.push(L[12]);
}
throw $e386387;
}
var $ret392393 = $Hanf_arg1268397($z388389,_plus5);
++R.GAS;
return $ret392393;
};
var $Hanf_arg1268397 = function(anf_arg777396,_plus5) {
var $z400401 = D;
var $f406407 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg777396):R.ffi.throwNonFunApp(L[12],_plus5,[("("),anf_arg777396]);
};
try {
if(--R.GAS > 0) {
$z400401 = $f406407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f406407,
"from":L[12]});
}
} catch($e398399) {
if(R.isCont($e398399)) {
var $ss402403 = {"from":L[12],
"go":function(anf_arg778408) {
return $Hanf_arg1267409(anf_arg778408,_plus5);
}};
$e398399.stack[R.EXN_STACKHEIGHT++] = $ss402403;
}
if(R.isPyretException($e398399)) {
$e398399.pyretStack.push(L[12]);
}
throw $e398399;
}
var $ret404405 = $Hanf_arg1267409($z400401,_plus5);
++R.GAS;
return $ret404405;
};
var $Hanf_arg1267409 = function(anf_arg778408,_plus5) {
var $z412413 = D;
var $f418419 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("bad-check-block-stmt"),anf_arg778408):R.ffi.throwNonFunApp(L[12],_plus5,[("bad-check-block-stmt"),anf_arg778408]);
};
try {
if(--R.GAS > 0) {
$z412413 = $f418419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f418419,
"from":L[12]});
}
} catch($e410411) {
if(R.isCont($e410411)) {
var $ss414415 = {"from":L[12],
"go":function(ann_DASH_check_DASH_temp774420) {
return $Hann_DASH_check_DASH_temp1266421(ann_DASH_check_DASH_temp774420);
}};
$e410411.stack[R.EXN_STACKHEIGHT++] = $ss414415;
}
if(R.isPyretException($e410411)) {
$e410411.pyretStack.push(L[12]);
}
throw $e410411;
}
var $ret416417 = $Hann_DASH_check_DASH_temp1266421($z412413);
++R.GAS;
return $ret416417;
};
var $Hann_DASH_check_DASH_temp1266421 = function(ann_DASH_check_DASH_temp774420) {
return ann_DASH_check_DASH_temp774420;
};
var $Hcont_tail_arg1264422 = function(cont_tail_arg771423,if_helper763424) {
if(--R.GAS > 0) {
$z425426 = R.isFunction(if_helper763424)?if_helper763424.app(cont_tail_arg771423):R.ffi.throwNonFunApp(L[12],if_helper763424,[cont_tail_arg771423]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper763424)?if_helper763424.app(cont_tail_arg771423):R.ffi.throwNonFunApp(L[12],if_helper763424,[cont_tail_arg771423]);
},
"from":L[12]});
}
++R.GAS;
return $z425426;
};
var $Hcont_tail_arg1265427 = function(cont_tail_arg768428,if_helper763424) {
if(--R.GAS > 0) {
$z429430 = R.isFunction(if_helper763424)?if_helper763424.app(cont_tail_arg768428):R.ffi.throwNonFunApp(L[12],if_helper763424,[cont_tail_arg768428]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper763424)?if_helper763424.app(cont_tail_arg768428):R.ffi.throwNonFunApp(L[12],if_helper763424,[cont_tail_arg768428]);
},
"from":L[12]});
}
++R.GAS;
return $z429430;
};
var $Hanf_arg1263431 = function(anf_arg760432,_plus5) {
var $z435436 = D;
var $f441442 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Expected a val binding or an expression, but got something else "),anf_arg760432):R.ffi.throwNonFunApp(L[13],_plus5,[("Expected a val binding or an expression, but got something else "),anf_arg760432]);
};
try {
if(--R.GAS > 0) {
$z435436 = $f441442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f441442,
"from":L[13]});
}
} catch($e433434) {
if(R.isCont($e433434)) {
var $ss437438 = {"from":L[13],
"go":function(ann_DASH_check_DASH_temp757443) {
return $Hann_DASH_check_DASH_temp1262444(ann_DASH_check_DASH_temp757443);
}};
$e433434.stack[R.EXN_STACKHEIGHT++] = $ss437438;
}
if(R.isPyretException($e433434)) {
$e433434.pyretStack.push(L[13]);
}
throw $e433434;
}
var $ret439440 = $Hann_DASH_check_DASH_temp1262444($z435436);
++R.GAS;
return $ret439440;
};
var $Hann_DASH_check_DASH_temp1262444 = function(ann_DASH_check_DASH_temp757443) {
return ann_DASH_check_DASH_temp757443;
};
var $Hanf_arg1261445 = function(anf_arg753446,_plus5) {
var $z449450 = D;
var $f455456 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg753446,(")")):R.ffi.throwNonFunApp(L[14],_plus5,[anf_arg753446,(")")]);
};
try {
if(--R.GAS > 0) {
$z449450 = $f455456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f455456,
"from":L[14]});
}
} catch($e447448) {
if(R.isCont($e447448)) {
var $ss451452 = {"from":L[14],
"go":function(anf_arg754457) {
return $Hanf_arg1260458(anf_arg754457,_plus5);
}};
$e447448.stack[R.EXN_STACKHEIGHT++] = $ss451452;
}
if(R.isPyretException($e447448)) {
$e447448.pyretStack.push(L[14]);
}
throw $e447448;
}
var $ret453454 = $Hanf_arg1260458($z449450,_plus5);
++R.GAS;
return $ret453454;
};
var $Hanf_arg1260458 = function(anf_arg754457,_plus5) {
var $z461462 = D;
var $f467468 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg754457):R.ffi.throwNonFunApp(L[14],_plus5,[("("),anf_arg754457]);
};
try {
if(--R.GAS > 0) {
$z461462 = $f467468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f467468,
"from":L[14]});
}
} catch($e459460) {
if(R.isCont($e459460)) {
var $ss463464 = {"from":L[14],
"go":function(anf_arg755469) {
return $Hanf_arg1259470(anf_arg755469,_plus5);
}};
$e459460.stack[R.EXN_STACKHEIGHT++] = $ss463464;
}
if(R.isPyretException($e459460)) {
$e459460.pyretStack.push(L[14]);
}
throw $e459460;
}
var $ret465466 = $Hanf_arg1259470($z461462,_plus5);
++R.GAS;
return $ret465466;
};
var $Hanf_arg1259470 = function(anf_arg755469,_plus5) {
var $z473474 = D;
var $f479480 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("bad-block-stmt"),anf_arg755469):R.ffi.throwNonFunApp(L[14],_plus5,[("bad-block-stmt"),anf_arg755469]);
};
try {
if(--R.GAS > 0) {
$z473474 = $f479480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f479480,
"from":L[14]});
}
} catch($e471472) {
if(R.isCont($e471472)) {
var $ss475476 = {"from":L[14],
"go":function(ann_DASH_check_DASH_temp751481) {
return $Hann_DASH_check_DASH_temp1258482(ann_DASH_check_DASH_temp751481);
}};
$e471472.stack[R.EXN_STACKHEIGHT++] = $ss475476;
}
if(R.isPyretException($e471472)) {
$e471472.pyretStack.push(L[14]);
}
throw $e471472;
}
var $ret477478 = $Hann_DASH_check_DASH_temp1258482($z473474);
++R.GAS;
return $ret477478;
};
var $Hann_DASH_check_DASH_temp1258482 = function(ann_DASH_check_DASH_temp751481) {
return ann_DASH_check_DASH_temp751481;
};
var $Hcont_tail_arg1256483 = function(cont_tail_arg748484,if_helper740485) {
if(--R.GAS > 0) {
$z486487 = R.isFunction(if_helper740485)?if_helper740485.app(cont_tail_arg748484):R.ffi.throwNonFunApp(L[14],if_helper740485,[cont_tail_arg748484]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper740485)?if_helper740485.app(cont_tail_arg748484):R.ffi.throwNonFunApp(L[14],if_helper740485,[cont_tail_arg748484]);
},
"from":L[14]});
}
++R.GAS;
return $z486487;
};
var $Hcont_tail_arg1257488 = function(cont_tail_arg745489,if_helper740485) {
if(--R.GAS > 0) {
$z490491 = R.isFunction(if_helper740485)?if_helper740485.app(cont_tail_arg745489):R.ffi.throwNonFunApp(L[14],if_helper740485,[cont_tail_arg745489]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper740485)?if_helper740485.app(cont_tail_arg745489):R.ffi.throwNonFunApp(L[14],if_helper740485,[cont_tail_arg745489]);
},
"from":L[14]});
}
++R.GAS;
return $z490491;
};
var $Hanf_arg1255492 = function(anf_arg737493,_plus5) {
var $z496497 = D;
var $f502503 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Empty block at "),anf_arg737493):R.ffi.throwNonFunApp(L[15],_plus5,[("Empty block at "),anf_arg737493]);
};
try {
if(--R.GAS > 0) {
$z496497 = $f502503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f502503,
"from":L[15]});
}
} catch($e494495) {
if(R.isCont($e494495)) {
var $ss498499 = {"from":L[15],
"go":function(ann_DASH_check_DASH_temp734504) {
return $Hann_DASH_check_DASH_temp1254505(ann_DASH_check_DASH_temp734504);
}};
$e494495.stack[R.EXN_STACKHEIGHT++] = $ss498499;
}
if(R.isPyretException($e494495)) {
$e494495.pyretStack.push(L[15]);
}
throw $e494495;
}
var $ret500501 = $Hann_DASH_check_DASH_temp1254505($z496497);
++R.GAS;
return $ret500501;
};
var $Hann_DASH_check_DASH_temp1254505 = function(ann_DASH_check_DASH_temp734504) {
return ann_DASH_check_DASH_temp734504;
};
var $Hanf_arg1253506 = function(anf_arg730507,_plus5) {
var $z510511 = D;
var $f516517 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg730507,(")")):R.ffi.throwNonFunApp(L[16],_plus5,[anf_arg730507,(")")]);
};
try {
if(--R.GAS > 0) {
$z510511 = $f516517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f516517,
"from":L[16]});
}
} catch($e508509) {
if(R.isCont($e508509)) {
var $ss512513 = {"from":L[16],
"go":function(anf_arg731518) {
return $Hanf_arg1252519(anf_arg731518,_plus5);
}};
$e508509.stack[R.EXN_STACKHEIGHT++] = $ss512513;
}
if(R.isPyretException($e508509)) {
$e508509.pyretStack.push(L[16]);
}
throw $e508509;
}
var $ret514515 = $Hanf_arg1252519($z510511,_plus5);
++R.GAS;
return $ret514515;
};
var $Hanf_arg1252519 = function(anf_arg731518,_plus5) {
var $z522523 = D;
var $f528529 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg731518):R.ffi.throwNonFunApp(L[16],_plus5,[("("),anf_arg731518]);
};
try {
if(--R.GAS > 0) {
$z522523 = $f528529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f528529,
"from":L[16]});
}
} catch($e520521) {
if(R.isCont($e520521)) {
var $ss524525 = {"from":L[16],
"go":function(anf_arg732530) {
return $Hanf_arg1251531(anf_arg732530,_plus5);
}};
$e520521.stack[R.EXN_STACKHEIGHT++] = $ss524525;
}
if(R.isPyretException($e520521)) {
$e520521.pyretStack.push(L[16]);
}
throw $e520521;
}
var $ret526527 = $Hanf_arg1251531($z522523,_plus5);
++R.GAS;
return $ret526527;
};
var $Hanf_arg1251531 = function(anf_arg732530,_plus5) {
var $z534535 = D;
var $f540541 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("empty-block"),anf_arg732530):R.ffi.throwNonFunApp(L[16],_plus5,[("empty-block"),anf_arg732530]);
};
try {
if(--R.GAS > 0) {
$z534535 = $f540541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f540541,
"from":L[16]});
}
} catch($e532533) {
if(R.isCont($e532533)) {
var $ss536537 = {"from":L[16],
"go":function(ann_DASH_check_DASH_temp728542) {
return $Hann_DASH_check_DASH_temp1250543(ann_DASH_check_DASH_temp728542);
}};
$e532533.stack[R.EXN_STACKHEIGHT++] = $ss536537;
}
if(R.isPyretException($e532533)) {
$e532533.pyretStack.push(L[16]);
}
throw $e532533;
}
var $ret538539 = $Hann_DASH_check_DASH_temp1250543($z534535);
++R.GAS;
return $ret538539;
};
var $Hann_DASH_check_DASH_temp1250543 = function(ann_DASH_check_DASH_temp728542) {
return ann_DASH_check_DASH_temp728542;
};
var $Hcont_tail_arg1248544 = function(cont_tail_arg725545,if_helper717546) {
if(--R.GAS > 0) {
$z547548 = R.isFunction(if_helper717546)?if_helper717546.app(cont_tail_arg725545):R.ffi.throwNonFunApp(L[16],if_helper717546,[cont_tail_arg725545]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper717546)?if_helper717546.app(cont_tail_arg725545):R.ffi.throwNonFunApp(L[16],if_helper717546,[cont_tail_arg725545]);
},
"from":L[16]});
}
++R.GAS;
return $z547548;
};
var $Hcont_tail_arg1249549 = function(cont_tail_arg722550,if_helper717546) {
if(--R.GAS > 0) {
$z551552 = R.isFunction(if_helper717546)?if_helper717546.app(cont_tail_arg722550):R.ffi.throwNonFunApp(L[16],if_helper717546,[cont_tail_arg722550]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper717546)?if_helper717546.app(cont_tail_arg722550):R.ffi.throwNonFunApp(L[16],if_helper717546,[cont_tail_arg722550]);
},
"from":L[16]});
}
++R.GAS;
return $z551552;
};
var $Hanf_arg1247553 = function(anf_arg714554,_plus5) {
var $z557558 = D;
var $f563564 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("parse error at end of file at "),anf_arg714554):R.ffi.throwNonFunApp(L[17],_plus5,[("parse error at end of file at "),anf_arg714554]);
};
try {
if(--R.GAS > 0) {
$z557558 = $f563564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f563564,
"from":L[17]});
}
} catch($e555556) {
if(R.isCont($e555556)) {
var $ss559560 = {"from":L[17],
"go":function(ann_DASH_check_DASH_temp711565) {
return $Hann_DASH_check_DASH_temp1246566(ann_DASH_check_DASH_temp711565);
}};
$e555556.stack[R.EXN_STACKHEIGHT++] = $ss559560;
}
if(R.isPyretException($e555556)) {
$e555556.pyretStack.push(L[17]);
}
throw $e555556;
}
var $ret561562 = $Hann_DASH_check_DASH_temp1246566($z557558);
++R.GAS;
return $ret561562;
};
var $Hann_DASH_check_DASH_temp1246566 = function(ann_DASH_check_DASH_temp711565) {
return ann_DASH_check_DASH_temp711565;
};
var $Hanf_arg1245567 = function(anf_arg707568,_plus5) {
var $z571572 = D;
var $f577578 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg707568,(")")):R.ffi.throwNonFunApp(L[18],_plus5,[anf_arg707568,(")")]);
};
try {
if(--R.GAS > 0) {
$z571572 = $f577578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f577578,
"from":L[18]});
}
} catch($e569570) {
if(R.isCont($e569570)) {
var $ss573574 = {"from":L[18],
"go":function(anf_arg708579) {
return $Hanf_arg1244580(anf_arg708579,_plus5);
}};
$e569570.stack[R.EXN_STACKHEIGHT++] = $ss573574;
}
if(R.isPyretException($e569570)) {
$e569570.pyretStack.push(L[18]);
}
throw $e569570;
}
var $ret575576 = $Hanf_arg1244580($z571572,_plus5);
++R.GAS;
return $ret575576;
};
var $Hanf_arg1244580 = function(anf_arg708579,_plus5) {
var $z583584 = D;
var $f589590 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg708579):R.ffi.throwNonFunApp(L[18],_plus5,[("("),anf_arg708579]);
};
try {
if(--R.GAS > 0) {
$z583584 = $f589590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f589590,
"from":L[18]});
}
} catch($e581582) {
if(R.isCont($e581582)) {
var $ss585586 = {"from":L[18],
"go":function(anf_arg709591) {
return $Hanf_arg1243592(anf_arg709591,_plus5);
}};
$e581582.stack[R.EXN_STACKHEIGHT++] = $ss585586;
}
if(R.isPyretException($e581582)) {
$e581582.pyretStack.push(L[18]);
}
throw $e581582;
}
var $ret587588 = $Hanf_arg1243592($z583584,_plus5);
++R.GAS;
return $ret587588;
};
var $Hanf_arg1243592 = function(anf_arg709591,_plus5) {
var $z595596 = D;
var $f601602 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("parse-error-eof"),anf_arg709591):R.ffi.throwNonFunApp(L[18],_plus5,[("parse-error-eof"),anf_arg709591]);
};
try {
if(--R.GAS > 0) {
$z595596 = $f601602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f601602,
"from":L[18]});
}
} catch($e593594) {
if(R.isCont($e593594)) {
var $ss597598 = {"from":L[18],
"go":function(ann_DASH_check_DASH_temp705603) {
return $Hann_DASH_check_DASH_temp1242604(ann_DASH_check_DASH_temp705603);
}};
$e593594.stack[R.EXN_STACKHEIGHT++] = $ss597598;
}
if(R.isPyretException($e593594)) {
$e593594.pyretStack.push(L[18]);
}
throw $e593594;
}
var $ret599600 = $Hann_DASH_check_DASH_temp1242604($z595596);
++R.GAS;
return $ret599600;
};
var $Hann_DASH_check_DASH_temp1242604 = function(ann_DASH_check_DASH_temp705603) {
return ann_DASH_check_DASH_temp705603;
};
var $Hcont_tail_arg1240605 = function(cont_tail_arg702606,if_helper694607) {
if(--R.GAS > 0) {
$z608609 = R.isFunction(if_helper694607)?if_helper694607.app(cont_tail_arg702606):R.ffi.throwNonFunApp(L[18],if_helper694607,[cont_tail_arg702606]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper694607)?if_helper694607.app(cont_tail_arg702606):R.ffi.throwNonFunApp(L[18],if_helper694607,[cont_tail_arg702606]);
},
"from":L[18]});
}
++R.GAS;
return $z608609;
};
var $Hcont_tail_arg1241610 = function(cont_tail_arg699611,if_helper694607) {
if(--R.GAS > 0) {
$z612613 = R.isFunction(if_helper694607)?if_helper694607.app(cont_tail_arg699611):R.ffi.throwNonFunApp(L[18],if_helper694607,[cont_tail_arg699611]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper694607)?if_helper694607.app(cont_tail_arg699611):R.ffi.throwNonFunApp(L[18],if_helper694607,[cont_tail_arg699611]);
},
"from":L[18]});
}
++R.GAS;
return $z612613;
};
var $Hanf_arg1239614 = function(anf_arg688615,self134616,_plus5) {
var $z619620 = D;
var $f625626 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("parse error around "),anf_arg688615):R.ffi.throwNonFunApp(L[19],_plus5,[("parse error around "),anf_arg688615]);
};
try {
if(--R.GAS > 0) {
$z619620 = $f625626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f625626,
"from":L[19]});
}
} catch($e617618) {
if(R.isCont($e617618)) {
var $ss621622 = {"from":L[19],
"go":function(anf_arg689627) {
return $Hanf_arg1238628(anf_arg689627,self134616,_plus5);
}};
$e617618.stack[R.EXN_STACKHEIGHT++] = $ss621622;
}
if(R.isPyretException($e617618)) {
$e617618.pyretStack.push(L[19]);
}
throw $e617618;
}
var $ret623624 = $Hanf_arg1238628($z619620,self134616,_plus5);
++R.GAS;
return $ret623624;
};
var $Hanf_arg1238628 = function(anf_arg689627,self134616,_plus5) {
var $z631632 = D;
var $f637638 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg689627,(", next token was ")):R.ffi.throwNonFunApp(L[19],_plus5,[anf_arg689627,(", next token was ")]);
};
try {
if(--R.GAS > 0) {
$z631632 = $f637638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f637638,
"from":L[19]});
}
} catch($e629630) {
if(R.isCont($e629630)) {
var $ss633634 = {"from":L[19],
"go":function(anf_arg690639) {
return $Hanf_arg1237640(anf_arg690639,self134616,_plus5);
}};
$e629630.stack[R.EXN_STACKHEIGHT++] = $ss633634;
}
if(R.isPyretException($e629630)) {
$e629630.pyretStack.push(L[19]);
}
throw $e629630;
}
var $ret635636 = $Hanf_arg1237640($z631632,self134616,_plus5);
++R.GAS;
return $ret635636;
};
var $Hanf_arg1237640 = function(anf_arg690639,self134616,_plus5) {
var anf_arg691651 = G(self134616,"next-token",L[21]);
var $z643644 = D;
var $f649650 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg690639,anf_arg691651):R.ffi.throwNonFunApp(L[20],_plus5,[anf_arg690639,anf_arg691651]);
};
try {
if(--R.GAS > 0) {
$z643644 = $f649650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f649650,
"from":L[20]});
}
} catch($e641642) {
if(R.isCont($e641642)) {
var $ss645646 = {"from":L[20],
"go":function(ann_DASH_check_DASH_temp685652) {
return $Hann_DASH_check_DASH_temp1236653(ann_DASH_check_DASH_temp685652);
}};
$e641642.stack[R.EXN_STACKHEIGHT++] = $ss645646;
}
if(R.isPyretException($e641642)) {
$e641642.pyretStack.push(L[20]);
}
throw $e641642;
}
var $ret647648 = $Hann_DASH_check_DASH_temp1236653($z643644);
++R.GAS;
return $ret647648;
};
var $Hann_DASH_check_DASH_temp1236653 = function(ann_DASH_check_DASH_temp685652) {
return ann_DASH_check_DASH_temp685652;
};
var $Hanf_arg1235654 = function(anf_arg677655,self113656,_plus5,torepr8) {
var anf_arg678667 = G(self113656,"next-token",L[22]);
var $z659660 = D;
var $f665666 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg678667):R.ffi.throwNonFunApp(L[22],torepr8,[anf_arg678667]);
};
try {
if(--R.GAS > 0) {
$z659660 = $f665666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f665666,
"from":L[22]});
}
} catch($e657658) {
if(R.isCont($e657658)) {
var $ss661662 = {"from":L[22],
"go":function(anf_arg679668) {
return $Hanf_arg1234669(anf_arg679668,anf_arg677655,_plus5);
}};
$e657658.stack[R.EXN_STACKHEIGHT++] = $ss661662;
}
if(R.isPyretException($e657658)) {
$e657658.pyretStack.push(L[22]);
}
throw $e657658;
}
var $ret663664 = $Hanf_arg1234669($z659660,anf_arg677655,_plus5);
++R.GAS;
return $ret663664;
};
var $Hanf_arg1234669 = function(anf_arg679668,anf_arg677655,_plus5) {
var $z672673 = D;
var $f678679 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg679668):R.ffi.throwNonFunApp(L[22],_plus5,[(", "),anf_arg679668]);
};
try {
if(--R.GAS > 0) {
$z672673 = $f678679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f678679,
"from":L[22]});
}
} catch($e670671) {
if(R.isCont($e670671)) {
var $ss674675 = {"from":L[22],
"go":function(anf_arg680680) {
return $Hanf_arg1233681(anf_arg680680,anf_arg677655,_plus5);
}};
$e670671.stack[R.EXN_STACKHEIGHT++] = $ss674675;
}
if(R.isPyretException($e670671)) {
$e670671.pyretStack.push(L[22]);
}
throw $e670671;
}
var $ret676677 = $Hanf_arg1233681($z672673,anf_arg677655,_plus5);
++R.GAS;
return $ret676677;
};
var $Hanf_arg1233681 = function(anf_arg680680,anf_arg677655,_plus5) {
var $z684685 = D;
var $f690691 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg677655,anf_arg680680):R.ffi.throwNonFunApp(L[22],_plus5,[anf_arg677655,anf_arg680680]);
};
try {
if(--R.GAS > 0) {
$z684685 = $f690691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f690691,
"from":L[22]});
}
} catch($e682683) {
if(R.isCont($e682683)) {
var $ss686687 = {"from":L[22],
"go":function(anf_arg681692) {
return $Hanf_arg1232693(anf_arg681692,_plus5);
}};
$e682683.stack[R.EXN_STACKHEIGHT++] = $ss686687;
}
if(R.isPyretException($e682683)) {
$e682683.pyretStack.push(L[22]);
}
throw $e682683;
}
var $ret688689 = $Hanf_arg1232693($z684685,_plus5);
++R.GAS;
return $ret688689;
};
var $Hanf_arg1232693 = function(anf_arg681692,_plus5) {
var $z696697 = D;
var $f702703 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg681692,(")")):R.ffi.throwNonFunApp(L[22],_plus5,[anf_arg681692,(")")]);
};
try {
if(--R.GAS > 0) {
$z696697 = $f702703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f702703,
"from":L[22]});
}
} catch($e694695) {
if(R.isCont($e694695)) {
var $ss698699 = {"from":L[22],
"go":function(anf_arg682704) {
return $Hanf_arg1231705(anf_arg682704,_plus5);
}};
$e694695.stack[R.EXN_STACKHEIGHT++] = $ss698699;
}
if(R.isPyretException($e694695)) {
$e694695.pyretStack.push(L[22]);
}
throw $e694695;
}
var $ret700701 = $Hanf_arg1231705($z696697,_plus5);
++R.GAS;
return $ret700701;
};
var $Hanf_arg1231705 = function(anf_arg682704,_plus5) {
var $z708709 = D;
var $f714715 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg682704):R.ffi.throwNonFunApp(L[22],_plus5,[("("),anf_arg682704]);
};
try {
if(--R.GAS > 0) {
$z708709 = $f714715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f714715,
"from":L[22]});
}
} catch($e706707) {
if(R.isCont($e706707)) {
var $ss710711 = {"from":L[22],
"go":function(anf_arg683716) {
return $Hanf_arg1230717(anf_arg683716,_plus5);
}};
$e706707.stack[R.EXN_STACKHEIGHT++] = $ss710711;
}
if(R.isPyretException($e706707)) {
$e706707.pyretStack.push(L[22]);
}
throw $e706707;
}
var $ret712713 = $Hanf_arg1230717($z708709,_plus5);
++R.GAS;
return $ret712713;
};
var $Hanf_arg1230717 = function(anf_arg683716,_plus5) {
var $z720721 = D;
var $f726727 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("parse-error-next-token"),anf_arg683716):R.ffi.throwNonFunApp(L[22],_plus5,[("parse-error-next-token"),anf_arg683716]);
};
try {
if(--R.GAS > 0) {
$z720721 = $f726727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f726727,
"from":L[22]});
}
} catch($e718719) {
if(R.isCont($e718719)) {
var $ss722723 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp675728) {
return $Hann_DASH_check_DASH_temp1229729(ann_DASH_check_DASH_temp675728);
}};
$e718719.stack[R.EXN_STACKHEIGHT++] = $ss722723;
}
if(R.isPyretException($e718719)) {
$e718719.pyretStack.push(L[22]);
}
throw $e718719;
}
var $ret724725 = $Hann_DASH_check_DASH_temp1229729($z720721);
++R.GAS;
return $ret724725;
};
var $Hann_DASH_check_DASH_temp1229729 = function(ann_DASH_check_DASH_temp675728) {
return ann_DASH_check_DASH_temp675728;
};
var $Hcont_tail_arg1227730 = function(cont_tail_arg672731,if_helper663732) {
if(--R.GAS > 0) {
$z733734 = R.isFunction(if_helper663732)?if_helper663732.app(cont_tail_arg672731):R.ffi.throwNonFunApp(L[22],if_helper663732,[cont_tail_arg672731]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper663732)?if_helper663732.app(cont_tail_arg672731):R.ffi.throwNonFunApp(L[22],if_helper663732,[cont_tail_arg672731]);
},
"from":L[22]});
}
++R.GAS;
return $z733734;
};
var $Hcont_tail_arg1228735 = function(cont_tail_arg668736,if_helper663732) {
if(--R.GAS > 0) {
$z737738 = R.isFunction(if_helper663732)?if_helper663732.app(cont_tail_arg668736):R.ffi.throwNonFunApp(L[22],if_helper663732,[cont_tail_arg668736]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper663732)?if_helper663732.app(cont_tail_arg668736):R.ffi.throwNonFunApp(L[22],if_helper663732,[cont_tail_arg668736]);
},
"from":L[22]});
}
++R.GAS;
return $z737738;
};
var $Hcont_tail_arg1225739 = function(cont_tail_arg618740,if_helper611741) {
if(--R.GAS > 0) {
$z742743 = R.isFunction(if_helper611741)?if_helper611741.app(cont_tail_arg618740):R.ffi.throwNonFunApp(L[23],if_helper611741,[cont_tail_arg618740]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper611741)?if_helper611741.app(cont_tail_arg618740):R.ffi.throwNonFunApp(L[23],if_helper611741,[cont_tail_arg618740]);
},
"from":L[23]});
}
++R.GAS;
return $z742743;
};
var $Hcont_tail_arg1226744 = function(cont_tail_arg616745,if_helper611741) {
if(--R.GAS > 0) {
$z746747 = R.isFunction(if_helper611741)?if_helper611741.app(cont_tail_arg616745):R.ffi.throwNonFunApp(L[23],if_helper611741,[cont_tail_arg616745]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper611741)?if_helper611741.app(cont_tail_arg616745):R.ffi.throwNonFunApp(L[23],if_helper611741,[cont_tail_arg616745]);
},
"from":L[23]});
}
++R.GAS;
return $z746747;
};
var $Hanf_arg1224748 = function(anf_arg602749,self131750,_plus5) {
var $z753754 = D;
var $f759760 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: Bad array index "),anf_arg602749):R.ffi.throwNonFunApp(L[24],_plus5,[("Error: Bad array index "),anf_arg602749]);
};
try {
if(--R.GAS > 0) {
$z753754 = $f759760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f759760,
"from":L[24]});
}
} catch($e751752) {
if(R.isCont($e751752)) {
var $ss755756 = {"from":L[24],
"go":function(anf_arg603761) {
return $Hanf_arg1223762(anf_arg603761,self131750,_plus5);
}};
$e751752.stack[R.EXN_STACKHEIGHT++] = $ss755756;
}
if(R.isPyretException($e751752)) {
$e751752.pyretStack.push(L[24]);
}
throw $e751752;
}
var $ret757758 = $Hanf_arg1223762($z753754,self131750,_plus5);
++R.GAS;
return $ret757758;
};
var $Hanf_arg1223762 = function(anf_arg603761,self131750,_plus5) {
var $z765766 = D;
var $f771772 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg603761,(" in ")):R.ffi.throwNonFunApp(L[24],_plus5,[anf_arg603761,(" in ")]);
};
try {
if(--R.GAS > 0) {
$z765766 = $f771772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f771772,
"from":L[24]});
}
} catch($e763764) {
if(R.isCont($e763764)) {
var $ss767768 = {"from":L[24],
"go":function(anf_arg604773) {
return $Hanf_arg1222774(anf_arg604773,self131750,_plus5);
}};
$e763764.stack[R.EXN_STACKHEIGHT++] = $ss767768;
}
if(R.isPyretException($e763764)) {
$e763764.pyretStack.push(L[24]);
}
throw $e763764;
}
var $ret769770 = $Hanf_arg1222774($z765766,self131750,_plus5);
++R.GAS;
return $ret769770;
};
var $Hanf_arg1222774 = function(anf_arg604773,self131750,_plus5) {
var anf_arg605785 = G(self131750,"method-name",L[25]);
var $z777778 = D;
var $f783784 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg604773,anf_arg605785):R.ffi.throwNonFunApp(L[24],_plus5,[anf_arg604773,anf_arg605785]);
};
try {
if(--R.GAS > 0) {
$z777778 = $f783784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f783784,
"from":L[24]});
}
} catch($e775776) {
if(R.isCont($e775776)) {
var $ss779780 = {"from":L[24],
"go":function(anf_arg606786) {
return $Hanf_arg1221787(anf_arg606786,self131750,_plus5);
}};
$e775776.stack[R.EXN_STACKHEIGHT++] = $ss779780;
}
if(R.isPyretException($e775776)) {
$e775776.pyretStack.push(L[24]);
}
throw $e775776;
}
var $ret781782 = $Hanf_arg1221787($z777778,self131750,_plus5);
++R.GAS;
return $ret781782;
};
var $Hanf_arg1221787 = function(anf_arg606786,self131750,_plus5) {
var $z790791 = D;
var $f796797 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg606786,(": ")):R.ffi.throwNonFunApp(L[24],_plus5,[anf_arg606786,(": ")]);
};
try {
if(--R.GAS > 0) {
$z790791 = $f796797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f796797,
"from":L[24]});
}
} catch($e788789) {
if(R.isCont($e788789)) {
var $ss792793 = {"from":L[24],
"go":function(anf_arg607798) {
return $Hanf_arg1220799(anf_arg607798,self131750,_plus5);
}};
$e788789.stack[R.EXN_STACKHEIGHT++] = $ss792793;
}
if(R.isPyretException($e788789)) {
$e788789.pyretStack.push(L[24]);
}
throw $e788789;
}
var $ret794795 = $Hanf_arg1220799($z790791,self131750,_plus5);
++R.GAS;
return $ret794795;
};
var $Hanf_arg1220799 = function(anf_arg607798,self131750,_plus5) {
var anf_arg608810 = G(self131750,"reason",L[27]);
var $z802803 = D;
var $f808809 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg607798,anf_arg608810):R.ffi.throwNonFunApp(L[26],_plus5,[anf_arg607798,anf_arg608810]);
};
try {
if(--R.GAS > 0) {
$z802803 = $f808809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f808809,
"from":L[26]});
}
} catch($e800801) {
if(R.isCont($e800801)) {
var $ss804805 = {"from":L[26],
"go":function(ann_DASH_check_DASH_temp600811) {
return $Hann_DASH_check_DASH_temp1219812(ann_DASH_check_DASH_temp600811);
}};
$e800801.stack[R.EXN_STACKHEIGHT++] = $ss804805;
}
if(R.isPyretException($e800801)) {
$e800801.pyretStack.push(L[26]);
}
throw $e800801;
}
var $ret806807 = $Hann_DASH_check_DASH_temp1219812($z802803);
++R.GAS;
return $ret806807;
};
var $Hann_DASH_check_DASH_temp1219812 = function(ann_DASH_check_DASH_temp600811) {
return ann_DASH_check_DASH_temp600811;
};
var $Hanf_arg1218813 = function(anf_arg584814,self101815,_plus5,torepr8) {
var anf_arg585826 = G(self101815,"array",L[28]);
var $z818819 = D;
var $f824825 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg585826):R.ffi.throwNonFunApp(L[28],torepr8,[anf_arg585826]);
};
try {
if(--R.GAS > 0) {
$z818819 = $f824825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f824825,
"from":L[28]});
}
} catch($e816817) {
if(R.isCont($e816817)) {
var $ss820821 = {"from":L[28],
"go":function(anf_arg586827) {
return $Hanf_arg1217828(anf_arg586827,anf_arg584814,self101815,_plus5,torepr8);
}};
$e816817.stack[R.EXN_STACKHEIGHT++] = $ss820821;
}
if(R.isPyretException($e816817)) {
$e816817.pyretStack.push(L[28]);
}
throw $e816817;
}
var $ret822823 = $Hanf_arg1217828($z818819,anf_arg584814,self101815,_plus5,torepr8);
++R.GAS;
return $ret822823;
};
var $Hanf_arg1217828 = function(anf_arg586827,anf_arg584814,self101815,_plus5,torepr8) {
var $z831832 = D;
var $f837838 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg586827):R.ffi.throwNonFunApp(L[28],_plus5,[(", "),anf_arg586827]);
};
try {
if(--R.GAS > 0) {
$z831832 = $f837838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f837838,
"from":L[28]});
}
} catch($e829830) {
if(R.isCont($e829830)) {
var $ss833834 = {"from":L[28],
"go":function(anf_arg587839) {
return $Hanf_arg1216840(anf_arg587839,anf_arg584814,self101815,_plus5,torepr8);
}};
$e829830.stack[R.EXN_STACKHEIGHT++] = $ss833834;
}
if(R.isPyretException($e829830)) {
$e829830.pyretStack.push(L[28]);
}
throw $e829830;
}
var $ret835836 = $Hanf_arg1216840($z831832,anf_arg584814,self101815,_plus5,torepr8);
++R.GAS;
return $ret835836;
};
var $Hanf_arg1216840 = function(anf_arg587839,anf_arg584814,self101815,_plus5,torepr8) {
var $z843844 = D;
var $f849850 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg584814,anf_arg587839):R.ffi.throwNonFunApp(L[28],_plus5,[anf_arg584814,anf_arg587839]);
};
try {
if(--R.GAS > 0) {
$z843844 = $f849850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f849850,
"from":L[28]});
}
} catch($e841842) {
if(R.isCont($e841842)) {
var $ss845846 = {"from":L[28],
"go":function(anf_arg588851) {
return $Hanf_arg1215852(anf_arg588851,self101815,_plus5,torepr8);
}};
$e841842.stack[R.EXN_STACKHEIGHT++] = $ss845846;
}
if(R.isPyretException($e841842)) {
$e841842.pyretStack.push(L[28]);
}
throw $e841842;
}
var $ret847848 = $Hanf_arg1215852($z843844,self101815,_plus5,torepr8);
++R.GAS;
return $ret847848;
};
var $Hanf_arg1215852 = function(anf_arg588851,self101815,_plus5,torepr8) {
var anf_arg589863 = G(self101815,"index",L[28]);
var $z855856 = D;
var $f861862 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg589863):R.ffi.throwNonFunApp(L[28],torepr8,[anf_arg589863]);
};
try {
if(--R.GAS > 0) {
$z855856 = $f861862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f861862,
"from":L[28]});
}
} catch($e853854) {
if(R.isCont($e853854)) {
var $ss857858 = {"from":L[28],
"go":function(anf_arg590864) {
return $Hanf_arg1214865(anf_arg590864,anf_arg588851,self101815,_plus5,torepr8);
}};
$e853854.stack[R.EXN_STACKHEIGHT++] = $ss857858;
}
if(R.isPyretException($e853854)) {
$e853854.pyretStack.push(L[28]);
}
throw $e853854;
}
var $ret859860 = $Hanf_arg1214865($z855856,anf_arg588851,self101815,_plus5,torepr8);
++R.GAS;
return $ret859860;
};
var $Hanf_arg1214865 = function(anf_arg590864,anf_arg588851,self101815,_plus5,torepr8) {
var $z868869 = D;
var $f874875 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg590864):R.ffi.throwNonFunApp(L[28],_plus5,[(", "),anf_arg590864]);
};
try {
if(--R.GAS > 0) {
$z868869 = $f874875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f874875,
"from":L[28]});
}
} catch($e866867) {
if(R.isCont($e866867)) {
var $ss870871 = {"from":L[28],
"go":function(anf_arg591876) {
return $Hanf_arg1213877(anf_arg591876,anf_arg588851,self101815,_plus5,torepr8);
}};
$e866867.stack[R.EXN_STACKHEIGHT++] = $ss870871;
}
if(R.isPyretException($e866867)) {
$e866867.pyretStack.push(L[28]);
}
throw $e866867;
}
var $ret872873 = $Hanf_arg1213877($z868869,anf_arg588851,self101815,_plus5,torepr8);
++R.GAS;
return $ret872873;
};
var $Hanf_arg1213877 = function(anf_arg591876,anf_arg588851,self101815,_plus5,torepr8) {
var $z880881 = D;
var $f886887 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg588851,anf_arg591876):R.ffi.throwNonFunApp(L[28],_plus5,[anf_arg588851,anf_arg591876]);
};
try {
if(--R.GAS > 0) {
$z880881 = $f886887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f886887,
"from":L[28]});
}
} catch($e878879) {
if(R.isCont($e878879)) {
var $ss882883 = {"from":L[28],
"go":function(anf_arg592888) {
return $Hanf_arg1212889(anf_arg592888,self101815,_plus5,torepr8);
}};
$e878879.stack[R.EXN_STACKHEIGHT++] = $ss882883;
}
if(R.isPyretException($e878879)) {
$e878879.pyretStack.push(L[28]);
}
throw $e878879;
}
var $ret884885 = $Hanf_arg1212889($z880881,self101815,_plus5,torepr8);
++R.GAS;
return $ret884885;
};
var $Hanf_arg1212889 = function(anf_arg592888,self101815,_plus5,torepr8) {
var anf_arg593900 = G(self101815,"reason",L[28]);
var $z892893 = D;
var $f898899 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg593900):R.ffi.throwNonFunApp(L[28],torepr8,[anf_arg593900]);
};
try {
if(--R.GAS > 0) {
$z892893 = $f898899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f898899,
"from":L[28]});
}
} catch($e890891) {
if(R.isCont($e890891)) {
var $ss894895 = {"from":L[28],
"go":function(anf_arg594901) {
return $Hanf_arg1211902(anf_arg594901,anf_arg592888,_plus5);
}};
$e890891.stack[R.EXN_STACKHEIGHT++] = $ss894895;
}
if(R.isPyretException($e890891)) {
$e890891.pyretStack.push(L[28]);
}
throw $e890891;
}
var $ret896897 = $Hanf_arg1211902($z892893,anf_arg592888,_plus5);
++R.GAS;
return $ret896897;
};
var $Hanf_arg1211902 = function(anf_arg594901,anf_arg592888,_plus5) {
var $z905906 = D;
var $f911912 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg594901):R.ffi.throwNonFunApp(L[28],_plus5,[(", "),anf_arg594901]);
};
try {
if(--R.GAS > 0) {
$z905906 = $f911912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f911912,
"from":L[28]});
}
} catch($e903904) {
if(R.isCont($e903904)) {
var $ss907908 = {"from":L[28],
"go":function(anf_arg595913) {
return $Hanf_arg1210914(anf_arg595913,anf_arg592888,_plus5);
}};
$e903904.stack[R.EXN_STACKHEIGHT++] = $ss907908;
}
if(R.isPyretException($e903904)) {
$e903904.pyretStack.push(L[28]);
}
throw $e903904;
}
var $ret909910 = $Hanf_arg1210914($z905906,anf_arg592888,_plus5);
++R.GAS;
return $ret909910;
};
var $Hanf_arg1210914 = function(anf_arg595913,anf_arg592888,_plus5) {
var $z917918 = D;
var $f923924 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg592888,anf_arg595913):R.ffi.throwNonFunApp(L[28],_plus5,[anf_arg592888,anf_arg595913]);
};
try {
if(--R.GAS > 0) {
$z917918 = $f923924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f923924,
"from":L[28]});
}
} catch($e915916) {
if(R.isCont($e915916)) {
var $ss919920 = {"from":L[28],
"go":function(anf_arg596925) {
return $Hanf_arg1209926(anf_arg596925,_plus5);
}};
$e915916.stack[R.EXN_STACKHEIGHT++] = $ss919920;
}
if(R.isPyretException($e915916)) {
$e915916.pyretStack.push(L[28]);
}
throw $e915916;
}
var $ret921922 = $Hanf_arg1209926($z917918,_plus5);
++R.GAS;
return $ret921922;
};
var $Hanf_arg1209926 = function(anf_arg596925,_plus5) {
var $z929930 = D;
var $f935936 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg596925,(")")):R.ffi.throwNonFunApp(L[28],_plus5,[anf_arg596925,(")")]);
};
try {
if(--R.GAS > 0) {
$z929930 = $f935936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f935936,
"from":L[28]});
}
} catch($e927928) {
if(R.isCont($e927928)) {
var $ss931932 = {"from":L[28],
"go":function(anf_arg597937) {
return $Hanf_arg1208938(anf_arg597937,_plus5);
}};
$e927928.stack[R.EXN_STACKHEIGHT++] = $ss931932;
}
if(R.isPyretException($e927928)) {
$e927928.pyretStack.push(L[28]);
}
throw $e927928;
}
var $ret933934 = $Hanf_arg1208938($z929930,_plus5);
++R.GAS;
return $ret933934;
};
var $Hanf_arg1208938 = function(anf_arg597937,_plus5) {
var $z941942 = D;
var $f947948 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg597937):R.ffi.throwNonFunApp(L[28],_plus5,[("("),anf_arg597937]);
};
try {
if(--R.GAS > 0) {
$z941942 = $f947948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f947948,
"from":L[28]});
}
} catch($e939940) {
if(R.isCont($e939940)) {
var $ss943944 = {"from":L[28],
"go":function(anf_arg598949) {
return $Hanf_arg1207950(anf_arg598949,_plus5);
}};
$e939940.stack[R.EXN_STACKHEIGHT++] = $ss943944;
}
if(R.isPyretException($e939940)) {
$e939940.pyretStack.push(L[28]);
}
throw $e939940;
}
var $ret945946 = $Hanf_arg1207950($z941942,_plus5);
++R.GAS;
return $ret945946;
};
var $Hanf_arg1207950 = function(anf_arg598949,_plus5) {
var $z953954 = D;
var $f959960 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("invalid-array-index"),anf_arg598949):R.ffi.throwNonFunApp(L[28],_plus5,[("invalid-array-index"),anf_arg598949]);
};
try {
if(--R.GAS > 0) {
$z953954 = $f959960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f959960,
"from":L[28]});
}
} catch($e951952) {
if(R.isCont($e951952)) {
var $ss955956 = {"from":L[28],
"go":function(ann_DASH_check_DASH_temp582961) {
return $Hann_DASH_check_DASH_temp1206962(ann_DASH_check_DASH_temp582961);
}};
$e951952.stack[R.EXN_STACKHEIGHT++] = $ss955956;
}
if(R.isPyretException($e951952)) {
$e951952.pyretStack.push(L[28]);
}
throw $e951952;
}
var $ret957958 = $Hann_DASH_check_DASH_temp1206962($z953954);
++R.GAS;
return $ret957958;
};
var $Hann_DASH_check_DASH_temp1206962 = function(ann_DASH_check_DASH_temp582961) {
return ann_DASH_check_DASH_temp582961;
};
var $Hcont_tail_arg1204963 = function(cont_tail_arg579964,if_helper568965) {
if(--R.GAS > 0) {
$z966967 = R.isFunction(if_helper568965)?if_helper568965.app(cont_tail_arg579964):R.ffi.throwNonFunApp(L[28],if_helper568965,[cont_tail_arg579964]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper568965)?if_helper568965.app(cont_tail_arg579964):R.ffi.throwNonFunApp(L[28],if_helper568965,[cont_tail_arg579964]);
},
"from":L[28]});
}
++R.GAS;
return $z966967;
};
var $Hcont_tail_arg1205968 = function(cont_tail_arg573969,if_helper568965) {
if(--R.GAS > 0) {
$z970971 = R.isFunction(if_helper568965)?if_helper568965.app(cont_tail_arg573969):R.ffi.throwNonFunApp(L[28],if_helper568965,[cont_tail_arg573969]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper568965)?if_helper568965.app(cont_tail_arg573969):R.ffi.throwNonFunApp(L[28],if_helper568965,[cont_tail_arg573969]);
},
"from":L[28]});
}
++R.GAS;
return $z970971;
};
var $Hanf_arg1203972 = function(anf_arg565973,_plus5) {
var $z976977 = D;
var $f982983 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: The following modules failed to load: "),anf_arg565973):R.ffi.throwNonFunApp(L[29],_plus5,[("Error: The following modules failed to load: "),anf_arg565973]);
};
try {
if(--R.GAS > 0) {
$z976977 = $f982983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f982983,
"from":L[29]});
}
} catch($e974975) {
if(R.isCont($e974975)) {
var $ss978979 = {"from":L[29],
"go":function(ann_DASH_check_DASH_temp563984) {
return $Hann_DASH_check_DASH_temp1202985(ann_DASH_check_DASH_temp563984);
}};
$e974975.stack[R.EXN_STACKHEIGHT++] = $ss978979;
}
if(R.isPyretException($e974975)) {
$e974975.pyretStack.push(L[29]);
}
throw $e974975;
}
var $ret980981 = $Hann_DASH_check_DASH_temp1202985($z976977);
++R.GAS;
return $ret980981;
};
var $Hann_DASH_check_DASH_temp1202985 = function(ann_DASH_check_DASH_temp563984) {
return ann_DASH_check_DASH_temp563984;
};
var $Hanf_arg1201986 = function(anf_arg559987,_plus5) {
var $z990991 = D;
var $f996997 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg559987,(")")):R.ffi.throwNonFunApp(L[30],_plus5,[anf_arg559987,(")")]);
};
try {
if(--R.GAS > 0) {
$z990991 = $f996997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f996997,
"from":L[30]});
}
} catch($e988989) {
if(R.isCont($e988989)) {
var $ss992993 = {"from":L[30],
"go":function(anf_arg560998) {
return $Hanf_arg1200999(anf_arg560998,_plus5);
}};
$e988989.stack[R.EXN_STACKHEIGHT++] = $ss992993;
}
if(R.isPyretException($e988989)) {
$e988989.pyretStack.push(L[30]);
}
throw $e988989;
}
var $ret994995 = $Hanf_arg1200999($z990991,_plus5);
++R.GAS;
return $ret994995;
};
var $Hanf_arg1200999 = function(anf_arg560998,_plus5) {
var $z10021003 = D;
var $f10081009 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg560998):R.ffi.throwNonFunApp(L[30],_plus5,[("("),anf_arg560998]);
};
try {
if(--R.GAS > 0) {
$z10021003 = $f10081009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10081009,
"from":L[30]});
}
} catch($e10001001) {
if(R.isCont($e10001001)) {
var $ss10041005 = {"from":L[30],
"go":function(anf_arg5611010) {
return $Hanf_arg11991011(anf_arg5611010,_plus5);
}};
$e10001001.stack[R.EXN_STACKHEIGHT++] = $ss10041005;
}
if(R.isPyretException($e10001001)) {
$e10001001.pyretStack.push(L[30]);
}
throw $e10001001;
}
var $ret10061007 = $Hanf_arg11991011($z10021003,_plus5);
++R.GAS;
return $ret10061007;
};
var $Hanf_arg11991011 = function(anf_arg5611010,_plus5) {
var $z10141015 = D;
var $f10201021 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("module-load-failure"),anf_arg5611010):R.ffi.throwNonFunApp(L[30],_plus5,[("module-load-failure"),anf_arg5611010]);
};
try {
if(--R.GAS > 0) {
$z10141015 = $f10201021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10201021,
"from":L[30]});
}
} catch($e10121013) {
if(R.isCont($e10121013)) {
var $ss10161017 = {"from":L[30],
"go":function(ann_DASH_check_DASH_temp5571022) {
return $Hann_DASH_check_DASH_temp11981023(ann_DASH_check_DASH_temp5571022);
}};
$e10121013.stack[R.EXN_STACKHEIGHT++] = $ss10161017;
}
if(R.isPyretException($e10121013)) {
$e10121013.pyretStack.push(L[30]);
}
throw $e10121013;
}
var $ret10181019 = $Hann_DASH_check_DASH_temp11981023($z10141015);
++R.GAS;
return $ret10181019;
};
var $Hann_DASH_check_DASH_temp11981023 = function(ann_DASH_check_DASH_temp5571022) {
return ann_DASH_check_DASH_temp5571022;
};
var $Hcont_tail_arg11961024 = function(cont_tail_arg5541025,if_helper5461026) {
if(--R.GAS > 0) {
$z10271028 = R.isFunction(if_helper5461026)?if_helper5461026.app(cont_tail_arg5541025):R.ffi.throwNonFunApp(L[30],if_helper5461026,[cont_tail_arg5541025]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper5461026)?if_helper5461026.app(cont_tail_arg5541025):R.ffi.throwNonFunApp(L[30],if_helper5461026,[cont_tail_arg5541025]);
},
"from":L[30]});
}
++R.GAS;
return $z10271028;
};
var $Hcont_tail_arg11971029 = function(cont_tail_arg5511030,if_helper5461026) {
if(--R.GAS > 0) {
$z10311032 = R.isFunction(if_helper5461026)?if_helper5461026.app(cont_tail_arg5511030):R.ffi.throwNonFunApp(L[30],if_helper5461026,[cont_tail_arg5511030]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper5461026)?if_helper5461026.app(cont_tail_arg5511030):R.ffi.throwNonFunApp(L[30],if_helper5461026,[cont_tail_arg5511030]);
},
"from":L[30]});
}
++R.GAS;
return $z10311032;
};
var $Hanf_arg11951033 = function(anf_arg5381034,self1241035,_plus5) {
var $z10381039 = D;
var $f10441045 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg5381034,(" was used at ")):R.ffi.throwNonFunApp(L[31],_plus5,[anf_arg5381034,(" was used at ")]);
};
try {
if(--R.GAS > 0) {
$z10381039 = $f10441045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10441045,
"from":L[31]});
}
} catch($e10361037) {
if(R.isCont($e10361037)) {
var $ss10401041 = {"from":L[31],
"go":function(anf_arg5391046) {
return $Hanf_arg11941047(anf_arg5391046,self1241035,_plus5);
}};
$e10361037.stack[R.EXN_STACKHEIGHT++] = $ss10401041;
}
if(R.isPyretException($e10361037)) {
$e10361037.pyretStack.push(L[31]);
}
throw $e10361037;
}
var $ret10421043 = $Hanf_arg11941047($z10381039,self1241035,_plus5);
++R.GAS;
return $ret10421043;
};
var $Hanf_arg11941047 = function(anf_arg5391046,self1241035,_plus5) {
var anf_bracket5401061 = G(self1241035,"loc",L[34]);
var anf_fun5411058 = G(anf_bracket5401061,"format",L[33]);
var $z10501051 = D;
var $f10561057 = function(_) {
return R.isFunction(anf_fun5411058)?anf_fun5411058.app((true)):R.ffi.throwNonFunApp(L[32],anf_fun5411058,[(true)]);
};
try {
if(--R.GAS > 0) {
$z10501051 = $f10561057();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10561057,
"from":L[32]});
}
} catch($e10481049) {
if(R.isCont($e10481049)) {
var $ss10521053 = {"from":L[32],
"go":function(anf_arg5421059) {
return $Hanf_arg11931060(anf_arg5421059,anf_arg5391046,_plus5);
}};
$e10481049.stack[R.EXN_STACKHEIGHT++] = $ss10521053;
}
if(R.isPyretException($e10481049)) {
$e10481049.pyretStack.push(L[32]);
}
throw $e10481049;
}
var $ret10541055 = $Hanf_arg11931060($z10501051,anf_arg5391046,_plus5);
++R.GAS;
return $ret10541055;
};
var $Hanf_arg11931060 = function(anf_arg5421059,anf_arg5391046,_plus5) {
var $z10641065 = D;
var $f10701071 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg5391046,anf_arg5421059):R.ffi.throwNonFunApp(L[31],_plus5,[anf_arg5391046,anf_arg5421059]);
};
try {
if(--R.GAS > 0) {
$z10641065 = $f10701071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10701071,
"from":L[31]});
}
} catch($e10621063) {
if(R.isCont($e10621063)) {
var $ss10661067 = {"from":L[31],
"go":function(anf_arg5431072) {
return $Hanf_arg11921073(anf_arg5431072,_plus5);
}};
$e10621063.stack[R.EXN_STACKHEIGHT++] = $ss10661067;
}
if(R.isPyretException($e10621063)) {
$e10621063.pyretStack.push(L[31]);
}
throw $e10621063;
}
var $ret10681069 = $Hanf_arg11921073($z10641065,_plus5);
++R.GAS;
return $ret10681069;
};
var $Hanf_arg11921073 = function(anf_arg5431072,_plus5) {
var $z10761077 = D;
var $f10821083 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg5431072,(" before it was defined.")):R.ffi.throwNonFunApp(L[35],_plus5,[anf_arg5431072,(" before it was defined.")]);
};
try {
if(--R.GAS > 0) {
$z10761077 = $f10821083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10821083,
"from":L[35]});
}
} catch($e10741075) {
if(R.isCont($e10741075)) {
var $ss10781079 = {"from":L[35],
"go":function(ann_DASH_check_DASH_temp5361084) {
return $Hann_DASH_check_DASH_temp11911085(ann_DASH_check_DASH_temp5361084);
}};
$e10741075.stack[R.EXN_STACKHEIGHT++] = $ss10781079;
}
if(R.isPyretException($e10741075)) {
$e10741075.pyretStack.push(L[35]);
}
throw $e10741075;
}
var $ret10801081 = $Hann_DASH_check_DASH_temp11911085($z10761077);
++R.GAS;
return $ret10801081;
};
var $Hann_DASH_check_DASH_temp11911085 = function(ann_DASH_check_DASH_temp5361084) {
return ann_DASH_check_DASH_temp5361084;
};
var $Hanf_arg11901086 = function(anf_arg5281087,self891088,_plus5,torepr8) {
var anf_arg5291099 = G(self891088,"name",L[36]);
var $z10911092 = D;
var $f10971098 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg5291099):R.ffi.throwNonFunApp(L[36],torepr8,[anf_arg5291099]);
};
try {
if(--R.GAS > 0) {
$z10911092 = $f10971098();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10971098,
"from":L[36]});
}
} catch($e10891090) {
if(R.isCont($e10891090)) {
var $ss10931094 = {"from":L[36],
"go":function(anf_arg5301100) {
return $Hanf_arg11891101(anf_arg5301100,anf_arg5281087,_plus5);
}};
$e10891090.stack[R.EXN_STACKHEIGHT++] = $ss10931094;
}
if(R.isPyretException($e10891090)) {
$e10891090.pyretStack.push(L[36]);
}
throw $e10891090;
}
var $ret10951096 = $Hanf_arg11891101($z10911092,anf_arg5281087,_plus5);
++R.GAS;
return $ret10951096;
};
var $Hanf_arg11891101 = function(anf_arg5301100,anf_arg5281087,_plus5) {
var $z11041105 = D;
var $f11101111 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg5301100):R.ffi.throwNonFunApp(L[36],_plus5,[(", "),anf_arg5301100]);
};
try {
if(--R.GAS > 0) {
$z11041105 = $f11101111();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11101111,
"from":L[36]});
}
} catch($e11021103) {
if(R.isCont($e11021103)) {
var $ss11061107 = {"from":L[36],
"go":function(anf_arg5311112) {
return $Hanf_arg11881113(anf_arg5311112,anf_arg5281087,_plus5);
}};
$e11021103.stack[R.EXN_STACKHEIGHT++] = $ss11061107;
}
if(R.isPyretException($e11021103)) {
$e11021103.pyretStack.push(L[36]);
}
throw $e11021103;
}
var $ret11081109 = $Hanf_arg11881113($z11041105,anf_arg5281087,_plus5);
++R.GAS;
return $ret11081109;
};
var $Hanf_arg11881113 = function(anf_arg5311112,anf_arg5281087,_plus5) {
var $z11161117 = D;
var $f11221123 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg5281087,anf_arg5311112):R.ffi.throwNonFunApp(L[36],_plus5,[anf_arg5281087,anf_arg5311112]);
};
try {
if(--R.GAS > 0) {
$z11161117 = $f11221123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11221123,
"from":L[36]});
}
} catch($e11141115) {
if(R.isCont($e11141115)) {
var $ss11181119 = {"from":L[36],
"go":function(anf_arg5321124) {
return $Hanf_arg11871125(anf_arg5321124,_plus5);
}};
$e11141115.stack[R.EXN_STACKHEIGHT++] = $ss11181119;
}
if(R.isPyretException($e11141115)) {
$e11141115.pyretStack.push(L[36]);
}
throw $e11141115;
}
var $ret11201121 = $Hanf_arg11871125($z11161117,_plus5);
++R.GAS;
return $ret11201121;
};
var $Hanf_arg11871125 = function(anf_arg5321124,_plus5) {
var $z11281129 = D;
var $f11341135 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg5321124,(")")):R.ffi.throwNonFunApp(L[36],_plus5,[anf_arg5321124,(")")]);
};
try {
if(--R.GAS > 0) {
$z11281129 = $f11341135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11341135,
"from":L[36]});
}
} catch($e11261127) {
if(R.isCont($e11261127)) {
var $ss11301131 = {"from":L[36],
"go":function(anf_arg5331136) {
return $Hanf_arg11861137(anf_arg5331136,_plus5);
}};
$e11261127.stack[R.EXN_STACKHEIGHT++] = $ss11301131;
}
if(R.isPyretException($e11261127)) {
$e11261127.pyretStack.push(L[36]);
}
throw $e11261127;
}
var $ret11321133 = $Hanf_arg11861137($z11281129,_plus5);
++R.GAS;
return $ret11321133;
};
var $Hanf_arg11861137 = function(anf_arg5331136,_plus5) {
var $z11401141 = D;
var $f11461147 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg5331136):R.ffi.throwNonFunApp(L[36],_plus5,[("("),anf_arg5331136]);
};
try {
if(--R.GAS > 0) {
$z11401141 = $f11461147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11461147,
"from":L[36]});
}
} catch($e11381139) {
if(R.isCont($e11381139)) {
var $ss11421143 = {"from":L[36],
"go":function(anf_arg5341148) {
return $Hanf_arg11851149(anf_arg5341148,_plus5);
}};
$e11381139.stack[R.EXN_STACKHEIGHT++] = $ss11421143;
}
if(R.isPyretException($e11381139)) {
$e11381139.pyretStack.push(L[36]);
}
throw $e11381139;
}
var $ret11441145 = $Hanf_arg11851149($z11401141,_plus5);
++R.GAS;
return $ret11441145;
};
var $Hanf_arg11851149 = function(anf_arg5341148,_plus5) {
var $z11521153 = D;
var $f11581159 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("uninitialized-id"),anf_arg5341148):R.ffi.throwNonFunApp(L[36],_plus5,[("uninitialized-id"),anf_arg5341148]);
};
try {
if(--R.GAS > 0) {
$z11521153 = $f11581159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11581159,
"from":L[36]});
}
} catch($e11501151) {
if(R.isCont($e11501151)) {
var $ss11541155 = {"from":L[36],
"go":function(ann_DASH_check_DASH_temp5261160) {
return $Hann_DASH_check_DASH_temp11841161(ann_DASH_check_DASH_temp5261160);
}};
$e11501151.stack[R.EXN_STACKHEIGHT++] = $ss11541155;
}
if(R.isPyretException($e11501151)) {
$e11501151.pyretStack.push(L[36]);
}
throw $e11501151;
}
var $ret11561157 = $Hann_DASH_check_DASH_temp11841161($z11521153);
++R.GAS;
return $ret11561157;
};
var $Hann_DASH_check_DASH_temp11841161 = function(ann_DASH_check_DASH_temp5261160) {
return ann_DASH_check_DASH_temp5261160;
};
var $Hcont_tail_arg11821162 = function(cont_tail_arg5231163,if_helper5141164) {
if(--R.GAS > 0) {
$z11651166 = R.isFunction(if_helper5141164)?if_helper5141164.app(cont_tail_arg5231163):R.ffi.throwNonFunApp(L[36],if_helper5141164,[cont_tail_arg5231163]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper5141164)?if_helper5141164.app(cont_tail_arg5231163):R.ffi.throwNonFunApp(L[36],if_helper5141164,[cont_tail_arg5231163]);
},
"from":L[36]});
}
++R.GAS;
return $z11651166;
};
var $Hcont_tail_arg11831167 = function(cont_tail_arg5191168,if_helper5141164) {
if(--R.GAS > 0) {
$z11691170 = R.isFunction(if_helper5141164)?if_helper5141164.app(cont_tail_arg5191168):R.ffi.throwNonFunApp(L[36],if_helper5141164,[cont_tail_arg5191168]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper5141164)?if_helper5141164.app(cont_tail_arg5191168):R.ffi.throwNonFunApp(L[36],if_helper5141164,[cont_tail_arg5191168]);
},
"from":L[36]});
}
++R.GAS;
return $z11691170;
};
var $Hanf_arg11811171 = function(anf_arg4931172,self831173,_plus5,torepr8) {
var anf_arg4941184 = G(self831173,"fun-name",L[37]);
var $z11761177 = D;
var $f11821183 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4941184):R.ffi.throwNonFunApp(L[37],torepr8,[anf_arg4941184]);
};
try {
if(--R.GAS > 0) {
$z11761177 = $f11821183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11821183,
"from":L[37]});
}
} catch($e11741175) {
if(R.isCont($e11741175)) {
var $ss11781179 = {"from":L[37],
"go":function(anf_arg4951185) {
return $Hanf_arg11801186(anf_arg4951185,anf_arg4931172,self831173,_plus5,torepr8);
}};
$e11741175.stack[R.EXN_STACKHEIGHT++] = $ss11781179;
}
if(R.isPyretException($e11741175)) {
$e11741175.pyretStack.push(L[37]);
}
throw $e11741175;
}
var $ret11801181 = $Hanf_arg11801186($z11761177,anf_arg4931172,self831173,_plus5,torepr8);
++R.GAS;
return $ret11801181;
};
var $Hanf_arg11801186 = function(anf_arg4951185,anf_arg4931172,self831173,_plus5,torepr8) {
var $z11891190 = D;
var $f11951196 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg4951185):R.ffi.throwNonFunApp(L[37],_plus5,[(", "),anf_arg4951185]);
};
try {
if(--R.GAS > 0) {
$z11891190 = $f11951196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11951196,
"from":L[37]});
}
} catch($e11871188) {
if(R.isCont($e11871188)) {
var $ss11911192 = {"from":L[37],
"go":function(anf_arg4961197) {
return $Hanf_arg11791198(anf_arg4961197,anf_arg4931172,self831173,_plus5,torepr8);
}};
$e11871188.stack[R.EXN_STACKHEIGHT++] = $ss11911192;
}
if(R.isPyretException($e11871188)) {
$e11871188.pyretStack.push(L[37]);
}
throw $e11871188;
}
var $ret11931194 = $Hanf_arg11791198($z11891190,anf_arg4931172,self831173,_plus5,torepr8);
++R.GAS;
return $ret11931194;
};
var $Hanf_arg11791198 = function(anf_arg4961197,anf_arg4931172,self831173,_plus5,torepr8) {
var $z12011202 = D;
var $f12071208 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4931172,anf_arg4961197):R.ffi.throwNonFunApp(L[37],_plus5,[anf_arg4931172,anf_arg4961197]);
};
try {
if(--R.GAS > 0) {
$z12011202 = $f12071208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12071208,
"from":L[37]});
}
} catch($e11991200) {
if(R.isCont($e11991200)) {
var $ss12031204 = {"from":L[37],
"go":function(anf_arg4971209) {
return $Hanf_arg11781210(anf_arg4971209,self831173,_plus5,torepr8);
}};
$e11991200.stack[R.EXN_STACKHEIGHT++] = $ss12031204;
}
if(R.isPyretException($e11991200)) {
$e11991200.pyretStack.push(L[37]);
}
throw $e11991200;
}
var $ret12051206 = $Hanf_arg11781210($z12011202,self831173,_plus5,torepr8);
++R.GAS;
return $ret12051206;
};
var $Hanf_arg11781210 = function(anf_arg4971209,self831173,_plus5,torepr8) {
var anf_arg4981221 = G(self831173,"message",L[37]);
var $z12131214 = D;
var $f12191220 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4981221):R.ffi.throwNonFunApp(L[37],torepr8,[anf_arg4981221]);
};
try {
if(--R.GAS > 0) {
$z12131214 = $f12191220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12191220,
"from":L[37]});
}
} catch($e12111212) {
if(R.isCont($e12111212)) {
var $ss12151216 = {"from":L[37],
"go":function(anf_arg4991222) {
return $Hanf_arg11771223(anf_arg4991222,anf_arg4971209,self831173,_plus5,torepr8);
}};
$e12111212.stack[R.EXN_STACKHEIGHT++] = $ss12151216;
}
if(R.isPyretException($e12111212)) {
$e12111212.pyretStack.push(L[37]);
}
throw $e12111212;
}
var $ret12171218 = $Hanf_arg11771223($z12131214,anf_arg4971209,self831173,_plus5,torepr8);
++R.GAS;
return $ret12171218;
};
var $Hanf_arg11771223 = function(anf_arg4991222,anf_arg4971209,self831173,_plus5,torepr8) {
var $z12261227 = D;
var $f12321233 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg4991222):R.ffi.throwNonFunApp(L[37],_plus5,[(", "),anf_arg4991222]);
};
try {
if(--R.GAS > 0) {
$z12261227 = $f12321233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12321233,
"from":L[37]});
}
} catch($e12241225) {
if(R.isCont($e12241225)) {
var $ss12281229 = {"from":L[37],
"go":function(anf_arg5001234) {
return $Hanf_arg11761235(anf_arg5001234,anf_arg4971209,self831173,_plus5,torepr8);
}};
$e12241225.stack[R.EXN_STACKHEIGHT++] = $ss12281229;
}
if(R.isPyretException($e12241225)) {
$e12241225.pyretStack.push(L[37]);
}
throw $e12241225;
}
var $ret12301231 = $Hanf_arg11761235($z12261227,anf_arg4971209,self831173,_plus5,torepr8);
++R.GAS;
return $ret12301231;
};
var $Hanf_arg11761235 = function(anf_arg5001234,anf_arg4971209,self831173,_plus5,torepr8) {
var $z12381239 = D;
var $f12441245 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4971209,anf_arg5001234):R.ffi.throwNonFunApp(L[37],_plus5,[anf_arg4971209,anf_arg5001234]);
};
try {
if(--R.GAS > 0) {
$z12381239 = $f12441245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12441245,
"from":L[37]});
}
} catch($e12361237) {
if(R.isCont($e12361237)) {
var $ss12401241 = {"from":L[37],
"go":function(anf_arg5011246) {
return $Hanf_arg11751247(anf_arg5011246,self831173,_plus5,torepr8);
}};
$e12361237.stack[R.EXN_STACKHEIGHT++] = $ss12401241;
}
if(R.isPyretException($e12361237)) {
$e12361237.pyretStack.push(L[37]);
}
throw $e12361237;
}
var $ret12421243 = $Hanf_arg11751247($z12381239,self831173,_plus5,torepr8);
++R.GAS;
return $ret12421243;
};
var $Hanf_arg11751247 = function(anf_arg5011246,self831173,_plus5,torepr8) {
var anf_arg5021258 = G(self831173,"arg-position",L[37]);
var $z12501251 = D;
var $f12561257 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg5021258):R.ffi.throwNonFunApp(L[37],torepr8,[anf_arg5021258]);
};
try {
if(--R.GAS > 0) {
$z12501251 = $f12561257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12561257,
"from":L[37]});
}
} catch($e12481249) {
if(R.isCont($e12481249)) {
var $ss12521253 = {"from":L[37],
"go":function(anf_arg5031259) {
return $Hanf_arg11741260(anf_arg5031259,anf_arg5011246,self831173,_plus5,torepr8);
}};
$e12481249.stack[R.EXN_STACKHEIGHT++] = $ss12521253;
}
if(R.isPyretException($e12481249)) {
$e12481249.pyretStack.push(L[37]);
}
throw $e12481249;
}
var $ret12541255 = $Hanf_arg11741260($z12501251,anf_arg5011246,self831173,_plus5,torepr8);
++R.GAS;
return $ret12541255;
};
var $Hanf_arg11741260 = function(anf_arg5031259,anf_arg5011246,self831173,_plus5,torepr8) {
var $z12631264 = D;
var $f12691270 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg5031259):R.ffi.throwNonFunApp(L[37],_plus5,[(", "),anf_arg5031259]);
};
try {
if(--R.GAS > 0) {
$z12631264 = $f12691270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12691270,
"from":L[37]});
}
} catch($e12611262) {
if(R.isCont($e12611262)) {
var $ss12651266 = {"from":L[37],
"go":function(anf_arg5041271) {
return $Hanf_arg11731272(anf_arg5041271,anf_arg5011246,self831173,_plus5,torepr8);
}};
$e12611262.stack[R.EXN_STACKHEIGHT++] = $ss12651266;
}
if(R.isPyretException($e12611262)) {
$e12611262.pyretStack.push(L[37]);
}
throw $e12611262;
}
var $ret12671268 = $Hanf_arg11731272($z12631264,anf_arg5011246,self831173,_plus5,torepr8);
++R.GAS;
return $ret12671268;
};
var $Hanf_arg11731272 = function(anf_arg5041271,anf_arg5011246,self831173,_plus5,torepr8) {
var $z12751276 = D;
var $f12811282 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg5011246,anf_arg5041271):R.ffi.throwNonFunApp(L[37],_plus5,[anf_arg5011246,anf_arg5041271]);
};
try {
if(--R.GAS > 0) {
$z12751276 = $f12811282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12811282,
"from":L[37]});
}
} catch($e12731274) {
if(R.isCont($e12731274)) {
var $ss12771278 = {"from":L[37],
"go":function(anf_arg5051283) {
return $Hanf_arg11721284(anf_arg5051283,self831173,_plus5,torepr8);
}};
$e12731274.stack[R.EXN_STACKHEIGHT++] = $ss12771278;
}
if(R.isPyretException($e12731274)) {
$e12731274.pyretStack.push(L[37]);
}
throw $e12731274;
}
var $ret12791280 = $Hanf_arg11721284($z12751276,self831173,_plus5,torepr8);
++R.GAS;
return $ret12791280;
};
var $Hanf_arg11721284 = function(anf_arg5051283,self831173,_plus5,torepr8) {
var anf_arg5061295 = G(self831173,"arg-val",L[37]);
var $z12871288 = D;
var $f12931294 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg5061295):R.ffi.throwNonFunApp(L[37],torepr8,[anf_arg5061295]);
};
try {
if(--R.GAS > 0) {
$z12871288 = $f12931294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12931294,
"from":L[37]});
}
} catch($e12851286) {
if(R.isCont($e12851286)) {
var $ss12891290 = {"from":L[37],
"go":function(anf_arg5071296) {
return $Hanf_arg11711297(anf_arg5071296,anf_arg5051283,_plus5);
}};
$e12851286.stack[R.EXN_STACKHEIGHT++] = $ss12891290;
}
if(R.isPyretException($e12851286)) {
$e12851286.pyretStack.push(L[37]);
}
throw $e12851286;
}
var $ret12911292 = $Hanf_arg11711297($z12871288,anf_arg5051283,_plus5);
++R.GAS;
return $ret12911292;
};
var $Hanf_arg11711297 = function(anf_arg5071296,anf_arg5051283,_plus5) {
var $z13001301 = D;
var $f13061307 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg5071296):R.ffi.throwNonFunApp(L[37],_plus5,[(", "),anf_arg5071296]);
};
try {
if(--R.GAS > 0) {
$z13001301 = $f13061307();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13061307,
"from":L[37]});
}
} catch($e12981299) {
if(R.isCont($e12981299)) {
var $ss13021303 = {"from":L[37],
"go":function(anf_arg5081308) {
return $Hanf_arg11701309(anf_arg5081308,anf_arg5051283,_plus5);
}};
$e12981299.stack[R.EXN_STACKHEIGHT++] = $ss13021303;
}
if(R.isPyretException($e12981299)) {
$e12981299.pyretStack.push(L[37]);
}
throw $e12981299;
}
var $ret13041305 = $Hanf_arg11701309($z13001301,anf_arg5051283,_plus5);
++R.GAS;
return $ret13041305;
};
var $Hanf_arg11701309 = function(anf_arg5081308,anf_arg5051283,_plus5) {
var $z13121313 = D;
var $f13181319 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg5051283,anf_arg5081308):R.ffi.throwNonFunApp(L[37],_plus5,[anf_arg5051283,anf_arg5081308]);
};
try {
if(--R.GAS > 0) {
$z13121313 = $f13181319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13181319,
"from":L[37]});
}
} catch($e13101311) {
if(R.isCont($e13101311)) {
var $ss13141315 = {"from":L[37],
"go":function(anf_arg5091320) {
return $Hanf_arg11691321(anf_arg5091320,_plus5);
}};
$e13101311.stack[R.EXN_STACKHEIGHT++] = $ss13141315;
}
if(R.isPyretException($e13101311)) {
$e13101311.pyretStack.push(L[37]);
}
throw $e13101311;
}
var $ret13161317 = $Hanf_arg11691321($z13121313,_plus5);
++R.GAS;
return $ret13161317;
};
var $Hanf_arg11691321 = function(anf_arg5091320,_plus5) {
var $z13241325 = D;
var $f13301331 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg5091320,(")")):R.ffi.throwNonFunApp(L[37],_plus5,[anf_arg5091320,(")")]);
};
try {
if(--R.GAS > 0) {
$z13241325 = $f13301331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13301331,
"from":L[37]});
}
} catch($e13221323) {
if(R.isCont($e13221323)) {
var $ss13261327 = {"from":L[37],
"go":function(anf_arg5101332) {
return $Hanf_arg11681333(anf_arg5101332,_plus5);
}};
$e13221323.stack[R.EXN_STACKHEIGHT++] = $ss13261327;
}
if(R.isPyretException($e13221323)) {
$e13221323.pyretStack.push(L[37]);
}
throw $e13221323;
}
var $ret13281329 = $Hanf_arg11681333($z13241325,_plus5);
++R.GAS;
return $ret13281329;
};
var $Hanf_arg11681333 = function(anf_arg5101332,_plus5) {
var $z13361337 = D;
var $f13421343 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg5101332):R.ffi.throwNonFunApp(L[37],_plus5,[("("),anf_arg5101332]);
};
try {
if(--R.GAS > 0) {
$z13361337 = $f13421343();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13421343,
"from":L[37]});
}
} catch($e13341335) {
if(R.isCont($e13341335)) {
var $ss13381339 = {"from":L[37],
"go":function(anf_arg5111344) {
return $Hanf_arg11671345(anf_arg5111344,_plus5);
}};
$e13341335.stack[R.EXN_STACKHEIGHT++] = $ss13381339;
}
if(R.isPyretException($e13341335)) {
$e13341335.pyretStack.push(L[37]);
}
throw $e13341335;
}
var $ret13401341 = $Hanf_arg11671345($z13361337,_plus5);
++R.GAS;
return $ret13401341;
};
var $Hanf_arg11671345 = function(anf_arg5111344,_plus5) {
var $z13481349 = D;
var $f13541355 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("bad-app"),anf_arg5111344):R.ffi.throwNonFunApp(L[37],_plus5,[("bad-app"),anf_arg5111344]);
};
try {
if(--R.GAS > 0) {
$z13481349 = $f13541355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13541355,
"from":L[37]});
}
} catch($e13461347) {
if(R.isCont($e13461347)) {
var $ss13501351 = {"from":L[37],
"go":function(ann_DASH_check_DASH_temp4911356) {
return $Hann_DASH_check_DASH_temp11661357(ann_DASH_check_DASH_temp4911356);
}};
$e13461347.stack[R.EXN_STACKHEIGHT++] = $ss13501351;
}
if(R.isPyretException($e13461347)) {
$e13461347.pyretStack.push(L[37]);
}
throw $e13461347;
}
var $ret13521353 = $Hann_DASH_check_DASH_temp11661357($z13481349);
++R.GAS;
return $ret13521353;
};
var $Hann_DASH_check_DASH_temp11661357 = function(ann_DASH_check_DASH_temp4911356) {
return ann_DASH_check_DASH_temp4911356;
};
var $Hcont_tail_arg11641358 = function(cont_tail_arg4881359,if_helper4761360) {
if(--R.GAS > 0) {
$z13611362 = R.isFunction(if_helper4761360)?if_helper4761360.app(cont_tail_arg4881359):R.ffi.throwNonFunApp(L[37],if_helper4761360,[cont_tail_arg4881359]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper4761360)?if_helper4761360.app(cont_tail_arg4881359):R.ffi.throwNonFunApp(L[37],if_helper4761360,[cont_tail_arg4881359]);
},
"from":L[37]});
}
++R.GAS;
return $z13611362;
};
var $Hcont_tail_arg11651363 = function(cont_tail_arg4811364,if_helper4761360) {
if(--R.GAS > 0) {
$z13651366 = R.isFunction(if_helper4761360)?if_helper4761360.app(cont_tail_arg4811364):R.ffi.throwNonFunApp(L[37],if_helper4761360,[cont_tail_arg4811364]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper4761360)?if_helper4761360.app(cont_tail_arg4811364):R.ffi.throwNonFunApp(L[37],if_helper4761360,[cont_tail_arg4811364]);
},
"from":L[37]});
}
++R.GAS;
return $z13651366;
};
var $Hanf_arg11631367 = function(anf_arg4691368,self1161369,_plus5,torepr8) {
var $z13721373 = D;
var $f13781379 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: Expected a function at "),anf_arg4691368):R.ffi.throwNonFunApp(L[38],_plus5,[("Error: Expected a function at "),anf_arg4691368]);
};
try {
if(--R.GAS > 0) {
$z13721373 = $f13781379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13781379,
"from":L[38]});
}
} catch($e13701371) {
if(R.isCont($e13701371)) {
var $ss13741375 = {"from":L[38],
"go":function(anf_arg4701380) {
return $Hanf_arg11621381(anf_arg4701380,self1161369,_plus5,torepr8);
}};
$e13701371.stack[R.EXN_STACKHEIGHT++] = $ss13741375;
}
if(R.isPyretException($e13701371)) {
$e13701371.pyretStack.push(L[38]);
}
throw $e13701371;
}
var $ret13761377 = $Hanf_arg11621381($z13721373,self1161369,_plus5,torepr8);
++R.GAS;
return $ret13761377;
};
var $Hanf_arg11621381 = function(anf_arg4701380,self1161369,_plus5,torepr8) {
var $z13841385 = D;
var $f13901391 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4701380,(", but got ")):R.ffi.throwNonFunApp(L[38],_plus5,[anf_arg4701380,(", but got ")]);
};
try {
if(--R.GAS > 0) {
$z13841385 = $f13901391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13901391,
"from":L[38]});
}
} catch($e13821383) {
if(R.isCont($e13821383)) {
var $ss13861387 = {"from":L[38],
"go":function(anf_arg4711392) {
return $Hanf_arg11611393(anf_arg4711392,self1161369,_plus5,torepr8);
}};
$e13821383.stack[R.EXN_STACKHEIGHT++] = $ss13861387;
}
if(R.isPyretException($e13821383)) {
$e13821383.pyretStack.push(L[38]);
}
throw $e13821383;
}
var $ret13881389 = $Hanf_arg11611393($z13841385,self1161369,_plus5,torepr8);
++R.GAS;
return $ret13881389;
};
var $Hanf_arg11611393 = function(anf_arg4711392,self1161369,_plus5,torepr8) {
var anf_arg4721404 = G(self1161369,"non-fun-val",L[40]);
var $z13961397 = D;
var $f14021403 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4721404):R.ffi.throwNonFunApp(L[39],torepr8,[anf_arg4721404]);
};
try {
if(--R.GAS > 0) {
$z13961397 = $f14021403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14021403,
"from":L[39]});
}
} catch($e13941395) {
if(R.isCont($e13941395)) {
var $ss13981399 = {"from":L[39],
"go":function(anf_arg4731405) {
return $Hanf_arg11601406(anf_arg4731405,anf_arg4711392,_plus5);
}};
$e13941395.stack[R.EXN_STACKHEIGHT++] = $ss13981399;
}
if(R.isPyretException($e13941395)) {
$e13941395.pyretStack.push(L[39]);
}
throw $e13941395;
}
var $ret14001401 = $Hanf_arg11601406($z13961397,anf_arg4711392,_plus5);
++R.GAS;
return $ret14001401;
};
var $Hanf_arg11601406 = function(anf_arg4731405,anf_arg4711392,_plus5) {
var $z14091410 = D;
var $f14151416 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4711392,anf_arg4731405):R.ffi.throwNonFunApp(L[41],_plus5,[anf_arg4711392,anf_arg4731405]);
};
try {
if(--R.GAS > 0) {
$z14091410 = $f14151416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14151416,
"from":L[41]});
}
} catch($e14071408) {
if(R.isCont($e14071408)) {
var $ss14111412 = {"from":L[41],
"go":function(ann_DASH_check_DASH_temp4661417) {
return $Hann_DASH_check_DASH_temp11591418(ann_DASH_check_DASH_temp4661417);
}};
$e14071408.stack[R.EXN_STACKHEIGHT++] = $ss14111412;
}
if(R.isPyretException($e14071408)) {
$e14071408.pyretStack.push(L[41]);
}
throw $e14071408;
}
var $ret14131414 = $Hann_DASH_check_DASH_temp11591418($z14091410);
++R.GAS;
return $ret14131414;
};
var $Hann_DASH_check_DASH_temp11591418 = function(ann_DASH_check_DASH_temp4661417) {
return ann_DASH_check_DASH_temp4661417;
};
var $Hanf_arg11581419 = function(anf_arg4541420,self771421,_plus5,torepr8) {
var anf_arg4551432 = G(self771421,"non-fun-val",L[42]);
var $z14241425 = D;
var $f14301431 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4551432):R.ffi.throwNonFunApp(L[42],torepr8,[anf_arg4551432]);
};
try {
if(--R.GAS > 0) {
$z14241425 = $f14301431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14301431,
"from":L[42]});
}
} catch($e14221423) {
if(R.isCont($e14221423)) {
var $ss14261427 = {"from":L[42],
"go":function(anf_arg4561433) {
return $Hanf_arg11571434(anf_arg4561433,anf_arg4541420,self771421,_plus5,torepr8);
}};
$e14221423.stack[R.EXN_STACKHEIGHT++] = $ss14261427;
}
if(R.isPyretException($e14221423)) {
$e14221423.pyretStack.push(L[42]);
}
throw $e14221423;
}
var $ret14281429 = $Hanf_arg11571434($z14241425,anf_arg4541420,self771421,_plus5,torepr8);
++R.GAS;
return $ret14281429;
};
var $Hanf_arg11571434 = function(anf_arg4561433,anf_arg4541420,self771421,_plus5,torepr8) {
var $z14371438 = D;
var $f14431444 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg4561433):R.ffi.throwNonFunApp(L[42],_plus5,[(", "),anf_arg4561433]);
};
try {
if(--R.GAS > 0) {
$z14371438 = $f14431444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14431444,
"from":L[42]});
}
} catch($e14351436) {
if(R.isCont($e14351436)) {
var $ss14391440 = {"from":L[42],
"go":function(anf_arg4571445) {
return $Hanf_arg11561446(anf_arg4571445,anf_arg4541420,self771421,_plus5,torepr8);
}};
$e14351436.stack[R.EXN_STACKHEIGHT++] = $ss14391440;
}
if(R.isPyretException($e14351436)) {
$e14351436.pyretStack.push(L[42]);
}
throw $e14351436;
}
var $ret14411442 = $Hanf_arg11561446($z14371438,anf_arg4541420,self771421,_plus5,torepr8);
++R.GAS;
return $ret14411442;
};
var $Hanf_arg11561446 = function(anf_arg4571445,anf_arg4541420,self771421,_plus5,torepr8) {
var $z14491450 = D;
var $f14551456 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4541420,anf_arg4571445):R.ffi.throwNonFunApp(L[42],_plus5,[anf_arg4541420,anf_arg4571445]);
};
try {
if(--R.GAS > 0) {
$z14491450 = $f14551456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14551456,
"from":L[42]});
}
} catch($e14471448) {
if(R.isCont($e14471448)) {
var $ss14511452 = {"from":L[42],
"go":function(anf_arg4581457) {
return $Hanf_arg11551458(anf_arg4581457,self771421,_plus5,torepr8);
}};
$e14471448.stack[R.EXN_STACKHEIGHT++] = $ss14511452;
}
if(R.isPyretException($e14471448)) {
$e14471448.pyretStack.push(L[42]);
}
throw $e14471448;
}
var $ret14531454 = $Hanf_arg11551458($z14491450,self771421,_plus5,torepr8);
++R.GAS;
return $ret14531454;
};
var $Hanf_arg11551458 = function(anf_arg4581457,self771421,_plus5,torepr8) {
var anf_arg4591469 = G(self771421,"args",L[42]);
var $z14611462 = D;
var $f14671468 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4591469):R.ffi.throwNonFunApp(L[42],torepr8,[anf_arg4591469]);
};
try {
if(--R.GAS > 0) {
$z14611462 = $f14671468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14671468,
"from":L[42]});
}
} catch($e14591460) {
if(R.isCont($e14591460)) {
var $ss14631464 = {"from":L[42],
"go":function(anf_arg4601470) {
return $Hanf_arg11541471(anf_arg4601470,anf_arg4581457,_plus5);
}};
$e14591460.stack[R.EXN_STACKHEIGHT++] = $ss14631464;
}
if(R.isPyretException($e14591460)) {
$e14591460.pyretStack.push(L[42]);
}
throw $e14591460;
}
var $ret14651466 = $Hanf_arg11541471($z14611462,anf_arg4581457,_plus5);
++R.GAS;
return $ret14651466;
};
var $Hanf_arg11541471 = function(anf_arg4601470,anf_arg4581457,_plus5) {
var $z14741475 = D;
var $f14801481 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg4601470):R.ffi.throwNonFunApp(L[42],_plus5,[(", "),anf_arg4601470]);
};
try {
if(--R.GAS > 0) {
$z14741475 = $f14801481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14801481,
"from":L[42]});
}
} catch($e14721473) {
if(R.isCont($e14721473)) {
var $ss14761477 = {"from":L[42],
"go":function(anf_arg4611482) {
return $Hanf_arg11531483(anf_arg4611482,anf_arg4581457,_plus5);
}};
$e14721473.stack[R.EXN_STACKHEIGHT++] = $ss14761477;
}
if(R.isPyretException($e14721473)) {
$e14721473.pyretStack.push(L[42]);
}
throw $e14721473;
}
var $ret14781479 = $Hanf_arg11531483($z14741475,anf_arg4581457,_plus5);
++R.GAS;
return $ret14781479;
};
var $Hanf_arg11531483 = function(anf_arg4611482,anf_arg4581457,_plus5) {
var $z14861487 = D;
var $f14921493 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4581457,anf_arg4611482):R.ffi.throwNonFunApp(L[42],_plus5,[anf_arg4581457,anf_arg4611482]);
};
try {
if(--R.GAS > 0) {
$z14861487 = $f14921493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14921493,
"from":L[42]});
}
} catch($e14841485) {
if(R.isCont($e14841485)) {
var $ss14881489 = {"from":L[42],
"go":function(anf_arg4621494) {
return $Hanf_arg11521495(anf_arg4621494,_plus5);
}};
$e14841485.stack[R.EXN_STACKHEIGHT++] = $ss14881489;
}
if(R.isPyretException($e14841485)) {
$e14841485.pyretStack.push(L[42]);
}
throw $e14841485;
}
var $ret14901491 = $Hanf_arg11521495($z14861487,_plus5);
++R.GAS;
return $ret14901491;
};
var $Hanf_arg11521495 = function(anf_arg4621494,_plus5) {
var $z14981499 = D;
var $f15041505 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4621494,(")")):R.ffi.throwNonFunApp(L[42],_plus5,[anf_arg4621494,(")")]);
};
try {
if(--R.GAS > 0) {
$z14981499 = $f15041505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15041505,
"from":L[42]});
}
} catch($e14961497) {
if(R.isCont($e14961497)) {
var $ss15001501 = {"from":L[42],
"go":function(anf_arg4631506) {
return $Hanf_arg11511507(anf_arg4631506,_plus5);
}};
$e14961497.stack[R.EXN_STACKHEIGHT++] = $ss15001501;
}
if(R.isPyretException($e14961497)) {
$e14961497.pyretStack.push(L[42]);
}
throw $e14961497;
}
var $ret15021503 = $Hanf_arg11511507($z14981499,_plus5);
++R.GAS;
return $ret15021503;
};
var $Hanf_arg11511507 = function(anf_arg4631506,_plus5) {
var $z15101511 = D;
var $f15161517 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg4631506):R.ffi.throwNonFunApp(L[42],_plus5,[("("),anf_arg4631506]);
};
try {
if(--R.GAS > 0) {
$z15101511 = $f15161517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15161517,
"from":L[42]});
}
} catch($e15081509) {
if(R.isCont($e15081509)) {
var $ss15121513 = {"from":L[42],
"go":function(anf_arg4641518) {
return $Hanf_arg11501519(anf_arg4641518,_plus5);
}};
$e15081509.stack[R.EXN_STACKHEIGHT++] = $ss15121513;
}
if(R.isPyretException($e15081509)) {
$e15081509.pyretStack.push(L[42]);
}
throw $e15081509;
}
var $ret15141515 = $Hanf_arg11501519($z15101511,_plus5);
++R.GAS;
return $ret15141515;
};
var $Hanf_arg11501519 = function(anf_arg4641518,_plus5) {
var $z15221523 = D;
var $f15281529 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("non-function-app"),anf_arg4641518):R.ffi.throwNonFunApp(L[42],_plus5,[("non-function-app"),anf_arg4641518]);
};
try {
if(--R.GAS > 0) {
$z15221523 = $f15281529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15281529,
"from":L[42]});
}
} catch($e15201521) {
if(R.isCont($e15201521)) {
var $ss15241525 = {"from":L[42],
"go":function(ann_DASH_check_DASH_temp4521530) {
return $Hann_DASH_check_DASH_temp11491531(ann_DASH_check_DASH_temp4521530);
}};
$e15201521.stack[R.EXN_STACKHEIGHT++] = $ss15241525;
}
if(R.isPyretException($e15201521)) {
$e15201521.pyretStack.push(L[42]);
}
throw $e15201521;
}
var $ret15261527 = $Hann_DASH_check_DASH_temp11491531($z15221523);
++R.GAS;
return $ret15261527;
};
var $Hann_DASH_check_DASH_temp11491531 = function(ann_DASH_check_DASH_temp4521530) {
return ann_DASH_check_DASH_temp4521530;
};
var $Hcont_tail_arg11471532 = function(cont_tail_arg4491533,if_helper4391534) {
if(--R.GAS > 0) {
$z15351536 = R.isFunction(if_helper4391534)?if_helper4391534.app(cont_tail_arg4491533):R.ffi.throwNonFunApp(L[42],if_helper4391534,[cont_tail_arg4491533]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper4391534)?if_helper4391534.app(cont_tail_arg4491533):R.ffi.throwNonFunApp(L[42],if_helper4391534,[cont_tail_arg4491533]);
},
"from":L[42]});
}
++R.GAS;
return $z15351536;
};
var $Hcont_tail_arg11481537 = function(cont_tail_arg4441538,if_helper4391534) {
if(--R.GAS > 0) {
$z15391540 = R.isFunction(if_helper4391534)?if_helper4391534.app(cont_tail_arg4441538):R.ffi.throwNonFunApp(L[42],if_helper4391534,[cont_tail_arg4441538]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper4391534)?if_helper4391534.app(cont_tail_arg4441538):R.ffi.throwNonFunApp(L[42],if_helper4391534,[cont_tail_arg4441538]);
},
"from":L[42]});
}
++R.GAS;
return $z15391540;
};
var $Hanf_arg11461541 = function(anf_arg4261542,self1121543,_plus5,tostring9) {
var $z15461547 = D;
var $f15521553 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: The function at "),anf_arg4261542):R.ffi.throwNonFunApp(L[43],_plus5,[("Error: The function at "),anf_arg4261542]);
};
try {
if(--R.GAS > 0) {
$z15461547 = $f15521553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15521553,
"from":L[43]});
}
} catch($e15441545) {
if(R.isCont($e15441545)) {
var $ss15481549 = {"from":L[43],
"go":function(anf_arg4271554) {
return $Hanf_arg11451555(anf_arg4271554,self1121543,_plus5,tostring9);
}};
$e15441545.stack[R.EXN_STACKHEIGHT++] = $ss15481549;
}
if(R.isPyretException($e15441545)) {
$e15441545.pyretStack.push(L[43]);
}
throw $e15441545;
}
var $ret15501551 = $Hanf_arg11451555($z15461547,self1121543,_plus5,tostring9);
++R.GAS;
return $ret15501551;
};
var $Hanf_arg11451555 = function(anf_arg4271554,self1121543,_plus5,tostring9) {
var $z15581559 = D;
var $f15641565 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4271554,(" expects ")):R.ffi.throwNonFunApp(L[43],_plus5,[anf_arg4271554,(" expects ")]);
};
try {
if(--R.GAS > 0) {
$z15581559 = $f15641565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15641565,
"from":L[43]});
}
} catch($e15561557) {
if(R.isCont($e15561557)) {
var $ss15601561 = {"from":L[43],
"go":function(anf_arg4281566) {
return $Hanf_arg11441567(anf_arg4281566,self1121543,_plus5,tostring9);
}};
$e15561557.stack[R.EXN_STACKHEIGHT++] = $ss15601561;
}
if(R.isPyretException($e15561557)) {
$e15561557.pyretStack.push(L[43]);
}
throw $e15561557;
}
var $ret15621563 = $Hanf_arg11441567($z15581559,self1121543,_plus5,tostring9);
++R.GAS;
return $ret15621563;
};
var $Hanf_arg11441567 = function(anf_arg4281566,self1121543,_plus5,tostring9) {
var anf_arg4291578 = G(self1121543,"expected-arity",L[45]);
var $z15701571 = D;
var $f15761577 = function(_) {
return R.isFunction(tostring9)?tostring9.app(anf_arg4291578):R.ffi.throwNonFunApp(L[44],tostring9,[anf_arg4291578]);
};
try {
if(--R.GAS > 0) {
$z15701571 = $f15761577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15761577,
"from":L[44]});
}
} catch($e15681569) {
if(R.isCont($e15681569)) {
var $ss15721573 = {"from":L[44],
"go":function(anf_arg4301579) {
return $Hanf_arg11431580(anf_arg4301579,anf_arg4281566,self1121543,_plus5,tostring9);
}};
$e15681569.stack[R.EXN_STACKHEIGHT++] = $ss15721573;
}
if(R.isPyretException($e15681569)) {
$e15681569.pyretStack.push(L[44]);
}
throw $e15681569;
}
var $ret15741575 = $Hanf_arg11431580($z15701571,anf_arg4281566,self1121543,_plus5,tostring9);
++R.GAS;
return $ret15741575;
};
var $Hanf_arg11431580 = function(anf_arg4301579,anf_arg4281566,self1121543,_plus5,tostring9) {
var $z15831584 = D;
var $f15891590 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4281566,anf_arg4301579):R.ffi.throwNonFunApp(L[43],_plus5,[anf_arg4281566,anf_arg4301579]);
};
try {
if(--R.GAS > 0) {
$z15831584 = $f15891590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15891590,
"from":L[43]});
}
} catch($e15811582) {
if(R.isCont($e15811582)) {
var $ss15851586 = {"from":L[43],
"go":function(anf_arg4311591) {
return $Hanf_arg11421592(anf_arg4311591,self1121543,_plus5,tostring9);
}};
$e15811582.stack[R.EXN_STACKHEIGHT++] = $ss15851586;
}
if(R.isPyretException($e15811582)) {
$e15811582.pyretStack.push(L[43]);
}
throw $e15811582;
}
var $ret15871588 = $Hanf_arg11421592($z15831584,self1121543,_plus5,tostring9);
++R.GAS;
return $ret15871588;
};
var $Hanf_arg11421592 = function(anf_arg4311591,self1121543,_plus5,tostring9) {
var $z15951596 = D;
var $f16011602 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4311591,(" arguments, but got ")):R.ffi.throwNonFunApp(L[43],_plus5,[anf_arg4311591,(" arguments, but got ")]);
};
try {
if(--R.GAS > 0) {
$z15951596 = $f16011602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16011602,
"from":L[43]});
}
} catch($e15931594) {
if(R.isCont($e15931594)) {
var $ss15971598 = {"from":L[43],
"go":function(anf_arg4321603) {
return $Hanf_arg11411604(anf_arg4321603,self1121543,_plus5,tostring9);
}};
$e15931594.stack[R.EXN_STACKHEIGHT++] = $ss15971598;
}
if(R.isPyretException($e15931594)) {
$e15931594.pyretStack.push(L[43]);
}
throw $e15931594;
}
var $ret15991600 = $Hanf_arg11411604($z15951596,self1121543,_plus5,tostring9);
++R.GAS;
return $ret15991600;
};
var $Hanf_arg11411604 = function(anf_arg4321603,self1121543,_plus5,tostring9) {
var anf_bracket4331618 = G(self1121543,"args",L[48]);
var anf_fun4341615 = G(anf_bracket4331618,"length",L[47]);
var $z16071608 = D;
var $f16131614 = function(_) {
return R.isFunction(anf_fun4341615)?anf_fun4341615.app():R.ffi.throwNonFunApp(L[46],anf_fun4341615,[]);
};
try {
if(--R.GAS > 0) {
$z16071608 = $f16131614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16131614,
"from":L[46]});
}
} catch($e16051606) {
if(R.isCont($e16051606)) {
var $ss16091610 = {"from":L[46],
"go":function(anf_arg4351616) {
return $Hanf_arg11401617(anf_arg4351616,anf_arg4321603,_plus5,tostring9);
}};
$e16051606.stack[R.EXN_STACKHEIGHT++] = $ss16091610;
}
if(R.isPyretException($e16051606)) {
$e16051606.pyretStack.push(L[46]);
}
throw $e16051606;
}
var $ret16111612 = $Hanf_arg11401617($z16071608,anf_arg4321603,_plus5,tostring9);
++R.GAS;
return $ret16111612;
};
var $Hanf_arg11401617 = function(anf_arg4351616,anf_arg4321603,_plus5,tostring9) {
var $z16211622 = D;
var $f16271628 = function(_) {
return R.isFunction(tostring9)?tostring9.app(anf_arg4351616):R.ffi.throwNonFunApp(L[49],tostring9,[anf_arg4351616]);
};
try {
if(--R.GAS > 0) {
$z16211622 = $f16271628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16271628,
"from":L[49]});
}
} catch($e16191620) {
if(R.isCont($e16191620)) {
var $ss16231624 = {"from":L[49],
"go":function(anf_arg4361629) {
return $Hanf_arg11391630(anf_arg4361629,anf_arg4321603,_plus5);
}};
$e16191620.stack[R.EXN_STACKHEIGHT++] = $ss16231624;
}
if(R.isPyretException($e16191620)) {
$e16191620.pyretStack.push(L[49]);
}
throw $e16191620;
}
var $ret16251626 = $Hanf_arg11391630($z16211622,anf_arg4321603,_plus5);
++R.GAS;
return $ret16251626;
};
var $Hanf_arg11391630 = function(anf_arg4361629,anf_arg4321603,_plus5) {
var $z16331634 = D;
var $f16391640 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4321603,anf_arg4361629):R.ffi.throwNonFunApp(L[50],_plus5,[anf_arg4321603,anf_arg4361629]);
};
try {
if(--R.GAS > 0) {
$z16331634 = $f16391640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16391640,
"from":L[50]});
}
} catch($e16311632) {
if(R.isCont($e16311632)) {
var $ss16351636 = {"from":L[50],
"go":function(ann_DASH_check_DASH_temp4231641) {
return $Hann_DASH_check_DASH_temp11381642(ann_DASH_check_DASH_temp4231641);
}};
$e16311632.stack[R.EXN_STACKHEIGHT++] = $ss16351636;
}
if(R.isPyretException($e16311632)) {
$e16311632.pyretStack.push(L[50]);
}
throw $e16311632;
}
var $ret16371638 = $Hann_DASH_check_DASH_temp11381642($z16331634);
++R.GAS;
return $ret16371638;
};
var $Hann_DASH_check_DASH_temp11381642 = function(ann_DASH_check_DASH_temp4231641) {
return ann_DASH_check_DASH_temp4231641;
};
var $Hanf_arg11371643 = function(anf_arg4111644,self711645,_plus5,torepr8) {
var anf_arg4121656 = G(self711645,"expected-arity",L[51]);
var $z16481649 = D;
var $f16541655 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4121656):R.ffi.throwNonFunApp(L[51],torepr8,[anf_arg4121656]);
};
try {
if(--R.GAS > 0) {
$z16481649 = $f16541655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16541655,
"from":L[51]});
}
} catch($e16461647) {
if(R.isCont($e16461647)) {
var $ss16501651 = {"from":L[51],
"go":function(anf_arg4131657) {
return $Hanf_arg11361658(anf_arg4131657,anf_arg4111644,self711645,_plus5,torepr8);
}};
$e16461647.stack[R.EXN_STACKHEIGHT++] = $ss16501651;
}
if(R.isPyretException($e16461647)) {
$e16461647.pyretStack.push(L[51]);
}
throw $e16461647;
}
var $ret16521653 = $Hanf_arg11361658($z16481649,anf_arg4111644,self711645,_plus5,torepr8);
++R.GAS;
return $ret16521653;
};
var $Hanf_arg11361658 = function(anf_arg4131657,anf_arg4111644,self711645,_plus5,torepr8) {
var $z16611662 = D;
var $f16671668 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg4131657):R.ffi.throwNonFunApp(L[51],_plus5,[(", "),anf_arg4131657]);
};
try {
if(--R.GAS > 0) {
$z16611662 = $f16671668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16671668,
"from":L[51]});
}
} catch($e16591660) {
if(R.isCont($e16591660)) {
var $ss16631664 = {"from":L[51],
"go":function(anf_arg4141669) {
return $Hanf_arg11351670(anf_arg4141669,anf_arg4111644,self711645,_plus5,torepr8);
}};
$e16591660.stack[R.EXN_STACKHEIGHT++] = $ss16631664;
}
if(R.isPyretException($e16591660)) {
$e16591660.pyretStack.push(L[51]);
}
throw $e16591660;
}
var $ret16651666 = $Hanf_arg11351670($z16611662,anf_arg4111644,self711645,_plus5,torepr8);
++R.GAS;
return $ret16651666;
};
var $Hanf_arg11351670 = function(anf_arg4141669,anf_arg4111644,self711645,_plus5,torepr8) {
var $z16731674 = D;
var $f16791680 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4111644,anf_arg4141669):R.ffi.throwNonFunApp(L[51],_plus5,[anf_arg4111644,anf_arg4141669]);
};
try {
if(--R.GAS > 0) {
$z16731674 = $f16791680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16791680,
"from":L[51]});
}
} catch($e16711672) {
if(R.isCont($e16711672)) {
var $ss16751676 = {"from":L[51],
"go":function(anf_arg4151681) {
return $Hanf_arg11341682(anf_arg4151681,self711645,_plus5,torepr8);
}};
$e16711672.stack[R.EXN_STACKHEIGHT++] = $ss16751676;
}
if(R.isPyretException($e16711672)) {
$e16711672.pyretStack.push(L[51]);
}
throw $e16711672;
}
var $ret16771678 = $Hanf_arg11341682($z16731674,self711645,_plus5,torepr8);
++R.GAS;
return $ret16771678;
};
var $Hanf_arg11341682 = function(anf_arg4151681,self711645,_plus5,torepr8) {
var anf_arg4161693 = G(self711645,"args",L[51]);
var $z16851686 = D;
var $f16911692 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4161693):R.ffi.throwNonFunApp(L[51],torepr8,[anf_arg4161693]);
};
try {
if(--R.GAS > 0) {
$z16851686 = $f16911692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16911692,
"from":L[51]});
}
} catch($e16831684) {
if(R.isCont($e16831684)) {
var $ss16871688 = {"from":L[51],
"go":function(anf_arg4171694) {
return $Hanf_arg11331695(anf_arg4171694,anf_arg4151681,_plus5);
}};
$e16831684.stack[R.EXN_STACKHEIGHT++] = $ss16871688;
}
if(R.isPyretException($e16831684)) {
$e16831684.pyretStack.push(L[51]);
}
throw $e16831684;
}
var $ret16891690 = $Hanf_arg11331695($z16851686,anf_arg4151681,_plus5);
++R.GAS;
return $ret16891690;
};
var $Hanf_arg11331695 = function(anf_arg4171694,anf_arg4151681,_plus5) {
var $z16981699 = D;
var $f17041705 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg4171694):R.ffi.throwNonFunApp(L[51],_plus5,[(", "),anf_arg4171694]);
};
try {
if(--R.GAS > 0) {
$z16981699 = $f17041705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17041705,
"from":L[51]});
}
} catch($e16961697) {
if(R.isCont($e16961697)) {
var $ss17001701 = {"from":L[51],
"go":function(anf_arg4181706) {
return $Hanf_arg11321707(anf_arg4181706,anf_arg4151681,_plus5);
}};
$e16961697.stack[R.EXN_STACKHEIGHT++] = $ss17001701;
}
if(R.isPyretException($e16961697)) {
$e16961697.pyretStack.push(L[51]);
}
throw $e16961697;
}
var $ret17021703 = $Hanf_arg11321707($z16981699,anf_arg4151681,_plus5);
++R.GAS;
return $ret17021703;
};
var $Hanf_arg11321707 = function(anf_arg4181706,anf_arg4151681,_plus5) {
var $z17101711 = D;
var $f17161717 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4151681,anf_arg4181706):R.ffi.throwNonFunApp(L[51],_plus5,[anf_arg4151681,anf_arg4181706]);
};
try {
if(--R.GAS > 0) {
$z17101711 = $f17161717();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17161717,
"from":L[51]});
}
} catch($e17081709) {
if(R.isCont($e17081709)) {
var $ss17121713 = {"from":L[51],
"go":function(anf_arg4191718) {
return $Hanf_arg11311719(anf_arg4191718,_plus5);
}};
$e17081709.stack[R.EXN_STACKHEIGHT++] = $ss17121713;
}
if(R.isPyretException($e17081709)) {
$e17081709.pyretStack.push(L[51]);
}
throw $e17081709;
}
var $ret17141715 = $Hanf_arg11311719($z17101711,_plus5);
++R.GAS;
return $ret17141715;
};
var $Hanf_arg11311719 = function(anf_arg4191718,_plus5) {
var $z17221723 = D;
var $f17281729 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg4191718,(")")):R.ffi.throwNonFunApp(L[51],_plus5,[anf_arg4191718,(")")]);
};
try {
if(--R.GAS > 0) {
$z17221723 = $f17281729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17281729,
"from":L[51]});
}
} catch($e17201721) {
if(R.isCont($e17201721)) {
var $ss17241725 = {"from":L[51],
"go":function(anf_arg4201730) {
return $Hanf_arg11301731(anf_arg4201730,_plus5);
}};
$e17201721.stack[R.EXN_STACKHEIGHT++] = $ss17241725;
}
if(R.isPyretException($e17201721)) {
$e17201721.pyretStack.push(L[51]);
}
throw $e17201721;
}
var $ret17261727 = $Hanf_arg11301731($z17221723,_plus5);
++R.GAS;
return $ret17261727;
};
var $Hanf_arg11301731 = function(anf_arg4201730,_plus5) {
var $z17341735 = D;
var $f17401741 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg4201730):R.ffi.throwNonFunApp(L[51],_plus5,[("("),anf_arg4201730]);
};
try {
if(--R.GAS > 0) {
$z17341735 = $f17401741();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17401741,
"from":L[51]});
}
} catch($e17321733) {
if(R.isCont($e17321733)) {
var $ss17361737 = {"from":L[51],
"go":function(anf_arg4211742) {
return $Hanf_arg11291743(anf_arg4211742,_plus5);
}};
$e17321733.stack[R.EXN_STACKHEIGHT++] = $ss17361737;
}
if(R.isPyretException($e17321733)) {
$e17321733.pyretStack.push(L[51]);
}
throw $e17321733;
}
var $ret17381739 = $Hanf_arg11291743($z17341735,_plus5);
++R.GAS;
return $ret17381739;
};
var $Hanf_arg11291743 = function(anf_arg4211742,_plus5) {
var $z17461747 = D;
var $f17521753 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("arity-mismatch"),anf_arg4211742):R.ffi.throwNonFunApp(L[51],_plus5,[("arity-mismatch"),anf_arg4211742]);
};
try {
if(--R.GAS > 0) {
$z17461747 = $f17521753();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17521753,
"from":L[51]});
}
} catch($e17441745) {
if(R.isCont($e17441745)) {
var $ss17481749 = {"from":L[51],
"go":function(ann_DASH_check_DASH_temp4091754) {
return $Hann_DASH_check_DASH_temp11281755(ann_DASH_check_DASH_temp4091754);
}};
$e17441745.stack[R.EXN_STACKHEIGHT++] = $ss17481749;
}
if(R.isPyretException($e17441745)) {
$e17441745.pyretStack.push(L[51]);
}
throw $e17441745;
}
var $ret17501751 = $Hann_DASH_check_DASH_temp11281755($z17461747);
++R.GAS;
return $ret17501751;
};
var $Hann_DASH_check_DASH_temp11281755 = function(ann_DASH_check_DASH_temp4091754) {
return ann_DASH_check_DASH_temp4091754;
};
var $Hcont_tail_arg11261756 = function(cont_tail_arg4061757,if_helper3961758) {
if(--R.GAS > 0) {
$z17591760 = R.isFunction(if_helper3961758)?if_helper3961758.app(cont_tail_arg4061757):R.ffi.throwNonFunApp(L[51],if_helper3961758,[cont_tail_arg4061757]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3961758)?if_helper3961758.app(cont_tail_arg4061757):R.ffi.throwNonFunApp(L[51],if_helper3961758,[cont_tail_arg4061757]);
},
"from":L[51]});
}
++R.GAS;
return $z17591760;
};
var $Hcont_tail_arg11271761 = function(cont_tail_arg4011762,if_helper3961758) {
if(--R.GAS > 0) {
$z17631764 = R.isFunction(if_helper3961758)?if_helper3961758.app(cont_tail_arg4011762):R.ffi.throwNonFunApp(L[51],if_helper3961758,[cont_tail_arg4011762]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3961758)?if_helper3961758.app(cont_tail_arg4011762):R.ffi.throwNonFunApp(L[51],if_helper3961758,[cont_tail_arg4011762]);
},
"from":L[51]});
}
++R.GAS;
return $z17631764;
};
var $Hanf_arg11251765 = function(anf_arg3831766,self1081767,_plus5,torepr8) {
var $z17701771 = D;
var $f17761777 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3831766,(".  Either both arguments must be numbers, or the left operand must have a ")):R.ffi.throwNonFunApp(L[52],_plus5,[anf_arg3831766,(".  Either both arguments must be numbers, or the left operand must have a ")]);
};
try {
if(--R.GAS > 0) {
$z17701771 = $f17761777();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17761777,
"from":L[52]});
}
} catch($e17681769) {
if(R.isCont($e17681769)) {
var $ss17721773 = {"from":L[52],
"go":function(anf_arg3841778) {
return $Hanf_arg11241779(anf_arg3841778,self1081767,_plus5,torepr8);
}};
$e17681769.stack[R.EXN_STACKHEIGHT++] = $ss17721773;
}
if(R.isPyretException($e17681769)) {
$e17681769.pyretStack.push(L[52]);
}
throw $e17681769;
}
var $ret17741775 = $Hanf_arg11241779($z17701771,self1081767,_plus5,torepr8);
++R.GAS;
return $ret17741775;
};
var $Hanf_arg11241779 = function(anf_arg3841778,self1081767,_plus5,torepr8) {
var anf_arg3851790 = G(self1081767,"methodname",L[53]);
var $z17821783 = D;
var $f17881789 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3841778,anf_arg3851790):R.ffi.throwNonFunApp(L[52],_plus5,[anf_arg3841778,anf_arg3851790]);
};
try {
if(--R.GAS > 0) {
$z17821783 = $f17881789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17881789,
"from":L[52]});
}
} catch($e17801781) {
if(R.isCont($e17801781)) {
var $ss17841785 = {"from":L[52],
"go":function(anf_arg3861791) {
return $Hanf_arg11231792(anf_arg3861791,self1081767,_plus5,torepr8);
}};
$e17801781.stack[R.EXN_STACKHEIGHT++] = $ss17841785;
}
if(R.isPyretException($e17801781)) {
$e17801781.pyretStack.push(L[52]);
}
throw $e17801781;
}
var $ret17861787 = $Hanf_arg11231792($z17821783,self1081767,_plus5,torepr8);
++R.GAS;
return $ret17861787;
};
var $Hanf_arg11231792 = function(anf_arg3861791,self1081767,_plus5,torepr8) {
var $z17951796 = D;
var $f18011802 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3861791,(" method.  Got: \n")):R.ffi.throwNonFunApp(L[52],_plus5,[anf_arg3861791,(" method.  Got: \n")]);
};
try {
if(--R.GAS > 0) {
$z17951796 = $f18011802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18011802,
"from":L[52]});
}
} catch($e17931794) {
if(R.isCont($e17931794)) {
var $ss17971798 = {"from":L[52],
"go":function(anf_arg3871803) {
return $Hanf_arg11221804(anf_arg3871803,self1081767,_plus5,torepr8);
}};
$e17931794.stack[R.EXN_STACKHEIGHT++] = $ss17971798;
}
if(R.isPyretException($e17931794)) {
$e17931794.pyretStack.push(L[52]);
}
throw $e17931794;
}
var $ret17991800 = $Hanf_arg11221804($z17951796,self1081767,_plus5,torepr8);
++R.GAS;
return $ret17991800;
};
var $Hanf_arg11221804 = function(anf_arg3871803,self1081767,_plus5,torepr8) {
var anf_arg3881815 = G(self1081767,"val1",L[55]);
var $z18071808 = D;
var $f18131814 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3881815):R.ffi.throwNonFunApp(L[54],torepr8,[anf_arg3881815]);
};
try {
if(--R.GAS > 0) {
$z18071808 = $f18131814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18131814,
"from":L[54]});
}
} catch($e18051806) {
if(R.isCont($e18051806)) {
var $ss18091810 = {"from":L[54],
"go":function(anf_arg3891816) {
return $Hanf_arg11211817(anf_arg3891816,anf_arg3871803,self1081767,_plus5,torepr8);
}};
$e18051806.stack[R.EXN_STACKHEIGHT++] = $ss18091810;
}
if(R.isPyretException($e18051806)) {
$e18051806.pyretStack.push(L[54]);
}
throw $e18051806;
}
var $ret18111812 = $Hanf_arg11211817($z18071808,anf_arg3871803,self1081767,_plus5,torepr8);
++R.GAS;
return $ret18111812;
};
var $Hanf_arg11211817 = function(anf_arg3891816,anf_arg3871803,self1081767,_plus5,torepr8) {
var $z18201821 = D;
var $f18261827 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3871803,anf_arg3891816):R.ffi.throwNonFunApp(L[52],_plus5,[anf_arg3871803,anf_arg3891816]);
};
try {
if(--R.GAS > 0) {
$z18201821 = $f18261827();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18261827,
"from":L[52]});
}
} catch($e18181819) {
if(R.isCont($e18181819)) {
var $ss18221823 = {"from":L[52],
"go":function(anf_arg3901828) {
return $Hanf_arg11201829(anf_arg3901828,self1081767,_plus5,torepr8);
}};
$e18181819.stack[R.EXN_STACKHEIGHT++] = $ss18221823;
}
if(R.isPyretException($e18181819)) {
$e18181819.pyretStack.push(L[52]);
}
throw $e18181819;
}
var $ret18241825 = $Hanf_arg11201829($z18201821,self1081767,_plus5,torepr8);
++R.GAS;
return $ret18241825;
};
var $Hanf_arg11201829 = function(anf_arg3901828,self1081767,_plus5,torepr8) {
var $z18321833 = D;
var $f18381839 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3901828,("\nand \n")):R.ffi.throwNonFunApp(L[52],_plus5,[anf_arg3901828,("\nand \n")]);
};
try {
if(--R.GAS > 0) {
$z18321833 = $f18381839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18381839,
"from":L[52]});
}
} catch($e18301831) {
if(R.isCont($e18301831)) {
var $ss18341835 = {"from":L[52],
"go":function(anf_arg3911840) {
return $Hanf_arg11191841(anf_arg3911840,self1081767,_plus5,torepr8);
}};
$e18301831.stack[R.EXN_STACKHEIGHT++] = $ss18341835;
}
if(R.isPyretException($e18301831)) {
$e18301831.pyretStack.push(L[52]);
}
throw $e18301831;
}
var $ret18361837 = $Hanf_arg11191841($z18321833,self1081767,_plus5,torepr8);
++R.GAS;
return $ret18361837;
};
var $Hanf_arg11191841 = function(anf_arg3911840,self1081767,_plus5,torepr8) {
var anf_arg3921852 = G(self1081767,"val2",L[57]);
var $z18441845 = D;
var $f18501851 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3921852):R.ffi.throwNonFunApp(L[56],torepr8,[anf_arg3921852]);
};
try {
if(--R.GAS > 0) {
$z18441845 = $f18501851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18501851,
"from":L[56]});
}
} catch($e18421843) {
if(R.isCont($e18421843)) {
var $ss18461847 = {"from":L[56],
"go":function(anf_arg3931853) {
return $Hanf_arg11181854(anf_arg3931853,anf_arg3911840,_plus5);
}};
$e18421843.stack[R.EXN_STACKHEIGHT++] = $ss18461847;
}
if(R.isPyretException($e18421843)) {
$e18421843.pyretStack.push(L[56]);
}
throw $e18421843;
}
var $ret18481849 = $Hanf_arg11181854($z18441845,anf_arg3911840,_plus5);
++R.GAS;
return $ret18481849;
};
var $Hanf_arg11181854 = function(anf_arg3931853,anf_arg3911840,_plus5) {
var $z18571858 = D;
var $f18631864 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3911840,anf_arg3931853):R.ffi.throwNonFunApp(L[58],_plus5,[anf_arg3911840,anf_arg3931853]);
};
try {
if(--R.GAS > 0) {
$z18571858 = $f18631864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18631864,
"from":L[58]});
}
} catch($e18551856) {
if(R.isCont($e18551856)) {
var $ss18591860 = {"from":L[58],
"go":function(ann_DASH_check_DASH_temp3811865) {
return $Hann_DASH_check_DASH_temp11171866(ann_DASH_check_DASH_temp3811865);
}};
$e18551856.stack[R.EXN_STACKHEIGHT++] = $ss18591860;
}
if(R.isPyretException($e18551856)) {
$e18551856.pyretStack.push(L[58]);
}
throw $e18551856;
}
var $ret18611862 = $Hann_DASH_check_DASH_temp11171866($z18571858);
++R.GAS;
return $ret18611862;
};
var $Hann_DASH_check_DASH_temp11171866 = function(ann_DASH_check_DASH_temp3811865) {
return ann_DASH_check_DASH_temp3811865;
};
var $Hanf_arg11161867 = function(anf_arg3651868,self651869,_plus5,torepr8) {
var anf_arg3661880 = G(self651869,"val2",L[59]);
var $z18721873 = D;
var $f18781879 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3661880):R.ffi.throwNonFunApp(L[59],torepr8,[anf_arg3661880]);
};
try {
if(--R.GAS > 0) {
$z18721873 = $f18781879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18781879,
"from":L[59]});
}
} catch($e18701871) {
if(R.isCont($e18701871)) {
var $ss18741875 = {"from":L[59],
"go":function(anf_arg3671881) {
return $Hanf_arg11151882(anf_arg3671881,anf_arg3651868,self651869,_plus5,torepr8);
}};
$e18701871.stack[R.EXN_STACKHEIGHT++] = $ss18741875;
}
if(R.isPyretException($e18701871)) {
$e18701871.pyretStack.push(L[59]);
}
throw $e18701871;
}
var $ret18761877 = $Hanf_arg11151882($z18721873,anf_arg3651868,self651869,_plus5,torepr8);
++R.GAS;
return $ret18761877;
};
var $Hanf_arg11151882 = function(anf_arg3671881,anf_arg3651868,self651869,_plus5,torepr8) {
var $z18851886 = D;
var $f18911892 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg3671881):R.ffi.throwNonFunApp(L[59],_plus5,[(", "),anf_arg3671881]);
};
try {
if(--R.GAS > 0) {
$z18851886 = $f18911892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18911892,
"from":L[59]});
}
} catch($e18831884) {
if(R.isCont($e18831884)) {
var $ss18871888 = {"from":L[59],
"go":function(anf_arg3681893) {
return $Hanf_arg11141894(anf_arg3681893,anf_arg3651868,self651869,_plus5,torepr8);
}};
$e18831884.stack[R.EXN_STACKHEIGHT++] = $ss18871888;
}
if(R.isPyretException($e18831884)) {
$e18831884.pyretStack.push(L[59]);
}
throw $e18831884;
}
var $ret18891890 = $Hanf_arg11141894($z18851886,anf_arg3651868,self651869,_plus5,torepr8);
++R.GAS;
return $ret18891890;
};
var $Hanf_arg11141894 = function(anf_arg3681893,anf_arg3651868,self651869,_plus5,torepr8) {
var $z18971898 = D;
var $f19031904 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3651868,anf_arg3681893):R.ffi.throwNonFunApp(L[59],_plus5,[anf_arg3651868,anf_arg3681893]);
};
try {
if(--R.GAS > 0) {
$z18971898 = $f19031904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19031904,
"from":L[59]});
}
} catch($e18951896) {
if(R.isCont($e18951896)) {
var $ss18991900 = {"from":L[59],
"go":function(anf_arg3691905) {
return $Hanf_arg11131906(anf_arg3691905,self651869,_plus5,torepr8);
}};
$e18951896.stack[R.EXN_STACKHEIGHT++] = $ss18991900;
}
if(R.isPyretException($e18951896)) {
$e18951896.pyretStack.push(L[59]);
}
throw $e18951896;
}
var $ret19011902 = $Hanf_arg11131906($z18971898,self651869,_plus5,torepr8);
++R.GAS;
return $ret19011902;
};
var $Hanf_arg11131906 = function(anf_arg3691905,self651869,_plus5,torepr8) {
var anf_arg3701917 = G(self651869,"opname",L[59]);
var $z19091910 = D;
var $f19151916 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3701917):R.ffi.throwNonFunApp(L[59],torepr8,[anf_arg3701917]);
};
try {
if(--R.GAS > 0) {
$z19091910 = $f19151916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19151916,
"from":L[59]});
}
} catch($e19071908) {
if(R.isCont($e19071908)) {
var $ss19111912 = {"from":L[59],
"go":function(anf_arg3711918) {
return $Hanf_arg11121919(anf_arg3711918,anf_arg3691905,self651869,_plus5,torepr8);
}};
$e19071908.stack[R.EXN_STACKHEIGHT++] = $ss19111912;
}
if(R.isPyretException($e19071908)) {
$e19071908.pyretStack.push(L[59]);
}
throw $e19071908;
}
var $ret19131914 = $Hanf_arg11121919($z19091910,anf_arg3691905,self651869,_plus5,torepr8);
++R.GAS;
return $ret19131914;
};
var $Hanf_arg11121919 = function(anf_arg3711918,anf_arg3691905,self651869,_plus5,torepr8) {
var $z19221923 = D;
var $f19281929 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg3711918):R.ffi.throwNonFunApp(L[59],_plus5,[(", "),anf_arg3711918]);
};
try {
if(--R.GAS > 0) {
$z19221923 = $f19281929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19281929,
"from":L[59]});
}
} catch($e19201921) {
if(R.isCont($e19201921)) {
var $ss19241925 = {"from":L[59],
"go":function(anf_arg3721930) {
return $Hanf_arg11111931(anf_arg3721930,anf_arg3691905,self651869,_plus5,torepr8);
}};
$e19201921.stack[R.EXN_STACKHEIGHT++] = $ss19241925;
}
if(R.isPyretException($e19201921)) {
$e19201921.pyretStack.push(L[59]);
}
throw $e19201921;
}
var $ret19261927 = $Hanf_arg11111931($z19221923,anf_arg3691905,self651869,_plus5,torepr8);
++R.GAS;
return $ret19261927;
};
var $Hanf_arg11111931 = function(anf_arg3721930,anf_arg3691905,self651869,_plus5,torepr8) {
var $z19341935 = D;
var $f19401941 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3691905,anf_arg3721930):R.ffi.throwNonFunApp(L[59],_plus5,[anf_arg3691905,anf_arg3721930]);
};
try {
if(--R.GAS > 0) {
$z19341935 = $f19401941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19401941,
"from":L[59]});
}
} catch($e19321933) {
if(R.isCont($e19321933)) {
var $ss19361937 = {"from":L[59],
"go":function(anf_arg3731942) {
return $Hanf_arg11101943(anf_arg3731942,self651869,_plus5,torepr8);
}};
$e19321933.stack[R.EXN_STACKHEIGHT++] = $ss19361937;
}
if(R.isPyretException($e19321933)) {
$e19321933.pyretStack.push(L[59]);
}
throw $e19321933;
}
var $ret19381939 = $Hanf_arg11101943($z19341935,self651869,_plus5,torepr8);
++R.GAS;
return $ret19381939;
};
var $Hanf_arg11101943 = function(anf_arg3731942,self651869,_plus5,torepr8) {
var anf_arg3741954 = G(self651869,"methodname",L[59]);
var $z19461947 = D;
var $f19521953 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3741954):R.ffi.throwNonFunApp(L[59],torepr8,[anf_arg3741954]);
};
try {
if(--R.GAS > 0) {
$z19461947 = $f19521953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19521953,
"from":L[59]});
}
} catch($e19441945) {
if(R.isCont($e19441945)) {
var $ss19481949 = {"from":L[59],
"go":function(anf_arg3751955) {
return $Hanf_arg11091956(anf_arg3751955,anf_arg3731942,_plus5);
}};
$e19441945.stack[R.EXN_STACKHEIGHT++] = $ss19481949;
}
if(R.isPyretException($e19441945)) {
$e19441945.pyretStack.push(L[59]);
}
throw $e19441945;
}
var $ret19501951 = $Hanf_arg11091956($z19461947,anf_arg3731942,_plus5);
++R.GAS;
return $ret19501951;
};
var $Hanf_arg11091956 = function(anf_arg3751955,anf_arg3731942,_plus5) {
var $z19591960 = D;
var $f19651966 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg3751955):R.ffi.throwNonFunApp(L[59],_plus5,[(", "),anf_arg3751955]);
};
try {
if(--R.GAS > 0) {
$z19591960 = $f19651966();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19651966,
"from":L[59]});
}
} catch($e19571958) {
if(R.isCont($e19571958)) {
var $ss19611962 = {"from":L[59],
"go":function(anf_arg3761967) {
return $Hanf_arg11081968(anf_arg3761967,anf_arg3731942,_plus5);
}};
$e19571958.stack[R.EXN_STACKHEIGHT++] = $ss19611962;
}
if(R.isPyretException($e19571958)) {
$e19571958.pyretStack.push(L[59]);
}
throw $e19571958;
}
var $ret19631964 = $Hanf_arg11081968($z19591960,anf_arg3731942,_plus5);
++R.GAS;
return $ret19631964;
};
var $Hanf_arg11081968 = function(anf_arg3761967,anf_arg3731942,_plus5) {
var $z19711972 = D;
var $f19771978 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3731942,anf_arg3761967):R.ffi.throwNonFunApp(L[59],_plus5,[anf_arg3731942,anf_arg3761967]);
};
try {
if(--R.GAS > 0) {
$z19711972 = $f19771978();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19771978,
"from":L[59]});
}
} catch($e19691970) {
if(R.isCont($e19691970)) {
var $ss19731974 = {"from":L[59],
"go":function(anf_arg3771979) {
return $Hanf_arg11071980(anf_arg3771979,_plus5);
}};
$e19691970.stack[R.EXN_STACKHEIGHT++] = $ss19731974;
}
if(R.isPyretException($e19691970)) {
$e19691970.pyretStack.push(L[59]);
}
throw $e19691970;
}
var $ret19751976 = $Hanf_arg11071980($z19711972,_plus5);
++R.GAS;
return $ret19751976;
};
var $Hanf_arg11071980 = function(anf_arg3771979,_plus5) {
var $z19831984 = D;
var $f19891990 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3771979,(")")):R.ffi.throwNonFunApp(L[59],_plus5,[anf_arg3771979,(")")]);
};
try {
if(--R.GAS > 0) {
$z19831984 = $f19891990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19891990,
"from":L[59]});
}
} catch($e19811982) {
if(R.isCont($e19811982)) {
var $ss19851986 = {"from":L[59],
"go":function(anf_arg3781991) {
return $Hanf_arg11061992(anf_arg3781991,_plus5);
}};
$e19811982.stack[R.EXN_STACKHEIGHT++] = $ss19851986;
}
if(R.isPyretException($e19811982)) {
$e19811982.pyretStack.push(L[59]);
}
throw $e19811982;
}
var $ret19871988 = $Hanf_arg11061992($z19831984,_plus5);
++R.GAS;
return $ret19871988;
};
var $Hanf_arg11061992 = function(anf_arg3781991,_plus5) {
var $z19951996 = D;
var $f20012002 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg3781991):R.ffi.throwNonFunApp(L[59],_plus5,[("("),anf_arg3781991]);
};
try {
if(--R.GAS > 0) {
$z19951996 = $f20012002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20012002,
"from":L[59]});
}
} catch($e19931994) {
if(R.isCont($e19931994)) {
var $ss19971998 = {"from":L[59],
"go":function(anf_arg3792003) {
return $Hanf_arg11052004(anf_arg3792003,_plus5);
}};
$e19931994.stack[R.EXN_STACKHEIGHT++] = $ss19971998;
}
if(R.isPyretException($e19931994)) {
$e19931994.pyretStack.push(L[59]);
}
throw $e19931994;
}
var $ret19992000 = $Hanf_arg11052004($z19951996,_plus5);
++R.GAS;
return $ret19992000;
};
var $Hanf_arg11052004 = function(anf_arg3792003,_plus5) {
var $z20072008 = D;
var $f20132014 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("numeric-binop-error"),anf_arg3792003):R.ffi.throwNonFunApp(L[59],_plus5,[("numeric-binop-error"),anf_arg3792003]);
};
try {
if(--R.GAS > 0) {
$z20072008 = $f20132014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20132014,
"from":L[59]});
}
} catch($e20052006) {
if(R.isCont($e20052006)) {
var $ss20092010 = {"from":L[59],
"go":function(ann_DASH_check_DASH_temp3632015) {
return $Hann_DASH_check_DASH_temp11042016(ann_DASH_check_DASH_temp3632015);
}};
$e20052006.stack[R.EXN_STACKHEIGHT++] = $ss20092010;
}
if(R.isPyretException($e20052006)) {
$e20052006.pyretStack.push(L[59]);
}
throw $e20052006;
}
var $ret20112012 = $Hann_DASH_check_DASH_temp11042016($z20072008);
++R.GAS;
return $ret20112012;
};
var $Hann_DASH_check_DASH_temp11042016 = function(ann_DASH_check_DASH_temp3632015) {
return ann_DASH_check_DASH_temp3632015;
};
var $Hcont_tail_arg11022017 = function(cont_tail_arg3602018,if_helper3492019) {
if(--R.GAS > 0) {
$z20202021 = R.isFunction(if_helper3492019)?if_helper3492019.app(cont_tail_arg3602018):R.ffi.throwNonFunApp(L[59],if_helper3492019,[cont_tail_arg3602018]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3492019)?if_helper3492019.app(cont_tail_arg3602018):R.ffi.throwNonFunApp(L[59],if_helper3492019,[cont_tail_arg3602018]);
},
"from":L[59]});
}
++R.GAS;
return $z20202021;
};
var $Hcont_tail_arg11032022 = function(cont_tail_arg3542023,if_helper3492019) {
if(--R.GAS > 0) {
$z20242025 = R.isFunction(if_helper3492019)?if_helper3492019.app(cont_tail_arg3542023):R.ffi.throwNonFunApp(L[59],if_helper3492019,[cont_tail_arg3542023]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3492019)?if_helper3492019.app(cont_tail_arg3542023):R.ffi.throwNonFunApp(L[59],if_helper3492019,[cont_tail_arg3542023]);
},
"from":L[59]});
}
++R.GAS;
return $z20242025;
};
var $Hanf_arg11012026 = function(anf_arg3422027,self1032028,_plus5,torepr8) {
var $z20312032 = D;
var $f20372038 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: Invalid use of +.  Either both arguments must be strings, both must be numbers, or the left operand must have a _plus method. Got: \n"),anf_arg3422027):R.ffi.throwNonFunApp(L[60],_plus5,[("Error: Invalid use of +.  Either both arguments must be strings, both must be numbers, or the left operand must have a _plus method. Got: \n"),anf_arg3422027]);
};
try {
if(--R.GAS > 0) {
$z20312032 = $f20372038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20372038,
"from":L[60]});
}
} catch($e20292030) {
if(R.isCont($e20292030)) {
var $ss20332034 = {"from":L[60],
"go":function(anf_arg3432039) {
return $Hanf_arg11002040(anf_arg3432039,self1032028,_plus5,torepr8);
}};
$e20292030.stack[R.EXN_STACKHEIGHT++] = $ss20332034;
}
if(R.isPyretException($e20292030)) {
$e20292030.pyretStack.push(L[60]);
}
throw $e20292030;
}
var $ret20352036 = $Hanf_arg11002040($z20312032,self1032028,_plus5,torepr8);
++R.GAS;
return $ret20352036;
};
var $Hanf_arg11002040 = function(anf_arg3432039,self1032028,_plus5,torepr8) {
var $z20432044 = D;
var $f20492050 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3432039,("\nand \n")):R.ffi.throwNonFunApp(L[60],_plus5,[anf_arg3432039,("\nand \n")]);
};
try {
if(--R.GAS > 0) {
$z20432044 = $f20492050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20492050,
"from":L[60]});
}
} catch($e20412042) {
if(R.isCont($e20412042)) {
var $ss20452046 = {"from":L[60],
"go":function(anf_arg3442051) {
return $Hanf_arg10992052(anf_arg3442051,self1032028,_plus5,torepr8);
}};
$e20412042.stack[R.EXN_STACKHEIGHT++] = $ss20452046;
}
if(R.isPyretException($e20412042)) {
$e20412042.pyretStack.push(L[60]);
}
throw $e20412042;
}
var $ret20472048 = $Hanf_arg10992052($z20432044,self1032028,_plus5,torepr8);
++R.GAS;
return $ret20472048;
};
var $Hanf_arg10992052 = function(anf_arg3442051,self1032028,_plus5,torepr8) {
var anf_arg3452063 = G(self1032028,"val2",L[62]);
var $z20552056 = D;
var $f20612062 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3452063):R.ffi.throwNonFunApp(L[61],torepr8,[anf_arg3452063]);
};
try {
if(--R.GAS > 0) {
$z20552056 = $f20612062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20612062,
"from":L[61]});
}
} catch($e20532054) {
if(R.isCont($e20532054)) {
var $ss20572058 = {"from":L[61],
"go":function(anf_arg3462064) {
return $Hanf_arg10982065(anf_arg3462064,anf_arg3442051,_plus5);
}};
$e20532054.stack[R.EXN_STACKHEIGHT++] = $ss20572058;
}
if(R.isPyretException($e20532054)) {
$e20532054.pyretStack.push(L[61]);
}
throw $e20532054;
}
var $ret20592060 = $Hanf_arg10982065($z20552056,anf_arg3442051,_plus5);
++R.GAS;
return $ret20592060;
};
var $Hanf_arg10982065 = function(anf_arg3462064,anf_arg3442051,_plus5) {
var $z20682069 = D;
var $f20742075 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3442051,anf_arg3462064):R.ffi.throwNonFunApp(L[63],_plus5,[anf_arg3442051,anf_arg3462064]);
};
try {
if(--R.GAS > 0) {
$z20682069 = $f20742075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20742075,
"from":L[63]});
}
} catch($e20662067) {
if(R.isCont($e20662067)) {
var $ss20702071 = {"from":L[63],
"go":function(ann_DASH_check_DASH_temp3402076) {
return $Hann_DASH_check_DASH_temp10972077(ann_DASH_check_DASH_temp3402076);
}};
$e20662067.stack[R.EXN_STACKHEIGHT++] = $ss20702071;
}
if(R.isPyretException($e20662067)) {
$e20662067.pyretStack.push(L[63]);
}
throw $e20662067;
}
var $ret20722073 = $Hann_DASH_check_DASH_temp10972077($z20682069);
++R.GAS;
return $ret20722073;
};
var $Hann_DASH_check_DASH_temp10972077 = function(ann_DASH_check_DASH_temp3402076) {
return ann_DASH_check_DASH_temp3402076;
};
var $Hanf_arg10962078 = function(anf_arg3322079,self592080,_plus5,torepr8) {
var anf_arg3332091 = G(self592080,"val2",L[64]);
var $z20832084 = D;
var $f20892090 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3332091):R.ffi.throwNonFunApp(L[64],torepr8,[anf_arg3332091]);
};
try {
if(--R.GAS > 0) {
$z20832084 = $f20892090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20892090,
"from":L[64]});
}
} catch($e20812082) {
if(R.isCont($e20812082)) {
var $ss20852086 = {"from":L[64],
"go":function(anf_arg3342092) {
return $Hanf_arg10952093(anf_arg3342092,anf_arg3322079,_plus5);
}};
$e20812082.stack[R.EXN_STACKHEIGHT++] = $ss20852086;
}
if(R.isPyretException($e20812082)) {
$e20812082.pyretStack.push(L[64]);
}
throw $e20812082;
}
var $ret20872088 = $Hanf_arg10952093($z20832084,anf_arg3322079,_plus5);
++R.GAS;
return $ret20872088;
};
var $Hanf_arg10952093 = function(anf_arg3342092,anf_arg3322079,_plus5) {
var $z20962097 = D;
var $f21022103 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg3342092):R.ffi.throwNonFunApp(L[64],_plus5,[(", "),anf_arg3342092]);
};
try {
if(--R.GAS > 0) {
$z20962097 = $f21022103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21022103,
"from":L[64]});
}
} catch($e20942095) {
if(R.isCont($e20942095)) {
var $ss20982099 = {"from":L[64],
"go":function(anf_arg3352104) {
return $Hanf_arg10942105(anf_arg3352104,anf_arg3322079,_plus5);
}};
$e20942095.stack[R.EXN_STACKHEIGHT++] = $ss20982099;
}
if(R.isPyretException($e20942095)) {
$e20942095.pyretStack.push(L[64]);
}
throw $e20942095;
}
var $ret21002101 = $Hanf_arg10942105($z20962097,anf_arg3322079,_plus5);
++R.GAS;
return $ret21002101;
};
var $Hanf_arg10942105 = function(anf_arg3352104,anf_arg3322079,_plus5) {
var $z21082109 = D;
var $f21142115 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3322079,anf_arg3352104):R.ffi.throwNonFunApp(L[64],_plus5,[anf_arg3322079,anf_arg3352104]);
};
try {
if(--R.GAS > 0) {
$z21082109 = $f21142115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21142115,
"from":L[64]});
}
} catch($e21062107) {
if(R.isCont($e21062107)) {
var $ss21102111 = {"from":L[64],
"go":function(anf_arg3362116) {
return $Hanf_arg10932117(anf_arg3362116,_plus5);
}};
$e21062107.stack[R.EXN_STACKHEIGHT++] = $ss21102111;
}
if(R.isPyretException($e21062107)) {
$e21062107.pyretStack.push(L[64]);
}
throw $e21062107;
}
var $ret21122113 = $Hanf_arg10932117($z21082109,_plus5);
++R.GAS;
return $ret21122113;
};
var $Hanf_arg10932117 = function(anf_arg3362116,_plus5) {
var $z21202121 = D;
var $f21262127 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3362116,(")")):R.ffi.throwNonFunApp(L[64],_plus5,[anf_arg3362116,(")")]);
};
try {
if(--R.GAS > 0) {
$z21202121 = $f21262127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21262127,
"from":L[64]});
}
} catch($e21182119) {
if(R.isCont($e21182119)) {
var $ss21222123 = {"from":L[64],
"go":function(anf_arg3372128) {
return $Hanf_arg10922129(anf_arg3372128,_plus5);
}};
$e21182119.stack[R.EXN_STACKHEIGHT++] = $ss21222123;
}
if(R.isPyretException($e21182119)) {
$e21182119.pyretStack.push(L[64]);
}
throw $e21182119;
}
var $ret21242125 = $Hanf_arg10922129($z21202121,_plus5);
++R.GAS;
return $ret21242125;
};
var $Hanf_arg10922129 = function(anf_arg3372128,_plus5) {
var $z21322133 = D;
var $f21382139 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg3372128):R.ffi.throwNonFunApp(L[64],_plus5,[("("),anf_arg3372128]);
};
try {
if(--R.GAS > 0) {
$z21322133 = $f21382139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21382139,
"from":L[64]});
}
} catch($e21302131) {
if(R.isCont($e21302131)) {
var $ss21342135 = {"from":L[64],
"go":function(anf_arg3382140) {
return $Hanf_arg10912141(anf_arg3382140,_plus5);
}};
$e21302131.stack[R.EXN_STACKHEIGHT++] = $ss21342135;
}
if(R.isPyretException($e21302131)) {
$e21302131.pyretStack.push(L[64]);
}
throw $e21302131;
}
var $ret21362137 = $Hanf_arg10912141($z21322133,_plus5);
++R.GAS;
return $ret21362137;
};
var $Hanf_arg10912141 = function(anf_arg3382140,_plus5) {
var $z21442145 = D;
var $f21502151 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("plus-error"),anf_arg3382140):R.ffi.throwNonFunApp(L[64],_plus5,[("plus-error"),anf_arg3382140]);
};
try {
if(--R.GAS > 0) {
$z21442145 = $f21502151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21502151,
"from":L[64]});
}
} catch($e21422143) {
if(R.isCont($e21422143)) {
var $ss21462147 = {"from":L[64],
"go":function(ann_DASH_check_DASH_temp3302152) {
return $Hann_DASH_check_DASH_temp10902153(ann_DASH_check_DASH_temp3302152);
}};
$e21422143.stack[R.EXN_STACKHEIGHT++] = $ss21462147;
}
if(R.isPyretException($e21422143)) {
$e21422143.pyretStack.push(L[64]);
}
throw $e21422143;
}
var $ret21482149 = $Hann_DASH_check_DASH_temp10902153($z21442145);
++R.GAS;
return $ret21482149;
};
var $Hann_DASH_check_DASH_temp10902153 = function(ann_DASH_check_DASH_temp3302152) {
return ann_DASH_check_DASH_temp3302152;
};
var $Hcont_tail_arg10882154 = function(cont_tail_arg3272155,if_helper3182156) {
if(--R.GAS > 0) {
$z21572158 = R.isFunction(if_helper3182156)?if_helper3182156.app(cont_tail_arg3272155):R.ffi.throwNonFunApp(L[64],if_helper3182156,[cont_tail_arg3272155]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3182156)?if_helper3182156.app(cont_tail_arg3272155):R.ffi.throwNonFunApp(L[64],if_helper3182156,[cont_tail_arg3272155]);
},
"from":L[64]});
}
++R.GAS;
return $z21572158;
};
var $Hcont_tail_arg10892159 = function(cont_tail_arg3232160,if_helper3182156) {
if(--R.GAS > 0) {
$z21612162 = R.isFunction(if_helper3182156)?if_helper3182156.app(cont_tail_arg3232160):R.ffi.throwNonFunApp(L[64],if_helper3182156,[cont_tail_arg3232160]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3182156)?if_helper3182156.app(cont_tail_arg3232160):R.ffi.throwNonFunApp(L[64],if_helper3182156,[cont_tail_arg3232160]);
},
"from":L[64]});
}
++R.GAS;
return $z21612162;
};
var $Hanf_arg10872163 = function(anf_arg3072164,self1002165,_plus5,torepr8) {
var $z21682169 = D;
var $f21742175 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: expected a number between "),anf_arg3072164):R.ffi.throwNonFunApp(L[65],_plus5,[("Error: expected a number between "),anf_arg3072164]);
};
try {
if(--R.GAS > 0) {
$z21682169 = $f21742175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21742175,
"from":L[65]});
}
} catch($e21662167) {
if(R.isCont($e21662167)) {
var $ss21702171 = {"from":L[65],
"go":function(anf_arg3082176) {
return $Hanf_arg10862177(anf_arg3082176,self1002165,_plus5,torepr8);
}};
$e21662167.stack[R.EXN_STACKHEIGHT++] = $ss21702171;
}
if(R.isPyretException($e21662167)) {
$e21662167.pyretStack.push(L[65]);
}
throw $e21662167;
}
var $ret21722173 = $Hanf_arg10862177($z21682169,self1002165,_plus5,torepr8);
++R.GAS;
return $ret21722173;
};
var $Hanf_arg10862177 = function(anf_arg3082176,self1002165,_plus5,torepr8) {
var $z21802181 = D;
var $f21862187 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3082176,(" and ")):R.ffi.throwNonFunApp(L[65],_plus5,[anf_arg3082176,(" and ")]);
};
try {
if(--R.GAS > 0) {
$z21802181 = $f21862187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21862187,
"from":L[65]});
}
} catch($e21782179) {
if(R.isCont($e21782179)) {
var $ss21822183 = {"from":L[65],
"go":function(anf_arg3092188) {
return $Hanf_arg10852189(anf_arg3092188,self1002165,_plus5,torepr8);
}};
$e21782179.stack[R.EXN_STACKHEIGHT++] = $ss21822183;
}
if(R.isPyretException($e21782179)) {
$e21782179.pyretStack.push(L[65]);
}
throw $e21782179;
}
var $ret21842185 = $Hanf_arg10852189($z21802181,self1002165,_plus5,torepr8);
++R.GAS;
return $ret21842185;
};
var $Hanf_arg10852189 = function(anf_arg3092188,self1002165,_plus5,torepr8) {
var anf_arg3102200 = G(self1002165,"high",L[67]);
var $z21922193 = D;
var $f21982199 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3102200):R.ffi.throwNonFunApp(L[66],torepr8,[anf_arg3102200]);
};
try {
if(--R.GAS > 0) {
$z21922193 = $f21982199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21982199,
"from":L[66]});
}
} catch($e21902191) {
if(R.isCont($e21902191)) {
var $ss21942195 = {"from":L[66],
"go":function(anf_arg3112201) {
return $Hanf_arg10842202(anf_arg3112201,anf_arg3092188,self1002165,_plus5,torepr8);
}};
$e21902191.stack[R.EXN_STACKHEIGHT++] = $ss21942195;
}
if(R.isPyretException($e21902191)) {
$e21902191.pyretStack.push(L[66]);
}
throw $e21902191;
}
var $ret21962197 = $Hanf_arg10842202($z21922193,anf_arg3092188,self1002165,_plus5,torepr8);
++R.GAS;
return $ret21962197;
};
var $Hanf_arg10842202 = function(anf_arg3112201,anf_arg3092188,self1002165,_plus5,torepr8) {
var $z22052206 = D;
var $f22112212 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3092188,anf_arg3112201):R.ffi.throwNonFunApp(L[65],_plus5,[anf_arg3092188,anf_arg3112201]);
};
try {
if(--R.GAS > 0) {
$z22052206 = $f22112212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22112212,
"from":L[65]});
}
} catch($e22032204) {
if(R.isCont($e22032204)) {
var $ss22072208 = {"from":L[65],
"go":function(anf_arg3122213) {
return $Hanf_arg10832214(anf_arg3122213,self1002165,_plus5,torepr8);
}};
$e22032204.stack[R.EXN_STACKHEIGHT++] = $ss22072208;
}
if(R.isPyretException($e22032204)) {
$e22032204.pyretStack.push(L[65]);
}
throw $e22032204;
}
var $ret22092210 = $Hanf_arg10832214($z22052206,self1002165,_plus5,torepr8);
++R.GAS;
return $ret22092210;
};
var $Hanf_arg10832214 = function(anf_arg3122213,self1002165,_plus5,torepr8) {
var $z22172218 = D;
var $f22232224 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3122213,(", but got ")):R.ffi.throwNonFunApp(L[65],_plus5,[anf_arg3122213,(", but got ")]);
};
try {
if(--R.GAS > 0) {
$z22172218 = $f22232224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22232224,
"from":L[65]});
}
} catch($e22152216) {
if(R.isCont($e22152216)) {
var $ss22192220 = {"from":L[65],
"go":function(anf_arg3132225) {
return $Hanf_arg10822226(anf_arg3132225,self1002165,_plus5,torepr8);
}};
$e22152216.stack[R.EXN_STACKHEIGHT++] = $ss22192220;
}
if(R.isPyretException($e22152216)) {
$e22152216.pyretStack.push(L[65]);
}
throw $e22152216;
}
var $ret22212222 = $Hanf_arg10822226($z22172218,self1002165,_plus5,torepr8);
++R.GAS;
return $ret22212222;
};
var $Hanf_arg10822226 = function(anf_arg3132225,self1002165,_plus5,torepr8) {
var anf_arg3142237 = G(self1002165,"val",L[69]);
var $z22292230 = D;
var $f22352236 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3142237):R.ffi.throwNonFunApp(L[68],torepr8,[anf_arg3142237]);
};
try {
if(--R.GAS > 0) {
$z22292230 = $f22352236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22352236,
"from":L[68]});
}
} catch($e22272228) {
if(R.isCont($e22272228)) {
var $ss22312232 = {"from":L[68],
"go":function(anf_arg3152238) {
return $Hanf_arg10812239(anf_arg3152238,anf_arg3132225,_plus5);
}};
$e22272228.stack[R.EXN_STACKHEIGHT++] = $ss22312232;
}
if(R.isPyretException($e22272228)) {
$e22272228.pyretStack.push(L[68]);
}
throw $e22272228;
}
var $ret22332234 = $Hanf_arg10812239($z22292230,anf_arg3132225,_plus5);
++R.GAS;
return $ret22332234;
};
var $Hanf_arg10812239 = function(anf_arg3152238,anf_arg3132225,_plus5) {
var $z22422243 = D;
var $f22482249 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3132225,anf_arg3152238):R.ffi.throwNonFunApp(L[70],_plus5,[anf_arg3132225,anf_arg3152238]);
};
try {
if(--R.GAS > 0) {
$z22422243 = $f22482249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22482249,
"from":L[70]});
}
} catch($e22402241) {
if(R.isCont($e22402241)) {
var $ss22442245 = {"from":L[70],
"go":function(ann_DASH_check_DASH_temp3052250) {
return $Hann_DASH_check_DASH_temp10802251(ann_DASH_check_DASH_temp3052250);
}};
$e22402241.stack[R.EXN_STACKHEIGHT++] = $ss22442245;
}
if(R.isPyretException($e22402241)) {
$e22402241.pyretStack.push(L[70]);
}
throw $e22402241;
}
var $ret22462247 = $Hann_DASH_check_DASH_temp10802251($z22422243);
++R.GAS;
return $ret22462247;
};
var $Hann_DASH_check_DASH_temp10802251 = function(ann_DASH_check_DASH_temp3052250) {
return ann_DASH_check_DASH_temp3052250;
};
var $Hanf_arg10792252 = function(anf_arg2932253,self532254,_plus5,torepr8) {
var anf_arg2942265 = G(self532254,"low",L[71]);
var $z22572258 = D;
var $f22632264 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2942265):R.ffi.throwNonFunApp(L[71],torepr8,[anf_arg2942265]);
};
try {
if(--R.GAS > 0) {
$z22572258 = $f22632264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22632264,
"from":L[71]});
}
} catch($e22552256) {
if(R.isCont($e22552256)) {
var $ss22592260 = {"from":L[71],
"go":function(anf_arg2952266) {
return $Hanf_arg10782267(anf_arg2952266,anf_arg2932253,self532254,_plus5,torepr8);
}};
$e22552256.stack[R.EXN_STACKHEIGHT++] = $ss22592260;
}
if(R.isPyretException($e22552256)) {
$e22552256.pyretStack.push(L[71]);
}
throw $e22552256;
}
var $ret22612262 = $Hanf_arg10782267($z22572258,anf_arg2932253,self532254,_plus5,torepr8);
++R.GAS;
return $ret22612262;
};
var $Hanf_arg10782267 = function(anf_arg2952266,anf_arg2932253,self532254,_plus5,torepr8) {
var $z22702271 = D;
var $f22762277 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg2952266):R.ffi.throwNonFunApp(L[71],_plus5,[(", "),anf_arg2952266]);
};
try {
if(--R.GAS > 0) {
$z22702271 = $f22762277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22762277,
"from":L[71]});
}
} catch($e22682269) {
if(R.isCont($e22682269)) {
var $ss22722273 = {"from":L[71],
"go":function(anf_arg2962278) {
return $Hanf_arg10772279(anf_arg2962278,anf_arg2932253,self532254,_plus5,torepr8);
}};
$e22682269.stack[R.EXN_STACKHEIGHT++] = $ss22722273;
}
if(R.isPyretException($e22682269)) {
$e22682269.pyretStack.push(L[71]);
}
throw $e22682269;
}
var $ret22742275 = $Hanf_arg10772279($z22702271,anf_arg2932253,self532254,_plus5,torepr8);
++R.GAS;
return $ret22742275;
};
var $Hanf_arg10772279 = function(anf_arg2962278,anf_arg2932253,self532254,_plus5,torepr8) {
var $z22822283 = D;
var $f22882289 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2932253,anf_arg2962278):R.ffi.throwNonFunApp(L[71],_plus5,[anf_arg2932253,anf_arg2962278]);
};
try {
if(--R.GAS > 0) {
$z22822283 = $f22882289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22882289,
"from":L[71]});
}
} catch($e22802281) {
if(R.isCont($e22802281)) {
var $ss22842285 = {"from":L[71],
"go":function(anf_arg2972290) {
return $Hanf_arg10762291(anf_arg2972290,self532254,_plus5,torepr8);
}};
$e22802281.stack[R.EXN_STACKHEIGHT++] = $ss22842285;
}
if(R.isPyretException($e22802281)) {
$e22802281.pyretStack.push(L[71]);
}
throw $e22802281;
}
var $ret22862287 = $Hanf_arg10762291($z22822283,self532254,_plus5,torepr8);
++R.GAS;
return $ret22862287;
};
var $Hanf_arg10762291 = function(anf_arg2972290,self532254,_plus5,torepr8) {
var anf_arg2982302 = G(self532254,"high",L[71]);
var $z22942295 = D;
var $f23002301 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2982302):R.ffi.throwNonFunApp(L[71],torepr8,[anf_arg2982302]);
};
try {
if(--R.GAS > 0) {
$z22942295 = $f23002301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23002301,
"from":L[71]});
}
} catch($e22922293) {
if(R.isCont($e22922293)) {
var $ss22962297 = {"from":L[71],
"go":function(anf_arg2992303) {
return $Hanf_arg10752304(anf_arg2992303,anf_arg2972290,_plus5);
}};
$e22922293.stack[R.EXN_STACKHEIGHT++] = $ss22962297;
}
if(R.isPyretException($e22922293)) {
$e22922293.pyretStack.push(L[71]);
}
throw $e22922293;
}
var $ret22982299 = $Hanf_arg10752304($z22942295,anf_arg2972290,_plus5);
++R.GAS;
return $ret22982299;
};
var $Hanf_arg10752304 = function(anf_arg2992303,anf_arg2972290,_plus5) {
var $z23072308 = D;
var $f23132314 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg2992303):R.ffi.throwNonFunApp(L[71],_plus5,[(", "),anf_arg2992303]);
};
try {
if(--R.GAS > 0) {
$z23072308 = $f23132314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23132314,
"from":L[71]});
}
} catch($e23052306) {
if(R.isCont($e23052306)) {
var $ss23092310 = {"from":L[71],
"go":function(anf_arg3002315) {
return $Hanf_arg10742316(anf_arg3002315,anf_arg2972290,_plus5);
}};
$e23052306.stack[R.EXN_STACKHEIGHT++] = $ss23092310;
}
if(R.isPyretException($e23052306)) {
$e23052306.pyretStack.push(L[71]);
}
throw $e23052306;
}
var $ret23112312 = $Hanf_arg10742316($z23072308,anf_arg2972290,_plus5);
++R.GAS;
return $ret23112312;
};
var $Hanf_arg10742316 = function(anf_arg3002315,anf_arg2972290,_plus5) {
var $z23192320 = D;
var $f23252326 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2972290,anf_arg3002315):R.ffi.throwNonFunApp(L[71],_plus5,[anf_arg2972290,anf_arg3002315]);
};
try {
if(--R.GAS > 0) {
$z23192320 = $f23252326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23252326,
"from":L[71]});
}
} catch($e23172318) {
if(R.isCont($e23172318)) {
var $ss23212322 = {"from":L[71],
"go":function(anf_arg3012327) {
return $Hanf_arg10732328(anf_arg3012327,_plus5);
}};
$e23172318.stack[R.EXN_STACKHEIGHT++] = $ss23212322;
}
if(R.isPyretException($e23172318)) {
$e23172318.pyretStack.push(L[71]);
}
throw $e23172318;
}
var $ret23232324 = $Hanf_arg10732328($z23192320,_plus5);
++R.GAS;
return $ret23232324;
};
var $Hanf_arg10732328 = function(anf_arg3012327,_plus5) {
var $z23312332 = D;
var $f23372338 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3012327,(")")):R.ffi.throwNonFunApp(L[71],_plus5,[anf_arg3012327,(")")]);
};
try {
if(--R.GAS > 0) {
$z23312332 = $f23372338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23372338,
"from":L[71]});
}
} catch($e23292330) {
if(R.isCont($e23292330)) {
var $ss23332334 = {"from":L[71],
"go":function(anf_arg3022339) {
return $Hanf_arg10722340(anf_arg3022339,_plus5);
}};
$e23292330.stack[R.EXN_STACKHEIGHT++] = $ss23332334;
}
if(R.isPyretException($e23292330)) {
$e23292330.pyretStack.push(L[71]);
}
throw $e23292330;
}
var $ret23352336 = $Hanf_arg10722340($z23312332,_plus5);
++R.GAS;
return $ret23352336;
};
var $Hanf_arg10722340 = function(anf_arg3022339,_plus5) {
var $z23432344 = D;
var $f23492350 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg3022339):R.ffi.throwNonFunApp(L[71],_plus5,[("("),anf_arg3022339]);
};
try {
if(--R.GAS > 0) {
$z23432344 = $f23492350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23492350,
"from":L[71]});
}
} catch($e23412342) {
if(R.isCont($e23412342)) {
var $ss23452346 = {"from":L[71],
"go":function(anf_arg3032351) {
return $Hanf_arg10712352(anf_arg3032351,_plus5);
}};
$e23412342.stack[R.EXN_STACKHEIGHT++] = $ss23452346;
}
if(R.isPyretException($e23412342)) {
$e23412342.pyretStack.push(L[71]);
}
throw $e23412342;
}
var $ret23472348 = $Hanf_arg10712352($z23432344,_plus5);
++R.GAS;
return $ret23472348;
};
var $Hanf_arg10712352 = function(anf_arg3032351,_plus5) {
var $z23552356 = D;
var $f23612362 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("outside-numeric-range"),anf_arg3032351):R.ffi.throwNonFunApp(L[71],_plus5,[("outside-numeric-range"),anf_arg3032351]);
};
try {
if(--R.GAS > 0) {
$z23552356 = $f23612362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23612362,
"from":L[71]});
}
} catch($e23532354) {
if(R.isCont($e23532354)) {
var $ss23572358 = {"from":L[71],
"go":function(ann_DASH_check_DASH_temp2912363) {
return $Hann_DASH_check_DASH_temp10702364(ann_DASH_check_DASH_temp2912363);
}};
$e23532354.stack[R.EXN_STACKHEIGHT++] = $ss23572358;
}
if(R.isPyretException($e23532354)) {
$e23532354.pyretStack.push(L[71]);
}
throw $e23532354;
}
var $ret23592360 = $Hann_DASH_check_DASH_temp10702364($z23552356);
++R.GAS;
return $ret23592360;
};
var $Hann_DASH_check_DASH_temp10702364 = function(ann_DASH_check_DASH_temp2912363) {
return ann_DASH_check_DASH_temp2912363;
};
var $Hcont_tail_arg10682365 = function(cont_tail_arg2882366,if_helper2782367) {
if(--R.GAS > 0) {
$z23682369 = R.isFunction(if_helper2782367)?if_helper2782367.app(cont_tail_arg2882366):R.ffi.throwNonFunApp(L[71],if_helper2782367,[cont_tail_arg2882366]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2782367)?if_helper2782367.app(cont_tail_arg2882366):R.ffi.throwNonFunApp(L[71],if_helper2782367,[cont_tail_arg2882366]);
},
"from":L[71]});
}
++R.GAS;
return $z23682369;
};
var $Hcont_tail_arg10692370 = function(cont_tail_arg2832371,if_helper2782367) {
if(--R.GAS > 0) {
$z23722373 = R.isFunction(if_helper2782367)?if_helper2782367.app(cont_tail_arg2832371):R.ffi.throwNonFunApp(L[71],if_helper2782367,[cont_tail_arg2832371]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2782367)?if_helper2782367.app(cont_tail_arg2832371):R.ffi.throwNonFunApp(L[71],if_helper2782367,[cont_tail_arg2832371]);
},
"from":L[71]});
}
++R.GAS;
return $z23722373;
};
var $Hanf_arg10672374 = function(anf_arg2722375,self962376,_plus5,torepr8) {
var $z23792380 = D;
var $f23852386 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2722375,(", but got ")):R.ffi.throwNonFunApp(L[72],_plus5,[anf_arg2722375,(", but got ")]);
};
try {
if(--R.GAS > 0) {
$z23792380 = $f23852386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23852386,
"from":L[72]});
}
} catch($e23772378) {
if(R.isCont($e23772378)) {
var $ss23812382 = {"from":L[72],
"go":function(anf_arg2732387) {
return $Hanf_arg10662388(anf_arg2732387,self962376,_plus5,torepr8);
}};
$e23772378.stack[R.EXN_STACKHEIGHT++] = $ss23812382;
}
if(R.isPyretException($e23772378)) {
$e23772378.pyretStack.push(L[72]);
}
throw $e23772378;
}
var $ret23832384 = $Hanf_arg10662388($z23792380,self962376,_plus5,torepr8);
++R.GAS;
return $ret23832384;
};
var $Hanf_arg10662388 = function(anf_arg2732387,self962376,_plus5,torepr8) {
var anf_arg2742399 = G(self962376,"val",L[74]);
var $z23912392 = D;
var $f23972398 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2742399):R.ffi.throwNonFunApp(L[73],torepr8,[anf_arg2742399]);
};
try {
if(--R.GAS > 0) {
$z23912392 = $f23972398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23972398,
"from":L[73]});
}
} catch($e23892390) {
if(R.isCont($e23892390)) {
var $ss23932394 = {"from":L[73],
"go":function(anf_arg2752400) {
return $Hanf_arg10652401(anf_arg2752400,anf_arg2732387,_plus5);
}};
$e23892390.stack[R.EXN_STACKHEIGHT++] = $ss23932394;
}
if(R.isPyretException($e23892390)) {
$e23892390.pyretStack.push(L[73]);
}
throw $e23892390;
}
var $ret23952396 = $Hanf_arg10652401($z23912392,anf_arg2732387,_plus5);
++R.GAS;
return $ret23952396;
};
var $Hanf_arg10652401 = function(anf_arg2752400,anf_arg2732387,_plus5) {
var $z24042405 = D;
var $f24102411 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2732387,anf_arg2752400):R.ffi.throwNonFunApp(L[75],_plus5,[anf_arg2732387,anf_arg2752400]);
};
try {
if(--R.GAS > 0) {
$z24042405 = $f24102411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24102411,
"from":L[75]});
}
} catch($e24022403) {
if(R.isCont($e24022403)) {
var $ss24062407 = {"from":L[75],
"go":function(ann_DASH_check_DASH_temp2702412) {
return $Hann_DASH_check_DASH_temp10642413(ann_DASH_check_DASH_temp2702412);
}};
$e24022403.stack[R.EXN_STACKHEIGHT++] = $ss24062407;
}
if(R.isPyretException($e24022403)) {
$e24022403.pyretStack.push(L[75]);
}
throw $e24022403;
}
var $ret24082409 = $Hann_DASH_check_DASH_temp10642413($z24042405);
++R.GAS;
return $ret24082409;
};
var $Hann_DASH_check_DASH_temp10642413 = function(ann_DASH_check_DASH_temp2702412) {
return ann_DASH_check_DASH_temp2702412;
};
var $Hanf_arg10632414 = function(anf_arg2622415,self472416,_plus5,torepr8) {
var anf_arg2632427 = G(self472416,"typ",L[76]);
var $z24192420 = D;
var $f24252426 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2632427):R.ffi.throwNonFunApp(L[76],torepr8,[anf_arg2632427]);
};
try {
if(--R.GAS > 0) {
$z24192420 = $f24252426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24252426,
"from":L[76]});
}
} catch($e24172418) {
if(R.isCont($e24172418)) {
var $ss24212422 = {"from":L[76],
"go":function(anf_arg2642428) {
return $Hanf_arg10622429(anf_arg2642428,anf_arg2622415,_plus5);
}};
$e24172418.stack[R.EXN_STACKHEIGHT++] = $ss24212422;
}
if(R.isPyretException($e24172418)) {
$e24172418.pyretStack.push(L[76]);
}
throw $e24172418;
}
var $ret24232424 = $Hanf_arg10622429($z24192420,anf_arg2622415,_plus5);
++R.GAS;
return $ret24232424;
};
var $Hanf_arg10622429 = function(anf_arg2642428,anf_arg2622415,_plus5) {
var $z24322433 = D;
var $f24382439 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg2642428):R.ffi.throwNonFunApp(L[76],_plus5,[(", "),anf_arg2642428]);
};
try {
if(--R.GAS > 0) {
$z24322433 = $f24382439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24382439,
"from":L[76]});
}
} catch($e24302431) {
if(R.isCont($e24302431)) {
var $ss24342435 = {"from":L[76],
"go":function(anf_arg2652440) {
return $Hanf_arg10612441(anf_arg2652440,anf_arg2622415,_plus5);
}};
$e24302431.stack[R.EXN_STACKHEIGHT++] = $ss24342435;
}
if(R.isPyretException($e24302431)) {
$e24302431.pyretStack.push(L[76]);
}
throw $e24302431;
}
var $ret24362437 = $Hanf_arg10612441($z24322433,anf_arg2622415,_plus5);
++R.GAS;
return $ret24362437;
};
var $Hanf_arg10612441 = function(anf_arg2652440,anf_arg2622415,_plus5) {
var $z24442445 = D;
var $f24502451 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2622415,anf_arg2652440):R.ffi.throwNonFunApp(L[76],_plus5,[anf_arg2622415,anf_arg2652440]);
};
try {
if(--R.GAS > 0) {
$z24442445 = $f24502451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24502451,
"from":L[76]});
}
} catch($e24422443) {
if(R.isCont($e24422443)) {
var $ss24462447 = {"from":L[76],
"go":function(anf_arg2662452) {
return $Hanf_arg10602453(anf_arg2662452,_plus5);
}};
$e24422443.stack[R.EXN_STACKHEIGHT++] = $ss24462447;
}
if(R.isPyretException($e24422443)) {
$e24422443.pyretStack.push(L[76]);
}
throw $e24422443;
}
var $ret24482449 = $Hanf_arg10602453($z24442445,_plus5);
++R.GAS;
return $ret24482449;
};
var $Hanf_arg10602453 = function(anf_arg2662452,_plus5) {
var $z24562457 = D;
var $f24622463 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2662452,(")")):R.ffi.throwNonFunApp(L[76],_plus5,[anf_arg2662452,(")")]);
};
try {
if(--R.GAS > 0) {
$z24562457 = $f24622463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24622463,
"from":L[76]});
}
} catch($e24542455) {
if(R.isCont($e24542455)) {
var $ss24582459 = {"from":L[76],
"go":function(anf_arg2672464) {
return $Hanf_arg10592465(anf_arg2672464,_plus5);
}};
$e24542455.stack[R.EXN_STACKHEIGHT++] = $ss24582459;
}
if(R.isPyretException($e24542455)) {
$e24542455.pyretStack.push(L[76]);
}
throw $e24542455;
}
var $ret24602461 = $Hanf_arg10592465($z24562457,_plus5);
++R.GAS;
return $ret24602461;
};
var $Hanf_arg10592465 = function(anf_arg2672464,_plus5) {
var $z24682469 = D;
var $f24742475 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg2672464):R.ffi.throwNonFunApp(L[76],_plus5,[("("),anf_arg2672464]);
};
try {
if(--R.GAS > 0) {
$z24682469 = $f24742475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24742475,
"from":L[76]});
}
} catch($e24662467) {
if(R.isCont($e24662467)) {
var $ss24702471 = {"from":L[76],
"go":function(anf_arg2682476) {
return $Hanf_arg10582477(anf_arg2682476,_plus5);
}};
$e24662467.stack[R.EXN_STACKHEIGHT++] = $ss24702471;
}
if(R.isPyretException($e24662467)) {
$e24662467.pyretStack.push(L[76]);
}
throw $e24662467;
}
var $ret24722473 = $Hanf_arg10582477($z24682469,_plus5);
++R.GAS;
return $ret24722473;
};
var $Hanf_arg10582477 = function(anf_arg2682476,_plus5) {
var $z24802481 = D;
var $f24862487 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("generic-type-mismatch"),anf_arg2682476):R.ffi.throwNonFunApp(L[76],_plus5,[("generic-type-mismatch"),anf_arg2682476]);
};
try {
if(--R.GAS > 0) {
$z24802481 = $f24862487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24862487,
"from":L[76]});
}
} catch($e24782479) {
if(R.isCont($e24782479)) {
var $ss24822483 = {"from":L[76],
"go":function(ann_DASH_check_DASH_temp2602488) {
return $Hann_DASH_check_DASH_temp10572489(ann_DASH_check_DASH_temp2602488);
}};
$e24782479.stack[R.EXN_STACKHEIGHT++] = $ss24822483;
}
if(R.isPyretException($e24782479)) {
$e24782479.pyretStack.push(L[76]);
}
throw $e24782479;
}
var $ret24842485 = $Hann_DASH_check_DASH_temp10572489($z24802481);
++R.GAS;
return $ret24842485;
};
var $Hann_DASH_check_DASH_temp10572489 = function(ann_DASH_check_DASH_temp2602488) {
return ann_DASH_check_DASH_temp2602488;
};
var $Hcont_tail_arg10552490 = function(cont_tail_arg2572491,if_helper2482492) {
if(--R.GAS > 0) {
$z24932494 = R.isFunction(if_helper2482492)?if_helper2482492.app(cont_tail_arg2572491):R.ffi.throwNonFunApp(L[76],if_helper2482492,[cont_tail_arg2572491]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2482492)?if_helper2482492.app(cont_tail_arg2572491):R.ffi.throwNonFunApp(L[76],if_helper2482492,[cont_tail_arg2572491]);
},
"from":L[76]});
}
++R.GAS;
return $z24932494;
};
var $Hcont_tail_arg10562495 = function(cont_tail_arg2532496,if_helper2482492) {
if(--R.GAS > 0) {
$z24972498 = R.isFunction(if_helper2482492)?if_helper2482492.app(cont_tail_arg2532496):R.ffi.throwNonFunApp(L[76],if_helper2482492,[cont_tail_arg2532496]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2482492)?if_helper2482492.app(cont_tail_arg2532496):R.ffi.throwNonFunApp(L[76],if_helper2482492,[cont_tail_arg2532496]);
},
"from":L[76]});
}
++R.GAS;
return $z24972498;
};
var $Hanf_arg10542499 = function(anf_arg2342500,self932501,_plus5,torepr8) {
var $z25042505 = D;
var $f25102511 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2342500,(" argument to ")):R.ffi.throwNonFunApp(L[77],_plus5,[anf_arg2342500,(" argument to ")]);
};
try {
if(--R.GAS > 0) {
$z25042505 = $f25102511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25102511,
"from":L[77]});
}
} catch($e25022503) {
if(R.isCont($e25022503)) {
var $ss25062507 = {"from":L[77],
"go":function(anf_arg2352512) {
return $Hanf_arg10532513(anf_arg2352512,self932501,_plus5,torepr8);
}};
$e25022503.stack[R.EXN_STACKHEIGHT++] = $ss25062507;
}
if(R.isPyretException($e25022503)) {
$e25022503.pyretStack.push(L[77]);
}
throw $e25022503;
}
var $ret25082509 = $Hanf_arg10532513($z25042505,self932501,_plus5,torepr8);
++R.GAS;
return $ret25082509;
};
var $Hanf_arg10532513 = function(anf_arg2352512,self932501,_plus5,torepr8) {
var anf_arg2362524 = G(self932501,"typ",L[78]);
var $z25162517 = D;
var $f25222523 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2352512,anf_arg2362524):R.ffi.throwNonFunApp(L[77],_plus5,[anf_arg2352512,anf_arg2362524]);
};
try {
if(--R.GAS > 0) {
$z25162517 = $f25222523();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25222523,
"from":L[77]});
}
} catch($e25142515) {
if(R.isCont($e25142515)) {
var $ss25182519 = {"from":L[77],
"go":function(anf_arg2372525) {
return $Hanf_arg10522526(anf_arg2372525,self932501,_plus5,torepr8);
}};
$e25142515.stack[R.EXN_STACKHEIGHT++] = $ss25182519;
}
if(R.isPyretException($e25142515)) {
$e25142515.pyretStack.push(L[77]);
}
throw $e25142515;
}
var $ret25202521 = $Hanf_arg10522526($z25162517,self932501,_plus5,torepr8);
++R.GAS;
return $ret25202521;
};
var $Hanf_arg10522526 = function(anf_arg2372525,self932501,_plus5,torepr8) {
var $z25292530 = D;
var $f25352536 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2372525,(" at ")):R.ffi.throwNonFunApp(L[77],_plus5,[anf_arg2372525,(" at ")]);
};
try {
if(--R.GAS > 0) {
$z25292530 = $f25352536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25352536,
"from":L[77]});
}
} catch($e25272528) {
if(R.isCont($e25272528)) {
var $ss25312532 = {"from":L[77],
"go":function(anf_arg2382537) {
return $Hanf_arg10512538(anf_arg2382537,self932501,_plus5,torepr8);
}};
$e25272528.stack[R.EXN_STACKHEIGHT++] = $ss25312532;
}
if(R.isPyretException($e25272528)) {
$e25272528.pyretStack.push(L[77]);
}
throw $e25272528;
}
var $ret25332534 = $Hanf_arg10512538($z25292530,self932501,_plus5,torepr8);
++R.GAS;
return $ret25332534;
};
var $Hanf_arg10512538 = function(anf_arg2382537,self932501,_plus5,torepr8) {
var anf_bracket2392552 = G(self932501,"loc",L[81]);
var anf_fun2402549 = G(anf_bracket2392552,"format",L[80]);
var $z25412542 = D;
var $f25472548 = function(_) {
return R.isFunction(anf_fun2402549)?anf_fun2402549.app((true)):R.ffi.throwNonFunApp(L[79],anf_fun2402549,[(true)]);
};
try {
if(--R.GAS > 0) {
$z25412542 = $f25472548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25472548,
"from":L[79]});
}
} catch($e25392540) {
if(R.isCont($e25392540)) {
var $ss25432544 = {"from":L[79],
"go":function(anf_arg2412550) {
return $Hanf_arg10502551(anf_arg2412550,anf_arg2382537,self932501,_plus5,torepr8);
}};
$e25392540.stack[R.EXN_STACKHEIGHT++] = $ss25432544;
}
if(R.isPyretException($e25392540)) {
$e25392540.pyretStack.push(L[79]);
}
throw $e25392540;
}
var $ret25452546 = $Hanf_arg10502551($z25412542,anf_arg2382537,self932501,_plus5,torepr8);
++R.GAS;
return $ret25452546;
};
var $Hanf_arg10502551 = function(anf_arg2412550,anf_arg2382537,self932501,_plus5,torepr8) {
var $z25552556 = D;
var $f25612562 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2382537,anf_arg2412550):R.ffi.throwNonFunApp(L[77],_plus5,[anf_arg2382537,anf_arg2412550]);
};
try {
if(--R.GAS > 0) {
$z25552556 = $f25612562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25612562,
"from":L[77]});
}
} catch($e25532554) {
if(R.isCont($e25532554)) {
var $ss25572558 = {"from":L[77],
"go":function(anf_arg2422563) {
return $Hanf_arg10492564(anf_arg2422563,self932501,_plus5,torepr8);
}};
$e25532554.stack[R.EXN_STACKHEIGHT++] = $ss25572558;
}
if(R.isPyretException($e25532554)) {
$e25532554.pyretStack.push(L[77]);
}
throw $e25532554;
}
var $ret25592560 = $Hanf_arg10492564($z25552556,self932501,_plus5,torepr8);
++R.GAS;
return $ret25592560;
};
var $Hanf_arg10492564 = function(anf_arg2422563,self932501,_plus5,torepr8) {
var $z25672568 = D;
var $f25732574 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2422563,(", but got ")):R.ffi.throwNonFunApp(L[77],_plus5,[anf_arg2422563,(", but got ")]);
};
try {
if(--R.GAS > 0) {
$z25672568 = $f25732574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25732574,
"from":L[77]});
}
} catch($e25652566) {
if(R.isCont($e25652566)) {
var $ss25692570 = {"from":L[77],
"go":function(anf_arg2432575) {
return $Hanf_arg10482576(anf_arg2432575,self932501,_plus5,torepr8);
}};
$e25652566.stack[R.EXN_STACKHEIGHT++] = $ss25692570;
}
if(R.isPyretException($e25652566)) {
$e25652566.pyretStack.push(L[77]);
}
throw $e25652566;
}
var $ret25712572 = $Hanf_arg10482576($z25672568,self932501,_plus5,torepr8);
++R.GAS;
return $ret25712572;
};
var $Hanf_arg10482576 = function(anf_arg2432575,self932501,_plus5,torepr8) {
var anf_arg2442587 = G(self932501,"value",L[83]);
var $z25792580 = D;
var $f25852586 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2442587):R.ffi.throwNonFunApp(L[82],torepr8,[anf_arg2442587]);
};
try {
if(--R.GAS > 0) {
$z25792580 = $f25852586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25852586,
"from":L[82]});
}
} catch($e25772578) {
if(R.isCont($e25772578)) {
var $ss25812582 = {"from":L[82],
"go":function(anf_arg2452588) {
return $Hanf_arg10472589(anf_arg2452588,anf_arg2432575,_plus5);
}};
$e25772578.stack[R.EXN_STACKHEIGHT++] = $ss25812582;
}
if(R.isPyretException($e25772578)) {
$e25772578.pyretStack.push(L[82]);
}
throw $e25772578;
}
var $ret25832584 = $Hanf_arg10472589($z25792580,anf_arg2432575,_plus5);
++R.GAS;
return $ret25832584;
};
var $Hanf_arg10472589 = function(anf_arg2452588,anf_arg2432575,_plus5) {
var $z25922593 = D;
var $f25982599 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2432575,anf_arg2452588):R.ffi.throwNonFunApp(L[84],_plus5,[anf_arg2432575,anf_arg2452588]);
};
try {
if(--R.GAS > 0) {
$z25922593 = $f25982599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25982599,
"from":L[84]});
}
} catch($e25902591) {
if(R.isCont($e25902591)) {
var $ss25942595 = {"from":L[84],
"go":function(ann_DASH_check_DASH_temp2322600) {
return $Hann_DASH_check_DASH_temp10462601(ann_DASH_check_DASH_temp2322600);
}};
$e25902591.stack[R.EXN_STACKHEIGHT++] = $ss25942595;
}
if(R.isPyretException($e25902591)) {
$e25902591.pyretStack.push(L[84]);
}
throw $e25902591;
}
var $ret25962597 = $Hann_DASH_check_DASH_temp10462601($z25922593);
++R.GAS;
return $ret25962597;
};
var $Hann_DASH_check_DASH_temp10462601 = function(ann_DASH_check_DASH_temp2322600) {
return ann_DASH_check_DASH_temp2322600;
};
var $Hanf_arg10452602 = function(anf_arg2162603,self412604,_plus5,torepr8) {
var anf_arg2172615 = G(self412604,"position",L[85]);
var $z26072608 = D;
var $f26132614 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2172615):R.ffi.throwNonFunApp(L[85],torepr8,[anf_arg2172615]);
};
try {
if(--R.GAS > 0) {
$z26072608 = $f26132614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26132614,
"from":L[85]});
}
} catch($e26052606) {
if(R.isCont($e26052606)) {
var $ss26092610 = {"from":L[85],
"go":function(anf_arg2182616) {
return $Hanf_arg10442617(anf_arg2182616,anf_arg2162603,self412604,_plus5,torepr8);
}};
$e26052606.stack[R.EXN_STACKHEIGHT++] = $ss26092610;
}
if(R.isPyretException($e26052606)) {
$e26052606.pyretStack.push(L[85]);
}
throw $e26052606;
}
var $ret26112612 = $Hanf_arg10442617($z26072608,anf_arg2162603,self412604,_plus5,torepr8);
++R.GAS;
return $ret26112612;
};
var $Hanf_arg10442617 = function(anf_arg2182616,anf_arg2162603,self412604,_plus5,torepr8) {
var $z26202621 = D;
var $f26262627 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg2182616):R.ffi.throwNonFunApp(L[85],_plus5,[(", "),anf_arg2182616]);
};
try {
if(--R.GAS > 0) {
$z26202621 = $f26262627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26262627,
"from":L[85]});
}
} catch($e26182619) {
if(R.isCont($e26182619)) {
var $ss26222623 = {"from":L[85],
"go":function(anf_arg2192628) {
return $Hanf_arg10432629(anf_arg2192628,anf_arg2162603,self412604,_plus5,torepr8);
}};
$e26182619.stack[R.EXN_STACKHEIGHT++] = $ss26222623;
}
if(R.isPyretException($e26182619)) {
$e26182619.pyretStack.push(L[85]);
}
throw $e26182619;
}
var $ret26242625 = $Hanf_arg10432629($z26202621,anf_arg2162603,self412604,_plus5,torepr8);
++R.GAS;
return $ret26242625;
};
var $Hanf_arg10432629 = function(anf_arg2192628,anf_arg2162603,self412604,_plus5,torepr8) {
var $z26322633 = D;
var $f26382639 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2162603,anf_arg2192628):R.ffi.throwNonFunApp(L[85],_plus5,[anf_arg2162603,anf_arg2192628]);
};
try {
if(--R.GAS > 0) {
$z26322633 = $f26382639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26382639,
"from":L[85]});
}
} catch($e26302631) {
if(R.isCont($e26302631)) {
var $ss26342635 = {"from":L[85],
"go":function(anf_arg2202640) {
return $Hanf_arg10422641(anf_arg2202640,self412604,_plus5,torepr8);
}};
$e26302631.stack[R.EXN_STACKHEIGHT++] = $ss26342635;
}
if(R.isPyretException($e26302631)) {
$e26302631.pyretStack.push(L[85]);
}
throw $e26302631;
}
var $ret26362637 = $Hanf_arg10422641($z26322633,self412604,_plus5,torepr8);
++R.GAS;
return $ret26362637;
};
var $Hanf_arg10422641 = function(anf_arg2202640,self412604,_plus5,torepr8) {
var anf_arg2212652 = G(self412604,"typ",L[85]);
var $z26442645 = D;
var $f26502651 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2212652):R.ffi.throwNonFunApp(L[85],torepr8,[anf_arg2212652]);
};
try {
if(--R.GAS > 0) {
$z26442645 = $f26502651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26502651,
"from":L[85]});
}
} catch($e26422643) {
if(R.isCont($e26422643)) {
var $ss26462647 = {"from":L[85],
"go":function(anf_arg2222653) {
return $Hanf_arg10412654(anf_arg2222653,anf_arg2202640,self412604,_plus5,torepr8);
}};
$e26422643.stack[R.EXN_STACKHEIGHT++] = $ss26462647;
}
if(R.isPyretException($e26422643)) {
$e26422643.pyretStack.push(L[85]);
}
throw $e26422643;
}
var $ret26482649 = $Hanf_arg10412654($z26442645,anf_arg2202640,self412604,_plus5,torepr8);
++R.GAS;
return $ret26482649;
};
var $Hanf_arg10412654 = function(anf_arg2222653,anf_arg2202640,self412604,_plus5,torepr8) {
var $z26572658 = D;
var $f26632664 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg2222653):R.ffi.throwNonFunApp(L[85],_plus5,[(", "),anf_arg2222653]);
};
try {
if(--R.GAS > 0) {
$z26572658 = $f26632664();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26632664,
"from":L[85]});
}
} catch($e26552656) {
if(R.isCont($e26552656)) {
var $ss26592660 = {"from":L[85],
"go":function(anf_arg2232665) {
return $Hanf_arg10402666(anf_arg2232665,anf_arg2202640,self412604,_plus5,torepr8);
}};
$e26552656.stack[R.EXN_STACKHEIGHT++] = $ss26592660;
}
if(R.isPyretException($e26552656)) {
$e26552656.pyretStack.push(L[85]);
}
throw $e26552656;
}
var $ret26612662 = $Hanf_arg10402666($z26572658,anf_arg2202640,self412604,_plus5,torepr8);
++R.GAS;
return $ret26612662;
};
var $Hanf_arg10402666 = function(anf_arg2232665,anf_arg2202640,self412604,_plus5,torepr8) {
var $z26692670 = D;
var $f26752676 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2202640,anf_arg2232665):R.ffi.throwNonFunApp(L[85],_plus5,[anf_arg2202640,anf_arg2232665]);
};
try {
if(--R.GAS > 0) {
$z26692670 = $f26752676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26752676,
"from":L[85]});
}
} catch($e26672668) {
if(R.isCont($e26672668)) {
var $ss26712672 = {"from":L[85],
"go":function(anf_arg2242677) {
return $Hanf_arg10392678(anf_arg2242677,self412604,_plus5,torepr8);
}};
$e26672668.stack[R.EXN_STACKHEIGHT++] = $ss26712672;
}
if(R.isPyretException($e26672668)) {
$e26672668.pyretStack.push(L[85]);
}
throw $e26672668;
}
var $ret26732674 = $Hanf_arg10392678($z26692670,self412604,_plus5,torepr8);
++R.GAS;
return $ret26732674;
};
var $Hanf_arg10392678 = function(anf_arg2242677,self412604,_plus5,torepr8) {
var anf_arg2252689 = G(self412604,"value",L[85]);
var $z26812682 = D;
var $f26872688 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2252689):R.ffi.throwNonFunApp(L[85],torepr8,[anf_arg2252689]);
};
try {
if(--R.GAS > 0) {
$z26812682 = $f26872688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26872688,
"from":L[85]});
}
} catch($e26792680) {
if(R.isCont($e26792680)) {
var $ss26832684 = {"from":L[85],
"go":function(anf_arg2262690) {
return $Hanf_arg10382691(anf_arg2262690,anf_arg2242677,_plus5);
}};
$e26792680.stack[R.EXN_STACKHEIGHT++] = $ss26832684;
}
if(R.isPyretException($e26792680)) {
$e26792680.pyretStack.push(L[85]);
}
throw $e26792680;
}
var $ret26852686 = $Hanf_arg10382691($z26812682,anf_arg2242677,_plus5);
++R.GAS;
return $ret26852686;
};
var $Hanf_arg10382691 = function(anf_arg2262690,anf_arg2242677,_plus5) {
var $z26942695 = D;
var $f27002701 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg2262690):R.ffi.throwNonFunApp(L[85],_plus5,[(", "),anf_arg2262690]);
};
try {
if(--R.GAS > 0) {
$z26942695 = $f27002701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27002701,
"from":L[85]});
}
} catch($e26922693) {
if(R.isCont($e26922693)) {
var $ss26962697 = {"from":L[85],
"go":function(anf_arg2272702) {
return $Hanf_arg10372703(anf_arg2272702,anf_arg2242677,_plus5);
}};
$e26922693.stack[R.EXN_STACKHEIGHT++] = $ss26962697;
}
if(R.isPyretException($e26922693)) {
$e26922693.pyretStack.push(L[85]);
}
throw $e26922693;
}
var $ret26982699 = $Hanf_arg10372703($z26942695,anf_arg2242677,_plus5);
++R.GAS;
return $ret26982699;
};
var $Hanf_arg10372703 = function(anf_arg2272702,anf_arg2242677,_plus5) {
var $z27062707 = D;
var $f27122713 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2242677,anf_arg2272702):R.ffi.throwNonFunApp(L[85],_plus5,[anf_arg2242677,anf_arg2272702]);
};
try {
if(--R.GAS > 0) {
$z27062707 = $f27122713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27122713,
"from":L[85]});
}
} catch($e27042705) {
if(R.isCont($e27042705)) {
var $ss27082709 = {"from":L[85],
"go":function(anf_arg2282714) {
return $Hanf_arg10362715(anf_arg2282714,_plus5);
}};
$e27042705.stack[R.EXN_STACKHEIGHT++] = $ss27082709;
}
if(R.isPyretException($e27042705)) {
$e27042705.pyretStack.push(L[85]);
}
throw $e27042705;
}
var $ret27102711 = $Hanf_arg10362715($z27062707,_plus5);
++R.GAS;
return $ret27102711;
};
var $Hanf_arg10362715 = function(anf_arg2282714,_plus5) {
var $z27182719 = D;
var $f27242725 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2282714,(")")):R.ffi.throwNonFunApp(L[85],_plus5,[anf_arg2282714,(")")]);
};
try {
if(--R.GAS > 0) {
$z27182719 = $f27242725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27242725,
"from":L[85]});
}
} catch($e27162717) {
if(R.isCont($e27162717)) {
var $ss27202721 = {"from":L[85],
"go":function(anf_arg2292726) {
return $Hanf_arg10352727(anf_arg2292726,_plus5);
}};
$e27162717.stack[R.EXN_STACKHEIGHT++] = $ss27202721;
}
if(R.isPyretException($e27162717)) {
$e27162717.pyretStack.push(L[85]);
}
throw $e27162717;
}
var $ret27222723 = $Hanf_arg10352727($z27182719,_plus5);
++R.GAS;
return $ret27222723;
};
var $Hanf_arg10352727 = function(anf_arg2292726,_plus5) {
var $z27302731 = D;
var $f27362737 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg2292726):R.ffi.throwNonFunApp(L[85],_plus5,[("("),anf_arg2292726]);
};
try {
if(--R.GAS > 0) {
$z27302731 = $f27362737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27362737,
"from":L[85]});
}
} catch($e27282729) {
if(R.isCont($e27282729)) {
var $ss27322733 = {"from":L[85],
"go":function(anf_arg2302738) {
return $Hanf_arg10342739(anf_arg2302738,_plus5);
}};
$e27282729.stack[R.EXN_STACKHEIGHT++] = $ss27322733;
}
if(R.isPyretException($e27282729)) {
$e27282729.pyretStack.push(L[85]);
}
throw $e27282729;
}
var $ret27342735 = $Hanf_arg10342739($z27302731,_plus5);
++R.GAS;
return $ret27342735;
};
var $Hanf_arg10342739 = function(anf_arg2302738,_plus5) {
var $z27422743 = D;
var $f27482749 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("non-boolean-op"),anf_arg2302738):R.ffi.throwNonFunApp(L[85],_plus5,[("non-boolean-op"),anf_arg2302738]);
};
try {
if(--R.GAS > 0) {
$z27422743 = $f27482749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27482749,
"from":L[85]});
}
} catch($e27402741) {
if(R.isCont($e27402741)) {
var $ss27442745 = {"from":L[85],
"go":function(ann_DASH_check_DASH_temp2142750) {
return $Hann_DASH_check_DASH_temp10332751(ann_DASH_check_DASH_temp2142750);
}};
$e27402741.stack[R.EXN_STACKHEIGHT++] = $ss27442745;
}
if(R.isPyretException($e27402741)) {
$e27402741.pyretStack.push(L[85]);
}
throw $e27402741;
}
var $ret27462747 = $Hann_DASH_check_DASH_temp10332751($z27422743);
++R.GAS;
return $ret27462747;
};
var $Hann_DASH_check_DASH_temp10332751 = function(ann_DASH_check_DASH_temp2142750) {
return ann_DASH_check_DASH_temp2142750;
};
var $Hcont_tail_arg10312752 = function(cont_tail_arg2112753,if_helper2002754) {
if(--R.GAS > 0) {
$z27552756 = R.isFunction(if_helper2002754)?if_helper2002754.app(cont_tail_arg2112753):R.ffi.throwNonFunApp(L[85],if_helper2002754,[cont_tail_arg2112753]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2002754)?if_helper2002754.app(cont_tail_arg2112753):R.ffi.throwNonFunApp(L[85],if_helper2002754,[cont_tail_arg2112753]);
},
"from":L[85]});
}
++R.GAS;
return $z27552756;
};
var $Hcont_tail_arg10322757 = function(cont_tail_arg2052758,if_helper2002754) {
if(--R.GAS > 0) {
$z27592760 = R.isFunction(if_helper2002754)?if_helper2002754.app(cont_tail_arg2052758):R.ffi.throwNonFunApp(L[85],if_helper2002754,[cont_tail_arg2052758]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2002754)?if_helper2002754.app(cont_tail_arg2052758):R.ffi.throwNonFunApp(L[85],if_helper2002754,[cont_tail_arg2052758]);
},
"from":L[85]});
}
++R.GAS;
return $z27592760;
};
var $Hanf_arg10302761 = function(anf_arg1892762,self882763,_plus5,torepr8) {
var $z27662767 = D;
var $f27722773 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1892762,(" at ")):R.ffi.throwNonFunApp(L[86],_plus5,[anf_arg1892762,(" at ")]);
};
try {
if(--R.GAS > 0) {
$z27662767 = $f27722773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27722773,
"from":L[86]});
}
} catch($e27642765) {
if(R.isCont($e27642765)) {
var $ss27682769 = {"from":L[86],
"go":function(anf_arg1902774) {
return $Hanf_arg10292775(anf_arg1902774,self882763,_plus5,torepr8);
}};
$e27642765.stack[R.EXN_STACKHEIGHT++] = $ss27682769;
}
if(R.isPyretException($e27642765)) {
$e27642765.pyretStack.push(L[86]);
}
throw $e27642765;
}
var $ret27702771 = $Hanf_arg10292775($z27662767,self882763,_plus5,torepr8);
++R.GAS;
return $ret27702771;
};
var $Hanf_arg10292775 = function(anf_arg1902774,self882763,_plus5,torepr8) {
var anf_bracket1912789 = G(self882763,"loc",L[89]);
var anf_fun1922786 = G(anf_bracket1912789,"format",L[88]);
var $z27782779 = D;
var $f27842785 = function(_) {
return R.isFunction(anf_fun1922786)?anf_fun1922786.app((true)):R.ffi.throwNonFunApp(L[87],anf_fun1922786,[(true)]);
};
try {
if(--R.GAS > 0) {
$z27782779 = $f27842785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27842785,
"from":L[87]});
}
} catch($e27762777) {
if(R.isCont($e27762777)) {
var $ss27802781 = {"from":L[87],
"go":function(anf_arg1932787) {
return $Hanf_arg10282788(anf_arg1932787,anf_arg1902774,self882763,_plus5,torepr8);
}};
$e27762777.stack[R.EXN_STACKHEIGHT++] = $ss27802781;
}
if(R.isPyretException($e27762777)) {
$e27762777.pyretStack.push(L[87]);
}
throw $e27762777;
}
var $ret27822783 = $Hanf_arg10282788($z27782779,anf_arg1902774,self882763,_plus5,torepr8);
++R.GAS;
return $ret27822783;
};
var $Hanf_arg10282788 = function(anf_arg1932787,anf_arg1902774,self882763,_plus5,torepr8) {
var $z27922793 = D;
var $f27982799 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1902774,anf_arg1932787):R.ffi.throwNonFunApp(L[86],_plus5,[anf_arg1902774,anf_arg1932787]);
};
try {
if(--R.GAS > 0) {
$z27922793 = $f27982799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27982799,
"from":L[86]});
}
} catch($e27902791) {
if(R.isCont($e27902791)) {
var $ss27942795 = {"from":L[86],
"go":function(anf_arg1942800) {
return $Hanf_arg10272801(anf_arg1942800,self882763,_plus5,torepr8);
}};
$e27902791.stack[R.EXN_STACKHEIGHT++] = $ss27942795;
}
if(R.isPyretException($e27902791)) {
$e27902791.pyretStack.push(L[86]);
}
throw $e27902791;
}
var $ret27962797 = $Hanf_arg10272801($z27922793,self882763,_plus5,torepr8);
++R.GAS;
return $ret27962797;
};
var $Hanf_arg10272801 = function(anf_arg1942800,self882763,_plus5,torepr8) {
var $z28042805 = D;
var $f28102811 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1942800,(", but got ")):R.ffi.throwNonFunApp(L[86],_plus5,[anf_arg1942800,(", but got ")]);
};
try {
if(--R.GAS > 0) {
$z28042805 = $f28102811();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28102811,
"from":L[86]});
}
} catch($e28022803) {
if(R.isCont($e28022803)) {
var $ss28062807 = {"from":L[86],
"go":function(anf_arg1952812) {
return $Hanf_arg10262813(anf_arg1952812,self882763,_plus5,torepr8);
}};
$e28022803.stack[R.EXN_STACKHEIGHT++] = $ss28062807;
}
if(R.isPyretException($e28022803)) {
$e28022803.pyretStack.push(L[86]);
}
throw $e28022803;
}
var $ret28082809 = $Hanf_arg10262813($z28042805,self882763,_plus5,torepr8);
++R.GAS;
return $ret28082809;
};
var $Hanf_arg10262813 = function(anf_arg1952812,self882763,_plus5,torepr8) {
var anf_arg1962824 = G(self882763,"value",L[91]);
var $z28162817 = D;
var $f28222823 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1962824):R.ffi.throwNonFunApp(L[90],torepr8,[anf_arg1962824]);
};
try {
if(--R.GAS > 0) {
$z28162817 = $f28222823();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28222823,
"from":L[90]});
}
} catch($e28142815) {
if(R.isCont($e28142815)) {
var $ss28182819 = {"from":L[90],
"go":function(anf_arg1972825) {
return $Hanf_arg10252826(anf_arg1972825,anf_arg1952812,_plus5);
}};
$e28142815.stack[R.EXN_STACKHEIGHT++] = $ss28182819;
}
if(R.isPyretException($e28142815)) {
$e28142815.pyretStack.push(L[90]);
}
throw $e28142815;
}
var $ret28202821 = $Hanf_arg10252826($z28162817,anf_arg1952812,_plus5);
++R.GAS;
return $ret28202821;
};
var $Hanf_arg10252826 = function(anf_arg1972825,anf_arg1952812,_plus5) {
var $z28292830 = D;
var $f28352836 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1952812,anf_arg1972825):R.ffi.throwNonFunApp(L[92],_plus5,[anf_arg1952812,anf_arg1972825]);
};
try {
if(--R.GAS > 0) {
$z28292830 = $f28352836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28352836,
"from":L[92]});
}
} catch($e28272828) {
if(R.isCont($e28272828)) {
var $ss28312832 = {"from":L[92],
"go":function(ann_DASH_check_DASH_temp1872837) {
return $Hann_DASH_check_DASH_temp10242838(ann_DASH_check_DASH_temp1872837);
}};
$e28272828.stack[R.EXN_STACKHEIGHT++] = $ss28312832;
}
if(R.isPyretException($e28272828)) {
$e28272828.pyretStack.push(L[92]);
}
throw $e28272828;
}
var $ret28332834 = $Hann_DASH_check_DASH_temp10242838($z28292830);
++R.GAS;
return $ret28332834;
};
var $Hann_DASH_check_DASH_temp10242838 = function(ann_DASH_check_DASH_temp1872837) {
return ann_DASH_check_DASH_temp1872837;
};
var $Hanf_arg10232839 = function(anf_arg1752840,self352841,_plus5,torepr8) {
var anf_arg1762852 = G(self352841,"typ",L[93]);
var $z28442845 = D;
var $f28502851 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1762852):R.ffi.throwNonFunApp(L[93],torepr8,[anf_arg1762852]);
};
try {
if(--R.GAS > 0) {
$z28442845 = $f28502851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28502851,
"from":L[93]});
}
} catch($e28422843) {
if(R.isCont($e28422843)) {
var $ss28462847 = {"from":L[93],
"go":function(anf_arg1772853) {
return $Hanf_arg10222854(anf_arg1772853,anf_arg1752840,self352841,_plus5,torepr8);
}};
$e28422843.stack[R.EXN_STACKHEIGHT++] = $ss28462847;
}
if(R.isPyretException($e28422843)) {
$e28422843.pyretStack.push(L[93]);
}
throw $e28422843;
}
var $ret28482849 = $Hanf_arg10222854($z28442845,anf_arg1752840,self352841,_plus5,torepr8);
++R.GAS;
return $ret28482849;
};
var $Hanf_arg10222854 = function(anf_arg1772853,anf_arg1752840,self352841,_plus5,torepr8) {
var $z28572858 = D;
var $f28632864 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1772853):R.ffi.throwNonFunApp(L[93],_plus5,[(", "),anf_arg1772853]);
};
try {
if(--R.GAS > 0) {
$z28572858 = $f28632864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28632864,
"from":L[93]});
}
} catch($e28552856) {
if(R.isCont($e28552856)) {
var $ss28592860 = {"from":L[93],
"go":function(anf_arg1782865) {
return $Hanf_arg10212866(anf_arg1782865,anf_arg1752840,self352841,_plus5,torepr8);
}};
$e28552856.stack[R.EXN_STACKHEIGHT++] = $ss28592860;
}
if(R.isPyretException($e28552856)) {
$e28552856.pyretStack.push(L[93]);
}
throw $e28552856;
}
var $ret28612862 = $Hanf_arg10212866($z28572858,anf_arg1752840,self352841,_plus5,torepr8);
++R.GAS;
return $ret28612862;
};
var $Hanf_arg10212866 = function(anf_arg1782865,anf_arg1752840,self352841,_plus5,torepr8) {
var $z28692870 = D;
var $f28752876 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1752840,anf_arg1782865):R.ffi.throwNonFunApp(L[93],_plus5,[anf_arg1752840,anf_arg1782865]);
};
try {
if(--R.GAS > 0) {
$z28692870 = $f28752876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28752876,
"from":L[93]});
}
} catch($e28672868) {
if(R.isCont($e28672868)) {
var $ss28712872 = {"from":L[93],
"go":function(anf_arg1792877) {
return $Hanf_arg10202878(anf_arg1792877,self352841,_plus5,torepr8);
}};
$e28672868.stack[R.EXN_STACKHEIGHT++] = $ss28712872;
}
if(R.isPyretException($e28672868)) {
$e28672868.pyretStack.push(L[93]);
}
throw $e28672868;
}
var $ret28732874 = $Hanf_arg10202878($z28692870,self352841,_plus5,torepr8);
++R.GAS;
return $ret28732874;
};
var $Hanf_arg10202878 = function(anf_arg1792877,self352841,_plus5,torepr8) {
var anf_arg1802889 = G(self352841,"value",L[93]);
var $z28812882 = D;
var $f28872888 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1802889):R.ffi.throwNonFunApp(L[93],torepr8,[anf_arg1802889]);
};
try {
if(--R.GAS > 0) {
$z28812882 = $f28872888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28872888,
"from":L[93]});
}
} catch($e28792880) {
if(R.isCont($e28792880)) {
var $ss28832884 = {"from":L[93],
"go":function(anf_arg1812890) {
return $Hanf_arg10192891(anf_arg1812890,anf_arg1792877,_plus5);
}};
$e28792880.stack[R.EXN_STACKHEIGHT++] = $ss28832884;
}
if(R.isPyretException($e28792880)) {
$e28792880.pyretStack.push(L[93]);
}
throw $e28792880;
}
var $ret28852886 = $Hanf_arg10192891($z28812882,anf_arg1792877,_plus5);
++R.GAS;
return $ret28852886;
};
var $Hanf_arg10192891 = function(anf_arg1812890,anf_arg1792877,_plus5) {
var $z28942895 = D;
var $f29002901 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1812890):R.ffi.throwNonFunApp(L[93],_plus5,[(", "),anf_arg1812890]);
};
try {
if(--R.GAS > 0) {
$z28942895 = $f29002901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29002901,
"from":L[93]});
}
} catch($e28922893) {
if(R.isCont($e28922893)) {
var $ss28962897 = {"from":L[93],
"go":function(anf_arg1822902) {
return $Hanf_arg10182903(anf_arg1822902,anf_arg1792877,_plus5);
}};
$e28922893.stack[R.EXN_STACKHEIGHT++] = $ss28962897;
}
if(R.isPyretException($e28922893)) {
$e28922893.pyretStack.push(L[93]);
}
throw $e28922893;
}
var $ret28982899 = $Hanf_arg10182903($z28942895,anf_arg1792877,_plus5);
++R.GAS;
return $ret28982899;
};
var $Hanf_arg10182903 = function(anf_arg1822902,anf_arg1792877,_plus5) {
var $z29062907 = D;
var $f29122913 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1792877,anf_arg1822902):R.ffi.throwNonFunApp(L[93],_plus5,[anf_arg1792877,anf_arg1822902]);
};
try {
if(--R.GAS > 0) {
$z29062907 = $f29122913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29122913,
"from":L[93]});
}
} catch($e29042905) {
if(R.isCont($e29042905)) {
var $ss29082909 = {"from":L[93],
"go":function(anf_arg1832914) {
return $Hanf_arg10172915(anf_arg1832914,_plus5);
}};
$e29042905.stack[R.EXN_STACKHEIGHT++] = $ss29082909;
}
if(R.isPyretException($e29042905)) {
$e29042905.pyretStack.push(L[93]);
}
throw $e29042905;
}
var $ret29102911 = $Hanf_arg10172915($z29062907,_plus5);
++R.GAS;
return $ret29102911;
};
var $Hanf_arg10172915 = function(anf_arg1832914,_plus5) {
var $z29182919 = D;
var $f29242925 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1832914,(")")):R.ffi.throwNonFunApp(L[93],_plus5,[anf_arg1832914,(")")]);
};
try {
if(--R.GAS > 0) {
$z29182919 = $f29242925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29242925,
"from":L[93]});
}
} catch($e29162917) {
if(R.isCont($e29162917)) {
var $ss29202921 = {"from":L[93],
"go":function(anf_arg1842926) {
return $Hanf_arg10162927(anf_arg1842926,_plus5);
}};
$e29162917.stack[R.EXN_STACKHEIGHT++] = $ss29202921;
}
if(R.isPyretException($e29162917)) {
$e29162917.pyretStack.push(L[93]);
}
throw $e29162917;
}
var $ret29222923 = $Hanf_arg10162927($z29182919,_plus5);
++R.GAS;
return $ret29222923;
};
var $Hanf_arg10162927 = function(anf_arg1842926,_plus5) {
var $z29302931 = D;
var $f29362937 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg1842926):R.ffi.throwNonFunApp(L[93],_plus5,[("("),anf_arg1842926]);
};
try {
if(--R.GAS > 0) {
$z29302931 = $f29362937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29362937,
"from":L[93]});
}
} catch($e29282929) {
if(R.isCont($e29282929)) {
var $ss29322933 = {"from":L[93],
"go":function(anf_arg1852938) {
return $Hanf_arg10152939(anf_arg1852938,_plus5);
}};
$e29282929.stack[R.EXN_STACKHEIGHT++] = $ss29322933;
}
if(R.isPyretException($e29282929)) {
$e29282929.pyretStack.push(L[93]);
}
throw $e29282929;
}
var $ret29342935 = $Hanf_arg10152939($z29302931,_plus5);
++R.GAS;
return $ret29342935;
};
var $Hanf_arg10152939 = function(anf_arg1852938,_plus5) {
var $z29422943 = D;
var $f29482949 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("non-boolean-condition"),anf_arg1852938):R.ffi.throwNonFunApp(L[93],_plus5,[("non-boolean-condition"),anf_arg1852938]);
};
try {
if(--R.GAS > 0) {
$z29422943 = $f29482949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29482949,
"from":L[93]});
}
} catch($e29402941) {
if(R.isCont($e29402941)) {
var $ss29442945 = {"from":L[93],
"go":function(ann_DASH_check_DASH_temp1732950) {
return $Hann_DASH_check_DASH_temp10142951(ann_DASH_check_DASH_temp1732950);
}};
$e29402941.stack[R.EXN_STACKHEIGHT++] = $ss29442945;
}
if(R.isPyretException($e29402941)) {
$e29402941.pyretStack.push(L[93]);
}
throw $e29402941;
}
var $ret29462947 = $Hann_DASH_check_DASH_temp10142951($z29422943);
++R.GAS;
return $ret29462947;
};
var $Hann_DASH_check_DASH_temp10142951 = function(ann_DASH_check_DASH_temp1732950) {
return ann_DASH_check_DASH_temp1732950;
};
var $Hcont_tail_arg10122952 = function(cont_tail_arg1702953,if_helper1602954) {
if(--R.GAS > 0) {
$z29552956 = R.isFunction(if_helper1602954)?if_helper1602954.app(cont_tail_arg1702953):R.ffi.throwNonFunApp(L[93],if_helper1602954,[cont_tail_arg1702953]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper1602954)?if_helper1602954.app(cont_tail_arg1702953):R.ffi.throwNonFunApp(L[93],if_helper1602954,[cont_tail_arg1702953]);
},
"from":L[93]});
}
++R.GAS;
return $z29552956;
};
var $Hcont_tail_arg10132957 = function(cont_tail_arg1652958,if_helper1602954) {
if(--R.GAS > 0) {
$z29592960 = R.isFunction(if_helper1602954)?if_helper1602954.app(cont_tail_arg1652958):R.ffi.throwNonFunApp(L[93],if_helper1602954,[cont_tail_arg1652958]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper1602954)?if_helper1602954.app(cont_tail_arg1652958):R.ffi.throwNonFunApp(L[93],if_helper1602954,[cont_tail_arg1652958]);
},
"from":L[93]});
}
++R.GAS;
return $z29592960;
};
var $Hanf_arg10112961 = function(anf_arg1492962,self842963,_plus5,torepr8) {
var $z29662967 = D;
var $f29722973 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error at "),anf_arg1492962):R.ffi.throwNonFunApp(L[94],_plus5,[("Error at "),anf_arg1492962]);
};
try {
if(--R.GAS > 0) {
$z29662967 = $f29722973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29722973,
"from":L[94]});
}
} catch($e29642965) {
if(R.isCont($e29642965)) {
var $ss29682969 = {"from":L[94],
"go":function(anf_arg1502974) {
return $Hanf_arg10102975(anf_arg1502974,self842963,_plus5,torepr8);
}};
$e29642965.stack[R.EXN_STACKHEIGHT++] = $ss29682969;
}
if(R.isPyretException($e29642965)) {
$e29642965.pyretStack.push(L[94]);
}
throw $e29642965;
}
var $ret29702971 = $Hanf_arg10102975($z29662967,self842963,_plus5,torepr8);
++R.GAS;
return $ret29702971;
};
var $Hanf_arg10102975 = function(anf_arg1502974,self842963,_plus5,torepr8) {
var $z29782979 = D;
var $f29842985 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1502974,(": tried to look up field ")):R.ffi.throwNonFunApp(L[94],_plus5,[anf_arg1502974,(": tried to look up field ")]);
};
try {
if(--R.GAS > 0) {
$z29782979 = $f29842985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29842985,
"from":L[94]});
}
} catch($e29762977) {
if(R.isCont($e29762977)) {
var $ss29802981 = {"from":L[94],
"go":function(anf_arg1512986) {
return $Hanf_arg10092987(anf_arg1512986,self842963,_plus5,torepr8);
}};
$e29762977.stack[R.EXN_STACKHEIGHT++] = $ss29802981;
}
if(R.isPyretException($e29762977)) {
$e29762977.pyretStack.push(L[94]);
}
throw $e29762977;
}
var $ret29822983 = $Hanf_arg10092987($z29782979,self842963,_plus5,torepr8);
++R.GAS;
return $ret29822983;
};
var $Hanf_arg10092987 = function(anf_arg1512986,self842963,_plus5,torepr8) {
var anf_arg1522998 = G(self842963,"field",L[95]);
var $z29902991 = D;
var $f29962997 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1512986,anf_arg1522998):R.ffi.throwNonFunApp(L[94],_plus5,[anf_arg1512986,anf_arg1522998]);
};
try {
if(--R.GAS > 0) {
$z29902991 = $f29962997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29962997,
"from":L[94]});
}
} catch($e29882989) {
if(R.isCont($e29882989)) {
var $ss29922993 = {"from":L[94],
"go":function(anf_arg1532999) {
return $Hanf_arg10083000(anf_arg1532999,self842963,_plus5,torepr8);
}};
$e29882989.stack[R.EXN_STACKHEIGHT++] = $ss29922993;
}
if(R.isPyretException($e29882989)) {
$e29882989.pyretStack.push(L[94]);
}
throw $e29882989;
}
var $ret29942995 = $Hanf_arg10083000($z29902991,self842963,_plus5,torepr8);
++R.GAS;
return $ret29942995;
};
var $Hanf_arg10083000 = function(anf_arg1532999,self842963,_plus5,torepr8) {
var $z30033004 = D;
var $f30093010 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1532999,(" on ")):R.ffi.throwNonFunApp(L[94],_plus5,[anf_arg1532999,(" on ")]);
};
try {
if(--R.GAS > 0) {
$z30033004 = $f30093010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30093010,
"from":L[94]});
}
} catch($e30013002) {
if(R.isCont($e30013002)) {
var $ss30053006 = {"from":L[94],
"go":function(anf_arg1543011) {
return $Hanf_arg10073012(anf_arg1543011,self842963,_plus5,torepr8);
}};
$e30013002.stack[R.EXN_STACKHEIGHT++] = $ss30053006;
}
if(R.isPyretException($e30013002)) {
$e30013002.pyretStack.push(L[94]);
}
throw $e30013002;
}
var $ret30073008 = $Hanf_arg10073012($z30033004,self842963,_plus5,torepr8);
++R.GAS;
return $ret30073008;
};
var $Hanf_arg10073012 = function(anf_arg1543011,self842963,_plus5,torepr8) {
var anf_arg1553023 = G(self842963,"non-obj",L[97]);
var $z30153016 = D;
var $f30213022 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1553023):R.ffi.throwNonFunApp(L[96],torepr8,[anf_arg1553023]);
};
try {
if(--R.GAS > 0) {
$z30153016 = $f30213022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30213022,
"from":L[96]});
}
} catch($e30133014) {
if(R.isCont($e30133014)) {
var $ss30173018 = {"from":L[96],
"go":function(anf_arg1563024) {
return $Hanf_arg10063025(anf_arg1563024,anf_arg1543011,_plus5);
}};
$e30133014.stack[R.EXN_STACKHEIGHT++] = $ss30173018;
}
if(R.isPyretException($e30133014)) {
$e30133014.pyretStack.push(L[96]);
}
throw $e30133014;
}
var $ret30193020 = $Hanf_arg10063025($z30153016,anf_arg1543011,_plus5);
++R.GAS;
return $ret30193020;
};
var $Hanf_arg10063025 = function(anf_arg1563024,anf_arg1543011,_plus5) {
var $z30283029 = D;
var $f30343035 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1543011,anf_arg1563024):R.ffi.throwNonFunApp(L[94],_plus5,[anf_arg1543011,anf_arg1563024]);
};
try {
if(--R.GAS > 0) {
$z30283029 = $f30343035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30343035,
"from":L[94]});
}
} catch($e30263027) {
if(R.isCont($e30263027)) {
var $ss30303031 = {"from":L[94],
"go":function(anf_arg1573036) {
return $Hanf_arg10053037(anf_arg1573036,_plus5);
}};
$e30263027.stack[R.EXN_STACKHEIGHT++] = $ss30303031;
}
if(R.isPyretException($e30263027)) {
$e30263027.pyretStack.push(L[94]);
}
throw $e30263027;
}
var $ret30323033 = $Hanf_arg10053037($z30283029,_plus5);
++R.GAS;
return $ret30323033;
};
var $Hanf_arg10053037 = function(anf_arg1573036,_plus5) {
var $z30403041 = D;
var $f30463047 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1573036,(", but it does not have fields")):R.ffi.throwNonFunApp(L[98],_plus5,[anf_arg1573036,(", but it does not have fields")]);
};
try {
if(--R.GAS > 0) {
$z30403041 = $f30463047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30463047,
"from":L[98]});
}
} catch($e30383039) {
if(R.isCont($e30383039)) {
var $ss30423043 = {"from":L[98],
"go":function(ann_DASH_check_DASH_temp1463048) {
return $Hann_DASH_check_DASH_temp10043049(ann_DASH_check_DASH_temp1463048);
}};
$e30383039.stack[R.EXN_STACKHEIGHT++] = $ss30423043;
}
if(R.isPyretException($e30383039)) {
$e30383039.pyretStack.push(L[98]);
}
throw $e30383039;
}
var $ret30443045 = $Hann_DASH_check_DASH_temp10043049($z30403041);
++R.GAS;
return $ret30443045;
};
var $Hann_DASH_check_DASH_temp10043049 = function(ann_DASH_check_DASH_temp1463048) {
return ann_DASH_check_DASH_temp1463048;
};
var $Hanf_arg10033050 = function(anf_arg1343051,self293052,_plus5,torepr8) {
var anf_arg1353063 = G(self293052,"non-obj",L[99]);
var $z30553056 = D;
var $f30613062 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1353063):R.ffi.throwNonFunApp(L[99],torepr8,[anf_arg1353063]);
};
try {
if(--R.GAS > 0) {
$z30553056 = $f30613062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30613062,
"from":L[99]});
}
} catch($e30533054) {
if(R.isCont($e30533054)) {
var $ss30573058 = {"from":L[99],
"go":function(anf_arg1363064) {
return $Hanf_arg10023065(anf_arg1363064,anf_arg1343051,self293052,_plus5,torepr8);
}};
$e30533054.stack[R.EXN_STACKHEIGHT++] = $ss30573058;
}
if(R.isPyretException($e30533054)) {
$e30533054.pyretStack.push(L[99]);
}
throw $e30533054;
}
var $ret30593060 = $Hanf_arg10023065($z30553056,anf_arg1343051,self293052,_plus5,torepr8);
++R.GAS;
return $ret30593060;
};
var $Hanf_arg10023065 = function(anf_arg1363064,anf_arg1343051,self293052,_plus5,torepr8) {
var $z30683069 = D;
var $f30743075 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1363064):R.ffi.throwNonFunApp(L[99],_plus5,[(", "),anf_arg1363064]);
};
try {
if(--R.GAS > 0) {
$z30683069 = $f30743075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30743075,
"from":L[99]});
}
} catch($e30663067) {
if(R.isCont($e30663067)) {
var $ss30703071 = {"from":L[99],
"go":function(anf_arg1373076) {
return $Hanf_arg10013077(anf_arg1373076,anf_arg1343051,self293052,_plus5,torepr8);
}};
$e30663067.stack[R.EXN_STACKHEIGHT++] = $ss30703071;
}
if(R.isPyretException($e30663067)) {
$e30663067.pyretStack.push(L[99]);
}
throw $e30663067;
}
var $ret30723073 = $Hanf_arg10013077($z30683069,anf_arg1343051,self293052,_plus5,torepr8);
++R.GAS;
return $ret30723073;
};
var $Hanf_arg10013077 = function(anf_arg1373076,anf_arg1343051,self293052,_plus5,torepr8) {
var $z30803081 = D;
var $f30863087 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1343051,anf_arg1373076):R.ffi.throwNonFunApp(L[99],_plus5,[anf_arg1343051,anf_arg1373076]);
};
try {
if(--R.GAS > 0) {
$z30803081 = $f30863087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30863087,
"from":L[99]});
}
} catch($e30783079) {
if(R.isCont($e30783079)) {
var $ss30823083 = {"from":L[99],
"go":function(anf_arg1383088) {
return $Hanf_arg10003089(anf_arg1383088,self293052,_plus5,torepr8);
}};
$e30783079.stack[R.EXN_STACKHEIGHT++] = $ss30823083;
}
if(R.isPyretException($e30783079)) {
$e30783079.pyretStack.push(L[99]);
}
throw $e30783079;
}
var $ret30843085 = $Hanf_arg10003089($z30803081,self293052,_plus5,torepr8);
++R.GAS;
return $ret30843085;
};
var $Hanf_arg10003089 = function(anf_arg1383088,self293052,_plus5,torepr8) {
var anf_arg1393100 = G(self293052,"field",L[99]);
var $z30923093 = D;
var $f30983099 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1393100):R.ffi.throwNonFunApp(L[99],torepr8,[anf_arg1393100]);
};
try {
if(--R.GAS > 0) {
$z30923093 = $f30983099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30983099,
"from":L[99]});
}
} catch($e30903091) {
if(R.isCont($e30903091)) {
var $ss30943095 = {"from":L[99],
"go":function(anf_arg1403101) {
return $Hanf_arg9993102(anf_arg1403101,anf_arg1383088,_plus5);
}};
$e30903091.stack[R.EXN_STACKHEIGHT++] = $ss30943095;
}
if(R.isPyretException($e30903091)) {
$e30903091.pyretStack.push(L[99]);
}
throw $e30903091;
}
var $ret30963097 = $Hanf_arg9993102($z30923093,anf_arg1383088,_plus5);
++R.GAS;
return $ret30963097;
};
var $Hanf_arg9993102 = function(anf_arg1403101,anf_arg1383088,_plus5) {
var $z31053106 = D;
var $f31113112 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1403101):R.ffi.throwNonFunApp(L[99],_plus5,[(", "),anf_arg1403101]);
};
try {
if(--R.GAS > 0) {
$z31053106 = $f31113112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31113112,
"from":L[99]});
}
} catch($e31033104) {
if(R.isCont($e31033104)) {
var $ss31073108 = {"from":L[99],
"go":function(anf_arg1413113) {
return $Hanf_arg9983114(anf_arg1413113,anf_arg1383088,_plus5);
}};
$e31033104.stack[R.EXN_STACKHEIGHT++] = $ss31073108;
}
if(R.isPyretException($e31033104)) {
$e31033104.pyretStack.push(L[99]);
}
throw $e31033104;
}
var $ret31093110 = $Hanf_arg9983114($z31053106,anf_arg1383088,_plus5);
++R.GAS;
return $ret31093110;
};
var $Hanf_arg9983114 = function(anf_arg1413113,anf_arg1383088,_plus5) {
var $z31173118 = D;
var $f31233124 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1383088,anf_arg1413113):R.ffi.throwNonFunApp(L[99],_plus5,[anf_arg1383088,anf_arg1413113]);
};
try {
if(--R.GAS > 0) {
$z31173118 = $f31233124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31233124,
"from":L[99]});
}
} catch($e31153116) {
if(R.isCont($e31153116)) {
var $ss31193120 = {"from":L[99],
"go":function(anf_arg1423125) {
return $Hanf_arg9973126(anf_arg1423125,_plus5);
}};
$e31153116.stack[R.EXN_STACKHEIGHT++] = $ss31193120;
}
if(R.isPyretException($e31153116)) {
$e31153116.pyretStack.push(L[99]);
}
throw $e31153116;
}
var $ret31213122 = $Hanf_arg9973126($z31173118,_plus5);
++R.GAS;
return $ret31213122;
};
var $Hanf_arg9973126 = function(anf_arg1423125,_plus5) {
var $z31293130 = D;
var $f31353136 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1423125,(")")):R.ffi.throwNonFunApp(L[99],_plus5,[anf_arg1423125,(")")]);
};
try {
if(--R.GAS > 0) {
$z31293130 = $f31353136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31353136,
"from":L[99]});
}
} catch($e31273128) {
if(R.isCont($e31273128)) {
var $ss31313132 = {"from":L[99],
"go":function(anf_arg1433137) {
return $Hanf_arg9963138(anf_arg1433137,_plus5);
}};
$e31273128.stack[R.EXN_STACKHEIGHT++] = $ss31313132;
}
if(R.isPyretException($e31273128)) {
$e31273128.pyretStack.push(L[99]);
}
throw $e31273128;
}
var $ret31333134 = $Hanf_arg9963138($z31293130,_plus5);
++R.GAS;
return $ret31333134;
};
var $Hanf_arg9963138 = function(anf_arg1433137,_plus5) {
var $z31413142 = D;
var $f31473148 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg1433137):R.ffi.throwNonFunApp(L[99],_plus5,[("("),anf_arg1433137]);
};
try {
if(--R.GAS > 0) {
$z31413142 = $f31473148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31473148,
"from":L[99]});
}
} catch($e31393140) {
if(R.isCont($e31393140)) {
var $ss31433144 = {"from":L[99],
"go":function(anf_arg1443149) {
return $Hanf_arg9953150(anf_arg1443149,_plus5);
}};
$e31393140.stack[R.EXN_STACKHEIGHT++] = $ss31433144;
}
if(R.isPyretException($e31393140)) {
$e31393140.pyretStack.push(L[99]);
}
throw $e31393140;
}
var $ret31453146 = $Hanf_arg9953150($z31413142,_plus5);
++R.GAS;
return $ret31453146;
};
var $Hanf_arg9953150 = function(anf_arg1443149,_plus5) {
var $z31533154 = D;
var $f31593160 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("lookup-non-object"),anf_arg1443149):R.ffi.throwNonFunApp(L[99],_plus5,[("lookup-non-object"),anf_arg1443149]);
};
try {
if(--R.GAS > 0) {
$z31533154 = $f31593160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31593160,
"from":L[99]});
}
} catch($e31513152) {
if(R.isCont($e31513152)) {
var $ss31553156 = {"from":L[99],
"go":function(ann_DASH_check_DASH_temp1323161) {
return $Hann_DASH_check_DASH_temp9943162(ann_DASH_check_DASH_temp1323161);
}};
$e31513152.stack[R.EXN_STACKHEIGHT++] = $ss31553156;
}
if(R.isPyretException($e31513152)) {
$e31513152.pyretStack.push(L[99]);
}
throw $e31513152;
}
var $ret31573158 = $Hann_DASH_check_DASH_temp9943162($z31533154);
++R.GAS;
return $ret31573158;
};
var $Hann_DASH_check_DASH_temp9943162 = function(ann_DASH_check_DASH_temp1323161) {
return ann_DASH_check_DASH_temp1323161;
};
var $Hcont_tail_arg9923163 = function(cont_tail_arg1293164,if_helper1193165) {
if(--R.GAS > 0) {
$z31663167 = R.isFunction(if_helper1193165)?if_helper1193165.app(cont_tail_arg1293164):R.ffi.throwNonFunApp(L[99],if_helper1193165,[cont_tail_arg1293164]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper1193165)?if_helper1193165.app(cont_tail_arg1293164):R.ffi.throwNonFunApp(L[99],if_helper1193165,[cont_tail_arg1293164]);
},
"from":L[99]});
}
++R.GAS;
return $z31663167;
};
var $Hcont_tail_arg9933168 = function(cont_tail_arg1243169,if_helper1193165) {
if(--R.GAS > 0) {
$z31703171 = R.isFunction(if_helper1193165)?if_helper1193165.app(cont_tail_arg1243169):R.ffi.throwNonFunApp(L[99],if_helper1193165,[cont_tail_arg1243169]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper1193165)?if_helper1193165.app(cont_tail_arg1243169):R.ffi.throwNonFunApp(L[99],if_helper1193165,[cont_tail_arg1243169]);
},
"from":L[99]});
}
++R.GAS;
return $z31703171;
};
var $Hanf_arg9913172 = function(anf_arg1093173,self803174,_plus5,torepr8) {
var $z31773178 = D;
var $f31833184 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error at "),anf_arg1093173):R.ffi.throwNonFunApp(L[100],_plus5,[("Error at "),anf_arg1093173]);
};
try {
if(--R.GAS > 0) {
$z31773178 = $f31833184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31833184,
"from":L[100]});
}
} catch($e31753176) {
if(R.isCont($e31753176)) {
var $ss31793180 = {"from":L[100],
"go":function(anf_arg1103185) {
return $Hanf_arg9903186(anf_arg1103185,self803174,_plus5,torepr8);
}};
$e31753176.stack[R.EXN_STACKHEIGHT++] = $ss31793180;
}
if(R.isPyretException($e31753176)) {
$e31753176.pyretStack.push(L[100]);
}
throw $e31753176;
}
var $ret31813182 = $Hanf_arg9903186($z31773178,self803174,_plus5,torepr8);
++R.GAS;
return $ret31813182;
};
var $Hanf_arg9903186 = function(anf_arg1103185,self803174,_plus5,torepr8) {
var $z31893190 = D;
var $f31953196 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1103185,(": field ")):R.ffi.throwNonFunApp(L[100],_plus5,[anf_arg1103185,(": field ")]);
};
try {
if(--R.GAS > 0) {
$z31893190 = $f31953196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31953196,
"from":L[100]});
}
} catch($e31873188) {
if(R.isCont($e31873188)) {
var $ss31913192 = {"from":L[100],
"go":function(anf_arg1113197) {
return $Hanf_arg9893198(anf_arg1113197,self803174,_plus5,torepr8);
}};
$e31873188.stack[R.EXN_STACKHEIGHT++] = $ss31913192;
}
if(R.isPyretException($e31873188)) {
$e31873188.pyretStack.push(L[100]);
}
throw $e31873188;
}
var $ret31933194 = $Hanf_arg9893198($z31893190,self803174,_plus5,torepr8);
++R.GAS;
return $ret31933194;
};
var $Hanf_arg9893198 = function(anf_arg1113197,self803174,_plus5,torepr8) {
var anf_arg1123209 = G(self803174,"field",L[101]);
var $z32013202 = D;
var $f32073208 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1113197,anf_arg1123209):R.ffi.throwNonFunApp(L[100],_plus5,[anf_arg1113197,anf_arg1123209]);
};
try {
if(--R.GAS > 0) {
$z32013202 = $f32073208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32073208,
"from":L[100]});
}
} catch($e31993200) {
if(R.isCont($e31993200)) {
var $ss32033204 = {"from":L[100],
"go":function(anf_arg1133210) {
return $Hanf_arg9883211(anf_arg1133210,self803174,_plus5,torepr8);
}};
$e31993200.stack[R.EXN_STACKHEIGHT++] = $ss32033204;
}
if(R.isPyretException($e31993200)) {
$e31993200.pyretStack.push(L[100]);
}
throw $e31993200;
}
var $ret32053206 = $Hanf_arg9883211($z32013202,self803174,_plus5,torepr8);
++R.GAS;
return $ret32053206;
};
var $Hanf_arg9883211 = function(anf_arg1133210,self803174,_plus5,torepr8) {
var $z32143215 = D;
var $f32203221 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1133210,(" not found on ")):R.ffi.throwNonFunApp(L[100],_plus5,[anf_arg1133210,(" not found on ")]);
};
try {
if(--R.GAS > 0) {
$z32143215 = $f32203221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32203221,
"from":L[100]});
}
} catch($e32123213) {
if(R.isCont($e32123213)) {
var $ss32163217 = {"from":L[100],
"go":function(anf_arg1143222) {
return $Hanf_arg9873223(anf_arg1143222,self803174,_plus5,torepr8);
}};
$e32123213.stack[R.EXN_STACKHEIGHT++] = $ss32163217;
}
if(R.isPyretException($e32123213)) {
$e32123213.pyretStack.push(L[100]);
}
throw $e32123213;
}
var $ret32183219 = $Hanf_arg9873223($z32143215,self803174,_plus5,torepr8);
++R.GAS;
return $ret32183219;
};
var $Hanf_arg9873223 = function(anf_arg1143222,self803174,_plus5,torepr8) {
var anf_arg1153234 = G(self803174,"obj",L[103]);
var $z32263227 = D;
var $f32323233 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1153234):R.ffi.throwNonFunApp(L[102],torepr8,[anf_arg1153234]);
};
try {
if(--R.GAS > 0) {
$z32263227 = $f32323233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32323233,
"from":L[102]});
}
} catch($e32243225) {
if(R.isCont($e32243225)) {
var $ss32283229 = {"from":L[102],
"go":function(anf_arg1163235) {
return $Hanf_arg9863236(anf_arg1163235,anf_arg1143222,_plus5);
}};
$e32243225.stack[R.EXN_STACKHEIGHT++] = $ss32283229;
}
if(R.isPyretException($e32243225)) {
$e32243225.pyretStack.push(L[102]);
}
throw $e32243225;
}
var $ret32303231 = $Hanf_arg9863236($z32263227,anf_arg1143222,_plus5);
++R.GAS;
return $ret32303231;
};
var $Hanf_arg9863236 = function(anf_arg1163235,anf_arg1143222,_plus5) {
var $z32393240 = D;
var $f32453246 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1143222,anf_arg1163235):R.ffi.throwNonFunApp(L[104],_plus5,[anf_arg1143222,anf_arg1163235]);
};
try {
if(--R.GAS > 0) {
$z32393240 = $f32453246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32453246,
"from":L[104]});
}
} catch($e32373238) {
if(R.isCont($e32373238)) {
var $ss32413242 = {"from":L[104],
"go":function(ann_DASH_check_DASH_temp1063247) {
return $Hann_DASH_check_DASH_temp9853248(ann_DASH_check_DASH_temp1063247);
}};
$e32373238.stack[R.EXN_STACKHEIGHT++] = $ss32413242;
}
if(R.isPyretException($e32373238)) {
$e32373238.pyretStack.push(L[104]);
}
throw $e32373238;
}
var $ret32433244 = $Hann_DASH_check_DASH_temp9853248($z32393240);
++R.GAS;
return $ret32433244;
};
var $Hann_DASH_check_DASH_temp9853248 = function(ann_DASH_check_DASH_temp1063247) {
return ann_DASH_check_DASH_temp1063247;
};
var $Hanf_arg9843249 = function(anf_arg943250,self233251,_plus5,torepr8) {
var anf_arg953262 = G(self233251,"obj",L[105]);
var $z32543255 = D;
var $f32603261 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg953262):R.ffi.throwNonFunApp(L[105],torepr8,[anf_arg953262]);
};
try {
if(--R.GAS > 0) {
$z32543255 = $f32603261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32603261,
"from":L[105]});
}
} catch($e32523253) {
if(R.isCont($e32523253)) {
var $ss32563257 = {"from":L[105],
"go":function(anf_arg963263) {
return $Hanf_arg9833264(anf_arg963263,anf_arg943250,self233251,_plus5,torepr8);
}};
$e32523253.stack[R.EXN_STACKHEIGHT++] = $ss32563257;
}
if(R.isPyretException($e32523253)) {
$e32523253.pyretStack.push(L[105]);
}
throw $e32523253;
}
var $ret32583259 = $Hanf_arg9833264($z32543255,anf_arg943250,self233251,_plus5,torepr8);
++R.GAS;
return $ret32583259;
};
var $Hanf_arg9833264 = function(anf_arg963263,anf_arg943250,self233251,_plus5,torepr8) {
var $z32673268 = D;
var $f32733274 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg963263):R.ffi.throwNonFunApp(L[105],_plus5,[(", "),anf_arg963263]);
};
try {
if(--R.GAS > 0) {
$z32673268 = $f32733274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32733274,
"from":L[105]});
}
} catch($e32653266) {
if(R.isCont($e32653266)) {
var $ss32693270 = {"from":L[105],
"go":function(anf_arg973275) {
return $Hanf_arg9823276(anf_arg973275,anf_arg943250,self233251,_plus5,torepr8);
}};
$e32653266.stack[R.EXN_STACKHEIGHT++] = $ss32693270;
}
if(R.isPyretException($e32653266)) {
$e32653266.pyretStack.push(L[105]);
}
throw $e32653266;
}
var $ret32713272 = $Hanf_arg9823276($z32673268,anf_arg943250,self233251,_plus5,torepr8);
++R.GAS;
return $ret32713272;
};
var $Hanf_arg9823276 = function(anf_arg973275,anf_arg943250,self233251,_plus5,torepr8) {
var $z32793280 = D;
var $f32853286 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg943250,anf_arg973275):R.ffi.throwNonFunApp(L[105],_plus5,[anf_arg943250,anf_arg973275]);
};
try {
if(--R.GAS > 0) {
$z32793280 = $f32853286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32853286,
"from":L[105]});
}
} catch($e32773278) {
if(R.isCont($e32773278)) {
var $ss32813282 = {"from":L[105],
"go":function(anf_arg983287) {
return $Hanf_arg9813288(anf_arg983287,self233251,_plus5,torepr8);
}};
$e32773278.stack[R.EXN_STACKHEIGHT++] = $ss32813282;
}
if(R.isPyretException($e32773278)) {
$e32773278.pyretStack.push(L[105]);
}
throw $e32773278;
}
var $ret32833284 = $Hanf_arg9813288($z32793280,self233251,_plus5,torepr8);
++R.GAS;
return $ret32833284;
};
var $Hanf_arg9813288 = function(anf_arg983287,self233251,_plus5,torepr8) {
var anf_arg993299 = G(self233251,"field",L[105]);
var $z32913292 = D;
var $f32973298 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg993299):R.ffi.throwNonFunApp(L[105],torepr8,[anf_arg993299]);
};
try {
if(--R.GAS > 0) {
$z32913292 = $f32973298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32973298,
"from":L[105]});
}
} catch($e32893290) {
if(R.isCont($e32893290)) {
var $ss32933294 = {"from":L[105],
"go":function(anf_arg1003300) {
return $Hanf_arg9803301(anf_arg1003300,anf_arg983287,_plus5);
}};
$e32893290.stack[R.EXN_STACKHEIGHT++] = $ss32933294;
}
if(R.isPyretException($e32893290)) {
$e32893290.pyretStack.push(L[105]);
}
throw $e32893290;
}
var $ret32953296 = $Hanf_arg9803301($z32913292,anf_arg983287,_plus5);
++R.GAS;
return $ret32953296;
};
var $Hanf_arg9803301 = function(anf_arg1003300,anf_arg983287,_plus5) {
var $z33043305 = D;
var $f33103311 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1003300):R.ffi.throwNonFunApp(L[105],_plus5,[(", "),anf_arg1003300]);
};
try {
if(--R.GAS > 0) {
$z33043305 = $f33103311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33103311,
"from":L[105]});
}
} catch($e33023303) {
if(R.isCont($e33023303)) {
var $ss33063307 = {"from":L[105],
"go":function(anf_arg1013312) {
return $Hanf_arg9793313(anf_arg1013312,anf_arg983287,_plus5);
}};
$e33023303.stack[R.EXN_STACKHEIGHT++] = $ss33063307;
}
if(R.isPyretException($e33023303)) {
$e33023303.pyretStack.push(L[105]);
}
throw $e33023303;
}
var $ret33083309 = $Hanf_arg9793313($z33043305,anf_arg983287,_plus5);
++R.GAS;
return $ret33083309;
};
var $Hanf_arg9793313 = function(anf_arg1013312,anf_arg983287,_plus5) {
var $z33163317 = D;
var $f33223323 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg983287,anf_arg1013312):R.ffi.throwNonFunApp(L[105],_plus5,[anf_arg983287,anf_arg1013312]);
};
try {
if(--R.GAS > 0) {
$z33163317 = $f33223323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33223323,
"from":L[105]});
}
} catch($e33143315) {
if(R.isCont($e33143315)) {
var $ss33183319 = {"from":L[105],
"go":function(anf_arg1023324) {
return $Hanf_arg9783325(anf_arg1023324,_plus5);
}};
$e33143315.stack[R.EXN_STACKHEIGHT++] = $ss33183319;
}
if(R.isPyretException($e33143315)) {
$e33143315.pyretStack.push(L[105]);
}
throw $e33143315;
}
var $ret33203321 = $Hanf_arg9783325($z33163317,_plus5);
++R.GAS;
return $ret33203321;
};
var $Hanf_arg9783325 = function(anf_arg1023324,_plus5) {
var $z33283329 = D;
var $f33343335 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1023324,(")")):R.ffi.throwNonFunApp(L[105],_plus5,[anf_arg1023324,(")")]);
};
try {
if(--R.GAS > 0) {
$z33283329 = $f33343335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33343335,
"from":L[105]});
}
} catch($e33263327) {
if(R.isCont($e33263327)) {
var $ss33303331 = {"from":L[105],
"go":function(anf_arg1033336) {
return $Hanf_arg9773337(anf_arg1033336,_plus5);
}};
$e33263327.stack[R.EXN_STACKHEIGHT++] = $ss33303331;
}
if(R.isPyretException($e33263327)) {
$e33263327.pyretStack.push(L[105]);
}
throw $e33263327;
}
var $ret33323333 = $Hanf_arg9773337($z33283329,_plus5);
++R.GAS;
return $ret33323333;
};
var $Hanf_arg9773337 = function(anf_arg1033336,_plus5) {
var $z33403341 = D;
var $f33463347 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg1033336):R.ffi.throwNonFunApp(L[105],_plus5,[("("),anf_arg1033336]);
};
try {
if(--R.GAS > 0) {
$z33403341 = $f33463347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33463347,
"from":L[105]});
}
} catch($e33383339) {
if(R.isCont($e33383339)) {
var $ss33423343 = {"from":L[105],
"go":function(anf_arg1043348) {
return $Hanf_arg9763349(anf_arg1043348,_plus5);
}};
$e33383339.stack[R.EXN_STACKHEIGHT++] = $ss33423343;
}
if(R.isPyretException($e33383339)) {
$e33383339.pyretStack.push(L[105]);
}
throw $e33383339;
}
var $ret33443345 = $Hanf_arg9763349($z33403341,_plus5);
++R.GAS;
return $ret33443345;
};
var $Hanf_arg9763349 = function(anf_arg1043348,_plus5) {
var $z33523353 = D;
var $f33583359 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("field-not-found"),anf_arg1043348):R.ffi.throwNonFunApp(L[105],_plus5,[("field-not-found"),anf_arg1043348]);
};
try {
if(--R.GAS > 0) {
$z33523353 = $f33583359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33583359,
"from":L[105]});
}
} catch($e33503351) {
if(R.isCont($e33503351)) {
var $ss33543355 = {"from":L[105],
"go":function(ann_DASH_check_DASH_temp923360) {
return $Hann_DASH_check_DASH_temp9753361(ann_DASH_check_DASH_temp923360);
}};
$e33503351.stack[R.EXN_STACKHEIGHT++] = $ss33543355;
}
if(R.isPyretException($e33503351)) {
$e33503351.pyretStack.push(L[105]);
}
throw $e33503351;
}
var $ret33563357 = $Hann_DASH_check_DASH_temp9753361($z33523353);
++R.GAS;
return $ret33563357;
};
var $Hann_DASH_check_DASH_temp9753361 = function(ann_DASH_check_DASH_temp923360) {
return ann_DASH_check_DASH_temp923360;
};
var $Hcont_tail_arg9733362 = function(cont_tail_arg893363,if_helper793364) {
if(--R.GAS > 0) {
$z33653366 = R.isFunction(if_helper793364)?if_helper793364.app(cont_tail_arg893363):R.ffi.throwNonFunApp(L[105],if_helper793364,[cont_tail_arg893363]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper793364)?if_helper793364.app(cont_tail_arg893363):R.ffi.throwNonFunApp(L[105],if_helper793364,[cont_tail_arg893363]);
},
"from":L[105]});
}
++R.GAS;
return $z33653366;
};
var $Hcont_tail_arg9743367 = function(cont_tail_arg843368,if_helper793364) {
if(--R.GAS > 0) {
$z33693370 = R.isFunction(if_helper793364)?if_helper793364.app(cont_tail_arg843368):R.ffi.throwNonFunApp(L[105],if_helper793364,[cont_tail_arg843368]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper793364)?if_helper793364.app(cont_tail_arg843368):R.ffi.throwNonFunApp(L[105],if_helper793364,[cont_tail_arg843368]);
},
"from":L[105]});
}
++R.GAS;
return $z33693370;
};
var $Hanf_arg9723371 = function(anf_arg733372,self763373,_plus5,torepr8) {
var $z33763377 = D;
var $f33823383 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg733372,("; relevant arguments: ")):R.ffi.throwNonFunApp(L[106],_plus5,[anf_arg733372,("; relevant arguments: ")]);
};
try {
if(--R.GAS > 0) {
$z33763377 = $f33823383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33823383,
"from":L[106]});
}
} catch($e33743375) {
if(R.isCont($e33743375)) {
var $ss33783379 = {"from":L[106],
"go":function(anf_arg743384) {
return $Hanf_arg9713385(anf_arg743384,self763373,_plus5,torepr8);
}};
$e33743375.stack[R.EXN_STACKHEIGHT++] = $ss33783379;
}
if(R.isPyretException($e33743375)) {
$e33743375.pyretStack.push(L[106]);
}
throw $e33743375;
}
var $ret33803381 = $Hanf_arg9713385($z33763377,self763373,_plus5,torepr8);
++R.GAS;
return $ret33803381;
};
var $Hanf_arg9713385 = function(anf_arg743384,self763373,_plus5,torepr8) {
var anf_arg753396 = G(self763373,"info-args",L[108]);
var $z33883389 = D;
var $f33943395 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg753396):R.ffi.throwNonFunApp(L[107],torepr8,[anf_arg753396]);
};
try {
if(--R.GAS > 0) {
$z33883389 = $f33943395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33943395,
"from":L[107]});
}
} catch($e33863387) {
if(R.isCont($e33863387)) {
var $ss33903391 = {"from":L[107],
"go":function(anf_arg763397) {
return $Hanf_arg9703398(anf_arg763397,anf_arg743384,_plus5);
}};
$e33863387.stack[R.EXN_STACKHEIGHT++] = $ss33903391;
}
if(R.isPyretException($e33863387)) {
$e33863387.pyretStack.push(L[107]);
}
throw $e33863387;
}
var $ret33923393 = $Hanf_arg9703398($z33883389,anf_arg743384,_plus5);
++R.GAS;
return $ret33923393;
};
var $Hanf_arg9703398 = function(anf_arg763397,anf_arg743384,_plus5) {
var $z34013402 = D;
var $f34073408 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg743384,anf_arg763397):R.ffi.throwNonFunApp(L[109],_plus5,[anf_arg743384,anf_arg763397]);
};
try {
if(--R.GAS > 0) {
$z34013402 = $f34073408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34073408,
"from":L[109]});
}
} catch($e33993400) {
if(R.isCont($e33993400)) {
var $ss34033404 = {"from":L[109],
"go":function(ann_DASH_check_DASH_temp713409) {
return $Hann_DASH_check_DASH_temp9693410(ann_DASH_check_DASH_temp713409);
}};
$e33993400.stack[R.EXN_STACKHEIGHT++] = $ss34033404;
}
if(R.isPyretException($e33993400)) {
$e33993400.pyretStack.push(L[109]);
}
throw $e33993400;
}
var $ret34053406 = $Hann_DASH_check_DASH_temp9693410($z34013402);
++R.GAS;
return $ret34053406;
};
var $Hann_DASH_check_DASH_temp9693410 = function(ann_DASH_check_DASH_temp713409) {
return ann_DASH_check_DASH_temp713409;
};
var $Hanf_arg9683411 = function(anf_arg633412,self173413,_plus5,torepr8) {
var anf_arg643424 = G(self173413,"info-args",L[110]);
var $z34163417 = D;
var $f34223423 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg643424):R.ffi.throwNonFunApp(L[110],torepr8,[anf_arg643424]);
};
try {
if(--R.GAS > 0) {
$z34163417 = $f34223423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34223423,
"from":L[110]});
}
} catch($e34143415) {
if(R.isCont($e34143415)) {
var $ss34183419 = {"from":L[110],
"go":function(anf_arg653425) {
return $Hanf_arg9673426(anf_arg653425,anf_arg633412,_plus5);
}};
$e34143415.stack[R.EXN_STACKHEIGHT++] = $ss34183419;
}
if(R.isPyretException($e34143415)) {
$e34143415.pyretStack.push(L[110]);
}
throw $e34143415;
}
var $ret34203421 = $Hanf_arg9673426($z34163417,anf_arg633412,_plus5);
++R.GAS;
return $ret34203421;
};
var $Hanf_arg9673426 = function(anf_arg653425,anf_arg633412,_plus5) {
var $z34293430 = D;
var $f34353436 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg653425):R.ffi.throwNonFunApp(L[110],_plus5,[(", "),anf_arg653425]);
};
try {
if(--R.GAS > 0) {
$z34293430 = $f34353436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34353436,
"from":L[110]});
}
} catch($e34273428) {
if(R.isCont($e34273428)) {
var $ss34313432 = {"from":L[110],
"go":function(anf_arg663437) {
return $Hanf_arg9663438(anf_arg663437,anf_arg633412,_plus5);
}};
$e34273428.stack[R.EXN_STACKHEIGHT++] = $ss34313432;
}
if(R.isPyretException($e34273428)) {
$e34273428.pyretStack.push(L[110]);
}
throw $e34273428;
}
var $ret34333434 = $Hanf_arg9663438($z34293430,anf_arg633412,_plus5);
++R.GAS;
return $ret34333434;
};
var $Hanf_arg9663438 = function(anf_arg663437,anf_arg633412,_plus5) {
var $z34413442 = D;
var $f34473448 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg633412,anf_arg663437):R.ffi.throwNonFunApp(L[110],_plus5,[anf_arg633412,anf_arg663437]);
};
try {
if(--R.GAS > 0) {
$z34413442 = $f34473448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34473448,
"from":L[110]});
}
} catch($e34393440) {
if(R.isCont($e34393440)) {
var $ss34433444 = {"from":L[110],
"go":function(anf_arg673449) {
return $Hanf_arg9653450(anf_arg673449,_plus5);
}};
$e34393440.stack[R.EXN_STACKHEIGHT++] = $ss34433444;
}
if(R.isPyretException($e34393440)) {
$e34393440.pyretStack.push(L[110]);
}
throw $e34393440;
}
var $ret34453446 = $Hanf_arg9653450($z34413442,_plus5);
++R.GAS;
return $ret34453446;
};
var $Hanf_arg9653450 = function(anf_arg673449,_plus5) {
var $z34533454 = D;
var $f34593460 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg673449,(")")):R.ffi.throwNonFunApp(L[110],_plus5,[anf_arg673449,(")")]);
};
try {
if(--R.GAS > 0) {
$z34533454 = $f34593460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34593460,
"from":L[110]});
}
} catch($e34513452) {
if(R.isCont($e34513452)) {
var $ss34553456 = {"from":L[110],
"go":function(anf_arg683461) {
return $Hanf_arg9643462(anf_arg683461,_plus5);
}};
$e34513452.stack[R.EXN_STACKHEIGHT++] = $ss34553456;
}
if(R.isPyretException($e34513452)) {
$e34513452.pyretStack.push(L[110]);
}
throw $e34513452;
}
var $ret34573458 = $Hanf_arg9643462($z34533454,_plus5);
++R.GAS;
return $ret34573458;
};
var $Hanf_arg9643462 = function(anf_arg683461,_plus5) {
var $z34653466 = D;
var $f34713472 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg683461):R.ffi.throwNonFunApp(L[110],_plus5,[("("),anf_arg683461]);
};
try {
if(--R.GAS > 0) {
$z34653466 = $f34713472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34713472,
"from":L[110]});
}
} catch($e34633464) {
if(R.isCont($e34633464)) {
var $ss34673468 = {"from":L[110],
"go":function(anf_arg693473) {
return $Hanf_arg9633474(anf_arg693473,_plus5);
}};
$e34633464.stack[R.EXN_STACKHEIGHT++] = $ss34673468;
}
if(R.isPyretException($e34633464)) {
$e34633464.pyretStack.push(L[110]);
}
throw $e34633464;
}
var $ret34693470 = $Hanf_arg9633474($z34653466,_plus5);
++R.GAS;
return $ret34693470;
};
var $Hanf_arg9633474 = function(anf_arg693473,_plus5) {
var $z34773478 = D;
var $f34833484 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("internal-error"),anf_arg693473):R.ffi.throwNonFunApp(L[110],_plus5,[("internal-error"),anf_arg693473]);
};
try {
if(--R.GAS > 0) {
$z34773478 = $f34833484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34833484,
"from":L[110]});
}
} catch($e34753476) {
if(R.isCont($e34753476)) {
var $ss34793480 = {"from":L[110],
"go":function(ann_DASH_check_DASH_temp613485) {
return $Hann_DASH_check_DASH_temp9623486(ann_DASH_check_DASH_temp613485);
}};
$e34753476.stack[R.EXN_STACKHEIGHT++] = $ss34793480;
}
if(R.isPyretException($e34753476)) {
$e34753476.pyretStack.push(L[110]);
}
throw $e34753476;
}
var $ret34813482 = $Hann_DASH_check_DASH_temp9623486($z34773478);
++R.GAS;
return $ret34813482;
};
var $Hann_DASH_check_DASH_temp9623486 = function(ann_DASH_check_DASH_temp613485) {
return ann_DASH_check_DASH_temp613485;
};
var $Hcont_tail_arg9603487 = function(cont_tail_arg583488,if_helper493489) {
if(--R.GAS > 0) {
$z34903491 = R.isFunction(if_helper493489)?if_helper493489.app(cont_tail_arg583488):R.ffi.throwNonFunApp(L[110],if_helper493489,[cont_tail_arg583488]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper493489)?if_helper493489.app(cont_tail_arg583488):R.ffi.throwNonFunApp(L[110],if_helper493489,[cont_tail_arg583488]);
},
"from":L[110]});
}
++R.GAS;
return $z34903491;
};
var $Hcont_tail_arg9613492 = function(cont_tail_arg543493,if_helper493489) {
if(--R.GAS > 0) {
$z34943495 = R.isFunction(if_helper493489)?if_helper493489.app(cont_tail_arg543493):R.ffi.throwNonFunApp(L[110],if_helper493489,[cont_tail_arg543493]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper493489)?if_helper493489.app(cont_tail_arg543493):R.ffi.throwNonFunApp(L[110],if_helper493489,[cont_tail_arg543493]);
},
"from":L[110]});
}
++R.GAS;
return $z34943495;
};
var $Hanf_arg9593496 = function(anf_arg463497,_plus5) {
var $z35003501 = D;
var $f35063507 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg463497,("` expression")):R.ffi.throwNonFunApp(L[111],_plus5,[anf_arg463497,("` expression")]);
};
try {
if(--R.GAS > 0) {
$z35003501 = $f35063507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35063507,
"from":L[111]});
}
} catch($e34983499) {
if(R.isCont($e34983499)) {
var $ss35023503 = {"from":L[111],
"go":function(ann_DASH_check_DASH_temp443508) {
return $Hann_DASH_check_DASH_temp9583509(ann_DASH_check_DASH_temp443508);
}};
$e34983499.stack[R.EXN_STACKHEIGHT++] = $ss35023503;
}
if(R.isPyretException($e34983499)) {
$e34983499.pyretStack.push(L[111]);
}
throw $e34983499;
}
var $ret35043505 = $Hann_DASH_check_DASH_temp9583509($z35003501);
++R.GAS;
return $ret35043505;
};
var $Hann_DASH_check_DASH_temp9583509 = function(ann_DASH_check_DASH_temp443508) {
return ann_DASH_check_DASH_temp443508;
};
var $Hanf_arg9573510 = function(anf_arg363511,self113512,_plus5,torepr8) {
var anf_arg373523 = G(self113512,"expression",L[112]);
var $z35153516 = D;
var $f35213522 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg373523):R.ffi.throwNonFunApp(L[112],torepr8,[anf_arg373523]);
};
try {
if(--R.GAS > 0) {
$z35153516 = $f35213522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35213522,
"from":L[112]});
}
} catch($e35133514) {
if(R.isCont($e35133514)) {
var $ss35173518 = {"from":L[112],
"go":function(anf_arg383524) {
return $Hanf_arg9563525(anf_arg383524,anf_arg363511,_plus5);
}};
$e35133514.stack[R.EXN_STACKHEIGHT++] = $ss35173518;
}
if(R.isPyretException($e35133514)) {
$e35133514.pyretStack.push(L[112]);
}
throw $e35133514;
}
var $ret35193520 = $Hanf_arg9563525($z35153516,anf_arg363511,_plus5);
++R.GAS;
return $ret35193520;
};
var $Hanf_arg9563525 = function(anf_arg383524,anf_arg363511,_plus5) {
var $z35283529 = D;
var $f35343535 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg383524):R.ffi.throwNonFunApp(L[112],_plus5,[(", "),anf_arg383524]);
};
try {
if(--R.GAS > 0) {
$z35283529 = $f35343535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35343535,
"from":L[112]});
}
} catch($e35263527) {
if(R.isCont($e35263527)) {
var $ss35303531 = {"from":L[112],
"go":function(anf_arg393536) {
return $Hanf_arg9553537(anf_arg393536,anf_arg363511,_plus5);
}};
$e35263527.stack[R.EXN_STACKHEIGHT++] = $ss35303531;
}
if(R.isPyretException($e35263527)) {
$e35263527.pyretStack.push(L[112]);
}
throw $e35263527;
}
var $ret35323533 = $Hanf_arg9553537($z35283529,anf_arg363511,_plus5);
++R.GAS;
return $ret35323533;
};
var $Hanf_arg9553537 = function(anf_arg393536,anf_arg363511,_plus5) {
var $z35403541 = D;
var $f35463547 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg363511,anf_arg393536):R.ffi.throwNonFunApp(L[112],_plus5,[anf_arg363511,anf_arg393536]);
};
try {
if(--R.GAS > 0) {
$z35403541 = $f35463547();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35463547,
"from":L[112]});
}
} catch($e35383539) {
if(R.isCont($e35383539)) {
var $ss35423543 = {"from":L[112],
"go":function(anf_arg403548) {
return $Hanf_arg9543549(anf_arg403548,_plus5);
}};
$e35383539.stack[R.EXN_STACKHEIGHT++] = $ss35423543;
}
if(R.isPyretException($e35383539)) {
$e35383539.pyretStack.push(L[112]);
}
throw $e35383539;
}
var $ret35443545 = $Hanf_arg9543549($z35403541,_plus5);
++R.GAS;
return $ret35443545;
};
var $Hanf_arg9543549 = function(anf_arg403548,_plus5) {
var $z35523553 = D;
var $f35583559 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg403548,(")")):R.ffi.throwNonFunApp(L[112],_plus5,[anf_arg403548,(")")]);
};
try {
if(--R.GAS > 0) {
$z35523553 = $f35583559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35583559,
"from":L[112]});
}
} catch($e35503551) {
if(R.isCont($e35503551)) {
var $ss35543555 = {"from":L[112],
"go":function(anf_arg413560) {
return $Hanf_arg9533561(anf_arg413560,_plus5);
}};
$e35503551.stack[R.EXN_STACKHEIGHT++] = $ss35543555;
}
if(R.isPyretException($e35503551)) {
$e35503551.pyretStack.push(L[112]);
}
throw $e35503551;
}
var $ret35563557 = $Hanf_arg9533561($z35523553,_plus5);
++R.GAS;
return $ret35563557;
};
var $Hanf_arg9533561 = function(anf_arg413560,_plus5) {
var $z35643565 = D;
var $f35703571 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg413560):R.ffi.throwNonFunApp(L[112],_plus5,[("("),anf_arg413560]);
};
try {
if(--R.GAS > 0) {
$z35643565 = $f35703571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35703571,
"from":L[112]});
}
} catch($e35623563) {
if(R.isCont($e35623563)) {
var $ss35663567 = {"from":L[112],
"go":function(anf_arg423572) {
return $Hanf_arg9523573(anf_arg423572,_plus5);
}};
$e35623563.stack[R.EXN_STACKHEIGHT++] = $ss35663567;
}
if(R.isPyretException($e35623563)) {
$e35623563.pyretStack.push(L[112]);
}
throw $e35623563;
}
var $ret35683569 = $Hanf_arg9523573($z35643565,_plus5);
++R.GAS;
return $ret35683569;
};
var $Hanf_arg9523573 = function(anf_arg423572,_plus5) {
var $z35763577 = D;
var $f35823583 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("no-branches-matched"),anf_arg423572):R.ffi.throwNonFunApp(L[112],_plus5,[("no-branches-matched"),anf_arg423572]);
};
try {
if(--R.GAS > 0) {
$z35763577 = $f35823583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35823583,
"from":L[112]});
}
} catch($e35743575) {
if(R.isCont($e35743575)) {
var $ss35783579 = {"from":L[112],
"go":function(ann_DASH_check_DASH_temp343584) {
return $Hann_DASH_check_DASH_temp9513585(ann_DASH_check_DASH_temp343584);
}};
$e35743575.stack[R.EXN_STACKHEIGHT++] = $ss35783579;
}
if(R.isPyretException($e35743575)) {
$e35743575.pyretStack.push(L[112]);
}
throw $e35743575;
}
var $ret35803581 = $Hann_DASH_check_DASH_temp9513585($z35763577);
++R.GAS;
return $ret35803581;
};
var $Hann_DASH_check_DASH_temp9513585 = function(ann_DASH_check_DASH_temp343584) {
return ann_DASH_check_DASH_temp343584;
};
var $Hcont_tail_arg9493586 = function(cont_tail_arg313587,if_helper223588) {
if(--R.GAS > 0) {
$z35893590 = R.isFunction(if_helper223588)?if_helper223588.app(cont_tail_arg313587):R.ffi.throwNonFunApp(L[112],if_helper223588,[cont_tail_arg313587]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper223588)?if_helper223588.app(cont_tail_arg313587):R.ffi.throwNonFunApp(L[112],if_helper223588,[cont_tail_arg313587]);
},
"from":L[112]});
}
++R.GAS;
return $z35893590;
};
var $Hcont_tail_arg9503591 = function(cont_tail_arg273592,if_helper223588) {
if(--R.GAS > 0) {
$z35933594 = R.isFunction(if_helper223588)?if_helper223588.app(cont_tail_arg273592):R.ffi.throwNonFunApp(L[112],if_helper223588,[cont_tail_arg273592]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper223588)?if_helper223588.app(cont_tail_arg273592):R.ffi.throwNonFunApp(L[112],if_helper223588,[cont_tail_arg273592]);
},
"from":L[112]});
}
++R.GAS;
return $z35933594;
};
var $Hanf_arg9483595 = function(anf_arg153596,_plus5) {
var $z35993600 = D;
var $f36053606 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg153596,(")")):R.ffi.throwNonFunApp(L[113],_plus5,[anf_arg153596,(")")]);
};
try {
if(--R.GAS > 0) {
$z35993600 = $f36053606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36053606,
"from":L[113]});
}
} catch($e35973598) {
if(R.isCont($e35973598)) {
var $ss36013602 = {"from":L[113],
"go":function(anf_arg163607) {
return $Hanf_arg9473608(anf_arg163607,_plus5);
}};
$e35973598.stack[R.EXN_STACKHEIGHT++] = $ss36013602;
}
if(R.isPyretException($e35973598)) {
$e35973598.pyretStack.push(L[113]);
}
throw $e35973598;
}
var $ret36033604 = $Hanf_arg9473608($z35993600,_plus5);
++R.GAS;
return $ret36033604;
};
var $Hanf_arg9473608 = function(anf_arg163607,_plus5) {
var $z36113612 = D;
var $f36173618 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg163607):R.ffi.throwNonFunApp(L[113],_plus5,[("("),anf_arg163607]);
};
try {
if(--R.GAS > 0) {
$z36113612 = $f36173618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36173618,
"from":L[113]});
}
} catch($e36093610) {
if(R.isCont($e36093610)) {
var $ss36133614 = {"from":L[113],
"go":function(anf_arg173619) {
return $Hanf_arg9463620(anf_arg173619,_plus5);
}};
$e36093610.stack[R.EXN_STACKHEIGHT++] = $ss36133614;
}
if(R.isPyretException($e36093610)) {
$e36093610.pyretStack.push(L[113]);
}
throw $e36093610;
}
var $ret36153616 = $Hanf_arg9463620($z36113612,_plus5);
++R.GAS;
return $ret36153616;
};
var $Hanf_arg9463620 = function(anf_arg173619,_plus5) {
var $z36233624 = D;
var $f36293630 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("message-exception"),anf_arg173619):R.ffi.throwNonFunApp(L[113],_plus5,[("message-exception"),anf_arg173619]);
};
try {
if(--R.GAS > 0) {
$z36233624 = $f36293630();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36293630,
"from":L[113]});
}
} catch($e36213622) {
if(R.isCont($e36213622)) {
var $ss36253626 = {"from":L[113],
"go":function(ann_DASH_check_DASH_temp133631) {
return $Hann_DASH_check_DASH_temp9453632(ann_DASH_check_DASH_temp133631);
}};
$e36213622.stack[R.EXN_STACKHEIGHT++] = $ss36253626;
}
if(R.isPyretException($e36213622)) {
$e36213622.pyretStack.push(L[113]);
}
throw $e36213622;
}
var $ret36273628 = $Hann_DASH_check_DASH_temp9453632($z36233624);
++R.GAS;
return $ret36273628;
};
var $Hann_DASH_check_DASH_temp9453632 = function(ann_DASH_check_DASH_temp133631) {
return ann_DASH_check_DASH_temp133631;
};
var $Hcont_tail_arg9433633 = function(cont_tail_arg103634,if_helper23635) {
if(--R.GAS > 0) {
$z36363637 = R.isFunction(if_helper23635)?if_helper23635.app(cont_tail_arg103634):R.ffi.throwNonFunApp(L[113],if_helper23635,[cont_tail_arg103634]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper23635)?if_helper23635.app(cont_tail_arg103634):R.ffi.throwNonFunApp(L[113],if_helper23635,[cont_tail_arg103634]);
},
"from":L[113]});
}
++R.GAS;
return $z36363637;
};
var $Hcont_tail_arg9443638 = function(cont_tail_arg73639,if_helper23635) {
if(--R.GAS > 0) {
$z36403641 = R.isFunction(if_helper23635)?if_helper23635.app(cont_tail_arg73639):R.ffi.throwNonFunApp(L[113],if_helper23635,[cont_tail_arg73639]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper23635)?if_helper23635.app(cont_tail_arg73639):R.ffi.throwNonFunApp(L[113],if_helper23635,[cont_tail_arg73639]);
},
"from":L[113]});
}
++R.GAS;
return $z36403641;
};
return R.loadModulesNew(NAMESPACE,[],function() {
return R.safeCall(function() {
var RuntimeErrorT123642 = R.namedBrander("RuntimeError");
var RuntimeError116 = R.makeBranderAnn(RuntimeErrorT123642,"RuntimeError");
var ParseErrorT243643 = R.namedBrander("ParseError");
var ParseError315 = R.makeBranderAnn(ParseErrorT243643,"ParseError");
var RuntimeError353644 = {"$var":D,
"$name":"RuntimeError3"};
var RuntimeError63646 = {"$var":D,
"$name":"RuntimeError"};
var is_DASH_RuntimeError73648 = {"$var":D,
"$name":"is-RuntimeError"};
var is_DASH_message_DASH_exception83650 = {"$var":D,
"$name":"is-message-exception"};
var message_DASH_exception93652 = {"$var":D,
"$name":"message-exception"};
var is_DASH_no_DASH_branches_DASH_matched103654 = {"$var":D,
"$name":"is-no-branches-matched"};
var no_DASH_branches_DASH_matched113656 = {"$var":D,
"$name":"no-branches-matched"};
var is_DASH_internal_DASH_error123658 = {"$var":D,
"$name":"is-internal-error"};
var internal_DASH_error133660 = {"$var":D,
"$name":"internal-error"};
var is_DASH_field_DASH_not_DASH_found143662 = {"$var":D,
"$name":"is-field-not-found"};
var field_DASH_not_DASH_found153664 = {"$var":D,
"$name":"field-not-found"};
var is_DASH_lookup_DASH_non_DASH_object163666 = {"$var":D,
"$name":"is-lookup-non-object"};
var lookup_DASH_non_DASH_object173668 = {"$var":D,
"$name":"lookup-non-object"};
var is_DASH_non_DASH_boolean_DASH_condition183670 = {"$var":D,
"$name":"is-non-boolean-condition"};
var non_DASH_boolean_DASH_condition193672 = {"$var":D,
"$name":"non-boolean-condition"};
var is_DASH_non_DASH_boolean_DASH_op203674 = {"$var":D,
"$name":"is-non-boolean-op"};
var non_DASH_boolean_DASH_op213676 = {"$var":D,
"$name":"non-boolean-op"};
var is_DASH_generic_DASH_type_DASH_mismatch223678 = {"$var":D,
"$name":"is-generic-type-mismatch"};
var generic_DASH_type_DASH_mismatch233680 = {"$var":D,
"$name":"generic-type-mismatch"};
var is_DASH_outside_DASH_numeric_DASH_range243682 = {"$var":D,
"$name":"is-outside-numeric-range"};
var outside_DASH_numeric_DASH_range253684 = {"$var":D,
"$name":"outside-numeric-range"};
var is_DASH_plus_DASH_error263686 = {"$var":D,
"$name":"is-plus-error"};
var plus_DASH_error273688 = {"$var":D,
"$name":"plus-error"};
var is_DASH_numeric_DASH_binop_DASH_error283690 = {"$var":D,
"$name":"is-numeric-binop-error"};
var numeric_DASH_binop_DASH_error293692 = {"$var":D,
"$name":"numeric-binop-error"};
var is_DASH_arity_DASH_mismatch303694 = {"$var":D,
"$name":"is-arity-mismatch"};
var arity_DASH_mismatch313696 = {"$var":D,
"$name":"arity-mismatch"};
var is_DASH_non_DASH_function_DASH_app323698 = {"$var":D,
"$name":"is-non-function-app"};
var non_DASH_function_DASH_app333700 = {"$var":D,
"$name":"non-function-app"};
var is_DASH_bad_DASH_app343702 = {"$var":D,
"$name":"is-bad-app"};
var bad_DASH_app353704 = {"$var":D,
"$name":"bad-app"};
var is_DASH_uninitialized_DASH_id363706 = {"$var":D,
"$name":"is-uninitialized-id"};
var uninitialized_DASH_id373708 = {"$var":D,
"$name":"uninitialized-id"};
var is_DASH_module_DASH_load_DASH_failure383710 = {"$var":D,
"$name":"is-module-load-failure"};
var module_DASH_load_DASH_failure393712 = {"$var":D,
"$name":"module-load-failure"};
var is_DASH_invalid_DASH_array_DASH_index403714 = {"$var":D,
"$name":"is-invalid-array-index"};
var invalid_DASH_array_DASH_index413716 = {"$var":D,
"$name":"invalid-array-index"};
var is_DASH_user_DASH_break423718 = {"$var":D,
"$name":"is-user-break"};
var user_DASH_break433720 = {"$var":D,
"$name":"user-break"};
var ParseError4443722 = {"$var":D,
"$name":"ParseError4"};
var ParseError453724 = {"$var":D,
"$name":"ParseError"};
var is_DASH_ParseError463726 = {"$var":D,
"$name":"is-ParseError"};
var is_DASH_parse_DASH_error_DASH_next_DASH_token473728 = {"$var":D,
"$name":"is-parse-error-next-token"};
var parse_DASH_error_DASH_next_DASH_token483730 = {"$var":D,
"$name":"parse-error-next-token"};
var is_DASH_parse_DASH_error_DASH_eof493732 = {"$var":D,
"$name":"is-parse-error-eof"};
var parse_DASH_error_DASH_eof503734 = {"$var":D,
"$name":"parse-error-eof"};
var is_DASH_empty_DASH_block513736 = {"$var":D,
"$name":"is-empty-block"};
var empty_DASH_block523738 = {"$var":D,
"$name":"empty-block"};
var is_DASH_bad_DASH_block_DASH_stmt533740 = {"$var":D,
"$name":"is-bad-block-stmt"};
var bad_DASH_block_DASH_stmt543742 = {"$var":D,
"$name":"bad-block-stmt"};
var is_DASH_bad_DASH_check_DASH_block_DASH_stmt553744 = {"$var":D,
"$name":"is-bad-check-block-stmt"};
var bad_DASH_check_DASH_block_DASH_stmt563746 = {"$var":D,
"$name":"bad-check-block-stmt"};
var is_DASH_fun_DASH_missing_DASH_colon573748 = {"$var":D,
"$name":"is-fun-missing-colon"};
var fun_DASH_missing_DASH_colon583750 = {"$var":D,
"$name":"fun-missing-colon"};
var is_DASH_fun_DASH_missing_DASH_end593752 = {"$var":D,
"$name":"is-fun-missing-end"};
var fun_DASH_missing_DASH_end603754 = {"$var":D,
"$name":"fun-missing-end"};
var is_DASH_args_DASH_missing_DASH_comma613756 = {"$var":D,
"$name":"is-args-missing-comma"};
var args_DASH_missing_DASH_comma623758 = {"$var":D,
"$name":"args-missing-comma"};
var is_DASH_app_DASH_args_DASH_missing_DASH_comma633760 = {"$var":D,
"$name":"is-app-args-missing-comma"};
var app_DASH_args_DASH_missing_DASH_comma643762 = {"$var":D,
"$name":"app-args-missing-comma"};
var is_DASH_missing_DASH_end653764 = {"$var":D,
"$name":"is-missing-end"};
var missing_DASH_end663766 = {"$var":D,
"$name":"missing-end"};
var is_DASH_missing_DASH_comma673768 = {"$var":D,
"$name":"is-missing-comma"};
var missing_DASH_comma683770 = {"$var":D,
"$name":"missing-comma"};
var anf_variant_member124481 = R.makeMethod(function(self25613) {
return function(cases_DASH_funs35614,else_DASH_clause45625) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[113],2,arguments);
}
var if_DASH_65626 = R.hasField(cases_DASH_funs35614,("message-exception"));
var if_helper23635 = R.makeFunction(function(if_helper_arg35631) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[113],1,arguments);
}
var ann_DASH_check_DASH_temp15632 = if_helper_arg35631;
return ann_DASH_check_DASH_temp15632;
});
var anf_if65630 = R.isBoolean(if_DASH_65626);
if(R.isPyretTrue(anf_if65630)) {
if(R.isPyretTrue(if_DASH_65626)) {
var call_DASH_message_DASH_exception15611 = G(cases_DASH_funs35614,"message-exception",L[113]);
var anf_arg95612 = G(self25613,"message",L[271]);
var $z56035604 = D;
var $f56095610 = function(_) {
return R.isFunction(call_DASH_message_DASH_exception15611)?call_DASH_message_DASH_exception15611.app(anf_arg95612):R.ffi.throwNonFunApp(L[113],call_DASH_message_DASH_exception15611,[anf_arg95612]);
};
try {
if(--R.GAS > 0) {
$z56035604 = $f56095610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56095610,
"from":L[113]});
}
} catch($e56015602) {
if(R.isCont($e56015602)) {
var $ss56055606 = {"from":L[113],
"go":function(cont_tail_arg103634) {
return $Hcont_tail_arg9433633(cont_tail_arg103634,if_helper23635);
}};
$e56015602.stack[R.EXN_STACKHEIGHT++] = $ss56055606;
}
if(R.isPyretException($e56015602)) {
$e56015602.pyretStack.push(L[113]);
}
throw $e56015602;
}
var $ret56075608 = $Hcont_tail_arg9433633($z56035604,if_helper23635);
++R.GAS;
return $ret56075608;
} else {
var $z56175618 = D;
var $f56235624 = function(_) {
return R.isFunction(else_DASH_clause45625)?else_DASH_clause45625.app():R.ffi.throwNonFunApp(L[113],else_DASH_clause45625,[]);
};
try {
if(--R.GAS > 0) {
$z56175618 = $f56235624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56235624,
"from":L[113]});
}
} catch($e56155616) {
if(R.isCont($e56155616)) {
var $ss56195620 = {"from":L[113],
"go":function(cont_tail_arg73639) {
return $Hcont_tail_arg9443638(cont_tail_arg73639,if_helper23635);
}};
$e56155616.stack[R.EXN_STACKHEIGHT++] = $ss56195620;
}
if(R.isPyretException($e56155616)) {
$e56155616.pyretStack.push(L[113]);
}
throw $e56155616;
}
var $ret56215622 = $Hcont_tail_arg9443638($z56175618,if_helper23635);
++R.GAS;
return $ret56215622;
}
} else {
var cont_tail_arg45629 = R.throwNonBooleanCondition(L[113],("if"),if_DASH_65626);
if(--R.GAS > 0) {
$z56275628 = R.isFunction(if_helper23635)?if_helper23635.app(cont_tail_arg45629):R.ffi.throwNonFunApp(L[113],if_helper23635,[cont_tail_arg45629]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper23635)?if_helper23635.app(cont_tail_arg45629):R.ffi.throwNonFunApp(L[113],if_helper23635,[cont_tail_arg45629]);
},
"from":L[113]});
}
++R.GAS;
return $z56275628;
}
};
},{"length":3});
var anf_variant_member184482 = R.makeMethod(function(self55600) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[113],0,arguments);
}
var anf_arg145599 = G(self55600,"message",L[113]);
var $z55915592 = D;
var $f55975598 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg145599):R.ffi.throwNonFunApp(L[113],torepr8,[anf_arg145599]);
};
try {
if(--R.GAS > 0) {
$z55915592 = $f55975598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55975598,
"from":L[113]});
}
} catch($e55895590) {
if(R.isCont($e55895590)) {
var $ss55935594 = {"from":L[113],
"go":function(anf_arg153596) {
return $Hanf_arg9483595(anf_arg153596,_plus5);
}};
$e55895590.stack[R.EXN_STACKHEIGHT++] = $ss55935594;
}
if(R.isPyretException($e55895590)) {
$e55895590.pyretStack.push(L[113]);
}
throw $e55895590;
}
var $ret55955596 = $Hanf_arg9483595($z55915592,_plus5);
++R.GAS;
return $ret55955596;
};
},{"length":1});
var anf_variant_member204483 = R.makeMethod(function(self705588) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[270],0,arguments);
}
var ann_DASH_check_DASH_temp195587 = G(self705588,"message",L[269]);
return ann_DASH_check_DASH_temp195587;
};
},{"length":1});
var anf_variant_member334490 = R.makeMethod(function(self85567) {
return function(cases_DASH_funs95568,else_DASH_clause105579) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[112],2,arguments);
}
var if_DASH_125580 = R.hasField(cases_DASH_funs95568,("no-branches-matched"));
var if_helper223588 = R.makeFunction(function(if_helper_arg235585) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[112],1,arguments);
}
var ann_DASH_check_DASH_temp215586 = if_helper_arg235585;
return ann_DASH_check_DASH_temp215586;
});
var anf_if265584 = R.isBoolean(if_DASH_125580);
if(R.isPyretTrue(anf_if265584)) {
if(R.isPyretTrue(if_DASH_125580)) {
var call_DASH_no_DASH_branches_DASH_matched75564 = G(cases_DASH_funs95568,"no-branches-matched",L[112]);
var anf_arg295565 = G(self85567,"loc",L[268]);
var anf_arg305566 = G(self85567,"expression",L[267]);
var $z55565557 = D;
var $f55625563 = function(_) {
return R.isFunction(call_DASH_no_DASH_branches_DASH_matched75564)?call_DASH_no_DASH_branches_DASH_matched75564.app(anf_arg295565,anf_arg305566):R.ffi.throwNonFunApp(L[112],call_DASH_no_DASH_branches_DASH_matched75564,[anf_arg295565,anf_arg305566]);
};
try {
if(--R.GAS > 0) {
$z55565557 = $f55625563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55625563,
"from":L[112]});
}
} catch($e55545555) {
if(R.isCont($e55545555)) {
var $ss55585559 = {"from":L[112],
"go":function(cont_tail_arg313587) {
return $Hcont_tail_arg9493586(cont_tail_arg313587,if_helper223588);
}};
$e55545555.stack[R.EXN_STACKHEIGHT++] = $ss55585559;
}
if(R.isPyretException($e55545555)) {
$e55545555.pyretStack.push(L[112]);
}
throw $e55545555;
}
var $ret55605561 = $Hcont_tail_arg9493586($z55565557,if_helper223588);
++R.GAS;
return $ret55605561;
} else {
var $z55715572 = D;
var $f55775578 = function(_) {
return R.isFunction(else_DASH_clause105579)?else_DASH_clause105579.app():R.ffi.throwNonFunApp(L[112],else_DASH_clause105579,[]);
};
try {
if(--R.GAS > 0) {
$z55715572 = $f55775578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55775578,
"from":L[112]});
}
} catch($e55695570) {
if(R.isCont($e55695570)) {
var $ss55735574 = {"from":L[112],
"go":function(cont_tail_arg273592) {
return $Hcont_tail_arg9503591(cont_tail_arg273592,if_helper223588);
}};
$e55695570.stack[R.EXN_STACKHEIGHT++] = $ss55735574;
}
if(R.isPyretException($e55695570)) {
$e55695570.pyretStack.push(L[112]);
}
throw $e55695570;
}
var $ret55755576 = $Hcont_tail_arg9503591($z55715572,if_helper223588);
++R.GAS;
return $ret55755576;
}
} else {
var cont_tail_arg245583 = R.throwNonBooleanCondition(L[112],("if"),if_DASH_125580);
if(--R.GAS > 0) {
$z55815582 = R.isFunction(if_helper223588)?if_helper223588.app(cont_tail_arg245583):R.ffi.throwNonFunApp(L[112],if_helper223588,[cont_tail_arg245583]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper223588)?if_helper223588.app(cont_tail_arg245583):R.ffi.throwNonFunApp(L[112],if_helper223588,[cont_tail_arg245583]);
},
"from":L[112]});
}
++R.GAS;
return $z55815582;
}
};
},{"length":3});
var anf_variant_member434491 = R.makeMethod(function(self113512) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[112],0,arguments);
}
var anf_arg355553 = G(self113512,"loc",L[112]);
var $z55455546 = D;
var $f55515552 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg355553):R.ffi.throwNonFunApp(L[112],torepr8,[anf_arg355553]);
};
try {
if(--R.GAS > 0) {
$z55455546 = $f55515552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55515552,
"from":L[112]});
}
} catch($e55435544) {
if(R.isCont($e55435544)) {
var $ss55475548 = {"from":L[112],
"go":function(anf_arg363511) {
return $Hanf_arg9573510(anf_arg363511,self113512,_plus5,torepr8);
}};
$e55435544.stack[R.EXN_STACKHEIGHT++] = $ss55475548;
}
if(R.isPyretException($e55435544)) {
$e55435544.pyretStack.push(L[112]);
}
throw $e55435544;
}
var $ret55495550 = $Hanf_arg9573510($z55455546,self113512,_plus5,torepr8);
++R.GAS;
return $ret55495550;
};
},{"length":1});
var anf_variant_member474492 = R.makeMethod(function(self735542) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[111],0,arguments);
}
var anf_arg455541 = G(self735542,"expression",L[266]);
var $z55335534 = D;
var $f55395540 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("No branches matched in this `"),anf_arg455541):R.ffi.throwNonFunApp(L[265],_plus5,[("No branches matched in this `"),anf_arg455541]);
};
try {
if(--R.GAS > 0) {
$z55335534 = $f55395540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55395540,
"from":L[265]});
}
} catch($e55315532) {
if(R.isCont($e55315532)) {
var $ss55355536 = {"from":L[265],
"go":function(anf_arg463497) {
return $Hanf_arg9593496(anf_arg463497,_plus5);
}};
$e55315532.stack[R.EXN_STACKHEIGHT++] = $ss55355536;
}
if(R.isPyretException($e55315532)) {
$e55315532.pyretStack.push(L[265]);
}
throw $e55315532;
}
var $ret55375538 = $Hanf_arg9593496($z55335534,_plus5);
++R.GAS;
return $ret55375538;
};
},{"length":1});
var anf_variant_member604500 = R.makeMethod(function(self145511) {
return function(cases_DASH_funs155512,else_DASH_clause165523) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[110],2,arguments);
}
var if_DASH_185524 = R.hasField(cases_DASH_funs155512,("internal-error"));
var if_helper493489 = R.makeFunction(function(if_helper_arg505529) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[110],1,arguments);
}
var ann_DASH_check_DASH_temp485530 = if_helper_arg505529;
return ann_DASH_check_DASH_temp485530;
});
var anf_if535528 = R.isBoolean(if_DASH_185524);
if(R.isPyretTrue(anf_if535528)) {
if(R.isPyretTrue(if_DASH_185524)) {
var call_DASH_internal_DASH_error135508 = G(cases_DASH_funs155512,"internal-error",L[110]);
var anf_arg565509 = G(self145511,"message",L[264]);
var anf_arg575510 = G(self145511,"info-args",L[263]);
var $z55005501 = D;
var $f55065507 = function(_) {
return R.isFunction(call_DASH_internal_DASH_error135508)?call_DASH_internal_DASH_error135508.app(anf_arg565509,anf_arg575510):R.ffi.throwNonFunApp(L[110],call_DASH_internal_DASH_error135508,[anf_arg565509,anf_arg575510]);
};
try {
if(--R.GAS > 0) {
$z55005501 = $f55065507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55065507,
"from":L[110]});
}
} catch($e54985499) {
if(R.isCont($e54985499)) {
var $ss55025503 = {"from":L[110],
"go":function(cont_tail_arg583488) {
return $Hcont_tail_arg9603487(cont_tail_arg583488,if_helper493489);
}};
$e54985499.stack[R.EXN_STACKHEIGHT++] = $ss55025503;
}
if(R.isPyretException($e54985499)) {
$e54985499.pyretStack.push(L[110]);
}
throw $e54985499;
}
var $ret55045505 = $Hcont_tail_arg9603487($z55005501,if_helper493489);
++R.GAS;
return $ret55045505;
} else {
var $z55155516 = D;
var $f55215522 = function(_) {
return R.isFunction(else_DASH_clause165523)?else_DASH_clause165523.app():R.ffi.throwNonFunApp(L[110],else_DASH_clause165523,[]);
};
try {
if(--R.GAS > 0) {
$z55155516 = $f55215522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55215522,
"from":L[110]});
}
} catch($e55135514) {
if(R.isCont($e55135514)) {
var $ss55175518 = {"from":L[110],
"go":function(cont_tail_arg543493) {
return $Hcont_tail_arg9613492(cont_tail_arg543493,if_helper493489);
}};
$e55135514.stack[R.EXN_STACKHEIGHT++] = $ss55175518;
}
if(R.isPyretException($e55135514)) {
$e55135514.pyretStack.push(L[110]);
}
throw $e55135514;
}
var $ret55195520 = $Hcont_tail_arg9613492($z55155516,if_helper493489);
++R.GAS;
return $ret55195520;
}
} else {
var cont_tail_arg515527 = R.throwNonBooleanCondition(L[110],("if"),if_DASH_185524);
if(--R.GAS > 0) {
$z55255526 = R.isFunction(if_helper493489)?if_helper493489.app(cont_tail_arg515527):R.ffi.throwNonFunApp(L[110],if_helper493489,[cont_tail_arg515527]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper493489)?if_helper493489.app(cont_tail_arg515527):R.ffi.throwNonFunApp(L[110],if_helper493489,[cont_tail_arg515527]);
},
"from":L[110]});
}
++R.GAS;
return $z55255526;
}
};
},{"length":3});
var anf_variant_member704501 = R.makeMethod(function(self173413) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[110],0,arguments);
}
var anf_arg625497 = G(self173413,"message",L[110]);
var $z54895490 = D;
var $f54955496 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg625497):R.ffi.throwNonFunApp(L[110],torepr8,[anf_arg625497]);
};
try {
if(--R.GAS > 0) {
$z54895490 = $f54955496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54955496,
"from":L[110]});
}
} catch($e54875488) {
if(R.isCont($e54875488)) {
var $ss54915492 = {"from":L[110],
"go":function(anf_arg633412) {
return $Hanf_arg9683411(anf_arg633412,self173413,_plus5,torepr8);
}};
$e54875488.stack[R.EXN_STACKHEIGHT++] = $ss54915492;
}
if(R.isPyretException($e54875488)) {
$e54875488.pyretStack.push(L[110]);
}
throw $e54875488;
}
var $ret54935494 = $Hanf_arg9683411($z54895490,self173413,_plus5,torepr8);
++R.GAS;
return $ret54935494;
};
},{"length":1});
var anf_variant_member774502 = R.makeMethod(function(self763373) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[109],0,arguments);
}
var anf_arg725486 = G(self763373,"message",L[262]);
var $z54785479 = D;
var $f54845485 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Internal error: "),anf_arg725486):R.ffi.throwNonFunApp(L[106],_plus5,[("Internal error: "),anf_arg725486]);
};
try {
if(--R.GAS > 0) {
$z54785479 = $f54845485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54845485,
"from":L[106]});
}
} catch($e54765477) {
if(R.isCont($e54765477)) {
var $ss54805481 = {"from":L[106],
"go":function(anf_arg733372) {
return $Hanf_arg9723371(anf_arg733372,self763373,_plus5,torepr8);
}};
$e54765477.stack[R.EXN_STACKHEIGHT++] = $ss54805481;
}
if(R.isPyretException($e54765477)) {
$e54765477.pyretStack.push(L[106]);
}
throw $e54765477;
}
var $ret54825483 = $Hanf_arg9723371($z54785479,self763373,_plus5,torepr8);
++R.GAS;
return $ret54825483;
};
},{"length":1});
var anf_variant_member914510 = R.makeMethod(function(self205456) {
return function(cases_DASH_funs215457,else_DASH_clause225468) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[105],2,arguments);
}
var if_DASH_245469 = R.hasField(cases_DASH_funs215457,("field-not-found"));
var if_helper793364 = R.makeFunction(function(if_helper_arg805474) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[105],1,arguments);
}
var ann_DASH_check_DASH_temp785475 = if_helper_arg805474;
return ann_DASH_check_DASH_temp785475;
});
var anf_if835473 = R.isBoolean(if_DASH_245469);
if(R.isPyretTrue(anf_if835473)) {
if(R.isPyretTrue(if_DASH_245469)) {
var call_DASH_field_DASH_not_DASH_found195452 = G(cases_DASH_funs215457,"field-not-found",L[105]);
var anf_arg865453 = G(self205456,"loc",L[261]);
var anf_arg875454 = G(self205456,"obj",L[260]);
var anf_arg885455 = G(self205456,"field",L[259]);
var $z54445445 = D;
var $f54505451 = function(_) {
return R.isFunction(call_DASH_field_DASH_not_DASH_found195452)?call_DASH_field_DASH_not_DASH_found195452.app(anf_arg865453,anf_arg875454,anf_arg885455):R.ffi.throwNonFunApp(L[105],call_DASH_field_DASH_not_DASH_found195452,[anf_arg865453,anf_arg875454,anf_arg885455]);
};
try {
if(--R.GAS > 0) {
$z54445445 = $f54505451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54505451,
"from":L[105]});
}
} catch($e54425443) {
if(R.isCont($e54425443)) {
var $ss54465447 = {"from":L[105],
"go":function(cont_tail_arg893363) {
return $Hcont_tail_arg9733362(cont_tail_arg893363,if_helper793364);
}};
$e54425443.stack[R.EXN_STACKHEIGHT++] = $ss54465447;
}
if(R.isPyretException($e54425443)) {
$e54425443.pyretStack.push(L[105]);
}
throw $e54425443;
}
var $ret54485449 = $Hcont_tail_arg9733362($z54445445,if_helper793364);
++R.GAS;
return $ret54485449;
} else {
var $z54605461 = D;
var $f54665467 = function(_) {
return R.isFunction(else_DASH_clause225468)?else_DASH_clause225468.app():R.ffi.throwNonFunApp(L[105],else_DASH_clause225468,[]);
};
try {
if(--R.GAS > 0) {
$z54605461 = $f54665467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54665467,
"from":L[105]});
}
} catch($e54585459) {
if(R.isCont($e54585459)) {
var $ss54625463 = {"from":L[105],
"go":function(cont_tail_arg843368) {
return $Hcont_tail_arg9743367(cont_tail_arg843368,if_helper793364);
}};
$e54585459.stack[R.EXN_STACKHEIGHT++] = $ss54625463;
}
if(R.isPyretException($e54585459)) {
$e54585459.pyretStack.push(L[105]);
}
throw $e54585459;
}
var $ret54645465 = $Hcont_tail_arg9743367($z54605461,if_helper793364);
++R.GAS;
return $ret54645465;
}
} else {
var cont_tail_arg815472 = R.throwNonBooleanCondition(L[105],("if"),if_DASH_245469);
if(--R.GAS > 0) {
$z54705471 = R.isFunction(if_helper793364)?if_helper793364.app(cont_tail_arg815472):R.ffi.throwNonFunApp(L[105],if_helper793364,[cont_tail_arg815472]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper793364)?if_helper793364.app(cont_tail_arg815472):R.ffi.throwNonFunApp(L[105],if_helper793364,[cont_tail_arg815472]);
},
"from":L[105]});
}
++R.GAS;
return $z54705471;
}
};
},{"length":3});
var anf_variant_member1054511 = R.makeMethod(function(self233251) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[105],0,arguments);
}
var anf_arg935441 = G(self233251,"loc",L[105]);
var $z54335434 = D;
var $f54395440 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg935441):R.ffi.throwNonFunApp(L[105],torepr8,[anf_arg935441]);
};
try {
if(--R.GAS > 0) {
$z54335434 = $f54395440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54395440,
"from":L[105]});
}
} catch($e54315432) {
if(R.isCont($e54315432)) {
var $ss54355436 = {"from":L[105],
"go":function(anf_arg943250) {
return $Hanf_arg9843249(anf_arg943250,self233251,_plus5,torepr8);
}};
$e54315432.stack[R.EXN_STACKHEIGHT++] = $ss54355436;
}
if(R.isPyretException($e54315432)) {
$e54315432.pyretStack.push(L[105]);
}
throw $e54315432;
}
var $ret54375438 = $Hanf_arg9843249($z54335434,self233251,_plus5,torepr8);
++R.GAS;
return $ret54375438;
};
},{"length":1});
var anf_variant_member1174512 = R.makeMethod(function(self803174) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[104],0,arguments);
}
var anf_bracket1075430 = G(self803174,"loc",L[258]);
var anf_fun1085429 = G(anf_bracket1075430,"format",L[257]);
var $z54215422 = D;
var $f54275428 = function(_) {
return R.isFunction(anf_fun1085429)?anf_fun1085429.app((true)):R.ffi.throwNonFunApp(L[256],anf_fun1085429,[(true)]);
};
try {
if(--R.GAS > 0) {
$z54215422 = $f54275428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54275428,
"from":L[256]});
}
} catch($e54195420) {
if(R.isCont($e54195420)) {
var $ss54235424 = {"from":L[256],
"go":function(anf_arg1093173) {
return $Hanf_arg9913172(anf_arg1093173,self803174,_plus5,torepr8);
}};
$e54195420.stack[R.EXN_STACKHEIGHT++] = $ss54235424;
}
if(R.isPyretException($e54195420)) {
$e54195420.pyretStack.push(L[256]);
}
throw $e54195420;
}
var $ret54255426 = $Hanf_arg9913172($z54215422,self803174,_plus5,torepr8);
++R.GAS;
return $ret54255426;
};
},{"length":1});
var anf_variant_member1314521 = R.makeMethod(function(self265399) {
return function(cases_DASH_funs275400,else_DASH_clause285411) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[99],2,arguments);
}
var if_DASH_305412 = R.hasField(cases_DASH_funs275400,("lookup-non-object"));
var if_helper1193165 = R.makeFunction(function(if_helper_arg1205417) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[99],1,arguments);
}
var ann_DASH_check_DASH_temp1185418 = if_helper_arg1205417;
return ann_DASH_check_DASH_temp1185418;
});
var anf_if1235416 = R.isBoolean(if_DASH_305412);
if(R.isPyretTrue(anf_if1235416)) {
if(R.isPyretTrue(if_DASH_305412)) {
var call_DASH_lookup_DASH_non_DASH_object255395 = G(cases_DASH_funs275400,"lookup-non-object",L[99]);
var anf_arg1265396 = G(self265399,"loc",L[255]);
var anf_arg1275397 = G(self265399,"non-obj",L[254]);
var anf_arg1285398 = G(self265399,"field",L[253]);
var $z53875388 = D;
var $f53935394 = function(_) {
return R.isFunction(call_DASH_lookup_DASH_non_DASH_object255395)?call_DASH_lookup_DASH_non_DASH_object255395.app(anf_arg1265396,anf_arg1275397,anf_arg1285398):R.ffi.throwNonFunApp(L[99],call_DASH_lookup_DASH_non_DASH_object255395,[anf_arg1265396,anf_arg1275397,anf_arg1285398]);
};
try {
if(--R.GAS > 0) {
$z53875388 = $f53935394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53935394,
"from":L[99]});
}
} catch($e53855386) {
if(R.isCont($e53855386)) {
var $ss53895390 = {"from":L[99],
"go":function(cont_tail_arg1293164) {
return $Hcont_tail_arg9923163(cont_tail_arg1293164,if_helper1193165);
}};
$e53855386.stack[R.EXN_STACKHEIGHT++] = $ss53895390;
}
if(R.isPyretException($e53855386)) {
$e53855386.pyretStack.push(L[99]);
}
throw $e53855386;
}
var $ret53915392 = $Hcont_tail_arg9923163($z53875388,if_helper1193165);
++R.GAS;
return $ret53915392;
} else {
var $z54035404 = D;
var $f54095410 = function(_) {
return R.isFunction(else_DASH_clause285411)?else_DASH_clause285411.app():R.ffi.throwNonFunApp(L[99],else_DASH_clause285411,[]);
};
try {
if(--R.GAS > 0) {
$z54035404 = $f54095410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54095410,
"from":L[99]});
}
} catch($e54015402) {
if(R.isCont($e54015402)) {
var $ss54055406 = {"from":L[99],
"go":function(cont_tail_arg1243169) {
return $Hcont_tail_arg9933168(cont_tail_arg1243169,if_helper1193165);
}};
$e54015402.stack[R.EXN_STACKHEIGHT++] = $ss54055406;
}
if(R.isPyretException($e54015402)) {
$e54015402.pyretStack.push(L[99]);
}
throw $e54015402;
}
var $ret54075408 = $Hcont_tail_arg9933168($z54035404,if_helper1193165);
++R.GAS;
return $ret54075408;
}
} else {
var cont_tail_arg1215415 = R.throwNonBooleanCondition(L[99],("if"),if_DASH_305412);
if(--R.GAS > 0) {
$z54135414 = R.isFunction(if_helper1193165)?if_helper1193165.app(cont_tail_arg1215415):R.ffi.throwNonFunApp(L[99],if_helper1193165,[cont_tail_arg1215415]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper1193165)?if_helper1193165.app(cont_tail_arg1215415):R.ffi.throwNonFunApp(L[99],if_helper1193165,[cont_tail_arg1215415]);
},
"from":L[99]});
}
++R.GAS;
return $z54135414;
}
};
},{"length":3});
var anf_variant_member1454522 = R.makeMethod(function(self293052) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[99],0,arguments);
}
var anf_arg1335384 = G(self293052,"loc",L[99]);
var $z53765377 = D;
var $f53825383 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1335384):R.ffi.throwNonFunApp(L[99],torepr8,[anf_arg1335384]);
};
try {
if(--R.GAS > 0) {
$z53765377 = $f53825383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53825383,
"from":L[99]});
}
} catch($e53745375) {
if(R.isCont($e53745375)) {
var $ss53785379 = {"from":L[99],
"go":function(anf_arg1343051) {
return $Hanf_arg10033050(anf_arg1343051,self293052,_plus5,torepr8);
}};
$e53745375.stack[R.EXN_STACKHEIGHT++] = $ss53785379;
}
if(R.isPyretException($e53745375)) {
$e53745375.pyretStack.push(L[99]);
}
throw $e53745375;
}
var $ret53805381 = $Hanf_arg10033050($z53765377,self293052,_plus5,torepr8);
++R.GAS;
return $ret53805381;
};
},{"length":1});
var anf_variant_member1584523 = R.makeMethod(function(self842963) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[98],0,arguments);
}
var anf_bracket1475373 = G(self842963,"loc",L[252]);
var anf_fun1485372 = G(anf_bracket1475373,"format",L[251]);
var $z53645365 = D;
var $f53705371 = function(_) {
return R.isFunction(anf_fun1485372)?anf_fun1485372.app((true)):R.ffi.throwNonFunApp(L[250],anf_fun1485372,[(true)]);
};
try {
if(--R.GAS > 0) {
$z53645365 = $f53705371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53705371,
"from":L[250]});
}
} catch($e53625363) {
if(R.isCont($e53625363)) {
var $ss53665367 = {"from":L[250],
"go":function(anf_arg1492962) {
return $Hanf_arg10112961(anf_arg1492962,self842963,_plus5,torepr8);
}};
$e53625363.stack[R.EXN_STACKHEIGHT++] = $ss53665367;
}
if(R.isPyretException($e53625363)) {
$e53625363.pyretStack.push(L[250]);
}
throw $e53625363;
}
var $ret53685369 = $Hanf_arg10112961($z53645365,self842963,_plus5,torepr8);
++R.GAS;
return $ret53685369;
};
},{"length":1});
var anf_variant_member1724532 = R.makeMethod(function(self325342) {
return function(cases_DASH_funs335343,else_DASH_clause345354) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[93],2,arguments);
}
var if_DASH_365355 = R.hasField(cases_DASH_funs335343,("non-boolean-condition"));
var if_helper1602954 = R.makeFunction(function(if_helper_arg1615360) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[93],1,arguments);
}
var ann_DASH_check_DASH_temp1595361 = if_helper_arg1615360;
return ann_DASH_check_DASH_temp1595361;
});
var anf_if1645359 = R.isBoolean(if_DASH_365355);
if(R.isPyretTrue(anf_if1645359)) {
if(R.isPyretTrue(if_DASH_365355)) {
var call_DASH_non_DASH_boolean_DASH_condition315338 = G(cases_DASH_funs335343,"non-boolean-condition",L[93]);
var anf_arg1675339 = G(self325342,"loc",L[249]);
var anf_arg1685340 = G(self325342,"typ",L[248]);
var anf_arg1695341 = G(self325342,"value",L[247]);
var $z53305331 = D;
var $f53365337 = function(_) {
return R.isFunction(call_DASH_non_DASH_boolean_DASH_condition315338)?call_DASH_non_DASH_boolean_DASH_condition315338.app(anf_arg1675339,anf_arg1685340,anf_arg1695341):R.ffi.throwNonFunApp(L[93],call_DASH_non_DASH_boolean_DASH_condition315338,[anf_arg1675339,anf_arg1685340,anf_arg1695341]);
};
try {
if(--R.GAS > 0) {
$z53305331 = $f53365337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53365337,
"from":L[93]});
}
} catch($e53285329) {
if(R.isCont($e53285329)) {
var $ss53325333 = {"from":L[93],
"go":function(cont_tail_arg1702953) {
return $Hcont_tail_arg10122952(cont_tail_arg1702953,if_helper1602954);
}};
$e53285329.stack[R.EXN_STACKHEIGHT++] = $ss53325333;
}
if(R.isPyretException($e53285329)) {
$e53285329.pyretStack.push(L[93]);
}
throw $e53285329;
}
var $ret53345335 = $Hcont_tail_arg10122952($z53305331,if_helper1602954);
++R.GAS;
return $ret53345335;
} else {
var $z53465347 = D;
var $f53525353 = function(_) {
return R.isFunction(else_DASH_clause345354)?else_DASH_clause345354.app():R.ffi.throwNonFunApp(L[93],else_DASH_clause345354,[]);
};
try {
if(--R.GAS > 0) {
$z53465347 = $f53525353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53525353,
"from":L[93]});
}
} catch($e53445345) {
if(R.isCont($e53445345)) {
var $ss53485349 = {"from":L[93],
"go":function(cont_tail_arg1652958) {
return $Hcont_tail_arg10132957(cont_tail_arg1652958,if_helper1602954);
}};
$e53445345.stack[R.EXN_STACKHEIGHT++] = $ss53485349;
}
if(R.isPyretException($e53445345)) {
$e53445345.pyretStack.push(L[93]);
}
throw $e53445345;
}
var $ret53505351 = $Hcont_tail_arg10132957($z53465347,if_helper1602954);
++R.GAS;
return $ret53505351;
}
} else {
var cont_tail_arg1625358 = R.throwNonBooleanCondition(L[93],("if"),if_DASH_365355);
if(--R.GAS > 0) {
$z53565357 = R.isFunction(if_helper1602954)?if_helper1602954.app(cont_tail_arg1625358):R.ffi.throwNonFunApp(L[93],if_helper1602954,[cont_tail_arg1625358]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper1602954)?if_helper1602954.app(cont_tail_arg1625358):R.ffi.throwNonFunApp(L[93],if_helper1602954,[cont_tail_arg1625358]);
},
"from":L[93]});
}
++R.GAS;
return $z53565357;
}
};
},{"length":3});
var anf_variant_member1864533 = R.makeMethod(function(self352841) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[93],0,arguments);
}
var anf_arg1745327 = G(self352841,"loc",L[93]);
var $z53195320 = D;
var $f53255326 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg1745327):R.ffi.throwNonFunApp(L[93],torepr8,[anf_arg1745327]);
};
try {
if(--R.GAS > 0) {
$z53195320 = $f53255326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53255326,
"from":L[93]});
}
} catch($e53175318) {
if(R.isCont($e53175318)) {
var $ss53215322 = {"from":L[93],
"go":function(anf_arg1752840) {
return $Hanf_arg10232839(anf_arg1752840,self352841,_plus5,torepr8);
}};
$e53175318.stack[R.EXN_STACKHEIGHT++] = $ss53215322;
}
if(R.isPyretException($e53175318)) {
$e53175318.pyretStack.push(L[93]);
}
throw $e53175318;
}
var $ret53235324 = $Hanf_arg10232839($z53195320,self352841,_plus5,torepr8);
++R.GAS;
return $ret53235324;
};
},{"length":1});
var anf_variant_member1984534 = R.makeMethod(function(self882763) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[92],0,arguments);
}
var anf_arg1885316 = G(self882763,"typ",L[246]);
var $z53085309 = D;
var $f53145315 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: expected a Boolean for the condition of a "),anf_arg1885316):R.ffi.throwNonFunApp(L[86],_plus5,[("Error: expected a Boolean for the condition of a "),anf_arg1885316]);
};
try {
if(--R.GAS > 0) {
$z53085309 = $f53145315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53145315,
"from":L[86]});
}
} catch($e53065307) {
if(R.isCont($e53065307)) {
var $ss53105311 = {"from":L[86],
"go":function(anf_arg1892762) {
return $Hanf_arg10302761(anf_arg1892762,self882763,_plus5,torepr8);
}};
$e53065307.stack[R.EXN_STACKHEIGHT++] = $ss53105311;
}
if(R.isPyretException($e53065307)) {
$e53065307.pyretStack.push(L[86]);
}
throw $e53065307;
}
var $ret53125313 = $Hanf_arg10302761($z53085309,self882763,_plus5,torepr8);
++R.GAS;
return $ret53125313;
};
},{"length":1});
var anf_variant_member2134543 = R.makeMethod(function(self385286) {
return function(cases_DASH_funs395287,else_DASH_clause405298) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[85],2,arguments);
}
var if_DASH_425299 = R.hasField(cases_DASH_funs395287,("non-boolean-op"));
var if_helper2002754 = R.makeFunction(function(if_helper_arg2015304) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[85],1,arguments);
}
var ann_DASH_check_DASH_temp1995305 = if_helper_arg2015304;
return ann_DASH_check_DASH_temp1995305;
});
var anf_if2045303 = R.isBoolean(if_DASH_425299);
if(R.isPyretTrue(anf_if2045303)) {
if(R.isPyretTrue(if_DASH_425299)) {
var call_DASH_non_DASH_boolean_DASH_op375281 = G(cases_DASH_funs395287,"non-boolean-op",L[85]);
var anf_arg2075282 = G(self385286,"loc",L[245]);
var anf_arg2085283 = G(self385286,"position",L[244]);
var anf_arg2095284 = G(self385286,"typ",L[243]);
var anf_arg2105285 = G(self385286,"value",L[242]);
var $z52735274 = D;
var $f52795280 = function(_) {
return R.isFunction(call_DASH_non_DASH_boolean_DASH_op375281)?call_DASH_non_DASH_boolean_DASH_op375281.app(anf_arg2075282,anf_arg2085283,anf_arg2095284,anf_arg2105285):R.ffi.throwNonFunApp(L[85],call_DASH_non_DASH_boolean_DASH_op375281,[anf_arg2075282,anf_arg2085283,anf_arg2095284,anf_arg2105285]);
};
try {
if(--R.GAS > 0) {
$z52735274 = $f52795280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52795280,
"from":L[85]});
}
} catch($e52715272) {
if(R.isCont($e52715272)) {
var $ss52755276 = {"from":L[85],
"go":function(cont_tail_arg2112753) {
return $Hcont_tail_arg10312752(cont_tail_arg2112753,if_helper2002754);
}};
$e52715272.stack[R.EXN_STACKHEIGHT++] = $ss52755276;
}
if(R.isPyretException($e52715272)) {
$e52715272.pyretStack.push(L[85]);
}
throw $e52715272;
}
var $ret52775278 = $Hcont_tail_arg10312752($z52735274,if_helper2002754);
++R.GAS;
return $ret52775278;
} else {
var $z52905291 = D;
var $f52965297 = function(_) {
return R.isFunction(else_DASH_clause405298)?else_DASH_clause405298.app():R.ffi.throwNonFunApp(L[85],else_DASH_clause405298,[]);
};
try {
if(--R.GAS > 0) {
$z52905291 = $f52965297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52965297,
"from":L[85]});
}
} catch($e52885289) {
if(R.isCont($e52885289)) {
var $ss52925293 = {"from":L[85],
"go":function(cont_tail_arg2052758) {
return $Hcont_tail_arg10322757(cont_tail_arg2052758,if_helper2002754);
}};
$e52885289.stack[R.EXN_STACKHEIGHT++] = $ss52925293;
}
if(R.isPyretException($e52885289)) {
$e52885289.pyretStack.push(L[85]);
}
throw $e52885289;
}
var $ret52945295 = $Hcont_tail_arg10322757($z52905291,if_helper2002754);
++R.GAS;
return $ret52945295;
}
} else {
var cont_tail_arg2025302 = R.throwNonBooleanCondition(L[85],("if"),if_DASH_425299);
if(--R.GAS > 0) {
$z53005301 = R.isFunction(if_helper2002754)?if_helper2002754.app(cont_tail_arg2025302):R.ffi.throwNonFunApp(L[85],if_helper2002754,[cont_tail_arg2025302]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2002754)?if_helper2002754.app(cont_tail_arg2025302):R.ffi.throwNonFunApp(L[85],if_helper2002754,[cont_tail_arg2025302]);
},
"from":L[85]});
}
++R.GAS;
return $z53005301;
}
};
},{"length":3});
var anf_variant_member2314544 = R.makeMethod(function(self412604) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[85],0,arguments);
}
var anf_arg2155270 = G(self412604,"loc",L[85]);
var $z52625263 = D;
var $f52685269 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2155270):R.ffi.throwNonFunApp(L[85],torepr8,[anf_arg2155270]);
};
try {
if(--R.GAS > 0) {
$z52625263 = $f52685269();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52685269,
"from":L[85]});
}
} catch($e52605261) {
if(R.isCont($e52605261)) {
var $ss52645265 = {"from":L[85],
"go":function(anf_arg2162603) {
return $Hanf_arg10452602(anf_arg2162603,self412604,_plus5,torepr8);
}};
$e52605261.stack[R.EXN_STACKHEIGHT++] = $ss52645265;
}
if(R.isPyretException($e52605261)) {
$e52605261.pyretStack.push(L[85]);
}
throw $e52605261;
}
var $ret52665267 = $Hanf_arg10452602($z52625263,self412604,_plus5,torepr8);
++R.GAS;
return $ret52665267;
};
},{"length":1});
var anf_variant_member2464545 = R.makeMethod(function(self932501) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[84],0,arguments);
}
var anf_arg2335259 = G(self932501,"position",L[241]);
var $z52515252 = D;
var $f52575258 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: expected a Boolean for the "),anf_arg2335259):R.ffi.throwNonFunApp(L[77],_plus5,[("Error: expected a Boolean for the "),anf_arg2335259]);
};
try {
if(--R.GAS > 0) {
$z52515252 = $f52575258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52575258,
"from":L[77]});
}
} catch($e52495250) {
if(R.isCont($e52495250)) {
var $ss52535254 = {"from":L[77],
"go":function(anf_arg2342500) {
return $Hanf_arg10542499(anf_arg2342500,self932501,_plus5,torepr8);
}};
$e52495250.stack[R.EXN_STACKHEIGHT++] = $ss52535254;
}
if(R.isPyretException($e52495250)) {
$e52495250.pyretStack.push(L[77]);
}
throw $e52495250;
}
var $ret52555256 = $Hanf_arg10542499($z52515252,self932501,_plus5,torepr8);
++R.GAS;
return $ret52555256;
};
},{"length":1});
var anf_variant_member2594555 = R.makeMethod(function(self445229) {
return function(cases_DASH_funs455230,else_DASH_clause465241) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[76],2,arguments);
}
var if_DASH_485242 = R.hasField(cases_DASH_funs455230,("generic-type-mismatch"));
var if_helper2482492 = R.makeFunction(function(if_helper_arg2495247) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[76],1,arguments);
}
var ann_DASH_check_DASH_temp2475248 = if_helper_arg2495247;
return ann_DASH_check_DASH_temp2475248;
});
var anf_if2525246 = R.isBoolean(if_DASH_485242);
if(R.isPyretTrue(anf_if2525246)) {
if(R.isPyretTrue(if_DASH_485242)) {
var call_DASH_generic_DASH_type_DASH_mismatch435226 = G(cases_DASH_funs455230,"generic-type-mismatch",L[76]);
var anf_arg2555227 = G(self445229,"val",L[240]);
var anf_arg2565228 = G(self445229,"typ",L[239]);
var $z52185219 = D;
var $f52245225 = function(_) {
return R.isFunction(call_DASH_generic_DASH_type_DASH_mismatch435226)?call_DASH_generic_DASH_type_DASH_mismatch435226.app(anf_arg2555227,anf_arg2565228):R.ffi.throwNonFunApp(L[76],call_DASH_generic_DASH_type_DASH_mismatch435226,[anf_arg2555227,anf_arg2565228]);
};
try {
if(--R.GAS > 0) {
$z52185219 = $f52245225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52245225,
"from":L[76]});
}
} catch($e52165217) {
if(R.isCont($e52165217)) {
var $ss52205221 = {"from":L[76],
"go":function(cont_tail_arg2572491) {
return $Hcont_tail_arg10552490(cont_tail_arg2572491,if_helper2482492);
}};
$e52165217.stack[R.EXN_STACKHEIGHT++] = $ss52205221;
}
if(R.isPyretException($e52165217)) {
$e52165217.pyretStack.push(L[76]);
}
throw $e52165217;
}
var $ret52225223 = $Hcont_tail_arg10552490($z52185219,if_helper2482492);
++R.GAS;
return $ret52225223;
} else {
var $z52335234 = D;
var $f52395240 = function(_) {
return R.isFunction(else_DASH_clause465241)?else_DASH_clause465241.app():R.ffi.throwNonFunApp(L[76],else_DASH_clause465241,[]);
};
try {
if(--R.GAS > 0) {
$z52335234 = $f52395240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52395240,
"from":L[76]});
}
} catch($e52315232) {
if(R.isCont($e52315232)) {
var $ss52355236 = {"from":L[76],
"go":function(cont_tail_arg2532496) {
return $Hcont_tail_arg10562495(cont_tail_arg2532496,if_helper2482492);
}};
$e52315232.stack[R.EXN_STACKHEIGHT++] = $ss52355236;
}
if(R.isPyretException($e52315232)) {
$e52315232.pyretStack.push(L[76]);
}
throw $e52315232;
}
var $ret52375238 = $Hcont_tail_arg10562495($z52335234,if_helper2482492);
++R.GAS;
return $ret52375238;
}
} else {
var cont_tail_arg2505245 = R.throwNonBooleanCondition(L[76],("if"),if_DASH_485242);
if(--R.GAS > 0) {
$z52435244 = R.isFunction(if_helper2482492)?if_helper2482492.app(cont_tail_arg2505245):R.ffi.throwNonFunApp(L[76],if_helper2482492,[cont_tail_arg2505245]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2482492)?if_helper2482492.app(cont_tail_arg2505245):R.ffi.throwNonFunApp(L[76],if_helper2482492,[cont_tail_arg2505245]);
},
"from":L[76]});
}
++R.GAS;
return $z52435244;
}
};
},{"length":3});
var anf_variant_member2694556 = R.makeMethod(function(self472416) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[76],0,arguments);
}
var anf_arg2615215 = G(self472416,"val",L[76]);
var $z52075208 = D;
var $f52135214 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2615215):R.ffi.throwNonFunApp(L[76],torepr8,[anf_arg2615215]);
};
try {
if(--R.GAS > 0) {
$z52075208 = $f52135214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52135214,
"from":L[76]});
}
} catch($e52055206) {
if(R.isCont($e52055206)) {
var $ss52095210 = {"from":L[76],
"go":function(anf_arg2622415) {
return $Hanf_arg10632414(anf_arg2622415,self472416,_plus5,torepr8);
}};
$e52055206.stack[R.EXN_STACKHEIGHT++] = $ss52095210;
}
if(R.isPyretException($e52055206)) {
$e52055206.pyretStack.push(L[76]);
}
throw $e52055206;
}
var $ret52115212 = $Hanf_arg10632414($z52075208,self472416,_plus5,torepr8);
++R.GAS;
return $ret52115212;
};
},{"length":1});
var anf_variant_member2764557 = R.makeMethod(function(self962376) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[75],0,arguments);
}
var anf_arg2715204 = G(self962376,"typ",L[238]);
var $z51965197 = D;
var $f52025203 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: expected "),anf_arg2715204):R.ffi.throwNonFunApp(L[72],_plus5,[("Error: expected "),anf_arg2715204]);
};
try {
if(--R.GAS > 0) {
$z51965197 = $f52025203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52025203,
"from":L[72]});
}
} catch($e51945195) {
if(R.isCont($e51945195)) {
var $ss51985199 = {"from":L[72],
"go":function(anf_arg2722375) {
return $Hanf_arg10672374(anf_arg2722375,self962376,_plus5,torepr8);
}};
$e51945195.stack[R.EXN_STACKHEIGHT++] = $ss51985199;
}
if(R.isPyretException($e51945195)) {
$e51945195.pyretStack.push(L[72]);
}
throw $e51945195;
}
var $ret52005201 = $Hanf_arg10672374($z51965197,self962376,_plus5,torepr8);
++R.GAS;
return $ret52005201;
};
},{"length":1});
var anf_variant_member2904565 = R.makeMethod(function(self505174) {
return function(cases_DASH_funs515175,else_DASH_clause525186) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[71],2,arguments);
}
var if_DASH_545187 = R.hasField(cases_DASH_funs515175,("outside-numeric-range"));
var if_helper2782367 = R.makeFunction(function(if_helper_arg2795192) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[71],1,arguments);
}
var ann_DASH_check_DASH_temp2775193 = if_helper_arg2795192;
return ann_DASH_check_DASH_temp2775193;
});
var anf_if2825191 = R.isBoolean(if_DASH_545187);
if(R.isPyretTrue(anf_if2825191)) {
if(R.isPyretTrue(if_DASH_545187)) {
var call_DASH_outside_DASH_numeric_DASH_range495170 = G(cases_DASH_funs515175,"outside-numeric-range",L[71]);
var anf_arg2855171 = G(self505174,"val",L[237]);
var anf_arg2865172 = G(self505174,"low",L[236]);
var anf_arg2875173 = G(self505174,"high",L[235]);
var $z51625163 = D;
var $f51685169 = function(_) {
return R.isFunction(call_DASH_outside_DASH_numeric_DASH_range495170)?call_DASH_outside_DASH_numeric_DASH_range495170.app(anf_arg2855171,anf_arg2865172,anf_arg2875173):R.ffi.throwNonFunApp(L[71],call_DASH_outside_DASH_numeric_DASH_range495170,[anf_arg2855171,anf_arg2865172,anf_arg2875173]);
};
try {
if(--R.GAS > 0) {
$z51625163 = $f51685169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51685169,
"from":L[71]});
}
} catch($e51605161) {
if(R.isCont($e51605161)) {
var $ss51645165 = {"from":L[71],
"go":function(cont_tail_arg2882366) {
return $Hcont_tail_arg10682365(cont_tail_arg2882366,if_helper2782367);
}};
$e51605161.stack[R.EXN_STACKHEIGHT++] = $ss51645165;
}
if(R.isPyretException($e51605161)) {
$e51605161.pyretStack.push(L[71]);
}
throw $e51605161;
}
var $ret51665167 = $Hcont_tail_arg10682365($z51625163,if_helper2782367);
++R.GAS;
return $ret51665167;
} else {
var $z51785179 = D;
var $f51845185 = function(_) {
return R.isFunction(else_DASH_clause525186)?else_DASH_clause525186.app():R.ffi.throwNonFunApp(L[71],else_DASH_clause525186,[]);
};
try {
if(--R.GAS > 0) {
$z51785179 = $f51845185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51845185,
"from":L[71]});
}
} catch($e51765177) {
if(R.isCont($e51765177)) {
var $ss51805181 = {"from":L[71],
"go":function(cont_tail_arg2832371) {
return $Hcont_tail_arg10692370(cont_tail_arg2832371,if_helper2782367);
}};
$e51765177.stack[R.EXN_STACKHEIGHT++] = $ss51805181;
}
if(R.isPyretException($e51765177)) {
$e51765177.pyretStack.push(L[71]);
}
throw $e51765177;
}
var $ret51825183 = $Hcont_tail_arg10692370($z51785179,if_helper2782367);
++R.GAS;
return $ret51825183;
}
} else {
var cont_tail_arg2805190 = R.throwNonBooleanCondition(L[71],("if"),if_DASH_545187);
if(--R.GAS > 0) {
$z51885189 = R.isFunction(if_helper2782367)?if_helper2782367.app(cont_tail_arg2805190):R.ffi.throwNonFunApp(L[71],if_helper2782367,[cont_tail_arg2805190]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper2782367)?if_helper2782367.app(cont_tail_arg2805190):R.ffi.throwNonFunApp(L[71],if_helper2782367,[cont_tail_arg2805190]);
},
"from":L[71]});
}
++R.GAS;
return $z51885189;
}
};
},{"length":3});
var anf_variant_member3044566 = R.makeMethod(function(self532254) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[71],0,arguments);
}
var anf_arg2925159 = G(self532254,"val",L[71]);
var $z51515152 = D;
var $f51575158 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg2925159):R.ffi.throwNonFunApp(L[71],torepr8,[anf_arg2925159]);
};
try {
if(--R.GAS > 0) {
$z51515152 = $f51575158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51575158,
"from":L[71]});
}
} catch($e51495150) {
if(R.isCont($e51495150)) {
var $ss51535154 = {"from":L[71],
"go":function(anf_arg2932253) {
return $Hanf_arg10792252(anf_arg2932253,self532254,_plus5,torepr8);
}};
$e51495150.stack[R.EXN_STACKHEIGHT++] = $ss51535154;
}
if(R.isPyretException($e51495150)) {
$e51495150.pyretStack.push(L[71]);
}
throw $e51495150;
}
var $ret51555156 = $Hanf_arg10792252($z51515152,self532254,_plus5,torepr8);
++R.GAS;
return $ret51555156;
};
},{"length":1});
var anf_variant_member3164567 = R.makeMethod(function(self1002165) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[70],0,arguments);
}
var anf_arg3065148 = G(self1002165,"low",L[234]);
var $z51405141 = D;
var $f51465147 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3065148):R.ffi.throwNonFunApp(L[233],torepr8,[anf_arg3065148]);
};
try {
if(--R.GAS > 0) {
$z51405141 = $f51465147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51465147,
"from":L[233]});
}
} catch($e51385139) {
if(R.isCont($e51385139)) {
var $ss51425143 = {"from":L[233],
"go":function(anf_arg3072164) {
return $Hanf_arg10872163(anf_arg3072164,self1002165,_plus5,torepr8);
}};
$e51385139.stack[R.EXN_STACKHEIGHT++] = $ss51425143;
}
if(R.isPyretException($e51385139)) {
$e51385139.pyretStack.push(L[233]);
}
throw $e51385139;
}
var $ret51445145 = $Hanf_arg10872163($z51405141,self1002165,_plus5,torepr8);
++R.GAS;
return $ret51445145;
};
},{"length":1});
var anf_variant_member3294576 = R.makeMethod(function(self565118) {
return function(cases_DASH_funs575119,else_DASH_clause585130) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[64],2,arguments);
}
var if_DASH_605131 = R.hasField(cases_DASH_funs575119,("plus-error"));
var if_helper3182156 = R.makeFunction(function(if_helper_arg3195136) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[64],1,arguments);
}
var ann_DASH_check_DASH_temp3175137 = if_helper_arg3195136;
return ann_DASH_check_DASH_temp3175137;
});
var anf_if3225135 = R.isBoolean(if_DASH_605131);
if(R.isPyretTrue(anf_if3225135)) {
if(R.isPyretTrue(if_DASH_605131)) {
var call_DASH_plus_DASH_error555115 = G(cases_DASH_funs575119,"plus-error",L[64]);
var anf_arg3255116 = G(self565118,"val1",L[232]);
var anf_arg3265117 = G(self565118,"val2",L[231]);
var $z51075108 = D;
var $f51135114 = function(_) {
return R.isFunction(call_DASH_plus_DASH_error555115)?call_DASH_plus_DASH_error555115.app(anf_arg3255116,anf_arg3265117):R.ffi.throwNonFunApp(L[64],call_DASH_plus_DASH_error555115,[anf_arg3255116,anf_arg3265117]);
};
try {
if(--R.GAS > 0) {
$z51075108 = $f51135114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51135114,
"from":L[64]});
}
} catch($e51055106) {
if(R.isCont($e51055106)) {
var $ss51095110 = {"from":L[64],
"go":function(cont_tail_arg3272155) {
return $Hcont_tail_arg10882154(cont_tail_arg3272155,if_helper3182156);
}};
$e51055106.stack[R.EXN_STACKHEIGHT++] = $ss51095110;
}
if(R.isPyretException($e51055106)) {
$e51055106.pyretStack.push(L[64]);
}
throw $e51055106;
}
var $ret51115112 = $Hcont_tail_arg10882154($z51075108,if_helper3182156);
++R.GAS;
return $ret51115112;
} else {
var $z51225123 = D;
var $f51285129 = function(_) {
return R.isFunction(else_DASH_clause585130)?else_DASH_clause585130.app():R.ffi.throwNonFunApp(L[64],else_DASH_clause585130,[]);
};
try {
if(--R.GAS > 0) {
$z51225123 = $f51285129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51285129,
"from":L[64]});
}
} catch($e51205121) {
if(R.isCont($e51205121)) {
var $ss51245125 = {"from":L[64],
"go":function(cont_tail_arg3232160) {
return $Hcont_tail_arg10892159(cont_tail_arg3232160,if_helper3182156);
}};
$e51205121.stack[R.EXN_STACKHEIGHT++] = $ss51245125;
}
if(R.isPyretException($e51205121)) {
$e51205121.pyretStack.push(L[64]);
}
throw $e51205121;
}
var $ret51265127 = $Hcont_tail_arg10892159($z51225123,if_helper3182156);
++R.GAS;
return $ret51265127;
}
} else {
var cont_tail_arg3205134 = R.throwNonBooleanCondition(L[64],("if"),if_DASH_605131);
if(--R.GAS > 0) {
$z51325133 = R.isFunction(if_helper3182156)?if_helper3182156.app(cont_tail_arg3205134):R.ffi.throwNonFunApp(L[64],if_helper3182156,[cont_tail_arg3205134]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3182156)?if_helper3182156.app(cont_tail_arg3205134):R.ffi.throwNonFunApp(L[64],if_helper3182156,[cont_tail_arg3205134]);
},
"from":L[64]});
}
++R.GAS;
return $z51325133;
}
};
},{"length":3});
var anf_variant_member3394577 = R.makeMethod(function(self592080) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[64],0,arguments);
}
var anf_arg3315104 = G(self592080,"val1",L[64]);
var $z50965097 = D;
var $f51025103 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3315104):R.ffi.throwNonFunApp(L[64],torepr8,[anf_arg3315104]);
};
try {
if(--R.GAS > 0) {
$z50965097 = $f51025103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51025103,
"from":L[64]});
}
} catch($e50945095) {
if(R.isCont($e50945095)) {
var $ss50985099 = {"from":L[64],
"go":function(anf_arg3322079) {
return $Hanf_arg10962078(anf_arg3322079,self592080,_plus5,torepr8);
}};
$e50945095.stack[R.EXN_STACKHEIGHT++] = $ss50985099;
}
if(R.isPyretException($e50945095)) {
$e50945095.pyretStack.push(L[64]);
}
throw $e50945095;
}
var $ret51005101 = $Hanf_arg10962078($z50965097,self592080,_plus5,torepr8);
++R.GAS;
return $ret51005101;
};
},{"length":1});
var anf_variant_member3474578 = R.makeMethod(function(self1032028) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[63],0,arguments);
}
var anf_arg3415093 = G(self1032028,"val1",L[230]);
var $z50855086 = D;
var $f50915092 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3415093):R.ffi.throwNonFunApp(L[229],torepr8,[anf_arg3415093]);
};
try {
if(--R.GAS > 0) {
$z50855086 = $f50915092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50915092,
"from":L[229]});
}
} catch($e50835084) {
if(R.isCont($e50835084)) {
var $ss50875088 = {"from":L[229],
"go":function(anf_arg3422027) {
return $Hanf_arg11012026(anf_arg3422027,self1032028,_plus5,torepr8);
}};
$e50835084.stack[R.EXN_STACKHEIGHT++] = $ss50875088;
}
if(R.isPyretException($e50835084)) {
$e50835084.pyretStack.push(L[229]);
}
throw $e50835084;
}
var $ret50895090 = $Hanf_arg11012026($z50855086,self1032028,_plus5,torepr8);
++R.GAS;
return $ret50895090;
};
},{"length":1});
var anf_variant_member3624586 = R.makeMethod(function(self625063) {
return function(cases_DASH_funs635064,else_DASH_clause645075) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[59],2,arguments);
}
var if_DASH_665076 = R.hasField(cases_DASH_funs635064,("numeric-binop-error"));
var if_helper3492019 = R.makeFunction(function(if_helper_arg3505081) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[59],1,arguments);
}
var ann_DASH_check_DASH_temp3485082 = if_helper_arg3505081;
return ann_DASH_check_DASH_temp3485082;
});
var anf_if3535080 = R.isBoolean(if_DASH_665076);
if(R.isPyretTrue(anf_if3535080)) {
if(R.isPyretTrue(if_DASH_665076)) {
var call_DASH_numeric_DASH_binop_DASH_error615058 = G(cases_DASH_funs635064,"numeric-binop-error",L[59]);
var anf_arg3565059 = G(self625063,"val1",L[228]);
var anf_arg3575060 = G(self625063,"val2",L[227]);
var anf_arg3585061 = G(self625063,"opname",L[226]);
var anf_arg3595062 = G(self625063,"methodname",L[225]);
var $z50505051 = D;
var $f50565057 = function(_) {
return R.isFunction(call_DASH_numeric_DASH_binop_DASH_error615058)?call_DASH_numeric_DASH_binop_DASH_error615058.app(anf_arg3565059,anf_arg3575060,anf_arg3585061,anf_arg3595062):R.ffi.throwNonFunApp(L[59],call_DASH_numeric_DASH_binop_DASH_error615058,[anf_arg3565059,anf_arg3575060,anf_arg3585061,anf_arg3595062]);
};
try {
if(--R.GAS > 0) {
$z50505051 = $f50565057();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50565057,
"from":L[59]});
}
} catch($e50485049) {
if(R.isCont($e50485049)) {
var $ss50525053 = {"from":L[59],
"go":function(cont_tail_arg3602018) {
return $Hcont_tail_arg11022017(cont_tail_arg3602018,if_helper3492019);
}};
$e50485049.stack[R.EXN_STACKHEIGHT++] = $ss50525053;
}
if(R.isPyretException($e50485049)) {
$e50485049.pyretStack.push(L[59]);
}
throw $e50485049;
}
var $ret50545055 = $Hcont_tail_arg11022017($z50505051,if_helper3492019);
++R.GAS;
return $ret50545055;
} else {
var $z50675068 = D;
var $f50735074 = function(_) {
return R.isFunction(else_DASH_clause645075)?else_DASH_clause645075.app():R.ffi.throwNonFunApp(L[59],else_DASH_clause645075,[]);
};
try {
if(--R.GAS > 0) {
$z50675068 = $f50735074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50735074,
"from":L[59]});
}
} catch($e50655066) {
if(R.isCont($e50655066)) {
var $ss50695070 = {"from":L[59],
"go":function(cont_tail_arg3542023) {
return $Hcont_tail_arg11032022(cont_tail_arg3542023,if_helper3492019);
}};
$e50655066.stack[R.EXN_STACKHEIGHT++] = $ss50695070;
}
if(R.isPyretException($e50655066)) {
$e50655066.pyretStack.push(L[59]);
}
throw $e50655066;
}
var $ret50715072 = $Hcont_tail_arg11032022($z50675068,if_helper3492019);
++R.GAS;
return $ret50715072;
}
} else {
var cont_tail_arg3515079 = R.throwNonBooleanCondition(L[59],("if"),if_DASH_665076);
if(--R.GAS > 0) {
$z50775078 = R.isFunction(if_helper3492019)?if_helper3492019.app(cont_tail_arg3515079):R.ffi.throwNonFunApp(L[59],if_helper3492019,[cont_tail_arg3515079]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3492019)?if_helper3492019.app(cont_tail_arg3515079):R.ffi.throwNonFunApp(L[59],if_helper3492019,[cont_tail_arg3515079]);
},
"from":L[59]});
}
++R.GAS;
return $z50775078;
}
};
},{"length":3});
var anf_variant_member3804587 = R.makeMethod(function(self651869) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[59],0,arguments);
}
var anf_arg3645047 = G(self651869,"val1",L[59]);
var $z50395040 = D;
var $f50455046 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg3645047):R.ffi.throwNonFunApp(L[59],torepr8,[anf_arg3645047]);
};
try {
if(--R.GAS > 0) {
$z50395040 = $f50455046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50455046,
"from":L[59]});
}
} catch($e50375038) {
if(R.isCont($e50375038)) {
var $ss50415042 = {"from":L[59],
"go":function(anf_arg3651868) {
return $Hanf_arg11161867(anf_arg3651868,self651869,_plus5,torepr8);
}};
$e50375038.stack[R.EXN_STACKHEIGHT++] = $ss50415042;
}
if(R.isPyretException($e50375038)) {
$e50375038.pyretStack.push(L[59]);
}
throw $e50375038;
}
var $ret50435044 = $Hanf_arg11161867($z50395040,self651869,_plus5,torepr8);
++R.GAS;
return $ret50435044;
};
},{"length":1});
var anf_variant_member3944588 = R.makeMethod(function(self1081767) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[58],0,arguments);
}
var anf_arg3825036 = G(self1081767,"opname",L[224]);
var $z50285029 = D;
var $f50345035 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: Invalid use of "),anf_arg3825036):R.ffi.throwNonFunApp(L[52],_plus5,[("Error: Invalid use of "),anf_arg3825036]);
};
try {
if(--R.GAS > 0) {
$z50285029 = $f50345035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50345035,
"from":L[52]});
}
} catch($e50265027) {
if(R.isCont($e50265027)) {
var $ss50305031 = {"from":L[52],
"go":function(anf_arg3831766) {
return $Hanf_arg11251765(anf_arg3831766,self1081767,_plus5,torepr8);
}};
$e50265027.stack[R.EXN_STACKHEIGHT++] = $ss50305031;
}
if(R.isPyretException($e50265027)) {
$e50265027.pyretStack.push(L[52]);
}
throw $e50265027;
}
var $ret50325033 = $Hanf_arg11251765($z50285029,self1081767,_plus5,torepr8);
++R.GAS;
return $ret50325033;
};
},{"length":1});
var anf_variant_member4084598 = R.makeMethod(function(self685006) {
return function(cases_DASH_funs695007,else_DASH_clause705018) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[51],2,arguments);
}
var if_DASH_725019 = R.hasField(cases_DASH_funs695007,("arity-mismatch"));
var if_helper3961758 = R.makeFunction(function(if_helper_arg3975024) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[51],1,arguments);
}
var ann_DASH_check_DASH_temp3955025 = if_helper_arg3975024;
return ann_DASH_check_DASH_temp3955025;
});
var anf_if4005023 = R.isBoolean(if_DASH_725019);
if(R.isPyretTrue(anf_if4005023)) {
if(R.isPyretTrue(if_DASH_725019)) {
var call_DASH_arity_DASH_mismatch675002 = G(cases_DASH_funs695007,"arity-mismatch",L[51]);
var anf_arg4035003 = G(self685006,"fun-loc",L[223]);
var anf_arg4045004 = G(self685006,"expected-arity",L[222]);
var anf_arg4055005 = G(self685006,"args",L[221]);
var $z49944995 = D;
var $f50005001 = function(_) {
return R.isFunction(call_DASH_arity_DASH_mismatch675002)?call_DASH_arity_DASH_mismatch675002.app(anf_arg4035003,anf_arg4045004,anf_arg4055005):R.ffi.throwNonFunApp(L[51],call_DASH_arity_DASH_mismatch675002,[anf_arg4035003,anf_arg4045004,anf_arg4055005]);
};
try {
if(--R.GAS > 0) {
$z49944995 = $f50005001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50005001,
"from":L[51]});
}
} catch($e49924993) {
if(R.isCont($e49924993)) {
var $ss49964997 = {"from":L[51],
"go":function(cont_tail_arg4061757) {
return $Hcont_tail_arg11261756(cont_tail_arg4061757,if_helper3961758);
}};
$e49924993.stack[R.EXN_STACKHEIGHT++] = $ss49964997;
}
if(R.isPyretException($e49924993)) {
$e49924993.pyretStack.push(L[51]);
}
throw $e49924993;
}
var $ret49984999 = $Hcont_tail_arg11261756($z49944995,if_helper3961758);
++R.GAS;
return $ret49984999;
} else {
var $z50105011 = D;
var $f50165017 = function(_) {
return R.isFunction(else_DASH_clause705018)?else_DASH_clause705018.app():R.ffi.throwNonFunApp(L[51],else_DASH_clause705018,[]);
};
try {
if(--R.GAS > 0) {
$z50105011 = $f50165017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50165017,
"from":L[51]});
}
} catch($e50085009) {
if(R.isCont($e50085009)) {
var $ss50125013 = {"from":L[51],
"go":function(cont_tail_arg4011762) {
return $Hcont_tail_arg11271761(cont_tail_arg4011762,if_helper3961758);
}};
$e50085009.stack[R.EXN_STACKHEIGHT++] = $ss50125013;
}
if(R.isPyretException($e50085009)) {
$e50085009.pyretStack.push(L[51]);
}
throw $e50085009;
}
var $ret50145015 = $Hcont_tail_arg11271761($z50105011,if_helper3961758);
++R.GAS;
return $ret50145015;
}
} else {
var cont_tail_arg3985022 = R.throwNonBooleanCondition(L[51],("if"),if_DASH_725019);
if(--R.GAS > 0) {
$z50205021 = R.isFunction(if_helper3961758)?if_helper3961758.app(cont_tail_arg3985022):R.ffi.throwNonFunApp(L[51],if_helper3961758,[cont_tail_arg3985022]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper3961758)?if_helper3961758.app(cont_tail_arg3985022):R.ffi.throwNonFunApp(L[51],if_helper3961758,[cont_tail_arg3985022]);
},
"from":L[51]});
}
++R.GAS;
return $z50205021;
}
};
},{"length":3});
var anf_variant_member4224599 = R.makeMethod(function(self711645) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[51],0,arguments);
}
var anf_arg4104991 = G(self711645,"fun-loc",L[51]);
var $z49834984 = D;
var $f49894990 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4104991):R.ffi.throwNonFunApp(L[51],torepr8,[anf_arg4104991]);
};
try {
if(--R.GAS > 0) {
$z49834984 = $f49894990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49894990,
"from":L[51]});
}
} catch($e49814982) {
if(R.isCont($e49814982)) {
var $ss49854986 = {"from":L[51],
"go":function(anf_arg4111644) {
return $Hanf_arg11371643(anf_arg4111644,self711645,_plus5,torepr8);
}};
$e49814982.stack[R.EXN_STACKHEIGHT++] = $ss49854986;
}
if(R.isPyretException($e49814982)) {
$e49814982.pyretStack.push(L[51]);
}
throw $e49814982;
}
var $ret49874988 = $Hanf_arg11371643($z49834984,self711645,_plus5,torepr8);
++R.GAS;
return $ret49874988;
};
},{"length":1});
var anf_variant_member4374600 = R.makeMethod(function(self1121543) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[50],0,arguments);
}
var anf_bracket4244980 = G(self1121543,"fun-loc",L[220]);
var anf_fun4254979 = G(anf_bracket4244980,"format",L[219]);
var $z49714972 = D;
var $f49774978 = function(_) {
return R.isFunction(anf_fun4254979)?anf_fun4254979.app((true)):R.ffi.throwNonFunApp(L[218],anf_fun4254979,[(true)]);
};
try {
if(--R.GAS > 0) {
$z49714972 = $f49774978();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49774978,
"from":L[218]});
}
} catch($e49694970) {
if(R.isCont($e49694970)) {
var $ss49734974 = {"from":L[218],
"go":function(anf_arg4261542) {
return $Hanf_arg11461541(anf_arg4261542,self1121543,_plus5,tostring9);
}};
$e49694970.stack[R.EXN_STACKHEIGHT++] = $ss49734974;
}
if(R.isPyretException($e49694970)) {
$e49694970.pyretStack.push(L[218]);
}
throw $e49694970;
}
var $ret49754976 = $Hanf_arg11461541($z49714972,self1121543,_plus5,tostring9);
++R.GAS;
return $ret49754976;
};
},{"length":1});
var anf_variant_member4514609 = R.makeMethod(function(self744949) {
return function(cases_DASH_funs754950,else_DASH_clause764961) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[42],2,arguments);
}
var if_DASH_784962 = R.hasField(cases_DASH_funs754950,("non-function-app"));
var if_helper4391534 = R.makeFunction(function(if_helper_arg4404967) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[42],1,arguments);
}
var ann_DASH_check_DASH_temp4384968 = if_helper_arg4404967;
return ann_DASH_check_DASH_temp4384968;
});
var anf_if4434966 = R.isBoolean(if_DASH_784962);
if(R.isPyretTrue(anf_if4434966)) {
if(R.isPyretTrue(if_DASH_784962)) {
var call_DASH_non_DASH_function_DASH_app734945 = G(cases_DASH_funs754950,"non-function-app",L[42]);
var anf_arg4464946 = G(self744949,"loc",L[217]);
var anf_arg4474947 = G(self744949,"non-fun-val",L[216]);
var anf_arg4484948 = G(self744949,"args",L[215]);
var $z49374938 = D;
var $f49434944 = function(_) {
return R.isFunction(call_DASH_non_DASH_function_DASH_app734945)?call_DASH_non_DASH_function_DASH_app734945.app(anf_arg4464946,anf_arg4474947,anf_arg4484948):R.ffi.throwNonFunApp(L[42],call_DASH_non_DASH_function_DASH_app734945,[anf_arg4464946,anf_arg4474947,anf_arg4484948]);
};
try {
if(--R.GAS > 0) {
$z49374938 = $f49434944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49434944,
"from":L[42]});
}
} catch($e49354936) {
if(R.isCont($e49354936)) {
var $ss49394940 = {"from":L[42],
"go":function(cont_tail_arg4491533) {
return $Hcont_tail_arg11471532(cont_tail_arg4491533,if_helper4391534);
}};
$e49354936.stack[R.EXN_STACKHEIGHT++] = $ss49394940;
}
if(R.isPyretException($e49354936)) {
$e49354936.pyretStack.push(L[42]);
}
throw $e49354936;
}
var $ret49414942 = $Hcont_tail_arg11471532($z49374938,if_helper4391534);
++R.GAS;
return $ret49414942;
} else {
var $z49534954 = D;
var $f49594960 = function(_) {
return R.isFunction(else_DASH_clause764961)?else_DASH_clause764961.app():R.ffi.throwNonFunApp(L[42],else_DASH_clause764961,[]);
};
try {
if(--R.GAS > 0) {
$z49534954 = $f49594960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49594960,
"from":L[42]});
}
} catch($e49514952) {
if(R.isCont($e49514952)) {
var $ss49554956 = {"from":L[42],
"go":function(cont_tail_arg4441538) {
return $Hcont_tail_arg11481537(cont_tail_arg4441538,if_helper4391534);
}};
$e49514952.stack[R.EXN_STACKHEIGHT++] = $ss49554956;
}
if(R.isPyretException($e49514952)) {
$e49514952.pyretStack.push(L[42]);
}
throw $e49514952;
}
var $ret49574958 = $Hcont_tail_arg11481537($z49534954,if_helper4391534);
++R.GAS;
return $ret49574958;
}
} else {
var cont_tail_arg4414965 = R.throwNonBooleanCondition(L[42],("if"),if_DASH_784962);
if(--R.GAS > 0) {
$z49634964 = R.isFunction(if_helper4391534)?if_helper4391534.app(cont_tail_arg4414965):R.ffi.throwNonFunApp(L[42],if_helper4391534,[cont_tail_arg4414965]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper4391534)?if_helper4391534.app(cont_tail_arg4414965):R.ffi.throwNonFunApp(L[42],if_helper4391534,[cont_tail_arg4414965]);
},
"from":L[42]});
}
++R.GAS;
return $z49634964;
}
};
},{"length":3});
var anf_variant_member4654610 = R.makeMethod(function(self771421) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[42],0,arguments);
}
var anf_arg4534934 = G(self771421,"loc",L[42]);
var $z49264927 = D;
var $f49324933 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4534934):R.ffi.throwNonFunApp(L[42],torepr8,[anf_arg4534934]);
};
try {
if(--R.GAS > 0) {
$z49264927 = $f49324933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49324933,
"from":L[42]});
}
} catch($e49244925) {
if(R.isCont($e49244925)) {
var $ss49284929 = {"from":L[42],
"go":function(anf_arg4541420) {
return $Hanf_arg11581419(anf_arg4541420,self771421,_plus5,torepr8);
}};
$e49244925.stack[R.EXN_STACKHEIGHT++] = $ss49284929;
}
if(R.isPyretException($e49244925)) {
$e49244925.pyretStack.push(L[42]);
}
throw $e49244925;
}
var $ret49304931 = $Hanf_arg11581419($z49264927,self771421,_plus5,torepr8);
++R.GAS;
return $ret49304931;
};
},{"length":1});
var anf_variant_member4744611 = R.makeMethod(function(self1161369) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[41],0,arguments);
}
var anf_bracket4674923 = G(self1161369,"loc",L[214]);
var anf_fun4684922 = G(anf_bracket4674923,"format",L[213]);
var $z49144915 = D;
var $f49204921 = function(_) {
return R.isFunction(anf_fun4684922)?anf_fun4684922.app((true)):R.ffi.throwNonFunApp(L[212],anf_fun4684922,[(true)]);
};
try {
if(--R.GAS > 0) {
$z49144915 = $f49204921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49204921,
"from":L[212]});
}
} catch($e49124913) {
if(R.isCont($e49124913)) {
var $ss49164917 = {"from":L[212],
"go":function(anf_arg4691368) {
return $Hanf_arg11631367(anf_arg4691368,self1161369,_plus5,torepr8);
}};
$e49124913.stack[R.EXN_STACKHEIGHT++] = $ss49164917;
}
if(R.isPyretException($e49124913)) {
$e49124913.pyretStack.push(L[212]);
}
throw $e49124913;
}
var $ret49184919 = $Hanf_arg11631367($z49144915,self1161369,_plus5,torepr8);
++R.GAS;
return $ret49184919;
};
},{"length":1});
var anf_variant_member4904620 = R.makeMethod(function(self803174) {
return function(cases_DASH_funs814893,else_DASH_clause824904) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[37],2,arguments);
}
var if_DASH_844905 = R.hasField(cases_DASH_funs814893,("bad-app"));
var if_helper4761360 = R.makeFunction(function(if_helper_arg4774910) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[37],1,arguments);
}
var ann_DASH_check_DASH_temp4754911 = if_helper_arg4774910;
return ann_DASH_check_DASH_temp4754911;
});
var anf_if4804909 = R.isBoolean(if_DASH_844905);
if(R.isPyretTrue(anf_if4804909)) {
if(R.isPyretTrue(if_DASH_844905)) {
var call_DASH_bad_DASH_app794887 = G(cases_DASH_funs814893,"bad-app",L[37]);
var anf_arg4834888 = G(self803174,"loc",L[211]);
var anf_arg4844889 = G(self803174,"fun-name",L[210]);
var anf_arg4854890 = G(self803174,"message",L[209]);
var anf_arg4864891 = G(self803174,"arg-position",L[208]);
var anf_arg4874892 = G(self803174,"arg-val",L[207]);
var $z48794880 = D;
var $f48854886 = function(_) {
return R.isFunction(call_DASH_bad_DASH_app794887)?call_DASH_bad_DASH_app794887.app(anf_arg4834888,anf_arg4844889,anf_arg4854890,anf_arg4864891,anf_arg4874892):R.ffi.throwNonFunApp(L[37],call_DASH_bad_DASH_app794887,[anf_arg4834888,anf_arg4844889,anf_arg4854890,anf_arg4864891,anf_arg4874892]);
};
try {
if(--R.GAS > 0) {
$z48794880 = $f48854886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48854886,
"from":L[37]});
}
} catch($e48774878) {
if(R.isCont($e48774878)) {
var $ss48814882 = {"from":L[37],
"go":function(cont_tail_arg4881359) {
return $Hcont_tail_arg11641358(cont_tail_arg4881359,if_helper4761360);
}};
$e48774878.stack[R.EXN_STACKHEIGHT++] = $ss48814882;
}
if(R.isPyretException($e48774878)) {
$e48774878.pyretStack.push(L[37]);
}
throw $e48774878;
}
var $ret48834884 = $Hcont_tail_arg11641358($z48794880,if_helper4761360);
++R.GAS;
return $ret48834884;
} else {
var $z48964897 = D;
var $f49024903 = function(_) {
return R.isFunction(else_DASH_clause824904)?else_DASH_clause824904.app():R.ffi.throwNonFunApp(L[37],else_DASH_clause824904,[]);
};
try {
if(--R.GAS > 0) {
$z48964897 = $f49024903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49024903,
"from":L[37]});
}
} catch($e48944895) {
if(R.isCont($e48944895)) {
var $ss48984899 = {"from":L[37],
"go":function(cont_tail_arg4811364) {
return $Hcont_tail_arg11651363(cont_tail_arg4811364,if_helper4761360);
}};
$e48944895.stack[R.EXN_STACKHEIGHT++] = $ss48984899;
}
if(R.isPyretException($e48944895)) {
$e48944895.pyretStack.push(L[37]);
}
throw $e48944895;
}
var $ret49004901 = $Hcont_tail_arg11651363($z48964897,if_helper4761360);
++R.GAS;
return $ret49004901;
}
} else {
var cont_tail_arg4784908 = R.throwNonBooleanCondition(L[37],("if"),if_DASH_844905);
if(--R.GAS > 0) {
$z49064907 = R.isFunction(if_helper4761360)?if_helper4761360.app(cont_tail_arg4784908):R.ffi.throwNonFunApp(L[37],if_helper4761360,[cont_tail_arg4784908]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper4761360)?if_helper4761360.app(cont_tail_arg4784908):R.ffi.throwNonFunApp(L[37],if_helper4761360,[cont_tail_arg4784908]);
},
"from":L[37]});
}
++R.GAS;
return $z49064907;
}
};
},{"length":3});
var anf_variant_member5124621 = R.makeMethod(function(self831173) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[37],0,arguments);
}
var anf_arg4924876 = G(self831173,"loc",L[37]);
var $z48684869 = D;
var $f48744875 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg4924876):R.ffi.throwNonFunApp(L[37],torepr8,[anf_arg4924876]);
};
try {
if(--R.GAS > 0) {
$z48684869 = $f48744875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48744875,
"from":L[37]});
}
} catch($e48664867) {
if(R.isCont($e48664867)) {
var $ss48704871 = {"from":L[37],
"go":function(anf_arg4931172) {
return $Hanf_arg11811171(anf_arg4931172,self831173,_plus5,torepr8);
}};
$e48664867.stack[R.EXN_STACKHEIGHT++] = $ss48704871;
}
if(R.isPyretException($e48664867)) {
$e48664867.pyretStack.push(L[37]);
}
throw $e48664867;
}
var $ret48724873 = $Hanf_arg11811171($z48684869,self831173,_plus5,torepr8);
++R.GAS;
return $ret48724873;
};
},{"length":1});
var anf_variant_member5254632 = R.makeMethod(function(self864846) {
return function(cases_DASH_funs874847,else_DASH_clause884858) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[36],2,arguments);
}
var if_DASH_904859 = R.hasField(cases_DASH_funs874847,("uninitialized-id"));
var if_helper5141164 = R.makeFunction(function(if_helper_arg5154864) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[36],1,arguments);
}
var ann_DASH_check_DASH_temp5134865 = if_helper_arg5154864;
return ann_DASH_check_DASH_temp5134865;
});
var anf_if5184863 = R.isBoolean(if_DASH_904859);
if(R.isPyretTrue(anf_if5184863)) {
if(R.isPyretTrue(if_DASH_904859)) {
var call_DASH_uninitialized_DASH_id854843 = G(cases_DASH_funs874847,"uninitialized-id",L[36]);
var anf_arg5214844 = G(self864846,"loc",L[206]);
var anf_arg5224845 = G(self864846,"name",L[205]);
var $z48354836 = D;
var $f48414842 = function(_) {
return R.isFunction(call_DASH_uninitialized_DASH_id854843)?call_DASH_uninitialized_DASH_id854843.app(anf_arg5214844,anf_arg5224845):R.ffi.throwNonFunApp(L[36],call_DASH_uninitialized_DASH_id854843,[anf_arg5214844,anf_arg5224845]);
};
try {
if(--R.GAS > 0) {
$z48354836 = $f48414842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48414842,
"from":L[36]});
}
} catch($e48334834) {
if(R.isCont($e48334834)) {
var $ss48374838 = {"from":L[36],
"go":function(cont_tail_arg5231163) {
return $Hcont_tail_arg11821162(cont_tail_arg5231163,if_helper5141164);
}};
$e48334834.stack[R.EXN_STACKHEIGHT++] = $ss48374838;
}
if(R.isPyretException($e48334834)) {
$e48334834.pyretStack.push(L[36]);
}
throw $e48334834;
}
var $ret48394840 = $Hcont_tail_arg11821162($z48354836,if_helper5141164);
++R.GAS;
return $ret48394840;
} else {
var $z48504851 = D;
var $f48564857 = function(_) {
return R.isFunction(else_DASH_clause884858)?else_DASH_clause884858.app():R.ffi.throwNonFunApp(L[36],else_DASH_clause884858,[]);
};
try {
if(--R.GAS > 0) {
$z48504851 = $f48564857();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48564857,
"from":L[36]});
}
} catch($e48484849) {
if(R.isCont($e48484849)) {
var $ss48524853 = {"from":L[36],
"go":function(cont_tail_arg5191168) {
return $Hcont_tail_arg11831167(cont_tail_arg5191168,if_helper5141164);
}};
$e48484849.stack[R.EXN_STACKHEIGHT++] = $ss48524853;
}
if(R.isPyretException($e48484849)) {
$e48484849.pyretStack.push(L[36]);
}
throw $e48484849;
}
var $ret48544855 = $Hcont_tail_arg11831167($z48504851,if_helper5141164);
++R.GAS;
return $ret48544855;
}
} else {
var cont_tail_arg5164862 = R.throwNonBooleanCondition(L[36],("if"),if_DASH_904859);
if(--R.GAS > 0) {
$z48604861 = R.isFunction(if_helper5141164)?if_helper5141164.app(cont_tail_arg5164862):R.ffi.throwNonFunApp(L[36],if_helper5141164,[cont_tail_arg5164862]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper5141164)?if_helper5141164.app(cont_tail_arg5164862):R.ffi.throwNonFunApp(L[36],if_helper5141164,[cont_tail_arg5164862]);
},
"from":L[36]});
}
++R.GAS;
return $z48604861;
}
};
},{"length":3});
var anf_variant_member5354633 = R.makeMethod(function(self891088) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[36],0,arguments);
}
var anf_arg5274832 = G(self891088,"loc",L[36]);
var $z48244825 = D;
var $f48304831 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg5274832):R.ffi.throwNonFunApp(L[36],torepr8,[anf_arg5274832]);
};
try {
if(--R.GAS > 0) {
$z48244825 = $f48304831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48304831,
"from":L[36]});
}
} catch($e48224823) {
if(R.isCont($e48224823)) {
var $ss48264827 = {"from":L[36],
"go":function(anf_arg5281087) {
return $Hanf_arg11901086(anf_arg5281087,self891088,_plus5,torepr8);
}};
$e48224823.stack[R.EXN_STACKHEIGHT++] = $ss48264827;
}
if(R.isPyretException($e48224823)) {
$e48224823.pyretStack.push(L[36]);
}
throw $e48224823;
}
var $ret48284829 = $Hanf_arg11901086($z48244825,self891088,_plus5,torepr8);
++R.GAS;
return $ret48284829;
};
},{"length":1});
var anf_variant_member5444634 = R.makeMethod(function(self1241035) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[35],0,arguments);
}
var anf_arg5374821 = G(self1241035,"name",L[204]);
var $z48134814 = D;
var $f48194820 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Error: The identifier "),anf_arg5374821):R.ffi.throwNonFunApp(L[31],_plus5,[("Error: The identifier "),anf_arg5374821]);
};
try {
if(--R.GAS > 0) {
$z48134814 = $f48194820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48194820,
"from":L[31]});
}
} catch($e48114812) {
if(R.isCont($e48114812)) {
var $ss48154816 = {"from":L[31],
"go":function(anf_arg5381034) {
return $Hanf_arg11951033(anf_arg5381034,self1241035,_plus5);
}};
$e48114812.stack[R.EXN_STACKHEIGHT++] = $ss48154816;
}
if(R.isPyretException($e48114812)) {
$e48114812.pyretStack.push(L[31]);
}
throw $e48114812;
}
var $ret48174818 = $Hanf_arg11951033($z48134814,self1241035,_plus5);
++R.GAS;
return $ret48174818;
};
},{"length":1});
var anf_variant_member5564642 = R.makeMethod(function(self924791) {
return function(cases_DASH_funs934792,else_DASH_clause944803) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[30],2,arguments);
}
var if_DASH_964804 = R.hasField(cases_DASH_funs934792,("module-load-failure"));
var if_helper5461026 = R.makeFunction(function(if_helper_arg5474809) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
var ann_DASH_check_DASH_temp5454810 = if_helper_arg5474809;
return ann_DASH_check_DASH_temp5454810;
});
var anf_if5504808 = R.isBoolean(if_DASH_964804);
if(R.isPyretTrue(anf_if5504808)) {
if(R.isPyretTrue(if_DASH_964804)) {
var call_DASH_module_DASH_load_DASH_failure914789 = G(cases_DASH_funs934792,"module-load-failure",L[30]);
var anf_arg5534790 = G(self924791,"names",L[203]);
var $z47814782 = D;
var $f47874788 = function(_) {
return R.isFunction(call_DASH_module_DASH_load_DASH_failure914789)?call_DASH_module_DASH_load_DASH_failure914789.app(anf_arg5534790):R.ffi.throwNonFunApp(L[30],call_DASH_module_DASH_load_DASH_failure914789,[anf_arg5534790]);
};
try {
if(--R.GAS > 0) {
$z47814782 = $f47874788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47874788,
"from":L[30]});
}
} catch($e47794780) {
if(R.isCont($e47794780)) {
var $ss47834784 = {"from":L[30],
"go":function(cont_tail_arg5541025) {
return $Hcont_tail_arg11961024(cont_tail_arg5541025,if_helper5461026);
}};
$e47794780.stack[R.EXN_STACKHEIGHT++] = $ss47834784;
}
if(R.isPyretException($e47794780)) {
$e47794780.pyretStack.push(L[30]);
}
throw $e47794780;
}
var $ret47854786 = $Hcont_tail_arg11961024($z47814782,if_helper5461026);
++R.GAS;
return $ret47854786;
} else {
var $z47954796 = D;
var $f48014802 = function(_) {
return R.isFunction(else_DASH_clause944803)?else_DASH_clause944803.app():R.ffi.throwNonFunApp(L[30],else_DASH_clause944803,[]);
};
try {
if(--R.GAS > 0) {
$z47954796 = $f48014802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48014802,
"from":L[30]});
}
} catch($e47934794) {
if(R.isCont($e47934794)) {
var $ss47974798 = {"from":L[30],
"go":function(cont_tail_arg5511030) {
return $Hcont_tail_arg11971029(cont_tail_arg5511030,if_helper5461026);
}};
$e47934794.stack[R.EXN_STACKHEIGHT++] = $ss47974798;
}
if(R.isPyretException($e47934794)) {
$e47934794.pyretStack.push(L[30]);
}
throw $e47934794;
}
var $ret47994800 = $Hcont_tail_arg11971029($z47954796,if_helper5461026);
++R.GAS;
return $ret47994800;
}
} else {
var cont_tail_arg5484807 = R.throwNonBooleanCondition(L[30],("if"),if_DASH_964804);
if(--R.GAS > 0) {
$z48054806 = R.isFunction(if_helper5461026)?if_helper5461026.app(cont_tail_arg5484807):R.ffi.throwNonFunApp(L[30],if_helper5461026,[cont_tail_arg5484807]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper5461026)?if_helper5461026.app(cont_tail_arg5484807):R.ffi.throwNonFunApp(L[30],if_helper5461026,[cont_tail_arg5484807]);
},
"from":L[30]});
}
++R.GAS;
return $z48054806;
}
};
},{"length":3});
var anf_variant_member5624643 = R.makeMethod(function(self954778) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[30],0,arguments);
}
var anf_arg5584777 = G(self954778,"names",L[30]);
var $z47694770 = D;
var $f47754776 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg5584777):R.ffi.throwNonFunApp(L[30],torepr8,[anf_arg5584777]);
};
try {
if(--R.GAS > 0) {
$z47694770 = $f47754776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47754776,
"from":L[30]});
}
} catch($e47674768) {
if(R.isCont($e47674768)) {
var $ss47714772 = {"from":L[30],
"go":function(anf_arg559987) {
return $Hanf_arg1201986(anf_arg559987,_plus5);
}};
$e47674768.stack[R.EXN_STACKHEIGHT++] = $ss47714772;
}
if(R.isPyretException($e47674768)) {
$e47674768.pyretStack.push(L[30]);
}
throw $e47674768;
}
var $ret47734774 = $Hanf_arg1201986($z47694770,_plus5);
++R.GAS;
return $ret47734774;
};
},{"length":1});
var anf_variant_member5664644 = R.makeMethod(function(self1264766) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[29],0,arguments);
}
var anf_arg5644765 = G(self1264766,"names",L[202]);
var $z47574758 = D;
var $f47634764 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg5644765):R.ffi.throwNonFunApp(L[201],torepr8,[anf_arg5644765]);
};
try {
if(--R.GAS > 0) {
$z47574758 = $f47634764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47634764,
"from":L[201]});
}
} catch($e47554756) {
if(R.isCont($e47554756)) {
var $ss47594760 = {"from":L[201],
"go":function(anf_arg565973) {
return $Hanf_arg1203972(anf_arg565973,_plus5);
}};
$e47554756.stack[R.EXN_STACKHEIGHT++] = $ss47594760;
}
if(R.isPyretException($e47554756)) {
$e47554756.pyretStack.push(L[201]);
}
throw $e47554756;
}
var $ret47614762 = $Hanf_arg1203972($z47574758,_plus5);
++R.GAS;
return $ret47614762;
};
},{"length":1});
var anf_variant_member5814651 = R.makeMethod(function(self984735) {
return function(cases_DASH_funs994736,else_DASH_clause1004747) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[28],2,arguments);
}
var if_DASH_1024748 = R.hasField(cases_DASH_funs994736,("invalid-array-index"));
var if_helper568965 = R.makeFunction(function(if_helper_arg5694753) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[28],1,arguments);
}
var ann_DASH_check_DASH_temp5674754 = if_helper_arg5694753;
return ann_DASH_check_DASH_temp5674754;
});
var anf_if5724752 = R.isBoolean(if_DASH_1024748);
if(R.isPyretTrue(anf_if5724752)) {
if(R.isPyretTrue(if_DASH_1024748)) {
var call_DASH_invalid_DASH_array_DASH_index974730 = G(cases_DASH_funs994736,"invalid-array-index",L[28]);
var anf_arg5754731 = G(self984735,"method-name",L[200]);
var anf_arg5764732 = G(self984735,"array",L[199]);
var anf_arg5774733 = G(self984735,"index",L[198]);
var anf_arg5784734 = G(self984735,"reason",L[197]);
var $z47224723 = D;
var $f47284729 = function(_) {
return R.isFunction(call_DASH_invalid_DASH_array_DASH_index974730)?call_DASH_invalid_DASH_array_DASH_index974730.app(anf_arg5754731,anf_arg5764732,anf_arg5774733,anf_arg5784734):R.ffi.throwNonFunApp(L[28],call_DASH_invalid_DASH_array_DASH_index974730,[anf_arg5754731,anf_arg5764732,anf_arg5774733,anf_arg5784734]);
};
try {
if(--R.GAS > 0) {
$z47224723 = $f47284729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47284729,
"from":L[28]});
}
} catch($e47204721) {
if(R.isCont($e47204721)) {
var $ss47244725 = {"from":L[28],
"go":function(cont_tail_arg579964) {
return $Hcont_tail_arg1204963(cont_tail_arg579964,if_helper568965);
}};
$e47204721.stack[R.EXN_STACKHEIGHT++] = $ss47244725;
}
if(R.isPyretException($e47204721)) {
$e47204721.pyretStack.push(L[28]);
}
throw $e47204721;
}
var $ret47264727 = $Hcont_tail_arg1204963($z47224723,if_helper568965);
++R.GAS;
return $ret47264727;
} else {
var $z47394740 = D;
var $f47454746 = function(_) {
return R.isFunction(else_DASH_clause1004747)?else_DASH_clause1004747.app():R.ffi.throwNonFunApp(L[28],else_DASH_clause1004747,[]);
};
try {
if(--R.GAS > 0) {
$z47394740 = $f47454746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47454746,
"from":L[28]});
}
} catch($e47374738) {
if(R.isCont($e47374738)) {
var $ss47414742 = {"from":L[28],
"go":function(cont_tail_arg573969) {
return $Hcont_tail_arg1205968(cont_tail_arg573969,if_helper568965);
}};
$e47374738.stack[R.EXN_STACKHEIGHT++] = $ss47414742;
}
if(R.isPyretException($e47374738)) {
$e47374738.pyretStack.push(L[28]);
}
throw $e47374738;
}
var $ret47434744 = $Hcont_tail_arg1205968($z47394740,if_helper568965);
++R.GAS;
return $ret47434744;
}
} else {
var cont_tail_arg5704751 = R.throwNonBooleanCondition(L[28],("if"),if_DASH_1024748);
if(--R.GAS > 0) {
$z47494750 = R.isFunction(if_helper568965)?if_helper568965.app(cont_tail_arg5704751):R.ffi.throwNonFunApp(L[28],if_helper568965,[cont_tail_arg5704751]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper568965)?if_helper568965.app(cont_tail_arg5704751):R.ffi.throwNonFunApp(L[28],if_helper568965,[cont_tail_arg5704751]);
},
"from":L[28]});
}
++R.GAS;
return $z47494750;
}
};
},{"length":3});
var anf_variant_member5994652 = R.makeMethod(function(self101815) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[28],0,arguments);
}
var anf_arg5834719 = G(self101815,"method-name",L[28]);
var $z47114712 = D;
var $f47174718 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg5834719):R.ffi.throwNonFunApp(L[28],torepr8,[anf_arg5834719]);
};
try {
if(--R.GAS > 0) {
$z47114712 = $f47174718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47174718,
"from":L[28]});
}
} catch($e47094710) {
if(R.isCont($e47094710)) {
var $ss47134714 = {"from":L[28],
"go":function(anf_arg584814) {
return $Hanf_arg1218813(anf_arg584814,self101815,_plus5,torepr8);
}};
$e47094710.stack[R.EXN_STACKHEIGHT++] = $ss47134714;
}
if(R.isPyretException($e47094710)) {
$e47094710.pyretStack.push(L[28]);
}
throw $e47094710;
}
var $ret47154716 = $Hanf_arg1218813($z47114712,self101815,_plus5,torepr8);
++R.GAS;
return $ret47154716;
};
},{"length":1});
var anf_variant_member6094653 = R.makeMethod(function(self131750) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[26],0,arguments);
}
var anf_arg6014708 = G(self131750,"index",L[196]);
var $z47004701 = D;
var $f47064707 = function(_) {
return R.isFunction(tostring9)?tostring9.app(anf_arg6014708):R.ffi.throwNonFunApp(L[195],tostring9,[anf_arg6014708]);
};
try {
if(--R.GAS > 0) {
$z47004701 = $f47064707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47064707,
"from":L[195]});
}
} catch($e46984699) {
if(R.isCont($e46984699)) {
var $ss47024703 = {"from":L[195],
"go":function(anf_arg602749) {
return $Hanf_arg1224748(anf_arg602749,self131750,_plus5);
}};
$e46984699.stack[R.EXN_STACKHEIGHT++] = $ss47024703;
}
if(R.isPyretException($e46984699)) {
$e46984699.pyretStack.push(L[195]);
}
throw $e46984699;
}
var $ret47044705 = $Hanf_arg1224748($z47004701,self131750,_plus5);
++R.GAS;
return $ret47044705;
};
},{"length":1});
var anf_singleton_variant_member6204663 = R.makeMethod(function(self1044697) {
return function(cases_DASH_funs1054678,else_DASH_clause1064689) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[23],2,arguments);
}
var if_DASH_1084690 = R.hasField(cases_DASH_funs1054678,("user-break"));
var if_helper611741 = R.makeFunction(function(if_helper_arg6124695) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
var ann_DASH_check_DASH_temp6104696 = if_helper_arg6124695;
return ann_DASH_check_DASH_temp6104696;
});
var anf_if6154694 = R.isBoolean(if_DASH_1084690);
if(R.isPyretTrue(anf_if6154694)) {
if(R.isPyretTrue(if_DASH_1084690)) {
var call_DASH_user_DASH_break1034677 = G(cases_DASH_funs1054678,"user-break",L[23]);
var $z46694670 = D;
var $f46754676 = function(_) {
return R.isFunction(call_DASH_user_DASH_break1034677)?call_DASH_user_DASH_break1034677.app():R.ffi.throwNonFunApp(L[23],call_DASH_user_DASH_break1034677,[]);
};
try {
if(--R.GAS > 0) {
$z46694670 = $f46754676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46754676,
"from":L[23]});
}
} catch($e46674668) {
if(R.isCont($e46674668)) {
var $ss46714672 = {"from":L[23],
"go":function(cont_tail_arg618740) {
return $Hcont_tail_arg1225739(cont_tail_arg618740,if_helper611741);
}};
$e46674668.stack[R.EXN_STACKHEIGHT++] = $ss46714672;
}
if(R.isPyretException($e46674668)) {
$e46674668.pyretStack.push(L[23]);
}
throw $e46674668;
}
var $ret46734674 = $Hcont_tail_arg1225739($z46694670,if_helper611741);
++R.GAS;
return $ret46734674;
} else {
var $z46814682 = D;
var $f46874688 = function(_) {
return R.isFunction(else_DASH_clause1064689)?else_DASH_clause1064689.app():R.ffi.throwNonFunApp(L[23],else_DASH_clause1064689,[]);
};
try {
if(--R.GAS > 0) {
$z46814682 = $f46874688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46874688,
"from":L[23]});
}
} catch($e46794680) {
if(R.isCont($e46794680)) {
var $ss46834684 = {"from":L[23],
"go":function(cont_tail_arg616745) {
return $Hcont_tail_arg1226744(cont_tail_arg616745,if_helper611741);
}};
$e46794680.stack[R.EXN_STACKHEIGHT++] = $ss46834684;
}
if(R.isPyretException($e46794680)) {
$e46794680.pyretStack.push(L[23]);
}
throw $e46794680;
}
var $ret46854686 = $Hcont_tail_arg1226744($z46814682,if_helper611741);
++R.GAS;
return $ret46854686;
}
} else {
var cont_tail_arg6134693 = R.throwNonBooleanCondition(L[23],("if"),if_DASH_1084690);
if(--R.GAS > 0) {
$z46914692 = R.isFunction(if_helper611741)?if_helper611741.app(cont_tail_arg6134693):R.ffi.throwNonFunApp(L[23],if_helper611741,[cont_tail_arg6134693]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper611741)?if_helper611741.app(cont_tail_arg6134693):R.ffi.throwNonFunApp(L[23],if_helper611741,[cont_tail_arg6134693]);
},
"from":L[23]});
}
++R.GAS;
return $z46914692;
}
};
},{"length":3});
var anf_singleton_variant_member6224664 = R.makeMethod(function(self1074666) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[23],0,arguments);
}
var ann_DASH_check_DASH_temp6214665 = ("user-break");
return ann_DASH_check_DASH_temp6214665;
};
},{"length":1});
var anf_assign6233645 = (function() {
var $message_DASH_exception_DASH_base44764477 = {"_match":anf_variant_member124481,
"_torepr":anf_variant_member184482,
"tostring":anf_variant_member204483};
var $message_DASH_exception_DASH_brands44794480 = {"$brand-message-exception4478":true};
$message_DASH_exception_DASH_brands44794480[RuntimeErrorT123642._brand] = true
var $no_DASH_branches_DASH_matched_DASH_base44854486 = {"_match":anf_variant_member334490,
"_torepr":anf_variant_member434491,
"tostring":anf_variant_member474492};
var $no_DASH_branches_DASH_matched_DASH_brands44884489 = {"$brand-no-branches-matched4487":true};
$no_DASH_branches_DASH_matched_DASH_brands44884489[RuntimeErrorT123642._brand] = true
var $internal_DASH_error_DASH_base44954496 = {"_match":anf_variant_member604500,
"_torepr":anf_variant_member704501,
"tostring":anf_variant_member774502};
var $internal_DASH_error_DASH_brands44984499 = {"$brand-internal-error4497":true};
$internal_DASH_error_DASH_brands44984499[RuntimeErrorT123642._brand] = true
var $field_DASH_not_DASH_found_DASH_base45054506 = {"_match":anf_variant_member914510,
"_torepr":anf_variant_member1054511,
"tostring":anf_variant_member1174512};
var $field_DASH_not_DASH_found_DASH_brands45084509 = {"$brand-field-not-found4507":true};
$field_DASH_not_DASH_found_DASH_brands45084509[RuntimeErrorT123642._brand] = true
var $lookup_DASH_non_DASH_object_DASH_base45164517 = {"_match":anf_variant_member1314521,
"_torepr":anf_variant_member1454522,
"tostring":anf_variant_member1584523};
var $lookup_DASH_non_DASH_object_DASH_brands45194520 = {"$brand-lookup-non-object4518":true};
$lookup_DASH_non_DASH_object_DASH_brands45194520[RuntimeErrorT123642._brand] = true
var $non_DASH_boolean_DASH_condition_DASH_base45274528 = {"_match":anf_variant_member1724532,
"_torepr":anf_variant_member1864533,
"tostring":anf_variant_member1984534};
var $non_DASH_boolean_DASH_condition_DASH_brands45304531 = {"$brand-non-boolean-condition4529":true};
$non_DASH_boolean_DASH_condition_DASH_brands45304531[RuntimeErrorT123642._brand] = true
var $non_DASH_boolean_DASH_op_DASH_base45384539 = {"_match":anf_variant_member2134543,
"_torepr":anf_variant_member2314544,
"tostring":anf_variant_member2464545};
var $non_DASH_boolean_DASH_op_DASH_brands45414542 = {"$brand-non-boolean-op4540":true};
$non_DASH_boolean_DASH_op_DASH_brands45414542[RuntimeErrorT123642._brand] = true
var $generic_DASH_type_DASH_mismatch_DASH_base45504551 = {"_match":anf_variant_member2594555,
"_torepr":anf_variant_member2694556,
"tostring":anf_variant_member2764557};
var $generic_DASH_type_DASH_mismatch_DASH_brands45534554 = {"$brand-generic-type-mismatch4552":true};
$generic_DASH_type_DASH_mismatch_DASH_brands45534554[RuntimeErrorT123642._brand] = true
var $outside_DASH_numeric_DASH_range_DASH_base45604561 = {"_match":anf_variant_member2904565,
"_torepr":anf_variant_member3044566,
"tostring":anf_variant_member3164567};
var $outside_DASH_numeric_DASH_range_DASH_brands45634564 = {"$brand-outside-numeric-range4562":true};
$outside_DASH_numeric_DASH_range_DASH_brands45634564[RuntimeErrorT123642._brand] = true
var $plus_DASH_error_DASH_base45714572 = {"_match":anf_variant_member3294576,
"_torepr":anf_variant_member3394577,
"tostring":anf_variant_member3474578};
var $plus_DASH_error_DASH_brands45744575 = {"$brand-plus-error4573":true};
$plus_DASH_error_DASH_brands45744575[RuntimeErrorT123642._brand] = true
var $numeric_DASH_binop_DASH_error_DASH_base45814582 = {"_match":anf_variant_member3624586,
"_torepr":anf_variant_member3804587,
"tostring":anf_variant_member3944588};
var $numeric_DASH_binop_DASH_error_DASH_brands45844585 = {"$brand-numeric-binop-error4583":true};
$numeric_DASH_binop_DASH_error_DASH_brands45844585[RuntimeErrorT123642._brand] = true
var $arity_DASH_mismatch_DASH_base45934594 = {"_match":anf_variant_member4084598,
"_torepr":anf_variant_member4224599,
"tostring":anf_variant_member4374600};
var $arity_DASH_mismatch_DASH_brands45964597 = {"$brand-arity-mismatch4595":true};
$arity_DASH_mismatch_DASH_brands45964597[RuntimeErrorT123642._brand] = true
var $non_DASH_function_DASH_app_DASH_base46044605 = {"_match":anf_variant_member4514609,
"_torepr":anf_variant_member4654610,
"tostring":anf_variant_member4744611};
var $non_DASH_function_DASH_app_DASH_brands46074608 = {"$brand-non-function-app4606":true};
$non_DASH_function_DASH_app_DASH_brands46074608[RuntimeErrorT123642._brand] = true
var $bad_DASH_app_DASH_base46154616 = {"_match":anf_variant_member4904620,
"_torepr":anf_variant_member5124621};
var $bad_DASH_app_DASH_brands46184619 = {"$brand-bad-app4617":true};
$bad_DASH_app_DASH_brands46184619[RuntimeErrorT123642._brand] = true
var $uninitialized_DASH_id_DASH_base46274628 = {"_match":anf_variant_member5254632,
"_torepr":anf_variant_member5354633,
"tostring":anf_variant_member5444634};
var $uninitialized_DASH_id_DASH_brands46304631 = {"$brand-uninitialized-id4629":true};
$uninitialized_DASH_id_DASH_brands46304631[RuntimeErrorT123642._brand] = true
var $module_DASH_load_DASH_failure_DASH_base46374638 = {"_match":anf_variant_member5564642,
"_torepr":anf_variant_member5624643,
"tostring":anf_variant_member5664644};
var $module_DASH_load_DASH_failure_DASH_brands46404641 = {"$brand-module-load-failure4639":true};
$module_DASH_load_DASH_failure_DASH_brands46404641[RuntimeErrorT123642._brand] = true
var $invalid_DASH_array_DASH_index_DASH_base46464647 = {"_match":anf_variant_member5814651,
"_torepr":anf_variant_member5994652,
"tostring":anf_variant_member6094653};
var $invalid_DASH_array_DASH_index_DASH_brands46494650 = {"$brand-invalid-array-index4648":true};
$invalid_DASH_array_DASH_index_DASH_brands46494650[RuntimeErrorT123642._brand] = true
var $user_DASH_break_DASH_base46584659 = {"_match":anf_singleton_variant_member6204663,
"_torepr":anf_singleton_variant_member6224664};
var $user_DASH_break_DASH_brands46614662 = {"$brand-user-break4660":true};
$user_DASH_break_DASH_brands46614662[RuntimeErrorT123642._brand] = true
return R.makeObject({"RuntimeError":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,RuntimeErrorT123642._brand));
}),
"is-message-exception":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[113],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-message-exception4478"));
}),
"message-exception":R.makeFunction(function(message694484) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[166],1,arguments);
}
return R.checkAnnArgs([$type$String11],[message694484],[L[167]],function() {
var dict = R.create($message_DASH_exception_DASH_base44764477);
dict["message"] = message694484
return R.makeBrandedObject(dict,$message_DASH_exception_DASH_brands44794480);
});
}),
"is-no-branches-matched":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[112],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-no-branches-matched4487"));
}),
"no-branches-matched":R.makeFunction(function(loc714493,expression724494) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[168],2,arguments);
}
return R.checkAnnArgs([$type$String11],[expression724494],[L[169]],function() {
var dict = R.create($no_DASH_branches_DASH_matched_DASH_base44854486);
dict["loc"] = loc714493
dict["expression"] = expression724494
return R.makeBrandedObject(dict,$no_DASH_branches_DASH_matched_DASH_brands44884489);
});
}),
"is-internal-error":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[110],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-internal-error4497"));
}),
"internal-error":R.makeFunction(function(message744503,info_DASH_args754504) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[170],2,arguments);
}
var dict = R.create($internal_DASH_error_DASH_base44954496);
dict["message"] = message744503
dict["info-args"] = info_DASH_args754504
return R.makeBrandedObject(dict,$internal_DASH_error_DASH_brands44984499);
}),
"is-field-not-found":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[105],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-field-not-found4507"));
}),
"field-not-found":R.makeFunction(function(loc774513,obj784514,field794515) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[171],3,arguments);
}
return R.checkAnnArgs([$type$String11],[field794515],[L[172]],function() {
var dict = R.create($field_DASH_not_DASH_found_DASH_base45054506);
dict["loc"] = loc774513
dict["obj"] = obj784514
dict["field"] = field794515
return R.makeBrandedObject(dict,$field_DASH_not_DASH_found_DASH_brands45084509);
});
}),
"is-lookup-non-object":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[99],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-lookup-non-object4518"));
}),
"lookup-non-object":R.makeFunction(function(loc814524,non_DASH_obj824525,field834526) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[173],3,arguments);
}
return R.checkAnnArgs([$type$String11],[field834526],[L[174]],function() {
var dict = R.create($lookup_DASH_non_DASH_object_DASH_base45164517);
dict["loc"] = loc814524
dict["non-obj"] = non_DASH_obj824525
dict["field"] = field834526
return R.makeBrandedObject(dict,$lookup_DASH_non_DASH_object_DASH_brands45194520);
});
}),
"is-non-boolean-condition":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[93],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-non-boolean-condition4529"));
}),
"non-boolean-condition":R.makeFunction(function(loc854535,typ864536,value874537) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[175],3,arguments);
}
var dict = R.create($non_DASH_boolean_DASH_condition_DASH_base45274528);
dict["loc"] = loc854535
dict["typ"] = typ864536
dict["value"] = value874537
return R.makeBrandedObject(dict,$non_DASH_boolean_DASH_condition_DASH_brands45304531);
}),
"is-non-boolean-op":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[85],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-non-boolean-op4540"));
}),
"non-boolean-op":R.makeFunction(function(loc894546,position904547,typ914548,value924549) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[176],4,arguments);
}
var dict = R.create($non_DASH_boolean_DASH_op_DASH_base45384539);
dict["loc"] = loc894546
dict["position"] = position904547
dict["typ"] = typ914548
dict["value"] = value924549
return R.makeBrandedObject(dict,$non_DASH_boolean_DASH_op_DASH_brands45414542);
}),
"is-generic-type-mismatch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[76],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-generic-type-mismatch4552"));
}),
"generic-type-mismatch":R.makeFunction(function(val944558,typ954559) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[177],2,arguments);
}
return R.checkAnnArgs([$type$String11],[typ954559],[L[178]],function() {
var dict = R.create($generic_DASH_type_DASH_mismatch_DASH_base45504551);
dict["val"] = val944558
dict["typ"] = typ954559
return R.makeBrandedObject(dict,$generic_DASH_type_DASH_mismatch_DASH_brands45534554);
});
}),
"is-outside-numeric-range":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[71],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-outside-numeric-range4562"));
}),
"outside-numeric-range":R.makeFunction(function(val974568,low984569,high994570) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[179],3,arguments);
}
var dict = R.create($outside_DASH_numeric_DASH_range_DASH_base45604561);
dict["val"] = val974568
dict["low"] = low984569
dict["high"] = high994570
return R.makeBrandedObject(dict,$outside_DASH_numeric_DASH_range_DASH_brands45634564);
}),
"is-plus-error":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[64],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-plus-error4573"));
}),
"plus-error":R.makeFunction(function(val11014579,val21024580) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[180],2,arguments);
}
var dict = R.create($plus_DASH_error_DASH_base45714572);
dict["val1"] = val11014579
dict["val2"] = val21024580
return R.makeBrandedObject(dict,$plus_DASH_error_DASH_brands45744575);
}),
"is-numeric-binop-error":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[59],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-numeric-binop-error4583"));
}),
"numeric-binop-error":R.makeFunction(function(val11044589,val21054590,opname1064591,methodname1074592) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[181],4,arguments);
}
var dict = R.create($numeric_DASH_binop_DASH_error_DASH_base45814582);
dict["val1"] = val11044589
dict["val2"] = val21054590
dict["opname"] = opname1064591
dict["methodname"] = methodname1074592
return R.makeBrandedObject(dict,$numeric_DASH_binop_DASH_error_DASH_brands45844585);
}),
"is-arity-mismatch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[51],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-arity-mismatch4595"));
}),
"arity-mismatch":R.makeFunction(function(fun_DASH_loc1094601,expected_DASH_arity1104602,args1114603) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[182],3,arguments);
}
var dict = R.create($arity_DASH_mismatch_DASH_base45934594);
dict["fun-loc"] = fun_DASH_loc1094601
dict["expected-arity"] = expected_DASH_arity1104602
dict["args"] = args1114603
return R.makeBrandedObject(dict,$arity_DASH_mismatch_DASH_brands45964597);
}),
"is-non-function-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[42],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-non-function-app4606"));
}),
"non-function-app":R.makeFunction(function(loc1134612,non_DASH_fun_DASH_val1144613,args1154614) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[183],3,arguments);
}
var dict = R.create($non_DASH_function_DASH_app_DASH_base46044605);
dict["loc"] = loc1134612
dict["non-fun-val"] = non_DASH_fun_DASH_val1144613
dict["args"] = args1154614
return R.makeBrandedObject(dict,$non_DASH_function_DASH_app_DASH_brands46074608);
}),
"is-bad-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[37],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-bad-app4617"));
}),
"bad-app":R.makeFunction(function(loc1174622,fun_DASH_name1184623,message1194624,arg_DASH_position1204625,arg_DASH_val1214626) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[184],5,arguments);
}
return R.checkAnnArgs([$type$String11,$type$String11,$type$Number10],[fun_DASH_name1184623,message1194624,arg_DASH_position1204625],[L[185],L[186],L[187]],function() {
var dict = R.create($bad_DASH_app_DASH_base46154616);
dict["loc"] = loc1174622
dict["fun-name"] = fun_DASH_name1184623
dict["message"] = message1194624
dict["arg-position"] = arg_DASH_position1204625
dict["arg-val"] = arg_DASH_val1214626
return R.makeBrandedObject(dict,$bad_DASH_app_DASH_brands46184619);
});
}),
"is-uninitialized-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[36],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-uninitialized-id4629"));
}),
"uninitialized-id":R.makeFunction(function(loc1224635,name1234636) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[188],2,arguments);
}
return R.checkAnnArgs([$type$String11],[name1234636],[L[189]],function() {
var dict = R.create($uninitialized_DASH_id_DASH_base46274628);
dict["loc"] = loc1224635
dict["name"] = name1234636
return R.makeBrandedObject(dict,$uninitialized_DASH_id_DASH_brands46304631);
});
}),
"is-module-load-failure":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-module-load-failure4639"));
}),
"module-load-failure":R.makeFunction(function(names1254645) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[190],1,arguments);
}
var dict = R.create($module_DASH_load_DASH_failure_DASH_base46374638);
dict["names"] = names1254645
return R.makeBrandedObject(dict,$module_DASH_load_DASH_failure_DASH_brands46404641);
}),
"is-invalid-array-index":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[28],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-invalid-array-index4648"));
}),
"invalid-array-index":R.makeFunction(function(method_DASH_name1274654,array1284655,index1294656,reason1304657) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[191],4,arguments);
}
return R.checkAnnArgs([$type$String11,$type$Number10,$type$String11],[method_DASH_name1274654,index1294656,reason1304657],[L[192],L[193],L[194]],function() {
var dict = R.create($invalid_DASH_array_DASH_index_DASH_base46464647);
dict["method-name"] = method_DASH_name1274654
dict["array"] = array1284655
dict["index"] = index1294656
dict["reason"] = reason1304657
return R.makeBrandedObject(dict,$invalid_DASH_array_DASH_index_DASH_brands46494650);
});
}),
"is-user-break":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-user-break4660"));
}),
"user-break":R.makeBrandedObject($user_DASH_break_DASH_base46584659,$user_DASH_break_DASH_brands46614662)});
})();
RuntimeError353644.$var = anf_assign6233645;
var anf_assign6243647 = G(RuntimeError353644.$var,"RuntimeError",L[0]);
RuntimeError63646.$var = anf_assign6243647;
var anf_assign6253649 = G(RuntimeError353644.$var,"RuntimeError",L[0]);
is_DASH_RuntimeError73648.$var = anf_assign6253649;
var anf_assign6263651 = G(RuntimeError353644.$var,"is-message-exception",L[113]);
is_DASH_message_DASH_exception83650.$var = anf_assign6263651;
var anf_assign6273653 = G(RuntimeError353644.$var,"message-exception",L[113]);
message_DASH_exception93652.$var = anf_assign6273653;
var anf_assign6283655 = G(RuntimeError353644.$var,"is-no-branches-matched",L[112]);
is_DASH_no_DASH_branches_DASH_matched103654.$var = anf_assign6283655;
var anf_assign6293657 = G(RuntimeError353644.$var,"no-branches-matched",L[112]);
no_DASH_branches_DASH_matched113656.$var = anf_assign6293657;
var anf_assign6303659 = G(RuntimeError353644.$var,"is-internal-error",L[110]);
is_DASH_internal_DASH_error123658.$var = anf_assign6303659;
var anf_assign6313661 = G(RuntimeError353644.$var,"internal-error",L[110]);
internal_DASH_error133660.$var = anf_assign6313661;
var anf_assign6323663 = G(RuntimeError353644.$var,"is-field-not-found",L[105]);
is_DASH_field_DASH_not_DASH_found143662.$var = anf_assign6323663;
var anf_assign6333665 = G(RuntimeError353644.$var,"field-not-found",L[105]);
field_DASH_not_DASH_found153664.$var = anf_assign6333665;
var anf_assign6343667 = G(RuntimeError353644.$var,"is-lookup-non-object",L[99]);
is_DASH_lookup_DASH_non_DASH_object163666.$var = anf_assign6343667;
var anf_assign6353669 = G(RuntimeError353644.$var,"lookup-non-object",L[99]);
lookup_DASH_non_DASH_object173668.$var = anf_assign6353669;
var anf_assign6363671 = G(RuntimeError353644.$var,"is-non-boolean-condition",L[93]);
is_DASH_non_DASH_boolean_DASH_condition183670.$var = anf_assign6363671;
var anf_assign6373673 = G(RuntimeError353644.$var,"non-boolean-condition",L[93]);
non_DASH_boolean_DASH_condition193672.$var = anf_assign6373673;
var anf_assign6383675 = G(RuntimeError353644.$var,"is-non-boolean-op",L[85]);
is_DASH_non_DASH_boolean_DASH_op203674.$var = anf_assign6383675;
var anf_assign6393677 = G(RuntimeError353644.$var,"non-boolean-op",L[85]);
non_DASH_boolean_DASH_op213676.$var = anf_assign6393677;
var anf_assign6403679 = G(RuntimeError353644.$var,"is-generic-type-mismatch",L[76]);
is_DASH_generic_DASH_type_DASH_mismatch223678.$var = anf_assign6403679;
var anf_assign6413681 = G(RuntimeError353644.$var,"generic-type-mismatch",L[76]);
generic_DASH_type_DASH_mismatch233680.$var = anf_assign6413681;
var anf_assign6423683 = G(RuntimeError353644.$var,"is-outside-numeric-range",L[71]);
is_DASH_outside_DASH_numeric_DASH_range243682.$var = anf_assign6423683;
var anf_assign6433685 = G(RuntimeError353644.$var,"outside-numeric-range",L[71]);
outside_DASH_numeric_DASH_range253684.$var = anf_assign6433685;
var anf_assign6443687 = G(RuntimeError353644.$var,"is-plus-error",L[64]);
is_DASH_plus_DASH_error263686.$var = anf_assign6443687;
var anf_assign6453689 = G(RuntimeError353644.$var,"plus-error",L[64]);
plus_DASH_error273688.$var = anf_assign6453689;
var anf_assign6463691 = G(RuntimeError353644.$var,"is-numeric-binop-error",L[59]);
is_DASH_numeric_DASH_binop_DASH_error283690.$var = anf_assign6463691;
var anf_assign6473693 = G(RuntimeError353644.$var,"numeric-binop-error",L[59]);
numeric_DASH_binop_DASH_error293692.$var = anf_assign6473693;
var anf_assign6483695 = G(RuntimeError353644.$var,"is-arity-mismatch",L[51]);
is_DASH_arity_DASH_mismatch303694.$var = anf_assign6483695;
var anf_assign6493697 = G(RuntimeError353644.$var,"arity-mismatch",L[51]);
arity_DASH_mismatch313696.$var = anf_assign6493697;
var anf_assign6503699 = G(RuntimeError353644.$var,"is-non-function-app",L[42]);
is_DASH_non_DASH_function_DASH_app323698.$var = anf_assign6503699;
var anf_assign6513701 = G(RuntimeError353644.$var,"non-function-app",L[42]);
non_DASH_function_DASH_app333700.$var = anf_assign6513701;
var anf_assign6523703 = G(RuntimeError353644.$var,"is-bad-app",L[37]);
is_DASH_bad_DASH_app343702.$var = anf_assign6523703;
var anf_assign6533705 = G(RuntimeError353644.$var,"bad-app",L[37]);
bad_DASH_app353704.$var = anf_assign6533705;
var anf_assign6543707 = G(RuntimeError353644.$var,"is-uninitialized-id",L[36]);
is_DASH_uninitialized_DASH_id363706.$var = anf_assign6543707;
var anf_assign6553709 = G(RuntimeError353644.$var,"uninitialized-id",L[36]);
uninitialized_DASH_id373708.$var = anf_assign6553709;
var anf_assign6563711 = G(RuntimeError353644.$var,"is-module-load-failure",L[30]);
is_DASH_module_DASH_load_DASH_failure383710.$var = anf_assign6563711;
var anf_assign6573713 = G(RuntimeError353644.$var,"module-load-failure",L[30]);
module_DASH_load_DASH_failure393712.$var = anf_assign6573713;
var anf_assign6583715 = G(RuntimeError353644.$var,"is-invalid-array-index",L[28]);
is_DASH_invalid_DASH_array_DASH_index403714.$var = anf_assign6583715;
var anf_assign6593717 = G(RuntimeError353644.$var,"invalid-array-index",L[28]);
invalid_DASH_array_DASH_index413716.$var = anf_assign6593717;
var anf_assign6603719 = G(RuntimeError353644.$var,"is-user-break",L[23]);
is_DASH_user_DASH_break423718.$var = anf_assign6603719;
var anf_assign6613721 = G(RuntimeError353644.$var,"user-break",L[23]);
user_DASH_break433720.$var = anf_assign6613721;
var anf_variant_member6743788 = R.makeMethod(function(self1104456) {
return function(cases_DASH_funs1114457,else_DASH_clause1124468) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[22],2,arguments);
}
var if_DASH_1144469 = R.hasField(cases_DASH_funs1114457,("parse-error-next-token"));
var if_helper663732 = R.makeFunction(function(if_helper_arg6644474) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
var ann_DASH_check_DASH_temp6624475 = if_helper_arg6644474;
return ann_DASH_check_DASH_temp6624475;
});
var anf_if6674473 = R.isBoolean(if_DASH_1144469);
if(R.isPyretTrue(anf_if6674473)) {
if(R.isPyretTrue(if_DASH_1144469)) {
var call_DASH_parse_DASH_error_DASH_next_DASH_token1094453 = G(cases_DASH_funs1114457,"parse-error-next-token",L[22]);
var anf_arg6704454 = G(self1104456,"loc",L[165]);
var anf_arg6714455 = G(self1104456,"next-token",L[164]);
var $z44454446 = D;
var $f44514452 = function(_) {
return R.isFunction(call_DASH_parse_DASH_error_DASH_next_DASH_token1094453)?call_DASH_parse_DASH_error_DASH_next_DASH_token1094453.app(anf_arg6704454,anf_arg6714455):R.ffi.throwNonFunApp(L[22],call_DASH_parse_DASH_error_DASH_next_DASH_token1094453,[anf_arg6704454,anf_arg6714455]);
};
try {
if(--R.GAS > 0) {
$z44454446 = $f44514452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44514452,
"from":L[22]});
}
} catch($e44434444) {
if(R.isCont($e44434444)) {
var $ss44474448 = {"from":L[22],
"go":function(cont_tail_arg672731) {
return $Hcont_tail_arg1227730(cont_tail_arg672731,if_helper663732);
}};
$e44434444.stack[R.EXN_STACKHEIGHT++] = $ss44474448;
}
if(R.isPyretException($e44434444)) {
$e44434444.pyretStack.push(L[22]);
}
throw $e44434444;
}
var $ret44494450 = $Hcont_tail_arg1227730($z44454446,if_helper663732);
++R.GAS;
return $ret44494450;
} else {
var $z44604461 = D;
var $f44664467 = function(_) {
return R.isFunction(else_DASH_clause1124468)?else_DASH_clause1124468.app():R.ffi.throwNonFunApp(L[22],else_DASH_clause1124468,[]);
};
try {
if(--R.GAS > 0) {
$z44604461 = $f44664467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44664467,
"from":L[22]});
}
} catch($e44584459) {
if(R.isCont($e44584459)) {
var $ss44624463 = {"from":L[22],
"go":function(cont_tail_arg668736) {
return $Hcont_tail_arg1228735(cont_tail_arg668736,if_helper663732);
}};
$e44584459.stack[R.EXN_STACKHEIGHT++] = $ss44624463;
}
if(R.isPyretException($e44584459)) {
$e44584459.pyretStack.push(L[22]);
}
throw $e44584459;
}
var $ret44644465 = $Hcont_tail_arg1228735($z44604461,if_helper663732);
++R.GAS;
return $ret44644465;
}
} else {
var cont_tail_arg6654472 = R.throwNonBooleanCondition(L[22],("if"),if_DASH_1144469);
if(--R.GAS > 0) {
$z44704471 = R.isFunction(if_helper663732)?if_helper663732.app(cont_tail_arg6654472):R.ffi.throwNonFunApp(L[22],if_helper663732,[cont_tail_arg6654472]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper663732)?if_helper663732.app(cont_tail_arg6654472):R.ffi.throwNonFunApp(L[22],if_helper663732,[cont_tail_arg6654472]);
},
"from":L[22]});
}
++R.GAS;
return $z44704471;
}
};
},{"length":3});
var anf_variant_member6843789 = R.makeMethod(function(self113656) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[22],0,arguments);
}
var anf_arg6764442 = G(self113656,"loc",L[22]);
var $z44344435 = D;
var $f44404441 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg6764442):R.ffi.throwNonFunApp(L[22],torepr8,[anf_arg6764442]);
};
try {
if(--R.GAS > 0) {
$z44344435 = $f44404441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44404441,
"from":L[22]});
}
} catch($e44324433) {
if(R.isCont($e44324433)) {
var $ss44364437 = {"from":L[22],
"go":function(anf_arg677655) {
return $Hanf_arg1235654(anf_arg677655,self113656,_plus5,torepr8);
}};
$e44324433.stack[R.EXN_STACKHEIGHT++] = $ss44364437;
}
if(R.isPyretException($e44324433)) {
$e44324433.pyretStack.push(L[22]);
}
throw $e44324433;
}
var $ret44384439 = $Hanf_arg1235654($z44344435,self113656,_plus5,torepr8);
++R.GAS;
return $ret44384439;
};
},{"length":1});
var anf_variant_member6923790 = R.makeMethod(function(self134616) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[20],0,arguments);
}
var anf_bracket6864431 = G(self134616,"loc",L[163]);
var anf_fun6874430 = G(anf_bracket6864431,"format",L[162]);
var $z44224423 = D;
var $f44284429 = function(_) {
return R.isFunction(anf_fun6874430)?anf_fun6874430.app((true)):R.ffi.throwNonFunApp(L[161],anf_fun6874430,[(true)]);
};
try {
if(--R.GAS > 0) {
$z44224423 = $f44284429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44284429,
"from":L[161]});
}
} catch($e44204421) {
if(R.isCont($e44204421)) {
var $ss44244425 = {"from":L[161],
"go":function(anf_arg688615) {
return $Hanf_arg1239614(anf_arg688615,self134616,_plus5);
}};
$e44204421.stack[R.EXN_STACKHEIGHT++] = $ss44244425;
}
if(R.isPyretException($e44204421)) {
$e44204421.pyretStack.push(L[161]);
}
throw $e44204421;
}
var $ret44264427 = $Hanf_arg1239614($z44224423,self134616,_plus5);
++R.GAS;
return $ret44264427;
};
},{"length":1});
var anf_variant_member7043798 = R.makeMethod(function(self1161369) {
return function(cases_DASH_funs1174401,else_DASH_clause1184412) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[18],2,arguments);
}
var if_DASH_1204413 = R.hasField(cases_DASH_funs1174401,("parse-error-eof"));
var if_helper694607 = R.makeFunction(function(if_helper_arg6954418) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[18],1,arguments);
}
var ann_DASH_check_DASH_temp6934419 = if_helper_arg6954418;
return ann_DASH_check_DASH_temp6934419;
});
var anf_if6984417 = R.isBoolean(if_DASH_1204413);
if(R.isPyretTrue(anf_if6984417)) {
if(R.isPyretTrue(if_DASH_1204413)) {
var call_DASH_parse_DASH_error_DASH_eof1154399 = G(cases_DASH_funs1174401,"parse-error-eof",L[18]);
var anf_arg7014400 = G(self1161369,"loc",L[160]);
var $z43914392 = D;
var $f43974398 = function(_) {
return R.isFunction(call_DASH_parse_DASH_error_DASH_eof1154399)?call_DASH_parse_DASH_error_DASH_eof1154399.app(anf_arg7014400):R.ffi.throwNonFunApp(L[18],call_DASH_parse_DASH_error_DASH_eof1154399,[anf_arg7014400]);
};
try {
if(--R.GAS > 0) {
$z43914392 = $f43974398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43974398,
"from":L[18]});
}
} catch($e43894390) {
if(R.isCont($e43894390)) {
var $ss43934394 = {"from":L[18],
"go":function(cont_tail_arg702606) {
return $Hcont_tail_arg1240605(cont_tail_arg702606,if_helper694607);
}};
$e43894390.stack[R.EXN_STACKHEIGHT++] = $ss43934394;
}
if(R.isPyretException($e43894390)) {
$e43894390.pyretStack.push(L[18]);
}
throw $e43894390;
}
var $ret43954396 = $Hcont_tail_arg1240605($z43914392,if_helper694607);
++R.GAS;
return $ret43954396;
} else {
var $z44044405 = D;
var $f44104411 = function(_) {
return R.isFunction(else_DASH_clause1184412)?else_DASH_clause1184412.app():R.ffi.throwNonFunApp(L[18],else_DASH_clause1184412,[]);
};
try {
if(--R.GAS > 0) {
$z44044405 = $f44104411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44104411,
"from":L[18]});
}
} catch($e44024403) {
if(R.isCont($e44024403)) {
var $ss44064407 = {"from":L[18],
"go":function(cont_tail_arg699611) {
return $Hcont_tail_arg1241610(cont_tail_arg699611,if_helper694607);
}};
$e44024403.stack[R.EXN_STACKHEIGHT++] = $ss44064407;
}
if(R.isPyretException($e44024403)) {
$e44024403.pyretStack.push(L[18]);
}
throw $e44024403;
}
var $ret44084409 = $Hcont_tail_arg1241610($z44044405,if_helper694607);
++R.GAS;
return $ret44084409;
}
} else {
var cont_tail_arg6964416 = R.throwNonBooleanCondition(L[18],("if"),if_DASH_1204413);
if(--R.GAS > 0) {
$z44144415 = R.isFunction(if_helper694607)?if_helper694607.app(cont_tail_arg6964416):R.ffi.throwNonFunApp(L[18],if_helper694607,[cont_tail_arg6964416]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper694607)?if_helper694607.app(cont_tail_arg6964416):R.ffi.throwNonFunApp(L[18],if_helper694607,[cont_tail_arg6964416]);
},
"from":L[18]});
}
++R.GAS;
return $z44144415;
}
};
},{"length":3});
var anf_variant_member7103799 = R.makeMethod(function(self1194388) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[18],0,arguments);
}
var anf_arg7064387 = G(self1194388,"loc",L[18]);
var $z43794380 = D;
var $f43854386 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg7064387):R.ffi.throwNonFunApp(L[18],torepr8,[anf_arg7064387]);
};
try {
if(--R.GAS > 0) {
$z43794380 = $f43854386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43854386,
"from":L[18]});
}
} catch($e43774378) {
if(R.isCont($e43774378)) {
var $ss43814382 = {"from":L[18],
"go":function(anf_arg707568) {
return $Hanf_arg1245567(anf_arg707568,_plus5);
}};
$e43774378.stack[R.EXN_STACKHEIGHT++] = $ss43814382;
}
if(R.isPyretException($e43774378)) {
$e43774378.pyretStack.push(L[18]);
}
throw $e43774378;
}
var $ret43834384 = $Hanf_arg1245567($z43794380,_plus5);
++R.GAS;
return $ret43834384;
};
},{"length":1});
var anf_variant_member7153800 = R.makeMethod(function(self1364376) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[17],0,arguments);
}
var anf_bracket7124375 = G(self1364376,"loc",L[159]);
var anf_fun7134374 = G(anf_bracket7124375,"format",L[158]);
var $z43664367 = D;
var $f43724373 = function(_) {
return R.isFunction(anf_fun7134374)?anf_fun7134374.app((true)):R.ffi.throwNonFunApp(L[157],anf_fun7134374,[(true)]);
};
try {
if(--R.GAS > 0) {
$z43664367 = $f43724373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43724373,
"from":L[157]});
}
} catch($e43644365) {
if(R.isCont($e43644365)) {
var $ss43684369 = {"from":L[157],
"go":function(anf_arg714554) {
return $Hanf_arg1247553(anf_arg714554,_plus5);
}};
$e43644365.stack[R.EXN_STACKHEIGHT++] = $ss43684369;
}
if(R.isPyretException($e43644365)) {
$e43644365.pyretStack.push(L[157]);
}
throw $e43644365;
}
var $ret43704371 = $Hanf_arg1247553($z43664367,_plus5);
++R.GAS;
return $ret43704371;
};
},{"length":1});
var anf_variant_member7273807 = R.makeMethod(function(self1224344) {
return function(cases_DASH_funs1234345,else_DASH_clause1244356) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[16],2,arguments);
}
var if_DASH_1264357 = R.hasField(cases_DASH_funs1234345,("empty-block"));
var if_helper717546 = R.makeFunction(function(if_helper_arg7184362) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[16],1,arguments);
}
var ann_DASH_check_DASH_temp7164363 = if_helper_arg7184362;
return ann_DASH_check_DASH_temp7164363;
});
var anf_if7214361 = R.isBoolean(if_DASH_1264357);
if(R.isPyretTrue(anf_if7214361)) {
if(R.isPyretTrue(if_DASH_1264357)) {
var call_DASH_empty_DASH_block1214342 = G(cases_DASH_funs1234345,"empty-block",L[16]);
var anf_arg7244343 = G(self1224344,"loc",L[156]);
var $z43344335 = D;
var $f43404341 = function(_) {
return R.isFunction(call_DASH_empty_DASH_block1214342)?call_DASH_empty_DASH_block1214342.app(anf_arg7244343):R.ffi.throwNonFunApp(L[16],call_DASH_empty_DASH_block1214342,[anf_arg7244343]);
};
try {
if(--R.GAS > 0) {
$z43344335 = $f43404341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43404341,
"from":L[16]});
}
} catch($e43324333) {
if(R.isCont($e43324333)) {
var $ss43364337 = {"from":L[16],
"go":function(cont_tail_arg725545) {
return $Hcont_tail_arg1248544(cont_tail_arg725545,if_helper717546);
}};
$e43324333.stack[R.EXN_STACKHEIGHT++] = $ss43364337;
}
if(R.isPyretException($e43324333)) {
$e43324333.pyretStack.push(L[16]);
}
throw $e43324333;
}
var $ret43384339 = $Hcont_tail_arg1248544($z43344335,if_helper717546);
++R.GAS;
return $ret43384339;
} else {
var $z43484349 = D;
var $f43544355 = function(_) {
return R.isFunction(else_DASH_clause1244356)?else_DASH_clause1244356.app():R.ffi.throwNonFunApp(L[16],else_DASH_clause1244356,[]);
};
try {
if(--R.GAS > 0) {
$z43484349 = $f43544355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43544355,
"from":L[16]});
}
} catch($e43464347) {
if(R.isCont($e43464347)) {
var $ss43504351 = {"from":L[16],
"go":function(cont_tail_arg722550) {
return $Hcont_tail_arg1249549(cont_tail_arg722550,if_helper717546);
}};
$e43464347.stack[R.EXN_STACKHEIGHT++] = $ss43504351;
}
if(R.isPyretException($e43464347)) {
$e43464347.pyretStack.push(L[16]);
}
throw $e43464347;
}
var $ret43524353 = $Hcont_tail_arg1249549($z43484349,if_helper717546);
++R.GAS;
return $ret43524353;
}
} else {
var cont_tail_arg7194360 = R.throwNonBooleanCondition(L[16],("if"),if_DASH_1264357);
if(--R.GAS > 0) {
$z43584359 = R.isFunction(if_helper717546)?if_helper717546.app(cont_tail_arg7194360):R.ffi.throwNonFunApp(L[16],if_helper717546,[cont_tail_arg7194360]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper717546)?if_helper717546.app(cont_tail_arg7194360):R.ffi.throwNonFunApp(L[16],if_helper717546,[cont_tail_arg7194360]);
},
"from":L[16]});
}
++R.GAS;
return $z43584359;
}
};
},{"length":3});
var anf_variant_member7333808 = R.makeMethod(function(self1254331) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[16],0,arguments);
}
var anf_arg7294330 = G(self1254331,"loc",L[16]);
var $z43224323 = D;
var $f43284329 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg7294330):R.ffi.throwNonFunApp(L[16],torepr8,[anf_arg7294330]);
};
try {
if(--R.GAS > 0) {
$z43224323 = $f43284329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43284329,
"from":L[16]});
}
} catch($e43204321) {
if(R.isCont($e43204321)) {
var $ss43244325 = {"from":L[16],
"go":function(anf_arg730507) {
return $Hanf_arg1253506(anf_arg730507,_plus5);
}};
$e43204321.stack[R.EXN_STACKHEIGHT++] = $ss43244325;
}
if(R.isPyretException($e43204321)) {
$e43204321.pyretStack.push(L[16]);
}
throw $e43204321;
}
var $ret43264327 = $Hanf_arg1253506($z43224323,_plus5);
++R.GAS;
return $ret43264327;
};
},{"length":1});
var anf_variant_member7383809 = R.makeMethod(function(self1384319) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[15],0,arguments);
}
var anf_bracket7354318 = G(self1384319,"loc",L[155]);
var anf_fun7364317 = G(anf_bracket7354318,"format",L[154]);
var $z43094310 = D;
var $f43154316 = function(_) {
return R.isFunction(anf_fun7364317)?anf_fun7364317.app((true)):R.ffi.throwNonFunApp(L[153],anf_fun7364317,[(true)]);
};
try {
if(--R.GAS > 0) {
$z43094310 = $f43154316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43154316,
"from":L[153]});
}
} catch($e43074308) {
if(R.isCont($e43074308)) {
var $ss43114312 = {"from":L[153],
"go":function(anf_arg737493) {
return $Hanf_arg1255492(anf_arg737493,_plus5);
}};
$e43074308.stack[R.EXN_STACKHEIGHT++] = $ss43114312;
}
if(R.isPyretException($e43074308)) {
$e43074308.pyretStack.push(L[153]);
}
throw $e43074308;
}
var $ret43134314 = $Hanf_arg1255492($z43094310,_plus5);
++R.GAS;
return $ret43134314;
};
},{"length":1});
var anf_variant_member7503816 = R.makeMethod(function(self1284287) {
return function(cases_DASH_funs1294288,else_DASH_clause1304299) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[14],2,arguments);
}
var if_DASH_1324300 = R.hasField(cases_DASH_funs1294288,("bad-block-stmt"));
var if_helper740485 = R.makeFunction(function(if_helper_arg7414305) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[14],1,arguments);
}
var ann_DASH_check_DASH_temp7394306 = if_helper_arg7414305;
return ann_DASH_check_DASH_temp7394306;
});
var anf_if7444304 = R.isBoolean(if_DASH_1324300);
if(R.isPyretTrue(anf_if7444304)) {
if(R.isPyretTrue(if_DASH_1324300)) {
var call_DASH_bad_DASH_block_DASH_stmt1274285 = G(cases_DASH_funs1294288,"bad-block-stmt",L[14]);
var anf_arg7474286 = G(self1284287,"loc",L[152]);
var $z42774278 = D;
var $f42834284 = function(_) {
return R.isFunction(call_DASH_bad_DASH_block_DASH_stmt1274285)?call_DASH_bad_DASH_block_DASH_stmt1274285.app(anf_arg7474286):R.ffi.throwNonFunApp(L[14],call_DASH_bad_DASH_block_DASH_stmt1274285,[anf_arg7474286]);
};
try {
if(--R.GAS > 0) {
$z42774278 = $f42834284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42834284,
"from":L[14]});
}
} catch($e42754276) {
if(R.isCont($e42754276)) {
var $ss42794280 = {"from":L[14],
"go":function(cont_tail_arg748484) {
return $Hcont_tail_arg1256483(cont_tail_arg748484,if_helper740485);
}};
$e42754276.stack[R.EXN_STACKHEIGHT++] = $ss42794280;
}
if(R.isPyretException($e42754276)) {
$e42754276.pyretStack.push(L[14]);
}
throw $e42754276;
}
var $ret42814282 = $Hcont_tail_arg1256483($z42774278,if_helper740485);
++R.GAS;
return $ret42814282;
} else {
var $z42914292 = D;
var $f42974298 = function(_) {
return R.isFunction(else_DASH_clause1304299)?else_DASH_clause1304299.app():R.ffi.throwNonFunApp(L[14],else_DASH_clause1304299,[]);
};
try {
if(--R.GAS > 0) {
$z42914292 = $f42974298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42974298,
"from":L[14]});
}
} catch($e42894290) {
if(R.isCont($e42894290)) {
var $ss42934294 = {"from":L[14],
"go":function(cont_tail_arg745489) {
return $Hcont_tail_arg1257488(cont_tail_arg745489,if_helper740485);
}};
$e42894290.stack[R.EXN_STACKHEIGHT++] = $ss42934294;
}
if(R.isPyretException($e42894290)) {
$e42894290.pyretStack.push(L[14]);
}
throw $e42894290;
}
var $ret42954296 = $Hcont_tail_arg1257488($z42914292,if_helper740485);
++R.GAS;
return $ret42954296;
}
} else {
var cont_tail_arg7424303 = R.throwNonBooleanCondition(L[14],("if"),if_DASH_1324300);
if(--R.GAS > 0) {
$z43014302 = R.isFunction(if_helper740485)?if_helper740485.app(cont_tail_arg7424303):R.ffi.throwNonFunApp(L[14],if_helper740485,[cont_tail_arg7424303]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper740485)?if_helper740485.app(cont_tail_arg7424303):R.ffi.throwNonFunApp(L[14],if_helper740485,[cont_tail_arg7424303]);
},
"from":L[14]});
}
++R.GAS;
return $z43014302;
}
};
},{"length":3});
var anf_variant_member7563817 = R.makeMethod(function(self131750) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[14],0,arguments);
}
var anf_arg7524274 = G(self131750,"loc",L[14]);
var $z42664267 = D;
var $f42724273 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg7524274):R.ffi.throwNonFunApp(L[14],torepr8,[anf_arg7524274]);
};
try {
if(--R.GAS > 0) {
$z42664267 = $f42724273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42724273,
"from":L[14]});
}
} catch($e42644265) {
if(R.isCont($e42644265)) {
var $ss42684269 = {"from":L[14],
"go":function(anf_arg753446) {
return $Hanf_arg1261445(anf_arg753446,_plus5);
}};
$e42644265.stack[R.EXN_STACKHEIGHT++] = $ss42684269;
}
if(R.isPyretException($e42644265)) {
$e42644265.pyretStack.push(L[14]);
}
throw $e42644265;
}
var $ret42704271 = $Hanf_arg1261445($z42664267,_plus5);
++R.GAS;
return $ret42704271;
};
},{"length":1});
var anf_variant_member7613818 = R.makeMethod(function(self1404176) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[13],0,arguments);
}
var anf_bracket7584263 = G(self1404176,"loc",L[151]);
var anf_fun7594262 = G(anf_bracket7584263,"format",L[150]);
var $z42544255 = D;
var $f42604261 = function(_) {
return R.isFunction(anf_fun7594262)?anf_fun7594262.app((true)):R.ffi.throwNonFunApp(L[149],anf_fun7594262,[(true)]);
};
try {
if(--R.GAS > 0) {
$z42544255 = $f42604261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42604261,
"from":L[149]});
}
} catch($e42524253) {
if(R.isCont($e42524253)) {
var $ss42564257 = {"from":L[149],
"go":function(anf_arg760432) {
return $Hanf_arg1263431(anf_arg760432,_plus5);
}};
$e42524253.stack[R.EXN_STACKHEIGHT++] = $ss42564257;
}
if(R.isPyretException($e42524253)) {
$e42524253.pyretStack.push(L[149]);
}
throw $e42524253;
}
var $ret42584259 = $Hanf_arg1263431($z42544255,_plus5);
++R.GAS;
return $ret42584259;
};
},{"length":1});
var anf_variant_member7733825 = R.makeMethod(function(self134616) {
return function(cases_DASH_funs1354233,else_DASH_clause1364244) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[12],2,arguments);
}
var if_DASH_1384245 = R.hasField(cases_DASH_funs1354233,("bad-check-block-stmt"));
var if_helper763424 = R.makeFunction(function(if_helper_arg7644250) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[12],1,arguments);
}
var ann_DASH_check_DASH_temp7624251 = if_helper_arg7644250;
return ann_DASH_check_DASH_temp7624251;
});
var anf_if7674249 = R.isBoolean(if_DASH_1384245);
if(R.isPyretTrue(anf_if7674249)) {
if(R.isPyretTrue(if_DASH_1384245)) {
var call_DASH_bad_DASH_check_DASH_block_DASH_stmt1334231 = G(cases_DASH_funs1354233,"bad-check-block-stmt",L[12]);
var anf_arg7704232 = G(self134616,"loc",L[148]);
var $z42234224 = D;
var $f42294230 = function(_) {
return R.isFunction(call_DASH_bad_DASH_check_DASH_block_DASH_stmt1334231)?call_DASH_bad_DASH_check_DASH_block_DASH_stmt1334231.app(anf_arg7704232):R.ffi.throwNonFunApp(L[12],call_DASH_bad_DASH_check_DASH_block_DASH_stmt1334231,[anf_arg7704232]);
};
try {
if(--R.GAS > 0) {
$z42234224 = $f42294230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42294230,
"from":L[12]});
}
} catch($e42214222) {
if(R.isCont($e42214222)) {
var $ss42254226 = {"from":L[12],
"go":function(cont_tail_arg771423) {
return $Hcont_tail_arg1264422(cont_tail_arg771423,if_helper763424);
}};
$e42214222.stack[R.EXN_STACKHEIGHT++] = $ss42254226;
}
if(R.isPyretException($e42214222)) {
$e42214222.pyretStack.push(L[12]);
}
throw $e42214222;
}
var $ret42274228 = $Hcont_tail_arg1264422($z42234224,if_helper763424);
++R.GAS;
return $ret42274228;
} else {
var $z42364237 = D;
var $f42424243 = function(_) {
return R.isFunction(else_DASH_clause1364244)?else_DASH_clause1364244.app():R.ffi.throwNonFunApp(L[12],else_DASH_clause1364244,[]);
};
try {
if(--R.GAS > 0) {
$z42364237 = $f42424243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42424243,
"from":L[12]});
}
} catch($e42344235) {
if(R.isCont($e42344235)) {
var $ss42384239 = {"from":L[12],
"go":function(cont_tail_arg768428) {
return $Hcont_tail_arg1265427(cont_tail_arg768428,if_helper763424);
}};
$e42344235.stack[R.EXN_STACKHEIGHT++] = $ss42384239;
}
if(R.isPyretException($e42344235)) {
$e42344235.pyretStack.push(L[12]);
}
throw $e42344235;
}
var $ret42404241 = $Hcont_tail_arg1265427($z42364237,if_helper763424);
++R.GAS;
return $ret42404241;
}
} else {
var cont_tail_arg7654248 = R.throwNonBooleanCondition(L[12],("if"),if_DASH_1384245);
if(--R.GAS > 0) {
$z42464247 = R.isFunction(if_helper763424)?if_helper763424.app(cont_tail_arg7654248):R.ffi.throwNonFunApp(L[12],if_helper763424,[cont_tail_arg7654248]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper763424)?if_helper763424.app(cont_tail_arg7654248):R.ffi.throwNonFunApp(L[12],if_helper763424,[cont_tail_arg7654248]);
},
"from":L[12]});
}
++R.GAS;
return $z42464247;
}
};
},{"length":3});
var anf_variant_member7793826 = R.makeMethod(function(self1374220) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[12],0,arguments);
}
var anf_arg7754219 = G(self1374220,"loc",L[12]);
var $z42114212 = D;
var $f42174218 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg7754219):R.ffi.throwNonFunApp(L[12],torepr8,[anf_arg7754219]);
};
try {
if(--R.GAS > 0) {
$z42114212 = $f42174218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42174218,
"from":L[12]});
}
} catch($e42094210) {
if(R.isCont($e42094210)) {
var $ss42134214 = {"from":L[12],
"go":function(anf_arg776385) {
return $Hanf_arg1269384(anf_arg776385,_plus5);
}};
$e42094210.stack[R.EXN_STACKHEIGHT++] = $ss42134214;
}
if(R.isPyretException($e42094210)) {
$e42094210.pyretStack.push(L[12]);
}
throw $e42094210;
}
var $ret42154216 = $Hanf_arg1269384($z42114212,_plus5);
++R.GAS;
return $ret42154216;
};
},{"length":1});
var anf_variant_member7843827 = R.makeMethod(function(self1424208) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[11],0,arguments);
}
var anf_bracket7814207 = G(self1424208,"loc",L[147]);
var anf_fun7824206 = G(anf_bracket7814207,"format",L[146]);
var $z41984199 = D;
var $f42044205 = function(_) {
return R.isFunction(anf_fun7824206)?anf_fun7824206.app((true)):R.ffi.throwNonFunApp(L[145],anf_fun7824206,[(true)]);
};
try {
if(--R.GAS > 0) {
$z41984199 = $f42044205();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42044205,
"from":L[145]});
}
} catch($e41964197) {
if(R.isCont($e41964197)) {
var $ss42004201 = {"from":L[145],
"go":function(anf_arg783371) {
return $Hanf_arg1271370(anf_arg783371,_plus5);
}};
$e41964197.stack[R.EXN_STACKHEIGHT++] = $ss42004201;
}
if(R.isPyretException($e41964197)) {
$e41964197.pyretStack.push(L[145]);
}
throw $e41964197;
}
var $ret42024203 = $Hanf_arg1271370($z41984199,_plus5);
++R.GAS;
return $ret42024203;
};
},{"length":1});
var anf_variant_member7963834 = R.makeMethod(function(self1404176) {
return function(cases_DASH_funs1414177,else_DASH_clause1424188) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[10],2,arguments);
}
var if_DASH_1444189 = R.hasField(cases_DASH_funs1414177,("fun-missing-colon"));
var if_helper786363 = R.makeFunction(function(if_helper_arg7874194) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[10],1,arguments);
}
var ann_DASH_check_DASH_temp7854195 = if_helper_arg7874194;
return ann_DASH_check_DASH_temp7854195;
});
var anf_if7904193 = R.isBoolean(if_DASH_1444189);
if(R.isPyretTrue(anf_if7904193)) {
if(R.isPyretTrue(if_DASH_1444189)) {
var call_DASH_fun_DASH_missing_DASH_colon1394174 = G(cases_DASH_funs1414177,"fun-missing-colon",L[10]);
var anf_arg7934175 = G(self1404176,"loc",L[144]);
var $z41664167 = D;
var $f41724173 = function(_) {
return R.isFunction(call_DASH_fun_DASH_missing_DASH_colon1394174)?call_DASH_fun_DASH_missing_DASH_colon1394174.app(anf_arg7934175):R.ffi.throwNonFunApp(L[10],call_DASH_fun_DASH_missing_DASH_colon1394174,[anf_arg7934175]);
};
try {
if(--R.GAS > 0) {
$z41664167 = $f41724173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41724173,
"from":L[10]});
}
} catch($e41644165) {
if(R.isCont($e41644165)) {
var $ss41684169 = {"from":L[10],
"go":function(cont_tail_arg794362) {
return $Hcont_tail_arg1272361(cont_tail_arg794362,if_helper786363);
}};
$e41644165.stack[R.EXN_STACKHEIGHT++] = $ss41684169;
}
if(R.isPyretException($e41644165)) {
$e41644165.pyretStack.push(L[10]);
}
throw $e41644165;
}
var $ret41704171 = $Hcont_tail_arg1272361($z41664167,if_helper786363);
++R.GAS;
return $ret41704171;
} else {
var $z41804181 = D;
var $f41864187 = function(_) {
return R.isFunction(else_DASH_clause1424188)?else_DASH_clause1424188.app():R.ffi.throwNonFunApp(L[10],else_DASH_clause1424188,[]);
};
try {
if(--R.GAS > 0) {
$z41804181 = $f41864187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41864187,
"from":L[10]});
}
} catch($e41784179) {
if(R.isCont($e41784179)) {
var $ss41824183 = {"from":L[10],
"go":function(cont_tail_arg791367) {
return $Hcont_tail_arg1273366(cont_tail_arg791367,if_helper786363);
}};
$e41784179.stack[R.EXN_STACKHEIGHT++] = $ss41824183;
}
if(R.isPyretException($e41784179)) {
$e41784179.pyretStack.push(L[10]);
}
throw $e41784179;
}
var $ret41844185 = $Hcont_tail_arg1273366($z41804181,if_helper786363);
++R.GAS;
return $ret41844185;
}
} else {
var cont_tail_arg7884192 = R.throwNonBooleanCondition(L[10],("if"),if_DASH_1444189);
if(--R.GAS > 0) {
$z41904191 = R.isFunction(if_helper786363)?if_helper786363.app(cont_tail_arg7884192):R.ffi.throwNonFunApp(L[10],if_helper786363,[cont_tail_arg7884192]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper786363)?if_helper786363.app(cont_tail_arg7884192):R.ffi.throwNonFunApp(L[10],if_helper786363,[cont_tail_arg7884192]);
},
"from":L[10]});
}
++R.GAS;
return $z41904191;
}
};
},{"length":3});
var anf_variant_member8023835 = R.makeMethod(function(self1434163) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[10],0,arguments);
}
var anf_arg7984162 = G(self1434163,"loc",L[10]);
var $z41544155 = D;
var $f41604161 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg7984162):R.ffi.throwNonFunApp(L[10],torepr8,[anf_arg7984162]);
};
try {
if(--R.GAS > 0) {
$z41544155 = $f41604161();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41604161,
"from":L[10]});
}
} catch($e41524153) {
if(R.isCont($e41524153)) {
var $ss41564157 = {"from":L[10],
"go":function(anf_arg799324) {
return $Hanf_arg1277323(anf_arg799324,_plus5);
}};
$e41524153.stack[R.EXN_STACKHEIGHT++] = $ss41564157;
}
if(R.isPyretException($e41524153)) {
$e41524153.pyretStack.push(L[10]);
}
throw $e41524153;
}
var $ret41584159 = $Hanf_arg1277323($z41544155,_plus5);
++R.GAS;
return $ret41584159;
};
},{"length":1});
var anf_variant_member8073836 = R.makeMethod(function(self1444151) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[9],0,arguments);
}
var anf_bracket8044150 = G(self1444151,"loc",L[143]);
var anf_fun8054149 = G(anf_bracket8044150,"format",L[142]);
var $z41414142 = D;
var $f41474148 = function(_) {
return R.isFunction(anf_fun8054149)?anf_fun8054149.app((true)):R.ffi.throwNonFunApp(L[141],anf_fun8054149,[(true)]);
};
try {
if(--R.GAS > 0) {
$z41414142 = $f41474148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41474148,
"from":L[141]});
}
} catch($e41394140) {
if(R.isCont($e41394140)) {
var $ss41434144 = {"from":L[141],
"go":function(anf_arg806310) {
return $Hanf_arg1279309(anf_arg806310,_plus5);
}};
$e41394140.stack[R.EXN_STACKHEIGHT++] = $ss41434144;
}
if(R.isPyretException($e41394140)) {
$e41394140.pyretStack.push(L[141]);
}
throw $e41394140;
}
var $ret41454146 = $Hanf_arg1279309($z41414142,_plus5);
++R.GAS;
return $ret41454146;
};
},{"length":1});
var anf_variant_member8193843 = R.makeMethod(function(self1464095) {
return function(cases_DASH_funs1474120,else_DASH_clause1484131) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[8],2,arguments);
}
var if_DASH_1504132 = R.hasField(cases_DASH_funs1474120,("fun-missing-end"));
var if_helper809302 = R.makeFunction(function(if_helper_arg8104137) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
var ann_DASH_check_DASH_temp8084138 = if_helper_arg8104137;
return ann_DASH_check_DASH_temp8084138;
});
var anf_if8134136 = R.isBoolean(if_DASH_1504132);
if(R.isPyretTrue(anf_if8134136)) {
if(R.isPyretTrue(if_DASH_1504132)) {
var call_DASH_fun_DASH_missing_DASH_end1454118 = G(cases_DASH_funs1474120,"fun-missing-end",L[8]);
var anf_arg8164119 = G(self1464095,"loc",L[140]);
var $z41104111 = D;
var $f41164117 = function(_) {
return R.isFunction(call_DASH_fun_DASH_missing_DASH_end1454118)?call_DASH_fun_DASH_missing_DASH_end1454118.app(anf_arg8164119):R.ffi.throwNonFunApp(L[8],call_DASH_fun_DASH_missing_DASH_end1454118,[anf_arg8164119]);
};
try {
if(--R.GAS > 0) {
$z41104111 = $f41164117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41164117,
"from":L[8]});
}
} catch($e41084109) {
if(R.isCont($e41084109)) {
var $ss41124113 = {"from":L[8],
"go":function(cont_tail_arg817301) {
return $Hcont_tail_arg1280300(cont_tail_arg817301,if_helper809302);
}};
$e41084109.stack[R.EXN_STACKHEIGHT++] = $ss41124113;
}
if(R.isPyretException($e41084109)) {
$e41084109.pyretStack.push(L[8]);
}
throw $e41084109;
}
var $ret41144115 = $Hcont_tail_arg1280300($z41104111,if_helper809302);
++R.GAS;
return $ret41144115;
} else {
var $z41234124 = D;
var $f41294130 = function(_) {
return R.isFunction(else_DASH_clause1484131)?else_DASH_clause1484131.app():R.ffi.throwNonFunApp(L[8],else_DASH_clause1484131,[]);
};
try {
if(--R.GAS > 0) {
$z41234124 = $f41294130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41294130,
"from":L[8]});
}
} catch($e41214122) {
if(R.isCont($e41214122)) {
var $ss41254126 = {"from":L[8],
"go":function(cont_tail_arg814306) {
return $Hcont_tail_arg1281305(cont_tail_arg814306,if_helper809302);
}};
$e41214122.stack[R.EXN_STACKHEIGHT++] = $ss41254126;
}
if(R.isPyretException($e41214122)) {
$e41214122.pyretStack.push(L[8]);
}
throw $e41214122;
}
var $ret41274128 = $Hcont_tail_arg1281305($z41234124,if_helper809302);
++R.GAS;
return $ret41274128;
}
} else {
var cont_tail_arg8114135 = R.throwNonBooleanCondition(L[8],("if"),if_DASH_1504132);
if(--R.GAS > 0) {
$z41334134 = R.isFunction(if_helper809302)?if_helper809302.app(cont_tail_arg8114135):R.ffi.throwNonFunApp(L[8],if_helper809302,[cont_tail_arg8114135]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper809302)?if_helper809302.app(cont_tail_arg8114135):R.ffi.throwNonFunApp(L[8],if_helper809302,[cont_tail_arg8114135]);
},
"from":L[8]});
}
++R.GAS;
return $z41334134;
}
};
},{"length":3});
var anf_variant_member8253844 = R.makeMethod(function(self1494107) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[8],0,arguments);
}
var anf_arg8214106 = G(self1494107,"loc",L[8]);
var $z40984099 = D;
var $f41044105 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg8214106):R.ffi.throwNonFunApp(L[8],torepr8,[anf_arg8214106]);
};
try {
if(--R.GAS > 0) {
$z40984099 = $f41044105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41044105,
"from":L[8]});
}
} catch($e40964097) {
if(R.isCont($e40964097)) {
var $ss41004101 = {"from":L[8],
"go":function(anf_arg822263) {
return $Hanf_arg1285262(anf_arg822263,_plus5);
}};
$e40964097.stack[R.EXN_STACKHEIGHT++] = $ss41004101;
}
if(R.isPyretException($e40964097)) {
$e40964097.pyretStack.push(L[8]);
}
throw $e40964097;
}
var $ret41024103 = $Hanf_arg1285262($z40984099,_plus5);
++R.GAS;
return $ret41024103;
};
},{"length":1});
var anf_variant_member8303845 = R.makeMethod(function(self1464095) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[7],0,arguments);
}
var anf_bracket8274094 = G(self1464095,"loc",L[139]);
var anf_fun8284093 = G(anf_bracket8274094,"format",L[138]);
var $z40854086 = D;
var $f40914092 = function(_) {
return R.isFunction(anf_fun8284093)?anf_fun8284093.app((true)):R.ffi.throwNonFunApp(L[137],anf_fun8284093,[(true)]);
};
try {
if(--R.GAS > 0) {
$z40854086 = $f40914092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40914092,
"from":L[137]});
}
} catch($e40834084) {
if(R.isCont($e40834084)) {
var $ss40874088 = {"from":L[137],
"go":function(anf_arg829249) {
return $Hanf_arg1287248(anf_arg829249,_plus5);
}};
$e40834084.stack[R.EXN_STACKHEIGHT++] = $ss40874088;
}
if(R.isPyretException($e40834084)) {
$e40834084.pyretStack.push(L[137]);
}
throw $e40834084;
}
var $ret40894090 = $Hanf_arg1287248($z40854086,_plus5);
++R.GAS;
return $ret40894090;
};
},{"length":1});
var anf_variant_member8423852 = R.makeMethod(function(self1524063) {
return function(cases_DASH_funs1534064,else_DASH_clause1544075) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[6],2,arguments);
}
var if_DASH_1564076 = R.hasField(cases_DASH_funs1534064,("args-missing-comma"));
var if_helper832241 = R.makeFunction(function(if_helper_arg8334081) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
var ann_DASH_check_DASH_temp8314082 = if_helper_arg8334081;
return ann_DASH_check_DASH_temp8314082;
});
var anf_if8364080 = R.isBoolean(if_DASH_1564076);
if(R.isPyretTrue(anf_if8364080)) {
if(R.isPyretTrue(if_DASH_1564076)) {
var call_DASH_args_DASH_missing_DASH_comma1514061 = G(cases_DASH_funs1534064,"args-missing-comma",L[6]);
var anf_arg8394062 = G(self1524063,"loc",L[136]);
var $z40534054 = D;
var $f40594060 = function(_) {
return R.isFunction(call_DASH_args_DASH_missing_DASH_comma1514061)?call_DASH_args_DASH_missing_DASH_comma1514061.app(anf_arg8394062):R.ffi.throwNonFunApp(L[6],call_DASH_args_DASH_missing_DASH_comma1514061,[anf_arg8394062]);
};
try {
if(--R.GAS > 0) {
$z40534054 = $f40594060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40594060,
"from":L[6]});
}
} catch($e40514052) {
if(R.isCont($e40514052)) {
var $ss40554056 = {"from":L[6],
"go":function(cont_tail_arg840240) {
return $Hcont_tail_arg1288239(cont_tail_arg840240,if_helper832241);
}};
$e40514052.stack[R.EXN_STACKHEIGHT++] = $ss40554056;
}
if(R.isPyretException($e40514052)) {
$e40514052.pyretStack.push(L[6]);
}
throw $e40514052;
}
var $ret40574058 = $Hcont_tail_arg1288239($z40534054,if_helper832241);
++R.GAS;
return $ret40574058;
} else {
var $z40674068 = D;
var $f40734074 = function(_) {
return R.isFunction(else_DASH_clause1544075)?else_DASH_clause1544075.app():R.ffi.throwNonFunApp(L[6],else_DASH_clause1544075,[]);
};
try {
if(--R.GAS > 0) {
$z40674068 = $f40734074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40734074,
"from":L[6]});
}
} catch($e40654066) {
if(R.isCont($e40654066)) {
var $ss40694070 = {"from":L[6],
"go":function(cont_tail_arg837245) {
return $Hcont_tail_arg1289244(cont_tail_arg837245,if_helper832241);
}};
$e40654066.stack[R.EXN_STACKHEIGHT++] = $ss40694070;
}
if(R.isPyretException($e40654066)) {
$e40654066.pyretStack.push(L[6]);
}
throw $e40654066;
}
var $ret40714072 = $Hcont_tail_arg1289244($z40674068,if_helper832241);
++R.GAS;
return $ret40714072;
}
} else {
var cont_tail_arg8344079 = R.throwNonBooleanCondition(L[6],("if"),if_DASH_1564076);
if(--R.GAS > 0) {
$z40774078 = R.isFunction(if_helper832241)?if_helper832241.app(cont_tail_arg8344079):R.ffi.throwNonFunApp(L[6],if_helper832241,[cont_tail_arg8344079]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper832241)?if_helper832241.app(cont_tail_arg8344079):R.ffi.throwNonFunApp(L[6],if_helper832241,[cont_tail_arg8344079]);
},
"from":L[6]});
}
++R.GAS;
return $z40774078;
}
};
},{"length":3});
var anf_variant_member8483853 = R.makeMethod(function(self1554050) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[6],0,arguments);
}
var anf_arg8444049 = G(self1554050,"loc",L[6]);
var $z40414042 = D;
var $f40474048 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg8444049):R.ffi.throwNonFunApp(L[6],torepr8,[anf_arg8444049]);
};
try {
if(--R.GAS > 0) {
$z40414042 = $f40474048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40474048,
"from":L[6]});
}
} catch($e40394040) {
if(R.isCont($e40394040)) {
var $ss40434044 = {"from":L[6],
"go":function(anf_arg845202) {
return $Hanf_arg1293201(anf_arg845202,_plus5);
}};
$e40394040.stack[R.EXN_STACKHEIGHT++] = $ss40434044;
}
if(R.isPyretException($e40394040)) {
$e40394040.pyretStack.push(L[6]);
}
throw $e40394040;
}
var $ret40454046 = $Hanf_arg1293201($z40414042,_plus5);
++R.GAS;
return $ret40454046;
};
},{"length":1});
var anf_variant_member8533854 = R.makeMethod(function(self1484038) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[5],0,arguments);
}
var anf_bracket8504037 = G(self1484038,"loc",L[135]);
var anf_fun8514036 = G(anf_bracket8504037,"format",L[134]);
var $z40284029 = D;
var $f40344035 = function(_) {
return R.isFunction(anf_fun8514036)?anf_fun8514036.app((true)):R.ffi.throwNonFunApp(L[133],anf_fun8514036,[(true)]);
};
try {
if(--R.GAS > 0) {
$z40284029 = $f40344035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40344035,
"from":L[133]});
}
} catch($e40264027) {
if(R.isCont($e40264027)) {
var $ss40304031 = {"from":L[133],
"go":function(anf_arg852188) {
return $Hanf_arg1295187(anf_arg852188,_plus5);
}};
$e40264027.stack[R.EXN_STACKHEIGHT++] = $ss40304031;
}
if(R.isPyretException($e40264027)) {
$e40264027.pyretStack.push(L[133]);
}
throw $e40264027;
}
var $ret40324033 = $Hanf_arg1295187($z40284029,_plus5);
++R.GAS;
return $ret40324033;
};
},{"length":1});
var anf_variant_member8653861 = R.makeMethod(function(self1584006) {
return function(cases_DASH_funs1594007,else_DASH_clause1604018) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[4],2,arguments);
}
var if_DASH_1624019 = R.hasField(cases_DASH_funs1594007,("app-args-missing-comma"));
var if_helper855180 = R.makeFunction(function(if_helper_arg8564024) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
var ann_DASH_check_DASH_temp8544025 = if_helper_arg8564024;
return ann_DASH_check_DASH_temp8544025;
});
var anf_if8594023 = R.isBoolean(if_DASH_1624019);
if(R.isPyretTrue(anf_if8594023)) {
if(R.isPyretTrue(if_DASH_1624019)) {
var call_DASH_app_DASH_args_DASH_missing_DASH_comma1574004 = G(cases_DASH_funs1594007,"app-args-missing-comma",L[4]);
var anf_arg8624005 = G(self1584006,"loc",L[132]);
var $z39963997 = D;
var $f40024003 = function(_) {
return R.isFunction(call_DASH_app_DASH_args_DASH_missing_DASH_comma1574004)?call_DASH_app_DASH_args_DASH_missing_DASH_comma1574004.app(anf_arg8624005):R.ffi.throwNonFunApp(L[4],call_DASH_app_DASH_args_DASH_missing_DASH_comma1574004,[anf_arg8624005]);
};
try {
if(--R.GAS > 0) {
$z39963997 = $f40024003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40024003,
"from":L[4]});
}
} catch($e39943995) {
if(R.isCont($e39943995)) {
var $ss39983999 = {"from":L[4],
"go":function(cont_tail_arg863179) {
return $Hcont_tail_arg1296178(cont_tail_arg863179,if_helper855180);
}};
$e39943995.stack[R.EXN_STACKHEIGHT++] = $ss39983999;
}
if(R.isPyretException($e39943995)) {
$e39943995.pyretStack.push(L[4]);
}
throw $e39943995;
}
var $ret40004001 = $Hcont_tail_arg1296178($z39963997,if_helper855180);
++R.GAS;
return $ret40004001;
} else {
var $z40104011 = D;
var $f40164017 = function(_) {
return R.isFunction(else_DASH_clause1604018)?else_DASH_clause1604018.app():R.ffi.throwNonFunApp(L[4],else_DASH_clause1604018,[]);
};
try {
if(--R.GAS > 0) {
$z40104011 = $f40164017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40164017,
"from":L[4]});
}
} catch($e40084009) {
if(R.isCont($e40084009)) {
var $ss40124013 = {"from":L[4],
"go":function(cont_tail_arg860184) {
return $Hcont_tail_arg1297183(cont_tail_arg860184,if_helper855180);
}};
$e40084009.stack[R.EXN_STACKHEIGHT++] = $ss40124013;
}
if(R.isPyretException($e40084009)) {
$e40084009.pyretStack.push(L[4]);
}
throw $e40084009;
}
var $ret40144015 = $Hcont_tail_arg1297183($z40104011,if_helper855180);
++R.GAS;
return $ret40144015;
}
} else {
var cont_tail_arg8574022 = R.throwNonBooleanCondition(L[4],("if"),if_DASH_1624019);
if(--R.GAS > 0) {
$z40204021 = R.isFunction(if_helper855180)?if_helper855180.app(cont_tail_arg8574022):R.ffi.throwNonFunApp(L[4],if_helper855180,[cont_tail_arg8574022]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper855180)?if_helper855180.app(cont_tail_arg8574022):R.ffi.throwNonFunApp(L[4],if_helper855180,[cont_tail_arg8574022]);
},
"from":L[4]});
}
++R.GAS;
return $z40204021;
}
};
},{"length":3});
var anf_variant_member8713862 = R.makeMethod(function(self1613993) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4],0,arguments);
}
var anf_arg8673992 = G(self1613993,"loc",L[4]);
var $z39843985 = D;
var $f39903991 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg8673992):R.ffi.throwNonFunApp(L[4],torepr8,[anf_arg8673992]);
};
try {
if(--R.GAS > 0) {
$z39843985 = $f39903991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39903991,
"from":L[4]});
}
} catch($e39823983) {
if(R.isCont($e39823983)) {
var $ss39863987 = {"from":L[4],
"go":function(anf_arg868141) {
return $Hanf_arg1301140(anf_arg868141,_plus5);
}};
$e39823983.stack[R.EXN_STACKHEIGHT++] = $ss39863987;
}
if(R.isPyretException($e39823983)) {
$e39823983.pyretStack.push(L[4]);
}
throw $e39823983;
}
var $ret39883989 = $Hanf_arg1301140($z39843985,_plus5);
++R.GAS;
return $ret39883989;
};
},{"length":1});
var anf_variant_member8763863 = R.makeMethod(function(self1503981) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3],0,arguments);
}
var anf_bracket8733980 = G(self1503981,"loc",L[131]);
var anf_fun8743979 = G(anf_bracket8733980,"format",L[130]);
var $z39713972 = D;
var $f39773978 = function(_) {
return R.isFunction(anf_fun8743979)?anf_fun8743979.app((true)):R.ffi.throwNonFunApp(L[129],anf_fun8743979,[(true)]);
};
try {
if(--R.GAS > 0) {
$z39713972 = $f39773978();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39773978,
"from":L[129]});
}
} catch($e39693970) {
if(R.isCont($e39693970)) {
var $ss39733974 = {"from":L[129],
"go":function(anf_arg875127) {
return $Hanf_arg1303126(anf_arg875127,_plus5);
}};
$e39693970.stack[R.EXN_STACKHEIGHT++] = $ss39733974;
}
if(R.isPyretException($e39693970)) {
$e39693970.pyretStack.push(L[129]);
}
throw $e39693970;
}
var $ret39753976 = $Hanf_arg1303126($z39713972,_plus5);
++R.GAS;
return $ret39753976;
};
},{"length":1});
var anf_variant_member8883870 = R.makeMethod(function(self1643949) {
return function(cases_DASH_funs1653950,else_DASH_clause1663961) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2],2,arguments);
}
var if_DASH_1683962 = R.hasField(cases_DASH_funs1653950,("missing-end"));
var if_helper878119 = R.makeFunction(function(if_helper_arg8793967) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
var ann_DASH_check_DASH_temp8773968 = if_helper_arg8793967;
return ann_DASH_check_DASH_temp8773968;
});
var anf_if8823966 = R.isBoolean(if_DASH_1683962);
if(R.isPyretTrue(anf_if8823966)) {
if(R.isPyretTrue(if_DASH_1683962)) {
var call_DASH_missing_DASH_end1633947 = G(cases_DASH_funs1653950,"missing-end",L[2]);
var anf_arg8853948 = G(self1643949,"loc",L[128]);
var $z39393940 = D;
var $f39453946 = function(_) {
return R.isFunction(call_DASH_missing_DASH_end1633947)?call_DASH_missing_DASH_end1633947.app(anf_arg8853948):R.ffi.throwNonFunApp(L[2],call_DASH_missing_DASH_end1633947,[anf_arg8853948]);
};
try {
if(--R.GAS > 0) {
$z39393940 = $f39453946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39453946,
"from":L[2]});
}
} catch($e39373938) {
if(R.isCont($e39373938)) {
var $ss39413942 = {"from":L[2],
"go":function(cont_tail_arg886118) {
return $Hcont_tail_arg1304117(cont_tail_arg886118,if_helper878119);
}};
$e39373938.stack[R.EXN_STACKHEIGHT++] = $ss39413942;
}
if(R.isPyretException($e39373938)) {
$e39373938.pyretStack.push(L[2]);
}
throw $e39373938;
}
var $ret39433944 = $Hcont_tail_arg1304117($z39393940,if_helper878119);
++R.GAS;
return $ret39433944;
} else {
var $z39533954 = D;
var $f39593960 = function(_) {
return R.isFunction(else_DASH_clause1663961)?else_DASH_clause1663961.app():R.ffi.throwNonFunApp(L[2],else_DASH_clause1663961,[]);
};
try {
if(--R.GAS > 0) {
$z39533954 = $f39593960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39593960,
"from":L[2]});
}
} catch($e39513952) {
if(R.isCont($e39513952)) {
var $ss39553956 = {"from":L[2],
"go":function(cont_tail_arg883123) {
return $Hcont_tail_arg1305122(cont_tail_arg883123,if_helper878119);
}};
$e39513952.stack[R.EXN_STACKHEIGHT++] = $ss39553956;
}
if(R.isPyretException($e39513952)) {
$e39513952.pyretStack.push(L[2]);
}
throw $e39513952;
}
var $ret39573958 = $Hcont_tail_arg1305122($z39533954,if_helper878119);
++R.GAS;
return $ret39573958;
}
} else {
var cont_tail_arg8803965 = R.throwNonBooleanCondition(L[2],("if"),if_DASH_1683962);
if(--R.GAS > 0) {
$z39633964 = R.isFunction(if_helper878119)?if_helper878119.app(cont_tail_arg8803965):R.ffi.throwNonFunApp(L[2],if_helper878119,[cont_tail_arg8803965]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper878119)?if_helper878119.app(cont_tail_arg8803965):R.ffi.throwNonFunApp(L[2],if_helper878119,[cont_tail_arg8803965]);
},
"from":L[2]});
}
++R.GAS;
return $z39633964;
}
};
},{"length":3});
var anf_variant_member8943871 = R.makeMethod(function(self1673936) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2],0,arguments);
}
var anf_arg8903935 = G(self1673936,"loc",L[2]);
var $z39273928 = D;
var $f39333934 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg8903935):R.ffi.throwNonFunApp(L[2],torepr8,[anf_arg8903935]);
};
try {
if(--R.GAS > 0) {
$z39273928 = $f39333934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39333934,
"from":L[2]});
}
} catch($e39253926) {
if(R.isCont($e39253926)) {
var $ss39293930 = {"from":L[2],
"go":function(anf_arg89180) {
return $Hanf_arg130979(anf_arg89180,_plus5);
}};
$e39253926.stack[R.EXN_STACKHEIGHT++] = $ss39293930;
}
if(R.isPyretException($e39253926)) {
$e39253926.pyretStack.push(L[2]);
}
throw $e39253926;
}
var $ret39313932 = $Hanf_arg130979($z39273928,_plus5);
++R.GAS;
return $ret39313932;
};
},{"length":1});
var anf_variant_member9063878 = R.makeMethod(function(self1703905) {
return function(cases_DASH_funs1713906,else_DASH_clause1723917) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
var if_DASH_1743918 = R.hasField(cases_DASH_funs1713906,("missing-comma"));
var if_helper89671 = R.makeFunction(function(if_helper_arg8973923) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
var ann_DASH_check_DASH_temp8953924 = if_helper_arg8973923;
return ann_DASH_check_DASH_temp8953924;
});
var anf_if9003922 = R.isBoolean(if_DASH_1743918);
if(R.isPyretTrue(anf_if9003922)) {
if(R.isPyretTrue(if_DASH_1743918)) {
var call_DASH_missing_DASH_comma1693903 = G(cases_DASH_funs1713906,"missing-comma",L[1]);
var anf_arg9033904 = G(self1703905,"loc",L[127]);
var $z38953896 = D;
var $f39013902 = function(_) {
return R.isFunction(call_DASH_missing_DASH_comma1693903)?call_DASH_missing_DASH_comma1693903.app(anf_arg9033904):R.ffi.throwNonFunApp(L[1],call_DASH_missing_DASH_comma1693903,[anf_arg9033904]);
};
try {
if(--R.GAS > 0) {
$z38953896 = $f39013902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39013902,
"from":L[1]});
}
} catch($e38933894) {
if(R.isCont($e38933894)) {
var $ss38973898 = {"from":L[1],
"go":function(cont_tail_arg90470) {
return $Hcont_tail_arg131069(cont_tail_arg90470,if_helper89671);
}};
$e38933894.stack[R.EXN_STACKHEIGHT++] = $ss38973898;
}
if(R.isPyretException($e38933894)) {
$e38933894.pyretStack.push(L[1]);
}
throw $e38933894;
}
var $ret38993900 = $Hcont_tail_arg131069($z38953896,if_helper89671);
++R.GAS;
return $ret38993900;
} else {
var $z39093910 = D;
var $f39153916 = function(_) {
return R.isFunction(else_DASH_clause1723917)?else_DASH_clause1723917.app():R.ffi.throwNonFunApp(L[1],else_DASH_clause1723917,[]);
};
try {
if(--R.GAS > 0) {
$z39093910 = $f39153916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39153916,
"from":L[1]});
}
} catch($e39073908) {
if(R.isCont($e39073908)) {
var $ss39113912 = {"from":L[1],
"go":function(cont_tail_arg90176) {
return $Hcont_tail_arg131175(cont_tail_arg90176,if_helper89671);
}};
$e39073908.stack[R.EXN_STACKHEIGHT++] = $ss39113912;
}
if(R.isPyretException($e39073908)) {
$e39073908.pyretStack.push(L[1]);
}
throw $e39073908;
}
var $ret39133914 = $Hcont_tail_arg131175($z39093910,if_helper89671);
++R.GAS;
return $ret39133914;
}
} else {
var cont_tail_arg8983921 = R.throwNonBooleanCondition(L[1],("if"),if_DASH_1743918);
if(--R.GAS > 0) {
$z39193920 = R.isFunction(if_helper89671)?if_helper89671.app(cont_tail_arg8983921):R.ffi.throwNonFunApp(L[1],if_helper89671,[cont_tail_arg8983921]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored74) {
return R.isFunction(if_helper89671)?if_helper89671.app(cont_tail_arg8983921):R.ffi.throwNonFunApp(L[1],if_helper89671,[cont_tail_arg8983921]);
},
"from":L[1]});
}
++R.GAS;
return $z39193920;
}
};
},{"length":3});
var anf_variant_member9123879 = R.makeMethod(function(self1733892) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1],0,arguments);
}
var anf_arg9083891 = G(self1733892,"loc",L[1]);
var $z38833884 = D;
var $f38893890 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg9083891):R.ffi.throwNonFunApp(L[1],torepr8,[anf_arg9083891]);
};
try {
if(--R.GAS > 0) {
$z38833884 = $f38893890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38893890,
"from":L[1]});
}
} catch($e38813882) {
if(R.isCont($e38813882)) {
var $ss38853886 = {"from":L[1],
"go":function(anf_arg90932) {
return $Hanf_arg131531(anf_arg90932,_plus5);
}};
$e38813882.stack[R.EXN_STACKHEIGHT++] = $ss38853886;
}
if(R.isPyretException($e38813882)) {
$e38813882.pyretStack.push(L[1]);
}
throw $e38813882;
}
var $ret38873888 = $Hanf_arg131531($z38833884,_plus5);
++R.GAS;
return $ret38873888;
};
},{"length":1});
var anf_assign9133723 = (function() {
var $parse_DASH_error_DASH_next_DASH_token_DASH_base37833784 = {"_match":anf_variant_member6743788,
"_torepr":anf_variant_member6843789,
"tostring":anf_variant_member6923790};
var $parse_DASH_error_DASH_next_DASH_token_DASH_brands37863787 = {"$brand-parse-error-next-token3785":true};
$parse_DASH_error_DASH_next_DASH_token_DASH_brands37863787[ParseErrorT243643._brand] = true
var $parse_DASH_error_DASH_eof_DASH_base37933794 = {"_match":anf_variant_member7043798,
"_torepr":anf_variant_member7103799,
"tostring":anf_variant_member7153800};
var $parse_DASH_error_DASH_eof_DASH_brands37963797 = {"$brand-parse-error-eof3795":true};
$parse_DASH_error_DASH_eof_DASH_brands37963797[ParseErrorT243643._brand] = true
var $empty_DASH_block_DASH_base38023803 = {"_match":anf_variant_member7273807,
"_torepr":anf_variant_member7333808,
"tostring":anf_variant_member7383809};
var $empty_DASH_block_DASH_brands38053806 = {"$brand-empty-block3804":true};
$empty_DASH_block_DASH_brands38053806[ParseErrorT243643._brand] = true
var $bad_DASH_block_DASH_stmt_DASH_base38113812 = {"_match":anf_variant_member7503816,
"_torepr":anf_variant_member7563817,
"tostring":anf_variant_member7613818};
var $bad_DASH_block_DASH_stmt_DASH_brands38143815 = {"$brand-bad-block-stmt3813":true};
$bad_DASH_block_DASH_stmt_DASH_brands38143815[ParseErrorT243643._brand] = true
var $bad_DASH_check_DASH_block_DASH_stmt_DASH_base38203821 = {"_match":anf_variant_member7733825,
"_torepr":anf_variant_member7793826,
"tostring":anf_variant_member7843827};
var $bad_DASH_check_DASH_block_DASH_stmt_DASH_brands38233824 = {"$brand-bad-check-block-stmt3822":true};
$bad_DASH_check_DASH_block_DASH_stmt_DASH_brands38233824[ParseErrorT243643._brand] = true
var $fun_DASH_missing_DASH_colon_DASH_base38293830 = {"_match":anf_variant_member7963834,
"_torepr":anf_variant_member8023835,
"tostring":anf_variant_member8073836};
var $fun_DASH_missing_DASH_colon_DASH_brands38323833 = {"$brand-fun-missing-colon3831":true};
$fun_DASH_missing_DASH_colon_DASH_brands38323833[ParseErrorT243643._brand] = true
var $fun_DASH_missing_DASH_end_DASH_base38383839 = {"_match":anf_variant_member8193843,
"_torepr":anf_variant_member8253844,
"tostring":anf_variant_member8303845};
var $fun_DASH_missing_DASH_end_DASH_brands38413842 = {"$brand-fun-missing-end3840":true};
$fun_DASH_missing_DASH_end_DASH_brands38413842[ParseErrorT243643._brand] = true
var $args_DASH_missing_DASH_comma_DASH_base38473848 = {"_match":anf_variant_member8423852,
"_torepr":anf_variant_member8483853,
"tostring":anf_variant_member8533854};
var $args_DASH_missing_DASH_comma_DASH_brands38503851 = {"$brand-args-missing-comma3849":true};
$args_DASH_missing_DASH_comma_DASH_brands38503851[ParseErrorT243643._brand] = true
var $app_DASH_args_DASH_missing_DASH_comma_DASH_base38563857 = {"_match":anf_variant_member8653861,
"_torepr":anf_variant_member8713862,
"tostring":anf_variant_member8763863};
var $app_DASH_args_DASH_missing_DASH_comma_DASH_brands38593860 = {"$brand-app-args-missing-comma3858":true};
$app_DASH_args_DASH_missing_DASH_comma_DASH_brands38593860[ParseErrorT243643._brand] = true
var $missing_DASH_end_DASH_base38653866 = {"_match":anf_variant_member8883870,
"_torepr":anf_variant_member8943871};
var $missing_DASH_end_DASH_brands38683869 = {"$brand-missing-end3867":true};
$missing_DASH_end_DASH_brands38683869[ParseErrorT243643._brand] = true
var $missing_DASH_comma_DASH_base38733874 = {"_match":anf_variant_member9063878,
"_torepr":anf_variant_member9123879};
var $missing_DASH_comma_DASH_brands38763877 = {"$brand-missing-comma3875":true};
$missing_DASH_comma_DASH_brands38763877[ParseErrorT243643._brand] = true
return R.makeObject({"ParseError":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[114],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ParseErrorT243643._brand));
}),
"is-parse-error-next-token":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-parse-error-next-token3785"));
}),
"parse-error-next-token":R.makeFunction(function(loc1323791,next_DASH_token1333792) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[115],2,arguments);
}
return R.checkAnnArgs([$type$String11],[next_DASH_token1333792],[L[116]],function() {
var dict = R.create($parse_DASH_error_DASH_next_DASH_token_DASH_base37833784);
dict["loc"] = loc1323791
dict["next-token"] = next_DASH_token1333792
return R.makeBrandedObject(dict,$parse_DASH_error_DASH_next_DASH_token_DASH_brands37863787);
});
}),
"is-parse-error-eof":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[18],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-parse-error-eof3795"));
}),
"parse-error-eof":R.makeFunction(function(loc1353801) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
var dict = R.create($parse_DASH_error_DASH_eof_DASH_base37933794);
dict["loc"] = loc1353801
return R.makeBrandedObject(dict,$parse_DASH_error_DASH_eof_DASH_brands37963797);
}),
"is-empty-block":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[16],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-empty-block3804"));
}),
"empty-block":R.makeFunction(function(loc1373810) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[118],1,arguments);
}
var dict = R.create($empty_DASH_block_DASH_base38023803);
dict["loc"] = loc1373810
return R.makeBrandedObject(dict,$empty_DASH_block_DASH_brands38053806);
}),
"is-bad-block-stmt":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[14],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-bad-block-stmt3813"));
}),
"bad-block-stmt":R.makeFunction(function(loc1393819) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[119],1,arguments);
}
var dict = R.create($bad_DASH_block_DASH_stmt_DASH_base38113812);
dict["loc"] = loc1393819
return R.makeBrandedObject(dict,$bad_DASH_block_DASH_stmt_DASH_brands38143815);
}),
"is-bad-check-block-stmt":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[12],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-bad-check-block-stmt3822"));
}),
"bad-check-block-stmt":R.makeFunction(function(loc1413828) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[120],1,arguments);
}
var dict = R.create($bad_DASH_check_DASH_block_DASH_stmt_DASH_base38203821);
dict["loc"] = loc1413828
return R.makeBrandedObject(dict,$bad_DASH_check_DASH_block_DASH_stmt_DASH_brands38233824);
}),
"is-fun-missing-colon":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[10],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-fun-missing-colon3831"));
}),
"fun-missing-colon":R.makeFunction(function(loc1433837) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[121],1,arguments);
}
var dict = R.create($fun_DASH_missing_DASH_colon_DASH_base38293830);
dict["loc"] = loc1433837
return R.makeBrandedObject(dict,$fun_DASH_missing_DASH_colon_DASH_brands38323833);
}),
"is-fun-missing-end":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-fun-missing-end3840"));
}),
"fun-missing-end":R.makeFunction(function(loc1453846) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[122],1,arguments);
}
var dict = R.create($fun_DASH_missing_DASH_end_DASH_base38383839);
dict["loc"] = loc1453846
return R.makeBrandedObject(dict,$fun_DASH_missing_DASH_end_DASH_brands38413842);
}),
"is-args-missing-comma":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-args-missing-comma3849"));
}),
"args-missing-comma":R.makeFunction(function(loc1473855) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[123],1,arguments);
}
var dict = R.create($args_DASH_missing_DASH_comma_DASH_base38473848);
dict["loc"] = loc1473855
return R.makeBrandedObject(dict,$args_DASH_missing_DASH_comma_DASH_brands38503851);
}),
"is-app-args-missing-comma":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-app-args-missing-comma3858"));
}),
"app-args-missing-comma":R.makeFunction(function(loc1493864) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[124],1,arguments);
}
var dict = R.create($app_DASH_args_DASH_missing_DASH_comma_DASH_base38563857);
dict["loc"] = loc1493864
return R.makeBrandedObject(dict,$app_DASH_args_DASH_missing_DASH_comma_DASH_brands38593860);
}),
"is-missing-end":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-missing-end3867"));
}),
"missing-end":R.makeFunction(function(loc1513872) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[125],1,arguments);
}
var dict = R.create($missing_DASH_end_DASH_base38653866);
dict["loc"] = loc1513872
return R.makeBrandedObject(dict,$missing_DASH_end_DASH_brands38683869);
}),
"is-missing-comma":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-missing-comma3875"));
}),
"missing-comma":R.makeFunction(function(loc1523880) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[126],1,arguments);
}
var dict = R.create($missing_DASH_comma_DASH_base38733874);
dict["loc"] = loc1523880
return R.makeBrandedObject(dict,$missing_DASH_comma_DASH_brands38763877);
})});
})();
ParseError4443722.$var = anf_assign9133723;
var anf_assign9143725 = G(ParseError4443722.$var,"ParseError",L[114]);
ParseError453724.$var = anf_assign9143725;
var anf_assign9153727 = G(ParseError4443722.$var,"ParseError",L[114]);
is_DASH_ParseError463726.$var = anf_assign9153727;
var anf_assign9163729 = G(ParseError4443722.$var,"is-parse-error-next-token",L[22]);
is_DASH_parse_DASH_error_DASH_next_DASH_token473728.$var = anf_assign9163729;
var anf_assign9173731 = G(ParseError4443722.$var,"parse-error-next-token",L[22]);
parse_DASH_error_DASH_next_DASH_token483730.$var = anf_assign9173731;
var anf_assign9183733 = G(ParseError4443722.$var,"is-parse-error-eof",L[18]);
is_DASH_parse_DASH_error_DASH_eof493732.$var = anf_assign9183733;
var anf_assign9193735 = G(ParseError4443722.$var,"parse-error-eof",L[18]);
parse_DASH_error_DASH_eof503734.$var = anf_assign9193735;
var anf_assign9203737 = G(ParseError4443722.$var,"is-empty-block",L[16]);
is_DASH_empty_DASH_block513736.$var = anf_assign9203737;
var anf_assign9213739 = G(ParseError4443722.$var,"empty-block",L[16]);
empty_DASH_block523738.$var = anf_assign9213739;
var anf_assign9223741 = G(ParseError4443722.$var,"is-bad-block-stmt",L[14]);
is_DASH_bad_DASH_block_DASH_stmt533740.$var = anf_assign9223741;
var anf_assign9233743 = G(ParseError4443722.$var,"bad-block-stmt",L[14]);
bad_DASH_block_DASH_stmt543742.$var = anf_assign9233743;
var anf_assign9243745 = G(ParseError4443722.$var,"is-bad-check-block-stmt",L[12]);
is_DASH_bad_DASH_check_DASH_block_DASH_stmt553744.$var = anf_assign9243745;
var anf_assign9253747 = G(ParseError4443722.$var,"bad-check-block-stmt",L[12]);
bad_DASH_check_DASH_block_DASH_stmt563746.$var = anf_assign9253747;
var anf_assign9263749 = G(ParseError4443722.$var,"is-fun-missing-colon",L[10]);
is_DASH_fun_DASH_missing_DASH_colon573748.$var = anf_assign9263749;
var anf_assign9273751 = G(ParseError4443722.$var,"fun-missing-colon",L[10]);
fun_DASH_missing_DASH_colon583750.$var = anf_assign9273751;
var anf_assign9283753 = G(ParseError4443722.$var,"is-fun-missing-end",L[8]);
is_DASH_fun_DASH_missing_DASH_end593752.$var = anf_assign9283753;
var anf_assign9293755 = G(ParseError4443722.$var,"fun-missing-end",L[8]);
fun_DASH_missing_DASH_end603754.$var = anf_assign9293755;
var anf_assign9303757 = G(ParseError4443722.$var,"is-args-missing-comma",L[6]);
is_DASH_args_DASH_missing_DASH_comma613756.$var = anf_assign9303757;
var anf_assign9313759 = G(ParseError4443722.$var,"args-missing-comma",L[6]);
args_DASH_missing_DASH_comma623758.$var = anf_assign9313759;
var anf_assign9323761 = G(ParseError4443722.$var,"is-app-args-missing-comma",L[4]);
is_DASH_app_DASH_args_DASH_missing_DASH_comma633760.$var = anf_assign9323761;
var anf_assign9333763 = G(ParseError4443722.$var,"app-args-missing-comma",L[4]);
app_DASH_args_DASH_missing_DASH_comma643762.$var = anf_assign9333763;
var anf_assign9343765 = G(ParseError4443722.$var,"is-missing-end",L[2]);
is_DASH_missing_DASH_end653764.$var = anf_assign9343765;
var anf_assign9353767 = G(ParseError4443722.$var,"missing-end",L[2]);
missing_DASH_end663766.$var = anf_assign9353767;
var anf_assign9363769 = G(ParseError4443722.$var,"is-missing-comma",L[1]);
is_DASH_missing_DASH_comma673768.$var = anf_assign9363769;
var anf_assign9373771 = G(ParseError4443722.$var,"missing-comma",L[1]);
missing_DASH_comma683770.$var = anf_assign9373771;
var provides93817 = R.makeObject({"RuntimeError":RuntimeError63646.$var,
"is-RuntimeError":is_DASH_RuntimeError73648.$var,
"message-exception":message_DASH_exception93652.$var,
"is-message-exception":is_DASH_message_DASH_exception83650.$var,
"no-branches-matched":no_DASH_branches_DASH_matched113656.$var,
"is-no-branches-matched":is_DASH_no_DASH_branches_DASH_matched103654.$var,
"internal-error":internal_DASH_error133660.$var,
"is-internal-error":is_DASH_internal_DASH_error123658.$var,
"field-not-found":field_DASH_not_DASH_found153664.$var,
"is-field-not-found":is_DASH_field_DASH_not_DASH_found143662.$var,
"lookup-non-object":lookup_DASH_non_DASH_object173668.$var,
"is-lookup-non-object":is_DASH_lookup_DASH_non_DASH_object163666.$var,
"non-boolean-condition":non_DASH_boolean_DASH_condition193672.$var,
"is-non-boolean-condition":is_DASH_non_DASH_boolean_DASH_condition183670.$var,
"non-boolean-op":non_DASH_boolean_DASH_op213676.$var,
"is-non-boolean-op":is_DASH_non_DASH_boolean_DASH_op203674.$var,
"generic-type-mismatch":generic_DASH_type_DASH_mismatch233680.$var,
"is-generic-type-mismatch":is_DASH_generic_DASH_type_DASH_mismatch223678.$var,
"outside-numeric-range":outside_DASH_numeric_DASH_range253684.$var,
"is-outside-numeric-range":is_DASH_outside_DASH_numeric_DASH_range243682.$var,
"plus-error":plus_DASH_error273688.$var,
"is-plus-error":is_DASH_plus_DASH_error263686.$var,
"numeric-binop-error":numeric_DASH_binop_DASH_error293692.$var,
"is-numeric-binop-error":is_DASH_numeric_DASH_binop_DASH_error283690.$var,
"arity-mismatch":arity_DASH_mismatch313696.$var,
"is-arity-mismatch":is_DASH_arity_DASH_mismatch303694.$var,
"non-function-app":non_DASH_function_DASH_app333700.$var,
"is-non-function-app":is_DASH_non_DASH_function_DASH_app323698.$var,
"bad-app":bad_DASH_app353704.$var,
"is-bad-app":is_DASH_bad_DASH_app343702.$var,
"uninitialized-id":uninitialized_DASH_id373708.$var,
"is-uninitialized-id":is_DASH_uninitialized_DASH_id363706.$var,
"module-load-failure":module_DASH_load_DASH_failure393712.$var,
"is-module-load-failure":is_DASH_module_DASH_load_DASH_failure383710.$var,
"invalid-array-index":invalid_DASH_array_DASH_index413716.$var,
"is-invalid-array-index":is_DASH_invalid_DASH_array_DASH_index403714.$var,
"user-break":user_DASH_break433720.$var,
"is-user-break":is_DASH_user_DASH_break423718.$var,
"ParseError":ParseError453724.$var,
"is-ParseError":is_DASH_ParseError463726.$var,
"parse-error-next-token":parse_DASH_error_DASH_next_DASH_token483730.$var,
"is-parse-error-next-token":is_DASH_parse_DASH_error_DASH_next_DASH_token473728.$var,
"parse-error-eof":parse_DASH_error_DASH_eof503734.$var,
"is-parse-error-eof":is_DASH_parse_DASH_error_DASH_eof493732.$var,
"empty-block":empty_DASH_block523738.$var,
"is-empty-block":is_DASH_empty_DASH_block513736.$var,
"bad-block-stmt":bad_DASH_block_DASH_stmt543742.$var,
"is-bad-block-stmt":is_DASH_bad_DASH_block_DASH_stmt533740.$var,
"bad-check-block-stmt":bad_DASH_check_DASH_block_DASH_stmt563746.$var,
"is-bad-check-block-stmt":is_DASH_bad_DASH_check_DASH_block_DASH_stmt553744.$var,
"fun-missing-colon":fun_DASH_missing_DASH_colon583750.$var,
"is-fun-missing-colon":is_DASH_fun_DASH_missing_DASH_colon573748.$var,
"fun-missing-end":fun_DASH_missing_DASH_end603754.$var,
"is-fun-missing-end":is_DASH_fun_DASH_missing_DASH_end593752.$var,
"args-missing-comma":args_DASH_missing_DASH_comma623758.$var,
"is-args-missing-comma":is_DASH_args_DASH_missing_DASH_comma613756.$var,
"app-args-missing-comma":app_DASH_args_DASH_missing_DASH_comma643762.$var,
"is-app-args-missing-comma":is_DASH_app_DASH_args_DASH_missing_DASH_comma633760.$var,
"missing-end":missing_DASH_end663766.$var,
"is-missing-end":is_DASH_missing_DASH_end653764.$var,
"missing-comma":missing_DASH_comma683770.$var,
"is-missing-comma":is_DASH_missing_DASH_comma673768.$var});
var anf_fun9393782 = G(builtins6,"current-checker",L[0]);
var $z37743775 = D;
var $f37803781 = function(_) {
return R.isFunction(anf_fun9393782)?anf_fun9393782.app():R.ffi.throwNonFunApp(L[0],anf_fun9393782,[]);
};
try {
if(--R.GAS > 0) {
$z37743775 = $f37803781();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37803781,
"from":L[0]});
}
} catch($e37723773) {
if(R.isCont($e37723773)) {
var $ss37763777 = {"from":L[0],
"go":function(anf_bracket94014) {
return $Hanf_bracket131713(anf_bracket94014,ParseError315,RuntimeError116,provides93817,nothing7);
}};
$e37723773.stack[R.EXN_STACKHEIGHT++] = $ss37763777;
}
if(R.isPyretException($e37723773)) {
$e37723773.pyretStack.push(L[0]);
}
throw $e37723773;
}
var $ret37783779 = $Hanf_bracket131713($z37743775,ParseError315,RuntimeError116,provides93817,nothing7);
++R.GAS;
return $ret37783779;
},function(moduleVal) {
R.modules["$src/arr/base/error.arr12"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/arrays',["trove/lists"],function($lists11417) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/base/arrays.arr16"]) {
return R.modules["$src/arr/base/arrays.arr16"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/base/arrays.arr";
var D = R.undefined;
var L = [[M,15,0,193,15,23,216],
[M,50,2,948,50,35,981],
[M,51,2,984,53,5,1060],
[M,51,6,988,51,18,1000],
[M,49,0,922,55,3,1076],
[M,45,2,897,45,9,904],
[M,39,2,798,44,5,894],
[M,40,4,815,43,7,888],
[M,37,0,705,47,3,920],
[M,41,28,857,41,32,861],
[M,40,9,820,40,17,828],
[M,41,6,835,41,33,862],
[M,42,11,874,42,17,880],
[M,41,6,835,42,17,880],
[M,30,19,613,30,47,641],
[M,30,19,613,30,37,631],
[M,30,19,613,30,62,656],
[M,30,19,613,30,56,650],
[M,30,6,600,30,68,662],
[M,29,4,578,31,7,670],
[M,27,19,517,27,45,543],
[M,27,19,517,27,37,535],
[M,27,19,517,27,60,558],
[M,27,19,517,27,54,552],
[M,27,6,504,27,66,564],
[M,26,4,483,28,7,572],
[M,50,24,970,50,34,980],
[M,50,24,970,50,32,978],
[M,38,2,763,38,34,795],
[M,37,24,729,37,38,743],
[M,37,47,752,37,53,758],
[M,35,11,692,35,22,703],
[M,17,0,218,33,3,679],
[M,30,19,613,30,33,627],
[M,30,19,613,30,31,625],
[M,27,19,517,27,33,531],
[M,27,19,517,27,31,529],
[M,25,4,439,25,42,477],
[M,24,4,397,24,40,433],
[M,21,6,345,21,33,372],
[M,20,4,319,23,7,391],
[M,19,4,275,19,42,313],
[M,18,2,256,18,14,268],
[M,17,16,234,17,24,242]];
var _lessthan1 = NAMESPACE.get("_lessthan");
var _plus2 = NAMESPACE.get("_plus");
var builtins3 = NAMESPACE.get("builtins");
var nothing4 = NAMESPACE.get("nothing");
var raw_DASH_array_DASH_get5 = NAMESPACE.get("raw-array-get");
var raw_DASH_array_DASH_length6 = NAMESPACE.get("raw-array-length");
var raw_DASH_array_DASH_of7 = NAMESPACE.get("raw-array-of");
var raw_DASH_array_DASH_set8 = NAMESPACE.get("raw-array-set");
var raw_DASH_array_DASH_to_DASH_list9 = NAMESPACE.get("raw-array-to-list");
var torepr10 = NAMESPACE.get("torepr");
var tostring11 = NAMESPACE.get("tostring");
var $type$Number12 = NAMESPACE.get("$type$Number");
var $type$RawArray13 = NAMESPACE.get("$type$RawArray");
var $Hanf_bracket9318 = function(anf_bracket5419,Array320,provides5221,nothing4) {
var anf_fun5532 = G(anf_bracket5419,"results",L[0]);
var $z2425 = D;
var $f3031 = function(_) {
return R.isFunction(anf_fun5532)?anf_fun5532.app():R.ffi.throwNonFunApp(L[0],anf_fun5532,[]);
};
try {
if(--R.GAS > 0) {
$z2425 = $f3031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3031,
"from":L[0]});
}
} catch($e2223) {
if(R.isCont($e2223)) {
var $ss2627 = {"from":L[0],
"go":function(checks5633) {
return $Hchecks9234(checks5633,Array320,provides5221,nothing4);
}};
$e2223.stack[R.EXN_STACKHEIGHT++] = $ss2627;
}
if(R.isPyretException($e2223)) {
$e2223.pyretStack.push(L[0]);
}
throw $e2223;
}
var $ret2829 = $Hchecks9234($z2425,Array320,provides5221,nothing4);
++R.GAS;
return $ret2829;
};
var $Hchecks9234 = function(checks5633,Array320,provides5221,nothing4) {
return R.makeObject({"answer":nothing4,
"provide-plus-types":R.makeObject({"values":provides5221,
"types":{"Array":Array320}}),
"checks":checks5633});
};
var $Hanf_arg9135 = function(anf_arg4636,l2537,lists114,make538,raw_DASH_array_DASH_of7,raw_DASH_array_DASH_set8) {
var $z4142 = D;
var $f4748 = function(_) {
return R.isFunction(raw_DASH_array_DASH_of7)?raw_DASH_array_DASH_of7.app((0),anf_arg4636):R.ffi.throwNonFunApp(L[1],raw_DASH_array_DASH_of7,[(0),anf_arg4636]);
};
try {
if(--R.GAS > 0) {
$z4142 = $f4748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4748,
"from":L[1]});
}
} catch($e3940) {
if(R.isCont($e3940)) {
var $ss4344 = {"from":L[1],
"go":function(arr2649) {
return $Harr9050(arr2649,l2537,lists114,make538,raw_DASH_array_DASH_set8);
}};
$e3940.stack[R.EXN_STACKHEIGHT++] = $ss4344;
}
if(R.isPyretException($e3940)) {
$e3940.pyretStack.push(L[1]);
}
throw $e3940;
}
var $ret4546 = $Harr9050($z4142,l2537,lists114,make538,raw_DASH_array_DASH_set8);
++R.GAS;
return $ret4546;
};
var $Harr9050 = function(arr2649,l2537,lists114,make538,raw_DASH_array_DASH_set8) {
var anf_fun4761 = G(lists114,"each_n",L[3]);
var anf_arg4962 = R.makeFunction(function(n2765,elt2866) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2],2,arguments);
}
var $z6970 = D;
var $f7576 = function(_) {
return R.isFunction(raw_DASH_array_DASH_set8)?raw_DASH_array_DASH_set8.app(arr2649,n2765,elt2866):R.ffi.throwNonFunApp(L[2],raw_DASH_array_DASH_set8,[arr2649,n2765,elt2866]);
};
try {
if(--R.GAS > 0) {
$z6970 = $f7576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7576,
"from":L[2]});
}
} catch($e6768) {
if(R.isCont($e6768)) {
var $ss7172 = {"from":L[2],
"go":function(ann_DASH_check_DASH_temp4877) {
return $Hann_DASH_check_DASH_temp8678(ann_DASH_check_DASH_temp4877);
}};
$e6768.stack[R.EXN_STACKHEIGHT++] = $ss7172;
}
if(R.isPyretException($e6768)) {
$e6768.pyretStack.push(L[2]);
}
throw $e6768;
}
var $ret7374 = $Hann_DASH_check_DASH_temp8678($z6970);
++R.GAS;
return $ret7374;
});
var $z5354 = D;
var $f5960 = function(_) {
return R.isFunction(anf_fun4761)?anf_fun4761.app(anf_arg4962,(0),l2537):R.ffi.throwNonFunApp(L[2],anf_fun4761,[anf_arg4962,(0),l2537]);
};
try {
if(--R.GAS > 0) {
$z5354 = $f5960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5960,
"from":L[2]});
}
} catch($e5152) {
if(R.isCont($e5152)) {
var $ss5556 = {"from":L[2],
"go":function(anf_begin_app_dropped8763) {
return $Hanf_begin_app_dropped8964(anf_begin_app_dropped8763,arr2649,make538);
}};
$e5152.stack[R.EXN_STACKHEIGHT++] = $ss5556;
}
if(R.isPyretException($e5152)) {
$e5152.pyretStack.push(L[2]);
}
throw $e5152;
}
var $ret5758 = $Hanf_begin_app_dropped8964($z5354,arr2649,make538);
++R.GAS;
return $ret5758;
};
var $Hanf_begin_app_dropped8964 = function(anf_begin_app_dropped8763,arr2649,make538) {
var $z8182 = D;
var $f8788 = function(_) {
return R.isFunction(make538.$var)?make538.$var.app(arr2649):R.ffi.throwNonFunApp(L[4],make538.$var,[arr2649]);
};
try {
if(--R.GAS > 0) {
$z8182 = $f8788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8788,
"from":L[4]});
}
} catch($e7980) {
if(R.isCont($e7980)) {
var $ss8384 = {"from":L[4],
"go":function(ann_DASH_check_DASH_temp4489) {
return $Hann_DASH_check_DASH_temp8890(ann_DASH_check_DASH_temp4489);
}};
$e7980.stack[R.EXN_STACKHEIGHT++] = $ss8384;
}
if(R.isPyretException($e7980)) {
$e7980.pyretStack.push(L[4]);
}
throw $e7980;
}
var $ret8586 = $Hann_DASH_check_DASH_temp8890($z8182);
++R.GAS;
return $ret8586;
};
var $Hann_DASH_check_DASH_temp8890 = function(ann_DASH_check_DASH_temp4489) {
return ann_DASH_check_DASH_temp4489;
};
var $Hann_DASH_check_DASH_temp8678 = function(ann_DASH_check_DASH_temp4877) {
return ann_DASH_check_DASH_temp4877;
};
var $Harr8591 = function(arr2292,f2093,len2194,make538,_lessthan1,_plus2,nothing4,raw_DASH_array_DASH_set8) {
var loop2395 = {"$var":D,
"$name":"loop"};
var anf_assign4296 = R.makeFunction(function(i24109) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
var $z112113 = D;
var $f118119 = function(_) {
return R.isFunction(_lessthan1)?_lessthan1.app(i24109,len2194):R.ffi.throwNonFunApp(L[7],_lessthan1,[i24109,len2194]);
};
try {
if(--R.GAS > 0) {
$z112113 = $f118119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f118119,
"from":L[7]});
}
} catch($e110111) {
if(R.isCont($e110111)) {
var $ss114115 = {"from":L[7],
"go":function(when_DASH_1120) {
return $Hwhen_DASH_81121(when_DASH_1120,arr2292,f2093,i24109,loop2395,_plus2,nothing4,raw_DASH_array_DASH_set8);
}};
$e110111.stack[R.EXN_STACKHEIGHT++] = $ss114115;
}
if(R.isPyretException($e110111)) {
$e110111.pyretStack.push(L[7]);
}
throw $e110111;
}
var $ret116117 = $Hwhen_DASH_81121($z112113,arr2292,f2093,i24109,loop2395,_plus2,nothing4,raw_DASH_array_DASH_set8);
++R.GAS;
return $ret116117;
});
loop2395.$var = anf_assign4296;
var $z99100 = D;
var $f105106 = function(_) {
return R.isFunction(loop2395.$var)?loop2395.$var.app((0)):R.ffi.throwNonFunApp(L[5],loop2395.$var,[(0)]);
};
try {
if(--R.GAS > 0) {
$z99100 = $f105106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f105106,
"from":L[5]});
}
} catch($e9798) {
if(R.isCont($e9798)) {
var $ss101102 = {"from":L[5],
"go":function(anf_begin_app_dropped82107) {
return $Hanf_begin_app_dropped84108(anf_begin_app_dropped82107,arr2292,make538);
}};
$e9798.stack[R.EXN_STACKHEIGHT++] = $ss101102;
}
if(R.isPyretException($e9798)) {
$e9798.pyretStack.push(L[5]);
}
throw $e9798;
}
var $ret103104 = $Hanf_begin_app_dropped84108($z99100,arr2292,make538);
++R.GAS;
return $ret103104;
};
var $Hanf_begin_app_dropped84108 = function(anf_begin_app_dropped82107,arr2292,make538) {
var $z124125 = D;
var $f130131 = function(_) {
return R.isFunction(make538.$var)?make538.$var.app(arr2292):R.ffi.throwNonFunApp(L[8],make538.$var,[arr2292]);
};
try {
if(--R.GAS > 0) {
$z124125 = $f130131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f130131,
"from":L[8]});
}
} catch($e122123) {
if(R.isCont($e122123)) {
var $ss126127 = {"from":L[8],
"go":function(ann_DASH_check_DASH_temp31132) {
return $Hann_DASH_check_DASH_temp83133(ann_DASH_check_DASH_temp31132);
}};
$e122123.stack[R.EXN_STACKHEIGHT++] = $ss126127;
}
if(R.isPyretException($e122123)) {
$e122123.pyretStack.push(L[8]);
}
throw $e122123;
}
var $ret128129 = $Hann_DASH_check_DASH_temp83133($z124125);
++R.GAS;
return $ret128129;
};
var $Hann_DASH_check_DASH_temp83133 = function(ann_DASH_check_DASH_temp31132) {
return ann_DASH_check_DASH_temp31132;
};
var $Hwhen_DASH_81121 = function(when_DASH_1120,arr2292,f2093,i24109,loop2395,_plus2,nothing4,raw_DASH_array_DASH_set8) {
var if_helper33145 = R.makeFunction(function(if_helper_arg34164) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
var ann_DASH_check_DASH_temp32165 = if_helper_arg34164;
return ann_DASH_check_DASH_temp32165;
});
var anf_if37163 = R.isBoolean(when_DASH_1120);
if(R.isPyretTrue(anf_if37163)) {
if(R.isPyretTrue(when_DASH_1120)) {
var $z136137 = D;
var $f142143 = function(_) {
return R.isFunction(f2093)?f2093.app(i24109):R.ffi.throwNonFunApp(L[9],f2093,[i24109]);
};
try {
if(--R.GAS > 0) {
$z136137 = $f142143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f142143,
"from":L[9]});
}
} catch($e134135) {
if(R.isCont($e134135)) {
var $ss138139 = {"from":L[9],
"go":function(anf_arg39144) {
return $Hanf_arg79146(anf_arg39144,arr2292,i24109,if_helper33145,loop2395,_plus2,nothing4,raw_DASH_array_DASH_set8);
}};
$e134135.stack[R.EXN_STACKHEIGHT++] = $ss138139;
}
if(R.isPyretException($e134135)) {
$e134135.pyretStack.push(L[9]);
}
throw $e134135;
}
var $ret140141 = $Hanf_arg79146($z136137,arr2292,i24109,if_helper33145,loop2395,_plus2,nothing4,raw_DASH_array_DASH_set8);
++R.GAS;
return $ret140141;
} else {
var $z149150 = D;
var $f155156 = function(_) {
return R.isFunction(if_helper33145)?if_helper33145.app(nothing4):R.ffi.throwNonFunApp(L[7],if_helper33145,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z149150 = $f155156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f155156,
"from":L[7]});
}
} catch($e147148) {
if(R.isCont($e147148)) {
var $ss151152 = {"from":L[7],
"go":function(cont_tail_app38157) {
return $Hcont_tail_app80158(cont_tail_app38157);
}};
$e147148.stack[R.EXN_STACKHEIGHT++] = $ss151152;
}
if(R.isPyretException($e147148)) {
$e147148.pyretStack.push(L[7]);
}
throw $e147148;
}
var $ret153154 = $Hcont_tail_app80158($z149150);
++R.GAS;
return $ret153154;
}
} else {
var cont_tail_arg35161 = R.throwNonBooleanCondition(L[10],("when"),when_DASH_1120);
if(--R.GAS > 0) {
$z159160 = R.isFunction(if_helper33145)?if_helper33145.app(cont_tail_arg35161):R.ffi.throwNonFunApp(L[10],if_helper33145,[cont_tail_arg35161]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored162) {
return R.isFunction(if_helper33145)?if_helper33145.app(cont_tail_arg35161):R.ffi.throwNonFunApp(L[10],if_helper33145,[cont_tail_arg35161]);
},
"from":L[10]});
}
++R.GAS;
return $z159160;
}
};
var $Hanf_arg79146 = function(anf_arg39144,arr2292,i24109,if_helper33145,loop2395,_plus2,nothing4,raw_DASH_array_DASH_set8) {
var $z168169 = D;
var $f174175 = function(_) {
return R.isFunction(raw_DASH_array_DASH_set8)?raw_DASH_array_DASH_set8.app(arr2292,i24109,anf_arg39144):R.ffi.throwNonFunApp(L[11],raw_DASH_array_DASH_set8,[arr2292,i24109,anf_arg39144]);
};
try {
if(--R.GAS > 0) {
$z168169 = $f174175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f174175,
"from":L[11]});
}
} catch($e166167) {
if(R.isCont($e166167)) {
var $ss170171 = {"from":L[11],
"go":function(anf_begin_app_dropped73176) {
return $Hanf_begin_app_dropped78177(anf_begin_app_dropped73176,i24109,if_helper33145,loop2395,_plus2,nothing4);
}};
$e166167.stack[R.EXN_STACKHEIGHT++] = $ss170171;
}
if(R.isPyretException($e166167)) {
$e166167.pyretStack.push(L[11]);
}
throw $e166167;
}
var $ret172173 = $Hanf_begin_app_dropped78177($z168169,i24109,if_helper33145,loop2395,_plus2,nothing4);
++R.GAS;
return $ret172173;
};
var $Hanf_begin_app_dropped78177 = function(anf_begin_app_dropped73176,i24109,if_helper33145,loop2395,_plus2,nothing4) {
var $z180181 = D;
var $f186187 = function(_) {
return R.isFunction(_plus2)?_plus2.app(i24109,(1)):R.ffi.throwNonFunApp(L[12],_plus2,[i24109,(1)]);
};
try {
if(--R.GAS > 0) {
$z180181 = $f186187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f186187,
"from":L[12]});
}
} catch($e178179) {
if(R.isCont($e178179)) {
var $ss182183 = {"from":L[12],
"go":function(anf_arg40188) {
return $Hanf_arg77189(anf_arg40188,if_helper33145,loop2395,nothing4);
}};
$e178179.stack[R.EXN_STACKHEIGHT++] = $ss182183;
}
if(R.isPyretException($e178179)) {
$e178179.pyretStack.push(L[12]);
}
throw $e178179;
}
var $ret184185 = $Hanf_arg77189($z180181,if_helper33145,loop2395,nothing4);
++R.GAS;
return $ret184185;
};
var $Hanf_arg77189 = function(anf_arg40188,if_helper33145,loop2395,nothing4) {
var $z192193 = D;
var $f198199 = function(_) {
return R.isFunction(loop2395.$var)?loop2395.$var.app(anf_arg40188):R.ffi.throwNonFunApp(L[13],loop2395.$var,[anf_arg40188]);
};
try {
if(--R.GAS > 0) {
$z192193 = $f198199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f198199,
"from":L[13]});
}
} catch($e190191) {
if(R.isCont($e190191)) {
var $ss194195 = {"from":L[13],
"go":function(anf_begin_app_dropped74200) {
return $Hanf_begin_app_dropped76201(anf_begin_app_dropped74200,if_helper33145,nothing4);
}};
$e190191.stack[R.EXN_STACKHEIGHT++] = $ss194195;
}
if(R.isPyretException($e190191)) {
$e190191.pyretStack.push(L[13]);
}
throw $e190191;
}
var $ret196197 = $Hanf_begin_app_dropped76201($z192193,if_helper33145,nothing4);
++R.GAS;
return $ret196197;
};
var $Hanf_begin_app_dropped76201 = function(anf_begin_app_dropped74200,if_helper33145,nothing4) {
var $z204205 = D;
var $f210211 = function(_) {
return R.isFunction(if_helper33145)?if_helper33145.app(nothing4):R.ffi.throwNonFunApp(L[7],if_helper33145,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z204205 = $f210211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f210211,
"from":L[7]});
}
} catch($e202203) {
if(R.isCont($e202203)) {
var $ss206207 = {"from":L[7],
"go":function(cont_tail_app41212) {
return $Hcont_tail_app75213(cont_tail_app41212);
}};
$e202203.stack[R.EXN_STACKHEIGHT++] = $ss206207;
}
if(R.isPyretException($e202203)) {
$e202203.pyretStack.push(L[7]);
}
throw $e202203;
}
var $ret208209 = $Hcont_tail_app75213($z204205);
++R.GAS;
return $ret208209;
};
var $Hcont_tail_app75213 = function(cont_tail_app41212) {
return cont_tail_app41212;
};
var $Hcont_tail_app80158 = function(cont_tail_app38157) {
return cont_tail_app38157;
};
var $Hann_DASH_check_DASH_temp72214 = function(ann_DASH_check_DASH_temp1215,Array320) {
return ann_DASH_check_DASH_temp1215;
};
var $Hanf_bracket71216 = function(anf_bracket22217,_plus2,tostring11) {
var anf_fun23228 = G(anf_bracket22217,"map",L[15]);
var $z220221 = D;
var $f226227 = function(_) {
return R.isFunction(anf_fun23228)?anf_fun23228.app(tostring11):R.ffi.throwNonFunApp(L[14],anf_fun23228,[tostring11]);
};
try {
if(--R.GAS > 0) {
$z220221 = $f226227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f226227,
"from":L[14]});
}
} catch($e218219) {
if(R.isCont($e218219)) {
var $ss222223 = {"from":L[14],
"go":function(anf_bracket24229) {
return $Hanf_bracket70230(anf_bracket24229,_plus2);
}};
$e218219.stack[R.EXN_STACKHEIGHT++] = $ss222223;
}
if(R.isPyretException($e218219)) {
$e218219.pyretStack.push(L[14]);
}
throw $e218219;
}
var $ret224225 = $Hanf_bracket70230($z220221,_plus2);
++R.GAS;
return $ret224225;
};
var $Hanf_bracket70230 = function(anf_bracket24229,_plus2) {
var anf_fun25241 = G(anf_bracket24229,"join-str",L[17]);
var $z233234 = D;
var $f239240 = function(_) {
return R.isFunction(anf_fun25241)?anf_fun25241.app((", ")):R.ffi.throwNonFunApp(L[16],anf_fun25241,[(", ")]);
};
try {
if(--R.GAS > 0) {
$z233234 = $f239240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f239240,
"from":L[16]});
}
} catch($e231232) {
if(R.isCont($e231232)) {
var $ss235236 = {"from":L[16],
"go":function(anf_arg26242) {
return $Hanf_arg69243(anf_arg26242,_plus2);
}};
$e231232.stack[R.EXN_STACKHEIGHT++] = $ss235236;
}
if(R.isPyretException($e231232)) {
$e231232.pyretStack.push(L[16]);
}
throw $e231232;
}
var $ret237238 = $Hanf_arg69243($z233234,_plus2);
++R.GAS;
return $ret237238;
};
var $Hanf_arg69243 = function(anf_arg26242,_plus2) {
var $z246247 = D;
var $f252253 = function(_) {
return R.isFunction(_plus2)?_plus2.app(("[array: "),anf_arg26242):R.ffi.throwNonFunApp(L[18],_plus2,[("[array: "),anf_arg26242]);
};
try {
if(--R.GAS > 0) {
$z246247 = $f252253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f252253,
"from":L[18]});
}
} catch($e244245) {
if(R.isCont($e244245)) {
var $ss248249 = {"from":L[18],
"go":function(anf_arg27254) {
return $Hanf_arg68255(anf_arg27254,_plus2);
}};
$e244245.stack[R.EXN_STACKHEIGHT++] = $ss248249;
}
if(R.isPyretException($e244245)) {
$e244245.pyretStack.push(L[18]);
}
throw $e244245;
}
var $ret250251 = $Hanf_arg68255($z246247,_plus2);
++R.GAS;
return $ret250251;
};
var $Hanf_arg68255 = function(anf_arg27254,_plus2) {
var $z258259 = D;
var $f264265 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg27254,("]")):R.ffi.throwNonFunApp(L[19],_plus2,[anf_arg27254,("]")]);
};
try {
if(--R.GAS > 0) {
$z258259 = $f264265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f264265,
"from":L[19]});
}
} catch($e256257) {
if(R.isCont($e256257)) {
var $ss260261 = {"from":L[19],
"go":function(ann_DASH_check_DASH_temp20266) {
return $Hann_DASH_check_DASH_temp67267(ann_DASH_check_DASH_temp20266);
}};
$e256257.stack[R.EXN_STACKHEIGHT++] = $ss260261;
}
if(R.isPyretException($e256257)) {
$e256257.pyretStack.push(L[19]);
}
throw $e256257;
}
var $ret262263 = $Hann_DASH_check_DASH_temp67267($z258259);
++R.GAS;
return $ret262263;
};
var $Hann_DASH_check_DASH_temp67267 = function(ann_DASH_check_DASH_temp20266) {
return ann_DASH_check_DASH_temp20266;
};
var $Hanf_bracket66268 = function(anf_bracket13269,_plus2,torepr10) {
var anf_fun14280 = G(anf_bracket13269,"map",L[21]);
var $z272273 = D;
var $f278279 = function(_) {
return R.isFunction(anf_fun14280)?anf_fun14280.app(torepr10):R.ffi.throwNonFunApp(L[20],anf_fun14280,[torepr10]);
};
try {
if(--R.GAS > 0) {
$z272273 = $f278279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f278279,
"from":L[20]});
}
} catch($e270271) {
if(R.isCont($e270271)) {
var $ss274275 = {"from":L[20],
"go":function(anf_bracket15281) {
return $Hanf_bracket65282(anf_bracket15281,_plus2);
}};
$e270271.stack[R.EXN_STACKHEIGHT++] = $ss274275;
}
if(R.isPyretException($e270271)) {
$e270271.pyretStack.push(L[20]);
}
throw $e270271;
}
var $ret276277 = $Hanf_bracket65282($z272273,_plus2);
++R.GAS;
return $ret276277;
};
var $Hanf_bracket65282 = function(anf_bracket15281,_plus2) {
var anf_fun16293 = G(anf_bracket15281,"join-str",L[23]);
var $z285286 = D;
var $f291292 = function(_) {
return R.isFunction(anf_fun16293)?anf_fun16293.app((", ")):R.ffi.throwNonFunApp(L[22],anf_fun16293,[(", ")]);
};
try {
if(--R.GAS > 0) {
$z285286 = $f291292();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f291292,
"from":L[22]});
}
} catch($e283284) {
if(R.isCont($e283284)) {
var $ss287288 = {"from":L[22],
"go":function(anf_arg17294) {
return $Hanf_arg64295(anf_arg17294,_plus2);
}};
$e283284.stack[R.EXN_STACKHEIGHT++] = $ss287288;
}
if(R.isPyretException($e283284)) {
$e283284.pyretStack.push(L[22]);
}
throw $e283284;
}
var $ret289290 = $Hanf_arg64295($z285286,_plus2);
++R.GAS;
return $ret289290;
};
var $Hanf_arg64295 = function(anf_arg17294,_plus2) {
var $z298299 = D;
var $f304305 = function(_) {
return R.isFunction(_plus2)?_plus2.app(("[array: "),anf_arg17294):R.ffi.throwNonFunApp(L[24],_plus2,[("[array: "),anf_arg17294]);
};
try {
if(--R.GAS > 0) {
$z298299 = $f304305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f304305,
"from":L[24]});
}
} catch($e296297) {
if(R.isCont($e296297)) {
var $ss300301 = {"from":L[24],
"go":function(anf_arg18306) {
return $Hanf_arg63307(anf_arg18306,_plus2);
}};
$e296297.stack[R.EXN_STACKHEIGHT++] = $ss300301;
}
if(R.isPyretException($e296297)) {
$e296297.pyretStack.push(L[24]);
}
throw $e296297;
}
var $ret302303 = $Hanf_arg63307($z298299,_plus2);
++R.GAS;
return $ret302303;
};
var $Hanf_arg63307 = function(anf_arg18306,_plus2) {
var $z310311 = D;
var $f316317 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg18306,("]")):R.ffi.throwNonFunApp(L[25],_plus2,[anf_arg18306,("]")]);
};
try {
if(--R.GAS > 0) {
$z310311 = $f316317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f316317,
"from":L[25]});
}
} catch($e308309) {
if(R.isCont($e308309)) {
var $ss312313 = {"from":L[25],
"go":function(ann_DASH_check_DASH_temp11318) {
return $Hann_DASH_check_DASH_temp62319(ann_DASH_check_DASH_temp11318);
}};
$e308309.stack[R.EXN_STACKHEIGHT++] = $ss312313;
}
if(R.isPyretException($e308309)) {
$e308309.pyretStack.push(L[25]);
}
throw $e308309;
}
var $ret314315 = $Hann_DASH_check_DASH_temp62319($z310311);
++R.GAS;
return $ret314315;
};
var $Hann_DASH_check_DASH_temp62319 = function(ann_DASH_check_DASH_temp11318) {
return ann_DASH_check_DASH_temp11318;
};
var $Hann_DASH_check_DASH_temp61320 = function(ann_DASH_check_DASH_temp9321) {
return ann_DASH_check_DASH_temp9321;
};
var $Hann_DASH_check_DASH_temp60322 = function(ann_DASH_check_DASH_temp7323) {
return ann_DASH_check_DASH_temp7323;
};
var $Hanf_begin_app_dropped59324 = function(anf_begin_app_dropped58325,self9326) {
var ann_DASH_check_DASH_temp5327 = self9326;
return ann_DASH_check_DASH_temp5327;
};
var $Hann_DASH_check_DASH_temp57328 = function(ann_DASH_check_DASH_temp3329) {
return ann_DASH_check_DASH_temp3329;
};
return R.loadModulesNew(NAMESPACE,[$lists11417],function($lists11417) {
var lists114 = R.getField($lists11417,"values");
var lists215 = R.getField($lists11417,"types");
return R.safeCall(function() {
var ArrayT4330 = R.namedBrander("Array");
var Array320 = R.makeBranderAnn(ArrayT4330,"Array");
var make538 = {"$var":D,
"$name":"make"};
var anf_assign30331 = R.makeFunction(function(arr6370) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[32],1,arguments);
}
return R.checkAnnArgs([$type$RawArray13],[arr6370],[L[43]],function() {
var anf_fun2381 = G(ArrayT4330,"brand",L[42]);
var anf_obj4383 = R.makeMethod(function($underscore7458) {
return function(ix8457) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[41],1,arguments);
}
var $z449450 = D;
var $f455456 = function(_) {
return R.isFunction(raw_DASH_array_DASH_get5)?raw_DASH_array_DASH_get5.app(arr6370,ix8457):R.ffi.throwNonFunApp(L[41],raw_DASH_array_DASH_get5,[arr6370,ix8457]);
};
try {
if(--R.GAS > 0) {
$z449450 = $f455456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f455456,
"from":L[41]});
}
} catch($e447448) {
if(R.isCont($e447448)) {
var $ss451452 = {"from":L[41],
"go":function(ann_DASH_check_DASH_temp3329) {
return $Hann_DASH_check_DASH_temp57328(ann_DASH_check_DASH_temp3329);
}};
$e447448.stack[R.EXN_STACKHEIGHT++] = $ss451452;
}
if(R.isPyretException($e447448)) {
$e447448.pyretStack.push(L[41]);
}
throw $e447448;
}
var $ret453454 = $Hann_DASH_check_DASH_temp57328($z449450);
++R.GAS;
return $ret453454;
};
},{"length":2});
var anf_obj6384 = R.makeMethod(function(self9326) {
return function(ix10445,val11446) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[40],2,arguments);
}
var $z437438 = D;
var $f443444 = function(_) {
return R.isFunction(raw_DASH_array_DASH_set8)?raw_DASH_array_DASH_set8.app(arr6370,ix10445,val11446):R.ffi.throwNonFunApp(L[39],raw_DASH_array_DASH_set8,[arr6370,ix10445,val11446]);
};
try {
if(--R.GAS > 0) {
$z437438 = $f443444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f443444,
"from":L[39]});
}
} catch($e435436) {
if(R.isCont($e435436)) {
var $ss439440 = {"from":L[39],
"go":function(anf_begin_app_dropped58325) {
return $Hanf_begin_app_dropped59324(anf_begin_app_dropped58325,self9326);
}};
$e435436.stack[R.EXN_STACKHEIGHT++] = $ss439440;
}
if(R.isPyretException($e435436)) {
$e435436.pyretStack.push(L[39]);
}
throw $e435436;
}
var $ret441442 = $Hanf_begin_app_dropped59324($z437438,self9326);
++R.GAS;
return $ret441442;
};
},{"length":3});
var anf_obj8385 = R.makeMethod(function($underscore12434) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[38],0,arguments);
}
var $z426427 = D;
var $f432433 = function(_) {
return R.isFunction(raw_DASH_array_DASH_length6)?raw_DASH_array_DASH_length6.app(arr6370):R.ffi.throwNonFunApp(L[38],raw_DASH_array_DASH_length6,[arr6370]);
};
try {
if(--R.GAS > 0) {
$z426427 = $f432433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f432433,
"from":L[38]});
}
} catch($e424425) {
if(R.isCont($e424425)) {
var $ss428429 = {"from":L[38],
"go":function(ann_DASH_check_DASH_temp7323) {
return $Hann_DASH_check_DASH_temp60322(ann_DASH_check_DASH_temp7323);
}};
$e424425.stack[R.EXN_STACKHEIGHT++] = $ss428429;
}
if(R.isPyretException($e424425)) {
$e424425.pyretStack.push(L[38]);
}
throw $e424425;
}
var $ret430431 = $Hann_DASH_check_DASH_temp60322($z426427);
++R.GAS;
return $ret430431;
};
},{"length":1});
var anf_obj10386 = R.makeMethod(function($underscore13423) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[37],0,arguments);
}
var $z415416 = D;
var $f421422 = function(_) {
return R.isFunction(raw_DASH_array_DASH_to_DASH_list9)?raw_DASH_array_DASH_to_DASH_list9.app(arr6370):R.ffi.throwNonFunApp(L[37],raw_DASH_array_DASH_to_DASH_list9,[arr6370]);
};
try {
if(--R.GAS > 0) {
$z415416 = $f421422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f421422,
"from":L[37]});
}
} catch($e413414) {
if(R.isCont($e413414)) {
var $ss417418 = {"from":L[37],
"go":function(ann_DASH_check_DASH_temp9321) {
return $Hann_DASH_check_DASH_temp61320(ann_DASH_check_DASH_temp9321);
}};
$e413414.stack[R.EXN_STACKHEIGHT++] = $ss417418;
}
if(R.isPyretException($e413414)) {
$e413414.pyretStack.push(L[37]);
}
throw $e413414;
}
var $ret419420 = $Hann_DASH_check_DASH_temp61320($z415416);
++R.GAS;
return $ret419420;
};
},{"length":1});
var anf_obj19387 = R.makeMethod(function(self14412) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[25],0,arguments);
}
var anf_fun12411 = G(self14412,"to-list",L[36]);
var $z403404 = D;
var $f409410 = function(_) {
return R.isFunction(anf_fun12411)?anf_fun12411.app():R.ffi.throwNonFunApp(L[35],anf_fun12411,[]);
};
try {
if(--R.GAS > 0) {
$z403404 = $f409410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f409410,
"from":L[35]});
}
} catch($e401402) {
if(R.isCont($e401402)) {
var $ss405406 = {"from":L[35],
"go":function(anf_bracket13269) {
return $Hanf_bracket66268(anf_bracket13269,_plus2,torepr10);
}};
$e401402.stack[R.EXN_STACKHEIGHT++] = $ss405406;
}
if(R.isPyretException($e401402)) {
$e401402.pyretStack.push(L[35]);
}
throw $e401402;
}
var $ret407408 = $Hanf_bracket66268($z403404,_plus2,torepr10);
++R.GAS;
return $ret407408;
};
},{"length":1});
var anf_obj28388 = R.makeMethod(function(self15400) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[19],0,arguments);
}
var anf_fun21399 = G(self15400,"to-list",L[34]);
var $z391392 = D;
var $f397398 = function(_) {
return R.isFunction(anf_fun21399)?anf_fun21399.app():R.ffi.throwNonFunApp(L[33],anf_fun21399,[]);
};
try {
if(--R.GAS > 0) {
$z391392 = $f397398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f397398,
"from":L[33]});
}
} catch($e389390) {
if(R.isCont($e389390)) {
var $ss393394 = {"from":L[33],
"go":function(anf_bracket22217) {
return $Hanf_bracket71216(anf_bracket22217,_plus2,tostring11);
}};
$e389390.stack[R.EXN_STACKHEIGHT++] = $ss393394;
}
if(R.isPyretException($e389390)) {
$e389390.pyretStack.push(L[33]);
}
throw $e389390;
}
var $ret395396 = $Hanf_bracket71216($z391392,_plus2,tostring11);
++R.GAS;
return $ret395396;
};
},{"length":1});
var anf_arg29382 = R.makeObject({"get":anf_obj4383,
"set":anf_obj6384,
"length":anf_obj8385,
"to-list":anf_obj10386,
"_torepr":anf_obj19387,
"tostring":anf_obj28388});
var $z373374 = D;
var $f379380 = function(_) {
return R.isFunction(anf_fun2381)?anf_fun2381.app(anf_arg29382):R.ffi.throwNonFunApp(L[32],anf_fun2381,[anf_arg29382]);
};
try {
if(--R.GAS > 0) {
$z373374 = $f379380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f379380,
"from":L[32]});
}
} catch($e371372) {
if(R.isCont($e371372)) {
var $ss375376 = {"from":L[32],
"go":function(ann_DASH_check_DASH_temp1215) {
return $Hann_DASH_check_DASH_temp72214(ann_DASH_check_DASH_temp1215,Array320);
}};
$e371372.stack[R.EXN_STACKHEIGHT++] = $ss375376;
}
if(R.isPyretException($e371372)) {
$e371372.pyretStack.push(L[32]);
}
throw $e371372;
}
var $ret377378 = $Hann_DASH_check_DASH_temp72214($z373374,Array320);
++R.GAS;
return $ret377378;
});
});
make538.$var = anf_assign30331;
var is_DASH_array16348 = G(ArrayT4330,"test",L[31]);
var build_DASH_array17332 = {"$var":D,
"$name":"build-array"};
var array_DASH_from_DASH_list18334 = {"$var":D,
"$name":"array-from-list"};
var anf_assign43333 = R.makeFunction(function(f2093,len2194) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[8],2,arguments);
}
return R.checkAnnArgs([R.Function,$type$Number12],[f2093,len2194],[L[29],L[30]],function() {
var $z362363 = D;
var $f368369 = function(_) {
return R.isFunction(raw_DASH_array_DASH_of7)?raw_DASH_array_DASH_of7.app(nothing4,len2194):R.ffi.throwNonFunApp(L[28],raw_DASH_array_DASH_of7,[nothing4,len2194]);
};
try {
if(--R.GAS > 0) {
$z362363 = $f368369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f368369,
"from":L[28]});
}
} catch($e360361) {
if(R.isCont($e360361)) {
var $ss364365 = {"from":L[28],
"go":function(arr2292) {
return $Harr8591(arr2292,f2093,len2194,make538,_lessthan1,_plus2,nothing4,raw_DASH_array_DASH_set8);
}};
$e360361.stack[R.EXN_STACKHEIGHT++] = $ss364365;
}
if(R.isPyretException($e360361)) {
$e360361.pyretStack.push(L[28]);
}
throw $e360361;
}
var $ret366367 = $Harr8591($z362363,f2093,len2194,make538,_lessthan1,_plus2,nothing4,raw_DASH_array_DASH_set8);
++R.GAS;
return $ret366367;
});
});
build_DASH_array17332.$var = anf_assign43333;
var anf_assign50335 = R.makeFunction(function(l2537) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
var anf_fun45359 = G(l2537,"length",L[27]);
var $z351352 = D;
var $f357358 = function(_) {
return R.isFunction(anf_fun45359)?anf_fun45359.app():R.ffi.throwNonFunApp(L[26],anf_fun45359,[]);
};
try {
if(--R.GAS > 0) {
$z351352 = $f357358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f357358,
"from":L[26]});
}
} catch($e349350) {
if(R.isCont($e349350)) {
var $ss353354 = {"from":L[26],
"go":function(anf_arg4636) {
return $Hanf_arg9135(anf_arg4636,l2537,lists114,make538,raw_DASH_array_DASH_of7,raw_DASH_array_DASH_set8);
}};
$e349350.stack[R.EXN_STACKHEIGHT++] = $ss353354;
}
if(R.isPyretException($e349350)) {
$e349350.pyretStack.push(L[26]);
}
throw $e349350;
}
var $ret355356 = $Hanf_arg9135($z351352,l2537,lists114,make538,raw_DASH_array_DASH_of7,raw_DASH_array_DASH_set8);
++R.GAS;
return $ret355356;
});
array_DASH_from_DASH_list18334.$var = anf_assign50335;
var anf_obj51347 = R.makeObject({"make":make538.$var});
var provides5221 = R.makeObject({"array":anf_obj51347,
"build-array":build_DASH_array17332.$var,
"array-from-list":array_DASH_from_DASH_list18334.$var,
"is-array":is_DASH_array16348});
var anf_fun53346 = G(builtins3,"current-checker",L[0]);
var $z338339 = D;
var $f344345 = function(_) {
return R.isFunction(anf_fun53346)?anf_fun53346.app():R.ffi.throwNonFunApp(L[0],anf_fun53346,[]);
};
try {
if(--R.GAS > 0) {
$z338339 = $f344345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f344345,
"from":L[0]});
}
} catch($e336337) {
if(R.isCont($e336337)) {
var $ss340341 = {"from":L[0],
"go":function(anf_bracket5419) {
return $Hanf_bracket9318(anf_bracket5419,Array320,provides5221,nothing4);
}};
$e336337.stack[R.EXN_STACKHEIGHT++] = $ss340341;
}
if(R.isPyretException($e336337)) {
$e336337.pyretStack.push(L[0]);
}
throw $e336337;
}
var $ret342343 = $Hanf_bracket9318($z338339,Array320,provides5221,nothing4);
++R.GAS;
return $ret342343;
},function(moduleVal) {
R.modules["$src/arr/base/arrays.arr16"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/sets',["trove/lists",
"trove/error",
"trove/option",
"trove/arrays"],function($lists12130,$error32231,$option52332,$arrays72433) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/base/sets.arr29"]) {
return R.modules["$src/arr/base/sets.arr29"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/base/sets.arr";
var D = R.undefined;
var L = [[M,14,18,214,14,32,228],
[M,34,0,531,100,3,3135],
[M,376,0,10102,381,3,10257],
[M,370,0,9958,374,3,10100],
[M,359,0,9706,362,3,9839],
[M,354,0,9570,357,3,9704],
[M,330,6,9043,330,14,9051],
[M,321,4,8736,331,7,9070],
[M,325,10,8966,325,28,8984],
[M,325,10,8966,325,22,8978],
[M,327,10,9009,327,15,9014],
[M,324,11,8937,324,28,8954],
[M,318,6,8698,318,14,8706],
[M,309,4,8457,319,7,8725],
[M,313,12,8612,313,17,8617],
[M,315,12,8647,315,30,8665],
[M,315,12,8647,315,24,8659],
[M,312,13,8580,312,31,8598],
[M,306,6,8419,306,14,8427],
[M,301,4,8265,307,7,8446],
[M,293,6,8087,293,14,8095],
[M,291,4,7985,294,7,8128],
[M,288,6,7933,288,14,7941],
[M,286,4,7827,289,7,7974],
[M,272,6,7491,278,9,7667],
[M,271,4,7470,279,7,7675],
[M,274,24,7570,274,36,7582],
[M,275,29,7612,275,41,7624],
[M,275,16,7599,275,41,7624],
[M,263,6,7277,269,9,7456],
[M,262,4,7255,270,7,7464],
[M,265,24,7355,265,38,7369],
[M,266,29,7399,266,43,7413],
[M,266,16,7386,266,43,7413],
[M,261,2,7216,331,7,9070],
[M,253,10,7133,253,24,7147],
[M,253,10,7133,253,18,7141],
[M,255,10,7172,255,11,7173],
[M,252,11,7103,252,29,7121],
[M,242,10,6849,242,11,6850],
[M,244,10,6875,244,24,6889],
[M,244,10,6875,244,18,6883],
[M,241,11,6819,241,29,6837],
[M,223,6,6263,223,14,6271],
[M,221,4,6161,224,7,6321],
[M,215,8,6075,215,12,6079],
[M,217,17,6109,217,39,6131],
[M,217,28,6120,217,38,6130],
[M,214,8,6039,214,34,6065],
[M,212,30,5957,212,33,5960],
[M,217,8,6100,217,16,6108],
[M,217,8,6100,217,40,6132],
[M,198,6,5596,204,9,5773],
[M,197,4,5575,205,7,5781],
[M,200,24,5676,200,36,5688],
[M,201,16,5705,201,41,5730],
[M,189,6,5381,195,9,5561],
[M,188,4,5359,196,7,5569],
[M,191,24,5460,191,38,5474],
[M,192,16,5491,192,43,5518],
[M,187,2,5317,258,7,7203],
[M,342,20,9334,342,34,9348],
[M,342,20,9334,342,32,9346],
[M,342,4,9318,342,68,9382],
[M,342,4,9318,342,14,9328],
[M,342,20,9334,342,41,9355],
[M,342,20,9334,342,39,9353],
[M,342,45,9359,342,60,9374],
[M,342,45,9359,342,58,9372],
[M,342,45,9359,342,67,9381],
[M,342,45,9359,342,65,9379],
[M,342,18,9332,342,68,9382],
[M,338,33,9257,338,54,9278],
[M,338,33,9257,338,47,9271],
[M,338,4,9228,338,32,9256],
[M,336,2,9095,339,5,9285],
[M,182,6,5239,182,46,5279],
[M,182,36,5269,182,45,5278],
[M,181,21,5206,181,46,5231],
[M,181,12,5197,183,17,5298],
[M,183,6,5287,183,16,5297],
[M,163,0,4638,184,3,5303],
[M,175,10,5061,175,14,5065],
[M,177,40,5120,177,76,5156],
[M,174,11,5035,174,25,5049],
[M,177,20,5100,177,77,5157],
[M,177,10,5090,177,78,5158],
[M,167,53,4827,167,54,4828],
[M,167,61,4835,167,76,4850],
[M,167,37,4811,167,51,4825],
[M,149,7,4461,149,26,4480],
[M,149,15,4469,149,25,4479],
[M,155,7,4543,155,26,4562],
[M,155,15,4551,155,25,4561],
[M,148,5,4434,148,23,4452],
[M,150,6,4488,150,10,4492],
[M,152,6,4509,152,16,4519],
[M,156,6,4570,156,15,4579],
[M,158,6,4596,158,22,4612],
[M,158,6,4596,158,28,4618],
[M,127,2,3963,127,26,3987],
[M,127,7,3968,127,24,3985],
[M,127,7,3968,127,17,3978],
[M,128,13,4001,128,21,4009],
[M,128,5,3993,128,21,4009],
[M,128,5,3993,128,27,4015],
[M,129,4,4020,129,8,4024],
[M,130,11,4036,130,19,4044],
[M,131,7,4058,131,30,4081],
[M,131,7,4058,131,28,4079],
[M,131,7,4058,131,21,4072],
[M,131,7,4058,131,16,4067],
[M,136,11,4185,136,19,4193],
[M,130,9,4034,130,25,4050],
[M,131,34,4085,131,58,4109],
[M,131,34,4085,131,56,4107],
[M,131,34,4085,131,49,4100],
[M,131,34,4085,131,43,4094],
[M,131,7,4058,131,59,4110],
[M,132,6,4117,132,21,4132],
[M,134,6,4149,134,22,4165],
[M,137,7,4207,137,32,4232],
[M,137,7,4207,137,30,4230],
[M,137,7,4207,137,23,4223],
[M,137,7,4207,137,17,4217],
[M,143,4,4339,143,48,4383],
[M,136,9,4183,136,25,4199],
[M,137,36,4236,137,60,4260],
[M,137,36,4236,137,58,4258],
[M,137,36,4236,137,51,4251],
[M,137,36,4236,137,46,4246],
[M,137,7,4207,137,61,4261],
[M,138,6,4268,138,23,4285],
[M,140,6,4302,140,22,4318],
[M,124,6,3869,124,64,3927],
[M,124,50,3913,124,63,3926],
[M,124,50,3913,124,57,3920],
[M,124,30,3893,124,48,3911],
[M,124,30,3893,124,42,3905],
[M,124,30,3893,124,37,3900],
[M,124,15,3878,124,28,3891],
[M,124,15,3878,124,22,3885],
[M,121,2,3759,125,5,3934],
[M,119,6,3703,119,52,3749],
[M,119,44,3741,119,51,3748],
[M,119,24,3721,119,42,3739],
[M,119,24,3721,119,36,3733],
[M,119,24,3721,119,30,3727],
[M,119,15,3712,119,22,3719],
[M,116,2,3583,120,5,3756],
[M,113,2,3471,115,5,3580],
[M,114,69,3560,114,82,3573],
[M,114,69,3560,114,76,3567],
[M,110,2,3363,112,5,3468],
[M,106,37,3290,106,51,3304],
[M,106,37,3290,106,49,3302],
[M,106,14,3267,106,52,3305],
[M,106,14,3267,106,57,3310],
[M,105,0,3192,107,3,3327],
[M,90,25,2862,90,63,2900],
[M,87,4,2690,91,7,2909],
[M,85,30,2628,85,52,2650],
[M,85,30,2628,85,50,2648],
[M,85,30,2628,85,40,2638],
[M,85,6,2604,85,78,2676],
[M,85,55,2653,85,78,2676],
[M,85,60,2658,85,70,2668],
[M,83,4,2496,86,7,2684],
[M,81,45,2461,81,65,2481],
[M,81,45,2461,81,63,2479],
[M,81,45,2461,81,55,2471],
[M,81,33,2449,81,43,2459],
[M,81,28,2444,81,66,2482],
[M,79,4,2318,82,7,2490],
[M,77,46,2282,77,67,2303],
[M,77,46,2282,77,65,2301],
[M,77,46,2282,77,56,2292],
[M,77,23,2259,77,68,2304],
[M,75,4,2136,78,7,2312],
[M,68,28,1901,68,45,1918],
[M,70,39,1990,70,60,2011],
[M,70,39,1990,70,55,2006],
[M,70,39,1990,70,48,1999],
[M,70,27,1978,70,37,1988],
[M,72,50,2088,72,72,2110],
[M,72,50,2088,72,67,2105],
[M,72,50,2088,72,60,2098],
[M,72,39,2077,72,48,2086],
[M,72,27,2065,72,37,2075],
[M,69,14,1933,69,31,1950],
[M,70,18,1969,70,26,1977],
[M,70,18,1969,70,73,2024],
[M,70,62,2013,70,72,2023],
[M,70,8,1959,70,17,1968],
[M,70,8,1959,70,74,2025],
[M,72,18,2056,72,26,2064],
[M,72,18,2056,72,73,2111],
[M,72,8,2046,72,17,2055],
[M,72,8,2046,72,74,2112],
[M,59,28,1518,59,64,1554],
[M,61,39,1626,61,60,1647],
[M,61,39,1626,61,55,1642],
[M,61,39,1626,61,48,1635],
[M,61,27,1614,61,37,1624],
[M,63,50,1724,63,72,1746],
[M,63,50,1724,63,67,1741],
[M,63,50,1724,63,60,1734],
[M,63,39,1713,63,48,1722],
[M,63,27,1701,63,37,1711],
[M,60,14,1569,60,31,1586],
[M,61,18,1605,61,26,1613],
[M,61,18,1605,61,73,1660],
[M,61,62,1649,61,72,1659],
[M,61,8,1595,61,17,1604],
[M,61,8,1595,61,74,1661],
[M,63,18,1692,63,26,1700],
[M,63,18,1692,63,73,1747],
[M,63,8,1682,63,17,1691],
[M,63,8,1682,63,74,1748],
[M,53,32,1302,53,55,1325],
[M,53,32,1302,53,50,1320],
[M,53,32,1302,53,41,1311],
[M,54,12,1338,54,36,1362],
[M,54,12,1338,54,31,1357],
[M,54,12,1338,54,22,1348],
[M,53,14,1284,53,31,1301],
[M,45,2,948,91,7,2909],
[M,35,2,547,43,33,940],
[M,98,24,3091,98,38,3105],
[M,98,24,3091,98,36,3103],
[M,98,4,3071,98,58,3125],
[M,98,4,3071,98,18,3085],
[M,98,42,3109,98,57,3124],
[M,98,42,3109,98,55,3122],
[M,98,22,3089,98,58,3125],
[M,13,18,179,13,33,194],
[M,377,2,10149,379,5,10236],
[M,377,9,10156,379,5,10236],
[M,378,4,10217,378,12,10225],
[M,376,27,10129,376,35,10137],
[M,371,29,10032,371,44,10047],
[M,371,2,10005,373,5,10096],
[M,372,4,10078,372,10,10084],
[M,370,27,9985,370,35,9993],
[M,364,0,9841,368,3,9956],
[M,365,2,9880,367,5,9952],
[M,366,4,9930,366,15,9941],
[M,365,6,9884,365,16,9894],
[M,364,24,9865,364,34,9875],
[M,361,19,9820,361,33,9834],
[M,359,28,9734,359,38,9744],
[M,356,19,9684,356,34,9699],
[M,354,28,9598,354,38,9608],
[M,347,0,9397,352,3,9568],
[M,349,2,9495,351,5,9564],
[M,350,4,9547,350,9,9552],
[M,349,6,9499,349,16,9509],
[M,347,23,9420,347,33,9430],
[M,347,47,9444,347,50,9447],
[M,186,0,5305,345,3,9395],
[M,187,4,5319,187,33,5348],
[M,187,22,5337,187,32,5347],
[M,261,4,7218,261,30,7244],
[M,261,22,7236,261,29,7243],
[M,323,6,8853,329,9,9036],
[M,323,65,8912,323,76,8923],
[M,323,43,8890,323,53,8900],
[M,323,18,8865,329,9,9036],
[M,324,11,8937,324,22,8948],
[M,321,23,8755,321,26,8758],
[M,321,37,8769,321,40,8772],
[M,310,6,8487,317,11,8691],
[M,311,55,8554,311,65,8564],
[M,311,33,8532,311,43,8542],
[M,311,8,8507,317,11,8691],
[M,312,13,8580,312,25,8592],
[M,302,6,8291,305,11,8412],
[M,303,55,8358,303,66,8369],
[M,303,33,8336,303,43,8346],
[M,303,8,8311,305,11,8412],
[M,304,10,8382,304,22,8394],
[M,296,4,8139,299,7,8254],
[M,298,6,8226,298,24,8244],
[M,298,6,8226,298,16,8236],
[M,293,15,8096,293,38,8119],
[M,293,15,8096,293,32,8113],
[M,293,15,8096,293,25,8106],
[M,288,15,7942,288,38,7965],
[M,288,15,7942,288,32,7959],
[M,288,15,7942,288,25,7952],
[M,281,4,7686,284,7,7816],
[M,283,6,7783,283,25,7802],
[M,283,6,7783,283,16,7793],
[M,273,6,7514,277,16,7655],
[M,273,22,7530,277,11,7650],
[M,274,13,7559,274,23,7569],
[M,273,6,7514,273,21,7529],
[M,273,6,7514,273,16,7524],
[M,264,6,7299,268,16,7444],
[M,264,22,7315,268,11,7439],
[M,265,13,7344,265,23,7354],
[M,264,6,7299,264,21,7314],
[M,264,6,7299,264,16,7309],
[M,261,13,7227,261,29,7243],
[M,249,4,6930,258,7,7203],
[M,251,38,7079,251,48,7089],
[M,251,6,7047,257,9,7195],
[M,252,11,7103,252,23,7115],
[M,249,23,6949,249,26,6952],
[M,249,37,6963,249,40,6966],
[M,238,4,6645,247,7,6919],
[M,240,38,6795,240,48,6805],
[M,240,6,6763,246,9,6911],
[M,241,11,6819,241,23,6831],
[M,238,22,6663,238,25,6666],
[M,238,36,6677,238,39,6680],
[M,231,4,6444,236,7,6634],
[M,233,38,6583,233,49,6594],
[M,233,6,6551,235,9,6626],
[M,234,8,6605,234,13,6610],
[M,231,18,6458,231,21,6461],
[M,231,32,6472,231,35,6475],
[M,228,6,6419,228,16,6429],
[M,226,21,6349,226,31,6359],
[M,226,4,6332,229,7,6437],
[M,223,15,6272,223,55,6312],
[M,223,33,6290,223,54,6311],
[M,223,15,6272,223,32,6289],
[M,223,15,6272,223,25,6282],
[M,214,10,6041,214,27,6058],
[M,214,10,6041,214,20,6051],
[M,212,4,5931,219,7,6150],
[M,207,4,5792,210,7,5920],
[M,209,6,5889,209,23,5906],
[M,209,6,5889,209,16,5899],
[M,199,6,5619,203,16,5761],
[M,199,23,5636,203,11,5756],
[M,201,16,5705,201,28,5717],
[M,200,13,5665,200,23,5675],
[M,199,6,5619,199,22,5635],
[M,199,6,5619,199,16,5629],
[M,190,6,5403,194,16,5549],
[M,190,23,5420,194,11,5544],
[M,192,16,5491,192,30,5505],
[M,191,13,5449,191,23,5459],
[M,190,6,5403,190,22,5419],
[M,190,6,5403,190,16,5413],
[M,187,13,5328,187,32,5347],
[M,342,4,9318,342,7,9321],
[M,341,2,9292,343,5,9388],
[M,338,4,9228,338,21,9245],
[M,338,4,9228,338,14,9238],
[M,336,31,9124,336,34,9127],
[M,336,45,9138,336,48,9141],
[M,181,21,5206,181,40,5225],
[M,181,30,5215,181,39,5224],
[M,170,2,4871,180,5,5184],
[M,171,4,4913,179,7,5178],
[M,173,6,4991,178,11,5170],
[M,172,6,4937,172,53,4984],
[M,164,2,4679,169,5,4868],
[M,165,4,4700,168,7,4862],
[M,167,6,4780,167,80,4854],
[M,166,6,4724,166,55,4773],
[M,163,29,4667,163,36,4674],
[M,147,0,4395,161,3,4636],
[M,148,13,4442,148,22,4451],
[M,147,24,4419,147,31,4426],
[M,109,0,3329,145,3,4393],
[M,126,2,3937,126,25,3960],
[M,126,7,3942,126,23,3958],
[M,126,7,3942,126,16,3951],
[M,123,6,3817,123,50,3861],
[M,123,32,3843,123,49,3860],
[M,123,32,3843,123,44,3855],
[M,123,32,3843,123,39,3850],
[M,123,24,3835,123,30,3841],
[M,123,15,3826,123,22,3833],
[M,122,13,3791,122,31,3809],
[M,122,13,3791,122,25,3803],
[M,122,13,3791,122,20,3798],
[M,118,6,3641,118,60,3695],
[M,118,42,3677,118,59,3694],
[M,118,42,3677,118,54,3689],
[M,118,42,3677,118,48,3683],
[M,118,29,3664,118,40,3675],
[M,118,29,3664,118,35,3670],
[M,118,15,3650,118,27,3662],
[M,118,15,3650,118,21,3656],
[M,117,13,3615,117,31,3633],
[M,117,13,3615,117,25,3627],
[M,117,13,3615,117,19,3621],
[M,114,28,3519,114,67,3558],
[M,114,54,3545,114,66,3557],
[M,114,54,3545,114,61,3552],
[M,114,46,3537,114,52,3543],
[M,114,37,3528,114,44,3535],
[M,114,13,3504,114,26,3517],
[M,114,13,3504,114,20,3511],
[M,111,40,3421,111,80,3461],
[M,111,72,3453,111,79,3460],
[M,111,58,3439,111,70,3451],
[M,111,58,3439,111,64,3445],
[M,111,49,3430,111,56,3437],
[M,111,27,3408,111,38,3419],
[M,111,27,3408,111,33,3414],
[M,111,13,3394,111,25,3406],
[M,111,13,3394,111,19,3400],
[M,109,22,3351,109,29,3358],
[M,106,22,3275,106,35,3288],
[M,106,22,3275,106,33,3286],
[M,105,33,3225,105,40,3232],
[M,105,51,3243,105,58,3250],
[M,102,0,3137,102,52,3189],
[M,102,30,3167,102,39,3176],
[M,45,4,950,45,72,1018],
[M,45,30,976,45,36,982],
[M,45,46,992,45,53,999],
[M,45,64,1010,45,71,1017],
[M,90,43,2880,90,62,2899],
[M,90,51,2888,90,61,2898],
[M,90,25,2862,90,39,2876],
[M,90,25,2862,90,34,2871],
[M,90,6,2843,90,21,2858],
[M,90,6,2843,90,16,2853],
[M,85,6,2604,85,27,2625],
[M,85,6,2604,85,25,2623],
[M,85,6,2604,85,15,2613],
[M,81,6,2422,81,25,2441],
[M,81,6,2422,81,23,2439],
[M,81,6,2422,81,15,2431],
[M,77,23,2259,77,43,2279],
[M,77,23,2259,77,41,2277],
[M,77,23,2259,77,32,2268],
[M,77,11,2247,77,21,2257],
[M,68,28,1901,68,39,1912],
[M,69,6,1925,70,74,2025],
[M,69,20,1939,69,30,1949],
[M,68,9,1882,68,27,1900],
[M,66,32,1800,66,39,1807],
[M,68,16,1889,68,26,1899],
[M,66,4,1772,74,7,2130],
[M,59,28,1518,59,36,1526],
[M,59,53,1543,59,63,1553],
[M,59,42,1532,59,51,1541],
[M,60,6,1561,61,74,1661],
[M,60,20,1575,60,30,1585],
[M,59,9,1499,59,27,1517],
[M,57,32,1414,57,39,1421],
[M,59,16,1506,59,26,1516],
[M,57,4,1386,65,7,1766],
[M,52,28,1265,52,32,1269],
[M,53,6,1276,53,55,1325],
[M,53,20,1290,53,30,1300],
[M,52,9,1246,52,27,1264],
[M,50,34,1152,50,41,1159],
[M,52,16,1253,52,26,1263],
[M,50,4,1122,56,7,1380],
[M,48,6,1102,48,12,1108],
[M,46,20,1045,46,26,1051],
[M,46,4,1029,49,7,1116],
[M,45,55,1001,45,71,1017],
[M,45,38,984,45,53,999],
[M,45,25,971,45,36,982],
[M,45,11,957,45,23,969],
[M,43,4,911,43,33,940],
[M,42,23,884,42,33,894],
[M,42,4,865,42,44,905],
[M,41,21,838,41,31,848],
[M,41,4,821,41,42,859],
[M,40,22,794,40,32,804],
[M,40,4,776,40,43,815],
[M,39,41,762,39,45,766],
[M,39,32,753,39,39,760],
[M,39,4,725,39,49,770],
[M,38,41,690,38,49,698],
[M,38,55,704,38,59,708],
[M,38,61,710,38,65,714],
[M,38,4,653,38,70,719],
[M,37,34,629,37,41,636],
[M,37,4,599,37,52,647],
[M,36,20,580,36,26,586],
[M,36,4,564,36,33,593],
[M,98,4,3071,98,11,3078],
[M,97,2,3045,99,5,3131],
[M,93,2,2921,96,5,3041],
[M,95,4,3021,95,16,3033],
[M,29,7,510,29,17,520],
[M,28,11,488,28,25,502],
[M,27,7,466,27,17,476],
[M,26,8,447,26,19,458],
[M,25,7,428,25,17,438]];
var _greaterequal5 = NAMESPACE.get("_greaterequal");
var _lessequal6 = NAMESPACE.get("_lessequal");
var _lessthan7 = NAMESPACE.get("_lessthan");
var _minus8 = NAMESPACE.get("_minus");
var _plus9 = NAMESPACE.get("_plus");
var builtins10 = NAMESPACE.get("builtins");
var nothing11 = NAMESPACE.get("nothing");
var num_DASH_abs12 = NAMESPACE.get("num-abs");
var num_DASH_max13 = NAMESPACE.get("num-max");
var raise14 = NAMESPACE.get("raise");
var raw_DASH_array_DASH_fold15 = NAMESPACE.get("raw-array-fold");
var torepr16 = NAMESPACE.get("torepr");
var tostring17 = NAMESPACE.get("tostring");
var $type$Boolean18 = NAMESPACE.get("$type$Boolean");
var $type$Number19 = NAMESPACE.get("$type$Number");
var $type$RawArray20 = NAMESPACE.get("$type$RawArray");
var $Hanf_obj93434 = function(anf_obj70835,AVLTree936,Set1137,anf_obj70538,anf_obj70639,anf_obj70740,leaf2241,list_DASH_to_DASH_list_DASH_set3842,list_DASH_to_DASH_tree_DASH_set3943,tree_DASH_set3644,builtins10,nothing11) {
var $z4748 = D;
var $f5354 = function(_) {
return R.isFunction(tree_DASH_set3644.$var)?tree_DASH_set3644.$var.app(leaf2241.$var):R.ffi.throwNonFunApp(L[0],tree_DASH_set3644.$var,[leaf2241.$var]);
};
try {
if(--R.GAS > 0) {
$z4748 = $f5354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5354,
"from":L[0]});
}
} catch($e4546) {
if(R.isCont($e4546)) {
var $ss4950 = {"from":L[0],
"go":function(anf_obj70955) {
return $Hanf_obj93356(anf_obj70955,AVLTree936,Set1137,anf_obj70538,anf_obj70639,anf_obj70740,anf_obj70835,list_DASH_to_DASH_list_DASH_set3842,list_DASH_to_DASH_tree_DASH_set3943,builtins10,nothing11);
}};
$e4546.stack[R.EXN_STACKHEIGHT++] = $ss4950;
}
if(R.isPyretException($e4546)) {
$e4546.pyretStack.push(L[0]);
}
throw $e4546;
}
var $ret5152 = $Hanf_obj93356($z4748,AVLTree936,Set1137,anf_obj70538,anf_obj70639,anf_obj70740,anf_obj70835,list_DASH_to_DASH_list_DASH_set3842,list_DASH_to_DASH_tree_DASH_set3943,builtins10,nothing11);
++R.GAS;
return $ret5152;
};
var $Hanf_obj93356 = function(anf_obj70955,AVLTree936,Set1137,anf_obj70538,anf_obj70639,anf_obj70740,anf_obj70835,list_DASH_to_DASH_list_DASH_set3842,list_DASH_to_DASH_tree_DASH_set3943,builtins10,nothing11) {
var provides71069 = R.makeObject({"set":anf_obj70538,
"list-set":anf_obj70639,
"tree-set":anf_obj70740,
"empty-list-set":anf_obj70835,
"empty-tree-set":anf_obj70955,
"list-to-list-set":list_DASH_to_DASH_list_DASH_set3842.$var,
"list-to-tree-set":list_DASH_to_DASH_tree_DASH_set3943.$var});
var anf_fun71167 = G(builtins10,"current-checker",L[1]);
var $z5960 = D;
var $f6566 = function(_) {
return R.isFunction(anf_fun71167)?anf_fun71167.app():R.ffi.throwNonFunApp(L[1],anf_fun71167,[]);
};
try {
if(--R.GAS > 0) {
$z5960 = $f6566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6566,
"from":L[1]});
}
} catch($e5758) {
if(R.isCont($e5758)) {
var $ss6162 = {"from":L[1],
"go":function(anf_bracket71268) {
return $Hanf_bracket93270(anf_bracket71268,AVLTree936,Set1137,provides71069,nothing11);
}};
$e5758.stack[R.EXN_STACKHEIGHT++] = $ss6162;
}
if(R.isPyretException($e5758)) {
$e5758.pyretStack.push(L[1]);
}
throw $e5758;
}
var $ret6364 = $Hanf_bracket93270($z5960,AVLTree936,Set1137,provides71069,nothing11);
++R.GAS;
return $ret6364;
};
var $Hanf_bracket93270 = function(anf_bracket71268,AVLTree936,Set1137,provides71069,nothing11) {
var anf_fun71381 = G(anf_bracket71268,"results",L[1]);
var $z7374 = D;
var $f7980 = function(_) {
return R.isFunction(anf_fun71381)?anf_fun71381.app():R.ffi.throwNonFunApp(L[1],anf_fun71381,[]);
};
try {
if(--R.GAS > 0) {
$z7374 = $f7980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7980,
"from":L[1]});
}
} catch($e7172) {
if(R.isCont($e7172)) {
var $ss7576 = {"from":L[1],
"go":function(checks71482) {
return $Hchecks93183(checks71482,AVLTree936,Set1137,provides71069,nothing11);
}};
$e7172.stack[R.EXN_STACKHEIGHT++] = $ss7576;
}
if(R.isPyretException($e7172)) {
$e7172.pyretStack.push(L[1]);
}
throw $e7172;
}
var $ret7778 = $Hchecks93183($z7374,AVLTree936,Set1137,provides71069,nothing11);
++R.GAS;
return $ret7778;
};
var $Hchecks93183 = function(checks71482,AVLTree936,Set1137,provides71069,nothing11) {
return R.makeObject({"answer":nothing11,
"provide-plus-types":R.makeObject({"values":provides71069,
"types":{"AVLTree":AVLTree936,
"Set":Set1137}}),
"checks":checks71482});
};
var $Htree93084 = function(tree18185,Set1137,tree_DASH_set3644) {
var $z8889 = D;
var $f9495 = function(_) {
return R.isFunction(tree_DASH_set3644.$var)?tree_DASH_set3644.$var.app(tree18185):R.ffi.throwNonFunApp(L[2],tree_DASH_set3644.$var,[tree18185]);
};
try {
if(--R.GAS > 0) {
$z8889 = $f9495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9495,
"from":L[2]});
}
} catch($e8687) {
if(R.isCont($e8687)) {
var $ss9091 = {"from":L[2],
"go":function(ann_DASH_check_DASH_temp70096) {
return $Hann_DASH_check_DASH_temp92997(ann_DASH_check_DASH_temp70096,Set1137);
}};
$e8687.stack[R.EXN_STACKHEIGHT++] = $ss9091;
}
if(R.isPyretException($e8687)) {
$e8687.pyretStack.push(L[2]);
}
throw $e8687;
}
var $ret9293 = $Hann_DASH_check_DASH_temp92997($z8889,Set1137);
++R.GAS;
return $ret9293;
};
var $Hann_DASH_check_DASH_temp92997 = function(ann_DASH_check_DASH_temp70096,Set1137) {
return ann_DASH_check_DASH_temp70096;
};
var $Hann_DASH_check_DASH_temp92898 = function(ann_DASH_check_DASH_temp70199) {
return ann_DASH_check_DASH_temp70199;
};
var $Hanf_arg927100 = function(anf_arg698101,Set1137,anf_arg697102,arr176103,raw_DASH_array_DASH_fold15) {
var $z106107 = D;
var $f112113 = function(_) {
return R.isFunction(raw_DASH_array_DASH_fold15)?raw_DASH_array_DASH_fold15.app(anf_arg697102,anf_arg698101,arr176103,(0)):R.ffi.throwNonFunApp(L[3],raw_DASH_array_DASH_fold15,[anf_arg697102,anf_arg698101,arr176103,(0)]);
};
try {
if(--R.GAS > 0) {
$z106107 = $f112113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f112113,
"from":L[3]});
}
} catch($e104105) {
if(R.isCont($e104105)) {
var $ss108109 = {"from":L[3],
"go":function(ann_DASH_check_DASH_temp694114) {
return $Hann_DASH_check_DASH_temp926115(ann_DASH_check_DASH_temp694114,Set1137);
}};
$e104105.stack[R.EXN_STACKHEIGHT++] = $ss108109;
}
if(R.isPyretException($e104105)) {
$e104105.pyretStack.push(L[3]);
}
throw $e104105;
}
var $ret110111 = $Hann_DASH_check_DASH_temp926115($z106107,Set1137);
++R.GAS;
return $ret110111;
};
var $Hann_DASH_check_DASH_temp926115 = function(ann_DASH_check_DASH_temp694114,Set1137) {
return ann_DASH_check_DASH_temp694114;
};
var $Hann_DASH_check_DASH_temp925116 = function(ann_DASH_check_DASH_temp695117) {
return ann_DASH_check_DASH_temp695117;
};
var $Hann_DASH_check_DASH_temp924118 = function(ann_DASH_check_DASH_temp688119) {
return ann_DASH_check_DASH_temp688119;
};
var $Hann_DASH_check_DASH_temp923120 = function(ann_DASH_check_DASH_temp690121) {
return ann_DASH_check_DASH_temp690121;
};
var $Hanf_arg922122 = function(anf_arg686123,Set1137,list_DASH_to_DASH_set37124,lst172125) {
var $z128129 = D;
var $f134135 = function(_) {
return R.isFunction(list_DASH_to_DASH_set37124.$var)?list_DASH_to_DASH_set37124.$var.app(lst172125,anf_arg686123):R.ffi.throwNonFunApp(L[4],list_DASH_to_DASH_set37124.$var,[lst172125,anf_arg686123]);
};
try {
if(--R.GAS > 0) {
$z128129 = $f134135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f134135,
"from":L[4]});
}
} catch($e126127) {
if(R.isCont($e126127)) {
var $ss130131 = {"from":L[4],
"go":function(ann_DASH_check_DASH_temp685136) {
return $Hann_DASH_check_DASH_temp921137(ann_DASH_check_DASH_temp685136,Set1137);
}};
$e126127.stack[R.EXN_STACKHEIGHT++] = $ss130131;
}
if(R.isPyretException($e126127)) {
$e126127.pyretStack.push(L[4]);
}
throw $e126127;
}
var $ret132133 = $Hann_DASH_check_DASH_temp921137($z128129,Set1137);
++R.GAS;
return $ret132133;
};
var $Hann_DASH_check_DASH_temp921137 = function(ann_DASH_check_DASH_temp685136,Set1137) {
return ann_DASH_check_DASH_temp685136;
};
var $Hanf_arg920138 = function(anf_arg683139,Set1137,list_DASH_to_DASH_set37124,lst171140) {
var $z143144 = D;
var $f149150 = function(_) {
return R.isFunction(list_DASH_to_DASH_set37124.$var)?list_DASH_to_DASH_set37124.$var.app(lst171140,anf_arg683139):R.ffi.throwNonFunApp(L[5],list_DASH_to_DASH_set37124.$var,[lst171140,anf_arg683139]);
};
try {
if(--R.GAS > 0) {
$z143144 = $f149150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f149150,
"from":L[5]});
}
} catch($e141142) {
if(R.isCont($e141142)) {
var $ss145146 = {"from":L[5],
"go":function(ann_DASH_check_DASH_temp682151) {
return $Hann_DASH_check_DASH_temp919152(ann_DASH_check_DASH_temp682151,Set1137);
}};
$e141142.stack[R.EXN_STACKHEIGHT++] = $ss145146;
}
if(R.isPyretException($e141142)) {
$e141142.pyretStack.push(L[5]);
}
throw $e141142;
}
var $ret147148 = $Hann_DASH_check_DASH_temp919152($z143144,Set1137);
++R.GAS;
return $ret147148;
};
var $Hann_DASH_check_DASH_temp919152 = function(ann_DASH_check_DASH_temp682151,Set1137) {
return ann_DASH_check_DASH_temp682151;
};
var $Hann_DASH_check_DASH_temp918153 = function(ann_DASH_check_DASH_temp676154,Set1137) {
return ann_DASH_check_DASH_temp676154;
};
var $Hann_DASH_check_DASH_temp917155 = function(ann_DASH_check_DASH_temp678156) {
return ann_DASH_check_DASH_temp678156;
};
var $Hnew_DASH_elems916157 = function(new_DASH_elems160158,Set1137,tree_DASH_set3644) {
var $z161162 = D;
var $f167168 = function(_) {
return R.isFunction(tree_DASH_set3644.$var === D?U(L[6],"tree-set"):tree_DASH_set3644.$var)?tree_DASH_set3644.$var === D?U(L[6],"tree-set"):tree_DASH_set3644.$var.app(new_DASH_elems160158):R.ffi.throwNonFunApp(L[7],tree_DASH_set3644.$var === D?U(L[6],"tree-set"):tree_DASH_set3644.$var,[new_DASH_elems160158]);
};
try {
if(--R.GAS > 0) {
$z161162 = $f167168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f167168,
"from":L[7]});
}
} catch($e159160) {
if(R.isCont($e159160)) {
var $ss163164 = {"from":L[7],
"go":function(ann_DASH_check_DASH_temp653169) {
return $Hann_DASH_check_DASH_temp915170(ann_DASH_check_DASH_temp653169,Set1137);
}};
$e159160.stack[R.EXN_STACKHEIGHT++] = $ss163164;
}
if(R.isPyretException($e159160)) {
$e159160.pyretStack.push(L[7]);
}
throw $e159160;
}
var $ret165166 = $Hann_DASH_check_DASH_temp915170($z161162,Set1137);
++R.GAS;
return $ret165166;
};
var $Hann_DASH_check_DASH_temp915170 = function(ann_DASH_check_DASH_temp653169,Set1137) {
return ann_DASH_check_DASH_temp653169;
};
var $Hif_DASH_914171 = function(if_DASH_53172,elem162173,elems161174) {
var if_helper656187 = R.makeFunction(function(if_helper_arg657206) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[11],1,arguments);
}
var ann_DASH_check_DASH_temp654207 = if_helper_arg657206;
return ann_DASH_check_DASH_temp654207;
});
var anf_if660205 = R.isBoolean(if_DASH_53172);
if(R.isPyretTrue(anf_if660205)) {
if(R.isPyretTrue(if_DASH_53172)) {
var anf_fun662185 = G(elems161174,"remove",L[9]);
var $z177178 = D;
var $f183184 = function(_) {
return R.isFunction(anf_fun662185)?anf_fun662185.app(elem162173):R.ffi.throwNonFunApp(L[8],anf_fun662185,[elem162173]);
};
try {
if(--R.GAS > 0) {
$z177178 = $f183184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f183184,
"from":L[8]});
}
} catch($e175176) {
if(R.isCont($e175176)) {
var $ss179180 = {"from":L[8],
"go":function(cont_tail_arg663186) {
return $Hcont_tail_arg912188(cont_tail_arg663186,if_helper656187);
}};
$e175176.stack[R.EXN_STACKHEIGHT++] = $ss179180;
}
if(R.isPyretException($e175176)) {
$e175176.pyretStack.push(L[8]);
}
throw $e175176;
}
var $ret181182 = $Hcont_tail_arg912188($z177178,if_helper656187);
++R.GAS;
return $ret181182;
} else {
var $z191192 = D;
var $f197198 = function(_) {
return R.isFunction(if_helper656187)?if_helper656187.app(elems161174):R.ffi.throwNonFunApp(L[10],if_helper656187,[elems161174]);
};
try {
if(--R.GAS > 0) {
$z191192 = $f197198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f197198,
"from":L[10]});
}
} catch($e189190) {
if(R.isCont($e189190)) {
var $ss193194 = {"from":L[10],
"go":function(cont_tail_app661199) {
return $Hcont_tail_app913200(cont_tail_app661199);
}};
$e189190.stack[R.EXN_STACKHEIGHT++] = $ss193194;
}
if(R.isPyretException($e189190)) {
$e189190.pyretStack.push(L[10]);
}
throw $e189190;
}
var $ret195196 = $Hcont_tail_app913200($z191192);
++R.GAS;
return $ret195196;
}
} else {
var cont_tail_arg658203 = R.throwNonBooleanCondition(L[11],("if"),if_DASH_53172);
if(--R.GAS > 0) {
$z201202 = R.isFunction(if_helper656187)?if_helper656187.app(cont_tail_arg658203):R.ffi.throwNonFunApp(L[11],if_helper656187,[cont_tail_arg658203]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper656187)?if_helper656187.app(cont_tail_arg658203):R.ffi.throwNonFunApp(L[11],if_helper656187,[cont_tail_arg658203]);
},
"from":L[11]});
}
++R.GAS;
return $z201202;
}
};
var $Hcont_tail_arg912188 = function(cont_tail_arg663186,if_helper656187) {
if(--R.GAS > 0) {
$z208209 = R.isFunction(if_helper656187)?if_helper656187.app(cont_tail_arg663186):R.ffi.throwNonFunApp(L[8],if_helper656187,[cont_tail_arg663186]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper656187)?if_helper656187.app(cont_tail_arg663186):R.ffi.throwNonFunApp(L[8],if_helper656187,[cont_tail_arg663186]);
},
"from":L[8]});
}
++R.GAS;
return $z208209;
};
var $Hcont_tail_app913200 = function(cont_tail_app661199) {
return cont_tail_app661199;
};
var $Hnew_DASH_elems911210 = function(new_DASH_elems155211,tree_DASH_set3644) {
var $z214215 = D;
var $f220221 = function(_) {
return R.isFunction(tree_DASH_set3644.$var === D?U(L[12],"tree-set"):tree_DASH_set3644.$var)?tree_DASH_set3644.$var === D?U(L[12],"tree-set"):tree_DASH_set3644.$var.app(new_DASH_elems155211):R.ffi.throwNonFunApp(L[13],tree_DASH_set3644.$var === D?U(L[12],"tree-set"):tree_DASH_set3644.$var,[new_DASH_elems155211]);
};
try {
if(--R.GAS > 0) {
$z214215 = $f220221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f220221,
"from":L[13]});
}
} catch($e212213) {
if(R.isCont($e212213)) {
var $ss216217 = {"from":L[13],
"go":function(ann_DASH_check_DASH_temp637222) {
return $Hann_DASH_check_DASH_temp910223(ann_DASH_check_DASH_temp637222);
}};
$e212213.stack[R.EXN_STACKHEIGHT++] = $ss216217;
}
if(R.isPyretException($e212213)) {
$e212213.pyretStack.push(L[13]);
}
throw $e212213;
}
var $ret218219 = $Hann_DASH_check_DASH_temp910223($z214215);
++R.GAS;
return $ret218219;
};
var $Hann_DASH_check_DASH_temp910223 = function(ann_DASH_check_DASH_temp637222) {
return ann_DASH_check_DASH_temp637222;
};
var $Hif_DASH_909224 = function(if_DASH_52225,elem157226,elems156227) {
var if_helper640238 = R.makeFunction(function(if_helper_arg641258) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[17],1,arguments);
}
var ann_DASH_check_DASH_temp638259 = if_helper_arg641258;
return ann_DASH_check_DASH_temp638259;
});
var anf_if644257 = R.isBoolean(if_DASH_52225);
if(R.isPyretTrue(anf_if644257)) {
if(R.isPyretTrue(if_DASH_52225)) {
var $z230231 = D;
var $f236237 = function(_) {
return R.isFunction(if_helper640238)?if_helper640238.app(elems156227):R.ffi.throwNonFunApp(L[14],if_helper640238,[elems156227]);
};
try {
if(--R.GAS > 0) {
$z230231 = $f236237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f236237,
"from":L[14]});
}
} catch($e228229) {
if(R.isCont($e228229)) {
var $ss232233 = {"from":L[14],
"go":function(cont_tail_app648239) {
return $Hcont_tail_app907240(cont_tail_app648239);
}};
$e228229.stack[R.EXN_STACKHEIGHT++] = $ss232233;
}
if(R.isPyretException($e228229)) {
$e228229.pyretStack.push(L[14]);
}
throw $e228229;
}
var $ret234235 = $Hcont_tail_app907240($z230231);
++R.GAS;
return $ret234235;
} else {
var anf_fun645251 = G(elems156227,"remove",L[16]);
var $z243244 = D;
var $f249250 = function(_) {
return R.isFunction(anf_fun645251)?anf_fun645251.app(elem157226):R.ffi.throwNonFunApp(L[15],anf_fun645251,[elem157226]);
};
try {
if(--R.GAS > 0) {
$z243244 = $f249250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f249250,
"from":L[15]});
}
} catch($e241242) {
if(R.isCont($e241242)) {
var $ss245246 = {"from":L[15],
"go":function(cont_tail_arg646252) {
return $Hcont_tail_arg908253(cont_tail_arg646252,if_helper640238);
}};
$e241242.stack[R.EXN_STACKHEIGHT++] = $ss245246;
}
if(R.isPyretException($e241242)) {
$e241242.pyretStack.push(L[15]);
}
throw $e241242;
}
var $ret247248 = $Hcont_tail_arg908253($z243244,if_helper640238);
++R.GAS;
return $ret247248;
}
} else {
var cont_tail_arg642256 = R.throwNonBooleanCondition(L[17],("if"),if_DASH_52225);
if(--R.GAS > 0) {
$z254255 = R.isFunction(if_helper640238)?if_helper640238.app(cont_tail_arg642256):R.ffi.throwNonFunApp(L[17],if_helper640238,[cont_tail_arg642256]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper640238)?if_helper640238.app(cont_tail_arg642256):R.ffi.throwNonFunApp(L[17],if_helper640238,[cont_tail_arg642256]);
},
"from":L[17]});
}
++R.GAS;
return $z254255;
}
};
var $Hcont_tail_app907240 = function(cont_tail_app648239) {
return cont_tail_app648239;
};
var $Hcont_tail_arg908253 = function(cont_tail_arg646252,if_helper640238) {
if(--R.GAS > 0) {
$z260261 = R.isFunction(if_helper640238)?if_helper640238.app(cont_tail_arg646252):R.ffi.throwNonFunApp(L[15],if_helper640238,[cont_tail_arg646252]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper640238)?if_helper640238.app(cont_tail_arg646252):R.ffi.throwNonFunApp(L[15],if_helper640238,[cont_tail_arg646252]);
},
"from":L[15]});
}
++R.GAS;
return $z260261;
};
var $Hnew_DASH_elems906262 = function(new_DASH_elems150263,tree_DASH_set3644) {
var $z266267 = D;
var $f272273 = function(_) {
return R.isFunction(tree_DASH_set3644.$var === D?U(L[18],"tree-set"):tree_DASH_set3644.$var)?tree_DASH_set3644.$var === D?U(L[18],"tree-set"):tree_DASH_set3644.$var.app(new_DASH_elems150263):R.ffi.throwNonFunApp(L[19],tree_DASH_set3644.$var === D?U(L[18],"tree-set"):tree_DASH_set3644.$var,[new_DASH_elems150263]);
};
try {
if(--R.GAS > 0) {
$z266267 = $f272273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f272273,
"from":L[19]});
}
} catch($e264265) {
if(R.isCont($e264265)) {
var $ss268269 = {"from":L[19],
"go":function(ann_DASH_check_DASH_temp630274) {
return $Hann_DASH_check_DASH_temp905275(ann_DASH_check_DASH_temp630274);
}};
$e264265.stack[R.EXN_STACKHEIGHT++] = $ss268269;
}
if(R.isPyretException($e264265)) {
$e264265.pyretStack.push(L[19]);
}
throw $e264265;
}
var $ret270271 = $Hann_DASH_check_DASH_temp905275($z266267);
++R.GAS;
return $ret270271;
};
var $Hann_DASH_check_DASH_temp905275 = function(ann_DASH_check_DASH_temp630274) {
return ann_DASH_check_DASH_temp630274;
};
var $Hann_DASH_check_DASH_temp904276 = function(ann_DASH_check_DASH_temp631277) {
return ann_DASH_check_DASH_temp631277;
};
var $Hann_DASH_check_DASH_temp903278 = function(ann_DASH_check_DASH_temp626279,lists225) {
return ann_DASH_check_DASH_temp626279;
};
var $Hanf_arg902280 = function(anf_arg624281,Set1137,tree_DASH_set3644) {
var $z284285 = D;
var $f290291 = function(_) {
return R.isFunction(tree_DASH_set3644.$var === D?U(L[20],"tree-set"):tree_DASH_set3644.$var)?tree_DASH_set3644.$var === D?U(L[20],"tree-set"):tree_DASH_set3644.$var.app(anf_arg624281):R.ffi.throwNonFunApp(L[21],tree_DASH_set3644.$var === D?U(L[20],"tree-set"):tree_DASH_set3644.$var,[anf_arg624281]);
};
try {
if(--R.GAS > 0) {
$z284285 = $f290291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f290291,
"from":L[21]});
}
} catch($e282283) {
if(R.isCont($e282283)) {
var $ss286287 = {"from":L[21],
"go":function(ann_DASH_check_DASH_temp621292) {
return $Hann_DASH_check_DASH_temp901293(ann_DASH_check_DASH_temp621292,Set1137);
}};
$e282283.stack[R.EXN_STACKHEIGHT++] = $ss286287;
}
if(R.isPyretException($e282283)) {
$e282283.pyretStack.push(L[21]);
}
throw $e282283;
}
var $ret288289 = $Hann_DASH_check_DASH_temp901293($z284285,Set1137);
++R.GAS;
return $ret288289;
};
var $Hann_DASH_check_DASH_temp901293 = function(ann_DASH_check_DASH_temp621292,Set1137) {
return ann_DASH_check_DASH_temp621292;
};
var $Hanf_arg900294 = function(anf_arg619295,Set1137,tree_DASH_set3644) {
var $z298299 = D;
var $f304305 = function(_) {
return R.isFunction(tree_DASH_set3644.$var === D?U(L[22],"tree-set"):tree_DASH_set3644.$var)?tree_DASH_set3644.$var === D?U(L[22],"tree-set"):tree_DASH_set3644.$var.app(anf_arg619295):R.ffi.throwNonFunApp(L[23],tree_DASH_set3644.$var === D?U(L[22],"tree-set"):tree_DASH_set3644.$var,[anf_arg619295]);
};
try {
if(--R.GAS > 0) {
$z298299 = $f304305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f304305,
"from":L[23]});
}
} catch($e296297) {
if(R.isCont($e296297)) {
var $ss300301 = {"from":L[23],
"go":function(ann_DASH_check_DASH_temp616306) {
return $Hann_DASH_check_DASH_temp899307(ann_DASH_check_DASH_temp616306,Set1137);
}};
$e296297.stack[R.EXN_STACKHEIGHT++] = $ss300301;
}
if(R.isPyretException($e296297)) {
$e296297.pyretStack.push(L[23]);
}
throw $e296297;
}
var $ret302303 = $Hann_DASH_check_DASH_temp899307($z298299,Set1137);
++R.GAS;
return $ret302303;
};
var $Hann_DASH_check_DASH_temp899307 = function(ann_DASH_check_DASH_temp616306,Set1137) {
return ann_DASH_check_DASH_temp616306;
};
var $Hann_DASH_check_DASH_temp898308 = function(ann_DASH_check_DASH_temp612309,$type$Boolean18) {
return ann_DASH_check_DASH_temp612309;
};
var $Hanf_arg897310 = function(anf_arg609311,_plus9) {
var $z314315 = D;
var $f320321 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("[tree-set: "),anf_arg609311):R.ffi.throwNonFunApp(L[24],_plus9,[("[tree-set: "),anf_arg609311]);
};
try {
if(--R.GAS > 0) {
$z314315 = $f320321();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f320321,
"from":L[24]});
}
} catch($e312313) {
if(R.isCont($e312313)) {
var $ss316317 = {"from":L[24],
"go":function(anf_arg610322) {
return $Hanf_arg896323(anf_arg610322,_plus9);
}};
$e312313.stack[R.EXN_STACKHEIGHT++] = $ss316317;
}
if(R.isPyretException($e312313)) {
$e312313.pyretStack.push(L[24]);
}
throw $e312313;
}
var $ret318319 = $Hanf_arg896323($z314315,_plus9);
++R.GAS;
return $ret318319;
};
var $Hanf_arg896323 = function(anf_arg610322,_plus9) {
var $z326327 = D;
var $f332333 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg610322,("]")):R.ffi.throwNonFunApp(L[25],_plus9,[anf_arg610322,("]")]);
};
try {
if(--R.GAS > 0) {
$z326327 = $f332333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f332333,
"from":L[25]});
}
} catch($e324325) {
if(R.isCont($e324325)) {
var $ss328329 = {"from":L[25],
"go":function(ann_DASH_check_DASH_temp593334) {
return $Hann_DASH_check_DASH_temp895335(ann_DASH_check_DASH_temp593334);
}};
$e324325.stack[R.EXN_STACKHEIGHT++] = $ss328329;
}
if(R.isPyretException($e324325)) {
$e324325.pyretStack.push(L[25]);
}
throw $e324325;
}
var $ret330331 = $Hann_DASH_check_DASH_temp895335($z326327);
++R.GAS;
return $ret330331;
};
var $Hann_DASH_check_DASH_temp895335 = function(ann_DASH_check_DASH_temp593334) {
return ann_DASH_check_DASH_temp593334;
};
var $Hcont_tail_arg891336 = function(cont_tail_arg606337,if_helper597338) {
if(--R.GAS > 0) {
$z339340 = R.isFunction(if_helper597338)?if_helper597338.app(cont_tail_arg606337):R.ffi.throwNonFunApp(L[26],if_helper597338,[cont_tail_arg606337]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper597338)?if_helper597338.app(cont_tail_arg606337):R.ffi.throwNonFunApp(L[26],if_helper597338,[cont_tail_arg606337]);
},
"from":L[26]});
}
++R.GAS;
return $z339340;
};
var $Hanf_arg894341 = function(anf_arg602342,elem140343,if_helper597338,_plus9,torepr16) {
var $z346347 = D;
var $f352353 = function(_) {
return R.isFunction(torepr16)?torepr16.app(elem140343):R.ffi.throwNonFunApp(L[27],torepr16,[elem140343]);
};
try {
if(--R.GAS > 0) {
$z346347 = $f352353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f352353,
"from":L[27]});
}
} catch($e344345) {
if(R.isCont($e344345)) {
var $ss348349 = {"from":L[27],
"go":function(anf_arg603354) {
return $Hanf_arg893355(anf_arg603354,anf_arg602342,if_helper597338,_plus9);
}};
$e344345.stack[R.EXN_STACKHEIGHT++] = $ss348349;
}
if(R.isPyretException($e344345)) {
$e344345.pyretStack.push(L[27]);
}
throw $e344345;
}
var $ret350351 = $Hanf_arg893355($z346347,anf_arg602342,if_helper597338,_plus9);
++R.GAS;
return $ret350351;
};
var $Hanf_arg893355 = function(anf_arg603354,anf_arg602342,if_helper597338,_plus9) {
var $z358359 = D;
var $f364365 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg602342,anf_arg603354):R.ffi.throwNonFunApp(L[28],_plus9,[anf_arg602342,anf_arg603354]);
};
try {
if(--R.GAS > 0) {
$z358359 = $f364365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f364365,
"from":L[28]});
}
} catch($e356357) {
if(R.isCont($e356357)) {
var $ss360361 = {"from":L[28],
"go":function(cont_tail_arg604366) {
return $Hcont_tail_arg892367(cont_tail_arg604366,if_helper597338);
}};
$e356357.stack[R.EXN_STACKHEIGHT++] = $ss360361;
}
if(R.isPyretException($e356357)) {
$e356357.pyretStack.push(L[28]);
}
throw $e356357;
}
var $ret362363 = $Hcont_tail_arg892367($z358359,if_helper597338);
++R.GAS;
return $ret362363;
};
var $Hcont_tail_arg892367 = function(cont_tail_arg604366,if_helper597338) {
if(--R.GAS > 0) {
$z368369 = R.isFunction(if_helper597338)?if_helper597338.app(cont_tail_arg604366):R.ffi.throwNonFunApp(L[28],if_helper597338,[cont_tail_arg604366]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper597338)?if_helper597338.app(cont_tail_arg604366):R.ffi.throwNonFunApp(L[28],if_helper597338,[cont_tail_arg604366]);
},
"from":L[28]});
}
++R.GAS;
return $z368369;
};
var $Hanf_arg890370 = function(anf_arg590371,_plus9) {
var $z374375 = D;
var $f380381 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("[tree-set: "),anf_arg590371):R.ffi.throwNonFunApp(L[29],_plus9,[("[tree-set: "),anf_arg590371]);
};
try {
if(--R.GAS > 0) {
$z374375 = $f380381();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f380381,
"from":L[29]});
}
} catch($e372373) {
if(R.isCont($e372373)) {
var $ss376377 = {"from":L[29],
"go":function(anf_arg591382) {
return $Hanf_arg889383(anf_arg591382,_plus9);
}};
$e372373.stack[R.EXN_STACKHEIGHT++] = $ss376377;
}
if(R.isPyretException($e372373)) {
$e372373.pyretStack.push(L[29]);
}
throw $e372373;
}
var $ret378379 = $Hanf_arg889383($z374375,_plus9);
++R.GAS;
return $ret378379;
};
var $Hanf_arg889383 = function(anf_arg591382,_plus9) {
var $z386387 = D;
var $f392393 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg591382,("]")):R.ffi.throwNonFunApp(L[30],_plus9,[anf_arg591382,("]")]);
};
try {
if(--R.GAS > 0) {
$z386387 = $f392393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f392393,
"from":L[30]});
}
} catch($e384385) {
if(R.isCont($e384385)) {
var $ss388389 = {"from":L[30],
"go":function(ann_DASH_check_DASH_temp574394) {
return $Hann_DASH_check_DASH_temp888395(ann_DASH_check_DASH_temp574394);
}};
$e384385.stack[R.EXN_STACKHEIGHT++] = $ss388389;
}
if(R.isPyretException($e384385)) {
$e384385.pyretStack.push(L[30]);
}
throw $e384385;
}
var $ret390391 = $Hann_DASH_check_DASH_temp888395($z386387);
++R.GAS;
return $ret390391;
};
var $Hann_DASH_check_DASH_temp888395 = function(ann_DASH_check_DASH_temp574394) {
return ann_DASH_check_DASH_temp574394;
};
var $Hcont_tail_arg884396 = function(cont_tail_arg587397,if_helper578398) {
if(--R.GAS > 0) {
$z399400 = R.isFunction(if_helper578398)?if_helper578398.app(cont_tail_arg587397):R.ffi.throwNonFunApp(L[31],if_helper578398,[cont_tail_arg587397]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper578398)?if_helper578398.app(cont_tail_arg587397):R.ffi.throwNonFunApp(L[31],if_helper578398,[cont_tail_arg587397]);
},
"from":L[31]});
}
++R.GAS;
return $z399400;
};
var $Hanf_arg887401 = function(anf_arg583402,elem137403,if_helper578398,_plus9,tostring17) {
var $z406407 = D;
var $f412413 = function(_) {
return R.isFunction(tostring17)?tostring17.app(elem137403):R.ffi.throwNonFunApp(L[32],tostring17,[elem137403]);
};
try {
if(--R.GAS > 0) {
$z406407 = $f412413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f412413,
"from":L[32]});
}
} catch($e404405) {
if(R.isCont($e404405)) {
var $ss408409 = {"from":L[32],
"go":function(anf_arg584414) {
return $Hanf_arg886415(anf_arg584414,anf_arg583402,if_helper578398,_plus9);
}};
$e404405.stack[R.EXN_STACKHEIGHT++] = $ss408409;
}
if(R.isPyretException($e404405)) {
$e404405.pyretStack.push(L[32]);
}
throw $e404405;
}
var $ret410411 = $Hanf_arg886415($z406407,anf_arg583402,if_helper578398,_plus9);
++R.GAS;
return $ret410411;
};
var $Hanf_arg886415 = function(anf_arg584414,anf_arg583402,if_helper578398,_plus9) {
var $z418419 = D;
var $f424425 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg583402,anf_arg584414):R.ffi.throwNonFunApp(L[33],_plus9,[anf_arg583402,anf_arg584414]);
};
try {
if(--R.GAS > 0) {
$z418419 = $f424425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f424425,
"from":L[33]});
}
} catch($e416417) {
if(R.isCont($e416417)) {
var $ss420421 = {"from":L[33],
"go":function(cont_tail_arg585426) {
return $Hcont_tail_arg885427(cont_tail_arg585426,if_helper578398);
}};
$e416417.stack[R.EXN_STACKHEIGHT++] = $ss420421;
}
if(R.isPyretException($e416417)) {
$e416417.pyretStack.push(L[33]);
}
throw $e416417;
}
var $ret422423 = $Hcont_tail_arg885427($z418419,if_helper578398);
++R.GAS;
return $ret422423;
};
var $Hcont_tail_arg885427 = function(cont_tail_arg585426,if_helper578398) {
if(--R.GAS > 0) {
$z428429 = R.isFunction(if_helper578398)?if_helper578398.app(cont_tail_arg585426):R.ffi.throwNonFunApp(L[33],if_helper578398,[cont_tail_arg585426]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper578398)?if_helper578398.app(cont_tail_arg585426):R.ffi.throwNonFunApp(L[33],if_helper578398,[cont_tail_arg585426]);
},
"from":L[33]});
}
++R.GAS;
return $z428429;
};
var $Hanf_arg883430 = function(anf_arg570431,_plus9) {
var $z434435 = D;
var $f440441 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg570431,(")")):R.ffi.throwNonFunApp(L[34],_plus9,[anf_arg570431,(")")]);
};
try {
if(--R.GAS > 0) {
$z434435 = $f440441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f440441,
"from":L[34]});
}
} catch($e432433) {
if(R.isCont($e432433)) {
var $ss436437 = {"from":L[34],
"go":function(anf_arg571442) {
return $Hanf_arg882443(anf_arg571442,_plus9);
}};
$e432433.stack[R.EXN_STACKHEIGHT++] = $ss436437;
}
if(R.isPyretException($e432433)) {
$e432433.pyretStack.push(L[34]);
}
throw $e432433;
}
var $ret438439 = $Hanf_arg882443($z434435,_plus9);
++R.GAS;
return $ret438439;
};
var $Hanf_arg882443 = function(anf_arg571442,_plus9) {
var $z446447 = D;
var $f452453 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg571442):R.ffi.throwNonFunApp(L[34],_plus9,[("("),anf_arg571442]);
};
try {
if(--R.GAS > 0) {
$z446447 = $f452453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f452453,
"from":L[34]});
}
} catch($e444445) {
if(R.isCont($e444445)) {
var $ss448449 = {"from":L[34],
"go":function(anf_arg572454) {
return $Hanf_arg881455(anf_arg572454,_plus9);
}};
$e444445.stack[R.EXN_STACKHEIGHT++] = $ss448449;
}
if(R.isPyretException($e444445)) {
$e444445.pyretStack.push(L[34]);
}
throw $e444445;
}
var $ret450451 = $Hanf_arg881455($z446447,_plus9);
++R.GAS;
return $ret450451;
};
var $Hanf_arg881455 = function(anf_arg572454,_plus9) {
var $z458459 = D;
var $f464465 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("tree-set"),anf_arg572454):R.ffi.throwNonFunApp(L[34],_plus9,[("tree-set"),anf_arg572454]);
};
try {
if(--R.GAS > 0) {
$z458459 = $f464465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f464465,
"from":L[34]});
}
} catch($e456457) {
if(R.isCont($e456457)) {
var $ss460461 = {"from":L[34],
"go":function(ann_DASH_check_DASH_temp568466) {
return $Hann_DASH_check_DASH_temp880467(ann_DASH_check_DASH_temp568466);
}};
$e456457.stack[R.EXN_STACKHEIGHT++] = $ss460461;
}
if(R.isPyretException($e456457)) {
$e456457.pyretStack.push(L[34]);
}
throw $e456457;
}
var $ret462463 = $Hann_DASH_check_DASH_temp880467($z458459);
++R.GAS;
return $ret462463;
};
var $Hann_DASH_check_DASH_temp880467 = function(ann_DASH_check_DASH_temp568466) {
return ann_DASH_check_DASH_temp568466;
};
var $Hcont_tail_arg878468 = function(cont_tail_arg565469,if_helper557470) {
if(--R.GAS > 0) {
$z471472 = R.isFunction(if_helper557470)?if_helper557470.app(cont_tail_arg565469):R.ffi.throwNonFunApp(L[34],if_helper557470,[cont_tail_arg565469]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper557470)?if_helper557470.app(cont_tail_arg565469):R.ffi.throwNonFunApp(L[34],if_helper557470,[cont_tail_arg565469]);
},
"from":L[34]});
}
++R.GAS;
return $z471472;
};
var $Hcont_tail_arg879473 = function(cont_tail_arg562474,if_helper557470) {
if(--R.GAS > 0) {
$z475476 = R.isFunction(if_helper557470)?if_helper557470.app(cont_tail_arg562474):R.ffi.throwNonFunApp(L[34],if_helper557470,[cont_tail_arg562474]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper557470)?if_helper557470.app(cont_tail_arg562474):R.ffi.throwNonFunApp(L[34],if_helper557470,[cont_tail_arg562474]);
},
"from":L[34]});
}
++R.GAS;
return $z475476;
};
var $Hann_DASH_check_DASH_temp877477 = function(ann_DASH_check_DASH_temp541478,Set1137) {
return ann_DASH_check_DASH_temp541478;
};
var $Hif_DASH_876479 = function(if_DASH_43480,elem133481,u132482) {
var if_helper544495 = R.makeFunction(function(if_helper_arg545513) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[38],1,arguments);
}
var ann_DASH_check_DASH_temp542514 = if_helper_arg545513;
return ann_DASH_check_DASH_temp542514;
});
var anf_if548512 = R.isBoolean(if_DASH_43480);
if(R.isPyretTrue(anf_if548512)) {
if(R.isPyretTrue(if_DASH_43480)) {
var anf_fun550493 = G(u132482,"remove",L[36]);
var $z485486 = D;
var $f491492 = function(_) {
return R.isFunction(anf_fun550493)?anf_fun550493.app(elem133481):R.ffi.throwNonFunApp(L[35],anf_fun550493,[elem133481]);
};
try {
if(--R.GAS > 0) {
$z485486 = $f491492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f491492,
"from":L[35]});
}
} catch($e483484) {
if(R.isCont($e483484)) {
var $ss487488 = {"from":L[35],
"go":function(cont_tail_arg551494) {
return $Hcont_tail_arg874496(cont_tail_arg551494,if_helper544495);
}};
$e483484.stack[R.EXN_STACKHEIGHT++] = $ss487488;
}
if(R.isPyretException($e483484)) {
$e483484.pyretStack.push(L[35]);
}
throw $e483484;
}
var $ret489490 = $Hcont_tail_arg874496($z485486,if_helper544495);
++R.GAS;
return $ret489490;
} else {
var $z499500 = D;
var $f505506 = function(_) {
return R.isFunction(if_helper544495)?if_helper544495.app(u132482):R.ffi.throwNonFunApp(L[37],if_helper544495,[u132482]);
};
try {
if(--R.GAS > 0) {
$z499500 = $f505506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f505506,
"from":L[37]});
}
} catch($e497498) {
if(R.isCont($e497498)) {
var $ss501502 = {"from":L[37],
"go":function(cont_tail_app549507) {
return $Hcont_tail_app875508(cont_tail_app549507);
}};
$e497498.stack[R.EXN_STACKHEIGHT++] = $ss501502;
}
if(R.isPyretException($e497498)) {
$e497498.pyretStack.push(L[37]);
}
throw $e497498;
}
var $ret503504 = $Hcont_tail_app875508($z499500);
++R.GAS;
return $ret503504;
}
} else {
var cont_tail_arg546511 = R.throwNonBooleanCondition(L[38],("if"),if_DASH_43480);
if(--R.GAS > 0) {
$z509510 = R.isFunction(if_helper544495)?if_helper544495.app(cont_tail_arg546511):R.ffi.throwNonFunApp(L[38],if_helper544495,[cont_tail_arg546511]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper544495)?if_helper544495.app(cont_tail_arg546511):R.ffi.throwNonFunApp(L[38],if_helper544495,[cont_tail_arg546511]);
},
"from":L[38]});
}
++R.GAS;
return $z509510;
}
};
var $Hcont_tail_arg874496 = function(cont_tail_arg551494,if_helper544495) {
if(--R.GAS > 0) {
$z515516 = R.isFunction(if_helper544495)?if_helper544495.app(cont_tail_arg551494):R.ffi.throwNonFunApp(L[35],if_helper544495,[cont_tail_arg551494]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper544495)?if_helper544495.app(cont_tail_arg551494):R.ffi.throwNonFunApp(L[35],if_helper544495,[cont_tail_arg551494]);
},
"from":L[35]});
}
++R.GAS;
return $z515516;
};
var $Hcont_tail_app875508 = function(cont_tail_app549507) {
return cont_tail_app549507;
};
var $Hann_DASH_check_DASH_temp873517 = function(ann_DASH_check_DASH_temp526518,Set1137) {
return ann_DASH_check_DASH_temp526518;
};
var $Hif_DASH_872519 = function(if_DASH_42520,elem129521,u128522) {
var if_helper529533 = R.makeFunction(function(if_helper_arg530553) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[42],1,arguments);
}
var ann_DASH_check_DASH_temp527554 = if_helper_arg530553;
return ann_DASH_check_DASH_temp527554;
});
var anf_if533552 = R.isBoolean(if_DASH_42520);
if(R.isPyretTrue(anf_if533552)) {
if(R.isPyretTrue(if_DASH_42520)) {
var $z525526 = D;
var $f531532 = function(_) {
return R.isFunction(if_helper529533)?if_helper529533.app(u128522):R.ffi.throwNonFunApp(L[39],if_helper529533,[u128522]);
};
try {
if(--R.GAS > 0) {
$z525526 = $f531532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f531532,
"from":L[39]});
}
} catch($e523524) {
if(R.isCont($e523524)) {
var $ss527528 = {"from":L[39],
"go":function(cont_tail_app537534) {
return $Hcont_tail_app870535(cont_tail_app537534);
}};
$e523524.stack[R.EXN_STACKHEIGHT++] = $ss527528;
}
if(R.isPyretException($e523524)) {
$e523524.pyretStack.push(L[39]);
}
throw $e523524;
}
var $ret529530 = $Hcont_tail_app870535($z525526);
++R.GAS;
return $ret529530;
} else {
var anf_fun534546 = G(u128522,"remove",L[41]);
var $z538539 = D;
var $f544545 = function(_) {
return R.isFunction(anf_fun534546)?anf_fun534546.app(elem129521):R.ffi.throwNonFunApp(L[40],anf_fun534546,[elem129521]);
};
try {
if(--R.GAS > 0) {
$z538539 = $f544545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f544545,
"from":L[40]});
}
} catch($e536537) {
if(R.isCont($e536537)) {
var $ss540541 = {"from":L[40],
"go":function(cont_tail_arg535547) {
return $Hcont_tail_arg871548(cont_tail_arg535547,if_helper529533);
}};
$e536537.stack[R.EXN_STACKHEIGHT++] = $ss540541;
}
if(R.isPyretException($e536537)) {
$e536537.pyretStack.push(L[40]);
}
throw $e536537;
}
var $ret542543 = $Hcont_tail_arg871548($z538539,if_helper529533);
++R.GAS;
return $ret542543;
}
} else {
var cont_tail_arg531551 = R.throwNonBooleanCondition(L[42],("if"),if_DASH_42520);
if(--R.GAS > 0) {
$z549550 = R.isFunction(if_helper529533)?if_helper529533.app(cont_tail_arg531551):R.ffi.throwNonFunApp(L[42],if_helper529533,[cont_tail_arg531551]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper529533)?if_helper529533.app(cont_tail_arg531551):R.ffi.throwNonFunApp(L[42],if_helper529533,[cont_tail_arg531551]);
},
"from":L[42]});
}
++R.GAS;
return $z549550;
}
};
var $Hcont_tail_app870535 = function(cont_tail_app537534) {
return cont_tail_app537534;
};
var $Hcont_tail_arg871548 = function(cont_tail_arg535547,if_helper529533) {
if(--R.GAS > 0) {
$z555556 = R.isFunction(if_helper529533)?if_helper529533.app(cont_tail_arg535547):R.ffi.throwNonFunApp(L[40],if_helper529533,[cont_tail_arg535547]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper529533)?if_helper529533.app(cont_tail_arg535547):R.ffi.throwNonFunApp(L[40],if_helper529533,[cont_tail_arg535547]);
},
"from":L[40]});
}
++R.GAS;
return $z555556;
};
var $Hann_DASH_check_DASH_temp869557 = function(ann_DASH_check_DASH_temp520558,Set1137) {
return ann_DASH_check_DASH_temp520558;
};
var $Hann_DASH_check_DASH_temp868559 = function(ann_DASH_check_DASH_temp521560) {
return ann_DASH_check_DASH_temp521560;
};
var $Hanf_arg867561 = function(anf_arg516562,Set1137,list_DASH_set34563) {
var $z566567 = D;
var $f572573 = function(_) {
return R.isFunction(list_DASH_set34563.$var === D?U(L[43],"list-set"):list_DASH_set34563.$var)?list_DASH_set34563.$var === D?U(L[43],"list-set"):list_DASH_set34563.$var.app(anf_arg516562):R.ffi.throwNonFunApp(L[44],list_DASH_set34563.$var === D?U(L[43],"list-set"):list_DASH_set34563.$var,[anf_arg516562]);
};
try {
if(--R.GAS > 0) {
$z566567 = $f572573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f572573,
"from":L[44]});
}
} catch($e564565) {
if(R.isCont($e564565)) {
var $ss568569 = {"from":L[44],
"go":function(ann_DASH_check_DASH_temp510574) {
return $Hann_DASH_check_DASH_temp866575(ann_DASH_check_DASH_temp510574,Set1137);
}};
$e564565.stack[R.EXN_STACKHEIGHT++] = $ss568569;
}
if(R.isPyretException($e564565)) {
$e564565.pyretStack.push(L[44]);
}
throw $e564565;
}
var $ret570571 = $Hann_DASH_check_DASH_temp866575($z566567,Set1137);
++R.GAS;
return $ret570571;
};
var $Hann_DASH_check_DASH_temp866575 = function(ann_DASH_check_DASH_temp510574,Set1137) {
return ann_DASH_check_DASH_temp510574;
};
var $Hif_DASH_865576 = function(if_DASH_41577,Set1137,elem117578,link15579,list_DASH_set34563,self116580) {
var if_helper499591 = R.makeFunction(function(if_helper_arg500611) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[48],1,arguments);
}
var ann_DASH_check_DASH_temp496612 = if_helper_arg500611;
return R.checkAnn(L[49],Set1137,ann_DASH_check_DASH_temp496612,function() {
return ann_DASH_check_DASH_temp496612;
});
});
var anf_if503610 = R.isBoolean(if_DASH_41577);
if(R.isPyretTrue(anf_if503610)) {
if(R.isPyretTrue(if_DASH_41577)) {
var $z583584 = D;
var $f589590 = function(_) {
return R.isFunction(if_helper499591)?if_helper499591.app(self116580):R.ffi.throwNonFunApp(L[45],if_helper499591,[self116580]);
};
try {
if(--R.GAS > 0) {
$z583584 = $f589590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f589590,
"from":L[45]});
}
} catch($e581582) {
if(R.isCont($e581582)) {
var $ss585586 = {"from":L[45],
"go":function(cont_tail_app508592) {
return $Hcont_tail_app862593(cont_tail_app508592);
}};
$e581582.stack[R.EXN_STACKHEIGHT++] = $ss585586;
}
if(R.isPyretException($e581582)) {
$e581582.pyretStack.push(L[45]);
}
throw $e581582;
}
var $ret587588 = $Hcont_tail_app862593($z583584);
++R.GAS;
return $ret587588;
} else {
var anf_arg504604 = G(self116580,"elems",L[47]);
var $z596597 = D;
var $f602603 = function(_) {
return R.isFunction(link15579)?link15579.app(elem117578,anf_arg504604):R.ffi.throwNonFunApp(L[46],link15579,[elem117578,anf_arg504604]);
};
try {
if(--R.GAS > 0) {
$z596597 = $f602603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f602603,
"from":L[46]});
}
} catch($e594595) {
if(R.isCont($e594595)) {
var $ss598599 = {"from":L[46],
"go":function(anf_arg505605) {
return $Hanf_arg864606(anf_arg505605,if_helper499591,list_DASH_set34563);
}};
$e594595.stack[R.EXN_STACKHEIGHT++] = $ss598599;
}
if(R.isPyretException($e594595)) {
$e594595.pyretStack.push(L[46]);
}
throw $e594595;
}
var $ret600601 = $Hanf_arg864606($z596597,if_helper499591,list_DASH_set34563);
++R.GAS;
return $ret600601;
}
} else {
var cont_tail_arg501609 = R.throwNonBooleanCondition(L[48],("if"),if_DASH_41577);
if(--R.GAS > 0) {
$z607608 = R.isFunction(if_helper499591)?if_helper499591.app(cont_tail_arg501609):R.ffi.throwNonFunApp(L[48],if_helper499591,[cont_tail_arg501609]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper499591)?if_helper499591.app(cont_tail_arg501609):R.ffi.throwNonFunApp(L[48],if_helper499591,[cont_tail_arg501609]);
},
"from":L[48]});
}
++R.GAS;
return $z607608;
}
};
var $Hcont_tail_app862593 = function(cont_tail_app508592) {
return cont_tail_app508592;
};
var $Hanf_arg864606 = function(anf_arg505605,if_helper499591,list_DASH_set34563) {
var $z615616 = D;
var $f621622 = function(_) {
return R.isFunction(list_DASH_set34563.$var === D?U(L[50],"list-set"):list_DASH_set34563.$var)?list_DASH_set34563.$var === D?U(L[50],"list-set"):list_DASH_set34563.$var.app(anf_arg505605):R.ffi.throwNonFunApp(L[51],list_DASH_set34563.$var === D?U(L[50],"list-set"):list_DASH_set34563.$var,[anf_arg505605]);
};
try {
if(--R.GAS > 0) {
$z615616 = $f621622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f621622,
"from":L[51]});
}
} catch($e613614) {
if(R.isCont($e613614)) {
var $ss617618 = {"from":L[51],
"go":function(cont_tail_arg506623) {
return $Hcont_tail_arg863624(cont_tail_arg506623,if_helper499591);
}};
$e613614.stack[R.EXN_STACKHEIGHT++] = $ss617618;
}
if(R.isPyretException($e613614)) {
$e613614.pyretStack.push(L[51]);
}
throw $e613614;
}
var $ret619620 = $Hcont_tail_arg863624($z615616,if_helper499591);
++R.GAS;
return $ret619620;
};
var $Hcont_tail_arg863624 = function(cont_tail_arg506623,if_helper499591) {
if(--R.GAS > 0) {
$z625626 = R.isFunction(if_helper499591)?if_helper499591.app(cont_tail_arg506623):R.ffi.throwNonFunApp(L[51],if_helper499591,[cont_tail_arg506623]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper499591)?if_helper499591.app(cont_tail_arg506623):R.ffi.throwNonFunApp(L[51],if_helper499591,[cont_tail_arg506623]);
},
"from":L[51]});
}
++R.GAS;
return $z625626;
};
var $Hann_DASH_check_DASH_temp861627 = function(ann_DASH_check_DASH_temp492628,$type$Boolean18) {
return ann_DASH_check_DASH_temp492628;
};
var $Hanf_arg860629 = function(anf_arg489630,_plus9) {
var $z633634 = D;
var $f639640 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("[list-set: "),anf_arg489630):R.ffi.throwNonFunApp(L[52],_plus9,[("[list-set: "),anf_arg489630]);
};
try {
if(--R.GAS > 0) {
$z633634 = $f639640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f639640,
"from":L[52]});
}
} catch($e631632) {
if(R.isCont($e631632)) {
var $ss635636 = {"from":L[52],
"go":function(anf_arg490641) {
return $Hanf_arg859642(anf_arg490641,_plus9);
}};
$e631632.stack[R.EXN_STACKHEIGHT++] = $ss635636;
}
if(R.isPyretException($e631632)) {
$e631632.pyretStack.push(L[52]);
}
throw $e631632;
}
var $ret637638 = $Hanf_arg859642($z633634,_plus9);
++R.GAS;
return $ret637638;
};
var $Hanf_arg859642 = function(anf_arg490641,_plus9) {
var $z645646 = D;
var $f651652 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg490641,("]")):R.ffi.throwNonFunApp(L[53],_plus9,[anf_arg490641,("]")]);
};
try {
if(--R.GAS > 0) {
$z645646 = $f651652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f651652,
"from":L[53]});
}
} catch($e643644) {
if(R.isCont($e643644)) {
var $ss647648 = {"from":L[53],
"go":function(ann_DASH_check_DASH_temp473653) {
return $Hann_DASH_check_DASH_temp858654(ann_DASH_check_DASH_temp473653);
}};
$e643644.stack[R.EXN_STACKHEIGHT++] = $ss647648;
}
if(R.isPyretException($e643644)) {
$e643644.pyretStack.push(L[53]);
}
throw $e643644;
}
var $ret649650 = $Hann_DASH_check_DASH_temp858654($z645646);
++R.GAS;
return $ret649650;
};
var $Hann_DASH_check_DASH_temp858654 = function(ann_DASH_check_DASH_temp473653) {
return ann_DASH_check_DASH_temp473653;
};
var $Hcont_tail_arg854655 = function(cont_tail_arg486656,if_helper477657) {
if(--R.GAS > 0) {
$z658659 = R.isFunction(if_helper477657)?if_helper477657.app(cont_tail_arg486656):R.ffi.throwNonFunApp(L[54],if_helper477657,[cont_tail_arg486656]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper477657)?if_helper477657.app(cont_tail_arg486656):R.ffi.throwNonFunApp(L[54],if_helper477657,[cont_tail_arg486656]);
},
"from":L[54]});
}
++R.GAS;
return $z658659;
};
var $Hanf_arg857660 = function(anf_arg482661,acc113662,if_helper477657,_plus9) {
var $z665666 = D;
var $f671672 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg482661,(", ")):R.ffi.throwNonFunApp(L[55],_plus9,[anf_arg482661,(", ")]);
};
try {
if(--R.GAS > 0) {
$z665666 = $f671672();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f671672,
"from":L[55]});
}
} catch($e663664) {
if(R.isCont($e663664)) {
var $ss667668 = {"from":L[55],
"go":function(anf_arg483673) {
return $Hanf_arg856674(anf_arg483673,acc113662,if_helper477657,_plus9);
}};
$e663664.stack[R.EXN_STACKHEIGHT++] = $ss667668;
}
if(R.isPyretException($e663664)) {
$e663664.pyretStack.push(L[55]);
}
throw $e663664;
}
var $ret669670 = $Hanf_arg856674($z665666,acc113662,if_helper477657,_plus9);
++R.GAS;
return $ret669670;
};
var $Hanf_arg856674 = function(anf_arg483673,acc113662,if_helper477657,_plus9) {
var $z677678 = D;
var $f683684 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg483673,acc113662):R.ffi.throwNonFunApp(L[55],_plus9,[anf_arg483673,acc113662]);
};
try {
if(--R.GAS > 0) {
$z677678 = $f683684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f683684,
"from":L[55]});
}
} catch($e675676) {
if(R.isCont($e675676)) {
var $ss679680 = {"from":L[55],
"go":function(cont_tail_arg484685) {
return $Hcont_tail_arg855686(cont_tail_arg484685,if_helper477657);
}};
$e675676.stack[R.EXN_STACKHEIGHT++] = $ss679680;
}
if(R.isPyretException($e675676)) {
$e675676.pyretStack.push(L[55]);
}
throw $e675676;
}
var $ret681682 = $Hcont_tail_arg855686($z677678,if_helper477657);
++R.GAS;
return $ret681682;
};
var $Hcont_tail_arg855686 = function(cont_tail_arg484685,if_helper477657) {
if(--R.GAS > 0) {
$z687688 = R.isFunction(if_helper477657)?if_helper477657.app(cont_tail_arg484685):R.ffi.throwNonFunApp(L[55],if_helper477657,[cont_tail_arg484685]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper477657)?if_helper477657.app(cont_tail_arg484685):R.ffi.throwNonFunApp(L[55],if_helper477657,[cont_tail_arg484685]);
},
"from":L[55]});
}
++R.GAS;
return $z687688;
};
var $Hanf_arg853689 = function(anf_arg470690,_plus9) {
var $z693694 = D;
var $f699700 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("[list-set: "),anf_arg470690):R.ffi.throwNonFunApp(L[56],_plus9,[("[list-set: "),anf_arg470690]);
};
try {
if(--R.GAS > 0) {
$z693694 = $f699700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f699700,
"from":L[56]});
}
} catch($e691692) {
if(R.isCont($e691692)) {
var $ss695696 = {"from":L[56],
"go":function(anf_arg471701) {
return $Hanf_arg852702(anf_arg471701,_plus9);
}};
$e691692.stack[R.EXN_STACKHEIGHT++] = $ss695696;
}
if(R.isPyretException($e691692)) {
$e691692.pyretStack.push(L[56]);
}
throw $e691692;
}
var $ret697698 = $Hanf_arg852702($z693694,_plus9);
++R.GAS;
return $ret697698;
};
var $Hanf_arg852702 = function(anf_arg471701,_plus9) {
var $z705706 = D;
var $f711712 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg471701,("]")):R.ffi.throwNonFunApp(L[57],_plus9,[anf_arg471701,("]")]);
};
try {
if(--R.GAS > 0) {
$z705706 = $f711712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f711712,
"from":L[57]});
}
} catch($e703704) {
if(R.isCont($e703704)) {
var $ss707708 = {"from":L[57],
"go":function(ann_DASH_check_DASH_temp454713) {
return $Hann_DASH_check_DASH_temp851714(ann_DASH_check_DASH_temp454713);
}};
$e703704.stack[R.EXN_STACKHEIGHT++] = $ss707708;
}
if(R.isPyretException($e703704)) {
$e703704.pyretStack.push(L[57]);
}
throw $e703704;
}
var $ret709710 = $Hann_DASH_check_DASH_temp851714($z705706);
++R.GAS;
return $ret709710;
};
var $Hann_DASH_check_DASH_temp851714 = function(ann_DASH_check_DASH_temp454713) {
return ann_DASH_check_DASH_temp454713;
};
var $Hcont_tail_arg847715 = function(cont_tail_arg467716,if_helper458717) {
if(--R.GAS > 0) {
$z718719 = R.isFunction(if_helper458717)?if_helper458717.app(cont_tail_arg467716):R.ffi.throwNonFunApp(L[58],if_helper458717,[cont_tail_arg467716]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper458717)?if_helper458717.app(cont_tail_arg467716):R.ffi.throwNonFunApp(L[58],if_helper458717,[cont_tail_arg467716]);
},
"from":L[58]});
}
++R.GAS;
return $z718719;
};
var $Hanf_arg850720 = function(anf_arg463721,acc110722,if_helper458717,_plus9) {
var $z725726 = D;
var $f731732 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg463721,(", ")):R.ffi.throwNonFunApp(L[59],_plus9,[anf_arg463721,(", ")]);
};
try {
if(--R.GAS > 0) {
$z725726 = $f731732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f731732,
"from":L[59]});
}
} catch($e723724) {
if(R.isCont($e723724)) {
var $ss727728 = {"from":L[59],
"go":function(anf_arg464733) {
return $Hanf_arg849734(anf_arg464733,acc110722,if_helper458717,_plus9);
}};
$e723724.stack[R.EXN_STACKHEIGHT++] = $ss727728;
}
if(R.isPyretException($e723724)) {
$e723724.pyretStack.push(L[59]);
}
throw $e723724;
}
var $ret729730 = $Hanf_arg849734($z725726,acc110722,if_helper458717,_plus9);
++R.GAS;
return $ret729730;
};
var $Hanf_arg849734 = function(anf_arg464733,acc110722,if_helper458717,_plus9) {
var $z737738 = D;
var $f743744 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg464733,acc110722):R.ffi.throwNonFunApp(L[59],_plus9,[anf_arg464733,acc110722]);
};
try {
if(--R.GAS > 0) {
$z737738 = $f743744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f743744,
"from":L[59]});
}
} catch($e735736) {
if(R.isCont($e735736)) {
var $ss739740 = {"from":L[59],
"go":function(cont_tail_arg465745) {
return $Hcont_tail_arg848746(cont_tail_arg465745,if_helper458717);
}};
$e735736.stack[R.EXN_STACKHEIGHT++] = $ss739740;
}
if(R.isPyretException($e735736)) {
$e735736.pyretStack.push(L[59]);
}
throw $e735736;
}
var $ret741742 = $Hcont_tail_arg848746($z737738,if_helper458717);
++R.GAS;
return $ret741742;
};
var $Hcont_tail_arg848746 = function(cont_tail_arg465745,if_helper458717) {
if(--R.GAS > 0) {
$z747748 = R.isFunction(if_helper458717)?if_helper458717.app(cont_tail_arg465745):R.ffi.throwNonFunApp(L[59],if_helper458717,[cont_tail_arg465745]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper458717)?if_helper458717.app(cont_tail_arg465745):R.ffi.throwNonFunApp(L[59],if_helper458717,[cont_tail_arg465745]);
},
"from":L[59]});
}
++R.GAS;
return $z747748;
};
var $Hanf_arg846749 = function(anf_arg450750,_plus9) {
var $z753754 = D;
var $f759760 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg450750,(")")):R.ffi.throwNonFunApp(L[60],_plus9,[anf_arg450750,(")")]);
};
try {
if(--R.GAS > 0) {
$z753754 = $f759760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f759760,
"from":L[60]});
}
} catch($e751752) {
if(R.isCont($e751752)) {
var $ss755756 = {"from":L[60],
"go":function(anf_arg451761) {
return $Hanf_arg845762(anf_arg451761,_plus9);
}};
$e751752.stack[R.EXN_STACKHEIGHT++] = $ss755756;
}
if(R.isPyretException($e751752)) {
$e751752.pyretStack.push(L[60]);
}
throw $e751752;
}
var $ret757758 = $Hanf_arg845762($z753754,_plus9);
++R.GAS;
return $ret757758;
};
var $Hanf_arg845762 = function(anf_arg451761,_plus9) {
var $z765766 = D;
var $f771772 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg451761):R.ffi.throwNonFunApp(L[60],_plus9,[("("),anf_arg451761]);
};
try {
if(--R.GAS > 0) {
$z765766 = $f771772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f771772,
"from":L[60]});
}
} catch($e763764) {
if(R.isCont($e763764)) {
var $ss767768 = {"from":L[60],
"go":function(anf_arg452773) {
return $Hanf_arg844774(anf_arg452773,_plus9);
}};
$e763764.stack[R.EXN_STACKHEIGHT++] = $ss767768;
}
if(R.isPyretException($e763764)) {
$e763764.pyretStack.push(L[60]);
}
throw $e763764;
}
var $ret769770 = $Hanf_arg844774($z765766,_plus9);
++R.GAS;
return $ret769770;
};
var $Hanf_arg844774 = function(anf_arg452773,_plus9) {
var $z777778 = D;
var $f783784 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("list-set"),anf_arg452773):R.ffi.throwNonFunApp(L[60],_plus9,[("list-set"),anf_arg452773]);
};
try {
if(--R.GAS > 0) {
$z777778 = $f783784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f783784,
"from":L[60]});
}
} catch($e775776) {
if(R.isCont($e775776)) {
var $ss779780 = {"from":L[60],
"go":function(ann_DASH_check_DASH_temp448785) {
return $Hann_DASH_check_DASH_temp843786(ann_DASH_check_DASH_temp448785);
}};
$e775776.stack[R.EXN_STACKHEIGHT++] = $ss779780;
}
if(R.isPyretException($e775776)) {
$e775776.pyretStack.push(L[60]);
}
throw $e775776;
}
var $ret781782 = $Hann_DASH_check_DASH_temp843786($z777778);
++R.GAS;
return $ret781782;
};
var $Hann_DASH_check_DASH_temp843786 = function(ann_DASH_check_DASH_temp448785) {
return ann_DASH_check_DASH_temp448785;
};
var $Hcont_tail_arg841787 = function(cont_tail_arg445788,if_helper437789) {
if(--R.GAS > 0) {
$z790791 = R.isFunction(if_helper437789)?if_helper437789.app(cont_tail_arg445788):R.ffi.throwNonFunApp(L[60],if_helper437789,[cont_tail_arg445788]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper437789)?if_helper437789.app(cont_tail_arg445788):R.ffi.throwNonFunApp(L[60],if_helper437789,[cont_tail_arg445788]);
},
"from":L[60]});
}
++R.GAS;
return $z790791;
};
var $Hcont_tail_arg842792 = function(cont_tail_arg442793,if_helper437789) {
if(--R.GAS > 0) {
$z794795 = R.isFunction(if_helper437789)?if_helper437789.app(cont_tail_arg442793):R.ffi.throwNonFunApp(L[60],if_helper437789,[cont_tail_arg442793]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper437789)?if_helper437789.app(cont_tail_arg442793):R.ffi.throwNonFunApp(L[60],if_helper437789,[cont_tail_arg442793]);
},
"from":L[60]});
}
++R.GAS;
return $z794795;
};
var $Hand_DASH_oper_DASH_840796 = function(and_DASH_oper_DASH_54797,other166798,self165799) {
var if_helper417812 = R.makeFunction(function(if_helper_arg418830) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[63],1,arguments);
}
var ann_DASH_check_DASH_temp416831 = if_helper_arg418830;
return ann_DASH_check_DASH_temp416831;
});
var anf_if421829 = R.isBoolean(and_DASH_oper_DASH_54797);
if(R.isPyretTrue(anf_if421829)) {
if(R.isPyretTrue(and_DASH_oper_DASH_54797)) {
var anf_fun423810 = G(self165799,"to-list",L[62]);
var $z802803 = D;
var $f808809 = function(_) {
return R.isFunction(anf_fun423810)?anf_fun423810.app():R.ffi.throwNonFunApp(L[61],anf_fun423810,[]);
};
try {
if(--R.GAS > 0) {
$z802803 = $f808809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f808809,
"from":L[61]});
}
} catch($e800801) {
if(R.isCont($e800801)) {
var $ss804805 = {"from":L[61],
"go":function(anf_bracket424811) {
return $Hanf_bracket838813(anf_bracket424811,if_helper417812,other166798);
}};
$e800801.stack[R.EXN_STACKHEIGHT++] = $ss804805;
}
if(R.isPyretException($e800801)) {
$e800801.pyretStack.push(L[61]);
}
throw $e800801;
}
var $ret806807 = $Hanf_bracket838813($z802803,if_helper417812,other166798);
++R.GAS;
return $ret806807;
} else {
var $z816817 = D;
var $f822823 = function(_) {
return R.isFunction(if_helper417812)?if_helper417812.app((false)):R.ffi.throwNonFunApp(L[63],if_helper417812,[(false)]);
};
try {
if(--R.GAS > 0) {
$z816817 = $f822823();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f822823,
"from":L[63]});
}
} catch($e814815) {
if(R.isCont($e814815)) {
var $ss818819 = {"from":L[63],
"go":function(cont_tail_app422824) {
return $Hcont_tail_app839825(cont_tail_app422824);
}};
$e814815.stack[R.EXN_STACKHEIGHT++] = $ss818819;
}
if(R.isPyretException($e814815)) {
$e814815.pyretStack.push(L[63]);
}
throw $e814815;
}
var $ret820821 = $Hcont_tail_app839825($z816817);
++R.GAS;
return $ret820821;
}
} else {
var cont_tail_arg419828 = R.throwNonBooleanOp(L[64],("first"),("and"),and_DASH_oper_DASH_54797);
if(--R.GAS > 0) {
$z826827 = R.isFunction(if_helper417812)?if_helper417812.app(cont_tail_arg419828):R.ffi.throwNonFunApp(L[64],if_helper417812,[cont_tail_arg419828]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper417812)?if_helper417812.app(cont_tail_arg419828):R.ffi.throwNonFunApp(L[64],if_helper417812,[cont_tail_arg419828]);
},
"from":L[64]});
}
++R.GAS;
return $z826827;
}
};
var $Hanf_bracket838813 = function(anf_bracket424811,if_helper417812,other166798) {
var anf_fun425842 = G(anf_bracket424811,"sort",L[66]);
var $z834835 = D;
var $f840841 = function(_) {
return R.isFunction(anf_fun425842)?anf_fun425842.app():R.ffi.throwNonFunApp(L[65],anf_fun425842,[]);
};
try {
if(--R.GAS > 0) {
$z834835 = $f840841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f840841,
"from":L[65]});
}
} catch($e832833) {
if(R.isCont($e832833)) {
var $ss836837 = {"from":L[65],
"go":function(anf_arg426843) {
return $Hanf_arg837844(anf_arg426843,if_helper417812,other166798);
}};
$e832833.stack[R.EXN_STACKHEIGHT++] = $ss836837;
}
if(R.isPyretException($e832833)) {
$e832833.pyretStack.push(L[65]);
}
throw $e832833;
}
var $ret838839 = $Hanf_arg837844($z834835,if_helper417812,other166798);
++R.GAS;
return $ret838839;
};
var $Hanf_arg837844 = function(anf_arg426843,if_helper417812,other166798) {
var anf_fun427855 = G(other166798,"to-list",L[68]);
var $z847848 = D;
var $f853854 = function(_) {
return R.isFunction(anf_fun427855)?anf_fun427855.app():R.ffi.throwNonFunApp(L[67],anf_fun427855,[]);
};
try {
if(--R.GAS > 0) {
$z847848 = $f853854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f853854,
"from":L[67]});
}
} catch($e845846) {
if(R.isCont($e845846)) {
var $ss849850 = {"from":L[67],
"go":function(anf_bracket428856) {
return $Hanf_bracket836857(anf_bracket428856,anf_arg426843,if_helper417812);
}};
$e845846.stack[R.EXN_STACKHEIGHT++] = $ss849850;
}
if(R.isPyretException($e845846)) {
$e845846.pyretStack.push(L[67]);
}
throw $e845846;
}
var $ret851852 = $Hanf_bracket836857($z847848,anf_arg426843,if_helper417812);
++R.GAS;
return $ret851852;
};
var $Hanf_bracket836857 = function(anf_bracket428856,anf_arg426843,if_helper417812) {
var anf_fun429868 = G(anf_bracket428856,"sort",L[70]);
var $z860861 = D;
var $f866867 = function(_) {
return R.isFunction(anf_fun429868)?anf_fun429868.app():R.ffi.throwNonFunApp(L[69],anf_fun429868,[]);
};
try {
if(--R.GAS > 0) {
$z860861 = $f866867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f866867,
"from":L[69]});
}
} catch($e858859) {
if(R.isCont($e858859)) {
var $ss862863 = {"from":L[69],
"go":function(anf_arg430869) {
return $Hanf_arg835870(anf_arg430869,anf_arg426843,if_helper417812);
}};
$e858859.stack[R.EXN_STACKHEIGHT++] = $ss862863;
}
if(R.isPyretException($e858859)) {
$e858859.pyretStack.push(L[69]);
}
throw $e858859;
}
var $ret864865 = $Hanf_arg835870($z860861,anf_arg426843,if_helper417812);
++R.GAS;
return $ret864865;
};
var $Hanf_arg835870 = function(anf_arg430869,anf_arg426843,if_helper417812) {
var and_DASH_oper_DASH_55881 = R.equiv(anf_arg426843,anf_arg430869);
var anf_if433887 = R.isBoolean(and_DASH_oper_DASH_55881);
if(R.isPyretTrue(anf_if433887)) {
var $z873874 = D;
var $f879880 = function(_) {
return R.isFunction(if_helper417812)?if_helper417812.app(and_DASH_oper_DASH_55881):R.ffi.throwNonFunApp(L[63],if_helper417812,[and_DASH_oper_DASH_55881]);
};
try {
if(--R.GAS > 0) {
$z873874 = $f879880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f879880,
"from":L[63]});
}
} catch($e871872) {
if(R.isCont($e871872)) {
var $ss875876 = {"from":L[63],
"go":function(cont_tail_app434882) {
return $Hcont_tail_app834883(cont_tail_app434882);
}};
$e871872.stack[R.EXN_STACKHEIGHT++] = $ss875876;
}
if(R.isPyretException($e871872)) {
$e871872.pyretStack.push(L[63]);
}
throw $e871872;
}
var $ret877878 = $Hcont_tail_app834883($z873874);
++R.GAS;
return $ret877878;
} else {
var cont_tail_arg431886 = R.throwNonBooleanOp(L[71],("second"),("and"),and_DASH_oper_DASH_55881);
if(--R.GAS > 0) {
$z884885 = R.isFunction(if_helper417812)?if_helper417812.app(cont_tail_arg431886):R.ffi.throwNonFunApp(L[71],if_helper417812,[cont_tail_arg431886]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper417812)?if_helper417812.app(cont_tail_arg431886):R.ffi.throwNonFunApp(L[71],if_helper417812,[cont_tail_arg431886]);
},
"from":L[71]});
}
++R.GAS;
return $z884885;
}
};
var $Hcont_tail_app834883 = function(cont_tail_app434882) {
return cont_tail_app434882;
};
var $Hcont_tail_app839825 = function(cont_tail_app422824) {
return cont_tail_app422824;
};
var $Hanf_bracket833888 = function(anf_bracket411889,Set1137,other164890,self163891) {
var anf_fun412904 = G(anf_bracket411889,"difference",L[74]);
var anf_fun413902 = G(self163891,"intersect",L[73]);
var $z894895 = D;
var $f900901 = function(_) {
return R.isFunction(anf_fun413902)?anf_fun413902.app(other164890):R.ffi.throwNonFunApp(L[72],anf_fun413902,[other164890]);
};
try {
if(--R.GAS > 0) {
$z894895 = $f900901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f900901,
"from":L[72]});
}
} catch($e892893) {
if(R.isCont($e892893)) {
var $ss896897 = {"from":L[72],
"go":function(anf_arg414903) {
return $Hanf_arg832905(anf_arg414903,Set1137,anf_fun412904);
}};
$e892893.stack[R.EXN_STACKHEIGHT++] = $ss896897;
}
if(R.isPyretException($e892893)) {
$e892893.pyretStack.push(L[72]);
}
throw $e892893;
}
var $ret898899 = $Hanf_arg832905($z894895,Set1137,anf_fun412904);
++R.GAS;
return $ret898899;
};
var $Hanf_arg832905 = function(anf_arg414903,Set1137,anf_fun412904) {
var $z908909 = D;
var $f914915 = function(_) {
return R.isFunction(anf_fun412904)?anf_fun412904.app(anf_arg414903):R.ffi.throwNonFunApp(L[75],anf_fun412904,[anf_arg414903]);
};
try {
if(--R.GAS > 0) {
$z908909 = $f914915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f914915,
"from":L[75]});
}
} catch($e906907) {
if(R.isCont($e906907)) {
var $ss910911 = {"from":L[75],
"go":function(ann_DASH_check_DASH_temp409916) {
return $Hann_DASH_check_DASH_temp831917(ann_DASH_check_DASH_temp409916,Set1137);
}};
$e906907.stack[R.EXN_STACKHEIGHT++] = $ss910911;
}
if(R.isPyretException($e906907)) {
$e906907.pyretStack.push(L[75]);
}
throw $e906907;
}
var $ret912913 = $Hann_DASH_check_DASH_temp831917($z908909,Set1137);
++R.GAS;
return $ret912913;
};
var $Hann_DASH_check_DASH_temp831917 = function(ann_DASH_check_DASH_temp409916,Set1137) {
return ann_DASH_check_DASH_temp409916;
};
var $Hanf_bracket830918 = function(anf_bracket402919,mkbranch26920,rebalance27921,remove_DASH_greatest_DASH_and_DASH_rebalance96922,tree94923) {
var anf_arg403936 = G(anf_bracket402919,"value",L[78]);
var anf_arg404934 = G(tree94923,"left",L[77]);
var $z926927 = D;
var $f932933 = function(_) {
return R.isFunction(remove_DASH_greatest_DASH_and_DASH_rebalance96922.$var)?remove_DASH_greatest_DASH_and_DASH_rebalance96922.$var.app(anf_arg404934):R.ffi.throwNonFunApp(L[76],remove_DASH_greatest_DASH_and_DASH_rebalance96922.$var,[anf_arg404934]);
};
try {
if(--R.GAS > 0) {
$z926927 = $f932933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f932933,
"from":L[76]});
}
} catch($e924925) {
if(R.isCont($e924925)) {
var $ss928929 = {"from":L[76],
"go":function(anf_arg405935) {
return $Hanf_arg829937(anf_arg405935,anf_arg403936,mkbranch26920,rebalance27921,tree94923);
}};
$e924925.stack[R.EXN_STACKHEIGHT++] = $ss928929;
}
if(R.isPyretException($e924925)) {
$e924925.pyretStack.push(L[76]);
}
throw $e924925;
}
var $ret930931 = $Hanf_arg829937($z926927,anf_arg403936,mkbranch26920,rebalance27921,tree94923);
++R.GAS;
return $ret930931;
};
var $Hanf_arg829937 = function(anf_arg405935,anf_arg403936,mkbranch26920,rebalance27921,tree94923) {
var anf_arg406948 = G(tree94923,"right",L[80]);
var $z940941 = D;
var $f946947 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg403936,anf_arg405935,anf_arg406948):R.ffi.throwNonFunApp(L[79],mkbranch26920.$var,[anf_arg403936,anf_arg405935,anf_arg406948]);
};
try {
if(--R.GAS > 0) {
$z940941 = $f946947();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f946947,
"from":L[79]});
}
} catch($e938939) {
if(R.isCont($e938939)) {
var $ss942943 = {"from":L[79],
"go":function(anf_arg407949) {
return $Hanf_arg828950(anf_arg407949,rebalance27921);
}};
$e938939.stack[R.EXN_STACKHEIGHT++] = $ss942943;
}
if(R.isPyretException($e938939)) {
$e938939.pyretStack.push(L[79]);
}
throw $e938939;
}
var $ret944945 = $Hanf_arg828950($z940941,rebalance27921);
++R.GAS;
return $ret944945;
};
var $Hanf_arg828950 = function(anf_arg407949,rebalance27921) {
var $z953954 = D;
var $f959960 = function(_) {
return R.isFunction(rebalance27921.$var)?rebalance27921.$var.app(anf_arg407949):R.ffi.throwNonFunApp(L[81],rebalance27921.$var,[anf_arg407949]);
};
try {
if(--R.GAS > 0) {
$z953954 = $f959960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f959960,
"from":L[81]});
}
} catch($e951952) {
if(R.isCont($e951952)) {
var $ss955956 = {"from":L[81],
"go":function(ann_DASH_check_DASH_temp362961) {
return $Hann_DASH_check_DASH_temp827962(ann_DASH_check_DASH_temp362961);
}};
$e951952.stack[R.EXN_STACKHEIGHT++] = $ss955956;
}
if(R.isPyretException($e951952)) {
$e951952.pyretStack.push(L[81]);
}
throw $e951952;
}
var $ret957958 = $Hann_DASH_check_DASH_temp827962($z953954);
++R.GAS;
return $ret957958;
};
var $Hann_DASH_check_DASH_temp827962 = function(ann_DASH_check_DASH_temp362961) {
return ann_DASH_check_DASH_temp362961;
};
var $Hann_DASH_check_DASH_temp826963 = function(ann_DASH_check_DASH_temp381964) {
return ann_DASH_check_DASH_temp381964;
};
var $Hif_DASH_825965 = function(if_DASH_31966,left105967,mkbranch26920,rebalance27921,remove_DASH_greatest_DASH_and_DASH_rebalance96922,right106968,val103969) {
var if_helper386980 = R.makeFunction(function(if_helper_arg387999) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[84],1,arguments);
}
var ann_DASH_check_DASH_temp3851000 = if_helper_arg387999;
return ann_DASH_check_DASH_temp3851000;
});
var anf_if390998 = R.isBoolean(if_DASH_31966);
if(R.isPyretTrue(anf_if390998)) {
if(R.isPyretTrue(if_DASH_31966)) {
var $z972973 = D;
var $f978979 = function(_) {
return R.isFunction(if_helper386980)?if_helper386980.app(left105967):R.ffi.throwNonFunApp(L[82],if_helper386980,[left105967]);
};
try {
if(--R.GAS > 0) {
$z972973 = $f978979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f978979,
"from":L[82]});
}
} catch($e970971) {
if(R.isCont($e970971)) {
var $ss974975 = {"from":L[82],
"go":function(cont_tail_app395981) {
return $Hcont_tail_app821982(cont_tail_app395981);
}};
$e970971.stack[R.EXN_STACKHEIGHT++] = $ss974975;
}
if(R.isPyretException($e970971)) {
$e970971.pyretStack.push(L[82]);
}
throw $e970971;
}
var $ret976977 = $Hcont_tail_app821982($z972973);
++R.GAS;
return $ret976977;
} else {
var $z985986 = D;
var $f991992 = function(_) {
return R.isFunction(remove_DASH_greatest_DASH_and_DASH_rebalance96922.$var)?remove_DASH_greatest_DASH_and_DASH_rebalance96922.$var.app(right106968):R.ffi.throwNonFunApp(L[83],remove_DASH_greatest_DASH_and_DASH_rebalance96922.$var,[right106968]);
};
try {
if(--R.GAS > 0) {
$z985986 = $f991992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f991992,
"from":L[83]});
}
} catch($e983984) {
if(R.isCont($e983984)) {
var $ss987988 = {"from":L[83],
"go":function(anf_arg391993) {
return $Hanf_arg824994(anf_arg391993,if_helper386980,left105967,mkbranch26920,rebalance27921,val103969);
}};
$e983984.stack[R.EXN_STACKHEIGHT++] = $ss987988;
}
if(R.isPyretException($e983984)) {
$e983984.pyretStack.push(L[83]);
}
throw $e983984;
}
var $ret989990 = $Hanf_arg824994($z985986,if_helper386980,left105967,mkbranch26920,rebalance27921,val103969);
++R.GAS;
return $ret989990;
}
} else {
var cont_tail_arg388997 = R.throwNonBooleanCondition(L[84],("if"),if_DASH_31966);
if(--R.GAS > 0) {
$z995996 = R.isFunction(if_helper386980)?if_helper386980.app(cont_tail_arg388997):R.ffi.throwNonFunApp(L[84],if_helper386980,[cont_tail_arg388997]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper386980)?if_helper386980.app(cont_tail_arg388997):R.ffi.throwNonFunApp(L[84],if_helper386980,[cont_tail_arg388997]);
},
"from":L[84]});
}
++R.GAS;
return $z995996;
}
};
var $Hcont_tail_app821982 = function(cont_tail_app395981) {
return cont_tail_app395981;
};
var $Hanf_arg824994 = function(anf_arg391993,if_helper386980,left105967,mkbranch26920,rebalance27921,val103969) {
var $z10031004 = D;
var $f10091010 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(val103969,left105967,anf_arg391993):R.ffi.throwNonFunApp(L[85],mkbranch26920.$var,[val103969,left105967,anf_arg391993]);
};
try {
if(--R.GAS > 0) {
$z10031004 = $f10091010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10091010,
"from":L[85]});
}
} catch($e10011002) {
if(R.isCont($e10011002)) {
var $ss10051006 = {"from":L[85],
"go":function(anf_arg3921011) {
return $Hanf_arg8231012(anf_arg3921011,if_helper386980,rebalance27921);
}};
$e10011002.stack[R.EXN_STACKHEIGHT++] = $ss10051006;
}
if(R.isPyretException($e10011002)) {
$e10011002.pyretStack.push(L[85]);
}
throw $e10011002;
}
var $ret10071008 = $Hanf_arg8231012($z10031004,if_helper386980,rebalance27921);
++R.GAS;
return $ret10071008;
};
var $Hanf_arg8231012 = function(anf_arg3921011,if_helper386980,rebalance27921) {
var $z10151016 = D;
var $f10211022 = function(_) {
return R.isFunction(rebalance27921.$var)?rebalance27921.$var.app(anf_arg3921011):R.ffi.throwNonFunApp(L[86],rebalance27921.$var,[anf_arg3921011]);
};
try {
if(--R.GAS > 0) {
$z10151016 = $f10211022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10211022,
"from":L[86]});
}
} catch($e10131014) {
if(R.isCont($e10131014)) {
var $ss10171018 = {"from":L[86],
"go":function(cont_tail_arg3931023) {
return $Hcont_tail_arg8221024(cont_tail_arg3931023,if_helper386980);
}};
$e10131014.stack[R.EXN_STACKHEIGHT++] = $ss10171018;
}
if(R.isPyretException($e10131014)) {
$e10131014.pyretStack.push(L[86]);
}
throw $e10131014;
}
var $ret10191020 = $Hcont_tail_arg8221024($z10151016,if_helper386980);
++R.GAS;
return $ret10191020;
};
var $Hcont_tail_arg8221024 = function(cont_tail_arg3931023,if_helper386980) {
if(--R.GAS > 0) {
$z10251026 = R.isFunction(if_helper386980)?if_helper386980.app(cont_tail_arg3931023):R.ffi.throwNonFunApp(L[86],if_helper386980,[cont_tail_arg3931023]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper386980)?if_helper386980.app(cont_tail_arg3931023):R.ffi.throwNonFunApp(L[86],if_helper386980,[cont_tail_arg3931023]);
},
"from":L[86]});
}
++R.GAS;
return $z10251026;
};
var $Hann_DASH_check_DASH_temp8201027 = function(ann_DASH_check_DASH_temp3831028) {
return ann_DASH_check_DASH_temp3831028;
};
var $Hann_DASH_check_DASH_temp8191029 = function(ann_DASH_check_DASH_temp3631030) {
return ann_DASH_check_DASH_temp3631030;
};
var $Hif_DASH_8181031 = function(if_DASH_291032,greatest951033,right1011034,t971035) {
var if_helper3681046 = R.makeFunction(function(if_helper_arg3691065) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[89],1,arguments);
}
var ann_DASH_check_DASH_temp3671066 = if_helper_arg3691065;
return ann_DASH_check_DASH_temp3671066;
});
var anf_if3721064 = R.isBoolean(if_DASH_291032);
if(R.isPyretTrue(anf_if3721064)) {
if(R.isPyretTrue(if_DASH_291032)) {
var $z10381039 = D;
var $f10441045 = function(_) {
return R.isFunction(if_helper3681046)?if_helper3681046.app(t971035):R.ffi.throwNonFunApp(L[87],if_helper3681046,[t971035]);
};
try {
if(--R.GAS > 0) {
$z10381039 = $f10441045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10441045,
"from":L[87]});
}
} catch($e10361037) {
if(R.isCont($e10361037)) {
var $ss10401041 = {"from":L[87],
"go":function(cont_tail_app3751047) {
return $Hcont_tail_app8161048(cont_tail_app3751047);
}};
$e10361037.stack[R.EXN_STACKHEIGHT++] = $ss10401041;
}
if(R.isPyretException($e10361037)) {
$e10361037.pyretStack.push(L[87]);
}
throw $e10361037;
}
var $ret10421043 = $Hcont_tail_app8161048($z10381039);
++R.GAS;
return $ret10421043;
} else {
var $z10511052 = D;
var $f10571058 = function(_) {
return R.isFunction(greatest951033.$var)?greatest951033.$var.app(right1011034):R.ffi.throwNonFunApp(L[88],greatest951033.$var,[right1011034]);
};
try {
if(--R.GAS > 0) {
$z10511052 = $f10571058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10571058,
"from":L[88]});
}
} catch($e10491050) {
if(R.isCont($e10491050)) {
var $ss10531054 = {"from":L[88],
"go":function(cont_tail_arg3731059) {
return $Hcont_tail_arg8171060(cont_tail_arg3731059,if_helper3681046);
}};
$e10491050.stack[R.EXN_STACKHEIGHT++] = $ss10531054;
}
if(R.isPyretException($e10491050)) {
$e10491050.pyretStack.push(L[88]);
}
throw $e10491050;
}
var $ret10551056 = $Hcont_tail_arg8171060($z10511052,if_helper3681046);
++R.GAS;
return $ret10551056;
}
} else {
var cont_tail_arg3701063 = R.throwNonBooleanCondition(L[89],("if"),if_DASH_291032);
if(--R.GAS > 0) {
$z10611062 = R.isFunction(if_helper3681046)?if_helper3681046.app(cont_tail_arg3701063):R.ffi.throwNonFunApp(L[89],if_helper3681046,[cont_tail_arg3701063]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper3681046)?if_helper3681046.app(cont_tail_arg3701063):R.ffi.throwNonFunApp(L[89],if_helper3681046,[cont_tail_arg3701063]);
},
"from":L[89]});
}
++R.GAS;
return $z10611062;
}
};
var $Hcont_tail_app8161048 = function(cont_tail_app3751047) {
return cont_tail_app3751047;
};
var $Hcont_tail_arg8171060 = function(cont_tail_arg3731059,if_helper3681046) {
if(--R.GAS > 0) {
$z10671068 = R.isFunction(if_helper3681046)?if_helper3681046.app(cont_tail_arg3731059):R.ffi.throwNonFunApp(L[88],if_helper3681046,[cont_tail_arg3731059]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper3681046)?if_helper3681046.app(cont_tail_arg3731059):R.ffi.throwNonFunApp(L[88],if_helper3681046,[cont_tail_arg3731059]);
},
"from":L[88]});
}
++R.GAS;
return $z10671068;
};
var $Hann_DASH_check_DASH_temp8151069 = function(ann_DASH_check_DASH_temp3651070) {
return ann_DASH_check_DASH_temp3651070;
};
var $Hif_DASH_8141071 = function(if_DASH_271072,is_DASH_leaf211073,leaf2241,swap_DASH_next_DASH_lowest291074,tree931075) {
var if_helper3411088 = R.makeFunction(function(if_helper_arg3421107) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[94],1,arguments);
}
var ann_DASH_check_DASH_temp3391108 = if_helper_arg3421107;
return ann_DASH_check_DASH_temp3391108;
});
var anf_if3451106 = R.isBoolean(if_DASH_271072);
if(R.isPyretTrue(anf_if3451106)) {
if(R.isPyretTrue(if_DASH_271072)) {
var anf_arg3541086 = G(tree931075,"right",L[91]);
var $z10781079 = D;
var $f10841085 = function(_) {
return R.isFunction(is_DASH_leaf211073.$var)?is_DASH_leaf211073.$var.app(anf_arg3541086):R.ffi.throwNonFunApp(L[90],is_DASH_leaf211073.$var,[anf_arg3541086]);
};
try {
if(--R.GAS > 0) {
$z10781079 = $f10841085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10841085,
"from":L[90]});
}
} catch($e10761077) {
if(R.isCont($e10761077)) {
var $ss10801081 = {"from":L[90],
"go":function(if_DASH_281087) {
return $Hif_DASH_8111089(if_DASH_281087,if_helper3411088,leaf2241,tree931075);
}};
$e10761077.stack[R.EXN_STACKHEIGHT++] = $ss10801081;
}
if(R.isPyretException($e10761077)) {
$e10761077.pyretStack.push(L[90]);
}
throw $e10761077;
}
var $ret10821083 = $Hif_DASH_8111089($z10781079,if_helper3411088,leaf2241,tree931075);
++R.GAS;
return $ret10821083;
} else {
var anf_arg3461100 = G(tree931075,"right",L[93]);
var $z10921093 = D;
var $f10981099 = function(_) {
return R.isFunction(is_DASH_leaf211073.$var)?is_DASH_leaf211073.$var.app(anf_arg3461100):R.ffi.throwNonFunApp(L[92],is_DASH_leaf211073.$var,[anf_arg3461100]);
};
try {
if(--R.GAS > 0) {
$z10921093 = $f10981099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10981099,
"from":L[92]});
}
} catch($e10901091) {
if(R.isCont($e10901091)) {
var $ss10941095 = {"from":L[92],
"go":function(if_DASH_261101) {
return $Hif_DASH_8131102(if_DASH_261101,if_helper3411088,swap_DASH_next_DASH_lowest291074,tree931075);
}};
$e10901091.stack[R.EXN_STACKHEIGHT++] = $ss10941095;
}
if(R.isPyretException($e10901091)) {
$e10901091.pyretStack.push(L[92]);
}
throw $e10901091;
}
var $ret10961097 = $Hif_DASH_8131102($z10921093,if_helper3411088,swap_DASH_next_DASH_lowest291074,tree931075);
++R.GAS;
return $ret10961097;
}
} else {
var cont_tail_arg3431105 = R.throwNonBooleanCondition(L[94],("if"),if_DASH_271072);
if(--R.GAS > 0) {
$z11031104 = R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3431105):R.ffi.throwNonFunApp(L[94],if_helper3411088,[cont_tail_arg3431105]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3431105):R.ffi.throwNonFunApp(L[94],if_helper3411088,[cont_tail_arg3431105]);
},
"from":L[94]});
}
++R.GAS;
return $z11031104;
}
};
var $Hif_DASH_8111089 = function(if_DASH_281087,if_helper3411088,leaf2241,tree931075) {
var anf_if3571127 = R.isBoolean(if_DASH_281087);
if(R.isPyretTrue(anf_if3571127)) {
if(R.isPyretTrue(if_DASH_281087)) {
var $z11111112 = D;
var $f11171118 = function(_) {
return R.isFunction(if_helper3411088)?if_helper3411088.app(leaf2241.$var):R.ffi.throwNonFunApp(L[95],if_helper3411088,[leaf2241.$var]);
};
try {
if(--R.GAS > 0) {
$z11111112 = $f11171118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11171118,
"from":L[95]});
}
} catch($e11091110) {
if(R.isCont($e11091110)) {
var $ss11131114 = {"from":L[95],
"go":function(cont_tail_app3601119) {
return $Hcont_tail_app8101120(cont_tail_app3601119);
}};
$e11091110.stack[R.EXN_STACKHEIGHT++] = $ss11131114;
}
if(R.isPyretException($e11091110)) {
$e11091110.pyretStack.push(L[95]);
}
throw $e11091110;
}
var $ret11151116 = $Hcont_tail_app8101120($z11111112);
++R.GAS;
return $ret11151116;
} else {
var cont_tail_arg3581123 = G(tree931075,"right",L[96]);
if(--R.GAS > 0) {
$z11211122 = R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3581123):R.ffi.throwNonFunApp(L[96],if_helper3411088,[cont_tail_arg3581123]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3581123):R.ffi.throwNonFunApp(L[96],if_helper3411088,[cont_tail_arg3581123]);
},
"from":L[96]});
}
++R.GAS;
return $z11211122;
}
} else {
var cont_tail_arg3551126 = R.throwNonBooleanCondition(L[90],("if"),if_DASH_281087);
if(--R.GAS > 0) {
$z11241125 = R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3551126):R.ffi.throwNonFunApp(L[90],if_helper3411088,[cont_tail_arg3551126]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3551126):R.ffi.throwNonFunApp(L[90],if_helper3411088,[cont_tail_arg3551126]);
},
"from":L[90]});
}
++R.GAS;
return $z11241125;
}
};
var $Hcont_tail_app8101120 = function(cont_tail_app3601119) {
return cont_tail_app3601119;
};
var $Hif_DASH_8131102 = function(if_DASH_261101,if_helper3411088,swap_DASH_next_DASH_lowest291074,tree931075) {
var anf_if3491146 = R.isBoolean(if_DASH_261101);
if(R.isPyretTrue(anf_if3491146)) {
if(R.isPyretTrue(if_DASH_261101)) {
var cont_tail_arg3521130 = G(tree931075,"left",L[97]);
if(--R.GAS > 0) {
$z11281129 = R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3521130):R.ffi.throwNonFunApp(L[97],if_helper3411088,[cont_tail_arg3521130]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3521130):R.ffi.throwNonFunApp(L[97],if_helper3411088,[cont_tail_arg3521130]);
},
"from":L[97]});
}
++R.GAS;
return $z11281129;
} else {
var $z11331134 = D;
var $f11391140 = function(_) {
return R.isFunction(swap_DASH_next_DASH_lowest291074.$var === D?U(L[98],"swap-next-lowest"):swap_DASH_next_DASH_lowest291074.$var)?swap_DASH_next_DASH_lowest291074.$var === D?U(L[98],"swap-next-lowest"):swap_DASH_next_DASH_lowest291074.$var.app(tree931075):R.ffi.throwNonFunApp(L[99],swap_DASH_next_DASH_lowest291074.$var === D?U(L[98],"swap-next-lowest"):swap_DASH_next_DASH_lowest291074.$var,[tree931075]);
};
try {
if(--R.GAS > 0) {
$z11331134 = $f11391140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11391140,
"from":L[99]});
}
} catch($e11311132) {
if(R.isCont($e11311132)) {
var $ss11351136 = {"from":L[99],
"go":function(cont_tail_arg3501141) {
return $Hcont_tail_arg8121142(cont_tail_arg3501141,if_helper3411088);
}};
$e11311132.stack[R.EXN_STACKHEIGHT++] = $ss11351136;
}
if(R.isPyretException($e11311132)) {
$e11311132.pyretStack.push(L[99]);
}
throw $e11311132;
}
var $ret11371138 = $Hcont_tail_arg8121142($z11331134,if_helper3411088);
++R.GAS;
return $ret11371138;
}
} else {
var cont_tail_arg3471145 = R.throwNonBooleanCondition(L[92],("if"),if_DASH_261101);
if(--R.GAS > 0) {
$z11431144 = R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3471145):R.ffi.throwNonFunApp(L[92],if_helper3411088,[cont_tail_arg3471145]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3471145):R.ffi.throwNonFunApp(L[92],if_helper3411088,[cont_tail_arg3471145]);
},
"from":L[92]});
}
++R.GAS;
return $z11431144;
}
};
var $Hcont_tail_arg8121142 = function(cont_tail_arg3501141,if_helper3411088) {
if(--R.GAS > 0) {
$z11471148 = R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3501141):R.ffi.throwNonFunApp(L[99],if_helper3411088,[cont_tail_arg3501141]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper3411088)?if_helper3411088.app(cont_tail_arg3501141):R.ffi.throwNonFunApp(L[99],if_helper3411088,[cont_tail_arg3501141]);
},
"from":L[99]});
}
++R.GAS;
return $z11471148;
};
var $Hlh8091149 = function(lh911150,left_DASH_left831151,left_DASH_right851152,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14) {
var anf_bracket2881169 = G(tree821155,"right",L[102]);
var anf_fun2891166 = G(anf_bracket2881169,"height",L[101]);
var $z11581159 = D;
var $f11641165 = function(_) {
return R.isFunction(anf_fun2891166)?anf_fun2891166.app():R.ffi.throwNonFunApp(L[100],anf_fun2891166,[]);
};
try {
if(--R.GAS > 0) {
$z11581159 = $f11641165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11641165,
"from":L[100]});
}
} catch($e11561157) {
if(R.isCont($e11561157)) {
var $ss11601161 = {"from":L[100],
"go":function(rh921167) {
return $Hrh8081168(rh921167,left_DASH_left831151,left_DASH_right851152,lh911150,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14);
}};
$e11561157.stack[R.EXN_STACKHEIGHT++] = $ss11601161;
}
if(R.isPyretException($e11561157)) {
$e11561157.pyretStack.push(L[100]);
}
throw $e11561157;
}
var $ret11621163 = $Hrh8081168($z11581159,left_DASH_left831151,left_DASH_right851152,lh911150,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14);
++R.GAS;
return $ret11621163;
};
var $Hrh8081168 = function(rh921167,left_DASH_left831151,left_DASH_right851152,lh911150,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14) {
var $z11721173 = D;
var $f11781179 = function(_) {
return R.isFunction(_minus8)?_minus8.app(lh911150,rh921167):R.ffi.throwNonFunApp(L[103],_minus8,[lh911150,rh921167]);
};
try {
if(--R.GAS > 0) {
$z11721173 = $f11781179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11781179,
"from":L[103]});
}
} catch($e11701171) {
if(R.isCont($e11701171)) {
var $ss11741175 = {"from":L[103],
"go":function(anf_arg2901180) {
return $Hanf_arg8071181(anf_arg2901180,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14);
}};
$e11701171.stack[R.EXN_STACKHEIGHT++] = $ss11741175;
}
if(R.isPyretException($e11701171)) {
$e11701171.pyretStack.push(L[103]);
}
throw $e11701171;
}
var $ret11761177 = $Hanf_arg8071181($z11721173,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14);
++R.GAS;
return $ret11761177;
};
var $Hanf_arg8071181 = function(anf_arg2901180,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14) {
var $z11841185 = D;
var $f11901191 = function(_) {
return R.isFunction(num_DASH_abs12)?num_DASH_abs12.app(anf_arg2901180):R.ffi.throwNonFunApp(L[104],num_DASH_abs12,[anf_arg2901180]);
};
try {
if(--R.GAS > 0) {
$z11841185 = $f11901191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11901191,
"from":L[104]});
}
} catch($e11821183) {
if(R.isCont($e11821183)) {
var $ss11861187 = {"from":L[104],
"go":function(anf_arg2911192) {
return $Hanf_arg8061193(anf_arg2911192,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,raise14);
}};
$e11821183.stack[R.EXN_STACKHEIGHT++] = $ss11861187;
}
if(R.isPyretException($e11821183)) {
$e11821183.pyretStack.push(L[104]);
}
throw $e11821183;
}
var $ret11881189 = $Hanf_arg8061193($z11841185,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,raise14);
++R.GAS;
return $ret11881189;
};
var $Hanf_arg8061193 = function(anf_arg2911192,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,raise14) {
var $z11961197 = D;
var $f12021203 = function(_) {
return R.isFunction(_lessequal6)?_lessequal6.app(anf_arg2911192,(1)):R.ffi.throwNonFunApp(L[105],_lessequal6,[anf_arg2911192,(1)]);
};
try {
if(--R.GAS > 0) {
$z11961197 = $f12021203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12021203,
"from":L[105]});
}
} catch($e11941195) {
if(R.isCont($e11941195)) {
var $ss11981199 = {"from":L[105],
"go":function(if_DASH_251204) {
return $Hif_DASH_8051205(if_DASH_251204,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_minus8,raise14);
}};
$e11941195.stack[R.EXN_STACKHEIGHT++] = $ss11981199;
}
if(R.isPyretException($e11941195)) {
$e11941195.pyretStack.push(L[105]);
}
throw $e11941195;
}
var $ret12001201 = $Hif_DASH_8051205($z11961197,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_minus8,raise14);
++R.GAS;
return $ret12001201;
};
var $Hif_DASH_8051205 = function(if_DASH_251204,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_minus8,raise14) {
var if_helper2921216 = R.makeFunction(function(if_helper_arg2931235) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[105],1,arguments);
}
var ann_DASH_check_DASH_temp2251236 = if_helper_arg2931235;
return ann_DASH_check_DASH_temp2251236;
});
var anf_if2961234 = R.isBoolean(if_DASH_251204);
if(R.isPyretTrue(anf_if2961234)) {
if(R.isPyretTrue(if_DASH_251204)) {
var $z12081209 = D;
var $f12141215 = function(_) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(tree821155):R.ffi.throwNonFunApp(L[106],if_helper2921216,[tree821155]);
};
try {
if(--R.GAS > 0) {
$z12081209 = $f12141215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12141215,
"from":L[106]});
}
} catch($e12061207) {
if(R.isCont($e12061207)) {
var $ss12101211 = {"from":L[106],
"go":function(cont_tail_app3371217) {
return $Hcont_tail_app7911218(cont_tail_app3371217);
}};
$e12061207.stack[R.EXN_STACKHEIGHT++] = $ss12101211;
}
if(R.isPyretException($e12061207)) {
$e12061207.pyretStack.push(L[106]);
}
throw $e12061207;
}
var $ret12121213 = $Hcont_tail_app7911218($z12081209);
++R.GAS;
return $ret12121213;
} else {
var $z12211222 = D;
var $f12271228 = function(_) {
return R.isFunction(_minus8)?_minus8.app(lh911150,rh921167):R.ffi.throwNonFunApp(L[107],_minus8,[lh911150,rh921167]);
};
try {
if(--R.GAS > 0) {
$z12211222 = $f12271228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12271228,
"from":L[107]});
}
} catch($e12191220) {
if(R.isCont($e12191220)) {
var $ss12231224 = {"from":L[107],
"go":function(anf_arg2971229) {
return $Hanf_arg8041230(anf_arg2971229,if_helper2921216,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_minus8,raise14);
}};
$e12191220.stack[R.EXN_STACKHEIGHT++] = $ss12231224;
}
if(R.isPyretException($e12191220)) {
$e12191220.pyretStack.push(L[107]);
}
throw $e12191220;
}
var $ret12251226 = $Hanf_arg8041230($z12211222,if_helper2921216,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_minus8,raise14);
++R.GAS;
return $ret12251226;
}
} else {
var cont_tail_arg2941233 = R.throwNonBooleanCondition(L[105],("if"),if_DASH_251204);
if(--R.GAS > 0) {
$z12311232 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg2941233):R.ffi.throwNonFunApp(L[105],if_helper2921216,[cont_tail_arg2941233]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg2941233):R.ffi.throwNonFunApp(L[105],if_helper2921216,[cont_tail_arg2941233]);
},
"from":L[105]});
}
++R.GAS;
return $z12311232;
}
};
var $Hcont_tail_app7911218 = function(cont_tail_app3371217) {
return cont_tail_app3371217;
};
var $Hanf_arg8041230 = function(anf_arg2971229,if_helper2921216,left_DASH_left831151,left_DASH_right851152,lh911150,rh921167,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_minus8,raise14) {
var if_DASH_231264 = R.equiv(anf_arg2971229,(2));
var anf_if3001268 = R.isBoolean(if_DASH_231264);
if(R.isPyretTrue(anf_if3001268)) {
if(R.isPyretTrue(if_DASH_231264)) {
var anf_bracket3221251 = G(tree821155,"left",L[111]);
var anf_bracket3231250 = G(anf_bracket3221251,"left",L[110]);
var anf_fun3241247 = G(anf_bracket3231250,"height",L[109]);
var $z12391240 = D;
var $f12451246 = function(_) {
return R.isFunction(anf_fun3241247)?anf_fun3241247.app():R.ffi.throwNonFunApp(L[108],anf_fun3241247,[]);
};
try {
if(--R.GAS > 0) {
$z12391240 = $f12451246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12451246,
"from":L[108]});
}
} catch($e12371238) {
if(R.isCont($e12371238)) {
var $ss12411242 = {"from":L[108],
"go":function(anf_arg3251248) {
return $Hanf_arg7961249(anf_arg3251248,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155,_greaterequal5);
}};
$e12371238.stack[R.EXN_STACKHEIGHT++] = $ss12411242;
}
if(R.isPyretException($e12371238)) {
$e12371238.pyretStack.push(L[108]);
}
throw $e12371238;
}
var $ret12431244 = $Hanf_arg7961249($z12391240,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155,_greaterequal5);
++R.GAS;
return $ret12431244;
} else {
var $z12541255 = D;
var $f12601261 = function(_) {
return R.isFunction(_minus8)?_minus8.app(rh921167,lh911150):R.ffi.throwNonFunApp(L[112],_minus8,[rh921167,lh911150]);
};
try {
if(--R.GAS > 0) {
$z12541255 = $f12601261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12601261,
"from":L[112]});
}
} catch($e12521253) {
if(R.isCont($e12521253)) {
var $ss12561257 = {"from":L[112],
"go":function(anf_arg3011262) {
return $Hanf_arg8031263(anf_arg3011262,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,raise14);
}};
$e12521253.stack[R.EXN_STACKHEIGHT++] = $ss12561257;
}
if(R.isPyretException($e12521253)) {
$e12521253.pyretStack.push(L[112]);
}
throw $e12521253;
}
var $ret12581259 = $Hanf_arg8031263($z12541255,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,raise14);
++R.GAS;
return $ret12581259;
}
} else {
var cont_tail_arg2981267 = R.throwNonBooleanCondition(L[113],("if"),if_DASH_231264);
if(--R.GAS > 0) {
$z12651266 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg2981267):R.ffi.throwNonFunApp(L[113],if_helper2921216,[cont_tail_arg2981267]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg2981267):R.ffi.throwNonFunApp(L[113],if_helper2921216,[cont_tail_arg2981267]);
},
"from":L[113]});
}
++R.GAS;
return $z12651266;
}
};
var $Hanf_arg7961249 = function(anf_arg3251248,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155,_greaterequal5) {
var anf_bracket3261283 = G(tree821155,"left",L[117]);
var anf_bracket3271282 = G(anf_bracket3261283,"right",L[116]);
var anf_fun3281279 = G(anf_bracket3271282,"height",L[115]);
var $z12711272 = D;
var $f12771278 = function(_) {
return R.isFunction(anf_fun3281279)?anf_fun3281279.app():R.ffi.throwNonFunApp(L[114],anf_fun3281279,[]);
};
try {
if(--R.GAS > 0) {
$z12711272 = $f12771278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12771278,
"from":L[114]});
}
} catch($e12691270) {
if(R.isCont($e12691270)) {
var $ss12731274 = {"from":L[114],
"go":function(anf_arg3291280) {
return $Hanf_arg7951281(anf_arg3291280,anf_arg3251248,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155,_greaterequal5);
}};
$e12691270.stack[R.EXN_STACKHEIGHT++] = $ss12731274;
}
if(R.isPyretException($e12691270)) {
$e12691270.pyretStack.push(L[114]);
}
throw $e12691270;
}
var $ret12751276 = $Hanf_arg7951281($z12711272,anf_arg3251248,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155,_greaterequal5);
++R.GAS;
return $ret12751276;
};
var $Hanf_arg7951281 = function(anf_arg3291280,anf_arg3251248,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155,_greaterequal5) {
var $z12861287 = D;
var $f12921293 = function(_) {
return R.isFunction(_greaterequal5)?_greaterequal5.app(anf_arg3251248,anf_arg3291280):R.ffi.throwNonFunApp(L[118],_greaterequal5,[anf_arg3251248,anf_arg3291280]);
};
try {
if(--R.GAS > 0) {
$z12861287 = $f12921293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12921293,
"from":L[118]});
}
} catch($e12841285) {
if(R.isCont($e12841285)) {
var $ss12881289 = {"from":L[118],
"go":function(if_DASH_241294) {
return $Hif_DASH_7941295(if_DASH_241294,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155);
}};
$e12841285.stack[R.EXN_STACKHEIGHT++] = $ss12881289;
}
if(R.isPyretException($e12841285)) {
$e12841285.pyretStack.push(L[118]);
}
throw $e12841285;
}
var $ret12901291 = $Hif_DASH_7941295($z12861287,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155);
++R.GAS;
return $ret12901291;
};
var $Hif_DASH_7941295 = function(if_DASH_241294,if_helper2921216,left_DASH_left831151,left_DASH_right851152,tree821155) {
var anf_if3321323 = R.isBoolean(if_DASH_241294);
if(R.isPyretTrue(anf_if3321323)) {
if(R.isPyretTrue(if_DASH_241294)) {
var $z12981299 = D;
var $f13041305 = function(_) {
return R.isFunction(left_DASH_left831151.$var)?left_DASH_left831151.$var.app(tree821155):R.ffi.throwNonFunApp(L[119],left_DASH_left831151.$var,[tree821155]);
};
try {
if(--R.GAS > 0) {
$z12981299 = $f13041305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13041305,
"from":L[119]});
}
} catch($e12961297) {
if(R.isCont($e12961297)) {
var $ss13001301 = {"from":L[119],
"go":function(cont_tail_arg3351306) {
return $Hcont_tail_arg7921307(cont_tail_arg3351306,if_helper2921216);
}};
$e12961297.stack[R.EXN_STACKHEIGHT++] = $ss13001301;
}
if(R.isPyretException($e12961297)) {
$e12961297.pyretStack.push(L[119]);
}
throw $e12961297;
}
var $ret13021303 = $Hcont_tail_arg7921307($z12981299,if_helper2921216);
++R.GAS;
return $ret13021303;
} else {
var $z13101311 = D;
var $f13161317 = function(_) {
return R.isFunction(left_DASH_right851152.$var)?left_DASH_right851152.$var.app(tree821155):R.ffi.throwNonFunApp(L[120],left_DASH_right851152.$var,[tree821155]);
};
try {
if(--R.GAS > 0) {
$z13101311 = $f13161317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13161317,
"from":L[120]});
}
} catch($e13081309) {
if(R.isCont($e13081309)) {
var $ss13121313 = {"from":L[120],
"go":function(cont_tail_arg3331318) {
return $Hcont_tail_arg7931319(cont_tail_arg3331318,if_helper2921216);
}};
$e13081309.stack[R.EXN_STACKHEIGHT++] = $ss13121313;
}
if(R.isPyretException($e13081309)) {
$e13081309.pyretStack.push(L[120]);
}
throw $e13081309;
}
var $ret13141315 = $Hcont_tail_arg7931319($z13101311,if_helper2921216);
++R.GAS;
return $ret13141315;
}
} else {
var cont_tail_arg3301322 = R.throwNonBooleanCondition(L[118],("if"),if_DASH_241294);
if(--R.GAS > 0) {
$z13201321 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3301322):R.ffi.throwNonFunApp(L[118],if_helper2921216,[cont_tail_arg3301322]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3301322):R.ffi.throwNonFunApp(L[118],if_helper2921216,[cont_tail_arg3301322]);
},
"from":L[118]});
}
++R.GAS;
return $z13201321;
}
};
var $Hcont_tail_arg7921307 = function(cont_tail_arg3351306,if_helper2921216) {
if(--R.GAS > 0) {
$z13241325 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3351306):R.ffi.throwNonFunApp(L[119],if_helper2921216,[cont_tail_arg3351306]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3351306):R.ffi.throwNonFunApp(L[119],if_helper2921216,[cont_tail_arg3351306]);
},
"from":L[119]});
}
++R.GAS;
return $z13241325;
};
var $Hcont_tail_arg7931319 = function(cont_tail_arg3331318,if_helper2921216) {
if(--R.GAS > 0) {
$z13261327 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3331318):R.ffi.throwNonFunApp(L[120],if_helper2921216,[cont_tail_arg3331318]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3331318):R.ffi.throwNonFunApp(L[120],if_helper2921216,[cont_tail_arg3331318]);
},
"from":L[120]});
}
++R.GAS;
return $z13261327;
};
var $Hanf_arg8031263 = function(anf_arg3011262,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,raise14) {
var if_DASH_211355 = R.equiv(anf_arg3011262,(2));
var anf_if3041359 = R.isBoolean(if_DASH_211355);
if(R.isPyretTrue(anf_if3041359)) {
if(R.isPyretTrue(if_DASH_211355)) {
var anf_bracket3071342 = G(tree821155,"right",L[124]);
var anf_bracket3081341 = G(anf_bracket3071342,"right",L[123]);
var anf_fun3091338 = G(anf_bracket3081341,"height",L[122]);
var $z13301331 = D;
var $f13361337 = function(_) {
return R.isFunction(anf_fun3091338)?anf_fun3091338.app():R.ffi.throwNonFunApp(L[121],anf_fun3091338,[]);
};
try {
if(--R.GAS > 0) {
$z13301331 = $f13361337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13361337,
"from":L[121]});
}
} catch($e13281329) {
if(R.isCont($e13281329)) {
var $ss13321333 = {"from":L[121],
"go":function(anf_arg3101339) {
return $Hanf_arg8011340(anf_arg3101339,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5);
}};
$e13281329.stack[R.EXN_STACKHEIGHT++] = $ss13321333;
}
if(R.isPyretException($e13281329)) {
$e13281329.pyretStack.push(L[121]);
}
throw $e13281329;
}
var $ret13341335 = $Hanf_arg8011340($z13301331,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5);
++R.GAS;
return $ret13341335;
} else {
var $z13451346 = D;
var $f13511352 = function(_) {
return R.isFunction(raise14)?raise14.app(("AVL tree invariant has been broken!")):R.ffi.throwNonFunApp(L[125],raise14,[("AVL tree invariant has been broken!")]);
};
try {
if(--R.GAS > 0) {
$z13451346 = $f13511352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13511352,
"from":L[125]});
}
} catch($e13431344) {
if(R.isCont($e13431344)) {
var $ss13471348 = {"from":L[125],
"go":function(cont_tail_arg3051353) {
return $Hcont_tail_arg8021354(cont_tail_arg3051353,if_helper2921216);
}};
$e13431344.stack[R.EXN_STACKHEIGHT++] = $ss13471348;
}
if(R.isPyretException($e13431344)) {
$e13431344.pyretStack.push(L[125]);
}
throw $e13431344;
}
var $ret13491350 = $Hcont_tail_arg8021354($z13451346,if_helper2921216);
++R.GAS;
return $ret13491350;
}
} else {
var cont_tail_arg3021358 = R.throwNonBooleanCondition(L[126],("if"),if_DASH_211355);
if(--R.GAS > 0) {
$z13561357 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3021358):R.ffi.throwNonFunApp(L[126],if_helper2921216,[cont_tail_arg3021358]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3021358):R.ffi.throwNonFunApp(L[126],if_helper2921216,[cont_tail_arg3021358]);
},
"from":L[126]});
}
++R.GAS;
return $z13561357;
}
};
var $Hanf_arg8011340 = function(anf_arg3101339,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5) {
var anf_bracket3111374 = G(tree821155,"right",L[130]);
var anf_bracket3121373 = G(anf_bracket3111374,"left",L[129]);
var anf_fun3131370 = G(anf_bracket3121373,"height",L[128]);
var $z13621363 = D;
var $f13681369 = function(_) {
return R.isFunction(anf_fun3131370)?anf_fun3131370.app():R.ffi.throwNonFunApp(L[127],anf_fun3131370,[]);
};
try {
if(--R.GAS > 0) {
$z13621363 = $f13681369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13681369,
"from":L[127]});
}
} catch($e13601361) {
if(R.isCont($e13601361)) {
var $ss13641365 = {"from":L[127],
"go":function(anf_arg3141371) {
return $Hanf_arg8001372(anf_arg3141371,anf_arg3101339,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5);
}};
$e13601361.stack[R.EXN_STACKHEIGHT++] = $ss13641365;
}
if(R.isPyretException($e13601361)) {
$e13601361.pyretStack.push(L[127]);
}
throw $e13601361;
}
var $ret13661367 = $Hanf_arg8001372($z13621363,anf_arg3101339,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5);
++R.GAS;
return $ret13661367;
};
var $Hanf_arg8001372 = function(anf_arg3141371,anf_arg3101339,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5) {
var $z13771378 = D;
var $f13831384 = function(_) {
return R.isFunction(_greaterequal5)?_greaterequal5.app(anf_arg3101339,anf_arg3141371):R.ffi.throwNonFunApp(L[131],_greaterequal5,[anf_arg3101339,anf_arg3141371]);
};
try {
if(--R.GAS > 0) {
$z13771378 = $f13831384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13831384,
"from":L[131]});
}
} catch($e13751376) {
if(R.isCont($e13751376)) {
var $ss13791380 = {"from":L[131],
"go":function(if_DASH_221385) {
return $Hif_DASH_7991386(if_DASH_221385,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155);
}};
$e13751376.stack[R.EXN_STACKHEIGHT++] = $ss13791380;
}
if(R.isPyretException($e13751376)) {
$e13751376.pyretStack.push(L[131]);
}
throw $e13751376;
}
var $ret13811382 = $Hif_DASH_7991386($z13771378,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155);
++R.GAS;
return $ret13811382;
};
var $Hif_DASH_7991386 = function(if_DASH_221385,if_helper2921216,right_DASH_left861153,right_DASH_right841154,tree821155) {
var anf_if3171414 = R.isBoolean(if_DASH_221385);
if(R.isPyretTrue(anf_if3171414)) {
if(R.isPyretTrue(if_DASH_221385)) {
var $z13891390 = D;
var $f13951396 = function(_) {
return R.isFunction(right_DASH_right841154.$var)?right_DASH_right841154.$var.app(tree821155):R.ffi.throwNonFunApp(L[132],right_DASH_right841154.$var,[tree821155]);
};
try {
if(--R.GAS > 0) {
$z13891390 = $f13951396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13951396,
"from":L[132]});
}
} catch($e13871388) {
if(R.isCont($e13871388)) {
var $ss13911392 = {"from":L[132],
"go":function(cont_tail_arg3201397) {
return $Hcont_tail_arg7971398(cont_tail_arg3201397,if_helper2921216);
}};
$e13871388.stack[R.EXN_STACKHEIGHT++] = $ss13911392;
}
if(R.isPyretException($e13871388)) {
$e13871388.pyretStack.push(L[132]);
}
throw $e13871388;
}
var $ret13931394 = $Hcont_tail_arg7971398($z13891390,if_helper2921216);
++R.GAS;
return $ret13931394;
} else {
var $z14011402 = D;
var $f14071408 = function(_) {
return R.isFunction(right_DASH_left861153.$var)?right_DASH_left861153.$var.app(tree821155):R.ffi.throwNonFunApp(L[133],right_DASH_left861153.$var,[tree821155]);
};
try {
if(--R.GAS > 0) {
$z14011402 = $f14071408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14071408,
"from":L[133]});
}
} catch($e13991400) {
if(R.isCont($e13991400)) {
var $ss14031404 = {"from":L[133],
"go":function(cont_tail_arg3181409) {
return $Hcont_tail_arg7981410(cont_tail_arg3181409,if_helper2921216);
}};
$e13991400.stack[R.EXN_STACKHEIGHT++] = $ss14031404;
}
if(R.isPyretException($e13991400)) {
$e13991400.pyretStack.push(L[133]);
}
throw $e13991400;
}
var $ret14051406 = $Hcont_tail_arg7981410($z14011402,if_helper2921216);
++R.GAS;
return $ret14051406;
}
} else {
var cont_tail_arg3151413 = R.throwNonBooleanCondition(L[131],("if"),if_DASH_221385);
if(--R.GAS > 0) {
$z14111412 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3151413):R.ffi.throwNonFunApp(L[131],if_helper2921216,[cont_tail_arg3151413]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3151413):R.ffi.throwNonFunApp(L[131],if_helper2921216,[cont_tail_arg3151413]);
},
"from":L[131]});
}
++R.GAS;
return $z14111412;
}
};
var $Hcont_tail_arg7971398 = function(cont_tail_arg3201397,if_helper2921216) {
if(--R.GAS > 0) {
$z14151416 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3201397):R.ffi.throwNonFunApp(L[132],if_helper2921216,[cont_tail_arg3201397]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3201397):R.ffi.throwNonFunApp(L[132],if_helper2921216,[cont_tail_arg3201397]);
},
"from":L[132]});
}
++R.GAS;
return $z14151416;
};
var $Hcont_tail_arg7981410 = function(cont_tail_arg3181409,if_helper2921216) {
if(--R.GAS > 0) {
$z14171418 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3181409):R.ffi.throwNonFunApp(L[133],if_helper2921216,[cont_tail_arg3181409]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3181409):R.ffi.throwNonFunApp(L[133],if_helper2921216,[cont_tail_arg3181409]);
},
"from":L[133]});
}
++R.GAS;
return $z14171418;
};
var $Hcont_tail_arg8021354 = function(cont_tail_arg3051353,if_helper2921216) {
if(--R.GAS > 0) {
$z14191420 = R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3051353):R.ffi.throwNonFunApp(L[125],if_helper2921216,[cont_tail_arg3051353]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper2921216)?if_helper2921216.app(cont_tail_arg3051353):R.ffi.throwNonFunApp(L[125],if_helper2921216,[cont_tail_arg3051353]);
},
"from":L[125]});
}
++R.GAS;
return $z14191420;
};
var $Hanf_arg7901421 = function(anf_arg2761422,anf_arg2701423,mkbranch26920,t901424) {
var anf_bracket2771443 = G(t901424,"right",L[141]);
var anf_arg2781435 = G(anf_bracket2771443,"value",L[140]);
var anf_bracket2791442 = G(t901424,"right",L[139]);
var anf_bracket2801441 = G(anf_bracket2791442,"left",L[138]);
var anf_arg2811436 = G(anf_bracket2801441,"right",L[137]);
var anf_bracket2821440 = G(t901424,"right",L[136]);
var anf_arg2831437 = G(anf_bracket2821440,"right",L[135]);
var $z14271428 = D;
var $f14331434 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2781435,anf_arg2811436,anf_arg2831437):R.ffi.throwNonFunApp(L[134],mkbranch26920.$var,[anf_arg2781435,anf_arg2811436,anf_arg2831437]);
};
try {
if(--R.GAS > 0) {
$z14271428 = $f14331434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14331434,
"from":L[134]});
}
} catch($e14251426) {
if(R.isCont($e14251426)) {
var $ss14291430 = {"from":L[134],
"go":function(anf_arg2841438) {
return $Hanf_arg7891439(anf_arg2841438,anf_arg2701423,anf_arg2761422,mkbranch26920);
}};
$e14251426.stack[R.EXN_STACKHEIGHT++] = $ss14291430;
}
if(R.isPyretException($e14251426)) {
$e14251426.pyretStack.push(L[134]);
}
throw $e14251426;
}
var $ret14311432 = $Hanf_arg7891439($z14271428,anf_arg2701423,anf_arg2761422,mkbranch26920);
++R.GAS;
return $ret14311432;
};
var $Hanf_arg7891439 = function(anf_arg2841438,anf_arg2701423,anf_arg2761422,mkbranch26920) {
var $z14461447 = D;
var $f14521453 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2701423,anf_arg2761422,anf_arg2841438):R.ffi.throwNonFunApp(L[142],mkbranch26920.$var,[anf_arg2701423,anf_arg2761422,anf_arg2841438]);
};
try {
if(--R.GAS > 0) {
$z14461447 = $f14521453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14521453,
"from":L[142]});
}
} catch($e14441445) {
if(R.isCont($e14441445)) {
var $ss14481449 = {"from":L[142],
"go":function(ann_DASH_check_DASH_temp2671454) {
return $Hann_DASH_check_DASH_temp7881455(ann_DASH_check_DASH_temp2671454);
}};
$e14441445.stack[R.EXN_STACKHEIGHT++] = $ss14481449;
}
if(R.isPyretException($e14441445)) {
$e14441445.pyretStack.push(L[142]);
}
throw $e14441445;
}
var $ret14501451 = $Hann_DASH_check_DASH_temp7881455($z14461447);
++R.GAS;
return $ret14501451;
};
var $Hann_DASH_check_DASH_temp7881455 = function(ann_DASH_check_DASH_temp2671454) {
return ann_DASH_check_DASH_temp2671454;
};
var $Hanf_arg7871456 = function(anf_arg2591457,anf_arg2511458,mkbranch26920,t891459) {
var anf_arg2601470 = G(t891459,"value",L[148]);
var anf_bracket2611476 = G(t891459,"left",L[147]);
var anf_bracket2621475 = G(anf_bracket2611476,"right",L[146]);
var anf_arg2631471 = G(anf_bracket2621475,"right",L[145]);
var anf_arg2641472 = G(t891459,"right",L[144]);
var $z14621463 = D;
var $f14681469 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2601470,anf_arg2631471,anf_arg2641472):R.ffi.throwNonFunApp(L[143],mkbranch26920.$var,[anf_arg2601470,anf_arg2631471,anf_arg2641472]);
};
try {
if(--R.GAS > 0) {
$z14621463 = $f14681469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14681469,
"from":L[143]});
}
} catch($e14601461) {
if(R.isCont($e14601461)) {
var $ss14641465 = {"from":L[143],
"go":function(anf_arg2651473) {
return $Hanf_arg7861474(anf_arg2651473,anf_arg2511458,anf_arg2591457,mkbranch26920);
}};
$e14601461.stack[R.EXN_STACKHEIGHT++] = $ss14641465;
}
if(R.isPyretException($e14601461)) {
$e14601461.pyretStack.push(L[143]);
}
throw $e14601461;
}
var $ret14661467 = $Hanf_arg7861474($z14621463,anf_arg2511458,anf_arg2591457,mkbranch26920);
++R.GAS;
return $ret14661467;
};
var $Hanf_arg7861474 = function(anf_arg2651473,anf_arg2511458,anf_arg2591457,mkbranch26920) {
var $z14791480 = D;
var $f14851486 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2511458,anf_arg2591457,anf_arg2651473):R.ffi.throwNonFunApp(L[149],mkbranch26920.$var,[anf_arg2511458,anf_arg2591457,anf_arg2651473]);
};
try {
if(--R.GAS > 0) {
$z14791480 = $f14851486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14851486,
"from":L[149]});
}
} catch($e14771478) {
if(R.isCont($e14771478)) {
var $ss14811482 = {"from":L[149],
"go":function(ann_DASH_check_DASH_temp2481487) {
return $Hann_DASH_check_DASH_temp7851488(ann_DASH_check_DASH_temp2481487);
}};
$e14771478.stack[R.EXN_STACKHEIGHT++] = $ss14811482;
}
if(R.isPyretException($e14771478)) {
$e14771478.pyretStack.push(L[149]);
}
throw $e14771478;
}
var $ret14831484 = $Hann_DASH_check_DASH_temp7851488($z14791480);
++R.GAS;
return $ret14831484;
};
var $Hann_DASH_check_DASH_temp7851488 = function(ann_DASH_check_DASH_temp2481487) {
return ann_DASH_check_DASH_temp2481487;
};
var $Hanf_arg7841489 = function(anf_arg2441490,anf_arg2391491,mkbranch26920,t881492) {
var anf_bracket2451506 = G(t881492,"right",L[152]);
var anf_arg2461503 = G(anf_bracket2451506,"right",L[151]);
var $z14951496 = D;
var $f15011502 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2391491,anf_arg2441490,anf_arg2461503):R.ffi.throwNonFunApp(L[150],mkbranch26920.$var,[anf_arg2391491,anf_arg2441490,anf_arg2461503]);
};
try {
if(--R.GAS > 0) {
$z14951496 = $f15011502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15011502,
"from":L[150]});
}
} catch($e14931494) {
if(R.isCont($e14931494)) {
var $ss14971498 = {"from":L[150],
"go":function(ann_DASH_check_DASH_temp2371504) {
return $Hann_DASH_check_DASH_temp7831505(ann_DASH_check_DASH_temp2371504);
}};
$e14931494.stack[R.EXN_STACKHEIGHT++] = $ss14971498;
}
if(R.isPyretException($e14931494)) {
$e14931494.pyretStack.push(L[150]);
}
throw $e14931494;
}
var $ret14991500 = $Hann_DASH_check_DASH_temp7831505($z14951496);
++R.GAS;
return $ret14991500;
};
var $Hann_DASH_check_DASH_temp7831505 = function(ann_DASH_check_DASH_temp2371504) {
return ann_DASH_check_DASH_temp2371504;
};
var $Hanf_arg7821507 = function(anf_arg2351508,anf_arg2281509,anf_arg2301510,mkbranch26920) {
var $z15131514 = D;
var $f15191520 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2281509,anf_arg2301510,anf_arg2351508):R.ffi.throwNonFunApp(L[153],mkbranch26920.$var,[anf_arg2281509,anf_arg2301510,anf_arg2351508]);
};
try {
if(--R.GAS > 0) {
$z15131514 = $f15191520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15191520,
"from":L[153]});
}
} catch($e15111512) {
if(R.isCont($e15111512)) {
var $ss15151516 = {"from":L[153],
"go":function(ann_DASH_check_DASH_temp2261521) {
return $Hann_DASH_check_DASH_temp7811522(ann_DASH_check_DASH_temp2261521);
}};
$e15111512.stack[R.EXN_STACKHEIGHT++] = $ss15151516;
}
if(R.isPyretException($e15111512)) {
$e15111512.pyretStack.push(L[153]);
}
throw $e15111512;
}
var $ret15171518 = $Hann_DASH_check_DASH_temp7811522($z15131514);
++R.GAS;
return $ret15171518;
};
var $Hann_DASH_check_DASH_temp7811522 = function(ann_DASH_check_DASH_temp2261521) {
return ann_DASH_check_DASH_temp2261521;
};
var $Hanf_arg7801523 = function(anf_arg2191524,branch241525,left801526,right811527,val791528,_plus9,num_DASH_max13) {
var anf_fun2201539 = G(right811527,"height",L[155]);
var $z15311532 = D;
var $f15371538 = function(_) {
return R.isFunction(anf_fun2201539)?anf_fun2201539.app():R.ffi.throwNonFunApp(L[154],anf_fun2201539,[]);
};
try {
if(--R.GAS > 0) {
$z15311532 = $f15371538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15371538,
"from":L[154]});
}
} catch($e15291530) {
if(R.isCont($e15291530)) {
var $ss15331534 = {"from":L[154],
"go":function(anf_arg2211540) {
return $Hanf_arg7791541(anf_arg2211540,anf_arg2191524,branch241525,left801526,right811527,val791528,_plus9,num_DASH_max13);
}};
$e15291530.stack[R.EXN_STACKHEIGHT++] = $ss15331534;
}
if(R.isPyretException($e15291530)) {
$e15291530.pyretStack.push(L[154]);
}
throw $e15291530;
}
var $ret15351536 = $Hanf_arg7791541($z15311532,anf_arg2191524,branch241525,left801526,right811527,val791528,_plus9,num_DASH_max13);
++R.GAS;
return $ret15351536;
};
var $Hanf_arg7791541 = function(anf_arg2211540,anf_arg2191524,branch241525,left801526,right811527,val791528,_plus9,num_DASH_max13) {
var $z15441545 = D;
var $f15501551 = function(_) {
return R.isFunction(num_DASH_max13)?num_DASH_max13.app(anf_arg2191524,anf_arg2211540):R.ffi.throwNonFunApp(L[156],num_DASH_max13,[anf_arg2191524,anf_arg2211540]);
};
try {
if(--R.GAS > 0) {
$z15441545 = $f15501551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15501551,
"from":L[156]});
}
} catch($e15421543) {
if(R.isCont($e15421543)) {
var $ss15461547 = {"from":L[156],
"go":function(anf_arg2221552) {
return $Hanf_arg7781553(anf_arg2221552,branch241525,left801526,right811527,val791528,_plus9);
}};
$e15421543.stack[R.EXN_STACKHEIGHT++] = $ss15461547;
}
if(R.isPyretException($e15421543)) {
$e15421543.pyretStack.push(L[156]);
}
throw $e15421543;
}
var $ret15481549 = $Hanf_arg7781553($z15441545,branch241525,left801526,right811527,val791528,_plus9);
++R.GAS;
return $ret15481549;
};
var $Hanf_arg7781553 = function(anf_arg2221552,branch241525,left801526,right811527,val791528,_plus9) {
var $z15561557 = D;
var $f15621563 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg2221552,(1)):R.ffi.throwNonFunApp(L[157],_plus9,[anf_arg2221552,(1)]);
};
try {
if(--R.GAS > 0) {
$z15561557 = $f15621563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15621563,
"from":L[157]});
}
} catch($e15541555) {
if(R.isCont($e15541555)) {
var $ss15581559 = {"from":L[157],
"go":function(anf_arg2231564) {
return $Hanf_arg7771565(anf_arg2231564,branch241525,left801526,right811527,val791528);
}};
$e15541555.stack[R.EXN_STACKHEIGHT++] = $ss15581559;
}
if(R.isPyretException($e15541555)) {
$e15541555.pyretStack.push(L[157]);
}
throw $e15541555;
}
var $ret15601561 = $Hanf_arg7771565($z15561557,branch241525,left801526,right811527,val791528);
++R.GAS;
return $ret15601561;
};
var $Hanf_arg7771565 = function(anf_arg2231564,branch241525,left801526,right811527,val791528) {
var $z15681569 = D;
var $f15741575 = function(_) {
return R.isFunction(branch241525.$var)?branch241525.$var.app(val791528,anf_arg2231564,left801526,right811527):R.ffi.throwNonFunApp(L[158],branch241525.$var,[val791528,anf_arg2231564,left801526,right811527]);
};
try {
if(--R.GAS > 0) {
$z15681569 = $f15741575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15741575,
"from":L[158]});
}
} catch($e15661567) {
if(R.isCont($e15661567)) {
var $ss15701571 = {"from":L[158],
"go":function(ann_DASH_check_DASH_temp2171576) {
return $Hann_DASH_check_DASH_temp7761577(ann_DASH_check_DASH_temp2171576);
}};
$e15661567.stack[R.EXN_STACKHEIGHT++] = $ss15701571;
}
if(R.isPyretException($e15661567)) {
$e15661567.pyretStack.push(L[158]);
}
throw $e15661567;
}
var $ret15721573 = $Hann_DASH_check_DASH_temp7761577($z15681569);
++R.GAS;
return $ret15721573;
};
var $Hann_DASH_check_DASH_temp7761577 = function(ann_DASH_check_DASH_temp2171576) {
return ann_DASH_check_DASH_temp2171576;
};
var $Hann_DASH_check_DASH_temp7751578 = function(ann_DASH_check_DASH_temp2141579) {
return ann_DASH_check_DASH_temp2141579;
};
var $Hanf_arg7741580 = function(anf_arg2041581,anf_fun2001582,anf_fun2021583,f711584) {
var $z15871588 = D;
var $f15931594 = function(_) {
return R.isFunction(anf_fun2021583)?anf_fun2021583.app(f711584,anf_arg2041581):R.ffi.throwNonFunApp(L[159],anf_fun2021583,[f711584,anf_arg2041581]);
};
try {
if(--R.GAS > 0) {
$z15871588 = $f15931594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15931594,
"from":L[159]});
}
} catch($e15851586) {
if(R.isCont($e15851586)) {
var $ss15891590 = {"from":L[159],
"go":function(anf_arg2051595) {
return $Hanf_arg7731596(anf_arg2051595,anf_fun2001582,f711584);
}};
$e15851586.stack[R.EXN_STACKHEIGHT++] = $ss15891590;
}
if(R.isPyretException($e15851586)) {
$e15851586.pyretStack.push(L[159]);
}
throw $e15851586;
}
var $ret15911592 = $Hanf_arg7731596($z15871588,anf_fun2001582,f711584);
++R.GAS;
return $ret15911592;
};
var $Hanf_arg7731596 = function(anf_arg2051595,anf_fun2001582,f711584) {
var $z15991600 = D;
var $f16051606 = function(_) {
return R.isFunction(anf_fun2001582)?anf_fun2001582.app(f711584,anf_arg2051595):R.ffi.throwNonFunApp(L[160],anf_fun2001582,[f711584,anf_arg2051595]);
};
try {
if(--R.GAS > 0) {
$z15991600 = $f16051606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16051606,
"from":L[160]});
}
} catch($e15971598) {
if(R.isCont($e15971598)) {
var $ss16011602 = {"from":L[160],
"go":function(ann_DASH_check_DASH_temp1981607) {
return $Hann_DASH_check_DASH_temp7721608(ann_DASH_check_DASH_temp1981607);
}};
$e15971598.stack[R.EXN_STACKHEIGHT++] = $ss16011602;
}
if(R.isPyretException($e15971598)) {
$e15971598.pyretStack.push(L[160]);
}
throw $e15971598;
}
var $ret16031604 = $Hann_DASH_check_DASH_temp7721608($z15991600);
++R.GAS;
return $ret16031604;
};
var $Hann_DASH_check_DASH_temp7721608 = function(ann_DASH_check_DASH_temp1981607) {
return ann_DASH_check_DASH_temp1981607;
};
var $Hanf_arg7711609 = function(anf_arg1901610,empty141611,link15579,lists225,self691612,_plus9) {
var anf_bracket1911626 = G(self691612,"right",L[163]);
var anf_fun1921623 = G(anf_bracket1911626,"postorder",L[162]);
var $z16151616 = D;
var $f16211622 = function(_) {
return R.isFunction(anf_fun1921623)?anf_fun1921623.app():R.ffi.throwNonFunApp(L[161],anf_fun1921623,[]);
};
try {
if(--R.GAS > 0) {
$z16151616 = $f16211622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16211622,
"from":L[161]});
}
} catch($e16131614) {
if(R.isCont($e16131614)) {
var $ss16171618 = {"from":L[161],
"go":function(anf_arg1931624) {
return $Hanf_arg7701625(anf_arg1931624,anf_arg1901610,empty141611,link15579,lists225,self691612,_plus9);
}};
$e16131614.stack[R.EXN_STACKHEIGHT++] = $ss16171618;
}
if(R.isPyretException($e16131614)) {
$e16131614.pyretStack.push(L[161]);
}
throw $e16131614;
}
var $ret16191620 = $Hanf_arg7701625($z16151616,anf_arg1901610,empty141611,link15579,lists225,self691612,_plus9);
++R.GAS;
return $ret16191620;
};
var $Hanf_arg7701625 = function(anf_arg1931624,anf_arg1901610,empty141611,link15579,lists225,self691612,_plus9) {
var $z16291630 = D;
var $f16351636 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg1901610,anf_arg1931624):R.ffi.throwNonFunApp(L[164],_plus9,[anf_arg1901610,anf_arg1931624]);
};
try {
if(--R.GAS > 0) {
$z16291630 = $f16351636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16351636,
"from":L[164]});
}
} catch($e16271628) {
if(R.isCont($e16271628)) {
var $ss16311632 = {"from":L[164],
"go":function(anf_arg1941637) {
return $Hanf_arg7691638(anf_arg1941637,empty141611,link15579,lists225,self691612,_plus9);
}};
$e16271628.stack[R.EXN_STACKHEIGHT++] = $ss16311632;
}
if(R.isPyretException($e16271628)) {
$e16271628.pyretStack.push(L[164]);
}
throw $e16271628;
}
var $ret16331634 = $Hanf_arg7691638($z16291630,empty141611,link15579,lists225,self691612,_plus9);
++R.GAS;
return $ret16331634;
};
var $Hanf_arg7691638 = function(anf_arg1941637,empty141611,link15579,lists225,self691612,_plus9) {
var anf_arg1951649 = G(self691612,"value",L[166]);
var $z16411642 = D;
var $f16471648 = function(_) {
return R.isFunction(link15579)?link15579.app(anf_arg1951649,empty141611):R.ffi.throwNonFunApp(L[165],link15579,[anf_arg1951649,empty141611]);
};
try {
if(--R.GAS > 0) {
$z16411642 = $f16471648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16471648,
"from":L[165]});
}
} catch($e16391640) {
if(R.isCont($e16391640)) {
var $ss16431644 = {"from":L[165],
"go":function(anf_arg1961650) {
return $Hanf_arg7681651(anf_arg1961650,anf_arg1941637,lists225,_plus9);
}};
$e16391640.stack[R.EXN_STACKHEIGHT++] = $ss16431644;
}
if(R.isPyretException($e16391640)) {
$e16391640.pyretStack.push(L[165]);
}
throw $e16391640;
}
var $ret16451646 = $Hanf_arg7681651($z16411642,anf_arg1941637,lists225,_plus9);
++R.GAS;
return $ret16451646;
};
var $Hanf_arg7681651 = function(anf_arg1961650,anf_arg1941637,lists225,_plus9) {
var $z16541655 = D;
var $f16601661 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg1941637,anf_arg1961650):R.ffi.throwNonFunApp(L[167],_plus9,[anf_arg1941637,anf_arg1961650]);
};
try {
if(--R.GAS > 0) {
$z16541655 = $f16601661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16601661,
"from":L[167]});
}
} catch($e16521653) {
if(R.isCont($e16521653)) {
var $ss16561657 = {"from":L[167],
"go":function(ann_DASH_check_DASH_temp1871662) {
return $Hann_DASH_check_DASH_temp7671663(ann_DASH_check_DASH_temp1871662,lists225);
}};
$e16521653.stack[R.EXN_STACKHEIGHT++] = $ss16561657;
}
if(R.isPyretException($e16521653)) {
$e16521653.pyretStack.push(L[167]);
}
throw $e16521653;
}
var $ret16581659 = $Hann_DASH_check_DASH_temp7671663($z16541655,lists225);
++R.GAS;
return $ret16581659;
};
var $Hann_DASH_check_DASH_temp7671663 = function(ann_DASH_check_DASH_temp1871662,lists225) {
return ann_DASH_check_DASH_temp1871662;
};
var $Hanf_arg7661664 = function(anf_arg1801665,link15579,lists225,self681666,_plus9) {
var anf_arg1811679 = G(self681666,"value",L[171]);
var anf_bracket1821681 = G(self681666,"right",L[170]);
var anf_fun1831677 = G(anf_bracket1821681,"inorder",L[169]);
var $z16691670 = D;
var $f16751676 = function(_) {
return R.isFunction(anf_fun1831677)?anf_fun1831677.app():R.ffi.throwNonFunApp(L[168],anf_fun1831677,[]);
};
try {
if(--R.GAS > 0) {
$z16691670 = $f16751676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16751676,
"from":L[168]});
}
} catch($e16671668) {
if(R.isCont($e16671668)) {
var $ss16711672 = {"from":L[168],
"go":function(anf_arg1841678) {
return $Hanf_arg7651680(anf_arg1841678,anf_arg1801665,anf_arg1811679,link15579,lists225,_plus9);
}};
$e16671668.stack[R.EXN_STACKHEIGHT++] = $ss16711672;
}
if(R.isPyretException($e16671668)) {
$e16671668.pyretStack.push(L[168]);
}
throw $e16671668;
}
var $ret16731674 = $Hanf_arg7651680($z16691670,anf_arg1801665,anf_arg1811679,link15579,lists225,_plus9);
++R.GAS;
return $ret16731674;
};
var $Hanf_arg7651680 = function(anf_arg1841678,anf_arg1801665,anf_arg1811679,link15579,lists225,_plus9) {
var $z16841685 = D;
var $f16901691 = function(_) {
return R.isFunction(link15579)?link15579.app(anf_arg1811679,anf_arg1841678):R.ffi.throwNonFunApp(L[172],link15579,[anf_arg1811679,anf_arg1841678]);
};
try {
if(--R.GAS > 0) {
$z16841685 = $f16901691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16901691,
"from":L[172]});
}
} catch($e16821683) {
if(R.isCont($e16821683)) {
var $ss16861687 = {"from":L[172],
"go":function(anf_arg1851692) {
return $Hanf_arg7641693(anf_arg1851692,anf_arg1801665,lists225,_plus9);
}};
$e16821683.stack[R.EXN_STACKHEIGHT++] = $ss16861687;
}
if(R.isPyretException($e16821683)) {
$e16821683.pyretStack.push(L[172]);
}
throw $e16821683;
}
var $ret16881689 = $Hanf_arg7641693($z16841685,anf_arg1801665,lists225,_plus9);
++R.GAS;
return $ret16881689;
};
var $Hanf_arg7641693 = function(anf_arg1851692,anf_arg1801665,lists225,_plus9) {
var $z16961697 = D;
var $f17021703 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg1801665,anf_arg1851692):R.ffi.throwNonFunApp(L[173],_plus9,[anf_arg1801665,anf_arg1851692]);
};
try {
if(--R.GAS > 0) {
$z16961697 = $f17021703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17021703,
"from":L[173]});
}
} catch($e16941695) {
if(R.isCont($e16941695)) {
var $ss16981699 = {"from":L[173],
"go":function(ann_DASH_check_DASH_temp1771704) {
return $Hann_DASH_check_DASH_temp7631705(ann_DASH_check_DASH_temp1771704,lists225);
}};
$e16941695.stack[R.EXN_STACKHEIGHT++] = $ss16981699;
}
if(R.isPyretException($e16941695)) {
$e16941695.pyretStack.push(L[173]);
}
throw $e16941695;
}
var $ret17001701 = $Hann_DASH_check_DASH_temp7631705($z16961697,lists225);
++R.GAS;
return $ret17001701;
};
var $Hann_DASH_check_DASH_temp7631705 = function(ann_DASH_check_DASH_temp1771704,lists225) {
return ann_DASH_check_DASH_temp1771704;
};
var $Hanf_arg7621706 = function(anf_arg1711707,anf_arg1681708,link15579,lists225,self671709,_plus9) {
var anf_bracket1721723 = G(self671709,"right",L[176]);
var anf_fun1731720 = G(anf_bracket1721723,"preorder",L[175]);
var $z17121713 = D;
var $f17181719 = function(_) {
return R.isFunction(anf_fun1731720)?anf_fun1731720.app():R.ffi.throwNonFunApp(L[174],anf_fun1731720,[]);
};
try {
if(--R.GAS > 0) {
$z17121713 = $f17181719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17181719,
"from":L[174]});
}
} catch($e17101711) {
if(R.isCont($e17101711)) {
var $ss17141715 = {"from":L[174],
"go":function(anf_arg1741721) {
return $Hanf_arg7611722(anf_arg1741721,anf_arg1681708,anf_arg1711707,link15579,lists225,_plus9);
}};
$e17101711.stack[R.EXN_STACKHEIGHT++] = $ss17141715;
}
if(R.isPyretException($e17101711)) {
$e17101711.pyretStack.push(L[174]);
}
throw $e17101711;
}
var $ret17161717 = $Hanf_arg7611722($z17121713,anf_arg1681708,anf_arg1711707,link15579,lists225,_plus9);
++R.GAS;
return $ret17161717;
};
var $Hanf_arg7611722 = function(anf_arg1741721,anf_arg1681708,anf_arg1711707,link15579,lists225,_plus9) {
var $z17261727 = D;
var $f17321733 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg1711707,anf_arg1741721):R.ffi.throwNonFunApp(L[177],_plus9,[anf_arg1711707,anf_arg1741721]);
};
try {
if(--R.GAS > 0) {
$z17261727 = $f17321733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17321733,
"from":L[177]});
}
} catch($e17241725) {
if(R.isCont($e17241725)) {
var $ss17281729 = {"from":L[177],
"go":function(anf_arg1751734) {
return $Hanf_arg7601735(anf_arg1751734,anf_arg1681708,link15579,lists225);
}};
$e17241725.stack[R.EXN_STACKHEIGHT++] = $ss17281729;
}
if(R.isPyretException($e17241725)) {
$e17241725.pyretStack.push(L[177]);
}
throw $e17241725;
}
var $ret17301731 = $Hanf_arg7601735($z17261727,anf_arg1681708,link15579,lists225);
++R.GAS;
return $ret17301731;
};
var $Hanf_arg7601735 = function(anf_arg1751734,anf_arg1681708,link15579,lists225) {
var $z17381739 = D;
var $f17441745 = function(_) {
return R.isFunction(link15579)?link15579.app(anf_arg1681708,anf_arg1751734):R.ffi.throwNonFunApp(L[178],link15579,[anf_arg1681708,anf_arg1751734]);
};
try {
if(--R.GAS > 0) {
$z17381739 = $f17441745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17441745,
"from":L[178]});
}
} catch($e17361737) {
if(R.isCont($e17361737)) {
var $ss17401741 = {"from":L[178],
"go":function(ann_DASH_check_DASH_temp1671746) {
return $Hann_DASH_check_DASH_temp7591747(ann_DASH_check_DASH_temp1671746,lists225);
}};
$e17361737.stack[R.EXN_STACKHEIGHT++] = $ss17401741;
}
if(R.isPyretException($e17361737)) {
$e17361737.pyretStack.push(L[178]);
}
throw $e17361737;
}
var $ret17421743 = $Hann_DASH_check_DASH_temp7591747($z17381739,lists225);
++R.GAS;
return $ret17421743;
};
var $Hann_DASH_check_DASH_temp7591747 = function(ann_DASH_check_DASH_temp1671746,lists225) {
return ann_DASH_check_DASH_temp1671746;
};
var $Hcont_tail_arg7511748 = function(cont_tail_arg1641749,if_helper1391750) {
if(--R.GAS > 0) {
$z17511752 = R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1641749):R.ffi.throwNonFunApp(L[179],if_helper1391750,[cont_tail_arg1641749]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1641749):R.ffi.throwNonFunApp(L[179],if_helper1391750,[cont_tail_arg1641749]);
},
"from":L[179]});
}
++R.GAS;
return $z17511752;
};
var $Hif_DASH_7581753 = function(if_DASH_171754,if_helper1391750,mkbranch26920,rebalance27921,self651755,val661756) {
var anf_if1471791 = R.isBoolean(if_DASH_171754);
if(R.isPyretTrue(anf_if1471791)) {
if(R.isPyretTrue(if_DASH_171754)) {
var anf_arg1561769 = G(self651755,"value",L[183]);
var anf_bracket1571771 = G(self651755,"left",L[182]);
var anf_fun1581767 = G(anf_bracket1571771,"remove",L[181]);
var $z17591760 = D;
var $f17651766 = function(_) {
return R.isFunction(anf_fun1581767)?anf_fun1581767.app(val661756):R.ffi.throwNonFunApp(L[180],anf_fun1581767,[val661756]);
};
try {
if(--R.GAS > 0) {
$z17591760 = $f17651766();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17651766,
"from":L[180]});
}
} catch($e17571758) {
if(R.isCont($e17571758)) {
var $ss17611762 = {"from":L[180],
"go":function(anf_arg1591768) {
return $Hanf_arg7541770(anf_arg1591768,anf_arg1561769,if_helper1391750,mkbranch26920,rebalance27921,self651755);
}};
$e17571758.stack[R.EXN_STACKHEIGHT++] = $ss17611762;
}
if(R.isPyretException($e17571758)) {
$e17571758.pyretStack.push(L[180]);
}
throw $e17571758;
}
var $ret17631764 = $Hanf_arg7541770($z17591760,anf_arg1561769,if_helper1391750,mkbranch26920,rebalance27921,self651755);
++R.GAS;
return $ret17631764;
} else {
var anf_arg1481784 = G(self651755,"value",L[188]);
var anf_arg1491785 = G(self651755,"left",L[187]);
var anf_bracket1501787 = G(self651755,"right",L[186]);
var anf_fun1511782 = G(anf_bracket1501787,"remove",L[185]);
var $z17741775 = D;
var $f17801781 = function(_) {
return R.isFunction(anf_fun1511782)?anf_fun1511782.app(val661756):R.ffi.throwNonFunApp(L[184],anf_fun1511782,[val661756]);
};
try {
if(--R.GAS > 0) {
$z17741775 = $f17801781();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17801781,
"from":L[184]});
}
} catch($e17721773) {
if(R.isCont($e17721773)) {
var $ss17761777 = {"from":L[184],
"go":function(anf_arg1521783) {
return $Hanf_arg7571786(anf_arg1521783,anf_arg1481784,anf_arg1491785,if_helper1391750,mkbranch26920,rebalance27921);
}};
$e17721773.stack[R.EXN_STACKHEIGHT++] = $ss17761777;
}
if(R.isPyretException($e17721773)) {
$e17721773.pyretStack.push(L[184]);
}
throw $e17721773;
}
var $ret17781779 = $Hanf_arg7571786($z17741775,anf_arg1481784,anf_arg1491785,if_helper1391750,mkbranch26920,rebalance27921);
++R.GAS;
return $ret17781779;
}
} else {
var cont_tail_arg1451790 = R.throwNonBooleanCondition(L[189],("if"),if_DASH_171754);
if(--R.GAS > 0) {
$z17881789 = R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1451790):R.ffi.throwNonFunApp(L[189],if_helper1391750,[cont_tail_arg1451790]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1451790):R.ffi.throwNonFunApp(L[189],if_helper1391750,[cont_tail_arg1451790]);
},
"from":L[189]});
}
++R.GAS;
return $z17881789;
}
};
var $Hanf_arg7541770 = function(anf_arg1591768,anf_arg1561769,if_helper1391750,mkbranch26920,rebalance27921,self651755) {
var anf_arg1601802 = G(self651755,"right",L[192]);
var $z17941795 = D;
var $f18001801 = function(_) {
return R.isFunction(mkbranch26920.$var === D?U(L[190],"mkbranch"):mkbranch26920.$var)?mkbranch26920.$var === D?U(L[190],"mkbranch"):mkbranch26920.$var.app(anf_arg1561769,anf_arg1591768,anf_arg1601802):R.ffi.throwNonFunApp(L[191],mkbranch26920.$var === D?U(L[190],"mkbranch"):mkbranch26920.$var,[anf_arg1561769,anf_arg1591768,anf_arg1601802]);
};
try {
if(--R.GAS > 0) {
$z17941795 = $f18001801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18001801,
"from":L[191]});
}
} catch($e17921793) {
if(R.isCont($e17921793)) {
var $ss17961797 = {"from":L[191],
"go":function(anf_arg1611803) {
return $Hanf_arg7531804(anf_arg1611803,if_helper1391750,rebalance27921);
}};
$e17921793.stack[R.EXN_STACKHEIGHT++] = $ss17961797;
}
if(R.isPyretException($e17921793)) {
$e17921793.pyretStack.push(L[191]);
}
throw $e17921793;
}
var $ret17981799 = $Hanf_arg7531804($z17941795,if_helper1391750,rebalance27921);
++R.GAS;
return $ret17981799;
};
var $Hanf_arg7531804 = function(anf_arg1611803,if_helper1391750,rebalance27921) {
var $z18071808 = D;
var $f18131814 = function(_) {
return R.isFunction(rebalance27921.$var === D?U(L[193],"rebalance"):rebalance27921.$var)?rebalance27921.$var === D?U(L[193],"rebalance"):rebalance27921.$var.app(anf_arg1611803):R.ffi.throwNonFunApp(L[194],rebalance27921.$var === D?U(L[193],"rebalance"):rebalance27921.$var,[anf_arg1611803]);
};
try {
if(--R.GAS > 0) {
$z18071808 = $f18131814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18131814,
"from":L[194]});
}
} catch($e18051806) {
if(R.isCont($e18051806)) {
var $ss18091810 = {"from":L[194],
"go":function(cont_tail_arg1621815) {
return $Hcont_tail_arg7521816(cont_tail_arg1621815,if_helper1391750);
}};
$e18051806.stack[R.EXN_STACKHEIGHT++] = $ss18091810;
}
if(R.isPyretException($e18051806)) {
$e18051806.pyretStack.push(L[194]);
}
throw $e18051806;
}
var $ret18111812 = $Hcont_tail_arg7521816($z18071808,if_helper1391750);
++R.GAS;
return $ret18111812;
};
var $Hcont_tail_arg7521816 = function(cont_tail_arg1621815,if_helper1391750) {
if(--R.GAS > 0) {
$z18171818 = R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1621815):R.ffi.throwNonFunApp(L[194],if_helper1391750,[cont_tail_arg1621815]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1621815):R.ffi.throwNonFunApp(L[194],if_helper1391750,[cont_tail_arg1621815]);
},
"from":L[194]});
}
++R.GAS;
return $z18171818;
};
var $Hanf_arg7571786 = function(anf_arg1521783,anf_arg1481784,anf_arg1491785,if_helper1391750,mkbranch26920,rebalance27921) {
var $z18211822 = D;
var $f18271828 = function(_) {
return R.isFunction(mkbranch26920.$var === D?U(L[195],"mkbranch"):mkbranch26920.$var)?mkbranch26920.$var === D?U(L[195],"mkbranch"):mkbranch26920.$var.app(anf_arg1481784,anf_arg1491785,anf_arg1521783):R.ffi.throwNonFunApp(L[196],mkbranch26920.$var === D?U(L[195],"mkbranch"):mkbranch26920.$var,[anf_arg1481784,anf_arg1491785,anf_arg1521783]);
};
try {
if(--R.GAS > 0) {
$z18211822 = $f18271828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18271828,
"from":L[196]});
}
} catch($e18191820) {
if(R.isCont($e18191820)) {
var $ss18231824 = {"from":L[196],
"go":function(anf_arg1531829) {
return $Hanf_arg7561830(anf_arg1531829,if_helper1391750,rebalance27921);
}};
$e18191820.stack[R.EXN_STACKHEIGHT++] = $ss18231824;
}
if(R.isPyretException($e18191820)) {
$e18191820.pyretStack.push(L[196]);
}
throw $e18191820;
}
var $ret18251826 = $Hanf_arg7561830($z18211822,if_helper1391750,rebalance27921);
++R.GAS;
return $ret18251826;
};
var $Hanf_arg7561830 = function(anf_arg1531829,if_helper1391750,rebalance27921) {
var $z18331834 = D;
var $f18391840 = function(_) {
return R.isFunction(rebalance27921.$var === D?U(L[197],"rebalance"):rebalance27921.$var)?rebalance27921.$var === D?U(L[197],"rebalance"):rebalance27921.$var.app(anf_arg1531829):R.ffi.throwNonFunApp(L[198],rebalance27921.$var === D?U(L[197],"rebalance"):rebalance27921.$var,[anf_arg1531829]);
};
try {
if(--R.GAS > 0) {
$z18331834 = $f18391840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18391840,
"from":L[198]});
}
} catch($e18311832) {
if(R.isCont($e18311832)) {
var $ss18351836 = {"from":L[198],
"go":function(cont_tail_arg1541841) {
return $Hcont_tail_arg7551842(cont_tail_arg1541841,if_helper1391750);
}};
$e18311832.stack[R.EXN_STACKHEIGHT++] = $ss18351836;
}
if(R.isPyretException($e18311832)) {
$e18311832.pyretStack.push(L[198]);
}
throw $e18311832;
}
var $ret18371838 = $Hcont_tail_arg7551842($z18331834,if_helper1391750);
++R.GAS;
return $ret18371838;
};
var $Hcont_tail_arg7551842 = function(cont_tail_arg1541841,if_helper1391750) {
if(--R.GAS > 0) {
$z18431844 = R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1541841):R.ffi.throwNonFunApp(L[198],if_helper1391750,[cont_tail_arg1541841]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1541841):R.ffi.throwNonFunApp(L[198],if_helper1391750,[cont_tail_arg1541841]);
},
"from":L[198]});
}
++R.GAS;
return $z18431844;
};
var $Hcont_tail_arg7431845 = function(cont_tail_arg1341846,if_helper1071847) {
if(--R.GAS > 0) {
$z18481849 = R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1341846):R.ffi.throwNonFunApp(L[199],if_helper1071847,[cont_tail_arg1341846]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1341846):R.ffi.throwNonFunApp(L[199],if_helper1071847,[cont_tail_arg1341846]);
},
"from":L[199]});
}
++R.GAS;
return $z18481849;
};
var $Hif_DASH_7501850 = function(if_DASH_151851,if_helper1071847,mkbranch26920,rebalance27921,self631852,val641853) {
var anf_if1151888 = R.isBoolean(if_DASH_151851);
if(R.isPyretTrue(anf_if1151888)) {
if(R.isPyretTrue(if_DASH_151851)) {
var anf_arg1241866 = G(self631852,"value",L[203]);
var anf_bracket1251868 = G(self631852,"left",L[202]);
var anf_fun1261864 = G(anf_bracket1251868,"insert",L[201]);
var $z18561857 = D;
var $f18621863 = function(_) {
return R.isFunction(anf_fun1261864)?anf_fun1261864.app(val641853):R.ffi.throwNonFunApp(L[200],anf_fun1261864,[val641853]);
};
try {
if(--R.GAS > 0) {
$z18561857 = $f18621863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18621863,
"from":L[200]});
}
} catch($e18541855) {
if(R.isCont($e18541855)) {
var $ss18581859 = {"from":L[200],
"go":function(anf_arg1271865) {
return $Hanf_arg7461867(anf_arg1271865,anf_arg1241866,if_helper1071847,mkbranch26920,rebalance27921,self631852);
}};
$e18541855.stack[R.EXN_STACKHEIGHT++] = $ss18581859;
}
if(R.isPyretException($e18541855)) {
$e18541855.pyretStack.push(L[200]);
}
throw $e18541855;
}
var $ret18601861 = $Hanf_arg7461867($z18561857,anf_arg1241866,if_helper1071847,mkbranch26920,rebalance27921,self631852);
++R.GAS;
return $ret18601861;
} else {
var anf_arg1161881 = G(self631852,"value",L[208]);
var anf_arg1171882 = G(self631852,"left",L[207]);
var anf_bracket1181884 = G(self631852,"right",L[206]);
var anf_fun1191879 = G(anf_bracket1181884,"insert",L[205]);
var $z18711872 = D;
var $f18771878 = function(_) {
return R.isFunction(anf_fun1191879)?anf_fun1191879.app(val641853):R.ffi.throwNonFunApp(L[204],anf_fun1191879,[val641853]);
};
try {
if(--R.GAS > 0) {
$z18711872 = $f18771878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18771878,
"from":L[204]});
}
} catch($e18691870) {
if(R.isCont($e18691870)) {
var $ss18731874 = {"from":L[204],
"go":function(anf_arg1201880) {
return $Hanf_arg7491883(anf_arg1201880,anf_arg1161881,anf_arg1171882,if_helper1071847,mkbranch26920,rebalance27921);
}};
$e18691870.stack[R.EXN_STACKHEIGHT++] = $ss18731874;
}
if(R.isPyretException($e18691870)) {
$e18691870.pyretStack.push(L[204]);
}
throw $e18691870;
}
var $ret18751876 = $Hanf_arg7491883($z18711872,anf_arg1161881,anf_arg1171882,if_helper1071847,mkbranch26920,rebalance27921);
++R.GAS;
return $ret18751876;
}
} else {
var cont_tail_arg1131887 = R.throwNonBooleanCondition(L[209],("if"),if_DASH_151851);
if(--R.GAS > 0) {
$z18851886 = R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1131887):R.ffi.throwNonFunApp(L[209],if_helper1071847,[cont_tail_arg1131887]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1131887):R.ffi.throwNonFunApp(L[209],if_helper1071847,[cont_tail_arg1131887]);
},
"from":L[209]});
}
++R.GAS;
return $z18851886;
}
};
var $Hanf_arg7461867 = function(anf_arg1271865,anf_arg1241866,if_helper1071847,mkbranch26920,rebalance27921,self631852) {
var anf_arg1281899 = G(self631852,"right",L[212]);
var $z18911892 = D;
var $f18971898 = function(_) {
return R.isFunction(mkbranch26920.$var === D?U(L[210],"mkbranch"):mkbranch26920.$var)?mkbranch26920.$var === D?U(L[210],"mkbranch"):mkbranch26920.$var.app(anf_arg1241866,anf_arg1271865,anf_arg1281899):R.ffi.throwNonFunApp(L[211],mkbranch26920.$var === D?U(L[210],"mkbranch"):mkbranch26920.$var,[anf_arg1241866,anf_arg1271865,anf_arg1281899]);
};
try {
if(--R.GAS > 0) {
$z18911892 = $f18971898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18971898,
"from":L[211]});
}
} catch($e18891890) {
if(R.isCont($e18891890)) {
var $ss18931894 = {"from":L[211],
"go":function(anf_arg1291900) {
return $Hanf_arg7451901(anf_arg1291900,if_helper1071847,rebalance27921);
}};
$e18891890.stack[R.EXN_STACKHEIGHT++] = $ss18931894;
}
if(R.isPyretException($e18891890)) {
$e18891890.pyretStack.push(L[211]);
}
throw $e18891890;
}
var $ret18951896 = $Hanf_arg7451901($z18911892,if_helper1071847,rebalance27921);
++R.GAS;
return $ret18951896;
};
var $Hanf_arg7451901 = function(anf_arg1291900,if_helper1071847,rebalance27921) {
var $z19041905 = D;
var $f19101911 = function(_) {
return R.isFunction(rebalance27921.$var === D?U(L[213],"rebalance"):rebalance27921.$var)?rebalance27921.$var === D?U(L[213],"rebalance"):rebalance27921.$var.app(anf_arg1291900):R.ffi.throwNonFunApp(L[214],rebalance27921.$var === D?U(L[213],"rebalance"):rebalance27921.$var,[anf_arg1291900]);
};
try {
if(--R.GAS > 0) {
$z19041905 = $f19101911();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19101911,
"from":L[214]});
}
} catch($e19021903) {
if(R.isCont($e19021903)) {
var $ss19061907 = {"from":L[214],
"go":function(cont_tail_arg1301912) {
return $Hcont_tail_arg7441913(cont_tail_arg1301912,if_helper1071847);
}};
$e19021903.stack[R.EXN_STACKHEIGHT++] = $ss19061907;
}
if(R.isPyretException($e19021903)) {
$e19021903.pyretStack.push(L[214]);
}
throw $e19021903;
}
var $ret19081909 = $Hcont_tail_arg7441913($z19041905,if_helper1071847);
++R.GAS;
return $ret19081909;
};
var $Hcont_tail_arg7441913 = function(cont_tail_arg1301912,if_helper1071847) {
if(--R.GAS > 0) {
$z19141915 = R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1301912):R.ffi.throwNonFunApp(L[214],if_helper1071847,[cont_tail_arg1301912]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1301912):R.ffi.throwNonFunApp(L[214],if_helper1071847,[cont_tail_arg1301912]);
},
"from":L[214]});
}
++R.GAS;
return $z19141915;
};
var $Hanf_arg7491883 = function(anf_arg1201880,anf_arg1161881,anf_arg1171882,if_helper1071847,mkbranch26920,rebalance27921) {
var $z19181919 = D;
var $f19241925 = function(_) {
return R.isFunction(mkbranch26920.$var === D?U(L[215],"mkbranch"):mkbranch26920.$var)?mkbranch26920.$var === D?U(L[215],"mkbranch"):mkbranch26920.$var.app(anf_arg1161881,anf_arg1171882,anf_arg1201880):R.ffi.throwNonFunApp(L[216],mkbranch26920.$var === D?U(L[215],"mkbranch"):mkbranch26920.$var,[anf_arg1161881,anf_arg1171882,anf_arg1201880]);
};
try {
if(--R.GAS > 0) {
$z19181919 = $f19241925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19241925,
"from":L[216]});
}
} catch($e19161917) {
if(R.isCont($e19161917)) {
var $ss19201921 = {"from":L[216],
"go":function(anf_arg1211926) {
return $Hanf_arg7481927(anf_arg1211926,if_helper1071847,rebalance27921);
}};
$e19161917.stack[R.EXN_STACKHEIGHT++] = $ss19201921;
}
if(R.isPyretException($e19161917)) {
$e19161917.pyretStack.push(L[216]);
}
throw $e19161917;
}
var $ret19221923 = $Hanf_arg7481927($z19181919,if_helper1071847,rebalance27921);
++R.GAS;
return $ret19221923;
};
var $Hanf_arg7481927 = function(anf_arg1211926,if_helper1071847,rebalance27921) {
var $z19301931 = D;
var $f19361937 = function(_) {
return R.isFunction(rebalance27921.$var === D?U(L[217],"rebalance"):rebalance27921.$var)?rebalance27921.$var === D?U(L[217],"rebalance"):rebalance27921.$var.app(anf_arg1211926):R.ffi.throwNonFunApp(L[218],rebalance27921.$var === D?U(L[217],"rebalance"):rebalance27921.$var,[anf_arg1211926]);
};
try {
if(--R.GAS > 0) {
$z19301931 = $f19361937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19361937,
"from":L[218]});
}
} catch($e19281929) {
if(R.isCont($e19281929)) {
var $ss19321933 = {"from":L[218],
"go":function(cont_tail_arg1221938) {
return $Hcont_tail_arg7471939(cont_tail_arg1221938,if_helper1071847);
}};
$e19281929.stack[R.EXN_STACKHEIGHT++] = $ss19321933;
}
if(R.isPyretException($e19281929)) {
$e19281929.pyretStack.push(L[218]);
}
throw $e19281929;
}
var $ret19341935 = $Hcont_tail_arg7471939($z19301931,if_helper1071847);
++R.GAS;
return $ret19341935;
};
var $Hcont_tail_arg7471939 = function(cont_tail_arg1221938,if_helper1071847) {
if(--R.GAS > 0) {
$z19401941 = R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1221938):R.ffi.throwNonFunApp(L[218],if_helper1071847,[cont_tail_arg1221938]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1221938):R.ffi.throwNonFunApp(L[218],if_helper1071847,[cont_tail_arg1221938]);
},
"from":L[218]});
}
++R.GAS;
return $z19401941;
};
var $Hcont_tail_app7391942 = function(cont_tail_app1031943) {
return cont_tail_app1031943;
};
var $Hif_DASH_7421944 = function(if_DASH_131945,if_helper861946,self611947,val621948) {
var anf_if941980 = R.isBoolean(if_DASH_131945);
if(R.isPyretTrue(anf_if941980)) {
if(R.isPyretTrue(if_DASH_131945)) {
var anf_bracket991962 = G(self611947,"left",L[221]);
var anf_fun1001959 = G(anf_bracket991962,"contains",L[220]);
var $z19511952 = D;
var $f19571958 = function(_) {
return R.isFunction(anf_fun1001959)?anf_fun1001959.app(val621948):R.ffi.throwNonFunApp(L[219],anf_fun1001959,[val621948]);
};
try {
if(--R.GAS > 0) {
$z19511952 = $f19571958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19571958,
"from":L[219]});
}
} catch($e19491950) {
if(R.isCont($e19491950)) {
var $ss19531954 = {"from":L[219],
"go":function(cont_tail_arg1011960) {
return $Hcont_tail_arg7401961(cont_tail_arg1011960,if_helper861946);
}};
$e19491950.stack[R.EXN_STACKHEIGHT++] = $ss19531954;
}
if(R.isPyretException($e19491950)) {
$e19491950.pyretStack.push(L[219]);
}
throw $e19491950;
}
var $ret19551956 = $Hcont_tail_arg7401961($z19511952,if_helper861946);
++R.GAS;
return $ret19551956;
} else {
var anf_bracket951976 = G(self611947,"right",L[224]);
var anf_fun961973 = G(anf_bracket951976,"contains",L[223]);
var $z19651966 = D;
var $f19711972 = function(_) {
return R.isFunction(anf_fun961973)?anf_fun961973.app(val621948):R.ffi.throwNonFunApp(L[222],anf_fun961973,[val621948]);
};
try {
if(--R.GAS > 0) {
$z19651966 = $f19711972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19711972,
"from":L[222]});
}
} catch($e19631964) {
if(R.isCont($e19631964)) {
var $ss19671968 = {"from":L[222],
"go":function(cont_tail_arg971974) {
return $Hcont_tail_arg7411975(cont_tail_arg971974,if_helper861946);
}};
$e19631964.stack[R.EXN_STACKHEIGHT++] = $ss19671968;
}
if(R.isPyretException($e19631964)) {
$e19631964.pyretStack.push(L[222]);
}
throw $e19631964;
}
var $ret19691970 = $Hcont_tail_arg7411975($z19651966,if_helper861946);
++R.GAS;
return $ret19691970;
}
} else {
var cont_tail_arg921979 = R.throwNonBooleanCondition(L[225],("if"),if_DASH_131945);
if(--R.GAS > 0) {
$z19771978 = R.isFunction(if_helper861946)?if_helper861946.app(cont_tail_arg921979):R.ffi.throwNonFunApp(L[225],if_helper861946,[cont_tail_arg921979]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper861946)?if_helper861946.app(cont_tail_arg921979):R.ffi.throwNonFunApp(L[225],if_helper861946,[cont_tail_arg921979]);
},
"from":L[225]});
}
++R.GAS;
return $z19771978;
}
};
var $Hcont_tail_arg7401961 = function(cont_tail_arg1011960,if_helper861946) {
if(--R.GAS > 0) {
$z19811982 = R.isFunction(if_helper861946)?if_helper861946.app(cont_tail_arg1011960):R.ffi.throwNonFunApp(L[219],if_helper861946,[cont_tail_arg1011960]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper861946)?if_helper861946.app(cont_tail_arg1011960):R.ffi.throwNonFunApp(L[219],if_helper861946,[cont_tail_arg1011960]);
},
"from":L[219]});
}
++R.GAS;
return $z19811982;
};
var $Hcont_tail_arg7411975 = function(cont_tail_arg971974,if_helper861946) {
if(--R.GAS > 0) {
$z19831984 = R.isFunction(if_helper861946)?if_helper861946.app(cont_tail_arg971974):R.ffi.throwNonFunApp(L[222],if_helper861946,[cont_tail_arg971974]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper861946)?if_helper861946.app(cont_tail_arg971974):R.ffi.throwNonFunApp(L[222],if_helper861946,[cont_tail_arg971974]);
},
"from":L[222]});
}
++R.GAS;
return $z19831984;
};
var $Hanf_arg7381985 = function(anf_arg661986,self111987,_plus9,torepr16) {
var anf_arg671998 = G(self111987,"h",L[226]);
var $z19901991 = D;
var $f19961997 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg671998):R.ffi.throwNonFunApp(L[226],torepr16,[anf_arg671998]);
};
try {
if(--R.GAS > 0) {
$z19901991 = $f19961997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19961997,
"from":L[226]});
}
} catch($e19881989) {
if(R.isCont($e19881989)) {
var $ss19921993 = {"from":L[226],
"go":function(anf_arg681999) {
return $Hanf_arg7372000(anf_arg681999,anf_arg661986,self111987,_plus9,torepr16);
}};
$e19881989.stack[R.EXN_STACKHEIGHT++] = $ss19921993;
}
if(R.isPyretException($e19881989)) {
$e19881989.pyretStack.push(L[226]);
}
throw $e19881989;
}
var $ret19941995 = $Hanf_arg7372000($z19901991,anf_arg661986,self111987,_plus9,torepr16);
++R.GAS;
return $ret19941995;
};
var $Hanf_arg7372000 = function(anf_arg681999,anf_arg661986,self111987,_plus9,torepr16) {
var $z20032004 = D;
var $f20092010 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg681999):R.ffi.throwNonFunApp(L[226],_plus9,[(", "),anf_arg681999]);
};
try {
if(--R.GAS > 0) {
$z20032004 = $f20092010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20092010,
"from":L[226]});
}
} catch($e20012002) {
if(R.isCont($e20012002)) {
var $ss20052006 = {"from":L[226],
"go":function(anf_arg692011) {
return $Hanf_arg7362012(anf_arg692011,anf_arg661986,self111987,_plus9,torepr16);
}};
$e20012002.stack[R.EXN_STACKHEIGHT++] = $ss20052006;
}
if(R.isPyretException($e20012002)) {
$e20012002.pyretStack.push(L[226]);
}
throw $e20012002;
}
var $ret20072008 = $Hanf_arg7362012($z20032004,anf_arg661986,self111987,_plus9,torepr16);
++R.GAS;
return $ret20072008;
};
var $Hanf_arg7362012 = function(anf_arg692011,anf_arg661986,self111987,_plus9,torepr16) {
var $z20152016 = D;
var $f20212022 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg661986,anf_arg692011):R.ffi.throwNonFunApp(L[226],_plus9,[anf_arg661986,anf_arg692011]);
};
try {
if(--R.GAS > 0) {
$z20152016 = $f20212022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20212022,
"from":L[226]});
}
} catch($e20132014) {
if(R.isCont($e20132014)) {
var $ss20172018 = {"from":L[226],
"go":function(anf_arg702023) {
return $Hanf_arg7352024(anf_arg702023,self111987,_plus9,torepr16);
}};
$e20132014.stack[R.EXN_STACKHEIGHT++] = $ss20172018;
}
if(R.isPyretException($e20132014)) {
$e20132014.pyretStack.push(L[226]);
}
throw $e20132014;
}
var $ret20192020 = $Hanf_arg7352024($z20152016,self111987,_plus9,torepr16);
++R.GAS;
return $ret20192020;
};
var $Hanf_arg7352024 = function(anf_arg702023,self111987,_plus9,torepr16) {
var anf_arg712035 = G(self111987,"left",L[226]);
var $z20272028 = D;
var $f20332034 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg712035):R.ffi.throwNonFunApp(L[226],torepr16,[anf_arg712035]);
};
try {
if(--R.GAS > 0) {
$z20272028 = $f20332034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20332034,
"from":L[226]});
}
} catch($e20252026) {
if(R.isCont($e20252026)) {
var $ss20292030 = {"from":L[226],
"go":function(anf_arg722036) {
return $Hanf_arg7342037(anf_arg722036,anf_arg702023,self111987,_plus9,torepr16);
}};
$e20252026.stack[R.EXN_STACKHEIGHT++] = $ss20292030;
}
if(R.isPyretException($e20252026)) {
$e20252026.pyretStack.push(L[226]);
}
throw $e20252026;
}
var $ret20312032 = $Hanf_arg7342037($z20272028,anf_arg702023,self111987,_plus9,torepr16);
++R.GAS;
return $ret20312032;
};
var $Hanf_arg7342037 = function(anf_arg722036,anf_arg702023,self111987,_plus9,torepr16) {
var $z20402041 = D;
var $f20462047 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg722036):R.ffi.throwNonFunApp(L[226],_plus9,[(", "),anf_arg722036]);
};
try {
if(--R.GAS > 0) {
$z20402041 = $f20462047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20462047,
"from":L[226]});
}
} catch($e20382039) {
if(R.isCont($e20382039)) {
var $ss20422043 = {"from":L[226],
"go":function(anf_arg732048) {
return $Hanf_arg7332049(anf_arg732048,anf_arg702023,self111987,_plus9,torepr16);
}};
$e20382039.stack[R.EXN_STACKHEIGHT++] = $ss20422043;
}
if(R.isPyretException($e20382039)) {
$e20382039.pyretStack.push(L[226]);
}
throw $e20382039;
}
var $ret20442045 = $Hanf_arg7332049($z20402041,anf_arg702023,self111987,_plus9,torepr16);
++R.GAS;
return $ret20442045;
};
var $Hanf_arg7332049 = function(anf_arg732048,anf_arg702023,self111987,_plus9,torepr16) {
var $z20522053 = D;
var $f20582059 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg702023,anf_arg732048):R.ffi.throwNonFunApp(L[226],_plus9,[anf_arg702023,anf_arg732048]);
};
try {
if(--R.GAS > 0) {
$z20522053 = $f20582059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20582059,
"from":L[226]});
}
} catch($e20502051) {
if(R.isCont($e20502051)) {
var $ss20542055 = {"from":L[226],
"go":function(anf_arg742060) {
return $Hanf_arg7322061(anf_arg742060,self111987,_plus9,torepr16);
}};
$e20502051.stack[R.EXN_STACKHEIGHT++] = $ss20542055;
}
if(R.isPyretException($e20502051)) {
$e20502051.pyretStack.push(L[226]);
}
throw $e20502051;
}
var $ret20562057 = $Hanf_arg7322061($z20522053,self111987,_plus9,torepr16);
++R.GAS;
return $ret20562057;
};
var $Hanf_arg7322061 = function(anf_arg742060,self111987,_plus9,torepr16) {
var anf_arg752072 = G(self111987,"right",L[226]);
var $z20642065 = D;
var $f20702071 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg752072):R.ffi.throwNonFunApp(L[226],torepr16,[anf_arg752072]);
};
try {
if(--R.GAS > 0) {
$z20642065 = $f20702071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20702071,
"from":L[226]});
}
} catch($e20622063) {
if(R.isCont($e20622063)) {
var $ss20662067 = {"from":L[226],
"go":function(anf_arg762073) {
return $Hanf_arg7312074(anf_arg762073,anf_arg742060,_plus9);
}};
$e20622063.stack[R.EXN_STACKHEIGHT++] = $ss20662067;
}
if(R.isPyretException($e20622063)) {
$e20622063.pyretStack.push(L[226]);
}
throw $e20622063;
}
var $ret20682069 = $Hanf_arg7312074($z20642065,anf_arg742060,_plus9);
++R.GAS;
return $ret20682069;
};
var $Hanf_arg7312074 = function(anf_arg762073,anf_arg742060,_plus9) {
var $z20772078 = D;
var $f20832084 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg762073):R.ffi.throwNonFunApp(L[226],_plus9,[(", "),anf_arg762073]);
};
try {
if(--R.GAS > 0) {
$z20772078 = $f20832084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20832084,
"from":L[226]});
}
} catch($e20752076) {
if(R.isCont($e20752076)) {
var $ss20792080 = {"from":L[226],
"go":function(anf_arg772085) {
return $Hanf_arg7302086(anf_arg772085,anf_arg742060,_plus9);
}};
$e20752076.stack[R.EXN_STACKHEIGHT++] = $ss20792080;
}
if(R.isPyretException($e20752076)) {
$e20752076.pyretStack.push(L[226]);
}
throw $e20752076;
}
var $ret20812082 = $Hanf_arg7302086($z20772078,anf_arg742060,_plus9);
++R.GAS;
return $ret20812082;
};
var $Hanf_arg7302086 = function(anf_arg772085,anf_arg742060,_plus9) {
var $z20892090 = D;
var $f20952096 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg742060,anf_arg772085):R.ffi.throwNonFunApp(L[226],_plus9,[anf_arg742060,anf_arg772085]);
};
try {
if(--R.GAS > 0) {
$z20892090 = $f20952096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20952096,
"from":L[226]});
}
} catch($e20872088) {
if(R.isCont($e20872088)) {
var $ss20912092 = {"from":L[226],
"go":function(anf_arg782097) {
return $Hanf_arg7292098(anf_arg782097,_plus9);
}};
$e20872088.stack[R.EXN_STACKHEIGHT++] = $ss20912092;
}
if(R.isPyretException($e20872088)) {
$e20872088.pyretStack.push(L[226]);
}
throw $e20872088;
}
var $ret20932094 = $Hanf_arg7292098($z20892090,_plus9);
++R.GAS;
return $ret20932094;
};
var $Hanf_arg7292098 = function(anf_arg782097,_plus9) {
var $z21012102 = D;
var $f21072108 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg782097,(")")):R.ffi.throwNonFunApp(L[226],_plus9,[anf_arg782097,(")")]);
};
try {
if(--R.GAS > 0) {
$z21012102 = $f21072108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21072108,
"from":L[226]});
}
} catch($e20992100) {
if(R.isCont($e20992100)) {
var $ss21032104 = {"from":L[226],
"go":function(anf_arg792109) {
return $Hanf_arg7282110(anf_arg792109,_plus9);
}};
$e20992100.stack[R.EXN_STACKHEIGHT++] = $ss21032104;
}
if(R.isPyretException($e20992100)) {
$e20992100.pyretStack.push(L[226]);
}
throw $e20992100;
}
var $ret21052106 = $Hanf_arg7282110($z21012102,_plus9);
++R.GAS;
return $ret21052106;
};
var $Hanf_arg7282110 = function(anf_arg792109,_plus9) {
var $z21132114 = D;
var $f21192120 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg792109):R.ffi.throwNonFunApp(L[226],_plus9,[("("),anf_arg792109]);
};
try {
if(--R.GAS > 0) {
$z21132114 = $f21192120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21192120,
"from":L[226]});
}
} catch($e21112112) {
if(R.isCont($e21112112)) {
var $ss21152116 = {"from":L[226],
"go":function(anf_arg802121) {
return $Hanf_arg7272122(anf_arg802121,_plus9);
}};
$e21112112.stack[R.EXN_STACKHEIGHT++] = $ss21152116;
}
if(R.isPyretException($e21112112)) {
$e21112112.pyretStack.push(L[226]);
}
throw $e21112112;
}
var $ret21172118 = $Hanf_arg7272122($z21132114,_plus9);
++R.GAS;
return $ret21172118;
};
var $Hanf_arg7272122 = function(anf_arg802121,_plus9) {
var $z21252126 = D;
var $f21312132 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("branch"),anf_arg802121):R.ffi.throwNonFunApp(L[226],_plus9,[("branch"),anf_arg802121]);
};
try {
if(--R.GAS > 0) {
$z21252126 = $f21312132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21312132,
"from":L[226]});
}
} catch($e21232124) {
if(R.isCont($e21232124)) {
var $ss21272128 = {"from":L[226],
"go":function(ann_DASH_check_DASH_temp642133) {
return $Hann_DASH_check_DASH_temp7262134(ann_DASH_check_DASH_temp642133);
}};
$e21232124.stack[R.EXN_STACKHEIGHT++] = $ss21272128;
}
if(R.isPyretException($e21232124)) {
$e21232124.pyretStack.push(L[226]);
}
throw $e21232124;
}
var $ret21292130 = $Hann_DASH_check_DASH_temp7262134($z21252126);
++R.GAS;
return $ret21292130;
};
var $Hann_DASH_check_DASH_temp7262134 = function(ann_DASH_check_DASH_temp642133) {
return ann_DASH_check_DASH_temp642133;
};
var $Hcont_tail_arg7242135 = function(cont_tail_arg612136,if_helper502137) {
if(--R.GAS > 0) {
$z21382139 = R.isFunction(if_helper502137)?if_helper502137.app(cont_tail_arg612136):R.ffi.throwNonFunApp(L[226],if_helper502137,[cont_tail_arg612136]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper502137)?if_helper502137.app(cont_tail_arg612136):R.ffi.throwNonFunApp(L[226],if_helper502137,[cont_tail_arg612136]);
},
"from":L[226]});
}
++R.GAS;
return $z21382139;
};
var $Hcont_tail_arg7252140 = function(cont_tail_arg552141,if_helper502137) {
if(--R.GAS > 0) {
$z21422143 = R.isFunction(if_helper502137)?if_helper502137.app(cont_tail_arg552141):R.ffi.throwNonFunApp(L[226],if_helper502137,[cont_tail_arg552141]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper502137)?if_helper502137.app(cont_tail_arg552141):R.ffi.throwNonFunApp(L[226],if_helper502137,[cont_tail_arg552141]);
},
"from":L[226]});
}
++R.GAS;
return $z21422143;
};
var $Hann_DASH_check_DASH_temp7232144 = function(ann_DASH_check_DASH_temp372145,AVLTree936) {
return ann_DASH_check_DASH_temp372145;
};
var $Hcont_tail_arg7212146 = function(cont_tail_arg282147,if_helper212148) {
if(--R.GAS > 0) {
$z21492150 = R.isFunction(if_helper212148)?if_helper212148.app(cont_tail_arg282147):R.ffi.throwNonFunApp(L[227],if_helper212148,[cont_tail_arg282147]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper212148)?if_helper212148.app(cont_tail_arg282147):R.ffi.throwNonFunApp(L[227],if_helper212148,[cont_tail_arg282147]);
},
"from":L[227]});
}
++R.GAS;
return $z21492150;
};
var $Hcont_tail_arg7222151 = function(cont_tail_arg262152,if_helper212148) {
if(--R.GAS > 0) {
$z21532154 = R.isFunction(if_helper212148)?if_helper212148.app(cont_tail_arg262152):R.ffi.throwNonFunApp(L[227],if_helper212148,[cont_tail_arg262152]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper212148)?if_helper212148.app(cont_tail_arg262152):R.ffi.throwNonFunApp(L[227],if_helper212148,[cont_tail_arg262152]);
},
"from":L[227]});
}
++R.GAS;
return $z21532154;
};
var $Hand_DASH_oper_DASH_7202155 = function(and_DASH_oper_DASH_192156,other752157,self742158) {
var if_helper52171 = R.makeFunction(function(if_helper_arg62189) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[230],1,arguments);
}
var ann_DASH_check_DASH_temp42190 = if_helper_arg62189;
return ann_DASH_check_DASH_temp42190;
});
var anf_if92188 = R.isBoolean(and_DASH_oper_DASH_192156);
if(R.isPyretTrue(anf_if92188)) {
if(R.isPyretTrue(and_DASH_oper_DASH_192156)) {
var anf_fun112169 = G(self742158,"inorder",L[229]);
var $z21612162 = D;
var $f21672168 = function(_) {
return R.isFunction(anf_fun112169)?anf_fun112169.app():R.ffi.throwNonFunApp(L[228],anf_fun112169,[]);
};
try {
if(--R.GAS > 0) {
$z21612162 = $f21672168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21672168,
"from":L[228]});
}
} catch($e21592160) {
if(R.isCont($e21592160)) {
var $ss21632164 = {"from":L[228],
"go":function(anf_arg122170) {
return $Hanf_arg7182172(anf_arg122170,if_helper52171,other752157);
}};
$e21592160.stack[R.EXN_STACKHEIGHT++] = $ss21632164;
}
if(R.isPyretException($e21592160)) {
$e21592160.pyretStack.push(L[228]);
}
throw $e21592160;
}
var $ret21652166 = $Hanf_arg7182172($z21612162,if_helper52171,other752157);
++R.GAS;
return $ret21652166;
} else {
var $z21752176 = D;
var $f21812182 = function(_) {
return R.isFunction(if_helper52171)?if_helper52171.app((false)):R.ffi.throwNonFunApp(L[230],if_helper52171,[(false)]);
};
try {
if(--R.GAS > 0) {
$z21752176 = $f21812182();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21812182,
"from":L[230]});
}
} catch($e21732174) {
if(R.isCont($e21732174)) {
var $ss21772178 = {"from":L[230],
"go":function(cont_tail_app102183) {
return $Hcont_tail_app7192184(cont_tail_app102183);
}};
$e21732174.stack[R.EXN_STACKHEIGHT++] = $ss21772178;
}
if(R.isPyretException($e21732174)) {
$e21732174.pyretStack.push(L[230]);
}
throw $e21732174;
}
var $ret21792180 = $Hcont_tail_app7192184($z21752176);
++R.GAS;
return $ret21792180;
}
} else {
var cont_tail_arg72187 = R.throwNonBooleanOp(L[231],("first"),("and"),and_DASH_oper_DASH_192156);
if(--R.GAS > 0) {
$z21852186 = R.isFunction(if_helper52171)?if_helper52171.app(cont_tail_arg72187):R.ffi.throwNonFunApp(L[231],if_helper52171,[cont_tail_arg72187]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper52171)?if_helper52171.app(cont_tail_arg72187):R.ffi.throwNonFunApp(L[231],if_helper52171,[cont_tail_arg72187]);
},
"from":L[231]});
}
++R.GAS;
return $z21852186;
}
};
var $Hanf_arg7182172 = function(anf_arg122170,if_helper52171,other752157) {
var anf_fun132201 = G(other752157,"inorder",L[233]);
var $z21932194 = D;
var $f21992200 = function(_) {
return R.isFunction(anf_fun132201)?anf_fun132201.app():R.ffi.throwNonFunApp(L[232],anf_fun132201,[]);
};
try {
if(--R.GAS > 0) {
$z21932194 = $f21992200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21992200,
"from":L[232]});
}
} catch($e21912192) {
if(R.isCont($e21912192)) {
var $ss21952196 = {"from":L[232],
"go":function(anf_arg142202) {
return $Hanf_arg7172203(anf_arg142202,anf_arg122170,if_helper52171);
}};
$e21912192.stack[R.EXN_STACKHEIGHT++] = $ss21952196;
}
if(R.isPyretException($e21912192)) {
$e21912192.pyretStack.push(L[232]);
}
throw $e21912192;
}
var $ret21972198 = $Hanf_arg7172203($z21932194,anf_arg122170,if_helper52171);
++R.GAS;
return $ret21972198;
};
var $Hanf_arg7172203 = function(anf_arg142202,anf_arg122170,if_helper52171) {
var and_DASH_oper_DASH_202214 = R.equiv(anf_arg122170,anf_arg142202);
var anf_if172220 = R.isBoolean(and_DASH_oper_DASH_202214);
if(R.isPyretTrue(anf_if172220)) {
var $z22062207 = D;
var $f22122213 = function(_) {
return R.isFunction(if_helper52171)?if_helper52171.app(and_DASH_oper_DASH_202214):R.ffi.throwNonFunApp(L[230],if_helper52171,[and_DASH_oper_DASH_202214]);
};
try {
if(--R.GAS > 0) {
$z22062207 = $f22122213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22122213,
"from":L[230]});
}
} catch($e22042205) {
if(R.isCont($e22042205)) {
var $ss22082209 = {"from":L[230],
"go":function(cont_tail_app182215) {
return $Hcont_tail_app7162216(cont_tail_app182215);
}};
$e22042205.stack[R.EXN_STACKHEIGHT++] = $ss22082209;
}
if(R.isPyretException($e22042205)) {
$e22042205.pyretStack.push(L[230]);
}
throw $e22042205;
}
var $ret22102211 = $Hcont_tail_app7162216($z22062207);
++R.GAS;
return $ret22102211;
} else {
var cont_tail_arg152219 = R.throwNonBooleanOp(L[234],("second"),("and"),and_DASH_oper_DASH_202214);
if(--R.GAS > 0) {
$z22172218 = R.isFunction(if_helper52171)?if_helper52171.app(cont_tail_arg152219):R.ffi.throwNonFunApp(L[234],if_helper52171,[cont_tail_arg152219]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper52171)?if_helper52171.app(cont_tail_arg152219):R.ffi.throwNonFunApp(L[234],if_helper52171,[cont_tail_arg152219]);
},
"from":L[234]});
}
++R.GAS;
return $z22172218;
}
};
var $Hcont_tail_app7162216 = function(cont_tail_app182215) {
return cont_tail_app182215;
};
var $Hcont_tail_app7192184 = function(cont_tail_app102183) {
return cont_tail_app102183;
};
var $Hann_DASH_check_DASH_temp7152221 = function(ann_DASH_check_DASH_temp12222,lists225) {
return ann_DASH_check_DASH_temp12222;
};
return R.loadModulesNew(NAMESPACE,[$lists12130,$error32231,$option52332,$arrays72433],function($lists12130,$error32231,$option52332,$arrays72433) {
var lists121 = R.getField($lists12130,"values");
var error322 = R.getField($error32231,"values");
var option523 = R.getField($option52332,"values");
var arrays724 = R.getField($arrays72433,"values");
var lists225 = R.getField($lists12130,"types");
var error426 = R.getField($error32231,"types");
var option627 = R.getField($option52332,"types");
var arrays828 = R.getField($arrays72433,"types");
return R.safeCall(function() {
var AVLTreeT1102223 = R.namedBrander("AVLTree");
var AVLTree936 = R.makeBranderAnn(AVLTreeT1102223,"AVLTree");
var SetT2122224 = R.namedBrander("Set");
var Set1137 = R.makeBranderAnn(SetT2122224,"Set");
var List133490 = G(lists121,"List",L[491]);
var empty141611 = G(lists121,"empty",L[490]);
var link15579 = G(lists121,"link",L[489]);
var is_DASH_empty163489 = G(lists121,"is-empty",L[488]);
var fold172706 = G(lists121,"fold",L[487]);
var AVLTree3182225 = {"$var":D,
"$name":"AVLTree3"};
var AVLTree192227 = {"$var":D,
"$name":"AVLTree"};
var is_DASH_AVLTree202229 = {"$var":D,
"$name":"is-AVLTree"};
var is_DASH_leaf211073 = {"$var":D,
"$name":"is-leaf"};
var leaf2241 = {"$var":D,
"$name":"leaf"};
var is_DASH_branch232233 = {"$var":D,
"$name":"is-branch"};
var branch241525 = {"$var":D,
"$name":"branch"};
var tree_DASH_fold252236 = {"$var":D,
"$name":"tree-fold"};
var mkbranch26920 = {"$var":D,
"$name":"mkbranch"};
var rebalance27921 = {"$var":D,
"$name":"rebalance"};
var remove_DASH_root282240 = {"$var":D,
"$name":"remove-root"};
var swap_DASH_next_DASH_lowest291074 = {"$var":D,
"$name":"swap-next-lowest"};
var Set4302243 = {"$var":D,
"$name":"Set4"};
var Set312245 = {"$var":D,
"$name":"Set"};
var is_DASH_Set322247 = {"$var":D,
"$name":"is-Set"};
var is_DASH_list_DASH_set332249 = {"$var":D,
"$name":"is-list-set"};
var list_DASH_set34563 = {"$var":D,
"$name":"list-set"};
var is_DASH_tree_DASH_set352252 = {"$var":D,
"$name":"is-tree-set"};
var tree_DASH_set3644 = {"$var":D,
"$name":"tree-set"};
var list_DASH_to_DASH_set37124 = {"$var":D,
"$name":"list-to-set"};
var list_DASH_to_DASH_list_DASH_set3842 = {"$var":D,
"$name":"list-to-list-set"};
var list_DASH_to_DASH_tree_DASH_set3943 = {"$var":D,
"$name":"list-to-tree-set"};
var list_DASH_to_DASH_tree402258 = {"$var":D,
"$name":"list-to-tree"};
var arr_DASH_to_DASH_list_DASH_set412260 = {"$var":D,
"$name":"arr-to-list-set"};
var arr_DASH_to_DASH_tree_DASH_set422262 = {"$var":D,
"$name":"arr-to-tree-set"};
var anf_shared33181 = R.makeMethod(function(self733488) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[485],0,arguments);
}
var anf_fun23487 = G(self733488,"inorder",L[486]);
var $z34793480 = D;
var $f34853486 = function(_) {
return R.isFunction(anf_fun23487)?anf_fun23487.app():R.ffi.throwNonFunApp(L[485],anf_fun23487,[]);
};
try {
if(--R.GAS > 0) {
$z34793480 = $f34853486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34853486,
"from":L[485]});
}
} catch($e34773478) {
if(R.isCont($e34773478)) {
var $ss34813482 = {"from":L[485],
"go":function(ann_DASH_check_DASH_temp12222) {
return $Hann_DASH_check_DASH_temp7152221(ann_DASH_check_DASH_temp12222,lists225);
}};
$e34773478.stack[R.EXN_STACKHEIGHT++] = $ss34813482;
}
if(R.isPyretException($e34773478)) {
$e34773478.pyretStack.push(L[485]);
}
throw $e34773478;
}
var $ret34833484 = $Hann_DASH_check_DASH_temp7152221($z34793480,lists225);
++R.GAS;
return $ret34833484;
};
},{"length":1});
var anf_shared193182 = R.makeMethod(function(self742158) {
return function(other752157) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[484],1,arguments);
}
var $z34693470 = D;
var $f34753476 = function(_) {
return R.isFunction(AVLTree192227.$var === D?U(L[483],"AVLTree"):AVLTree192227.$var)?AVLTree192227.$var === D?U(L[483],"AVLTree"):AVLTree192227.$var.app(other752157):R.ffi.throwNonFunApp(L[230],AVLTree192227.$var === D?U(L[483],"AVLTree"):AVLTree192227.$var,[other752157]);
};
try {
if(--R.GAS > 0) {
$z34693470 = $f34753476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34753476,
"from":L[230]});
}
} catch($e34673468) {
if(R.isCont($e34673468)) {
var $ss34713472 = {"from":L[230],
"go":function(and_DASH_oper_DASH_192156) {
return $Hand_DASH_oper_DASH_7202155(and_DASH_oper_DASH_192156,other752157,self742158);
}};
$e34673468.stack[R.EXN_STACKHEIGHT++] = $ss34713472;
}
if(R.isPyretException($e34673468)) {
$e34673468.pyretStack.push(L[230]);
}
throw $e34673468;
}
var $ret34733474 = $Hand_DASH_oper_DASH_7202155($z34693470,other752157,self742158);
++R.GAS;
return $ret34733474;
};
},{"length":2});
var anf_singleton_variant_member303188 = R.makeMethod(function(self23466) {
return function(cases_DASH_funs33447,else_DASH_clause43458) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[227],2,arguments);
}
var if_DASH_63459 = R.hasField(cases_DASH_funs33447,("leaf"));
var if_helper212148 = R.makeFunction(function(if_helper_arg223464) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[227],1,arguments);
}
var ann_DASH_check_DASH_temp203465 = if_helper_arg223464;
return ann_DASH_check_DASH_temp203465;
});
var anf_if253463 = R.isBoolean(if_DASH_63459);
if(R.isPyretTrue(anf_if253463)) {
if(R.isPyretTrue(if_DASH_63459)) {
var call_DASH_leaf13446 = G(cases_DASH_funs33447,"leaf",L[227]);
var $z34383439 = D;
var $f34443445 = function(_) {
return R.isFunction(call_DASH_leaf13446)?call_DASH_leaf13446.app():R.ffi.throwNonFunApp(L[227],call_DASH_leaf13446,[]);
};
try {
if(--R.GAS > 0) {
$z34383439 = $f34443445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34443445,
"from":L[227]});
}
} catch($e34363437) {
if(R.isCont($e34363437)) {
var $ss34403441 = {"from":L[227],
"go":function(cont_tail_arg282147) {
return $Hcont_tail_arg7212146(cont_tail_arg282147,if_helper212148);
}};
$e34363437.stack[R.EXN_STACKHEIGHT++] = $ss34403441;
}
if(R.isPyretException($e34363437)) {
$e34363437.pyretStack.push(L[227]);
}
throw $e34363437;
}
var $ret34423443 = $Hcont_tail_arg7212146($z34383439,if_helper212148);
++R.GAS;
return $ret34423443;
} else {
var $z34503451 = D;
var $f34563457 = function(_) {
return R.isFunction(else_DASH_clause43458)?else_DASH_clause43458.app():R.ffi.throwNonFunApp(L[227],else_DASH_clause43458,[]);
};
try {
if(--R.GAS > 0) {
$z34503451 = $f34563457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34563457,
"from":L[227]});
}
} catch($e34483449) {
if(R.isCont($e34483449)) {
var $ss34523453 = {"from":L[227],
"go":function(cont_tail_arg262152) {
return $Hcont_tail_arg7222151(cont_tail_arg262152,if_helper212148);
}};
$e34483449.stack[R.EXN_STACKHEIGHT++] = $ss34523453;
}
if(R.isPyretException($e34483449)) {
$e34483449.pyretStack.push(L[227]);
}
throw $e34483449;
}
var $ret34543455 = $Hcont_tail_arg7222151($z34503451,if_helper212148);
++R.GAS;
return $ret34543455;
}
} else {
var cont_tail_arg233462 = R.throwNonBooleanCondition(L[227],("if"),if_DASH_63459);
if(--R.GAS > 0) {
$z34603461 = R.isFunction(if_helper212148)?if_helper212148.app(cont_tail_arg233462):R.ffi.throwNonFunApp(L[227],if_helper212148,[cont_tail_arg233462]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper212148)?if_helper212148.app(cont_tail_arg233462):R.ffi.throwNonFunApp(L[227],if_helper212148,[cont_tail_arg233462]);
},
"from":L[227]});
}
++R.GAS;
return $z34603461;
}
};
},{"length":3});
var anf_singleton_variant_member323189 = R.makeMethod(function(self53435) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[227],0,arguments);
}
var ann_DASH_check_DASH_temp313434 = ("leaf");
return ann_DASH_check_DASH_temp313434;
};
},{"length":1});
var anf_singleton_variant_member343190 = R.makeMethod(function(self433433) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[482],0,arguments);
}
var ann_DASH_check_DASH_temp333432 = (0);
return R.checkAnn(L[481],$type$Number19,ann_DASH_check_DASH_temp333432,function() {
return ann_DASH_check_DASH_temp333432;
});
};
},{"length":1});
var anf_singleton_variant_member363191 = R.makeMethod(function(self443430) {
return function(val453431) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[480],1,arguments);
}
var ann_DASH_check_DASH_temp353429 = (false);
return R.checkAnn(L[479],$type$Boolean18,ann_DASH_check_DASH_temp353429,function() {
return ann_DASH_check_DASH_temp353429;
});
};
},{"length":2});
var anf_singleton_variant_member383192 = R.makeMethod(function(self463428) {
return function(val473427) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[478],1,arguments);
}
var $z34193420 = D;
var $f34253426 = function(_) {
return R.isFunction(mkbranch26920.$var === D?U(L[475],"mkbranch"):mkbranch26920.$var)?mkbranch26920.$var === D?U(L[475],"mkbranch"):mkbranch26920.$var.app(val473427,leaf2241.$var === D?U(L[476],"leaf"):leaf2241.$var,leaf2241.$var === D?U(L[477],"leaf"):leaf2241.$var):R.ffi.throwNonFunApp(L[478],mkbranch26920.$var === D?U(L[475],"mkbranch"):mkbranch26920.$var,[val473427,leaf2241.$var === D?U(L[476],"leaf"):leaf2241.$var,leaf2241.$var === D?U(L[477],"leaf"):leaf2241.$var]);
};
try {
if(--R.GAS > 0) {
$z34193420 = $f34253426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34253426,
"from":L[478]});
}
} catch($e34173418) {
if(R.isCont($e34173418)) {
var $ss34213422 = {"from":L[478],
"go":function(ann_DASH_check_DASH_temp372145) {
return $Hann_DASH_check_DASH_temp7232144(ann_DASH_check_DASH_temp372145,AVLTree936);
}};
$e34173418.stack[R.EXN_STACKHEIGHT++] = $ss34213422;
}
if(R.isPyretException($e34173418)) {
$e34173418.pyretStack.push(L[478]);
}
throw $e34173418;
}
var $ret34233424 = $Hann_DASH_check_DASH_temp7232144($z34193420,AVLTree936);
++R.GAS;
return $ret34233424;
};
},{"length":2});
var anf_singleton_variant_member403193 = R.makeMethod(function(self482663) {
return function(val493416) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[474],1,arguments);
}
var ann_DASH_check_DASH_temp393415 = leaf2241.$var === D?U(L[472],"leaf"):leaf2241.$var;
return R.checkAnn(L[473],AVLTree936,ann_DASH_check_DASH_temp393415,function() {
return ann_DASH_check_DASH_temp393415;
});
};
},{"length":2});
var anf_singleton_variant_member423194 = R.makeMethod(function(self503414) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[471],0,arguments);
}
var ann_DASH_check_DASH_temp413413 = empty141611;
return R.checkAnn(L[470],R.getDotAnn(L[470],"lists",lists225,"List"),ann_DASH_check_DASH_temp413413,function() {
return ann_DASH_check_DASH_temp413413;
});
};
},{"length":1});
var anf_singleton_variant_member443195 = R.makeMethod(function(self513412) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[469],0,arguments);
}
var ann_DASH_check_DASH_temp433411 = empty141611;
return R.checkAnn(L[468],R.getDotAnn(L[468],"lists",lists225,"List"),ann_DASH_check_DASH_temp433411,function() {
return ann_DASH_check_DASH_temp433411;
});
};
},{"length":1});
var anf_singleton_variant_member463196 = R.makeMethod(function(self523410) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[467],0,arguments);
}
var ann_DASH_check_DASH_temp453409 = empty141611;
return R.checkAnn(L[466],R.getDotAnn(L[466],"lists",lists225,"List"),ann_DASH_check_DASH_temp453409,function() {
return ann_DASH_check_DASH_temp453409;
});
};
},{"length":1});
var anf_singleton_variant_member483197 = R.makeMethod(function(self533407) {
return function(f543408,base553406) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[465],2,arguments);
}
var ann_DASH_check_DASH_temp473405 = base553406;
return ann_DASH_check_DASH_temp473405;
};
},{"length":3});
var anf_variant_member633203 = R.makeMethod(function(self83385) {
return function(cases_DASH_funs93386,else_DASH_clause103397) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[226],2,arguments);
}
var if_DASH_123398 = R.hasField(cases_DASH_funs93386,("branch"));
var if_helper502137 = R.makeFunction(function(if_helper_arg513403) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[226],1,arguments);
}
var ann_DASH_check_DASH_temp493404 = if_helper_arg513403;
return ann_DASH_check_DASH_temp493404;
});
var anf_if543402 = R.isBoolean(if_DASH_123398);
if(R.isPyretTrue(anf_if543402)) {
if(R.isPyretTrue(if_DASH_123398)) {
var call_DASH_branch73380 = G(cases_DASH_funs93386,"branch",L[226]);
var anf_arg573381 = G(self83385,"value",L[464]);
var anf_arg583382 = G(self83385,"h",L[463]);
var anf_arg593383 = G(self83385,"left",L[462]);
var anf_arg603384 = G(self83385,"right",L[461]);
var $z33723373 = D;
var $f33783379 = function(_) {
return R.isFunction(call_DASH_branch73380)?call_DASH_branch73380.app(anf_arg573381,anf_arg583382,anf_arg593383,anf_arg603384):R.ffi.throwNonFunApp(L[226],call_DASH_branch73380,[anf_arg573381,anf_arg583382,anf_arg593383,anf_arg603384]);
};
try {
if(--R.GAS > 0) {
$z33723373 = $f33783379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33783379,
"from":L[226]});
}
} catch($e33703371) {
if(R.isCont($e33703371)) {
var $ss33743375 = {"from":L[226],
"go":function(cont_tail_arg612136) {
return $Hcont_tail_arg7242135(cont_tail_arg612136,if_helper502137);
}};
$e33703371.stack[R.EXN_STACKHEIGHT++] = $ss33743375;
}
if(R.isPyretException($e33703371)) {
$e33703371.pyretStack.push(L[226]);
}
throw $e33703371;
}
var $ret33763377 = $Hcont_tail_arg7242135($z33723373,if_helper502137);
++R.GAS;
return $ret33763377;
} else {
var $z33893390 = D;
var $f33953396 = function(_) {
return R.isFunction(else_DASH_clause103397)?else_DASH_clause103397.app():R.ffi.throwNonFunApp(L[226],else_DASH_clause103397,[]);
};
try {
if(--R.GAS > 0) {
$z33893390 = $f33953396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33953396,
"from":L[226]});
}
} catch($e33873388) {
if(R.isCont($e33873388)) {
var $ss33913392 = {"from":L[226],
"go":function(cont_tail_arg552141) {
return $Hcont_tail_arg7252140(cont_tail_arg552141,if_helper502137);
}};
$e33873388.stack[R.EXN_STACKHEIGHT++] = $ss33913392;
}
if(R.isPyretException($e33873388)) {
$e33873388.pyretStack.push(L[226]);
}
throw $e33873388;
}
var $ret33933394 = $Hcont_tail_arg7252140($z33893390,if_helper502137);
++R.GAS;
return $ret33933394;
}
} else {
var cont_tail_arg523401 = R.throwNonBooleanCondition(L[226],("if"),if_DASH_123398);
if(--R.GAS > 0) {
$z33993400 = R.isFunction(if_helper502137)?if_helper502137.app(cont_tail_arg523401):R.ffi.throwNonFunApp(L[226],if_helper502137,[cont_tail_arg523401]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper502137)?if_helper502137.app(cont_tail_arg523401):R.ffi.throwNonFunApp(L[226],if_helper502137,[cont_tail_arg523401]);
},
"from":L[226]});
}
++R.GAS;
return $z33993400;
}
};
},{"length":3});
var anf_variant_member813204 = R.makeMethod(function(self111987) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[226],0,arguments);
}
var anf_arg653369 = G(self111987,"value",L[226]);
var $z33613362 = D;
var $f33673368 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg653369):R.ffi.throwNonFunApp(L[226],torepr16,[anf_arg653369]);
};
try {
if(--R.GAS > 0) {
$z33613362 = $f33673368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33673368,
"from":L[226]});
}
} catch($e33593360) {
if(R.isCont($e33593360)) {
var $ss33633364 = {"from":L[226],
"go":function(anf_arg661986) {
return $Hanf_arg7381985(anf_arg661986,self111987,_plus9,torepr16);
}};
$e33593360.stack[R.EXN_STACKHEIGHT++] = $ss33633364;
}
if(R.isPyretException($e33593360)) {
$e33593360.pyretStack.push(L[226]);
}
throw $e33593360;
}
var $ret33653366 = $Hanf_arg7381985($z33613362,self111987,_plus9,torepr16);
++R.GAS;
return $ret33653366;
};
},{"length":1});
var anf_variant_member833205 = R.makeMethod(function(self603358) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[460],0,arguments);
}
var ann_DASH_check_DASH_temp823357 = G(self603358,"h",L[458]);
return R.checkAnn(L[459],$type$Number19,ann_DASH_check_DASH_temp823357,function() {
return ann_DASH_check_DASH_temp823357;
});
};
},{"length":1});
var anf_variant_member1043206 = R.makeMethod(function(self611947) {
return function(val621948) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[457],1,arguments);
}
var anf_arg853356 = G(self611947,"value",L[456]);
var if_DASH_143349 = R.equiv(val621948,anf_arg853356);
var if_helper861946 = R.makeFunction(function(if_helper_arg873354) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[454],1,arguments);
}
var ann_DASH_check_DASH_temp843355 = if_helper_arg873354;
return R.checkAnn(L[455],$type$Boolean18,ann_DASH_check_DASH_temp843355,function() {
return ann_DASH_check_DASH_temp843355;
});
});
var anf_if903353 = R.isBoolean(if_DASH_143349);
if(R.isPyretTrue(anf_if903353)) {
if(R.isPyretTrue(if_DASH_143349)) {
var $z33303331 = D;
var $f33363337 = function(_) {
return R.isFunction(if_helper861946)?if_helper861946.app((true)):R.ffi.throwNonFunApp(L[451],if_helper861946,[(true)]);
};
try {
if(--R.GAS > 0) {
$z33303331 = $f33363337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33363337,
"from":L[451]});
}
} catch($e33283329) {
if(R.isCont($e33283329)) {
var $ss33323333 = {"from":L[451],
"go":function(cont_tail_app1031943) {
return $Hcont_tail_app7391942(cont_tail_app1031943);
}};
$e33283329.stack[R.EXN_STACKHEIGHT++] = $ss33323333;
}
if(R.isPyretException($e33283329)) {
$e33283329.pyretStack.push(L[451]);
}
throw $e33283329;
}
var $ret33343335 = $Hcont_tail_app7391942($z33303331);
++R.GAS;
return $ret33343335;
} else {
var anf_arg913348 = G(self611947,"value",L[453]);
var $z33403341 = D;
var $f33463347 = function(_) {
return R.isFunction(_lessthan7)?_lessthan7.app(val621948,anf_arg913348):R.ffi.throwNonFunApp(L[452],_lessthan7,[val621948,anf_arg913348]);
};
try {
if(--R.GAS > 0) {
$z33403341 = $f33463347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33463347,
"from":L[452]});
}
} catch($e33383339) {
if(R.isCont($e33383339)) {
var $ss33423343 = {"from":L[452],
"go":function(if_DASH_131945) {
return $Hif_DASH_7421944(if_DASH_131945,if_helper861946,self611947,val621948);
}};
$e33383339.stack[R.EXN_STACKHEIGHT++] = $ss33423343;
}
if(R.isPyretException($e33383339)) {
$e33383339.pyretStack.push(L[452]);
}
throw $e33383339;
}
var $ret33443345 = $Hif_DASH_7421944($z33403341,if_helper861946,self611947,val621948);
++R.GAS;
return $ret33443345;
}
} else {
var cont_tail_arg883352 = R.throwNonBooleanCondition(L[454],("if"),if_DASH_143349);
if(--R.GAS > 0) {
$z33503351 = R.isFunction(if_helper861946)?if_helper861946.app(cont_tail_arg883352):R.ffi.throwNonFunApp(L[454],if_helper861946,[cont_tail_arg883352]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper861946)?if_helper861946.app(cont_tail_arg883352):R.ffi.throwNonFunApp(L[454],if_helper861946,[cont_tail_arg883352]);
},
"from":L[454]});
}
++R.GAS;
return $z33503351;
}
};
},{"length":2});
var anf_variant_member1363207 = R.makeMethod(function(self631852) {
return function(val641853) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[450],1,arguments);
}
var anf_arg1063327 = G(self631852,"value",L[449]);
var if_DASH_163320 = R.equiv(val641853,anf_arg1063327);
var if_helper1071847 = R.makeFunction(function(if_helper_arg1083325) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[447],1,arguments);
}
var ann_DASH_check_DASH_temp1053326 = if_helper_arg1083325;
return R.checkAnn(L[448],AVLTree936,ann_DASH_check_DASH_temp1053326,function() {
return ann_DASH_check_DASH_temp1053326;
});
});
var anf_if1113324 = R.isBoolean(if_DASH_163320);
if(R.isPyretTrue(anf_if1113324)) {
if(R.isPyretTrue(if_DASH_163320)) {
var anf_arg1323307 = G(self631852,"left",L[444]);
var anf_arg1333308 = G(self631852,"right",L[443]);
var $z32993300 = D;
var $f33053306 = function(_) {
return R.isFunction(mkbranch26920.$var === D?U(L[442],"mkbranch"):mkbranch26920.$var)?mkbranch26920.$var === D?U(L[442],"mkbranch"):mkbranch26920.$var.app(val641853,anf_arg1323307,anf_arg1333308):R.ffi.throwNonFunApp(L[199],mkbranch26920.$var === D?U(L[442],"mkbranch"):mkbranch26920.$var,[val641853,anf_arg1323307,anf_arg1333308]);
};
try {
if(--R.GAS > 0) {
$z32993300 = $f33053306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33053306,
"from":L[199]});
}
} catch($e32973298) {
if(R.isCont($e32973298)) {
var $ss33013302 = {"from":L[199],
"go":function(cont_tail_arg1341846) {
return $Hcont_tail_arg7431845(cont_tail_arg1341846,if_helper1071847);
}};
$e32973298.stack[R.EXN_STACKHEIGHT++] = $ss33013302;
}
if(R.isPyretException($e32973298)) {
$e32973298.pyretStack.push(L[199]);
}
throw $e32973298;
}
var $ret33033304 = $Hcont_tail_arg7431845($z32993300,if_helper1071847);
++R.GAS;
return $ret33033304;
} else {
var anf_arg1123319 = G(self631852,"value",L[446]);
var $z33113312 = D;
var $f33173318 = function(_) {
return R.isFunction(_lessthan7)?_lessthan7.app(val641853,anf_arg1123319):R.ffi.throwNonFunApp(L[445],_lessthan7,[val641853,anf_arg1123319]);
};
try {
if(--R.GAS > 0) {
$z33113312 = $f33173318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33173318,
"from":L[445]});
}
} catch($e33093310) {
if(R.isCont($e33093310)) {
var $ss33133314 = {"from":L[445],
"go":function(if_DASH_151851) {
return $Hif_DASH_7501850(if_DASH_151851,if_helper1071847,mkbranch26920,rebalance27921,self631852,val641853);
}};
$e33093310.stack[R.EXN_STACKHEIGHT++] = $ss33133314;
}
if(R.isPyretException($e33093310)) {
$e33093310.pyretStack.push(L[445]);
}
throw $e33093310;
}
var $ret33153316 = $Hif_DASH_7501850($z33113312,if_helper1071847,mkbranch26920,rebalance27921,self631852,val641853);
++R.GAS;
return $ret33153316;
}
} else {
var cont_tail_arg1093323 = R.throwNonBooleanCondition(L[447],("if"),if_DASH_163320);
if(--R.GAS > 0) {
$z33213322 = R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1093323):R.ffi.throwNonFunApp(L[447],if_helper1071847,[cont_tail_arg1093323]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1071847)?if_helper1071847.app(cont_tail_arg1093323):R.ffi.throwNonFunApp(L[447],if_helper1071847,[cont_tail_arg1093323]);
},
"from":L[447]});
}
++R.GAS;
return $z33213322;
}
};
},{"length":2});
var anf_variant_member1663208 = R.makeMethod(function(self651755) {
return function(val661756) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[441],1,arguments);
}
var anf_arg1383296 = G(self651755,"value",L[440]);
var if_DASH_183289 = R.equiv(val661756,anf_arg1383296);
var if_helper1391750 = R.makeFunction(function(if_helper_arg1403294) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[438],1,arguments);
}
var ann_DASH_check_DASH_temp1373295 = if_helper_arg1403294;
return R.checkAnn(L[439],AVLTree936,ann_DASH_check_DASH_temp1373295,function() {
return ann_DASH_check_DASH_temp1373295;
});
});
var anf_if1433293 = R.isBoolean(if_DASH_183289);
if(R.isPyretTrue(anf_if1433293)) {
if(R.isPyretTrue(if_DASH_183289)) {
var $z32703271 = D;
var $f32763277 = function(_) {
return R.isFunction(remove_DASH_root282240.$var === D?U(L[435],"remove-root"):remove_DASH_root282240.$var)?remove_DASH_root282240.$var === D?U(L[435],"remove-root"):remove_DASH_root282240.$var.app(self651755):R.ffi.throwNonFunApp(L[179],remove_DASH_root282240.$var === D?U(L[435],"remove-root"):remove_DASH_root282240.$var,[self651755]);
};
try {
if(--R.GAS > 0) {
$z32703271 = $f32763277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32763277,
"from":L[179]});
}
} catch($e32683269) {
if(R.isCont($e32683269)) {
var $ss32723273 = {"from":L[179],
"go":function(cont_tail_arg1641749) {
return $Hcont_tail_arg7511748(cont_tail_arg1641749,if_helper1391750);
}};
$e32683269.stack[R.EXN_STACKHEIGHT++] = $ss32723273;
}
if(R.isPyretException($e32683269)) {
$e32683269.pyretStack.push(L[179]);
}
throw $e32683269;
}
var $ret32743275 = $Hcont_tail_arg7511748($z32703271,if_helper1391750);
++R.GAS;
return $ret32743275;
} else {
var anf_arg1443288 = G(self651755,"value",L[437]);
var $z32803281 = D;
var $f32863287 = function(_) {
return R.isFunction(_lessthan7)?_lessthan7.app(val661756,anf_arg1443288):R.ffi.throwNonFunApp(L[436],_lessthan7,[val661756,anf_arg1443288]);
};
try {
if(--R.GAS > 0) {
$z32803281 = $f32863287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32863287,
"from":L[436]});
}
} catch($e32783279) {
if(R.isCont($e32783279)) {
var $ss32823283 = {"from":L[436],
"go":function(if_DASH_171754) {
return $Hif_DASH_7581753(if_DASH_171754,if_helper1391750,mkbranch26920,rebalance27921,self651755,val661756);
}};
$e32783279.stack[R.EXN_STACKHEIGHT++] = $ss32823283;
}
if(R.isPyretException($e32783279)) {
$e32783279.pyretStack.push(L[436]);
}
throw $e32783279;
}
var $ret32843285 = $Hif_DASH_7581753($z32803281,if_helper1391750,mkbranch26920,rebalance27921,self651755,val661756);
++R.GAS;
return $ret32843285;
}
} else {
var cont_tail_arg1413292 = R.throwNonBooleanCondition(L[438],("if"),if_DASH_183289);
if(--R.GAS > 0) {
$z32903291 = R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1413292):R.ffi.throwNonFunApp(L[438],if_helper1391750,[cont_tail_arg1413292]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper1391750)?if_helper1391750.app(cont_tail_arg1413292):R.ffi.throwNonFunApp(L[438],if_helper1391750,[cont_tail_arg1413292]);
},
"from":L[438]});
}
++R.GAS;
return $z32903291;
}
};
},{"length":2});
var anf_variant_member1763209 = R.makeMethod(function(self671709) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[178],0,arguments);
}
var anf_arg1681708 = G(self671709,"value",L[434]);
var anf_bracket1693267 = G(self671709,"left",L[433]);
var anf_fun1703266 = G(anf_bracket1693267,"preorder",L[432]);
var $z32583259 = D;
var $f32643265 = function(_) {
return R.isFunction(anf_fun1703266)?anf_fun1703266.app():R.ffi.throwNonFunApp(L[431],anf_fun1703266,[]);
};
try {
if(--R.GAS > 0) {
$z32583259 = $f32643265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32643265,
"from":L[431]});
}
} catch($e32563257) {
if(R.isCont($e32563257)) {
var $ss32603261 = {"from":L[431],
"go":function(anf_arg1711707) {
return $Hanf_arg7621706(anf_arg1711707,anf_arg1681708,link15579,lists225,self671709,_plus9);
}};
$e32563257.stack[R.EXN_STACKHEIGHT++] = $ss32603261;
}
if(R.isPyretException($e32563257)) {
$e32563257.pyretStack.push(L[431]);
}
throw $e32563257;
}
var $ret32623263 = $Hanf_arg7621706($z32583259,anf_arg1681708,link15579,lists225,self671709,_plus9);
++R.GAS;
return $ret32623263;
};
},{"length":1});
var anf_variant_member1863210 = R.makeMethod(function(self681666) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[173],0,arguments);
}
var anf_bracket1783255 = G(self681666,"left",L[430]);
var anf_fun1793254 = G(anf_bracket1783255,"inorder",L[429]);
var $z32463247 = D;
var $f32523253 = function(_) {
return R.isFunction(anf_fun1793254)?anf_fun1793254.app():R.ffi.throwNonFunApp(L[428],anf_fun1793254,[]);
};
try {
if(--R.GAS > 0) {
$z32463247 = $f32523253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32523253,
"from":L[428]});
}
} catch($e32443245) {
if(R.isCont($e32443245)) {
var $ss32483249 = {"from":L[428],
"go":function(anf_arg1801665) {
return $Hanf_arg7661664(anf_arg1801665,link15579,lists225,self681666,_plus9);
}};
$e32443245.stack[R.EXN_STACKHEIGHT++] = $ss32483249;
}
if(R.isPyretException($e32443245)) {
$e32443245.pyretStack.push(L[428]);
}
throw $e32443245;
}
var $ret32503251 = $Hanf_arg7661664($z32463247,link15579,lists225,self681666,_plus9);
++R.GAS;
return $ret32503251;
};
},{"length":1});
var anf_variant_member1973211 = R.makeMethod(function(self691612) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[167],0,arguments);
}
var anf_bracket1883243 = G(self691612,"left",L[427]);
var anf_fun1893242 = G(anf_bracket1883243,"postorder",L[426]);
var $z32343235 = D;
var $f32403241 = function(_) {
return R.isFunction(anf_fun1893242)?anf_fun1893242.app():R.ffi.throwNonFunApp(L[425],anf_fun1893242,[]);
};
try {
if(--R.GAS > 0) {
$z32343235 = $f32403241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32403241,
"from":L[425]});
}
} catch($e32323233) {
if(R.isCont($e32323233)) {
var $ss32363237 = {"from":L[425],
"go":function(anf_arg1901610) {
return $Hanf_arg7711609(anf_arg1901610,empty141611,link15579,lists225,self691612,_plus9);
}};
$e32323233.stack[R.EXN_STACKHEIGHT++] = $ss32363237;
}
if(R.isPyretException($e32323233)) {
$e32323233.pyretStack.push(L[425]);
}
throw $e32323233;
}
var $ret32383239 = $Hanf_arg7711609($z32343235,empty141611,link15579,lists225,self691612,_plus9);
++R.GAS;
return $ret32383239;
};
},{"length":1});
var anf_variant_member2063212 = R.makeMethod(function(self703229) {
return function(f711584,base723227) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[160],2,arguments);
}
var anf_bracket1993231 = G(self703229,"right",L[424]);
var anf_fun2001582 = G(anf_bracket1993231,"fold",L[423]);
var anf_bracket2013230 = G(self703229,"left",L[422]);
var anf_fun2021583 = G(anf_bracket2013230,"fold",L[421]);
var anf_arg2033228 = G(self703229,"value",L[420]);
var $z32193220 = D;
var $f32253226 = function(_) {
return R.isFunction(f711584)?f711584.app(base723227,anf_arg2033228):R.ffi.throwNonFunApp(L[419],f711584,[base723227,anf_arg2033228]);
};
try {
if(--R.GAS > 0) {
$z32193220 = $f32253226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32253226,
"from":L[419]});
}
} catch($e32173218) {
if(R.isCont($e32173218)) {
var $ss32213222 = {"from":L[419],
"go":function(anf_arg2041581) {
return $Hanf_arg7741580(anf_arg2041581,anf_fun2001582,anf_fun2021583,f711584);
}};
$e32173218.stack[R.EXN_STACKHEIGHT++] = $ss32213222;
}
if(R.isPyretException($e32173218)) {
$e32173218.pyretStack.push(L[419]);
}
throw $e32173218;
}
var $ret32233224 = $Hanf_arg7741580($z32193220,anf_fun2001582,anf_fun2021583,f711584);
++R.GAS;
return $ret32233224;
};
},{"length":3});
var anf_assign2072226 = (function() {
var $leaf_DASH_base31833184 = {"to-list":anf_shared33181,
"_equals":anf_shared193182,
"_match":anf_singleton_variant_member303188,
"_torepr":anf_singleton_variant_member323189,
"height":anf_singleton_variant_member343190,
"contains":anf_singleton_variant_member363191,
"insert":anf_singleton_variant_member383192,
"remove":anf_singleton_variant_member403193,
"preorder":anf_singleton_variant_member423194,
"inorder":anf_singleton_variant_member443195,
"postorder":anf_singleton_variant_member463196,
"fold":anf_singleton_variant_member483197};
var $leaf_DASH_brands31863187 = {"$brand-leaf3185":true};
$leaf_DASH_brands31863187[AVLTreeT1102223._brand] = true
var $branch_DASH_base31983199 = {"to-list":anf_shared33181,
"_equals":anf_shared193182,
"_match":anf_variant_member633203,
"_torepr":anf_variant_member813204,
"height":anf_variant_member833205,
"contains":anf_variant_member1043206,
"insert":anf_variant_member1363207,
"remove":anf_variant_member1663208,
"preorder":anf_variant_member1763209,
"inorder":anf_variant_member1863210,
"postorder":anf_variant_member1973211,
"fold":anf_variant_member2063212};
var $branch_DASH_brands32013202 = {"$brand-branch3200":true};
$branch_DASH_brands32013202[AVLTreeT1102223._brand] = true
return R.makeObject({"AVLTree":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AVLTreeT1102223._brand));
}),
"is-leaf":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[227],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-leaf3185"));
}),
"leaf":R.makeBrandedObject($leaf_DASH_base31833184,$leaf_DASH_brands31863187),
"is-branch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[226],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-branch3200"));
}),
"branch":R.makeFunction(function(value563213,h573214,left583215,right593216) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[415],4,arguments);
}
return R.checkAnnArgs([$type$Number19,AVLTree936,AVLTree936],[h573214,left583215,right593216],[L[416],L[417],L[418]],function() {
var dict = R.create($branch_DASH_base31983199);
dict["value"] = value563213
dict["h"] = h573214
dict["left"] = left583215
dict["right"] = right593216
return R.makeBrandedObject(dict,$branch_DASH_brands32013202);
});
})});
})();
AVLTree3182225.$var = anf_assign2072226;
var anf_assign2082228 = G(AVLTree3182225.$var,"AVLTree",L[1]);
AVLTree192227.$var = anf_assign2082228;
var anf_assign2092230 = G(AVLTree3182225.$var,"AVLTree",L[1]);
is_DASH_AVLTree202229.$var = anf_assign2092230;
var anf_assign2102231 = G(AVLTree3182225.$var,"is-leaf",L[227]);
is_DASH_leaf211073.$var = anf_assign2102231;
var anf_assign2112232 = G(AVLTree3182225.$var,"leaf",L[227]);
leaf2241.$var = anf_assign2112232;
var anf_assign2122234 = G(AVLTree3182225.$var,"is-branch",L[226]);
is_DASH_branch232233.$var = anf_assign2122234;
var anf_assign2132235 = G(AVLTree3182225.$var,"branch",L[226]);
branch241525.$var = anf_assign2132235;
var anf_assign2162237 = R.makeFunction(function(f763167,base773168,tree783169) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[413],3,arguments);
}
var anf_fun2153180 = G(tree783169,"fold",L[414]);
var $z31723173 = D;
var $f31783179 = function(_) {
return R.isFunction(anf_fun2153180)?anf_fun2153180.app(f763167,base773168):R.ffi.throwNonFunApp(L[413],anf_fun2153180,[f763167,base773168]);
};
try {
if(--R.GAS > 0) {
$z31723173 = $f31783179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31783179,
"from":L[413]});
}
} catch($e31703171) {
if(R.isCont($e31703171)) {
var $ss31743175 = {"from":L[413],
"go":function(ann_DASH_check_DASH_temp2141579) {
return $Hann_DASH_check_DASH_temp7751578(ann_DASH_check_DASH_temp2141579);
}};
$e31703171.stack[R.EXN_STACKHEIGHT++] = $ss31743175;
}
if(R.isPyretException($e31703171)) {
$e31703171.pyretStack.push(L[413]);
}
throw $e31703171;
}
var $ret31763177 = $Hann_DASH_check_DASH_temp7751578($z31723173);
++R.GAS;
return $ret31763177;
});
tree_DASH_fold252236.$var = anf_assign2162237;
var anf_assign2242238 = R.makeFunction(function(val791528,left801526,right811527) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[158],3,arguments);
}
return R.checkAnnArgs([AVLTree936,AVLTree936],[left801526,right811527],[L[411],L[412]],function() {
var anf_fun2183166 = G(left801526,"height",L[410]);
var $z31583159 = D;
var $f31643165 = function(_) {
return R.isFunction(anf_fun2183166)?anf_fun2183166.app():R.ffi.throwNonFunApp(L[409],anf_fun2183166,[]);
};
try {
if(--R.GAS > 0) {
$z31583159 = $f31643165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31643165,
"from":L[409]});
}
} catch($e31563157) {
if(R.isCont($e31563157)) {
var $ss31603161 = {"from":L[409],
"go":function(anf_arg2191524) {
return $Hanf_arg7801523(anf_arg2191524,branch241525,left801526,right811527,val791528,_plus9,num_DASH_max13);
}};
$e31563157.stack[R.EXN_STACKHEIGHT++] = $ss31603161;
}
if(R.isPyretException($e31563157)) {
$e31563157.pyretStack.push(L[409]);
}
throw $e31563157;
}
var $ret31623163 = $Hanf_arg7801523($z31583159,branch241525,left801526,right811527,val791528,_plus9,num_DASH_max13);
++R.GAS;
return $ret31623163;
});
});
mkbranch26920.$var = anf_assign2242238;
var anf_assign3382239 = R.makeFunction(function(tree821155) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[368],1,arguments);
}
return R.checkAnnArgs([AVLTree936],[tree821155],[L[408]],function() {
var left_DASH_left831151 = {"$var":D,
"$name":"left-left"};
var right_DASH_right841154 = {"$var":D,
"$name":"right-right"};
var left_DASH_right851152 = {"$var":D,
"$name":"left-right"};
var right_DASH_left861153 = {"$var":D,
"$name":"right-left"};
var anf_assign2363072 = R.makeFunction(function(t873139) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[153],1,arguments);
}
var anf_bracket2273155 = G(t873139,"left",L[407]);
var anf_arg2281509 = G(anf_bracket2273155,"value",L[406]);
var anf_bracket2293154 = G(t873139,"left",L[405]);
var anf_arg2301510 = G(anf_bracket2293154,"left",L[404]);
var anf_arg2313150 = G(t873139,"value",L[403]);
var anf_bracket2323153 = G(t873139,"left",L[402]);
var anf_arg2333151 = G(anf_bracket2323153,"right",L[401]);
var anf_arg2343152 = G(t873139,"right",L[400]);
var $z31423143 = D;
var $f31483149 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2313150,anf_arg2333151,anf_arg2343152):R.ffi.throwNonFunApp(L[399],mkbranch26920.$var,[anf_arg2313150,anf_arg2333151,anf_arg2343152]);
};
try {
if(--R.GAS > 0) {
$z31423143 = $f31483149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31483149,
"from":L[399]});
}
} catch($e31403141) {
if(R.isCont($e31403141)) {
var $ss31443145 = {"from":L[399],
"go":function(anf_arg2351508) {
return $Hanf_arg7821507(anf_arg2351508,anf_arg2281509,anf_arg2301510,mkbranch26920);
}};
$e31403141.stack[R.EXN_STACKHEIGHT++] = $ss31443145;
}
if(R.isPyretException($e31403141)) {
$e31403141.pyretStack.push(L[399]);
}
throw $e31403141;
}
var $ret31463147 = $Hanf_arg7821507($z31423143,anf_arg2281509,anf_arg2301510,mkbranch26920);
++R.GAS;
return $ret31463147;
});
left_DASH_left831151.$var = anf_assign2363072;
var anf_assign2473073 = R.makeFunction(function(t881492) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[150],1,arguments);
}
var anf_bracket2383138 = G(t881492,"right",L[398]);
var anf_arg2391491 = G(anf_bracket2383138,"value",L[397]);
var anf_arg2403134 = G(t881492,"value",L[396]);
var anf_arg2413135 = G(t881492,"left",L[395]);
var anf_bracket2423137 = G(t881492,"right",L[394]);
var anf_arg2433136 = G(anf_bracket2423137,"left",L[393]);
var $z31263127 = D;
var $f31323133 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2403134,anf_arg2413135,anf_arg2433136):R.ffi.throwNonFunApp(L[392],mkbranch26920.$var,[anf_arg2403134,anf_arg2413135,anf_arg2433136]);
};
try {
if(--R.GAS > 0) {
$z31263127 = $f31323133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31323133,
"from":L[392]});
}
} catch($e31243125) {
if(R.isCont($e31243125)) {
var $ss31283129 = {"from":L[392],
"go":function(anf_arg2441490) {
return $Hanf_arg7841489(anf_arg2441490,anf_arg2391491,mkbranch26920,t881492);
}};
$e31243125.stack[R.EXN_STACKHEIGHT++] = $ss31283129;
}
if(R.isPyretException($e31243125)) {
$e31243125.pyretStack.push(L[392]);
}
throw $e31243125;
}
var $ret31303131 = $Hanf_arg7841489($z31263127,anf_arg2391491,mkbranch26920,t881492);
++R.GAS;
return $ret31303131;
});
right_DASH_right841154.$var = anf_assign2473073;
var anf_assign2663074 = R.makeFunction(function(t891459) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[149],1,arguments);
}
var anf_bracket2493123 = G(t891459,"left",L[391]);
var anf_bracket2503122 = G(anf_bracket2493123,"right",L[390]);
var anf_arg2511458 = G(anf_bracket2503122,"value",L[389]);
var anf_bracket2523121 = G(t891459,"left",L[388]);
var anf_arg2533115 = G(anf_bracket2523121,"value",L[387]);
var anf_bracket2543120 = G(t891459,"left",L[386]);
var anf_arg2553116 = G(anf_bracket2543120,"left",L[385]);
var anf_bracket2563119 = G(t891459,"left",L[384]);
var anf_bracket2573118 = G(anf_bracket2563119,"right",L[383]);
var anf_arg2583117 = G(anf_bracket2573118,"left",L[382]);
var $z31073108 = D;
var $f31133114 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2533115,anf_arg2553116,anf_arg2583117):R.ffi.throwNonFunApp(L[381],mkbranch26920.$var,[anf_arg2533115,anf_arg2553116,anf_arg2583117]);
};
try {
if(--R.GAS > 0) {
$z31073108 = $f31133114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31133114,
"from":L[381]});
}
} catch($e31053106) {
if(R.isCont($e31053106)) {
var $ss31093110 = {"from":L[381],
"go":function(anf_arg2591457) {
return $Hanf_arg7871456(anf_arg2591457,anf_arg2511458,mkbranch26920,t891459);
}};
$e31053106.stack[R.EXN_STACKHEIGHT++] = $ss31093110;
}
if(R.isPyretException($e31053106)) {
$e31053106.pyretStack.push(L[381]);
}
throw $e31053106;
}
var $ret31113112 = $Hanf_arg7871456($z31073108,anf_arg2511458,mkbranch26920,t891459);
++R.GAS;
return $ret31113112;
});
left_DASH_right851152.$var = anf_assign2663074;
var anf_assign2853075 = R.makeFunction(function(t901424) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[142],1,arguments);
}
var anf_bracket2683104 = G(t901424,"right",L[380]);
var anf_bracket2693103 = G(anf_bracket2683104,"left",L[379]);
var anf_arg2701423 = G(anf_bracket2693103,"value",L[378]);
var anf_arg2713098 = G(t901424,"value",L[377]);
var anf_arg2723099 = G(t901424,"left",L[376]);
var anf_bracket2733102 = G(t901424,"right",L[375]);
var anf_bracket2743101 = G(anf_bracket2733102,"left",L[374]);
var anf_arg2753100 = G(anf_bracket2743101,"left",L[373]);
var $z30903091 = D;
var $f30963097 = function(_) {
return R.isFunction(mkbranch26920.$var)?mkbranch26920.$var.app(anf_arg2713098,anf_arg2723099,anf_arg2753100):R.ffi.throwNonFunApp(L[372],mkbranch26920.$var,[anf_arg2713098,anf_arg2723099,anf_arg2753100]);
};
try {
if(--R.GAS > 0) {
$z30903091 = $f30963097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30963097,
"from":L[372]});
}
} catch($e30883089) {
if(R.isCont($e30883089)) {
var $ss30923093 = {"from":L[372],
"go":function(anf_arg2761422) {
return $Hanf_arg7901421(anf_arg2761422,anf_arg2701423,mkbranch26920,t901424);
}};
$e30883089.stack[R.EXN_STACKHEIGHT++] = $ss30923093;
}
if(R.isPyretException($e30883089)) {
$e30883089.pyretStack.push(L[372]);
}
throw $e30883089;
}
var $ret30943095 = $Hanf_arg7901421($z30903091,anf_arg2701423,mkbranch26920,t901424);
++R.GAS;
return $ret30943095;
});
right_DASH_left861153.$var = anf_assign2853075;
var anf_bracket2863087 = G(tree821155,"left",L[371]);
var anf_fun2873086 = G(anf_bracket2863087,"height",L[370]);
var $z30783079 = D;
var $f30843085 = function(_) {
return R.isFunction(anf_fun2873086)?anf_fun2873086.app():R.ffi.throwNonFunApp(L[369],anf_fun2873086,[]);
};
try {
if(--R.GAS > 0) {
$z30783079 = $f30843085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30843085,
"from":L[369]});
}
} catch($e30763077) {
if(R.isCont($e30763077)) {
var $ss30803081 = {"from":L[369],
"go":function(lh911150) {
return $Hlh8091149(lh911150,left_DASH_left831151,left_DASH_right851152,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14);
}};
$e30763077.stack[R.EXN_STACKHEIGHT++] = $ss30803081;
}
if(R.isPyretException($e30763077)) {
$e30763077.pyretStack.push(L[369]);
}
throw $e30763077;
}
var $ret30823083 = $Hlh8091149($z30783079,left_DASH_left831151,left_DASH_right851152,right_DASH_left861153,right_DASH_right841154,tree821155,_greaterequal5,_lessequal6,_minus8,num_DASH_abs12,raise14);
++R.GAS;
return $ret30823083;
});
});
rebalance27921.$var = anf_assign3382239;
var anf_assign3612241 = R.makeFunction(function(tree931075) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[365],1,arguments);
}
return R.checkAnnArgs([AVLTree936],[tree931075],[L[367]],function() {
var anf_arg3403071 = G(tree931075,"left",L[366]);
var $z30633064 = D;
var $f30693070 = function(_) {
return R.isFunction(is_DASH_leaf211073.$var)?is_DASH_leaf211073.$var.app(anf_arg3403071):R.ffi.throwNonFunApp(L[94],is_DASH_leaf211073.$var,[anf_arg3403071]);
};
try {
if(--R.GAS > 0) {
$z30633064 = $f30693070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30693070,
"from":L[94]});
}
} catch($e30613062) {
if(R.isCont($e30613062)) {
var $ss30653066 = {"from":L[94],
"go":function(if_DASH_271072) {
return $Hif_DASH_8141071(if_DASH_271072,is_DASH_leaf211073,leaf2241,swap_DASH_next_DASH_lowest291074,tree931075);
}};
$e30613062.stack[R.EXN_STACKHEIGHT++] = $ss30653066;
}
if(R.isPyretException($e30613062)) {
$e30613062.pyretStack.push(L[94]);
}
throw $e30613062;
}
var $ret30673068 = $Hif_DASH_8141071($z30633064,is_DASH_leaf211073,leaf2241,swap_DASH_next_DASH_lowest291074,tree931075);
++R.GAS;
return $ret30673068;
});
});
remove_DASH_root282240.$var = anf_assign3612241;
var anf_assign4082242 = R.makeFunction(function(tree94923) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[81],1,arguments);
}
return R.checkAnnArgs([AVLTree936],[tree94923],[L[364]],function() {
var greatest951033 = {"$var":D,
"$name":"greatest"};
var remove_DASH_greatest_DASH_and_DASH_rebalance96922 = {"$var":D,
"$name":"remove-greatest-and-rebalance"};
var anf_assign3802969 = R.makeFunction(function(t971035) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[360],1,arguments);
}
var cases_DASH_val303060 = t971035;
var anf_fun3643031 = G(cases_DASH_val303060,"_match",L[361]);
var anf_obj3663035 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[363],0,arguments);
}
var $z30523053 = D;
var $f30583059 = function(_) {
return R.isFunction(raise14)?raise14.app(("Went too far in traversal step")):R.ffi.throwNonFunApp(L[363],raise14,[("Went too far in traversal step")]);
};
try {
if(--R.GAS > 0) {
$z30523053 = $f30583059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30583059,
"from":L[363]});
}
} catch($e30503051) {
if(R.isCont($e30503051)) {
var $ss30543055 = {"from":L[363],
"go":function(ann_DASH_check_DASH_temp3651070) {
return $Hann_DASH_check_DASH_temp8151069(ann_DASH_check_DASH_temp3651070);
}};
$e30503051.stack[R.EXN_STACKHEIGHT++] = $ss30543055;
}
if(R.isPyretException($e30503051)) {
$e30503051.pyretStack.push(L[363]);
}
throw $e30503051;
}
var $ret30563057 = $Hann_DASH_check_DASH_temp8151069($z30523053);
++R.GAS;
return $ret30563057;
});
var anf_obj3763036 = R.makeFunction(function($underscore983037,$underscore993038,$underscore1003039,right1011034) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[362],4,arguments);
}
var $z30423043 = D;
var $f30483049 = function(_) {
return R.isFunction(is_DASH_leaf211073.$var)?is_DASH_leaf211073.$var.app(right1011034):R.ffi.throwNonFunApp(L[89],is_DASH_leaf211073.$var,[right1011034]);
};
try {
if(--R.GAS > 0) {
$z30423043 = $f30483049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30483049,
"from":L[89]});
}
} catch($e30403041) {
if(R.isCont($e30403041)) {
var $ss30443045 = {"from":L[89],
"go":function(if_DASH_291032) {
return $Hif_DASH_8181031(if_DASH_291032,greatest951033,right1011034,t971035);
}};
$e30403041.stack[R.EXN_STACKHEIGHT++] = $ss30443045;
}
if(R.isPyretException($e30403041)) {
$e30403041.pyretStack.push(L[89]);
}
throw $e30403041;
}
var $ret30463047 = $Hif_DASH_8181031($z30423043,greatest951033,right1011034,t971035);
++R.GAS;
return $ret30463047;
});
var anf_arg3773032 = R.makeObject({"leaf":anf_obj3663035,
"branch":anf_obj3763036});
var anf_arg3793033 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[361],0,arguments);
}
var ann_DASH_check_DASH_temp3783034 = R.throwNoBranchesMatched(L[361],("cases"));
return ann_DASH_check_DASH_temp3783034;
});
var $z30233024 = D;
var $f30293030 = function(_) {
return R.isFunction(anf_fun3643031)?anf_fun3643031.app(anf_arg3773032,anf_arg3793033):R.ffi.throwNonFunApp(L[360],anf_fun3643031,[anf_arg3773032,anf_arg3793033]);
};
try {
if(--R.GAS > 0) {
$z30233024 = $f30293030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30293030,
"from":L[360]});
}
} catch($e30213022) {
if(R.isCont($e30213022)) {
var $ss30253026 = {"from":L[360],
"go":function(ann_DASH_check_DASH_temp3631030) {
return $Hann_DASH_check_DASH_temp8191029(ann_DASH_check_DASH_temp3631030);
}};
$e30213022.stack[R.EXN_STACKHEIGHT++] = $ss30253026;
}
if(R.isPyretException($e30213022)) {
$e30213022.pyretStack.push(L[360]);
}
throw $e30213022;
}
var $ret30273028 = $Hann_DASH_check_DASH_temp8191029($z30233024);
++R.GAS;
return $ret30273028;
});
greatest951033.$var = anf_assign3802969;
var anf_assign4002970 = R.makeFunction(function(t1022982) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[356],1,arguments);
}
var cases_DASH_val323020 = t1022982;
var anf_fun3822993 = G(cases_DASH_val323020,"_match",L[357]);
var anf_obj3842997 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[359],0,arguments);
}
var $z30123013 = D;
var $f30183019 = function(_) {
return R.isFunction(raise14)?raise14.app(("Went too far in removal step")):R.ffi.throwNonFunApp(L[359],raise14,[("Went too far in removal step")]);
};
try {
if(--R.GAS > 0) {
$z30123013 = $f30183019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30183019,
"from":L[359]});
}
} catch($e30103011) {
if(R.isCont($e30103011)) {
var $ss30143015 = {"from":L[359],
"go":function(ann_DASH_check_DASH_temp3831028) {
return $Hann_DASH_check_DASH_temp8201027(ann_DASH_check_DASH_temp3831028);
}};
$e30103011.stack[R.EXN_STACKHEIGHT++] = $ss30143015;
}
if(R.isPyretException($e30103011)) {
$e30103011.pyretStack.push(L[359]);
}
throw $e30103011;
}
var $ret30163017 = $Hann_DASH_check_DASH_temp8201027($z30123013);
++R.GAS;
return $ret30163017;
});
var anf_obj3962998 = R.makeFunction(function(val103969,$underscore1042999,left105967,right106968) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[358],4,arguments);
}
var $z30023003 = D;
var $f30083009 = function(_) {
return R.isFunction(is_DASH_leaf211073.$var)?is_DASH_leaf211073.$var.app(right106968):R.ffi.throwNonFunApp(L[84],is_DASH_leaf211073.$var,[right106968]);
};
try {
if(--R.GAS > 0) {
$z30023003 = $f30083009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30083009,
"from":L[84]});
}
} catch($e30003001) {
if(R.isCont($e30003001)) {
var $ss30043005 = {"from":L[84],
"go":function(if_DASH_31966) {
return $Hif_DASH_825965(if_DASH_31966,left105967,mkbranch26920,rebalance27921,remove_DASH_greatest_DASH_and_DASH_rebalance96922,right106968,val103969);
}};
$e30003001.stack[R.EXN_STACKHEIGHT++] = $ss30043005;
}
if(R.isPyretException($e30003001)) {
$e30003001.pyretStack.push(L[84]);
}
throw $e30003001;
}
var $ret30063007 = $Hif_DASH_825965($z30023003,left105967,mkbranch26920,rebalance27921,remove_DASH_greatest_DASH_and_DASH_rebalance96922,right106968,val103969);
++R.GAS;
return $ret30063007;
});
var anf_arg3972994 = R.makeObject({"leaf":anf_obj3842997,
"branch":anf_obj3962998});
var anf_arg3992995 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[357],0,arguments);
}
var ann_DASH_check_DASH_temp3982996 = R.throwNoBranchesMatched(L[357],("cases"));
return ann_DASH_check_DASH_temp3982996;
});
var $z29852986 = D;
var $f29912992 = function(_) {
return R.isFunction(anf_fun3822993)?anf_fun3822993.app(anf_arg3972994,anf_arg3992995):R.ffi.throwNonFunApp(L[356],anf_fun3822993,[anf_arg3972994,anf_arg3992995]);
};
try {
if(--R.GAS > 0) {
$z29852986 = $f29912992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29912992,
"from":L[356]});
}
} catch($e29832984) {
if(R.isCont($e29832984)) {
var $ss29872988 = {"from":L[356],
"go":function(ann_DASH_check_DASH_temp381964) {
return $Hann_DASH_check_DASH_temp826963(ann_DASH_check_DASH_temp381964);
}};
$e29832984.stack[R.EXN_STACKHEIGHT++] = $ss29872988;
}
if(R.isPyretException($e29832984)) {
$e29832984.pyretStack.push(L[356]);
}
throw $e29832984;
}
var $ret29892990 = $Hann_DASH_check_DASH_temp826963($z29852986);
++R.GAS;
return $ret29892990;
});
remove_DASH_greatest_DASH_and_DASH_rebalance96922.$var = anf_assign4002970;
var anf_arg4012981 = G(tree94923,"left",L[355]);
var $z29732974 = D;
var $f29792980 = function(_) {
return R.isFunction(greatest951033.$var)?greatest951033.$var.app(anf_arg4012981):R.ffi.throwNonFunApp(L[354],greatest951033.$var,[anf_arg4012981]);
};
try {
if(--R.GAS > 0) {
$z29732974 = $f29792980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29792980,
"from":L[354]});
}
} catch($e29712972) {
if(R.isCont($e29712972)) {
var $ss29752976 = {"from":L[354],
"go":function(anf_bracket402919) {
return $Hanf_bracket830918(anf_bracket402919,mkbranch26920,rebalance27921,remove_DASH_greatest_DASH_and_DASH_rebalance96922,tree94923);
}};
$e29712972.stack[R.EXN_STACKHEIGHT++] = $ss29752976;
}
if(R.isPyretException($e29712972)) {
$e29712972.pyretStack.push(L[354]);
}
throw $e29712972;
}
var $ret29772978 = $Hanf_bracket830918($z29732974,mkbranch26920,rebalance27921,remove_DASH_greatest_DASH_and_DASH_rebalance96922,tree94923);
++R.GAS;
return $ret29772978;
});
});
swap_DASH_next_DASH_lowest291074.$var = anf_assign4082242;
var anf_shared4152397 = R.makeMethod(function(self163891) {
return function(other164890) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[75],1,arguments);
}
return R.checkAnnArgs([Set1137,Set1137],[self163891,other164890],[L[352],L[353]],function() {
var anf_fun4102968 = G(self163891,"union",L[351]);
var $z29602961 = D;
var $f29662967 = function(_) {
return R.isFunction(anf_fun4102968)?anf_fun4102968.app(other164890):R.ffi.throwNonFunApp(L[350],anf_fun4102968,[other164890]);
};
try {
if(--R.GAS > 0) {
$z29602961 = $f29662967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29662967,
"from":L[350]});
}
} catch($e29582959) {
if(R.isCont($e29582959)) {
var $ss29622963 = {"from":L[350],
"go":function(anf_bracket411889) {
return $Hanf_bracket833888(anf_bracket411889,Set1137,other164890,self163891);
}};
$e29582959.stack[R.EXN_STACKHEIGHT++] = $ss29622963;
}
if(R.isPyretException($e29582959)) {
$e29582959.pyretStack.push(L[350]);
}
throw $e29582959;
}
var $ret29642965 = $Hanf_bracket833888($z29602961,Set1137,other164890,self163891);
++R.GAS;
return $ret29642965;
});
};
},{"length":2});
var anf_shared4352398 = R.makeMethod(function(self165799) {
return function(other166798) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[349],1,arguments);
}
var $z29502951 = D;
var $f29562957 = function(_) {
return R.isFunction(Set312245.$var === D?U(L[348],"Set"):Set312245.$var)?Set312245.$var === D?U(L[348],"Set"):Set312245.$var.app(other166798):R.ffi.throwNonFunApp(L[63],Set312245.$var === D?U(L[348],"Set"):Set312245.$var,[other166798]);
};
try {
if(--R.GAS > 0) {
$z29502951 = $f29562957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29562957,
"from":L[63]});
}
} catch($e29482949) {
if(R.isCont($e29482949)) {
var $ss29522953 = {"from":L[63],
"go":function(and_DASH_oper_DASH_54797) {
return $Hand_DASH_oper_DASH_840796(and_DASH_oper_DASH_54797,other166798,self165799);
}};
$e29482949.stack[R.EXN_STACKHEIGHT++] = $ss29522953;
}
if(R.isPyretException($e29482949)) {
$e29482949.pyretStack.push(L[63]);
}
throw $e29482949;
}
var $ret29542955 = $Hand_DASH_oper_DASH_840796($z29502951,other166798,self165799);
++R.GAS;
return $ret29542955;
};
},{"length":2});
var anf_variant_member4472404 = R.makeMethod(function(self342928) {
return function(cases_DASH_funs352929,else_DASH_clause362940) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[60],2,arguments);
}
var if_DASH_382941 = R.hasField(cases_DASH_funs352929,("list-set"));
var if_helper437789 = R.makeFunction(function(if_helper_arg4382946) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[60],1,arguments);
}
var ann_DASH_check_DASH_temp4362947 = if_helper_arg4382946;
return ann_DASH_check_DASH_temp4362947;
});
var anf_if4412945 = R.isBoolean(if_DASH_382941);
if(R.isPyretTrue(anf_if4412945)) {
if(R.isPyretTrue(if_DASH_382941)) {
var call_DASH_list_DASH_set332926 = G(cases_DASH_funs352929,"list-set",L[60]);
var anf_arg4442927 = G(self342928,"elems",L[347]);
var $z29182919 = D;
var $f29242925 = function(_) {
return R.isFunction(call_DASH_list_DASH_set332926)?call_DASH_list_DASH_set332926.app(anf_arg4442927):R.ffi.throwNonFunApp(L[60],call_DASH_list_DASH_set332926,[anf_arg4442927]);
};
try {
if(--R.GAS > 0) {
$z29182919 = $f29242925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29242925,
"from":L[60]});
}
} catch($e29162917) {
if(R.isCont($e29162917)) {
var $ss29202921 = {"from":L[60],
"go":function(cont_tail_arg445788) {
return $Hcont_tail_arg841787(cont_tail_arg445788,if_helper437789);
}};
$e29162917.stack[R.EXN_STACKHEIGHT++] = $ss29202921;
}
if(R.isPyretException($e29162917)) {
$e29162917.pyretStack.push(L[60]);
}
throw $e29162917;
}
var $ret29222923 = $Hcont_tail_arg841787($z29182919,if_helper437789);
++R.GAS;
return $ret29222923;
} else {
var $z29322933 = D;
var $f29382939 = function(_) {
return R.isFunction(else_DASH_clause362940)?else_DASH_clause362940.app():R.ffi.throwNonFunApp(L[60],else_DASH_clause362940,[]);
};
try {
if(--R.GAS > 0) {
$z29322933 = $f29382939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29382939,
"from":L[60]});
}
} catch($e29302931) {
if(R.isCont($e29302931)) {
var $ss29342935 = {"from":L[60],
"go":function(cont_tail_arg442793) {
return $Hcont_tail_arg842792(cont_tail_arg442793,if_helper437789);
}};
$e29302931.stack[R.EXN_STACKHEIGHT++] = $ss29342935;
}
if(R.isPyretException($e29302931)) {
$e29302931.pyretStack.push(L[60]);
}
throw $e29302931;
}
var $ret29362937 = $Hcont_tail_arg842792($z29322933,if_helper437789);
++R.GAS;
return $ret29362937;
}
} else {
var cont_tail_arg4392944 = R.throwNonBooleanCondition(L[60],("if"),if_DASH_382941);
if(--R.GAS > 0) {
$z29422943 = R.isFunction(if_helper437789)?if_helper437789.app(cont_tail_arg4392944):R.ffi.throwNonFunApp(L[60],if_helper437789,[cont_tail_arg4392944]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper437789)?if_helper437789.app(cont_tail_arg4392944):R.ffi.throwNonFunApp(L[60],if_helper437789,[cont_tail_arg4392944]);
},
"from":L[60]});
}
++R.GAS;
return $z29422943;
}
};
},{"length":3});
var anf_variant_member4532405 = R.makeMethod(function(self372915) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[60],0,arguments);
}
var anf_arg4492914 = G(self372915,"elems",L[60]);
var $z29062907 = D;
var $f29122913 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg4492914):R.ffi.throwNonFunApp(L[60],torepr16,[anf_arg4492914]);
};
try {
if(--R.GAS > 0) {
$z29062907 = $f29122913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29122913,
"from":L[60]});
}
} catch($e29042905) {
if(R.isCont($e29042905)) {
var $ss29082909 = {"from":L[60],
"go":function(anf_arg450750) {
return $Hanf_arg846749(anf_arg450750,_plus9);
}};
$e29042905.stack[R.EXN_STACKHEIGHT++] = $ss29082909;
}
if(R.isPyretException($e29042905)) {
$e29042905.pyretStack.push(L[60]);
}
throw $e29042905;
}
var $ret29102911 = $Hanf_arg846749($z29062907,_plus9);
++R.GAS;
return $ret29102911;
};
},{"length":1});
var anf_variant_member4722406 = R.makeMethod(function(self1082903) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[57],0,arguments);
}
var anf_bracket4552902 = G(self1082903,"elems",L[346]);
var anf_fun4562872 = G(anf_bracket4552902,"foldl",L[345]);
var anf_arg4692873 = R.makeFunction(function(elem1092874,acc110722) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[342],2,arguments);
}
var if_DASH_392895 = R.equiv(acc110722,(""));
var if_helper458717 = R.makeFunction(function(if_helper_arg4592900) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[344],1,arguments);
}
var ann_DASH_check_DASH_temp4572901 = if_helper_arg4592900;
return ann_DASH_check_DASH_temp4572901;
});
var anf_if4622899 = R.isBoolean(if_DASH_392895);
if(R.isPyretTrue(anf_if4622899)) {
if(R.isPyretTrue(if_DASH_392895)) {
var $z28772878 = D;
var $f28832884 = function(_) {
return R.isFunction(tostring17)?tostring17.app(elem1092874):R.ffi.throwNonFunApp(L[58],tostring17,[elem1092874]);
};
try {
if(--R.GAS > 0) {
$z28772878 = $f28832884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28832884,
"from":L[58]});
}
} catch($e28752876) {
if(R.isCont($e28752876)) {
var $ss28792880 = {"from":L[58],
"go":function(cont_tail_arg467716) {
return $Hcont_tail_arg847715(cont_tail_arg467716,if_helper458717);
}};
$e28752876.stack[R.EXN_STACKHEIGHT++] = $ss28792880;
}
if(R.isPyretException($e28752876)) {
$e28752876.pyretStack.push(L[58]);
}
throw $e28752876;
}
var $ret28812882 = $Hcont_tail_arg847715($z28772878,if_helper458717);
++R.GAS;
return $ret28812882;
} else {
var $z28872888 = D;
var $f28932894 = function(_) {
return R.isFunction(tostring17)?tostring17.app(elem1092874):R.ffi.throwNonFunApp(L[343],tostring17,[elem1092874]);
};
try {
if(--R.GAS > 0) {
$z28872888 = $f28932894();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28932894,
"from":L[343]});
}
} catch($e28852886) {
if(R.isCont($e28852886)) {
var $ss28892890 = {"from":L[343],
"go":function(anf_arg463721) {
return $Hanf_arg850720(anf_arg463721,acc110722,if_helper458717,_plus9);
}};
$e28852886.stack[R.EXN_STACKHEIGHT++] = $ss28892890;
}
if(R.isPyretException($e28852886)) {
$e28852886.pyretStack.push(L[343]);
}
throw $e28852886;
}
var $ret28912892 = $Hanf_arg850720($z28872888,acc110722,if_helper458717,_plus9);
++R.GAS;
return $ret28912892;
}
} else {
var cont_tail_arg4602898 = R.throwNonBooleanCondition(L[344],("if"),if_DASH_392895);
if(--R.GAS > 0) {
$z28962897 = R.isFunction(if_helper458717)?if_helper458717.app(cont_tail_arg4602898):R.ffi.throwNonFunApp(L[344],if_helper458717,[cont_tail_arg4602898]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper458717)?if_helper458717.app(cont_tail_arg4602898):R.ffi.throwNonFunApp(L[344],if_helper458717,[cont_tail_arg4602898]);
},
"from":L[344]});
}
++R.GAS;
return $z28962897;
}
});
var $z28642865 = D;
var $f28702871 = function(_) {
return R.isFunction(anf_fun4562872)?anf_fun4562872.app(anf_arg4692873,("")):R.ffi.throwNonFunApp(L[341],anf_fun4562872,[anf_arg4692873,("")]);
};
try {
if(--R.GAS > 0) {
$z28642865 = $f28702871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28702871,
"from":L[341]});
}
} catch($e28622863) {
if(R.isCont($e28622863)) {
var $ss28662867 = {"from":L[341],
"go":function(anf_arg470690) {
return $Hanf_arg853689(anf_arg470690,_plus9);
}};
$e28622863.stack[R.EXN_STACKHEIGHT++] = $ss28662867;
}
if(R.isPyretException($e28622863)) {
$e28622863.pyretStack.push(L[341]);
}
throw $e28622863;
}
var $ret28682869 = $Hanf_arg853689($z28642865,_plus9);
++R.GAS;
return $ret28682869;
};
},{"length":1});
var anf_variant_member4912407 = R.makeMethod(function(self1112861) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[53],0,arguments);
}
var anf_bracket4742860 = G(self1112861,"elems",L[340]);
var anf_fun4752830 = G(anf_bracket4742860,"foldl",L[339]);
var anf_arg4882831 = R.makeFunction(function(elem1122832,acc113662) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[336],2,arguments);
}
var if_DASH_402853 = R.equiv(acc113662,(""));
var if_helper477657 = R.makeFunction(function(if_helper_arg4782858) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[338],1,arguments);
}
var ann_DASH_check_DASH_temp4762859 = if_helper_arg4782858;
return ann_DASH_check_DASH_temp4762859;
});
var anf_if4812857 = R.isBoolean(if_DASH_402853);
if(R.isPyretTrue(anf_if4812857)) {
if(R.isPyretTrue(if_DASH_402853)) {
var $z28352836 = D;
var $f28412842 = function(_) {
return R.isFunction(torepr16)?torepr16.app(elem1122832):R.ffi.throwNonFunApp(L[54],torepr16,[elem1122832]);
};
try {
if(--R.GAS > 0) {
$z28352836 = $f28412842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28412842,
"from":L[54]});
}
} catch($e28332834) {
if(R.isCont($e28332834)) {
var $ss28372838 = {"from":L[54],
"go":function(cont_tail_arg486656) {
return $Hcont_tail_arg854655(cont_tail_arg486656,if_helper477657);
}};
$e28332834.stack[R.EXN_STACKHEIGHT++] = $ss28372838;
}
if(R.isPyretException($e28332834)) {
$e28332834.pyretStack.push(L[54]);
}
throw $e28332834;
}
var $ret28392840 = $Hcont_tail_arg854655($z28352836,if_helper477657);
++R.GAS;
return $ret28392840;
} else {
var $z28452846 = D;
var $f28512852 = function(_) {
return R.isFunction(torepr16)?torepr16.app(elem1122832):R.ffi.throwNonFunApp(L[337],torepr16,[elem1122832]);
};
try {
if(--R.GAS > 0) {
$z28452846 = $f28512852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28512852,
"from":L[337]});
}
} catch($e28432844) {
if(R.isCont($e28432844)) {
var $ss28472848 = {"from":L[337],
"go":function(anf_arg482661) {
return $Hanf_arg857660(anf_arg482661,acc113662,if_helper477657,_plus9);
}};
$e28432844.stack[R.EXN_STACKHEIGHT++] = $ss28472848;
}
if(R.isPyretException($e28432844)) {
$e28432844.pyretStack.push(L[337]);
}
throw $e28432844;
}
var $ret28492850 = $Hanf_arg857660($z28452846,acc113662,if_helper477657,_plus9);
++R.GAS;
return $ret28492850;
}
} else {
var cont_tail_arg4792856 = R.throwNonBooleanCondition(L[338],("if"),if_DASH_402853);
if(--R.GAS > 0) {
$z28542855 = R.isFunction(if_helper477657)?if_helper477657.app(cont_tail_arg4792856):R.ffi.throwNonFunApp(L[338],if_helper477657,[cont_tail_arg4792856]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper477657)?if_helper477657.app(cont_tail_arg4792856):R.ffi.throwNonFunApp(L[338],if_helper477657,[cont_tail_arg4792856]);
},
"from":L[338]});
}
++R.GAS;
return $z28542855;
}
});
var $z28222823 = D;
var $f28282829 = function(_) {
return R.isFunction(anf_fun4752830)?anf_fun4752830.app(anf_arg4882831,("")):R.ffi.throwNonFunApp(L[335],anf_fun4752830,[anf_arg4882831,("")]);
};
try {
if(--R.GAS > 0) {
$z28222823 = $f28282829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28282829,
"from":L[335]});
}
} catch($e28202821) {
if(R.isCont($e28202821)) {
var $ss28242825 = {"from":L[335],
"go":function(anf_arg489630) {
return $Hanf_arg860629(anf_arg489630,_plus9);
}};
$e28202821.stack[R.EXN_STACKHEIGHT++] = $ss28242825;
}
if(R.isPyretException($e28202821)) {
$e28202821.pyretStack.push(L[335]);
}
throw $e28202821;
}
var $ret28262827 = $Hanf_arg860629($z28222823,_plus9);
++R.GAS;
return $ret28262827;
};
},{"length":1});
var anf_variant_member4952408 = R.makeMethod(function(self1142819) {
return function(elem1152817) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[332],1,arguments);
}
var anf_bracket4932818 = G(self1142819,"elems",L[334]);
var anf_fun4942816 = G(anf_bracket4932818,"member",L[333]);
var $z28082809 = D;
var $f28142815 = function(_) {
return R.isFunction(anf_fun4942816)?anf_fun4942816.app(elem1152817):R.ffi.throwNonFunApp(L[332],anf_fun4942816,[elem1152817]);
};
try {
if(--R.GAS > 0) {
$z28082809 = $f28142815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28142815,
"from":L[332]});
}
} catch($e28062807) {
if(R.isCont($e28062807)) {
var $ss28102811 = {"from":L[332],
"go":function(ann_DASH_check_DASH_temp492628) {
return $Hann_DASH_check_DASH_temp861627(ann_DASH_check_DASH_temp492628,$type$Boolean18);
}};
$e28062807.stack[R.EXN_STACKHEIGHT++] = $ss28102811;
}
if(R.isPyretException($e28062807)) {
$e28062807.pyretStack.push(L[332]);
}
throw $e28062807;
}
var $ret28122813 = $Hann_DASH_check_DASH_temp861627($z28082809,$type$Boolean18);
++R.GAS;
return $ret28122813;
};
},{"length":2});
var anf_variant_member5092409 = R.makeMethod(function(self116580) {
return function(elem117578) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[331],1,arguments);
}
var anf_bracket4972805 = G(self116580,"elems",L[330]);
var anf_fun4982804 = G(anf_bracket4972805,"member",L[329]);
var $z27962797 = D;
var $f28022803 = function(_) {
return R.isFunction(anf_fun4982804)?anf_fun4982804.app(elem117578):R.ffi.throwNonFunApp(L[48],anf_fun4982804,[elem117578]);
};
try {
if(--R.GAS > 0) {
$z27962797 = $f28022803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28022803,
"from":L[48]});
}
} catch($e27942795) {
if(R.isCont($e27942795)) {
var $ss27982799 = {"from":L[48],
"go":function(if_DASH_41577) {
return $Hif_DASH_865576(if_DASH_41577,Set1137,elem117578,link15579,list_DASH_set34563,self116580);
}};
$e27942795.stack[R.EXN_STACKHEIGHT++] = $ss27982799;
}
if(R.isPyretException($e27942795)) {
$e27942795.pyretStack.push(L[48]);
}
throw $e27942795;
}
var $ret28002801 = $Hif_DASH_865576($z27962797,Set1137,elem117578,link15579,list_DASH_set34563,self116580);
++R.GAS;
return $ret28002801;
};
},{"length":2});
var anf_variant_member5172410 = R.makeMethod(function(self1182793) {
return function(elem1192791) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[44],1,arguments);
}
var anf_bracket5112792 = G(self1182793,"elems",L[328]);
var anf_fun5122786 = G(anf_bracket5112792,"filter",L[327]);
var anf_arg5152787 = R.makeFunction(function(x1202788) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[326],1,arguments);
}
var anf_arg5142790 = R.equiv(x1202788,elem1192791);
var ann_DASH_check_DASH_temp5132789 = R.not(anf_arg5142790);
return ann_DASH_check_DASH_temp5132789;
});
var $z27782779 = D;
var $f27842785 = function(_) {
return R.isFunction(anf_fun5122786)?anf_fun5122786.app(anf_arg5152787):R.ffi.throwNonFunApp(L[325],anf_fun5122786,[anf_arg5152787]);
};
try {
if(--R.GAS > 0) {
$z27782779 = $f27842785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27842785,
"from":L[325]});
}
} catch($e27762777) {
if(R.isCont($e27762777)) {
var $ss27802781 = {"from":L[325],
"go":function(anf_arg516562) {
return $Hanf_arg867561(anf_arg516562,Set1137,list_DASH_set34563);
}};
$e27762777.stack[R.EXN_STACKHEIGHT++] = $ss27802781;
}
if(R.isPyretException($e27762777)) {
$e27762777.pyretStack.push(L[325]);
}
throw $e27762777;
}
var $ret27822783 = $Hanf_arg867561($z27782779,Set1137,list_DASH_set34563);
++R.GAS;
return $ret27822783;
};
},{"length":2});
var anf_variant_member5192411 = R.makeMethod(function(self1212775) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[324],0,arguments);
}
var ann_DASH_check_DASH_temp5182774 = G(self1212775,"elems",L[322]);
return R.checkAnn(L[323],R.getDotAnn(L[323],"lists",lists225,"List"),ann_DASH_check_DASH_temp5182774,function() {
return ann_DASH_check_DASH_temp5182774;
});
};
},{"length":1});
var anf_variant_member5252412 = R.makeMethod(function(self1222758) {
return function(other1232760) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[316],1,arguments);
}
return R.checkAnnArgs([Set1137,Set1137],[self1222758,other1232760],[L[320],L[321]],function() {
var anf_arg5232757 = R.makeFunction(function(u1242761,elem1252762) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[318],2,arguments);
}
var anf_fun5222773 = G(u1242761,"add",L[319]);
var $z27652766 = D;
var $f27712772 = function(_) {
return R.isFunction(anf_fun5222773)?anf_fun5222773.app(elem1252762):R.ffi.throwNonFunApp(L[318],anf_fun5222773,[elem1252762]);
};
try {
if(--R.GAS > 0) {
$z27652766 = $f27712772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27712772,
"from":L[318]});
}
} catch($e27632764) {
if(R.isCont($e27632764)) {
var $ss27672768 = {"from":L[318],
"go":function(ann_DASH_check_DASH_temp521560) {
return $Hann_DASH_check_DASH_temp868559(ann_DASH_check_DASH_temp521560);
}};
$e27632764.stack[R.EXN_STACKHEIGHT++] = $ss27672768;
}
if(R.isPyretException($e27632764)) {
$e27632764.pyretStack.push(L[318]);
}
throw $e27632764;
}
var $ret27692770 = $Hann_DASH_check_DASH_temp868559($z27652766);
++R.GAS;
return $ret27692770;
});
var anf_arg5242759 = G(other1232760,"elems",L[317]);
var $z27492750 = D;
var $f27552756 = function(_) {
return R.isFunction(fold172706)?fold172706.app(anf_arg5232757,self1222758,anf_arg5242759):R.ffi.throwNonFunApp(L[316],fold172706,[anf_arg5232757,self1222758,anf_arg5242759]);
};
try {
if(--R.GAS > 0) {
$z27492750 = $f27552756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27552756,
"from":L[316]});
}
} catch($e27472748) {
if(R.isCont($e27472748)) {
var $ss27512752 = {"from":L[316],
"go":function(ann_DASH_check_DASH_temp520558) {
return $Hann_DASH_check_DASH_temp869557(ann_DASH_check_DASH_temp520558,Set1137);
}};
$e27472748.stack[R.EXN_STACKHEIGHT++] = $ss27512752;
}
if(R.isPyretException($e27472748)) {
$e27472748.pyretStack.push(L[316]);
}
throw $e27472748;
}
var $ret27532754 = $Hann_DASH_check_DASH_temp869557($z27492750,Set1137);
++R.GAS;
return $ret27532754;
});
};
},{"length":2});
var anf_variant_member5402413 = R.makeMethod(function(self1262733) {
return function(other1272746) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[310],1,arguments);
}
return R.checkAnnArgs([Set1137,Set1137],[self1262733,other1272746],[L[314],L[315]],function() {
var anf_arg5382732 = R.makeFunction(function(u128522,elem129521) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[312],2,arguments);
}
var anf_fun5282745 = G(other1272746,"member",L[313]);
var $z27372738 = D;
var $f27432744 = function(_) {
return R.isFunction(anf_fun5282745)?anf_fun5282745.app(elem129521):R.ffi.throwNonFunApp(L[42],anf_fun5282745,[elem129521]);
};
try {
if(--R.GAS > 0) {
$z27372738 = $f27432744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27432744,
"from":L[42]});
}
} catch($e27352736) {
if(R.isCont($e27352736)) {
var $ss27392740 = {"from":L[42],
"go":function(if_DASH_42520) {
return $Hif_DASH_872519(if_DASH_42520,elem129521,u128522);
}};
$e27352736.stack[R.EXN_STACKHEIGHT++] = $ss27392740;
}
if(R.isPyretException($e27352736)) {
$e27352736.pyretStack.push(L[42]);
}
throw $e27352736;
}
var $ret27412742 = $Hif_DASH_872519($z27372738,elem129521,u128522);
++R.GAS;
return $ret27412742;
});
var anf_arg5392734 = G(self1262733,"elems",L[311]);
var $z27242725 = D;
var $f27302731 = function(_) {
return R.isFunction(fold172706)?fold172706.app(anf_arg5382732,self1262733,anf_arg5392734):R.ffi.throwNonFunApp(L[310],fold172706,[anf_arg5382732,self1262733,anf_arg5392734]);
};
try {
if(--R.GAS > 0) {
$z27242725 = $f27302731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27302731,
"from":L[310]});
}
} catch($e27222723) {
if(R.isCont($e27222723)) {
var $ss27262727 = {"from":L[310],
"go":function(ann_DASH_check_DASH_temp526518) {
return $Hann_DASH_check_DASH_temp873517(ann_DASH_check_DASH_temp526518,Set1137);
}};
$e27222723.stack[R.EXN_STACKHEIGHT++] = $ss27262727;
}
if(R.isPyretException($e27222723)) {
$e27222723.pyretStack.push(L[310]);
}
throw $e27222723;
}
var $ret27282729 = $Hann_DASH_check_DASH_temp873517($z27242725,Set1137);
++R.GAS;
return $ret27282729;
});
};
},{"length":2});
var anf_variant_member5552414 = R.makeMethod(function(self1302708) {
return function(other1312721) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[304],1,arguments);
}
return R.checkAnnArgs([Set1137,Set1137],[self1302708,other1312721],[L[308],L[309]],function() {
var anf_arg5532707 = R.makeFunction(function(u132482,elem133481) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[306],2,arguments);
}
var anf_fun5432720 = G(other1312721,"member",L[307]);
var $z27122713 = D;
var $f27182719 = function(_) {
return R.isFunction(anf_fun5432720)?anf_fun5432720.app(elem133481):R.ffi.throwNonFunApp(L[38],anf_fun5432720,[elem133481]);
};
try {
if(--R.GAS > 0) {
$z27122713 = $f27182719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27182719,
"from":L[38]});
}
} catch($e27102711) {
if(R.isCont($e27102711)) {
var $ss27142715 = {"from":L[38],
"go":function(if_DASH_43480) {
return $Hif_DASH_876479(if_DASH_43480,elem133481,u132482);
}};
$e27102711.stack[R.EXN_STACKHEIGHT++] = $ss27142715;
}
if(R.isPyretException($e27102711)) {
$e27102711.pyretStack.push(L[38]);
}
throw $e27102711;
}
var $ret27162717 = $Hif_DASH_876479($z27122713,elem133481,u132482);
++R.GAS;
return $ret27162717;
});
var anf_arg5542709 = G(self1302708,"elems",L[305]);
var $z26982699 = D;
var $f27042705 = function(_) {
return R.isFunction(fold172706)?fold172706.app(anf_arg5532707,self1302708,anf_arg5542709):R.ffi.throwNonFunApp(L[304],fold172706,[anf_arg5532707,self1302708,anf_arg5542709]);
};
try {
if(--R.GAS > 0) {
$z26982699 = $f27042705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27042705,
"from":L[304]});
}
} catch($e26962697) {
if(R.isCont($e26962697)) {
var $ss27002701 = {"from":L[304],
"go":function(ann_DASH_check_DASH_temp541478) {
return $Hann_DASH_check_DASH_temp877477(ann_DASH_check_DASH_temp541478,Set1137);
}};
$e26962697.stack[R.EXN_STACKHEIGHT++] = $ss27002701;
}
if(R.isPyretException($e26962697)) {
$e26962697.pyretStack.push(L[304]);
}
throw $e26962697;
}
var $ret27022703 = $Hann_DASH_check_DASH_temp877477($z26982699,Set1137);
++R.GAS;
return $ret27022703;
});
};
},{"length":2});
var anf_variant_member5672421 = R.makeMethod(function(self452676) {
return function(cases_DASH_funs462677,else_DASH_clause472688) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[34],2,arguments);
}
var if_DASH_492689 = R.hasField(cases_DASH_funs462677,("tree-set"));
var if_helper557470 = R.makeFunction(function(if_helper_arg5582694) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[34],1,arguments);
}
var ann_DASH_check_DASH_temp5562695 = if_helper_arg5582694;
return ann_DASH_check_DASH_temp5562695;
});
var anf_if5612693 = R.isBoolean(if_DASH_492689);
if(R.isPyretTrue(anf_if5612693)) {
if(R.isPyretTrue(if_DASH_492689)) {
var call_DASH_tree_DASH_set442674 = G(cases_DASH_funs462677,"tree-set",L[34]);
var anf_arg5642675 = G(self452676,"elems",L[303]);
var $z26662667 = D;
var $f26722673 = function(_) {
return R.isFunction(call_DASH_tree_DASH_set442674)?call_DASH_tree_DASH_set442674.app(anf_arg5642675):R.ffi.throwNonFunApp(L[34],call_DASH_tree_DASH_set442674,[anf_arg5642675]);
};
try {
if(--R.GAS > 0) {
$z26662667 = $f26722673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26722673,
"from":L[34]});
}
} catch($e26642665) {
if(R.isCont($e26642665)) {
var $ss26682669 = {"from":L[34],
"go":function(cont_tail_arg565469) {
return $Hcont_tail_arg878468(cont_tail_arg565469,if_helper557470);
}};
$e26642665.stack[R.EXN_STACKHEIGHT++] = $ss26682669;
}
if(R.isPyretException($e26642665)) {
$e26642665.pyretStack.push(L[34]);
}
throw $e26642665;
}
var $ret26702671 = $Hcont_tail_arg878468($z26662667,if_helper557470);
++R.GAS;
return $ret26702671;
} else {
var $z26802681 = D;
var $f26862687 = function(_) {
return R.isFunction(else_DASH_clause472688)?else_DASH_clause472688.app():R.ffi.throwNonFunApp(L[34],else_DASH_clause472688,[]);
};
try {
if(--R.GAS > 0) {
$z26802681 = $f26862687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26862687,
"from":L[34]});
}
} catch($e26782679) {
if(R.isCont($e26782679)) {
var $ss26822683 = {"from":L[34],
"go":function(cont_tail_arg562474) {
return $Hcont_tail_arg879473(cont_tail_arg562474,if_helper557470);
}};
$e26782679.stack[R.EXN_STACKHEIGHT++] = $ss26822683;
}
if(R.isPyretException($e26782679)) {
$e26782679.pyretStack.push(L[34]);
}
throw $e26782679;
}
var $ret26842685 = $Hcont_tail_arg879473($z26802681,if_helper557470);
++R.GAS;
return $ret26842685;
}
} else {
var cont_tail_arg5592692 = R.throwNonBooleanCondition(L[34],("if"),if_DASH_492689);
if(--R.GAS > 0) {
$z26902691 = R.isFunction(if_helper557470)?if_helper557470.app(cont_tail_arg5592692):R.ffi.throwNonFunApp(L[34],if_helper557470,[cont_tail_arg5592692]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper557470)?if_helper557470.app(cont_tail_arg5592692):R.ffi.throwNonFunApp(L[34],if_helper557470,[cont_tail_arg5592692]);
},
"from":L[34]});
}
++R.GAS;
return $z26902691;
}
};
},{"length":3});
var anf_variant_member5732422 = R.makeMethod(function(self482663) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[34],0,arguments);
}
var anf_arg5692662 = G(self482663,"elems",L[34]);
var $z26542655 = D;
var $f26602661 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg5692662):R.ffi.throwNonFunApp(L[34],torepr16,[anf_arg5692662]);
};
try {
if(--R.GAS > 0) {
$z26542655 = $f26602661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26602661,
"from":L[34]});
}
} catch($e26522653) {
if(R.isCont($e26522653)) {
var $ss26562657 = {"from":L[34],
"go":function(anf_arg570431) {
return $Hanf_arg883430(anf_arg570431,_plus9);
}};
$e26522653.stack[R.EXN_STACKHEIGHT++] = $ss26562657;
}
if(R.isPyretException($e26522653)) {
$e26522653.pyretStack.push(L[34]);
}
throw $e26522653;
}
var $ret26582659 = $Hanf_arg883430($z26542655,_plus9);
++R.GAS;
return $ret26582659;
};
},{"length":1});
var anf_variant_member5922423 = R.makeMethod(function(self1352651) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[30],0,arguments);
}
var anf_bracket5752650 = G(self1352651,"elems",L[302]);
var anf_fun5762620 = G(anf_bracket5752650,"fold",L[301]);
var anf_arg5892621 = R.makeFunction(function(acc1362622,elem137403) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[299],2,arguments);
}
var if_DASH_502643 = R.equiv(acc1362622,(""));
var if_helper578398 = R.makeFunction(function(if_helper_arg5792648) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[300],1,arguments);
}
var ann_DASH_check_DASH_temp5772649 = if_helper_arg5792648;
return ann_DASH_check_DASH_temp5772649;
});
var anf_if5822647 = R.isBoolean(if_DASH_502643);
if(R.isPyretTrue(anf_if5822647)) {
if(R.isPyretTrue(if_DASH_502643)) {
var $z26252626 = D;
var $f26312632 = function(_) {
return R.isFunction(tostring17)?tostring17.app(elem137403):R.ffi.throwNonFunApp(L[31],tostring17,[elem137403]);
};
try {
if(--R.GAS > 0) {
$z26252626 = $f26312632();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26312632,
"from":L[31]});
}
} catch($e26232624) {
if(R.isCont($e26232624)) {
var $ss26272628 = {"from":L[31],
"go":function(cont_tail_arg587397) {
return $Hcont_tail_arg884396(cont_tail_arg587397,if_helper578398);
}};
$e26232624.stack[R.EXN_STACKHEIGHT++] = $ss26272628;
}
if(R.isPyretException($e26232624)) {
$e26232624.pyretStack.push(L[31]);
}
throw $e26232624;
}
var $ret26292630 = $Hcont_tail_arg884396($z26252626,if_helper578398);
++R.GAS;
return $ret26292630;
} else {
var $z26352636 = D;
var $f26412642 = function(_) {
return R.isFunction(_plus9)?_plus9.app(acc1362622,(", ")):R.ffi.throwNonFunApp(L[33],_plus9,[acc1362622,(", ")]);
};
try {
if(--R.GAS > 0) {
$z26352636 = $f26412642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26412642,
"from":L[33]});
}
} catch($e26332634) {
if(R.isCont($e26332634)) {
var $ss26372638 = {"from":L[33],
"go":function(anf_arg583402) {
return $Hanf_arg887401(anf_arg583402,elem137403,if_helper578398,_plus9,tostring17);
}};
$e26332634.stack[R.EXN_STACKHEIGHT++] = $ss26372638;
}
if(R.isPyretException($e26332634)) {
$e26332634.pyretStack.push(L[33]);
}
throw $e26332634;
}
var $ret26392640 = $Hanf_arg887401($z26352636,elem137403,if_helper578398,_plus9,tostring17);
++R.GAS;
return $ret26392640;
}
} else {
var cont_tail_arg5802646 = R.throwNonBooleanCondition(L[300],("if"),if_DASH_502643);
if(--R.GAS > 0) {
$z26442645 = R.isFunction(if_helper578398)?if_helper578398.app(cont_tail_arg5802646):R.ffi.throwNonFunApp(L[300],if_helper578398,[cont_tail_arg5802646]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper578398)?if_helper578398.app(cont_tail_arg5802646):R.ffi.throwNonFunApp(L[300],if_helper578398,[cont_tail_arg5802646]);
},
"from":L[300]});
}
++R.GAS;
return $z26442645;
}
});
var $z26122613 = D;
var $f26182619 = function(_) {
return R.isFunction(anf_fun5762620)?anf_fun5762620.app(anf_arg5892621,("")):R.ffi.throwNonFunApp(L[298],anf_fun5762620,[anf_arg5892621,("")]);
};
try {
if(--R.GAS > 0) {
$z26122613 = $f26182619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26182619,
"from":L[298]});
}
} catch($e26102611) {
if(R.isCont($e26102611)) {
var $ss26142615 = {"from":L[298],
"go":function(anf_arg590371) {
return $Hanf_arg890370(anf_arg590371,_plus9);
}};
$e26102611.stack[R.EXN_STACKHEIGHT++] = $ss26142615;
}
if(R.isPyretException($e26102611)) {
$e26102611.pyretStack.push(L[298]);
}
throw $e26102611;
}
var $ret26162617 = $Hanf_arg890370($z26122613,_plus9);
++R.GAS;
return $ret26162617;
};
},{"length":1});
var anf_variant_member6112424 = R.makeMethod(function(self1382609) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[25],0,arguments);
}
var anf_bracket5942608 = G(self1382609,"elems",L[297]);
var anf_fun5952578 = G(anf_bracket5942608,"fold",L[296]);
var anf_arg6082579 = R.makeFunction(function(acc1392580,elem140343) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[294],2,arguments);
}
var if_DASH_512601 = R.equiv(acc1392580,(""));
var if_helper597338 = R.makeFunction(function(if_helper_arg5982606) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[295],1,arguments);
}
var ann_DASH_check_DASH_temp5962607 = if_helper_arg5982606;
return ann_DASH_check_DASH_temp5962607;
});
var anf_if6012605 = R.isBoolean(if_DASH_512601);
if(R.isPyretTrue(anf_if6012605)) {
if(R.isPyretTrue(if_DASH_512601)) {
var $z25832584 = D;
var $f25892590 = function(_) {
return R.isFunction(torepr16)?torepr16.app(elem140343):R.ffi.throwNonFunApp(L[26],torepr16,[elem140343]);
};
try {
if(--R.GAS > 0) {
$z25832584 = $f25892590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25892590,
"from":L[26]});
}
} catch($e25812582) {
if(R.isCont($e25812582)) {
var $ss25852586 = {"from":L[26],
"go":function(cont_tail_arg606337) {
return $Hcont_tail_arg891336(cont_tail_arg606337,if_helper597338);
}};
$e25812582.stack[R.EXN_STACKHEIGHT++] = $ss25852586;
}
if(R.isPyretException($e25812582)) {
$e25812582.pyretStack.push(L[26]);
}
throw $e25812582;
}
var $ret25872588 = $Hcont_tail_arg891336($z25832584,if_helper597338);
++R.GAS;
return $ret25872588;
} else {
var $z25932594 = D;
var $f25992600 = function(_) {
return R.isFunction(_plus9)?_plus9.app(acc1392580,(", ")):R.ffi.throwNonFunApp(L[28],_plus9,[acc1392580,(", ")]);
};
try {
if(--R.GAS > 0) {
$z25932594 = $f25992600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25992600,
"from":L[28]});
}
} catch($e25912592) {
if(R.isCont($e25912592)) {
var $ss25952596 = {"from":L[28],
"go":function(anf_arg602342) {
return $Hanf_arg894341(anf_arg602342,elem140343,if_helper597338,_plus9,torepr16);
}};
$e25912592.stack[R.EXN_STACKHEIGHT++] = $ss25952596;
}
if(R.isPyretException($e25912592)) {
$e25912592.pyretStack.push(L[28]);
}
throw $e25912592;
}
var $ret25972598 = $Hanf_arg894341($z25932594,elem140343,if_helper597338,_plus9,torepr16);
++R.GAS;
return $ret25972598;
}
} else {
var cont_tail_arg5992604 = R.throwNonBooleanCondition(L[295],("if"),if_DASH_512601);
if(--R.GAS > 0) {
$z26022603 = R.isFunction(if_helper597338)?if_helper597338.app(cont_tail_arg5992604):R.ffi.throwNonFunApp(L[295],if_helper597338,[cont_tail_arg5992604]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored204) {
return R.isFunction(if_helper597338)?if_helper597338.app(cont_tail_arg5992604):R.ffi.throwNonFunApp(L[295],if_helper597338,[cont_tail_arg5992604]);
},
"from":L[295]});
}
++R.GAS;
return $z26022603;
}
});
var $z25702571 = D;
var $f25762577 = function(_) {
return R.isFunction(anf_fun5952578)?anf_fun5952578.app(anf_arg6082579,("")):R.ffi.throwNonFunApp(L[293],anf_fun5952578,[anf_arg6082579,("")]);
};
try {
if(--R.GAS > 0) {
$z25702571 = $f25762577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25762577,
"from":L[293]});
}
} catch($e25682569) {
if(R.isCont($e25682569)) {
var $ss25722573 = {"from":L[293],
"go":function(anf_arg609311) {
return $Hanf_arg897310(anf_arg609311,_plus9);
}};
$e25682569.stack[R.EXN_STACKHEIGHT++] = $ss25722573;
}
if(R.isPyretException($e25682569)) {
$e25682569.pyretStack.push(L[293]);
}
throw $e25682569;
}
var $ret25742575 = $Hanf_arg897310($z25702571,_plus9);
++R.GAS;
return $ret25742575;
};
},{"length":1});
var anf_variant_member6152425 = R.makeMethod(function(self1412567) {
return function(elem1422565) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[290],1,arguments);
}
var anf_bracket6132566 = G(self1412567,"elems",L[292]);
var anf_fun6142564 = G(anf_bracket6132566,"contains",L[291]);
var $z25562557 = D;
var $f25622563 = function(_) {
return R.isFunction(anf_fun6142564)?anf_fun6142564.app(elem1422565):R.ffi.throwNonFunApp(L[290],anf_fun6142564,[elem1422565]);
};
try {
if(--R.GAS > 0) {
$z25562557 = $f25622563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25622563,
"from":L[290]});
}
} catch($e25542555) {
if(R.isCont($e25542555)) {
var $ss25582559 = {"from":L[290],
"go":function(ann_DASH_check_DASH_temp612309) {
return $Hann_DASH_check_DASH_temp898308(ann_DASH_check_DASH_temp612309,$type$Boolean18);
}};
$e25542555.stack[R.EXN_STACKHEIGHT++] = $ss25582559;
}
if(R.isPyretException($e25542555)) {
$e25542555.pyretStack.push(L[290]);
}
throw $e25542555;
}
var $ret25602561 = $Hann_DASH_check_DASH_temp898308($z25562557,$type$Boolean18);
++R.GAS;
return $ret25602561;
};
},{"length":2});
var anf_variant_member6202426 = R.makeMethod(function(self1432553) {
return function(elem1442551) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
var anf_bracket6172552 = G(self1432553,"elems",L[289]);
var anf_fun6182550 = G(anf_bracket6172552,"insert",L[288]);
var $z25422543 = D;
var $f25482549 = function(_) {
return R.isFunction(anf_fun6182550)?anf_fun6182550.app(elem1442551):R.ffi.throwNonFunApp(L[287],anf_fun6182550,[elem1442551]);
};
try {
if(--R.GAS > 0) {
$z25422543 = $f25482549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25482549,
"from":L[287]});
}
} catch($e25402541) {
if(R.isCont($e25402541)) {
var $ss25442545 = {"from":L[287],
"go":function(anf_arg619295) {
return $Hanf_arg900294(anf_arg619295,Set1137,tree_DASH_set3644);
}};
$e25402541.stack[R.EXN_STACKHEIGHT++] = $ss25442545;
}
if(R.isPyretException($e25402541)) {
$e25402541.pyretStack.push(L[287]);
}
throw $e25402541;
}
var $ret25462547 = $Hanf_arg900294($z25422543,Set1137,tree_DASH_set3644);
++R.GAS;
return $ret25462547;
};
},{"length":2});
var anf_variant_member6252427 = R.makeMethod(function(self1452539) {
return function(elem1462537) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[21],1,arguments);
}
var anf_bracket6222538 = G(self1452539,"elems",L[286]);
var anf_fun6232536 = G(anf_bracket6222538,"remove",L[285]);
var $z25282529 = D;
var $f25342535 = function(_) {
return R.isFunction(anf_fun6232536)?anf_fun6232536.app(elem1462537):R.ffi.throwNonFunApp(L[284],anf_fun6232536,[elem1462537]);
};
try {
if(--R.GAS > 0) {
$z25282529 = $f25342535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25342535,
"from":L[284]});
}
} catch($e25262527) {
if(R.isCont($e25262527)) {
var $ss25302531 = {"from":L[284],
"go":function(anf_arg624281) {
return $Hanf_arg902280(anf_arg624281,Set1137,tree_DASH_set3644);
}};
$e25262527.stack[R.EXN_STACKHEIGHT++] = $ss25302531;
}
if(R.isPyretException($e25262527)) {
$e25262527.pyretStack.push(L[284]);
}
throw $e25262527;
}
var $ret25322533 = $Hanf_arg902280($z25282529,Set1137,tree_DASH_set3644);
++R.GAS;
return $ret25322533;
};
},{"length":2});
var anf_variant_member6292428 = R.makeMethod(function(self1472525) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[281],0,arguments);
}
var anf_bracket6272524 = G(self1472525,"elems",L[283]);
var anf_fun6282523 = G(anf_bracket6272524,"inorder",L[282]);
var $z25152516 = D;
var $f25212522 = function(_) {
return R.isFunction(anf_fun6282523)?anf_fun6282523.app():R.ffi.throwNonFunApp(L[281],anf_fun6282523,[]);
};
try {
if(--R.GAS > 0) {
$z25152516 = $f25212522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25212522,
"from":L[281]});
}
} catch($e25132514) {
if(R.isCont($e25132514)) {
var $ss25172518 = {"from":L[281],
"go":function(ann_DASH_check_DASH_temp626279) {
return $Hann_DASH_check_DASH_temp903278(ann_DASH_check_DASH_temp626279,lists225);
}};
$e25132514.stack[R.EXN_STACKHEIGHT++] = $ss25172518;
}
if(R.isPyretException($e25132514)) {
$e25132514.pyretStack.push(L[281]);
}
throw $e25132514;
}
var $ret25192520 = $Hann_DASH_check_DASH_temp903278($z25152516,lists225);
++R.GAS;
return $ret25192520;
};
},{"length":1});
var anf_variant_member6362429 = R.makeMethod(function(self1482499) {
return function(other1492498) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[19],1,arguments);
}
var anf_arg6332495 = R.makeFunction(function(elems1512500,elem1522501) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[279],2,arguments);
}
var anf_fun6322512 = G(elems1512500,"insert",L[280]);
var $z25042505 = D;
var $f25102511 = function(_) {
return R.isFunction(anf_fun6322512)?anf_fun6322512.app(elem1522501):R.ffi.throwNonFunApp(L[279],anf_fun6322512,[elem1522501]);
};
try {
if(--R.GAS > 0) {
$z25042505 = $f25102511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25102511,
"from":L[279]});
}
} catch($e25022503) {
if(R.isCont($e25022503)) {
var $ss25062507 = {"from":L[279],
"go":function(ann_DASH_check_DASH_temp631277) {
return $Hann_DASH_check_DASH_temp904276(ann_DASH_check_DASH_temp631277);
}};
$e25022503.stack[R.EXN_STACKHEIGHT++] = $ss25062507;
}
if(R.isPyretException($e25022503)) {
$e25022503.pyretStack.push(L[279]);
}
throw $e25022503;
}
var $ret25082509 = $Hann_DASH_check_DASH_temp904276($z25042505);
++R.GAS;
return $ret25082509;
});
var anf_arg6342496 = G(self1482499,"elems",L[278]);
var anf_arg6352497 = G(other1492498,"elems",L[277]);
var $z24872488 = D;
var $f24932494 = function(_) {
return R.isFunction(tree_DASH_fold252236.$var)?tree_DASH_fold252236.$var.app(anf_arg6332495,anf_arg6342496,anf_arg6352497):R.ffi.throwNonFunApp(L[276],tree_DASH_fold252236.$var,[anf_arg6332495,anf_arg6342496,anf_arg6352497]);
};
try {
if(--R.GAS > 0) {
$z24872488 = $f24932494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24932494,
"from":L[276]});
}
} catch($e24852486) {
if(R.isCont($e24852486)) {
var $ss24892490 = {"from":L[276],
"go":function(new_DASH_elems150263) {
return $Hnew_DASH_elems906262(new_DASH_elems150263,tree_DASH_set3644);
}};
$e24852486.stack[R.EXN_STACKHEIGHT++] = $ss24892490;
}
if(R.isPyretException($e24852486)) {
$e24852486.pyretStack.push(L[276]);
}
throw $e24852486;
}
var $ret24912492 = $Hnew_DASH_elems906262($z24872488,tree_DASH_set3644);
++R.GAS;
return $ret24912492;
};
},{"length":2});
var anf_variant_member6522430 = R.makeMethod(function(self1532472) {
return function(other1542484) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[13],1,arguments);
}
var anf_arg6492469 = R.makeFunction(function(elems156227,elem157226) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[274],2,arguments);
}
var anf_fun6392483 = G(other1542484,"member",L[275]);
var $z24752476 = D;
var $f24812482 = function(_) {
return R.isFunction(anf_fun6392483)?anf_fun6392483.app(elem157226):R.ffi.throwNonFunApp(L[17],anf_fun6392483,[elem157226]);
};
try {
if(--R.GAS > 0) {
$z24752476 = $f24812482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24812482,
"from":L[17]});
}
} catch($e24732474) {
if(R.isCont($e24732474)) {
var $ss24772478 = {"from":L[17],
"go":function(if_DASH_52225) {
return $Hif_DASH_909224(if_DASH_52225,elem157226,elems156227);
}};
$e24732474.stack[R.EXN_STACKHEIGHT++] = $ss24772478;
}
if(R.isPyretException($e24732474)) {
$e24732474.pyretStack.push(L[17]);
}
throw $e24732474;
}
var $ret24792480 = $Hif_DASH_909224($z24752476,elem157226,elems156227);
++R.GAS;
return $ret24792480;
});
var anf_arg6502470 = G(self1532472,"elems",L[273]);
var anf_arg6512471 = G(self1532472,"elems",L[272]);
var $z24612462 = D;
var $f24672468 = function(_) {
return R.isFunction(tree_DASH_fold252236.$var)?tree_DASH_fold252236.$var.app(anf_arg6492469,anf_arg6502470,anf_arg6512471):R.ffi.throwNonFunApp(L[271],tree_DASH_fold252236.$var,[anf_arg6492469,anf_arg6502470,anf_arg6512471]);
};
try {
if(--R.GAS > 0) {
$z24612462 = $f24672468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24672468,
"from":L[271]});
}
} catch($e24592460) {
if(R.isCont($e24592460)) {
var $ss24632464 = {"from":L[271],
"go":function(new_DASH_elems155211) {
return $Hnew_DASH_elems911210(new_DASH_elems155211,tree_DASH_set3644);
}};
$e24592460.stack[R.EXN_STACKHEIGHT++] = $ss24632464;
}
if(R.isPyretException($e24592460)) {
$e24592460.pyretStack.push(L[271]);
}
throw $e24592460;
}
var $ret24652466 = $Hnew_DASH_elems911210($z24612462,tree_DASH_set3644);
++R.GAS;
return $ret24652466;
};
},{"length":2});
var anf_variant_member6682431 = R.makeMethod(function(self1582447) {
return function(other1592446) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
return R.checkAnnArgs([Set1137,Set1137],[self1582447,other1592446],[L[269],L[270]],function() {
var anf_arg6652443 = R.makeFunction(function(elems161174,elem162173) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[267],2,arguments);
}
var anf_fun6552458 = G(self1582447,"member",L[268]);
var $z24502451 = D;
var $f24562457 = function(_) {
return R.isFunction(anf_fun6552458)?anf_fun6552458.app(elem162173):R.ffi.throwNonFunApp(L[11],anf_fun6552458,[elem162173]);
};
try {
if(--R.GAS > 0) {
$z24502451 = $f24562457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24562457,
"from":L[11]});
}
} catch($e24482449) {
if(R.isCont($e24482449)) {
var $ss24522453 = {"from":L[11],
"go":function(if_DASH_53172) {
return $Hif_DASH_914171(if_DASH_53172,elem162173,elems161174);
}};
$e24482449.stack[R.EXN_STACKHEIGHT++] = $ss24522453;
}
if(R.isPyretException($e24482449)) {
$e24482449.pyretStack.push(L[11]);
}
throw $e24482449;
}
var $ret24542455 = $Hif_DASH_914171($z24502451,elem162173,elems161174);
++R.GAS;
return $ret24542455;
});
var anf_arg6662444 = G(self1582447,"elems",L[266]);
var anf_arg6672445 = G(other1592446,"elems",L[265]);
var $z24352436 = D;
var $f24412442 = function(_) {
return R.isFunction(tree_DASH_fold252236.$var)?tree_DASH_fold252236.$var.app(anf_arg6652443,anf_arg6662444,anf_arg6672445):R.ffi.throwNonFunApp(L[264],tree_DASH_fold252236.$var,[anf_arg6652443,anf_arg6662444,anf_arg6672445]);
};
try {
if(--R.GAS > 0) {
$z24352436 = $f24412442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24412442,
"from":L[264]});
}
} catch($e24332434) {
if(R.isCont($e24332434)) {
var $ss24372438 = {"from":L[264],
"go":function(new_DASH_elems160158) {
return $Hnew_DASH_elems916157(new_DASH_elems160158,Set1137,tree_DASH_set3644);
}};
$e24332434.stack[R.EXN_STACKHEIGHT++] = $ss24372438;
}
if(R.isPyretException($e24332434)) {
$e24332434.pyretStack.push(L[264]);
}
throw $e24332434;
}
var $ret24392440 = $Hnew_DASH_elems916157($z24352436,Set1137,tree_DASH_set3644);
++R.GAS;
return $ret24392440;
});
};
},{"length":2});
var anf_assign6692244 = (function() {
var $list_DASH_set_DASH_base23992400 = {"symmetric_difference":anf_shared4152397,
"_equals":anf_shared4352398,
"_match":anf_variant_member4472404,
"_torepr":anf_variant_member4532405,
"tostring":anf_variant_member4722406,
"_torepr":anf_variant_member4912407,
"member":anf_variant_member4952408,
"add":anf_variant_member5092409,
"remove":anf_variant_member5172410,
"to-list":anf_variant_member5192411,
"union":anf_variant_member5252412,
"intersect":anf_variant_member5402413,
"difference":anf_variant_member5552414};
var $list_DASH_set_DASH_brands24022403 = {"$brand-list-set2401":true};
$list_DASH_set_DASH_brands24022403[SetT2122224._brand] = true
var $tree_DASH_set_DASH_base24162417 = {"symmetric_difference":anf_shared4152397,
"_equals":anf_shared4352398,
"_match":anf_variant_member5672421,
"_torepr":anf_variant_member5732422,
"tostring":anf_variant_member5922423,
"_torepr":anf_variant_member6112424,
"member":anf_variant_member6152425,
"add":anf_variant_member6202426,
"remove":anf_variant_member6252427,
"to-list":anf_variant_member6292428,
"union":anf_variant_member6362429,
"intersect":anf_variant_member6522430,
"difference":anf_variant_member6682431};
var $tree_DASH_set_DASH_brands24192420 = {"$brand-tree-set2418":true};
$tree_DASH_set_DASH_brands24192420[SetT2122224._brand] = true
return R.makeObject({"Set":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[259],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,SetT2122224._brand));
}),
"is-list-set":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[60],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-list-set2401"));
}),
"list-set":R.makeFunction(function(elems1072415) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[260],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[261],"lists",lists225,"List")],[elems1072415],[L[261]],function() {
var dict = R.create($list_DASH_set_DASH_base23992400);
dict["elems"] = elems1072415
return R.makeBrandedObject(dict,$list_DASH_set_DASH_brands24022403);
});
}),
"is-tree-set":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[34],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-tree-set2418"));
}),
"tree-set":R.makeFunction(function(elems1342432) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[262],1,arguments);
}
return R.checkAnnArgs([AVLTree936],[elems1342432],[L[263]],function() {
var dict = R.create($tree_DASH_set_DASH_base24162417);
dict["elems"] = elems1342432
return R.makeBrandedObject(dict,$tree_DASH_set_DASH_brands24192420);
});
})});
})();
Set4302243.$var = anf_assign6692244;
var anf_assign6702246 = G(Set4302243.$var,"Set",L[259]);
Set312245.$var = anf_assign6702246;
var anf_assign6712248 = G(Set4302243.$var,"Set",L[259]);
is_DASH_Set322247.$var = anf_assign6712248;
var anf_assign6722250 = G(Set4302243.$var,"is-list-set",L[60]);
is_DASH_list_DASH_set332249.$var = anf_assign6722250;
var anf_assign6732251 = G(Set4302243.$var,"list-set",L[60]);
list_DASH_set34563.$var = anf_assign6732251;
var anf_assign6742253 = G(Set4302243.$var,"is-tree-set",L[34]);
is_DASH_tree_DASH_set352252.$var = anf_assign6742253;
var anf_assign6752254 = G(Set4302243.$var,"tree-set",L[34]);
tree_DASH_set3644.$var = anf_assign6752254;
var anf_assign6812255 = R.makeFunction(function(lst1672370,base_DASH_set1682371) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[253],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[257],"lists",lists225,"List"),Set1137],[lst1672370,base_DASH_set1682371],[L[257],L[258]],function() {
var anf_fun6772382 = G(lists121,"fold",L[256]);
var anf_arg6802383 = R.makeFunction(function(s1692384,elem1702385) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[254],2,arguments);
}
var anf_fun6792396 = G(s1692384,"add",L[255]);
var $z23882389 = D;
var $f23942395 = function(_) {
return R.isFunction(anf_fun6792396)?anf_fun6792396.app(elem1702385):R.ffi.throwNonFunApp(L[254],anf_fun6792396,[elem1702385]);
};
try {
if(--R.GAS > 0) {
$z23882389 = $f23942395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23942395,
"from":L[254]});
}
} catch($e23862387) {
if(R.isCont($e23862387)) {
var $ss23902391 = {"from":L[254],
"go":function(ann_DASH_check_DASH_temp678156) {
return $Hann_DASH_check_DASH_temp917155(ann_DASH_check_DASH_temp678156);
}};
$e23862387.stack[R.EXN_STACKHEIGHT++] = $ss23902391;
}
if(R.isPyretException($e23862387)) {
$e23862387.pyretStack.push(L[254]);
}
throw $e23862387;
}
var $ret23922393 = $Hann_DASH_check_DASH_temp917155($z23882389);
++R.GAS;
return $ret23922393;
});
var $z23742375 = D;
var $f23802381 = function(_) {
return R.isFunction(anf_fun6772382)?anf_fun6772382.app(anf_arg6802383,base_DASH_set1682371,lst1672370):R.ffi.throwNonFunApp(L[253],anf_fun6772382,[anf_arg6802383,base_DASH_set1682371,lst1672370]);
};
try {
if(--R.GAS > 0) {
$z23742375 = $f23802381();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23802381,
"from":L[253]});
}
} catch($e23722373) {
if(R.isCont($e23722373)) {
var $ss23762377 = {"from":L[253],
"go":function(ann_DASH_check_DASH_temp676154) {
return $Hann_DASH_check_DASH_temp918153(ann_DASH_check_DASH_temp676154,Set1137);
}};
$e23722373.stack[R.EXN_STACKHEIGHT++] = $ss23762377;
}
if(R.isPyretException($e23722373)) {
$e23722373.pyretStack.push(L[253]);
}
throw $e23722373;
}
var $ret23782379 = $Hann_DASH_check_DASH_temp918153($z23742375,Set1137);
++R.GAS;
return $ret23782379;
});
});
list_DASH_to_DASH_set37124.$var = anf_assign6812255;
var anf_assign6842256 = R.makeFunction(function(lst171140) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[5],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[252],"lists",lists225,"List")],[lst171140],[L[252]],function() {
var $z23622363 = D;
var $f23682369 = function(_) {
return R.isFunction(list_DASH_set34563.$var)?list_DASH_set34563.$var.app(empty141611):R.ffi.throwNonFunApp(L[251],list_DASH_set34563.$var,[empty141611]);
};
try {
if(--R.GAS > 0) {
$z23622363 = $f23682369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23682369,
"from":L[251]});
}
} catch($e23602361) {
if(R.isCont($e23602361)) {
var $ss23642365 = {"from":L[251],
"go":function(anf_arg683139) {
return $Hanf_arg920138(anf_arg683139,Set1137,list_DASH_to_DASH_set37124,lst171140);
}};
$e23602361.stack[R.EXN_STACKHEIGHT++] = $ss23642365;
}
if(R.isPyretException($e23602361)) {
$e23602361.pyretStack.push(L[251]);
}
throw $e23602361;
}
var $ret23662367 = $Hanf_arg920138($z23622363,Set1137,list_DASH_to_DASH_set37124,lst171140);
++R.GAS;
return $ret23662367;
});
});
list_DASH_to_DASH_list_DASH_set3842.$var = anf_assign6842256;
var anf_assign6872257 = R.makeFunction(function(lst172125) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[250],"lists",lists225,"List")],[lst172125],[L[250]],function() {
var $z23522353 = D;
var $f23582359 = function(_) {
return R.isFunction(tree_DASH_set3644.$var)?tree_DASH_set3644.$var.app(leaf2241.$var):R.ffi.throwNonFunApp(L[249],tree_DASH_set3644.$var,[leaf2241.$var]);
};
try {
if(--R.GAS > 0) {
$z23522353 = $f23582359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23582359,
"from":L[249]});
}
} catch($e23502351) {
if(R.isCont($e23502351)) {
var $ss23542355 = {"from":L[249],
"go":function(anf_arg686123) {
return $Hanf_arg922122(anf_arg686123,Set1137,list_DASH_to_DASH_set37124,lst172125);
}};
$e23502351.stack[R.EXN_STACKHEIGHT++] = $ss23542355;
}
if(R.isPyretException($e23502351)) {
$e23502351.pyretStack.push(L[249]);
}
throw $e23502351;
}
var $ret23562357 = $Hanf_arg922122($z23522353,Set1137,list_DASH_to_DASH_set37124,lst172125);
++R.GAS;
return $ret23562357;
});
});
list_DASH_to_DASH_tree_DASH_set3943.$var = anf_assign6872257;
var anf_assign6932259 = R.makeFunction(function(lst1732324) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[244],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[248],"lists",lists225,"List")],[lst1732324],[L[248]],function() {
var anf_fun6892335 = G(lists121,"fold",L[247]);
var anf_arg6922336 = R.makeFunction(function(tree1742337,elt1752338) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[245],2,arguments);
}
var anf_fun6912349 = G(tree1742337,"insert",L[246]);
var $z23412342 = D;
var $f23472348 = function(_) {
return R.isFunction(anf_fun6912349)?anf_fun6912349.app(elt1752338):R.ffi.throwNonFunApp(L[245],anf_fun6912349,[elt1752338]);
};
try {
if(--R.GAS > 0) {
$z23412342 = $f23472348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23472348,
"from":L[245]});
}
} catch($e23392340) {
if(R.isCont($e23392340)) {
var $ss23432344 = {"from":L[245],
"go":function(ann_DASH_check_DASH_temp690121) {
return $Hann_DASH_check_DASH_temp923120(ann_DASH_check_DASH_temp690121);
}};
$e23392340.stack[R.EXN_STACKHEIGHT++] = $ss23432344;
}
if(R.isPyretException($e23392340)) {
$e23392340.pyretStack.push(L[245]);
}
throw $e23392340;
}
var $ret23452346 = $Hann_DASH_check_DASH_temp923120($z23412342);
++R.GAS;
return $ret23452346;
});
var $z23272328 = D;
var $f23332334 = function(_) {
return R.isFunction(anf_fun6892335)?anf_fun6892335.app(anf_arg6922336,leaf2241.$var,lst1732324):R.ffi.throwNonFunApp(L[244],anf_fun6892335,[anf_arg6922336,leaf2241.$var,lst1732324]);
};
try {
if(--R.GAS > 0) {
$z23272328 = $f23332334();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23332334,
"from":L[244]});
}
} catch($e23252326) {
if(R.isCont($e23252326)) {
var $ss23292330 = {"from":L[244],
"go":function(ann_DASH_check_DASH_temp688119) {
return $Hann_DASH_check_DASH_temp924118(ann_DASH_check_DASH_temp688119);
}};
$e23252326.stack[R.EXN_STACKHEIGHT++] = $ss23292330;
}
if(R.isPyretException($e23252326)) {
$e23252326.pyretStack.push(L[244]);
}
throw $e23252326;
}
var $ret23312332 = $Hann_DASH_check_DASH_temp924118($z23272328);
++R.GAS;
return $ret23312332;
});
});
list_DASH_to_DASH_tree402258.$var = anf_assign6932259;
var anf_assign6992261 = R.makeFunction(function(arr176103) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
return R.checkAnnArgs([$type$RawArray20],[arr176103],[L[243]],function() {
var anf_arg697102 = R.makeFunction(function(ls1772310,elt1782311,$underscore1792312) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[241],3,arguments);
}
var anf_fun6962323 = G(ls1772310,"add",L[242]);
var $z23152316 = D;
var $f23212322 = function(_) {
return R.isFunction(anf_fun6962323)?anf_fun6962323.app(elt1782311):R.ffi.throwNonFunApp(L[241],anf_fun6962323,[elt1782311]);
};
try {
if(--R.GAS > 0) {
$z23152316 = $f23212322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23212322,
"from":L[241]});
}
} catch($e23132314) {
if(R.isCont($e23132314)) {
var $ss23172318 = {"from":L[241],
"go":function(ann_DASH_check_DASH_temp695117) {
return $Hann_DASH_check_DASH_temp925116(ann_DASH_check_DASH_temp695117);
}};
$e23132314.stack[R.EXN_STACKHEIGHT++] = $ss23172318;
}
if(R.isPyretException($e23132314)) {
$e23132314.pyretStack.push(L[241]);
}
throw $e23132314;
}
var $ret23192320 = $Hann_DASH_check_DASH_temp925116($z23152316);
++R.GAS;
return $ret23192320;
});
var $z23022303 = D;
var $f23082309 = function(_) {
return R.isFunction(list_DASH_set34563.$var)?list_DASH_set34563.$var.app(empty141611):R.ffi.throwNonFunApp(L[240],list_DASH_set34563.$var,[empty141611]);
};
try {
if(--R.GAS > 0) {
$z23022303 = $f23082309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23082309,
"from":L[240]});
}
} catch($e23002301) {
if(R.isCont($e23002301)) {
var $ss23042305 = {"from":L[240],
"go":function(anf_arg698101) {
return $Hanf_arg927100(anf_arg698101,Set1137,anf_arg697102,arr176103,raw_DASH_array_DASH_fold15);
}};
$e23002301.stack[R.EXN_STACKHEIGHT++] = $ss23042305;
}
if(R.isPyretException($e23002301)) {
$e23002301.pyretStack.push(L[240]);
}
throw $e23002301;
}
var $ret23062307 = $Hanf_arg927100($z23022303,Set1137,anf_arg697102,arr176103,raw_DASH_array_DASH_fold15);
++R.GAS;
return $ret23062307;
});
});
arr_DASH_to_DASH_list_DASH_set412260.$var = anf_assign6992261;
var anf_assign7042263 = R.makeFunction(function(arr1802274) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
return R.checkAnnArgs([$type$RawArray20],[arr1802274],[L[239]],function() {
var anf_arg7032285 = R.makeFunction(function(t1822286,elt1832287,$underscore1842288) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[237],3,arguments);
}
var anf_fun7022299 = G(t1822286,"insert",L[238]);
var $z22912292 = D;
var $f22972298 = function(_) {
return R.isFunction(anf_fun7022299)?anf_fun7022299.app(elt1832287):R.ffi.throwNonFunApp(L[237],anf_fun7022299,[elt1832287]);
};
try {
if(--R.GAS > 0) {
$z22912292 = $f22972298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22972298,
"from":L[237]});
}
} catch($e22892290) {
if(R.isCont($e22892290)) {
var $ss22932294 = {"from":L[237],
"go":function(ann_DASH_check_DASH_temp70199) {
return $Hann_DASH_check_DASH_temp92898(ann_DASH_check_DASH_temp70199);
}};
$e22892290.stack[R.EXN_STACKHEIGHT++] = $ss22932294;
}
if(R.isPyretException($e22892290)) {
$e22892290.pyretStack.push(L[237]);
}
throw $e22892290;
}
var $ret22952296 = $Hann_DASH_check_DASH_temp92898($z22912292);
++R.GAS;
return $ret22952296;
});
var $z22772278 = D;
var $f22832284 = function(_) {
return R.isFunction(raw_DASH_array_DASH_fold15)?raw_DASH_array_DASH_fold15.app(anf_arg7032285,leaf2241.$var,arr1802274,(0)):R.ffi.throwNonFunApp(L[236],raw_DASH_array_DASH_fold15,[anf_arg7032285,leaf2241.$var,arr1802274,(0)]);
};
try {
if(--R.GAS > 0) {
$z22772278 = $f22832284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22832284,
"from":L[236]});
}
} catch($e22752276) {
if(R.isCont($e22752276)) {
var $ss22792280 = {"from":L[236],
"go":function(tree18185) {
return $Htree93084(tree18185,Set1137,tree_DASH_set3644);
}};
$e22752276.stack[R.EXN_STACKHEIGHT++] = $ss22792280;
}
if(R.isPyretException($e22752276)) {
$e22752276.pyretStack.push(L[236]);
}
throw $e22752276;
}
var $ret22812282 = $Htree93084($z22772278,Set1137,tree_DASH_set3644);
++R.GAS;
return $ret22812282;
});
});
arr_DASH_to_DASH_tree_DASH_set422262.$var = anf_assign7042263;
var anf_obj70538 = R.makeObject({"make":arr_DASH_to_DASH_list_DASH_set412260.$var});
var anf_obj70639 = R.makeObject({"make":arr_DASH_to_DASH_list_DASH_set412260.$var});
var anf_obj70740 = R.makeObject({"make":arr_DASH_to_DASH_tree_DASH_set422262.$var});
var $z22662267 = D;
var $f22722273 = function(_) {
return R.isFunction(list_DASH_set34563.$var)?list_DASH_set34563.$var.app(empty141611):R.ffi.throwNonFunApp(L[235],list_DASH_set34563.$var,[empty141611]);
};
try {
if(--R.GAS > 0) {
$z22662267 = $f22722273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22722273,
"from":L[235]});
}
} catch($e22642265) {
if(R.isCont($e22642265)) {
var $ss22682269 = {"from":L[235],
"go":function(anf_obj70835) {
return $Hanf_obj93434(anf_obj70835,AVLTree936,Set1137,anf_obj70538,anf_obj70639,anf_obj70740,leaf2241,list_DASH_to_DASH_list_DASH_set3842,list_DASH_to_DASH_tree_DASH_set3943,tree_DASH_set3644,builtins10,nothing11);
}};
$e22642265.stack[R.EXN_STACKHEIGHT++] = $ss22682269;
}
if(R.isPyretException($e22642265)) {
$e22642265.pyretStack.push(L[235]);
}
throw $e22642265;
}
var $ret22702271 = $Hanf_obj93434($z22662267,AVLTree936,Set1137,anf_obj70538,anf_obj70639,anf_obj70740,leaf2241,list_DASH_to_DASH_list_DASH_set3842,list_DASH_to_DASH_tree_DASH_set3943,tree_DASH_set3644,builtins10,nothing11);
++R.GAS;
return $ret22702271;
},function(moduleVal) {
R.modules["$src/arr/base/sets.arr29"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/srcloc',["trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($arrays11223,$lists31324,$option51425,$error71526,$sets91627) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/trove/srcloc.arr22"]) {
return R.modules["$src/arr/trove/srcloc.arr22"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/trove/srcloc.arr";
var D = R.undefined;
var L = [[M,6,0,48,48,3,1449],
[M,36,6,1020,36,56,1070],
[M,36,26,1040,36,56,1070],
[M,36,43,1057,36,55,1069],
[M,36,28,1042,36,39,1053],
[M,36,6,1020,36,22,1036],
[M,31,20,837,31,38,855],
[M,32,20,889,32,45,914],
[M,32,29,898,32,44,913],
[M,31,6,823,33,51,966],
[M,33,24,939,33,51,966],
[M,33,33,948,33,50,965],
[M,29,4,693,34,7,974],
[M,20,2,462,44,7,1350],
[M,12,6,199,12,67,260],
[M,12,27,220,12,67,260],
[M,12,50,243,12,66,259],
[M,12,29,222,12,46,239],
[M,12,6,199,12,23,216],
[M,8,4,96,10,7,163],
[M,7,2,63,19,7,459],
[M,3,0,21,52,3,1565],
[M,50,0,1451,52,3,1565],
[M,7,4,65,7,24,85],
[M,20,4,464,28,7,682],
[M,21,18,490,21,24,496],
[M,22,22,520,22,28,526],
[M,23,24,552,23,30,558],
[M,24,22,582,24,28,588],
[M,25,20,610,25,26,616],
[M,26,22,640,26,28,646],
[M,27,20,668,27,26,674],
[M,38,4,1084,44,7,1350],
[M,40,6,1230,43,9,1342],
[M,42,36,1316,42,52,1332],
[M,42,18,1298,42,33,1313],
[M,41,8,1259,41,28,1279],
[M,38,26,1106,38,32,1112],
[M,36,6,1020,36,15,1029],
[M,35,29,1005,35,35,1011],
[M,35,4,980,37,7,1078],
[M,31,20,837,31,31,848],
[M,31,45,862,31,47,864],
[M,31,9,826,31,18,835],
[M,27,8,656,27,26,674],
[M,26,8,626,26,28,646],
[M,25,8,598,25,26,616],
[M,24,8,568,24,28,588],
[M,23,8,536,23,30,558],
[M,22,8,506,22,28,526],
[M,21,8,480,21,24,496],
[M,14,4,274,19,7,459],
[M,15,6,301,18,9,451],
[M,17,8,403,17,46,441],
[M,16,8,330,16,72,394],
[M,16,54,376,16,71,393],
[M,16,35,357,16,51,373],
[M,12,6,199,12,16,209],
[M,11,4,169,13,7,268],
[M,9,6,119,9,42,155],
[M,9,20,133,9,36,149],
[M,7,12,73,7,23,84],
[M,47,2,1403,47,44,1445],
[M,47,22,1423,47,34,1435],
[M,46,2,1362,46,39,1399],
[M,46,18,1378,46,29,1389]];
var _lessthan3 = NAMESPACE.get("_lessthan");
var _plus4 = NAMESPACE.get("_plus");
var builtins5 = NAMESPACE.get("builtins");
var nothing6 = NAMESPACE.get("nothing");
var raise7 = NAMESPACE.get("raise");
var torepr8 = NAMESPACE.get("torepr");
var tostring9 = NAMESPACE.get("tostring");
var $type$Number10 = NAMESPACE.get("$type$Number");
var $type$String11 = NAMESPACE.get("$type$String");
var $Hanf_bracket21328 = function(anf_bracket15629,Srcloc6030,provides15431,nothing6) {
var anf_fun15742 = G(anf_bracket15629,"results",L[0]);
var $z3435 = D;
var $f4041 = function(_) {
return R.isFunction(anf_fun15742)?anf_fun15742.app():R.ffi.throwNonFunApp(L[0],anf_fun15742,[]);
};
try {
if(--R.GAS > 0) {
$z3435 = $f4041();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4041,
"from":L[0]});
}
} catch($e3233) {
if(R.isCont($e3233)) {
var $ss3637 = {"from":L[0],
"go":function(checks15843) {
return $Hchecks21244(checks15843,Srcloc6030,provides15431,nothing6);
}};
$e3233.stack[R.EXN_STACKHEIGHT++] = $ss3637;
}
if(R.isPyretException($e3233)) {
$e3233.pyretStack.push(L[0]);
}
throw $e3233;
}
var $ret3839 = $Hchecks21244($z3435,Srcloc6030,provides15431,nothing6);
++R.GAS;
return $ret3839;
};
var $Hchecks21244 = function(checks15843,Srcloc6030,provides15431,nothing6) {
return R.makeObject({"answer":nothing6,
"provide-plus-types":R.makeObject({"values":provides15431,
"types":{"Srcloc":Srcloc6030}}),
"checks":checks15843});
};
var $Hann_DASH_check_DASH_temp21145 = function(ann_DASH_check_DASH_temp15246) {
return ann_DASH_check_DASH_temp15246;
};
var $Hann_DASH_check_DASH_temp21047 = function(ann_DASH_check_DASH_temp13548) {
return ann_DASH_check_DASH_temp13548;
};
var $Hann_DASH_check_DASH_temp20949 = function(ann_DASH_check_DASH_temp14050) {
return ann_DASH_check_DASH_temp14050;
};
var $Hand_DASH_oper_DASH_20851 = function(and_DASH_oper_DASH_1752,other9553,self9454) {
var if_helper12265 = R.makeFunction(function(if_helper_arg12392) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
var ann_DASH_check_DASH_temp12193 = if_helper_arg12392;
return ann_DASH_check_DASH_temp12193;
});
var anf_if12691 = R.isBoolean(and_DASH_oper_DASH_1752);
if(R.isPyretTrue(anf_if12691)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1752)) {
var anf_arg12874 = G(self9454,"source",L[4]);
var anf_arg12975 = G(other9553,"source",L[3]);
var and_DASH_oper_DASH_1866 = R.equiv(anf_arg12874,anf_arg12975);
var anf_if13273 = R.isBoolean(and_DASH_oper_DASH_1866);
if(R.isPyretTrue(anf_if13273)) {
var $z5758 = D;
var $f6364 = function(_) {
return R.isFunction(if_helper12265)?if_helper12265.app(and_DASH_oper_DASH_1866):R.ffi.throwNonFunApp(L[1],if_helper12265,[and_DASH_oper_DASH_1866]);
};
try {
if(--R.GAS > 0) {
$z5758 = $f6364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6364,
"from":L[1]});
}
} catch($e5556) {
if(R.isCont($e5556)) {
var $ss5960 = {"from":L[1],
"go":function(cont_tail_app13367) {
return $Hcont_tail_app20668(cont_tail_app13367);
}};
$e5556.stack[R.EXN_STACKHEIGHT++] = $ss5960;
}
if(R.isPyretException($e5556)) {
$e5556.pyretStack.push(L[1]);
}
throw $e5556;
}
var $ret6162 = $Hcont_tail_app20668($z5758);
++R.GAS;
return $ret6162;
} else {
var cont_tail_arg13071 = R.throwNonBooleanOp(L[2],("second"),("and"),and_DASH_oper_DASH_1866);
if(--R.GAS > 0) {
$z6970 = R.isFunction(if_helper12265)?if_helper12265.app(cont_tail_arg13071):R.ffi.throwNonFunApp(L[2],if_helper12265,[cont_tail_arg13071]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper12265)?if_helper12265.app(cont_tail_arg13071):R.ffi.throwNonFunApp(L[2],if_helper12265,[cont_tail_arg13071]);
},
"from":L[2]});
}
++R.GAS;
return $z6970;
}
} else {
var $z7879 = D;
var $f8485 = function(_) {
return R.isFunction(if_helper12265)?if_helper12265.app((false)):R.ffi.throwNonFunApp(L[1],if_helper12265,[(false)]);
};
try {
if(--R.GAS > 0) {
$z7879 = $f8485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8485,
"from":L[1]});
}
} catch($e7677) {
if(R.isCont($e7677)) {
var $ss8081 = {"from":L[1],
"go":function(cont_tail_app12786) {
return $Hcont_tail_app20787(cont_tail_app12786);
}};
$e7677.stack[R.EXN_STACKHEIGHT++] = $ss8081;
}
if(R.isPyretException($e7677)) {
$e7677.pyretStack.push(L[1]);
}
throw $e7677;
}
var $ret8283 = $Hcont_tail_app20787($z7879);
++R.GAS;
return $ret8283;
}
} else {
var cont_tail_arg12490 = R.throwNonBooleanOp(L[5],("first"),("and"),and_DASH_oper_DASH_1752);
if(--R.GAS > 0) {
$z8889 = R.isFunction(if_helper12265)?if_helper12265.app(cont_tail_arg12490):R.ffi.throwNonFunApp(L[5],if_helper12265,[cont_tail_arg12490]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper12265)?if_helper12265.app(cont_tail_arg12490):R.ffi.throwNonFunApp(L[5],if_helper12265,[cont_tail_arg12490]);
},
"from":L[5]});
}
++R.GAS;
return $z8889;
}
};
var $Hcont_tail_app20668 = function(cont_tail_app13367) {
return cont_tail_app13367;
};
var $Hcont_tail_app20787 = function(cont_tail_app12786) {
return cont_tail_app12786;
};
var $Hcont_tail_arg20494 = function(cont_tail_arg11895,if_helper10496) {
if(--R.GAS > 0) {
$z9798 = R.isFunction(if_helper10496)?if_helper10496.app(cont_tail_arg11895):R.ffi.throwNonFunApp(L[6],if_helper10496,[cont_tail_arg11895]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper10496)?if_helper10496.app(cont_tail_arg11895):R.ffi.throwNonFunApp(L[6],if_helper10496,[cont_tail_arg11895]);
},
"from":L[6]});
}
++R.GAS;
return $z9798;
};
var $Hcont_tail_app20599 = function(cont_tail_app116100) {
return cont_tail_app116100;
};
var $Hanf_arg203101 = function(anf_arg106102,self92103,_plus4,tostring9) {
var anf_arg107114 = G(self92103,"start-line",L[8]);
var $z106107 = D;
var $f112113 = function(_) {
return R.isFunction(tostring9)?tostring9.app(anf_arg107114):R.ffi.throwNonFunApp(L[7],tostring9,[anf_arg107114]);
};
try {
if(--R.GAS > 0) {
$z106107 = $f112113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f112113,
"from":L[7]});
}
} catch($e104105) {
if(R.isCont($e104105)) {
var $ss108109 = {"from":L[7],
"go":function(anf_arg108115) {
return $Hanf_arg202116(anf_arg108115,anf_arg106102,self92103,_plus4,tostring9);
}};
$e104105.stack[R.EXN_STACKHEIGHT++] = $ss108109;
}
if(R.isPyretException($e104105)) {
$e104105.pyretStack.push(L[7]);
}
throw $e104105;
}
var $ret110111 = $Hanf_arg202116($z106107,anf_arg106102,self92103,_plus4,tostring9);
++R.GAS;
return $ret110111;
};
var $Hanf_arg202116 = function(anf_arg108115,anf_arg106102,self92103,_plus4,tostring9) {
var $z119120 = D;
var $f125126 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg106102,anf_arg108115):R.ffi.throwNonFunApp(L[9],_plus4,[anf_arg106102,anf_arg108115]);
};
try {
if(--R.GAS > 0) {
$z119120 = $f125126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f125126,
"from":L[9]});
}
} catch($e117118) {
if(R.isCont($e117118)) {
var $ss121122 = {"from":L[9],
"go":function(anf_arg109127) {
return $Hanf_arg201128(anf_arg109127,self92103,_plus4,tostring9);
}};
$e117118.stack[R.EXN_STACKHEIGHT++] = $ss121122;
}
if(R.isPyretException($e117118)) {
$e117118.pyretStack.push(L[9]);
}
throw $e117118;
}
var $ret123124 = $Hanf_arg201128($z119120,self92103,_plus4,tostring9);
++R.GAS;
return $ret123124;
};
var $Hanf_arg201128 = function(anf_arg109127,self92103,_plus4,tostring9) {
var $z131132 = D;
var $f137138 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg109127,(", column ")):R.ffi.throwNonFunApp(L[9],_plus4,[anf_arg109127,(", column ")]);
};
try {
if(--R.GAS > 0) {
$z131132 = $f137138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f137138,
"from":L[9]});
}
} catch($e129130) {
if(R.isCont($e129130)) {
var $ss133134 = {"from":L[9],
"go":function(anf_arg110139) {
return $Hanf_arg200140(anf_arg110139,self92103,_plus4,tostring9);
}};
$e129130.stack[R.EXN_STACKHEIGHT++] = $ss133134;
}
if(R.isPyretException($e129130)) {
$e129130.pyretStack.push(L[9]);
}
throw $e129130;
}
var $ret135136 = $Hanf_arg200140($z131132,self92103,_plus4,tostring9);
++R.GAS;
return $ret135136;
};
var $Hanf_arg200140 = function(anf_arg110139,self92103,_plus4,tostring9) {
var anf_arg111151 = G(self92103,"start-column",L[11]);
var $z143144 = D;
var $f149150 = function(_) {
return R.isFunction(tostring9)?tostring9.app(anf_arg111151):R.ffi.throwNonFunApp(L[10],tostring9,[anf_arg111151]);
};
try {
if(--R.GAS > 0) {
$z143144 = $f149150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f149150,
"from":L[10]});
}
} catch($e141142) {
if(R.isCont($e141142)) {
var $ss145146 = {"from":L[10],
"go":function(anf_arg112152) {
return $Hanf_arg199153(anf_arg112152,anf_arg110139,_plus4);
}};
$e141142.stack[R.EXN_STACKHEIGHT++] = $ss145146;
}
if(R.isPyretException($e141142)) {
$e141142.pyretStack.push(L[10]);
}
throw $e141142;
}
var $ret147148 = $Hanf_arg199153($z143144,anf_arg110139,_plus4);
++R.GAS;
return $ret147148;
};
var $Hanf_arg199153 = function(anf_arg112152,anf_arg110139,_plus4) {
var $z156157 = D;
var $f162163 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg110139,anf_arg112152):R.ffi.throwNonFunApp(L[12],_plus4,[anf_arg110139,anf_arg112152]);
};
try {
if(--R.GAS > 0) {
$z156157 = $f162163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f162163,
"from":L[12]});
}
} catch($e154155) {
if(R.isCont($e154155)) {
var $ss158159 = {"from":L[12],
"go":function(ann_DASH_check_DASH_temp103164) {
return $Hann_DASH_check_DASH_temp198165(ann_DASH_check_DASH_temp103164);
}};
$e154155.stack[R.EXN_STACKHEIGHT++] = $ss158159;
}
if(R.isPyretException($e154155)) {
$e154155.pyretStack.push(L[12]);
}
throw $e154155;
}
var $ret160161 = $Hann_DASH_check_DASH_temp198165($z156157);
++R.GAS;
return $ret160161;
};
var $Hann_DASH_check_DASH_temp198165 = function(ann_DASH_check_DASH_temp103164) {
return ann_DASH_check_DASH_temp103164;
};
var $Hanf_arg197166 = function(anf_arg75167,self14168,_plus4,torepr8) {
var anf_arg76179 = G(self14168,"start-line",L[13]);
var $z171172 = D;
var $f177178 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg76179):R.ffi.throwNonFunApp(L[13],torepr8,[anf_arg76179]);
};
try {
if(--R.GAS > 0) {
$z171172 = $f177178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f177178,
"from":L[13]});
}
} catch($e169170) {
if(R.isCont($e169170)) {
var $ss173174 = {"from":L[13],
"go":function(anf_arg77180) {
return $Hanf_arg196181(anf_arg77180,anf_arg75167,self14168,_plus4,torepr8);
}};
$e169170.stack[R.EXN_STACKHEIGHT++] = $ss173174;
}
if(R.isPyretException($e169170)) {
$e169170.pyretStack.push(L[13]);
}
throw $e169170;
}
var $ret175176 = $Hanf_arg196181($z171172,anf_arg75167,self14168,_plus4,torepr8);
++R.GAS;
return $ret175176;
};
var $Hanf_arg196181 = function(anf_arg77180,anf_arg75167,self14168,_plus4,torepr8) {
var $z184185 = D;
var $f190191 = function(_) {
return R.isFunction(_plus4)?_plus4.app((", "),anf_arg77180):R.ffi.throwNonFunApp(L[13],_plus4,[(", "),anf_arg77180]);
};
try {
if(--R.GAS > 0) {
$z184185 = $f190191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f190191,
"from":L[13]});
}
} catch($e182183) {
if(R.isCont($e182183)) {
var $ss186187 = {"from":L[13],
"go":function(anf_arg78192) {
return $Hanf_arg195193(anf_arg78192,anf_arg75167,self14168,_plus4,torepr8);
}};
$e182183.stack[R.EXN_STACKHEIGHT++] = $ss186187;
}
if(R.isPyretException($e182183)) {
$e182183.pyretStack.push(L[13]);
}
throw $e182183;
}
var $ret188189 = $Hanf_arg195193($z184185,anf_arg75167,self14168,_plus4,torepr8);
++R.GAS;
return $ret188189;
};
var $Hanf_arg195193 = function(anf_arg78192,anf_arg75167,self14168,_plus4,torepr8) {
var $z196197 = D;
var $f202203 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg75167,anf_arg78192):R.ffi.throwNonFunApp(L[13],_plus4,[anf_arg75167,anf_arg78192]);
};
try {
if(--R.GAS > 0) {
$z196197 = $f202203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f202203,
"from":L[13]});
}
} catch($e194195) {
if(R.isCont($e194195)) {
var $ss198199 = {"from":L[13],
"go":function(anf_arg79204) {
return $Hanf_arg194205(anf_arg79204,self14168,_plus4,torepr8);
}};
$e194195.stack[R.EXN_STACKHEIGHT++] = $ss198199;
}
if(R.isPyretException($e194195)) {
$e194195.pyretStack.push(L[13]);
}
throw $e194195;
}
var $ret200201 = $Hanf_arg194205($z196197,self14168,_plus4,torepr8);
++R.GAS;
return $ret200201;
};
var $Hanf_arg194205 = function(anf_arg79204,self14168,_plus4,torepr8) {
var anf_arg80216 = G(self14168,"start-column",L[13]);
var $z208209 = D;
var $f214215 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg80216):R.ffi.throwNonFunApp(L[13],torepr8,[anf_arg80216]);
};
try {
if(--R.GAS > 0) {
$z208209 = $f214215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f214215,
"from":L[13]});
}
} catch($e206207) {
if(R.isCont($e206207)) {
var $ss210211 = {"from":L[13],
"go":function(anf_arg81217) {
return $Hanf_arg193218(anf_arg81217,anf_arg79204,self14168,_plus4,torepr8);
}};
$e206207.stack[R.EXN_STACKHEIGHT++] = $ss210211;
}
if(R.isPyretException($e206207)) {
$e206207.pyretStack.push(L[13]);
}
throw $e206207;
}
var $ret212213 = $Hanf_arg193218($z208209,anf_arg79204,self14168,_plus4,torepr8);
++R.GAS;
return $ret212213;
};
var $Hanf_arg193218 = function(anf_arg81217,anf_arg79204,self14168,_plus4,torepr8) {
var $z221222 = D;
var $f227228 = function(_) {
return R.isFunction(_plus4)?_plus4.app((", "),anf_arg81217):R.ffi.throwNonFunApp(L[13],_plus4,[(", "),anf_arg81217]);
};
try {
if(--R.GAS > 0) {
$z221222 = $f227228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f227228,
"from":L[13]});
}
} catch($e219220) {
if(R.isCont($e219220)) {
var $ss223224 = {"from":L[13],
"go":function(anf_arg82229) {
return $Hanf_arg192230(anf_arg82229,anf_arg79204,self14168,_plus4,torepr8);
}};
$e219220.stack[R.EXN_STACKHEIGHT++] = $ss223224;
}
if(R.isPyretException($e219220)) {
$e219220.pyretStack.push(L[13]);
}
throw $e219220;
}
var $ret225226 = $Hanf_arg192230($z221222,anf_arg79204,self14168,_plus4,torepr8);
++R.GAS;
return $ret225226;
};
var $Hanf_arg192230 = function(anf_arg82229,anf_arg79204,self14168,_plus4,torepr8) {
var $z233234 = D;
var $f239240 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg79204,anf_arg82229):R.ffi.throwNonFunApp(L[13],_plus4,[anf_arg79204,anf_arg82229]);
};
try {
if(--R.GAS > 0) {
$z233234 = $f239240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f239240,
"from":L[13]});
}
} catch($e231232) {
if(R.isCont($e231232)) {
var $ss235236 = {"from":L[13],
"go":function(anf_arg83241) {
return $Hanf_arg191242(anf_arg83241,self14168,_plus4,torepr8);
}};
$e231232.stack[R.EXN_STACKHEIGHT++] = $ss235236;
}
if(R.isPyretException($e231232)) {
$e231232.pyretStack.push(L[13]);
}
throw $e231232;
}
var $ret237238 = $Hanf_arg191242($z233234,self14168,_plus4,torepr8);
++R.GAS;
return $ret237238;
};
var $Hanf_arg191242 = function(anf_arg83241,self14168,_plus4,torepr8) {
var anf_arg84253 = G(self14168,"start-char",L[13]);
var $z245246 = D;
var $f251252 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg84253):R.ffi.throwNonFunApp(L[13],torepr8,[anf_arg84253]);
};
try {
if(--R.GAS > 0) {
$z245246 = $f251252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f251252,
"from":L[13]});
}
} catch($e243244) {
if(R.isCont($e243244)) {
var $ss247248 = {"from":L[13],
"go":function(anf_arg85254) {
return $Hanf_arg190255(anf_arg85254,anf_arg83241,self14168,_plus4,torepr8);
}};
$e243244.stack[R.EXN_STACKHEIGHT++] = $ss247248;
}
if(R.isPyretException($e243244)) {
$e243244.pyretStack.push(L[13]);
}
throw $e243244;
}
var $ret249250 = $Hanf_arg190255($z245246,anf_arg83241,self14168,_plus4,torepr8);
++R.GAS;
return $ret249250;
};
var $Hanf_arg190255 = function(anf_arg85254,anf_arg83241,self14168,_plus4,torepr8) {
var $z258259 = D;
var $f264265 = function(_) {
return R.isFunction(_plus4)?_plus4.app((", "),anf_arg85254):R.ffi.throwNonFunApp(L[13],_plus4,[(", "),anf_arg85254]);
};
try {
if(--R.GAS > 0) {
$z258259 = $f264265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f264265,
"from":L[13]});
}
} catch($e256257) {
if(R.isCont($e256257)) {
var $ss260261 = {"from":L[13],
"go":function(anf_arg86266) {
return $Hanf_arg189267(anf_arg86266,anf_arg83241,self14168,_plus4,torepr8);
}};
$e256257.stack[R.EXN_STACKHEIGHT++] = $ss260261;
}
if(R.isPyretException($e256257)) {
$e256257.pyretStack.push(L[13]);
}
throw $e256257;
}
var $ret262263 = $Hanf_arg189267($z258259,anf_arg83241,self14168,_plus4,torepr8);
++R.GAS;
return $ret262263;
};
var $Hanf_arg189267 = function(anf_arg86266,anf_arg83241,self14168,_plus4,torepr8) {
var $z270271 = D;
var $f276277 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg83241,anf_arg86266):R.ffi.throwNonFunApp(L[13],_plus4,[anf_arg83241,anf_arg86266]);
};
try {
if(--R.GAS > 0) {
$z270271 = $f276277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f276277,
"from":L[13]});
}
} catch($e268269) {
if(R.isCont($e268269)) {
var $ss272273 = {"from":L[13],
"go":function(anf_arg87278) {
return $Hanf_arg188279(anf_arg87278,self14168,_plus4,torepr8);
}};
$e268269.stack[R.EXN_STACKHEIGHT++] = $ss272273;
}
if(R.isPyretException($e268269)) {
$e268269.pyretStack.push(L[13]);
}
throw $e268269;
}
var $ret274275 = $Hanf_arg188279($z270271,self14168,_plus4,torepr8);
++R.GAS;
return $ret274275;
};
var $Hanf_arg188279 = function(anf_arg87278,self14168,_plus4,torepr8) {
var anf_arg88290 = G(self14168,"end-line",L[13]);
var $z282283 = D;
var $f288289 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg88290):R.ffi.throwNonFunApp(L[13],torepr8,[anf_arg88290]);
};
try {
if(--R.GAS > 0) {
$z282283 = $f288289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f288289,
"from":L[13]});
}
} catch($e280281) {
if(R.isCont($e280281)) {
var $ss284285 = {"from":L[13],
"go":function(anf_arg89291) {
return $Hanf_arg187292(anf_arg89291,anf_arg87278,self14168,_plus4,torepr8);
}};
$e280281.stack[R.EXN_STACKHEIGHT++] = $ss284285;
}
if(R.isPyretException($e280281)) {
$e280281.pyretStack.push(L[13]);
}
throw $e280281;
}
var $ret286287 = $Hanf_arg187292($z282283,anf_arg87278,self14168,_plus4,torepr8);
++R.GAS;
return $ret286287;
};
var $Hanf_arg187292 = function(anf_arg89291,anf_arg87278,self14168,_plus4,torepr8) {
var $z295296 = D;
var $f301302 = function(_) {
return R.isFunction(_plus4)?_plus4.app((", "),anf_arg89291):R.ffi.throwNonFunApp(L[13],_plus4,[(", "),anf_arg89291]);
};
try {
if(--R.GAS > 0) {
$z295296 = $f301302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f301302,
"from":L[13]});
}
} catch($e293294) {
if(R.isCont($e293294)) {
var $ss297298 = {"from":L[13],
"go":function(anf_arg90303) {
return $Hanf_arg186304(anf_arg90303,anf_arg87278,self14168,_plus4,torepr8);
}};
$e293294.stack[R.EXN_STACKHEIGHT++] = $ss297298;
}
if(R.isPyretException($e293294)) {
$e293294.pyretStack.push(L[13]);
}
throw $e293294;
}
var $ret299300 = $Hanf_arg186304($z295296,anf_arg87278,self14168,_plus4,torepr8);
++R.GAS;
return $ret299300;
};
var $Hanf_arg186304 = function(anf_arg90303,anf_arg87278,self14168,_plus4,torepr8) {
var $z307308 = D;
var $f313314 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg87278,anf_arg90303):R.ffi.throwNonFunApp(L[13],_plus4,[anf_arg87278,anf_arg90303]);
};
try {
if(--R.GAS > 0) {
$z307308 = $f313314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f313314,
"from":L[13]});
}
} catch($e305306) {
if(R.isCont($e305306)) {
var $ss309310 = {"from":L[13],
"go":function(anf_arg91315) {
return $Hanf_arg185316(anf_arg91315,self14168,_plus4,torepr8);
}};
$e305306.stack[R.EXN_STACKHEIGHT++] = $ss309310;
}
if(R.isPyretException($e305306)) {
$e305306.pyretStack.push(L[13]);
}
throw $e305306;
}
var $ret311312 = $Hanf_arg185316($z307308,self14168,_plus4,torepr8);
++R.GAS;
return $ret311312;
};
var $Hanf_arg185316 = function(anf_arg91315,self14168,_plus4,torepr8) {
var anf_arg92327 = G(self14168,"end-column",L[13]);
var $z319320 = D;
var $f325326 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg92327):R.ffi.throwNonFunApp(L[13],torepr8,[anf_arg92327]);
};
try {
if(--R.GAS > 0) {
$z319320 = $f325326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f325326,
"from":L[13]});
}
} catch($e317318) {
if(R.isCont($e317318)) {
var $ss321322 = {"from":L[13],
"go":function(anf_arg93328) {
return $Hanf_arg184329(anf_arg93328,anf_arg91315,self14168,_plus4,torepr8);
}};
$e317318.stack[R.EXN_STACKHEIGHT++] = $ss321322;
}
if(R.isPyretException($e317318)) {
$e317318.pyretStack.push(L[13]);
}
throw $e317318;
}
var $ret323324 = $Hanf_arg184329($z319320,anf_arg91315,self14168,_plus4,torepr8);
++R.GAS;
return $ret323324;
};
var $Hanf_arg184329 = function(anf_arg93328,anf_arg91315,self14168,_plus4,torepr8) {
var $z332333 = D;
var $f338339 = function(_) {
return R.isFunction(_plus4)?_plus4.app((", "),anf_arg93328):R.ffi.throwNonFunApp(L[13],_plus4,[(", "),anf_arg93328]);
};
try {
if(--R.GAS > 0) {
$z332333 = $f338339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f338339,
"from":L[13]});
}
} catch($e330331) {
if(R.isCont($e330331)) {
var $ss334335 = {"from":L[13],
"go":function(anf_arg94340) {
return $Hanf_arg183341(anf_arg94340,anf_arg91315,self14168,_plus4,torepr8);
}};
$e330331.stack[R.EXN_STACKHEIGHT++] = $ss334335;
}
if(R.isPyretException($e330331)) {
$e330331.pyretStack.push(L[13]);
}
throw $e330331;
}
var $ret336337 = $Hanf_arg183341($z332333,anf_arg91315,self14168,_plus4,torepr8);
++R.GAS;
return $ret336337;
};
var $Hanf_arg183341 = function(anf_arg94340,anf_arg91315,self14168,_plus4,torepr8) {
var $z344345 = D;
var $f350351 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg91315,anf_arg94340):R.ffi.throwNonFunApp(L[13],_plus4,[anf_arg91315,anf_arg94340]);
};
try {
if(--R.GAS > 0) {
$z344345 = $f350351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f350351,
"from":L[13]});
}
} catch($e342343) {
if(R.isCont($e342343)) {
var $ss346347 = {"from":L[13],
"go":function(anf_arg95352) {
return $Hanf_arg182353(anf_arg95352,self14168,_plus4,torepr8);
}};
$e342343.stack[R.EXN_STACKHEIGHT++] = $ss346347;
}
if(R.isPyretException($e342343)) {
$e342343.pyretStack.push(L[13]);
}
throw $e342343;
}
var $ret348349 = $Hanf_arg182353($z344345,self14168,_plus4,torepr8);
++R.GAS;
return $ret348349;
};
var $Hanf_arg182353 = function(anf_arg95352,self14168,_plus4,torepr8) {
var anf_arg96364 = G(self14168,"end-char",L[13]);
var $z356357 = D;
var $f362363 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg96364):R.ffi.throwNonFunApp(L[13],torepr8,[anf_arg96364]);
};
try {
if(--R.GAS > 0) {
$z356357 = $f362363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f362363,
"from":L[13]});
}
} catch($e354355) {
if(R.isCont($e354355)) {
var $ss358359 = {"from":L[13],
"go":function(anf_arg97365) {
return $Hanf_arg181366(anf_arg97365,anf_arg95352,_plus4);
}};
$e354355.stack[R.EXN_STACKHEIGHT++] = $ss358359;
}
if(R.isPyretException($e354355)) {
$e354355.pyretStack.push(L[13]);
}
throw $e354355;
}
var $ret360361 = $Hanf_arg181366($z356357,anf_arg95352,_plus4);
++R.GAS;
return $ret360361;
};
var $Hanf_arg181366 = function(anf_arg97365,anf_arg95352,_plus4) {
var $z369370 = D;
var $f375376 = function(_) {
return R.isFunction(_plus4)?_plus4.app((", "),anf_arg97365):R.ffi.throwNonFunApp(L[13],_plus4,[(", "),anf_arg97365]);
};
try {
if(--R.GAS > 0) {
$z369370 = $f375376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f375376,
"from":L[13]});
}
} catch($e367368) {
if(R.isCont($e367368)) {
var $ss371372 = {"from":L[13],
"go":function(anf_arg98377) {
return $Hanf_arg180378(anf_arg98377,anf_arg95352,_plus4);
}};
$e367368.stack[R.EXN_STACKHEIGHT++] = $ss371372;
}
if(R.isPyretException($e367368)) {
$e367368.pyretStack.push(L[13]);
}
throw $e367368;
}
var $ret373374 = $Hanf_arg180378($z369370,anf_arg95352,_plus4);
++R.GAS;
return $ret373374;
};
var $Hanf_arg180378 = function(anf_arg98377,anf_arg95352,_plus4) {
var $z381382 = D;
var $f387388 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg95352,anf_arg98377):R.ffi.throwNonFunApp(L[13],_plus4,[anf_arg95352,anf_arg98377]);
};
try {
if(--R.GAS > 0) {
$z381382 = $f387388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f387388,
"from":L[13]});
}
} catch($e379380) {
if(R.isCont($e379380)) {
var $ss383384 = {"from":L[13],
"go":function(anf_arg99389) {
return $Hanf_arg179390(anf_arg99389,_plus4);
}};
$e379380.stack[R.EXN_STACKHEIGHT++] = $ss383384;
}
if(R.isPyretException($e379380)) {
$e379380.pyretStack.push(L[13]);
}
throw $e379380;
}
var $ret385386 = $Hanf_arg179390($z381382,_plus4);
++R.GAS;
return $ret385386;
};
var $Hanf_arg179390 = function(anf_arg99389,_plus4) {
var $z393394 = D;
var $f399400 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg99389,(")")):R.ffi.throwNonFunApp(L[13],_plus4,[anf_arg99389,(")")]);
};
try {
if(--R.GAS > 0) {
$z393394 = $f399400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f399400,
"from":L[13]});
}
} catch($e391392) {
if(R.isCont($e391392)) {
var $ss395396 = {"from":L[13],
"go":function(anf_arg100401) {
return $Hanf_arg178402(anf_arg100401,_plus4);
}};
$e391392.stack[R.EXN_STACKHEIGHT++] = $ss395396;
}
if(R.isPyretException($e391392)) {
$e391392.pyretStack.push(L[13]);
}
throw $e391392;
}
var $ret397398 = $Hanf_arg178402($z393394,_plus4);
++R.GAS;
return $ret397398;
};
var $Hanf_arg178402 = function(anf_arg100401,_plus4) {
var $z405406 = D;
var $f411412 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("("),anf_arg100401):R.ffi.throwNonFunApp(L[13],_plus4,[("("),anf_arg100401]);
};
try {
if(--R.GAS > 0) {
$z405406 = $f411412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f411412,
"from":L[13]});
}
} catch($e403404) {
if(R.isCont($e403404)) {
var $ss407408 = {"from":L[13],
"go":function(anf_arg101413) {
return $Hanf_arg177414(anf_arg101413,_plus4);
}};
$e403404.stack[R.EXN_STACKHEIGHT++] = $ss407408;
}
if(R.isPyretException($e403404)) {
$e403404.pyretStack.push(L[13]);
}
throw $e403404;
}
var $ret409410 = $Hanf_arg177414($z405406,_plus4);
++R.GAS;
return $ret409410;
};
var $Hanf_arg177414 = function(anf_arg101413,_plus4) {
var $z417418 = D;
var $f423424 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("srcloc"),anf_arg101413):R.ffi.throwNonFunApp(L[13],_plus4,[("srcloc"),anf_arg101413]);
};
try {
if(--R.GAS > 0) {
$z417418 = $f423424();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f423424,
"from":L[13]});
}
} catch($e415416) {
if(R.isCont($e415416)) {
var $ss419420 = {"from":L[13],
"go":function(ann_DASH_check_DASH_temp73425) {
return $Hann_DASH_check_DASH_temp176426(ann_DASH_check_DASH_temp73425);
}};
$e415416.stack[R.EXN_STACKHEIGHT++] = $ss419420;
}
if(R.isPyretException($e415416)) {
$e415416.pyretStack.push(L[13]);
}
throw $e415416;
}
var $ret421422 = $Hann_DASH_check_DASH_temp176426($z417418);
++R.GAS;
return $ret421422;
};
var $Hann_DASH_check_DASH_temp176426 = function(ann_DASH_check_DASH_temp73425) {
return ann_DASH_check_DASH_temp73425;
};
var $Hcont_tail_arg174427 = function(cont_tail_arg70428,if_helper56429) {
if(--R.GAS > 0) {
$z430431 = R.isFunction(if_helper56429)?if_helper56429.app(cont_tail_arg70428):R.ffi.throwNonFunApp(L[13],if_helper56429,[cont_tail_arg70428]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper56429)?if_helper56429.app(cont_tail_arg70428):R.ffi.throwNonFunApp(L[13],if_helper56429,[cont_tail_arg70428]);
},
"from":L[13]});
}
++R.GAS;
return $z430431;
};
var $Hcont_tail_arg175432 = function(cont_tail_arg61433,if_helper56429) {
if(--R.GAS > 0) {
$z434435 = R.isFunction(if_helper56429)?if_helper56429.app(cont_tail_arg61433):R.ffi.throwNonFunApp(L[13],if_helper56429,[cont_tail_arg61433]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper56429)?if_helper56429.app(cont_tail_arg61433):R.ffi.throwNonFunApp(L[13],if_helper56429,[cont_tail_arg61433]);
},
"from":L[13]});
}
++R.GAS;
return $z434435;
};
var $Hann_DASH_check_DASH_temp173436 = function(ann_DASH_check_DASH_temp43437) {
return ann_DASH_check_DASH_temp43437;
};
var $Hann_DASH_check_DASH_temp172438 = function(ann_DASH_check_DASH_temp45439) {
return ann_DASH_check_DASH_temp45439;
};
var $Hand_DASH_oper_DASH_171440 = function(and_DASH_oper_DASH_7441,other74442,self73443) {
var if_helper30454 = R.makeFunction(function(if_helper_arg31480) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[14],1,arguments);
}
var ann_DASH_check_DASH_temp29481 = if_helper_arg31480;
return ann_DASH_check_DASH_temp29481;
});
var anf_if34479 = R.isBoolean(and_DASH_oper_DASH_7441);
if(R.isPyretTrue(anf_if34479)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7441)) {
var anf_arg36462 = G(other74442,"module-name",L[17]);
var anf_arg37463 = G(self73443,"module-name",L[16]);
var and_DASH_oper_DASH_8455 = R.equiv(anf_arg36462,anf_arg37463);
var anf_if40461 = R.isBoolean(and_DASH_oper_DASH_8455);
if(R.isPyretTrue(anf_if40461)) {
var $z446447 = D;
var $f452453 = function(_) {
return R.isFunction(if_helper30454)?if_helper30454.app(and_DASH_oper_DASH_8455):R.ffi.throwNonFunApp(L[14],if_helper30454,[and_DASH_oper_DASH_8455]);
};
try {
if(--R.GAS > 0) {
$z446447 = $f452453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f452453,
"from":L[14]});
}
} catch($e444445) {
if(R.isCont($e444445)) {
var $ss448449 = {"from":L[14],
"go":function(cont_tail_app41456) {
return $Hcont_tail_app169457(cont_tail_app41456);
}};
$e444445.stack[R.EXN_STACKHEIGHT++] = $ss448449;
}
if(R.isPyretException($e444445)) {
$e444445.pyretStack.push(L[14]);
}
throw $e444445;
}
var $ret450451 = $Hcont_tail_app169457($z446447);
++R.GAS;
return $ret450451;
} else {
var cont_tail_arg38460 = R.throwNonBooleanOp(L[15],("second"),("and"),and_DASH_oper_DASH_8455);
if(--R.GAS > 0) {
$z458459 = R.isFunction(if_helper30454)?if_helper30454.app(cont_tail_arg38460):R.ffi.throwNonFunApp(L[15],if_helper30454,[cont_tail_arg38460]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper30454)?if_helper30454.app(cont_tail_arg38460):R.ffi.throwNonFunApp(L[15],if_helper30454,[cont_tail_arg38460]);
},
"from":L[15]});
}
++R.GAS;
return $z458459;
}
} else {
var $z466467 = D;
var $f472473 = function(_) {
return R.isFunction(if_helper30454)?if_helper30454.app((false)):R.ffi.throwNonFunApp(L[14],if_helper30454,[(false)]);
};
try {
if(--R.GAS > 0) {
$z466467 = $f472473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f472473,
"from":L[14]});
}
} catch($e464465) {
if(R.isCont($e464465)) {
var $ss468469 = {"from":L[14],
"go":function(cont_tail_app35474) {
return $Hcont_tail_app170475(cont_tail_app35474);
}};
$e464465.stack[R.EXN_STACKHEIGHT++] = $ss468469;
}
if(R.isPyretException($e464465)) {
$e464465.pyretStack.push(L[14]);
}
throw $e464465;
}
var $ret470471 = $Hcont_tail_app170475($z466467);
++R.GAS;
return $ret470471;
}
} else {
var cont_tail_arg32478 = R.throwNonBooleanOp(L[18],("first"),("and"),and_DASH_oper_DASH_7441);
if(--R.GAS > 0) {
$z476477 = R.isFunction(if_helper30454)?if_helper30454.app(cont_tail_arg32478):R.ffi.throwNonFunApp(L[18],if_helper30454,[cont_tail_arg32478]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper30454)?if_helper30454.app(cont_tail_arg32478):R.ffi.throwNonFunApp(L[18],if_helper30454,[cont_tail_arg32478]);
},
"from":L[18]});
}
++R.GAS;
return $z476477;
}
};
var $Hcont_tail_app169457 = function(cont_tail_app41456) {
return cont_tail_app41456;
};
var $Hcont_tail_app170475 = function(cont_tail_app35474) {
return cont_tail_app35474;
};
var $Hanf_arg168482 = function(anf_arg27483,_plus4) {
var $z486487 = D;
var $f492493 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg27483,(">")):R.ffi.throwNonFunApp(L[19],_plus4,[anf_arg27483,(">")]);
};
try {
if(--R.GAS > 0) {
$z486487 = $f492493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f492493,
"from":L[19]});
}
} catch($e484485) {
if(R.isCont($e484485)) {
var $ss488489 = {"from":L[19],
"go":function(ann_DASH_check_DASH_temp25494) {
return $Hann_DASH_check_DASH_temp167495(ann_DASH_check_DASH_temp25494);
}};
$e484485.stack[R.EXN_STACKHEIGHT++] = $ss488489;
}
if(R.isPyretException($e484485)) {
$e484485.pyretStack.push(L[19]);
}
throw $e484485;
}
var $ret490491 = $Hann_DASH_check_DASH_temp167495($z486487);
++R.GAS;
return $ret490491;
};
var $Hann_DASH_check_DASH_temp167495 = function(ann_DASH_check_DASH_temp25494) {
return ann_DASH_check_DASH_temp25494;
};
var $Hanf_arg166496 = function(anf_arg21497,_plus4) {
var $z500501 = D;
var $f506507 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg21497,(")")):R.ffi.throwNonFunApp(L[20],_plus4,[anf_arg21497,(")")]);
};
try {
if(--R.GAS > 0) {
$z500501 = $f506507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f506507,
"from":L[20]});
}
} catch($e498499) {
if(R.isCont($e498499)) {
var $ss502503 = {"from":L[20],
"go":function(anf_arg22508) {
return $Hanf_arg165509(anf_arg22508,_plus4);
}};
$e498499.stack[R.EXN_STACKHEIGHT++] = $ss502503;
}
if(R.isPyretException($e498499)) {
$e498499.pyretStack.push(L[20]);
}
throw $e498499;
}
var $ret504505 = $Hanf_arg165509($z500501,_plus4);
++R.GAS;
return $ret504505;
};
var $Hanf_arg165509 = function(anf_arg22508,_plus4) {
var $z512513 = D;
var $f518519 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("("),anf_arg22508):R.ffi.throwNonFunApp(L[20],_plus4,[("("),anf_arg22508]);
};
try {
if(--R.GAS > 0) {
$z512513 = $f518519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f518519,
"from":L[20]});
}
} catch($e510511) {
if(R.isCont($e510511)) {
var $ss514515 = {"from":L[20],
"go":function(anf_arg23520) {
return $Hanf_arg164521(anf_arg23520,_plus4);
}};
$e510511.stack[R.EXN_STACKHEIGHT++] = $ss514515;
}
if(R.isPyretException($e510511)) {
$e510511.pyretStack.push(L[20]);
}
throw $e510511;
}
var $ret516517 = $Hanf_arg164521($z512513,_plus4);
++R.GAS;
return $ret516517;
};
var $Hanf_arg164521 = function(anf_arg23520,_plus4) {
var $z524525 = D;
var $f530531 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("builtin"),anf_arg23520):R.ffi.throwNonFunApp(L[20],_plus4,[("builtin"),anf_arg23520]);
};
try {
if(--R.GAS > 0) {
$z524525 = $f530531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f530531,
"from":L[20]});
}
} catch($e522523) {
if(R.isCont($e522523)) {
var $ss526527 = {"from":L[20],
"go":function(ann_DASH_check_DASH_temp19532) {
return $Hann_DASH_check_DASH_temp163533(ann_DASH_check_DASH_temp19532);
}};
$e522523.stack[R.EXN_STACKHEIGHT++] = $ss526527;
}
if(R.isPyretException($e522523)) {
$e522523.pyretStack.push(L[20]);
}
throw $e522523;
}
var $ret528529 = $Hann_DASH_check_DASH_temp163533($z524525);
++R.GAS;
return $ret528529;
};
var $Hann_DASH_check_DASH_temp163533 = function(ann_DASH_check_DASH_temp19532) {
return ann_DASH_check_DASH_temp19532;
};
var $Hcont_tail_arg161534 = function(cont_tail_arg16535,if_helper8536) {
if(--R.GAS > 0) {
$z537538 = R.isFunction(if_helper8536)?if_helper8536.app(cont_tail_arg16535):R.ffi.throwNonFunApp(L[20],if_helper8536,[cont_tail_arg16535]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper8536)?if_helper8536.app(cont_tail_arg16535):R.ffi.throwNonFunApp(L[20],if_helper8536,[cont_tail_arg16535]);
},
"from":L[20]});
}
++R.GAS;
return $z537538;
};
var $Hcont_tail_arg162539 = function(cont_tail_arg13540,if_helper8536) {
if(--R.GAS > 0) {
$z541542 = R.isFunction(if_helper8536)?if_helper8536.app(cont_tail_arg13540):R.ffi.throwNonFunApp(L[20],if_helper8536,[cont_tail_arg13540]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper8536)?if_helper8536.app(cont_tail_arg13540):R.ffi.throwNonFunApp(L[20],if_helper8536,[cont_tail_arg13540]);
},
"from":L[20]});
}
++R.GAS;
return $z541542;
};
var $Hann_DASH_check_DASH_temp160543 = function(ann_DASH_check_DASH_temp4544) {
return ann_DASH_check_DASH_temp4544;
};
var $Hann_DASH_check_DASH_temp159545 = function(ann_DASH_check_DASH_temp1546) {
return ann_DASH_check_DASH_temp1546;
};
return R.loadModulesNew(NAMESPACE,[$arrays11223,$lists31324,$option51425,$error71526,$sets91627],function($arrays11223,$lists31324,$option51425,$error71526,$sets91627) {
var arrays112 = R.getField($arrays11223,"values");
var lists313 = R.getField($lists31324,"values");
var option514 = R.getField($option51425,"values");
var error715 = R.getField($error71526,"values");
var sets916 = R.getField($sets91627,"values");
var arrays217 = R.getField($arrays11223,"types");
var lists418 = R.getField($lists31324,"types");
var option619 = R.getField($option51425,"types");
var error820 = R.getField($error71526,"types");
var sets1021 = R.getField($sets91627,"types");
return R.safeCall(function() {
var List11547 = R.getDotAnn(L[21],"lists",lists418,"List");
var Option12548 = R.getDotAnn(L[21],"option",option619,"Option");
var Array13549 = R.getDotAnn(L[21],"arrays",arrays217,"Array");
var Set14550 = R.getDotAnn(L[21],"sets",sets1021,"Set");
var array15930 = G(arrays112,"array",L[21]);
var build_DASH_array16929 = G(arrays112,"build-array",L[21]);
var array_DASH_from_DASH_list17928 = G(arrays112,"array-from-list",L[21]);
var is_DASH_array18927 = G(arrays112,"is-array",L[21]);
var list19926 = G(lists313,"list",L[21]);
var is_DASH_empty20925 = G(lists313,"is-empty",L[21]);
var is_DASH_link21924 = G(lists313,"is-link",L[21]);
var empty22923 = G(lists313,"empty",L[21]);
var link23922 = G(lists313,"link",L[21]);
var range24921 = G(lists313,"range",L[21]);
var repeat25920 = G(lists313,"repeat",L[21]);
var filter26919 = G(lists313,"filter",L[21]);
var partition27918 = G(lists313,"partition",L[21]);
var split_DASH_at28917 = G(lists313,"split-at",L[21]);
var any29916 = G(lists313,"any",L[21]);
var find30915 = G(lists313,"find",L[21]);
var map31914 = G(lists313,"map",L[21]);
var map232913 = G(lists313,"map2",L[21]);
var map333912 = G(lists313,"map3",L[21]);
var map434911 = G(lists313,"map4",L[21]);
var map_n35910 = G(lists313,"map_n",L[21]);
var map2_n36909 = G(lists313,"map2_n",L[21]);
var map3_n37908 = G(lists313,"map3_n",L[21]);
var map4_n38907 = G(lists313,"map4_n",L[21]);
var each39906 = G(lists313,"each",L[21]);
var each240905 = G(lists313,"each2",L[21]);
var each341904 = G(lists313,"each3",L[21]);
var each442903 = G(lists313,"each4",L[21]);
var each_n43902 = G(lists313,"each_n",L[21]);
var each2_n44901 = G(lists313,"each2_n",L[21]);
var each3_n45900 = G(lists313,"each3_n",L[21]);
var each4_n46899 = G(lists313,"each4_n",L[21]);
var fold47898 = G(lists313,"fold",L[21]);
var fold248897 = G(lists313,"fold2",L[21]);
var fold349896 = G(lists313,"fold3",L[21]);
var fold450895 = G(lists313,"fold4",L[21]);
var index51894 = G(lists313,"index",L[21]);
var Option52893 = G(option514,"Option",L[21]);
var is_DASH_none53892 = G(option514,"is-none",L[21]);
var is_DASH_some54891 = G(option514,"is-some",L[21]);
var none55890 = G(option514,"none",L[21]);
var some56889 = G(option514,"some",L[21]);
var set57888 = G(sets916,"set",L[21]);
var tree_DASH_set58887 = G(sets916,"tree-set",L[21]);
var list_DASH_set59886 = G(sets916,"list-set",L[21]);
var SrclocT161551 = R.namedBrander("Srcloc");
var Srcloc6030 = R.makeBranderAnn(SrclocT161551,"Srcloc");
var Srcloc262552 = {"$var":D,
"$name":"Srcloc2"};
var Srcloc63554 = {"$var":D,
"$name":"Srcloc"};
var is_DASH_Srcloc64556 = {"$var":D,
"$name":"is-Srcloc"};
var is_DASH_builtin65558 = {"$var":D,
"$name":"is-builtin"};
var builtin66560 = {"$var":D,
"$name":"builtin"};
var is_DASH_srcloc67562 = {"$var":D,
"$name":"is-srcloc"};
var srcloc68564 = {"$var":D,
"$name":"srcloc"};
var old_DASH_srcloc69566 = {"$var":D,
"$name":"old-srcloc"};
var anf_shared3596 = R.makeMethod(function(self99885) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[64],0,arguments);
}
var anf_fun2884 = G(self99885,"format",L[65]);
var $z876877 = D;
var $f882883 = function(_) {
return R.isFunction(anf_fun2884)?anf_fun2884.app((true)):R.ffi.throwNonFunApp(L[64],anf_fun2884,[(true)]);
};
try {
if(--R.GAS > 0) {
$z876877 = $f882883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f882883,
"from":L[64]});
}
} catch($e874875) {
if(R.isCont($e874875)) {
var $ss878879 = {"from":L[64],
"go":function(ann_DASH_check_DASH_temp1546) {
return $Hann_DASH_check_DASH_temp159545(ann_DASH_check_DASH_temp1546);
}};
$e874875.stack[R.EXN_STACKHEIGHT++] = $ss878879;
}
if(R.isPyretException($e874875)) {
$e874875.pyretStack.push(L[64]);
}
throw $e874875;
}
var $ret880881 = $Hann_DASH_check_DASH_temp159545($z876877);
++R.GAS;
return $ret880881;
};
},{"length":1});
var anf_shared6597 = R.makeMethod(function(self100872) {
return function(other101873) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[62],1,arguments);
}
var anf_fun5871 = G(other101873,"before",L[63]);
var $z863864 = D;
var $f869870 = function(_) {
return R.isFunction(anf_fun5871)?anf_fun5871.app(self100872):R.ffi.throwNonFunApp(L[62],anf_fun5871,[self100872]);
};
try {
if(--R.GAS > 0) {
$z863864 = $f869870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f869870,
"from":L[62]});
}
} catch($e861862) {
if(R.isCont($e861862)) {
var $ss865866 = {"from":L[62],
"go":function(ann_DASH_check_DASH_temp4544) {
return $Hann_DASH_check_DASH_temp160543(ann_DASH_check_DASH_temp4544);
}};
$e861862.stack[R.EXN_STACKHEIGHT++] = $ss865866;
}
if(R.isPyretException($e861862)) {
$e861862.pyretStack.push(L[62]);
}
throw $e861862;
}
var $ret867868 = $Hann_DASH_check_DASH_temp160543($z863864);
++R.GAS;
return $ret867868;
};
},{"length":2});
var anf_variant_member18603 = R.makeMethod(function(self2841) {
return function(cases_DASH_funs3842,else_DASH_clause4853) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[20],2,arguments);
}
var if_DASH_6854 = R.hasField(cases_DASH_funs3842,("builtin"));
var if_helper8536 = R.makeFunction(function(if_helper_arg9859) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[20],1,arguments);
}
var ann_DASH_check_DASH_temp7860 = if_helper_arg9859;
return ann_DASH_check_DASH_temp7860;
});
var anf_if12858 = R.isBoolean(if_DASH_6854);
if(R.isPyretTrue(anf_if12858)) {
if(R.isPyretTrue(if_DASH_6854)) {
var call_DASH_builtin1839 = G(cases_DASH_funs3842,"builtin",L[20]);
var anf_arg15840 = G(self2841,"module-name",L[61]);
var $z831832 = D;
var $f837838 = function(_) {
return R.isFunction(call_DASH_builtin1839)?call_DASH_builtin1839.app(anf_arg15840):R.ffi.throwNonFunApp(L[20],call_DASH_builtin1839,[anf_arg15840]);
};
try {
if(--R.GAS > 0) {
$z831832 = $f837838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f837838,
"from":L[20]});
}
} catch($e829830) {
if(R.isCont($e829830)) {
var $ss833834 = {"from":L[20],
"go":function(cont_tail_arg16535) {
return $Hcont_tail_arg161534(cont_tail_arg16535,if_helper8536);
}};
$e829830.stack[R.EXN_STACKHEIGHT++] = $ss833834;
}
if(R.isPyretException($e829830)) {
$e829830.pyretStack.push(L[20]);
}
throw $e829830;
}
var $ret835836 = $Hcont_tail_arg161534($z831832,if_helper8536);
++R.GAS;
return $ret835836;
} else {
var $z845846 = D;
var $f851852 = function(_) {
return R.isFunction(else_DASH_clause4853)?else_DASH_clause4853.app():R.ffi.throwNonFunApp(L[20],else_DASH_clause4853,[]);
};
try {
if(--R.GAS > 0) {
$z845846 = $f851852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f851852,
"from":L[20]});
}
} catch($e843844) {
if(R.isCont($e843844)) {
var $ss847848 = {"from":L[20],
"go":function(cont_tail_arg13540) {
return $Hcont_tail_arg162539(cont_tail_arg13540,if_helper8536);
}};
$e843844.stack[R.EXN_STACKHEIGHT++] = $ss847848;
}
if(R.isPyretException($e843844)) {
$e843844.pyretStack.push(L[20]);
}
throw $e843844;
}
var $ret849850 = $Hcont_tail_arg162539($z845846,if_helper8536);
++R.GAS;
return $ret849850;
}
} else {
var cont_tail_arg10857 = R.throwNonBooleanCondition(L[20],("if"),if_DASH_6854);
if(--R.GAS > 0) {
$z855856 = R.isFunction(if_helper8536)?if_helper8536.app(cont_tail_arg10857):R.ffi.throwNonFunApp(L[20],if_helper8536,[cont_tail_arg10857]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper8536)?if_helper8536.app(cont_tail_arg10857):R.ffi.throwNonFunApp(L[20],if_helper8536,[cont_tail_arg10857]);
},
"from":L[20]});
}
++R.GAS;
return $z855856;
}
};
},{"length":3});
var anf_variant_member24604 = R.makeMethod(function(self5828) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[20],0,arguments);
}
var anf_arg20827 = G(self5828,"module-name",L[20]);
var $z819820 = D;
var $f825826 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg20827):R.ffi.throwNonFunApp(L[20],torepr8,[anf_arg20827]);
};
try {
if(--R.GAS > 0) {
$z819820 = $f825826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f825826,
"from":L[20]});
}
} catch($e817818) {
if(R.isCont($e817818)) {
var $ss821822 = {"from":L[20],
"go":function(anf_arg21497) {
return $Hanf_arg166496(anf_arg21497,_plus4);
}};
$e817818.stack[R.EXN_STACKHEIGHT++] = $ss821822;
}
if(R.isPyretException($e817818)) {
$e817818.pyretStack.push(L[20]);
}
throw $e817818;
}
var $ret823824 = $Hanf_arg166496($z819820,_plus4);
++R.GAS;
return $ret823824;
};
},{"length":1});
var anf_variant_member28605 = R.makeMethod(function(self71815) {
return function($underscore72816) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[19],1,arguments);
}
var anf_arg26814 = G(self71815,"module-name",L[60]);
var $z806807 = D;
var $f812813 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("<builtin "),anf_arg26814):R.ffi.throwNonFunApp(L[59],_plus4,[("<builtin "),anf_arg26814]);
};
try {
if(--R.GAS > 0) {
$z806807 = $f812813();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f812813,
"from":L[59]});
}
} catch($e804805) {
if(R.isCont($e804805)) {
var $ss808809 = {"from":L[59],
"go":function(anf_arg27483) {
return $Hanf_arg168482(anf_arg27483,_plus4);
}};
$e804805.stack[R.EXN_STACKHEIGHT++] = $ss808809;
}
if(R.isPyretException($e804805)) {
$e804805.pyretStack.push(L[59]);
}
throw $e804805;
}
var $ret810811 = $Hanf_arg168482($z806807,_plus4);
++R.GAS;
return $ret810811;
};
},{"length":2});
var anf_variant_member42606 = R.makeMethod(function(self73443) {
return function(other74442) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[58],1,arguments);
}
var $z796797 = D;
var $f802803 = function(_) {
return R.isFunction(is_DASH_builtin65558.$var === D?U(L[57],"is-builtin"):is_DASH_builtin65558.$var)?is_DASH_builtin65558.$var === D?U(L[57],"is-builtin"):is_DASH_builtin65558.$var.app(other74442):R.ffi.throwNonFunApp(L[14],is_DASH_builtin65558.$var === D?U(L[57],"is-builtin"):is_DASH_builtin65558.$var,[other74442]);
};
try {
if(--R.GAS > 0) {
$z796797 = $f802803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f802803,
"from":L[14]});
}
} catch($e794795) {
if(R.isCont($e794795)) {
var $ss798799 = {"from":L[14],
"go":function(and_DASH_oper_DASH_7441) {
return $Hand_DASH_oper_DASH_171440(and_DASH_oper_DASH_7441,other74442,self73443);
}};
$e794795.stack[R.EXN_STACKHEIGHT++] = $ss798799;
}
if(R.isPyretException($e794795)) {
$e794795.pyretStack.push(L[14]);
}
throw $e794795;
}
var $ret800801 = $Hand_DASH_oper_DASH_171440($z796797,other74442,self73443);
++R.GAS;
return $ret800801;
};
},{"length":2});
var anf_variant_member54607 = R.makeMethod(function(self75792) {
return function(other76791) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[51],1,arguments);
}
var cases_DASH_val9793 = other76791;
var anf_fun44764 = G(cases_DASH_val9793,"_match",L[52]);
var anf_obj48768 = R.makeFunction(function(module_DASH_name77778) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[54],1,arguments);
}
var anf_arg46789 = G(self75792,"module-name",L[56]);
var anf_arg47790 = G(other76791,"module-name",L[55]);
var $z781782 = D;
var $f787788 = function(_) {
return R.isFunction(_lessthan3)?_lessthan3.app(anf_arg46789,anf_arg47790):R.ffi.throwNonFunApp(L[54],_lessthan3,[anf_arg46789,anf_arg47790]);
};
try {
if(--R.GAS > 0) {
$z781782 = $f787788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f787788,
"from":L[54]});
}
} catch($e779780) {
if(R.isCont($e779780)) {
var $ss783784 = {"from":L[54],
"go":function(ann_DASH_check_DASH_temp45439) {
return $Hann_DASH_check_DASH_temp172438(ann_DASH_check_DASH_temp45439);
}};
$e779780.stack[R.EXN_STACKHEIGHT++] = $ss783784;
}
if(R.isPyretException($e779780)) {
$e779780.pyretStack.push(L[54]);
}
throw $e779780;
}
var $ret785786 = $Hann_DASH_check_DASH_temp172438($z781782);
++R.GAS;
return $ret785786;
});
var anf_obj50769 = R.makeFunction(function($underscore78770,$underscore79771,$underscore80772,$underscore81773,$underscore82774,$underscore83775,$underscore84776) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[53],7,arguments);
}
var ann_DASH_check_DASH_temp49777 = (false);
return ann_DASH_check_DASH_temp49777;
});
var anf_arg51765 = R.makeObject({"builtin":anf_obj48768,
"srcloc":anf_obj50769});
var anf_arg53766 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[52],0,arguments);
}
var ann_DASH_check_DASH_temp52767 = R.throwNoBranchesMatched(L[52],("cases"));
return ann_DASH_check_DASH_temp52767;
});
var $z756757 = D;
var $f762763 = function(_) {
return R.isFunction(anf_fun44764)?anf_fun44764.app(anf_arg51765,anf_arg53766):R.ffi.throwNonFunApp(L[51],anf_fun44764,[anf_arg51765,anf_arg53766]);
};
try {
if(--R.GAS > 0) {
$z756757 = $f762763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f762763,
"from":L[51]});
}
} catch($e754755) {
if(R.isCont($e754755)) {
var $ss758759 = {"from":L[51],
"go":function(ann_DASH_check_DASH_temp43437) {
return $Hann_DASH_check_DASH_temp173436(ann_DASH_check_DASH_temp43437);
}};
$e754755.stack[R.EXN_STACKHEIGHT++] = $ss758759;
}
if(R.isPyretException($e754755)) {
$e754755.pyretStack.push(L[51]);
}
throw $e754755;
}
var $ret760761 = $Hann_DASH_check_DASH_temp173436($z756757);
++R.GAS;
return $ret760761;
};
},{"length":2});
var anf_variant_member72614 = R.makeMethod(function(self11734) {
return function(cases_DASH_funs12735,else_DASH_clause13746) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[13],2,arguments);
}
var if_DASH_15747 = R.hasField(cases_DASH_funs12735,("srcloc"));
var if_helper56429 = R.makeFunction(function(if_helper_arg57752) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[13],1,arguments);
}
var ann_DASH_check_DASH_temp55753 = if_helper_arg57752;
return ann_DASH_check_DASH_temp55753;
});
var anf_if60751 = R.isBoolean(if_DASH_15747);
if(R.isPyretTrue(anf_if60751)) {
if(R.isPyretTrue(if_DASH_15747)) {
var call_DASH_srcloc10726 = G(cases_DASH_funs12735,"srcloc",L[13]);
var anf_arg63727 = G(self11734,"source",L[50]);
var anf_arg64728 = G(self11734,"start-line",L[49]);
var anf_arg65729 = G(self11734,"start-column",L[48]);
var anf_arg66730 = G(self11734,"start-char",L[47]);
var anf_arg67731 = G(self11734,"end-line",L[46]);
var anf_arg68732 = G(self11734,"end-column",L[45]);
var anf_arg69733 = G(self11734,"end-char",L[44]);
var $z718719 = D;
var $f724725 = function(_) {
return R.isFunction(call_DASH_srcloc10726)?call_DASH_srcloc10726.app(anf_arg63727,anf_arg64728,anf_arg65729,anf_arg66730,anf_arg67731,anf_arg68732,anf_arg69733):R.ffi.throwNonFunApp(L[13],call_DASH_srcloc10726,[anf_arg63727,anf_arg64728,anf_arg65729,anf_arg66730,anf_arg67731,anf_arg68732,anf_arg69733]);
};
try {
if(--R.GAS > 0) {
$z718719 = $f724725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f724725,
"from":L[13]});
}
} catch($e716717) {
if(R.isCont($e716717)) {
var $ss720721 = {"from":L[13],
"go":function(cont_tail_arg70428) {
return $Hcont_tail_arg174427(cont_tail_arg70428,if_helper56429);
}};
$e716717.stack[R.EXN_STACKHEIGHT++] = $ss720721;
}
if(R.isPyretException($e716717)) {
$e716717.pyretStack.push(L[13]);
}
throw $e716717;
}
var $ret722723 = $Hcont_tail_arg174427($z718719,if_helper56429);
++R.GAS;
return $ret722723;
} else {
var $z738739 = D;
var $f744745 = function(_) {
return R.isFunction(else_DASH_clause13746)?else_DASH_clause13746.app():R.ffi.throwNonFunApp(L[13],else_DASH_clause13746,[]);
};
try {
if(--R.GAS > 0) {
$z738739 = $f744745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f744745,
"from":L[13]});
}
} catch($e736737) {
if(R.isCont($e736737)) {
var $ss740741 = {"from":L[13],
"go":function(cont_tail_arg61433) {
return $Hcont_tail_arg175432(cont_tail_arg61433,if_helper56429);
}};
$e736737.stack[R.EXN_STACKHEIGHT++] = $ss740741;
}
if(R.isPyretException($e736737)) {
$e736737.pyretStack.push(L[13]);
}
throw $e736737;
}
var $ret742743 = $Hcont_tail_arg175432($z738739,if_helper56429);
++R.GAS;
return $ret742743;
}
} else {
var cont_tail_arg58750 = R.throwNonBooleanCondition(L[13],("if"),if_DASH_15747);
if(--R.GAS > 0) {
$z748749 = R.isFunction(if_helper56429)?if_helper56429.app(cont_tail_arg58750):R.ffi.throwNonFunApp(L[13],if_helper56429,[cont_tail_arg58750]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper56429)?if_helper56429.app(cont_tail_arg58750):R.ffi.throwNonFunApp(L[13],if_helper56429,[cont_tail_arg58750]);
},
"from":L[13]});
}
++R.GAS;
return $z748749;
}
};
},{"length":3});
var anf_variant_member102615 = R.makeMethod(function(self14168) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[13],0,arguments);
}
var anf_arg74715 = G(self14168,"source",L[13]);
var $z707708 = D;
var $f713714 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg74715):R.ffi.throwNonFunApp(L[13],torepr8,[anf_arg74715]);
};
try {
if(--R.GAS > 0) {
$z707708 = $f713714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f713714,
"from":L[13]});
}
} catch($e705706) {
if(R.isCont($e705706)) {
var $ss709710 = {"from":L[13],
"go":function(anf_arg75167) {
return $Hanf_arg197166(anf_arg75167,self14168,_plus4,torepr8);
}};
$e705706.stack[R.EXN_STACKHEIGHT++] = $ss709710;
}
if(R.isPyretException($e705706)) {
$e705706.pyretStack.push(L[13]);
}
throw $e705706;
}
var $ret711712 = $Hanf_arg197166($z707708,self14168,_plus4,torepr8);
++R.GAS;
return $ret711712;
};
},{"length":1});
var anf_variant_member120616 = R.makeMethod(function(self92103) {
return function(show_DASH_file93704) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[12],1,arguments);
}
var if_DASH_16688 = show_DASH_file93704;
var if_helper10496 = R.makeFunction(function(if_helper_arg105693) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[43],1,arguments);
}
var $z696697 = D;
var $f702703 = function(_) {
return R.isFunction(_plus4)?_plus4.app(if_helper_arg105693,("line ")):R.ffi.throwNonFunApp(L[9],_plus4,[if_helper_arg105693,("line ")]);
};
try {
if(--R.GAS > 0) {
$z696697 = $f702703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f702703,
"from":L[9]});
}
} catch($e694695) {
if(R.isCont($e694695)) {
var $ss698699 = {"from":L[9],
"go":function(anf_arg106102) {
return $Hanf_arg203101(anf_arg106102,self92103,_plus4,tostring9);
}};
$e694695.stack[R.EXN_STACKHEIGHT++] = $ss698699;
}
if(R.isPyretException($e694695)) {
$e694695.pyretStack.push(L[9]);
}
throw $e694695;
}
var $ret700701 = $Hanf_arg203101($z696697,self92103,_plus4,tostring9);
++R.GAS;
return $ret700701;
});
var anf_if115692 = R.isBoolean(if_DASH_16688);
if(R.isPyretTrue(anf_if115692)) {
if(R.isPyretTrue(if_DASH_16688)) {
var anf_arg117677 = G(self92103,"source",L[41]);
var $z669670 = D;
var $f675676 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg117677,(": ")):R.ffi.throwNonFunApp(L[6],_plus4,[anf_arg117677,(": ")]);
};
try {
if(--R.GAS > 0) {
$z669670 = $f675676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f675676,
"from":L[6]});
}
} catch($e667668) {
if(R.isCont($e667668)) {
var $ss671672 = {"from":L[6],
"go":function(cont_tail_arg11895) {
return $Hcont_tail_arg20494(cont_tail_arg11895,if_helper10496);
}};
$e667668.stack[R.EXN_STACKHEIGHT++] = $ss671672;
}
if(R.isPyretException($e667668)) {
$e667668.pyretStack.push(L[6]);
}
throw $e667668;
}
var $ret673674 = $Hcont_tail_arg20494($z669670,if_helper10496);
++R.GAS;
return $ret673674;
} else {
var $z680681 = D;
var $f686687 = function(_) {
return R.isFunction(if_helper10496)?if_helper10496.app(("")):R.ffi.throwNonFunApp(L[42],if_helper10496,[("")]);
};
try {
if(--R.GAS > 0) {
$z680681 = $f686687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f686687,
"from":L[42]});
}
} catch($e678679) {
if(R.isCont($e678679)) {
var $ss682683 = {"from":L[42],
"go":function(cont_tail_app116100) {
return $Hcont_tail_app20599(cont_tail_app116100);
}};
$e678679.stack[R.EXN_STACKHEIGHT++] = $ss682683;
}
if(R.isPyretException($e678679)) {
$e678679.pyretStack.push(L[42]);
}
throw $e678679;
}
var $ret684685 = $Hcont_tail_app20599($z680681);
++R.GAS;
return $ret684685;
}
} else {
var cont_tail_arg113691 = R.throwNonBooleanCondition(L[43],("if"),if_DASH_16688);
if(--R.GAS > 0) {
$z689690 = R.isFunction(if_helper10496)?if_helper10496.app(cont_tail_arg113691):R.ffi.throwNonFunApp(L[43],if_helper10496,[cont_tail_arg113691]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored72) {
return R.isFunction(if_helper10496)?if_helper10496.app(cont_tail_arg113691):R.ffi.throwNonFunApp(L[43],if_helper10496,[cont_tail_arg113691]);
},
"from":L[43]});
}
++R.GAS;
return $z689690;
}
};
},{"length":2});
var anf_variant_member134617 = R.makeMethod(function(self9454) {
return function(other9553) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[40],1,arguments);
}
return R.checkAnnArgs([Srcloc6030],[other9553],[L[39]],function() {
var $z659660 = D;
var $f665666 = function(_) {
return R.isFunction(is_DASH_srcloc67562.$var === D?U(L[38],"is-srcloc"):is_DASH_srcloc67562.$var)?is_DASH_srcloc67562.$var === D?U(L[38],"is-srcloc"):is_DASH_srcloc67562.$var.app(other9553):R.ffi.throwNonFunApp(L[1],is_DASH_srcloc67562.$var === D?U(L[38],"is-srcloc"):is_DASH_srcloc67562.$var,[other9553]);
};
try {
if(--R.GAS > 0) {
$z659660 = $f665666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f665666,
"from":L[1]});
}
} catch($e657658) {
if(R.isCont($e657658)) {
var $ss661662 = {"from":L[1],
"go":function(and_DASH_oper_DASH_1752) {
return $Hand_DASH_oper_DASH_20851(and_DASH_oper_DASH_1752,other9553,self9454);
}};
$e657658.stack[R.EXN_STACKHEIGHT++] = $ss661662;
}
if(R.isPyretException($e657658)) {
$e657658.pyretStack.push(L[1]);
}
throw $e657658;
}
var $ret663664 = $Hand_DASH_oper_DASH_20851($z659660,other9553,self9454);
++R.GAS;
return $ret663664;
});
};
},{"length":2});
var anf_variant_member144618 = R.makeMethod(function(self96652) {
return function(other97651) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[32],1,arguments);
}
return R.checkAnnArgs([Srcloc6030],[other97651],[L[37]],function() {
var cases_DASH_val19656 = other97651;
var anf_fun136636 = G(cases_DASH_val19656,"_match",L[33]);
var anf_obj138653 = R.makeFunction(function($underscore98654) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[36],1,arguments);
}
var ann_DASH_check_DASH_temp137655 = (true);
return ann_DASH_check_DASH_temp137655;
});
var anf_arg139637 = R.makeObject({"builtin":anf_obj138653});
var anf_arg143638 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[33],0,arguments);
}
var anf_arg141649 = G(self96652,"start-char",L[35]);
var anf_arg142650 = G(other97651,"start-char",L[34]);
var $z641642 = D;
var $f647648 = function(_) {
return R.isFunction(_lessthan3)?_lessthan3.app(anf_arg141649,anf_arg142650):R.ffi.throwNonFunApp(L[33],_lessthan3,[anf_arg141649,anf_arg142650]);
};
try {
if(--R.GAS > 0) {
$z641642 = $f647648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f647648,
"from":L[33]});
}
} catch($e639640) {
if(R.isCont($e639640)) {
var $ss643644 = {"from":L[33],
"go":function(ann_DASH_check_DASH_temp14050) {
return $Hann_DASH_check_DASH_temp20949(ann_DASH_check_DASH_temp14050);
}};
$e639640.stack[R.EXN_STACKHEIGHT++] = $ss643644;
}
if(R.isPyretException($e639640)) {
$e639640.pyretStack.push(L[33]);
}
throw $e639640;
}
var $ret645646 = $Hann_DASH_check_DASH_temp20949($z641642);
++R.GAS;
return $ret645646;
});
var $z628629 = D;
var $f634635 = function(_) {
return R.isFunction(anf_fun136636)?anf_fun136636.app(anf_arg139637,anf_arg143638):R.ffi.throwNonFunApp(L[32],anf_fun136636,[anf_arg139637,anf_arg143638]);
};
try {
if(--R.GAS > 0) {
$z628629 = $f634635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f634635,
"from":L[32]});
}
} catch($e626627) {
if(R.isCont($e626627)) {
var $ss630631 = {"from":L[32],
"go":function(ann_DASH_check_DASH_temp13548) {
return $Hann_DASH_check_DASH_temp21047(ann_DASH_check_DASH_temp13548);
}};
$e626627.stack[R.EXN_STACKHEIGHT++] = $ss630631;
}
if(R.isPyretException($e626627)) {
$e626627.pyretStack.push(L[32]);
}
throw $e626627;
}
var $ret632633 = $Hann_DASH_check_DASH_temp21047($z628629);
++R.GAS;
return $ret632633;
});
};
},{"length":2});
var anf_assign145553 = (function() {
var $builtin_DASH_base598599 = {"tostring":anf_shared3596,
"after":anf_shared6597,
"_match":anf_variant_member18603,
"_torepr":anf_variant_member24604,
"format":anf_variant_member28605,
"same-file":anf_variant_member42606,
"before":anf_variant_member54607};
var $builtin_DASH_brands601602 = {"$brand-builtin600":true};
$builtin_DASH_brands601602[SrclocT161551._brand] = true
var $srcloc_DASH_base609610 = {"tostring":anf_shared3596,
"after":anf_shared6597,
"_match":anf_variant_member72614,
"_torepr":anf_variant_member102615,
"format":anf_variant_member120616,
"same-file":anf_variant_member134617,
"before":anf_variant_member144618};
var $srcloc_DASH_brands612613 = {"$brand-srcloc611":true};
$srcloc_DASH_brands612613[SrclocT161551._brand] = true
return R.makeObject({"Srcloc":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,SrclocT161551._brand));
}),
"is-builtin":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[20],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-builtin600"));
}),
"builtin":R.makeFunction(function(module_DASH_name70608) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
var dict = R.create($builtin_DASH_base598599);
dict["module-name"] = module_DASH_name70608
return R.makeBrandedObject(dict,$builtin_DASH_brands601602);
}),
"is-srcloc":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[13],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-srcloc611"));
}),
"srcloc":R.makeFunction(function(source85619,start_DASH_line86620,start_DASH_column87621,start_DASH_char88622,end_DASH_line89623,end_DASH_column90624,end_DASH_char91625) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[24],7,arguments);
}
return R.checkAnnArgs([$type$String11,$type$Number10,$type$Number10,$type$Number10,$type$Number10,$type$Number10,$type$Number10],[source85619,start_DASH_line86620,start_DASH_column87621,start_DASH_char88622,end_DASH_line89623,end_DASH_column90624,end_DASH_char91625],[L[25],L[26],L[27],L[28],L[29],L[30],L[31]],function() {
var dict = R.create($srcloc_DASH_base609610);
dict["source"] = source85619
dict["start-line"] = start_DASH_line86620
dict["start-column"] = start_DASH_column87621
dict["start-char"] = start_DASH_char88622
dict["end-line"] = end_DASH_line89623
dict["end-column"] = end_DASH_column90624
dict["end-char"] = end_DASH_char91625
return R.makeBrandedObject(dict,$srcloc_DASH_brands612613);
});
})});
})();
Srcloc262552.$var = anf_assign145553;
var anf_assign146555 = G(Srcloc262552.$var,"Srcloc",L[0]);
Srcloc63554.$var = anf_assign146555;
var anf_assign147557 = G(Srcloc262552.$var,"Srcloc",L[0]);
is_DASH_Srcloc64556.$var = anf_assign147557;
var anf_assign148559 = G(Srcloc262552.$var,"is-builtin",L[20]);
is_DASH_builtin65558.$var = anf_assign148559;
var anf_assign149561 = G(Srcloc262552.$var,"builtin",L[20]);
builtin66560.$var = anf_assign149561;
var anf_assign150563 = G(Srcloc262552.$var,"is-srcloc",L[13]);
is_DASH_srcloc67562.$var = anf_assign150563;
var anf_assign151565 = G(Srcloc262552.$var,"srcloc",L[13]);
srcloc68564.$var = anf_assign151565;
var anf_assign153567 = R.makeFunction(function(file102579,startR103580,startC104581,startCh105582,endR106583,endC107584,endCh108585) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[22],7,arguments);
}
var $z588589 = D;
var $f594595 = function(_) {
return R.isFunction(raise7)?raise7.app(("Cannot create old-srclocs anymore")):R.ffi.throwNonFunApp(L[22],raise7,[("Cannot create old-srclocs anymore")]);
};
try {
if(--R.GAS > 0) {
$z588589 = $f594595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f594595,
"from":L[22]});
}
} catch($e586587) {
if(R.isCont($e586587)) {
var $ss590591 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp15246) {
return $Hann_DASH_check_DASH_temp21145(ann_DASH_check_DASH_temp15246);
}};
$e586587.stack[R.EXN_STACKHEIGHT++] = $ss590591;
}
if(R.isPyretException($e586587)) {
$e586587.pyretStack.push(L[22]);
}
throw $e586587;
}
var $ret592593 = $Hann_DASH_check_DASH_temp21145($z588589);
++R.GAS;
return $ret592593;
});
old_DASH_srcloc69566.$var = anf_assign153567;
var provides15431 = R.makeObject({"Srcloc":Srcloc63554.$var,
"is-Srcloc":is_DASH_Srcloc64556.$var,
"builtin":builtin66560.$var,
"is-builtin":is_DASH_builtin65558.$var,
"srcloc":srcloc68564.$var,
"is-srcloc":is_DASH_srcloc67562.$var,
"old-srcloc":old_DASH_srcloc69566.$var});
var anf_fun155578 = G(builtins5,"current-checker",L[0]);
var $z570571 = D;
var $f576577 = function(_) {
return R.isFunction(anf_fun155578)?anf_fun155578.app():R.ffi.throwNonFunApp(L[0],anf_fun155578,[]);
};
try {
if(--R.GAS > 0) {
$z570571 = $f576577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f576577,
"from":L[0]});
}
} catch($e568569) {
if(R.isCont($e568569)) {
var $ss572573 = {"from":L[0],
"go":function(anf_bracket15629) {
return $Hanf_bracket21328(anf_bracket15629,Srcloc6030,provides15431,nothing6);
}};
$e568569.stack[R.EXN_STACKHEIGHT++] = $ss572573;
}
if(R.isPyretException($e568569)) {
$e568569.pyretStack.push(L[0]);
}
throw $e568569;
}
var $ret574575 = $Hanf_bracket21328($z570571,Srcloc6030,provides15431,nothing6);
++R.GAS;
return $ret574575;
},function(moduleVal) {
R.modules["$src/arr/trove/srcloc.arr22"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/contracts',["trove/lists"],function($L11316) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/base/contracts.arr15"]) {
return R.modules["$src/arr/base/contracts.arr15"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/base/contracts.arr";
var D = R.undefined;
var L = [[M,7,0,62,19,3,423],
[M,48,6,1393,48,77,1464],
[M,47,4,1371,49,7,1472],
[M,48,68,1455,48,77,1464],
[M,46,2,1326,49,7,1472],
[M,43,6,1180,44,58,1315],
[M,44,8,1265,44,41,1298],
[M,44,8,1265,44,31,1288],
[M,44,8,1265,44,27,1284],
[M,44,8,1265,44,58,1315],
[M,44,8,1265,44,50,1307],
[M,42,4,1158,45,7,1323],
[M,41,2,1082,45,7,1323],
[M,39,6,1001,39,76,1071],
[M,39,60,1055,39,76,1071],
[M,39,67,1062,39,75,1070],
[M,38,4,979,40,7,1079],
[M,37,2,933,40,7,1079],
[M,35,6,865,35,63,922],
[M,35,47,906,35,63,922],
[M,35,54,913,35,62,921],
[M,34,4,843,36,7,930],
[M,33,2,796,36,7,930],
[M,28,6,686,28,80,760],
[M,28,59,739,28,80,760],
[M,28,59,739,28,74,754],
[M,28,59,739,28,67,747],
[M,27,4,664,29,7,768],
[M,26,2,626,29,7,768],
[M,24,6,514,24,107,615],
[M,24,51,559,24,61,569],
[M,24,86,594,24,107,615],
[M,24,95,603,24,106,614],
[M,23,4,492,25,7,623],
[M,22,2,446,25,7,623],
[M,16,6,328,17,31,411],
[M,17,10,390,17,31,411],
[M,17,19,399,17,30,410],
[M,15,4,306,18,7,419],
[M,14,2,255,18,7,419],
[M,11,6,161,12,31,244],
[M,12,10,223,12,31,244],
[M,12,19,232,12,30,243],
[M,10,4,139,13,7,252],
[M,9,2,92,13,7,252],
[M,8,2,85,8,6,89],
[M,32,0,774,50,3,1476],
[M,33,4,798,33,38,832],
[M,33,31,825,33,37,831],
[M,37,4,935,37,37,968],
[M,41,4,1084,41,67,1147],
[M,41,46,1126,41,52,1132],
[M,41,46,1126,41,66,1146],
[M,46,4,1328,46,36,1360],
[M,48,46,1433,48,56,1443],
[M,46,30,1354,46,35,1359],
[M,46,24,1348,46,28,1352],
[M,43,46,1220,43,62,1236],
[M,43,53,1227,43,61,1235],
[M,41,28,1108,41,66,1146],
[M,41,23,1103,41,26,1106],
[M,39,21,1016,39,35,1030],
[M,37,27,958,37,36,967],
[M,37,22,953,37,25,956],
[M,35,20,879,35,29,888],
[M,33,23,817,33,37,831],
[M,33,18,812,33,21,815],
[M,21,0,425,30,3,772],
[M,22,4,448,22,37,481],
[M,26,4,628,26,29,653],
[M,28,25,705,28,35,715],
[M,26,23,647,26,28,652],
[M,26,18,642,26,21,645],
[M,24,14,522,24,35,543],
[M,24,14,522,24,29,537],
[M,24,14,522,24,22,530],
[M,22,30,474,22,36,480],
[M,22,23,467,22,28,472],
[M,22,18,462,22,21,465],
[M,9,4,94,9,38,128],
[M,9,24,114,9,37,127],
[M,14,4,257,14,42,295],
[M,14,28,281,14,41,294],
[M,16,29,351,16,50,372],
[M,16,29,351,16,44,366],
[M,16,29,351,16,37,359],
[M,14,18,271,14,41,294],
[M,14,13,266,14,16,269],
[M,11,29,184,11,50,205],
[M,11,29,184,11,44,199],
[M,11,29,184,11,37,192],
[M,9,14,104,9,37,127],
[M,9,9,99,9,12,102]];
var _plus7 = NAMESPACE.get("_plus");
var builtins8 = NAMESPACE.get("builtins");
var nothing9 = NAMESPACE.get("nothing");
var torepr10 = NAMESPACE.get("torepr");
var tostring11 = NAMESPACE.get("tostring");
var $type$String12 = NAMESPACE.get("$type$String");
var $Hanf_bracket42017 = function(anf_bracket30118,ContractResult319,FailureReason720,FieldFailure521,provides29922,nothing9) {
var anf_fun30233 = G(anf_bracket30118,"results",L[0]);
var $z2526 = D;
var $f3132 = function(_) {
return R.isFunction(anf_fun30233)?anf_fun30233.app():R.ffi.throwNonFunApp(L[0],anf_fun30233,[]);
};
try {
if(--R.GAS > 0) {
$z2526 = $f3132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3132,
"from":L[0]});
}
} catch($e2324) {
if(R.isCont($e2324)) {
var $ss2728 = {"from":L[0],
"go":function(checks30334) {
return $Hchecks41935(checks30334,ContractResult319,FailureReason720,FieldFailure521,provides29922,nothing9);
}};
$e2324.stack[R.EXN_STACKHEIGHT++] = $ss2728;
}
if(R.isPyretException($e2324)) {
$e2324.pyretStack.push(L[0]);
}
throw $e2324;
}
var $ret2930 = $Hchecks41935($z2526,ContractResult319,FailureReason720,FieldFailure521,provides29922,nothing9);
++R.GAS;
return $ret2930;
};
var $Hchecks41935 = function(checks30334,ContractResult319,FailureReason720,FieldFailure521,provides29922,nothing9) {
return R.makeObject({"answer":nothing9,
"provide-plus-types":R.makeObject({"values":provides29922,
"types":{"ContractResult":ContractResult319,
"FieldFailure":FieldFailure521,
"FailureReason":FailureReason720}}),
"checks":checks30334});
};
var $Hanf_arg41836 = function(anf_arg28437,self6038,_plus7) {
var $z4142 = D;
var $f4748 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg28437,(" on ")):R.ffi.throwNonFunApp(L[1],_plus7,[anf_arg28437,(" on ")]);
};
try {
if(--R.GAS > 0) {
$z4142 = $f4748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4748,
"from":L[1]});
}
} catch($e3940) {
if(R.isCont($e3940)) {
var $ss4344 = {"from":L[1],
"go":function(anf_arg28549) {
return $Hanf_arg41750(anf_arg28549,self6038,_plus7);
}};
$e3940.stack[R.EXN_STACKHEIGHT++] = $ss4344;
}
if(R.isPyretException($e3940)) {
$e3940.pyretStack.push(L[1]);
}
throw $e3940;
}
var $ret4546 = $Hanf_arg41750($z4142,self6038,_plus7);
++R.GAS;
return $ret4546;
};
var $Hanf_arg41750 = function(anf_arg28549,self6038,_plus7) {
var anf_arg28661 = G(self6038,"name",L[3]);
var $z5354 = D;
var $f5960 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg28549,anf_arg28661):R.ffi.throwNonFunApp(L[2],_plus7,[anf_arg28549,anf_arg28661]);
};
try {
if(--R.GAS > 0) {
$z5354 = $f5960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5960,
"from":L[2]});
}
} catch($e5152) {
if(R.isCont($e5152)) {
var $ss5556 = {"from":L[2],
"go":function(ann_DASH_check_DASH_temp28262) {
return $Hann_DASH_check_DASH_temp41663(ann_DASH_check_DASH_temp28262);
}};
$e5152.stack[R.EXN_STACKHEIGHT++] = $ss5556;
}
if(R.isPyretException($e5152)) {
$e5152.pyretStack.push(L[2]);
}
throw $e5152;
}
var $ret5758 = $Hann_DASH_check_DASH_temp41663($z5354);
++R.GAS;
return $ret5758;
};
var $Hann_DASH_check_DASH_temp41663 = function(ann_DASH_check_DASH_temp28262) {
return ann_DASH_check_DASH_temp28262;
};
var $Hanf_arg41564 = function(anf_arg27465,self5366,_plus7,torepr10) {
var anf_arg27577 = G(self5366,"field",L[4]);
var $z6970 = D;
var $f7576 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg27577):R.ffi.throwNonFunApp(L[4],torepr10,[anf_arg27577]);
};
try {
if(--R.GAS > 0) {
$z6970 = $f7576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7576,
"from":L[4]});
}
} catch($e6768) {
if(R.isCont($e6768)) {
var $ss7172 = {"from":L[4],
"go":function(anf_arg27678) {
return $Hanf_arg41479(anf_arg27678,anf_arg27465,_plus7);
}};
$e6768.stack[R.EXN_STACKHEIGHT++] = $ss7172;
}
if(R.isPyretException($e6768)) {
$e6768.pyretStack.push(L[4]);
}
throw $e6768;
}
var $ret7374 = $Hanf_arg41479($z6970,anf_arg27465,_plus7);
++R.GAS;
return $ret7374;
};
var $Hanf_arg41479 = function(anf_arg27678,anf_arg27465,_plus7) {
var $z8283 = D;
var $f8889 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg27678):R.ffi.throwNonFunApp(L[4],_plus7,[(", "),anf_arg27678]);
};
try {
if(--R.GAS > 0) {
$z8283 = $f8889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8889,
"from":L[4]});
}
} catch($e8081) {
if(R.isCont($e8081)) {
var $ss8485 = {"from":L[4],
"go":function(anf_arg27790) {
return $Hanf_arg41391(anf_arg27790,anf_arg27465,_plus7);
}};
$e8081.stack[R.EXN_STACKHEIGHT++] = $ss8485;
}
if(R.isPyretException($e8081)) {
$e8081.pyretStack.push(L[4]);
}
throw $e8081;
}
var $ret8687 = $Hanf_arg41391($z8283,anf_arg27465,_plus7);
++R.GAS;
return $ret8687;
};
var $Hanf_arg41391 = function(anf_arg27790,anf_arg27465,_plus7) {
var $z9495 = D;
var $f100101 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg27465,anf_arg27790):R.ffi.throwNonFunApp(L[4],_plus7,[anf_arg27465,anf_arg27790]);
};
try {
if(--R.GAS > 0) {
$z9495 = $f100101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f100101,
"from":L[4]});
}
} catch($e9293) {
if(R.isCont($e9293)) {
var $ss9697 = {"from":L[4],
"go":function(anf_arg278102) {
return $Hanf_arg412103(anf_arg278102,_plus7);
}};
$e9293.stack[R.EXN_STACKHEIGHT++] = $ss9697;
}
if(R.isPyretException($e9293)) {
$e9293.pyretStack.push(L[4]);
}
throw $e9293;
}
var $ret9899 = $Hanf_arg412103($z9495,_plus7);
++R.GAS;
return $ret9899;
};
var $Hanf_arg412103 = function(anf_arg278102,_plus7) {
var $z106107 = D;
var $f112113 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg278102,(")")):R.ffi.throwNonFunApp(L[4],_plus7,[anf_arg278102,(")")]);
};
try {
if(--R.GAS > 0) {
$z106107 = $f112113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f112113,
"from":L[4]});
}
} catch($e104105) {
if(R.isCont($e104105)) {
var $ss108109 = {"from":L[4],
"go":function(anf_arg279114) {
return $Hanf_arg411115(anf_arg279114,_plus7);
}};
$e104105.stack[R.EXN_STACKHEIGHT++] = $ss108109;
}
if(R.isPyretException($e104105)) {
$e104105.pyretStack.push(L[4]);
}
throw $e104105;
}
var $ret110111 = $Hanf_arg411115($z106107,_plus7);
++R.GAS;
return $ret110111;
};
var $Hanf_arg411115 = function(anf_arg279114,_plus7) {
var $z118119 = D;
var $f124125 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg279114):R.ffi.throwNonFunApp(L[4],_plus7,[("("),anf_arg279114]);
};
try {
if(--R.GAS > 0) {
$z118119 = $f124125();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f124125,
"from":L[4]});
}
} catch($e116117) {
if(R.isCont($e116117)) {
var $ss120121 = {"from":L[4],
"go":function(anf_arg280126) {
return $Hanf_arg410127(anf_arg280126,_plus7);
}};
$e116117.stack[R.EXN_STACKHEIGHT++] = $ss120121;
}
if(R.isPyretException($e116117)) {
$e116117.pyretStack.push(L[4]);
}
throw $e116117;
}
var $ret122123 = $Hanf_arg410127($z118119,_plus7);
++R.GAS;
return $ret122123;
};
var $Hanf_arg410127 = function(anf_arg280126,_plus7) {
var $z130131 = D;
var $f136137 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("dot-ann-not-present"),anf_arg280126):R.ffi.throwNonFunApp(L[4],_plus7,[("dot-ann-not-present"),anf_arg280126]);
};
try {
if(--R.GAS > 0) {
$z130131 = $f136137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f136137,
"from":L[4]});
}
} catch($e128129) {
if(R.isCont($e128129)) {
var $ss132133 = {"from":L[4],
"go":function(ann_DASH_check_DASH_temp272138) {
return $Hann_DASH_check_DASH_temp409139(ann_DASH_check_DASH_temp272138);
}};
$e128129.stack[R.EXN_STACKHEIGHT++] = $ss132133;
}
if(R.isPyretException($e128129)) {
$e128129.pyretStack.push(L[4]);
}
throw $e128129;
}
var $ret134135 = $Hann_DASH_check_DASH_temp409139($z130131);
++R.GAS;
return $ret134135;
};
var $Hann_DASH_check_DASH_temp409139 = function(ann_DASH_check_DASH_temp272138) {
return ann_DASH_check_DASH_temp272138;
};
var $Hcont_tail_arg407140 = function(cont_tail_arg269141,if_helper260142) {
if(--R.GAS > 0) {
$z143144 = R.isFunction(if_helper260142)?if_helper260142.app(cont_tail_arg269141):R.ffi.throwNonFunApp(L[4],if_helper260142,[cont_tail_arg269141]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper260142)?if_helper260142.app(cont_tail_arg269141):R.ffi.throwNonFunApp(L[4],if_helper260142,[cont_tail_arg269141]);
},
"from":L[4]});
}
++R.GAS;
return $z143144;
};
var $Hcont_tail_arg408146 = function(cont_tail_arg265147,if_helper260142) {
if(--R.GAS > 0) {
$z148149 = R.isFunction(if_helper260142)?if_helper260142.app(cont_tail_arg265147):R.ffi.throwNonFunApp(L[4],if_helper260142,[cont_tail_arg265147]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper260142)?if_helper260142.app(cont_tail_arg265147):R.ffi.throwNonFunApp(L[4],if_helper260142,[cont_tail_arg265147]);
},
"from":L[4]});
}
++R.GAS;
return $z148149;
};
var $Hanf_arg406150 = function(anf_arg250151,self57152,_plus7,tostring11) {
var $z155156 = D;
var $f161162 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Record annotation failed on value\n"),anf_arg250151):R.ffi.throwNonFunApp(L[5],_plus7,[("Record annotation failed on value\n"),anf_arg250151]);
};
try {
if(--R.GAS > 0) {
$z155156 = $f161162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f161162,
"from":L[5]});
}
} catch($e153154) {
if(R.isCont($e153154)) {
var $ss157158 = {"from":L[5],
"go":function(anf_arg251163) {
return $Hanf_arg405164(anf_arg251163,self57152,_plus7,tostring11);
}};
$e153154.stack[R.EXN_STACKHEIGHT++] = $ss157158;
}
if(R.isPyretException($e153154)) {
$e153154.pyretStack.push(L[5]);
}
throw $e153154;
}
var $ret159160 = $Hanf_arg405164($z155156,self57152,_plus7,tostring11);
++R.GAS;
return $ret159160;
};
var $Hanf_arg405164 = function(anf_arg251163,self57152,_plus7,tostring11) {
var $z167168 = D;
var $f173174 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg251163,("\n\nBecause: ")):R.ffi.throwNonFunApp(L[5],_plus7,[anf_arg251163,("\n\nBecause: ")]);
};
try {
if(--R.GAS > 0) {
$z167168 = $f173174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f173174,
"from":L[5]});
}
} catch($e165166) {
if(R.isCont($e165166)) {
var $ss169170 = {"from":L[5],
"go":function(anf_arg252175) {
return $Hanf_arg404176(anf_arg252175,self57152,_plus7,tostring11);
}};
$e165166.stack[R.EXN_STACKHEIGHT++] = $ss169170;
}
if(R.isPyretException($e165166)) {
$e165166.pyretStack.push(L[5]);
}
throw $e165166;
}
var $ret171172 = $Hanf_arg404176($z167168,self57152,_plus7,tostring11);
++R.GAS;
return $ret171172;
};
var $Hanf_arg404176 = function(anf_arg252175,self57152,_plus7,tostring11) {
var anf_bracket253190 = G(self57152,"field-failures",L[8]);
var anf_fun254187 = G(anf_bracket253190,"map",L[7]);
var $z179180 = D;
var $f185186 = function(_) {
return R.isFunction(anf_fun254187)?anf_fun254187.app(tostring11):R.ffi.throwNonFunApp(L[6],anf_fun254187,[tostring11]);
};
try {
if(--R.GAS > 0) {
$z179180 = $f185186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f185186,
"from":L[6]});
}
} catch($e177178) {
if(R.isCont($e177178)) {
var $ss181182 = {"from":L[6],
"go":function(anf_bracket255188) {
return $Hanf_bracket403189(anf_bracket255188,anf_arg252175,_plus7);
}};
$e177178.stack[R.EXN_STACKHEIGHT++] = $ss181182;
}
if(R.isPyretException($e177178)) {
$e177178.pyretStack.push(L[6]);
}
throw $e177178;
}
var $ret183184 = $Hanf_bracket403189($z179180,anf_arg252175,_plus7);
++R.GAS;
return $ret183184;
};
var $Hanf_bracket403189 = function(anf_bracket255188,anf_arg252175,_plus7) {
var anf_fun256201 = G(anf_bracket255188,"join-str",L[10]);
var $z193194 = D;
var $f199200 = function(_) {
return R.isFunction(anf_fun256201)?anf_fun256201.app(("\n\n")):R.ffi.throwNonFunApp(L[9],anf_fun256201,[("\n\n")]);
};
try {
if(--R.GAS > 0) {
$z193194 = $f199200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f199200,
"from":L[9]});
}
} catch($e191192) {
if(R.isCont($e191192)) {
var $ss195196 = {"from":L[9],
"go":function(anf_arg257202) {
return $Hanf_arg402203(anf_arg257202,anf_arg252175,_plus7);
}};
$e191192.stack[R.EXN_STACKHEIGHT++] = $ss195196;
}
if(R.isPyretException($e191192)) {
$e191192.pyretStack.push(L[9]);
}
throw $e191192;
}
var $ret197198 = $Hanf_arg402203($z193194,anf_arg252175,_plus7);
++R.GAS;
return $ret197198;
};
var $Hanf_arg402203 = function(anf_arg257202,anf_arg252175,_plus7) {
var $z206207 = D;
var $f212213 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg252175,anf_arg257202):R.ffi.throwNonFunApp(L[11],_plus7,[anf_arg252175,anf_arg257202]);
};
try {
if(--R.GAS > 0) {
$z206207 = $f212213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f212213,
"from":L[11]});
}
} catch($e204205) {
if(R.isCont($e204205)) {
var $ss208209 = {"from":L[11],
"go":function(ann_DASH_check_DASH_temp248214) {
return $Hann_DASH_check_DASH_temp401215(ann_DASH_check_DASH_temp248214);
}};
$e204205.stack[R.EXN_STACKHEIGHT++] = $ss208209;
}
if(R.isPyretException($e204205)) {
$e204205.pyretStack.push(L[11]);
}
throw $e204205;
}
var $ret210211 = $Hann_DASH_check_DASH_temp401215($z206207);
++R.GAS;
return $ret210211;
};
var $Hann_DASH_check_DASH_temp401215 = function(ann_DASH_check_DASH_temp248214) {
return ann_DASH_check_DASH_temp248214;
};
var $Hanf_arg400216 = function(anf_arg240217,self47218,_plus7,torepr10) {
var anf_arg241229 = G(self47218,"field-failures",L[12]);
var $z221222 = D;
var $f227228 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg241229):R.ffi.throwNonFunApp(L[12],torepr10,[anf_arg241229]);
};
try {
if(--R.GAS > 0) {
$z221222 = $f227228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f227228,
"from":L[12]});
}
} catch($e219220) {
if(R.isCont($e219220)) {
var $ss223224 = {"from":L[12],
"go":function(anf_arg242230) {
return $Hanf_arg399231(anf_arg242230,anf_arg240217,_plus7);
}};
$e219220.stack[R.EXN_STACKHEIGHT++] = $ss223224;
}
if(R.isPyretException($e219220)) {
$e219220.pyretStack.push(L[12]);
}
throw $e219220;
}
var $ret225226 = $Hanf_arg399231($z221222,anf_arg240217,_plus7);
++R.GAS;
return $ret225226;
};
var $Hanf_arg399231 = function(anf_arg242230,anf_arg240217,_plus7) {
var $z234235 = D;
var $f240241 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg242230):R.ffi.throwNonFunApp(L[12],_plus7,[(", "),anf_arg242230]);
};
try {
if(--R.GAS > 0) {
$z234235 = $f240241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f240241,
"from":L[12]});
}
} catch($e232233) {
if(R.isCont($e232233)) {
var $ss236237 = {"from":L[12],
"go":function(anf_arg243242) {
return $Hanf_arg398243(anf_arg243242,anf_arg240217,_plus7);
}};
$e232233.stack[R.EXN_STACKHEIGHT++] = $ss236237;
}
if(R.isPyretException($e232233)) {
$e232233.pyretStack.push(L[12]);
}
throw $e232233;
}
var $ret238239 = $Hanf_arg398243($z234235,anf_arg240217,_plus7);
++R.GAS;
return $ret238239;
};
var $Hanf_arg398243 = function(anf_arg243242,anf_arg240217,_plus7) {
var $z246247 = D;
var $f252253 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg240217,anf_arg243242):R.ffi.throwNonFunApp(L[12],_plus7,[anf_arg240217,anf_arg243242]);
};
try {
if(--R.GAS > 0) {
$z246247 = $f252253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f252253,
"from":L[12]});
}
} catch($e244245) {
if(R.isCont($e244245)) {
var $ss248249 = {"from":L[12],
"go":function(anf_arg244254) {
return $Hanf_arg397255(anf_arg244254,_plus7);
}};
$e244245.stack[R.EXN_STACKHEIGHT++] = $ss248249;
}
if(R.isPyretException($e244245)) {
$e244245.pyretStack.push(L[12]);
}
throw $e244245;
}
var $ret250251 = $Hanf_arg397255($z246247,_plus7);
++R.GAS;
return $ret250251;
};
var $Hanf_arg397255 = function(anf_arg244254,_plus7) {
var $z258259 = D;
var $f264265 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg244254,(")")):R.ffi.throwNonFunApp(L[12],_plus7,[anf_arg244254,(")")]);
};
try {
if(--R.GAS > 0) {
$z258259 = $f264265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f264265,
"from":L[12]});
}
} catch($e256257) {
if(R.isCont($e256257)) {
var $ss260261 = {"from":L[12],
"go":function(anf_arg245266) {
return $Hanf_arg396267(anf_arg245266,_plus7);
}};
$e256257.stack[R.EXN_STACKHEIGHT++] = $ss260261;
}
if(R.isPyretException($e256257)) {
$e256257.pyretStack.push(L[12]);
}
throw $e256257;
}
var $ret262263 = $Hanf_arg396267($z258259,_plus7);
++R.GAS;
return $ret262263;
};
var $Hanf_arg396267 = function(anf_arg245266,_plus7) {
var $z270271 = D;
var $f276277 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg245266):R.ffi.throwNonFunApp(L[12],_plus7,[("("),anf_arg245266]);
};
try {
if(--R.GAS > 0) {
$z270271 = $f276277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f276277,
"from":L[12]});
}
} catch($e268269) {
if(R.isCont($e268269)) {
var $ss272273 = {"from":L[12],
"go":function(anf_arg246278) {
return $Hanf_arg395279(anf_arg246278,_plus7);
}};
$e268269.stack[R.EXN_STACKHEIGHT++] = $ss272273;
}
if(R.isPyretException($e268269)) {
$e268269.pyretStack.push(L[12]);
}
throw $e268269;
}
var $ret274275 = $Hanf_arg395279($z270271,_plus7);
++R.GAS;
return $ret274275;
};
var $Hanf_arg395279 = function(anf_arg246278,_plus7) {
var $z282283 = D;
var $f288289 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("record-fields-fail"),anf_arg246278):R.ffi.throwNonFunApp(L[12],_plus7,[("record-fields-fail"),anf_arg246278]);
};
try {
if(--R.GAS > 0) {
$z282283 = $f288289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f288289,
"from":L[12]});
}
} catch($e280281) {
if(R.isCont($e280281)) {
var $ss284285 = {"from":L[12],
"go":function(ann_DASH_check_DASH_temp238290) {
return $Hann_DASH_check_DASH_temp394291(ann_DASH_check_DASH_temp238290);
}};
$e280281.stack[R.EXN_STACKHEIGHT++] = $ss284285;
}
if(R.isPyretException($e280281)) {
$e280281.pyretStack.push(L[12]);
}
throw $e280281;
}
var $ret286287 = $Hann_DASH_check_DASH_temp394291($z282283);
++R.GAS;
return $ret286287;
};
var $Hann_DASH_check_DASH_temp394291 = function(ann_DASH_check_DASH_temp238290) {
return ann_DASH_check_DASH_temp238290;
};
var $Hcont_tail_arg392292 = function(cont_tail_arg235293,if_helper226294) {
if(--R.GAS > 0) {
$z295296 = R.isFunction(if_helper226294)?if_helper226294.app(cont_tail_arg235293):R.ffi.throwNonFunApp(L[12],if_helper226294,[cont_tail_arg235293]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper226294)?if_helper226294.app(cont_tail_arg235293):R.ffi.throwNonFunApp(L[12],if_helper226294,[cont_tail_arg235293]);
},
"from":L[12]});
}
++R.GAS;
return $z295296;
};
var $Hcont_tail_arg393297 = function(cont_tail_arg231298,if_helper226294) {
if(--R.GAS > 0) {
$z299300 = R.isFunction(if_helper226294)?if_helper226294.app(cont_tail_arg231298):R.ffi.throwNonFunApp(L[12],if_helper226294,[cont_tail_arg231298]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper226294)?if_helper226294.app(cont_tail_arg231298):R.ffi.throwNonFunApp(L[12],if_helper226294,[cont_tail_arg231298]);
},
"from":L[12]});
}
++R.GAS;
return $z299300;
};
var $Hanf_arg391301 = function(anf_arg220302,self54303,_plus7,torepr10) {
var $z306307 = D;
var $f312313 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg220302,(" failed on value ")):R.ffi.throwNonFunApp(L[13],_plus7,[anf_arg220302,(" failed on value ")]);
};
try {
if(--R.GAS > 0) {
$z306307 = $f312313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f312313,
"from":L[13]});
}
} catch($e304305) {
if(R.isCont($e304305)) {
var $ss308309 = {"from":L[13],
"go":function(anf_arg221314) {
return $Hanf_arg390315(anf_arg221314,self54303,_plus7,torepr10);
}};
$e304305.stack[R.EXN_STACKHEIGHT++] = $ss308309;
}
if(R.isPyretException($e304305)) {
$e304305.pyretStack.push(L[13]);
}
throw $e304305;
}
var $ret310311 = $Hanf_arg390315($z306307,self54303,_plus7,torepr10);
++R.GAS;
return $ret310311;
};
var $Hanf_arg390315 = function(anf_arg221314,self54303,_plus7,torepr10) {
var anf_arg222326 = G(self54303,"val",L[15]);
var $z318319 = D;
var $f324325 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg222326):R.ffi.throwNonFunApp(L[14],torepr10,[anf_arg222326]);
};
try {
if(--R.GAS > 0) {
$z318319 = $f324325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f324325,
"from":L[14]});
}
} catch($e316317) {
if(R.isCont($e316317)) {
var $ss320321 = {"from":L[14],
"go":function(anf_arg223327) {
return $Hanf_arg389328(anf_arg223327,anf_arg221314,_plus7);
}};
$e316317.stack[R.EXN_STACKHEIGHT++] = $ss320321;
}
if(R.isPyretException($e316317)) {
$e316317.pyretStack.push(L[14]);
}
throw $e316317;
}
var $ret322323 = $Hanf_arg389328($z318319,anf_arg221314,_plus7);
++R.GAS;
return $ret322323;
};
var $Hanf_arg389328 = function(anf_arg223327,anf_arg221314,_plus7) {
var $z331332 = D;
var $f337338 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg221314,anf_arg223327):R.ffi.throwNonFunApp(L[16],_plus7,[anf_arg221314,anf_arg223327]);
};
try {
if(--R.GAS > 0) {
$z331332 = $f337338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f337338,
"from":L[16]});
}
} catch($e329330) {
if(R.isCont($e329330)) {
var $ss333334 = {"from":L[16],
"go":function(ann_DASH_check_DASH_temp218339) {
return $Hann_DASH_check_DASH_temp388340(ann_DASH_check_DASH_temp218339);
}};
$e329330.stack[R.EXN_STACKHEIGHT++] = $ss333334;
}
if(R.isPyretException($e329330)) {
$e329330.pyretStack.push(L[16]);
}
throw $e329330;
}
var $ret335336 = $Hann_DASH_check_DASH_temp388340($z331332);
++R.GAS;
return $ret335336;
};
var $Hann_DASH_check_DASH_temp388340 = function(ann_DASH_check_DASH_temp218339) {
return ann_DASH_check_DASH_temp218339;
};
var $Hanf_arg387341 = function(anf_arg210342,self41343,_plus7,torepr10) {
var anf_arg211354 = G(self41343,"pred-name",L[17]);
var $z346347 = D;
var $f352353 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg211354):R.ffi.throwNonFunApp(L[17],torepr10,[anf_arg211354]);
};
try {
if(--R.GAS > 0) {
$z346347 = $f352353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f352353,
"from":L[17]});
}
} catch($e344345) {
if(R.isCont($e344345)) {
var $ss348349 = {"from":L[17],
"go":function(anf_arg212355) {
return $Hanf_arg386356(anf_arg212355,anf_arg210342,_plus7);
}};
$e344345.stack[R.EXN_STACKHEIGHT++] = $ss348349;
}
if(R.isPyretException($e344345)) {
$e344345.pyretStack.push(L[17]);
}
throw $e344345;
}
var $ret350351 = $Hanf_arg386356($z346347,anf_arg210342,_plus7);
++R.GAS;
return $ret350351;
};
var $Hanf_arg386356 = function(anf_arg212355,anf_arg210342,_plus7) {
var $z359360 = D;
var $f365366 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg212355):R.ffi.throwNonFunApp(L[17],_plus7,[(", "),anf_arg212355]);
};
try {
if(--R.GAS > 0) {
$z359360 = $f365366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f365366,
"from":L[17]});
}
} catch($e357358) {
if(R.isCont($e357358)) {
var $ss361362 = {"from":L[17],
"go":function(anf_arg213367) {
return $Hanf_arg385368(anf_arg213367,anf_arg210342,_plus7);
}};
$e357358.stack[R.EXN_STACKHEIGHT++] = $ss361362;
}
if(R.isPyretException($e357358)) {
$e357358.pyretStack.push(L[17]);
}
throw $e357358;
}
var $ret363364 = $Hanf_arg385368($z359360,anf_arg210342,_plus7);
++R.GAS;
return $ret363364;
};
var $Hanf_arg385368 = function(anf_arg213367,anf_arg210342,_plus7) {
var $z371372 = D;
var $f377378 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg210342,anf_arg213367):R.ffi.throwNonFunApp(L[17],_plus7,[anf_arg210342,anf_arg213367]);
};
try {
if(--R.GAS > 0) {
$z371372 = $f377378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f377378,
"from":L[17]});
}
} catch($e369370) {
if(R.isCont($e369370)) {
var $ss373374 = {"from":L[17],
"go":function(anf_arg214379) {
return $Hanf_arg384380(anf_arg214379,_plus7);
}};
$e369370.stack[R.EXN_STACKHEIGHT++] = $ss373374;
}
if(R.isPyretException($e369370)) {
$e369370.pyretStack.push(L[17]);
}
throw $e369370;
}
var $ret375376 = $Hanf_arg384380($z371372,_plus7);
++R.GAS;
return $ret375376;
};
var $Hanf_arg384380 = function(anf_arg214379,_plus7) {
var $z383384 = D;
var $f389390 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg214379,(")")):R.ffi.throwNonFunApp(L[17],_plus7,[anf_arg214379,(")")]);
};
try {
if(--R.GAS > 0) {
$z383384 = $f389390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f389390,
"from":L[17]});
}
} catch($e381382) {
if(R.isCont($e381382)) {
var $ss385386 = {"from":L[17],
"go":function(anf_arg215391) {
return $Hanf_arg383392(anf_arg215391,_plus7);
}};
$e381382.stack[R.EXN_STACKHEIGHT++] = $ss385386;
}
if(R.isPyretException($e381382)) {
$e381382.pyretStack.push(L[17]);
}
throw $e381382;
}
var $ret387388 = $Hanf_arg383392($z383384,_plus7);
++R.GAS;
return $ret387388;
};
var $Hanf_arg383392 = function(anf_arg215391,_plus7) {
var $z395396 = D;
var $f401402 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg215391):R.ffi.throwNonFunApp(L[17],_plus7,[("("),anf_arg215391]);
};
try {
if(--R.GAS > 0) {
$z395396 = $f401402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f401402,
"from":L[17]});
}
} catch($e393394) {
if(R.isCont($e393394)) {
var $ss397398 = {"from":L[17],
"go":function(anf_arg216403) {
return $Hanf_arg382404(anf_arg216403,_plus7);
}};
$e393394.stack[R.EXN_STACKHEIGHT++] = $ss397398;
}
if(R.isPyretException($e393394)) {
$e393394.pyretStack.push(L[17]);
}
throw $e393394;
}
var $ret399400 = $Hanf_arg382404($z395396,_plus7);
++R.GAS;
return $ret399400;
};
var $Hanf_arg382404 = function(anf_arg216403,_plus7) {
var $z407408 = D;
var $f413414 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("predicate-failure"),anf_arg216403):R.ffi.throwNonFunApp(L[17],_plus7,[("predicate-failure"),anf_arg216403]);
};
try {
if(--R.GAS > 0) {
$z407408 = $f413414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f413414,
"from":L[17]});
}
} catch($e405406) {
if(R.isCont($e405406)) {
var $ss409410 = {"from":L[17],
"go":function(ann_DASH_check_DASH_temp208415) {
return $Hann_DASH_check_DASH_temp381416(ann_DASH_check_DASH_temp208415);
}};
$e405406.stack[R.EXN_STACKHEIGHT++] = $ss409410;
}
if(R.isPyretException($e405406)) {
$e405406.pyretStack.push(L[17]);
}
throw $e405406;
}
var $ret411412 = $Hann_DASH_check_DASH_temp381416($z407408);
++R.GAS;
return $ret411412;
};
var $Hann_DASH_check_DASH_temp381416 = function(ann_DASH_check_DASH_temp208415) {
return ann_DASH_check_DASH_temp208415;
};
var $Hcont_tail_arg379417 = function(cont_tail_arg205418,if_helper196419) {
if(--R.GAS > 0) {
$z420421 = R.isFunction(if_helper196419)?if_helper196419.app(cont_tail_arg205418):R.ffi.throwNonFunApp(L[17],if_helper196419,[cont_tail_arg205418]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper196419)?if_helper196419.app(cont_tail_arg205418):R.ffi.throwNonFunApp(L[17],if_helper196419,[cont_tail_arg205418]);
},
"from":L[17]});
}
++R.GAS;
return $z420421;
};
var $Hcont_tail_arg380422 = function(cont_tail_arg201423,if_helper196419) {
if(--R.GAS > 0) {
$z424425 = R.isFunction(if_helper196419)?if_helper196419.app(cont_tail_arg201423):R.ffi.throwNonFunApp(L[17],if_helper196419,[cont_tail_arg201423]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper196419)?if_helper196419.app(cont_tail_arg201423):R.ffi.throwNonFunApp(L[17],if_helper196419,[cont_tail_arg201423]);
},
"from":L[17]});
}
++R.GAS;
return $z424425;
};
var $Hanf_arg378426 = function(anf_arg190427,self51428,_plus7,torepr10) {
var $z431432 = D;
var $f437438 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg190427,(", but got ")):R.ffi.throwNonFunApp(L[18],_plus7,[anf_arg190427,(", but got ")]);
};
try {
if(--R.GAS > 0) {
$z431432 = $f437438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f437438,
"from":L[18]});
}
} catch($e429430) {
if(R.isCont($e429430)) {
var $ss433434 = {"from":L[18],
"go":function(anf_arg191439) {
return $Hanf_arg377440(anf_arg191439,self51428,_plus7,torepr10);
}};
$e429430.stack[R.EXN_STACKHEIGHT++] = $ss433434;
}
if(R.isPyretException($e429430)) {
$e429430.pyretStack.push(L[18]);
}
throw $e429430;
}
var $ret435436 = $Hanf_arg377440($z431432,self51428,_plus7,torepr10);
++R.GAS;
return $ret435436;
};
var $Hanf_arg377440 = function(anf_arg191439,self51428,_plus7,torepr10) {
var anf_arg192451 = G(self51428,"val",L[20]);
var $z443444 = D;
var $f449450 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg192451):R.ffi.throwNonFunApp(L[19],torepr10,[anf_arg192451]);
};
try {
if(--R.GAS > 0) {
$z443444 = $f449450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f449450,
"from":L[19]});
}
} catch($e441442) {
if(R.isCont($e441442)) {
var $ss445446 = {"from":L[19],
"go":function(anf_arg193452) {
return $Hanf_arg376453(anf_arg193452,anf_arg191439,_plus7);
}};
$e441442.stack[R.EXN_STACKHEIGHT++] = $ss445446;
}
if(R.isPyretException($e441442)) {
$e441442.pyretStack.push(L[19]);
}
throw $e441442;
}
var $ret447448 = $Hanf_arg376453($z443444,anf_arg191439,_plus7);
++R.GAS;
return $ret447448;
};
var $Hanf_arg376453 = function(anf_arg193452,anf_arg191439,_plus7) {
var $z456457 = D;
var $f462463 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg191439,anf_arg193452):R.ffi.throwNonFunApp(L[21],_plus7,[anf_arg191439,anf_arg193452]);
};
try {
if(--R.GAS > 0) {
$z456457 = $f462463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f462463,
"from":L[21]});
}
} catch($e454455) {
if(R.isCont($e454455)) {
var $ss458459 = {"from":L[21],
"go":function(ann_DASH_check_DASH_temp188464) {
return $Hann_DASH_check_DASH_temp375465(ann_DASH_check_DASH_temp188464);
}};
$e454455.stack[R.EXN_STACKHEIGHT++] = $ss458459;
}
if(R.isPyretException($e454455)) {
$e454455.pyretStack.push(L[21]);
}
throw $e454455;
}
var $ret460461 = $Hann_DASH_check_DASH_temp375465($z456457);
++R.GAS;
return $ret460461;
};
var $Hann_DASH_check_DASH_temp375465 = function(ann_DASH_check_DASH_temp188464) {
return ann_DASH_check_DASH_temp188464;
};
var $Hanf_arg374466 = function(anf_arg180467,self35468,_plus7,torepr10) {
var anf_arg181479 = G(self35468,"name",L[22]);
var $z471472 = D;
var $f477478 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg181479):R.ffi.throwNonFunApp(L[22],torepr10,[anf_arg181479]);
};
try {
if(--R.GAS > 0) {
$z471472 = $f477478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f477478,
"from":L[22]});
}
} catch($e469470) {
if(R.isCont($e469470)) {
var $ss473474 = {"from":L[22],
"go":function(anf_arg182480) {
return $Hanf_arg373481(anf_arg182480,anf_arg180467,_plus7);
}};
$e469470.stack[R.EXN_STACKHEIGHT++] = $ss473474;
}
if(R.isPyretException($e469470)) {
$e469470.pyretStack.push(L[22]);
}
throw $e469470;
}
var $ret475476 = $Hanf_arg373481($z471472,anf_arg180467,_plus7);
++R.GAS;
return $ret475476;
};
var $Hanf_arg373481 = function(anf_arg182480,anf_arg180467,_plus7) {
var $z484485 = D;
var $f490491 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg182480):R.ffi.throwNonFunApp(L[22],_plus7,[(", "),anf_arg182480]);
};
try {
if(--R.GAS > 0) {
$z484485 = $f490491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f490491,
"from":L[22]});
}
} catch($e482483) {
if(R.isCont($e482483)) {
var $ss486487 = {"from":L[22],
"go":function(anf_arg183492) {
return $Hanf_arg372493(anf_arg183492,anf_arg180467,_plus7);
}};
$e482483.stack[R.EXN_STACKHEIGHT++] = $ss486487;
}
if(R.isPyretException($e482483)) {
$e482483.pyretStack.push(L[22]);
}
throw $e482483;
}
var $ret488489 = $Hanf_arg372493($z484485,anf_arg180467,_plus7);
++R.GAS;
return $ret488489;
};
var $Hanf_arg372493 = function(anf_arg183492,anf_arg180467,_plus7) {
var $z496497 = D;
var $f502503 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg180467,anf_arg183492):R.ffi.throwNonFunApp(L[22],_plus7,[anf_arg180467,anf_arg183492]);
};
try {
if(--R.GAS > 0) {
$z496497 = $f502503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f502503,
"from":L[22]});
}
} catch($e494495) {
if(R.isCont($e494495)) {
var $ss498499 = {"from":L[22],
"go":function(anf_arg184504) {
return $Hanf_arg371505(anf_arg184504,_plus7);
}};
$e494495.stack[R.EXN_STACKHEIGHT++] = $ss498499;
}
if(R.isPyretException($e494495)) {
$e494495.pyretStack.push(L[22]);
}
throw $e494495;
}
var $ret500501 = $Hanf_arg371505($z496497,_plus7);
++R.GAS;
return $ret500501;
};
var $Hanf_arg371505 = function(anf_arg184504,_plus7) {
var $z508509 = D;
var $f514515 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg184504,(")")):R.ffi.throwNonFunApp(L[22],_plus7,[anf_arg184504,(")")]);
};
try {
if(--R.GAS > 0) {
$z508509 = $f514515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f514515,
"from":L[22]});
}
} catch($e506507) {
if(R.isCont($e506507)) {
var $ss510511 = {"from":L[22],
"go":function(anf_arg185516) {
return $Hanf_arg370517(anf_arg185516,_plus7);
}};
$e506507.stack[R.EXN_STACKHEIGHT++] = $ss510511;
}
if(R.isPyretException($e506507)) {
$e506507.pyretStack.push(L[22]);
}
throw $e506507;
}
var $ret512513 = $Hanf_arg370517($z508509,_plus7);
++R.GAS;
return $ret512513;
};
var $Hanf_arg370517 = function(anf_arg185516,_plus7) {
var $z520521 = D;
var $f526527 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg185516):R.ffi.throwNonFunApp(L[22],_plus7,[("("),anf_arg185516]);
};
try {
if(--R.GAS > 0) {
$z520521 = $f526527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f526527,
"from":L[22]});
}
} catch($e518519) {
if(R.isCont($e518519)) {
var $ss522523 = {"from":L[22],
"go":function(anf_arg186528) {
return $Hanf_arg369529(anf_arg186528,_plus7);
}};
$e518519.stack[R.EXN_STACKHEIGHT++] = $ss522523;
}
if(R.isPyretException($e518519)) {
$e518519.pyretStack.push(L[22]);
}
throw $e518519;
}
var $ret524525 = $Hanf_arg369529($z520521,_plus7);
++R.GAS;
return $ret524525;
};
var $Hanf_arg369529 = function(anf_arg186528,_plus7) {
var $z532533 = D;
var $f538539 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("type-mismatch"),anf_arg186528):R.ffi.throwNonFunApp(L[22],_plus7,[("type-mismatch"),anf_arg186528]);
};
try {
if(--R.GAS > 0) {
$z532533 = $f538539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f538539,
"from":L[22]});
}
} catch($e530531) {
if(R.isCont($e530531)) {
var $ss534535 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp178540) {
return $Hann_DASH_check_DASH_temp368541(ann_DASH_check_DASH_temp178540);
}};
$e530531.stack[R.EXN_STACKHEIGHT++] = $ss534535;
}
if(R.isPyretException($e530531)) {
$e530531.pyretStack.push(L[22]);
}
throw $e530531;
}
var $ret536537 = $Hann_DASH_check_DASH_temp368541($z532533);
++R.GAS;
return $ret536537;
};
var $Hann_DASH_check_DASH_temp368541 = function(ann_DASH_check_DASH_temp178540) {
return ann_DASH_check_DASH_temp178540;
};
var $Hcont_tail_arg366542 = function(cont_tail_arg175543,if_helper166544) {
if(--R.GAS > 0) {
$z545546 = R.isFunction(if_helper166544)?if_helper166544.app(cont_tail_arg175543):R.ffi.throwNonFunApp(L[22],if_helper166544,[cont_tail_arg175543]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper166544)?if_helper166544.app(cont_tail_arg175543):R.ffi.throwNonFunApp(L[22],if_helper166544,[cont_tail_arg175543]);
},
"from":L[22]});
}
++R.GAS;
return $z545546;
};
var $Hcont_tail_arg367547 = function(cont_tail_arg171548,if_helper166544) {
if(--R.GAS > 0) {
$z549550 = R.isFunction(if_helper166544)?if_helper166544.app(cont_tail_arg171548):R.ffi.throwNonFunApp(L[22],if_helper166544,[cont_tail_arg171548]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper166544)?if_helper166544.app(cont_tail_arg171548):R.ffi.throwNonFunApp(L[22],if_helper166544,[cont_tail_arg171548]);
},
"from":L[22]});
}
++R.GAS;
return $z549550;
};
var $Hanf_arg365551 = function(anf_arg152552,self48553,_plus7) {
var $z556557 = D;
var $f562563 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg152552,(" in required at ")):R.ffi.throwNonFunApp(L[23],_plus7,[anf_arg152552,(" in required at ")]);
};
try {
if(--R.GAS > 0) {
$z556557 = $f562563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f562563,
"from":L[23]});
}
} catch($e554555) {
if(R.isCont($e554555)) {
var $ss558559 = {"from":L[23],
"go":function(anf_arg153564) {
return $Hanf_arg364565(anf_arg153564,self48553,_plus7);
}};
$e554555.stack[R.EXN_STACKHEIGHT++] = $ss558559;
}
if(R.isPyretException($e554555)) {
$e554555.pyretStack.push(L[23]);
}
throw $e554555;
}
var $ret560561 = $Hanf_arg364565($z556557,self48553,_plus7);
++R.GAS;
return $ret560561;
};
var $Hanf_arg364565 = function(anf_arg153564,self48553,_plus7) {
var anf_bracket154579 = G(self48553,"loc",L[26]);
var anf_fun155576 = G(anf_bracket154579,"format",L[25]);
var $z568569 = D;
var $f574575 = function(_) {
return R.isFunction(anf_fun155576)?anf_fun155576.app((true)):R.ffi.throwNonFunApp(L[24],anf_fun155576,[(true)]);
};
try {
if(--R.GAS > 0) {
$z568569 = $f574575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f574575,
"from":L[24]});
}
} catch($e566567) {
if(R.isCont($e566567)) {
var $ss570571 = {"from":L[24],
"go":function(anf_arg156577) {
return $Hanf_arg363578(anf_arg156577,anf_arg153564,_plus7);
}};
$e566567.stack[R.EXN_STACKHEIGHT++] = $ss570571;
}
if(R.isPyretException($e566567)) {
$e566567.pyretStack.push(L[24]);
}
throw $e566567;
}
var $ret572573 = $Hanf_arg363578($z568569,anf_arg153564,_plus7);
++R.GAS;
return $ret572573;
};
var $Hanf_arg363578 = function(anf_arg156577,anf_arg153564,_plus7) {
var $z582583 = D;
var $f588589 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg153564,anf_arg156577):R.ffi.throwNonFunApp(L[27],_plus7,[anf_arg153564,anf_arg156577]);
};
try {
if(--R.GAS > 0) {
$z582583 = $f588589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f588589,
"from":L[27]});
}
} catch($e580581) {
if(R.isCont($e580581)) {
var $ss584585 = {"from":L[27],
"go":function(ann_DASH_check_DASH_temp150590) {
return $Hann_DASH_check_DASH_temp362591(ann_DASH_check_DASH_temp150590);
}};
$e580581.stack[R.EXN_STACKHEIGHT++] = $ss584585;
}
if(R.isPyretException($e580581)) {
$e580581.pyretStack.push(L[27]);
}
throw $e580581;
}
var $ret586587 = $Hann_DASH_check_DASH_temp362591($z582583);
++R.GAS;
return $ret586587;
};
var $Hann_DASH_check_DASH_temp362591 = function(ann_DASH_check_DASH_temp150590) {
return ann_DASH_check_DASH_temp150590;
};
var $Hanf_arg361592 = function(anf_arg142593,self29594,_plus7,torepr10) {
var anf_arg143605 = G(self29594,"field",L[28]);
var $z597598 = D;
var $f603604 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg143605):R.ffi.throwNonFunApp(L[28],torepr10,[anf_arg143605]);
};
try {
if(--R.GAS > 0) {
$z597598 = $f603604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f603604,
"from":L[28]});
}
} catch($e595596) {
if(R.isCont($e595596)) {
var $ss599600 = {"from":L[28],
"go":function(anf_arg144606) {
return $Hanf_arg360607(anf_arg144606,anf_arg142593,_plus7);
}};
$e595596.stack[R.EXN_STACKHEIGHT++] = $ss599600;
}
if(R.isPyretException($e595596)) {
$e595596.pyretStack.push(L[28]);
}
throw $e595596;
}
var $ret601602 = $Hanf_arg360607($z597598,anf_arg142593,_plus7);
++R.GAS;
return $ret601602;
};
var $Hanf_arg360607 = function(anf_arg144606,anf_arg142593,_plus7) {
var $z610611 = D;
var $f616617 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg144606):R.ffi.throwNonFunApp(L[28],_plus7,[(", "),anf_arg144606]);
};
try {
if(--R.GAS > 0) {
$z610611 = $f616617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f616617,
"from":L[28]});
}
} catch($e608609) {
if(R.isCont($e608609)) {
var $ss612613 = {"from":L[28],
"go":function(anf_arg145618) {
return $Hanf_arg359619(anf_arg145618,anf_arg142593,_plus7);
}};
$e608609.stack[R.EXN_STACKHEIGHT++] = $ss612613;
}
if(R.isPyretException($e608609)) {
$e608609.pyretStack.push(L[28]);
}
throw $e608609;
}
var $ret614615 = $Hanf_arg359619($z610611,anf_arg142593,_plus7);
++R.GAS;
return $ret614615;
};
var $Hanf_arg359619 = function(anf_arg145618,anf_arg142593,_plus7) {
var $z622623 = D;
var $f628629 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg142593,anf_arg145618):R.ffi.throwNonFunApp(L[28],_plus7,[anf_arg142593,anf_arg145618]);
};
try {
if(--R.GAS > 0) {
$z622623 = $f628629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f628629,
"from":L[28]});
}
} catch($e620621) {
if(R.isCont($e620621)) {
var $ss624625 = {"from":L[28],
"go":function(anf_arg146630) {
return $Hanf_arg358631(anf_arg146630,_plus7);
}};
$e620621.stack[R.EXN_STACKHEIGHT++] = $ss624625;
}
if(R.isPyretException($e620621)) {
$e620621.pyretStack.push(L[28]);
}
throw $e620621;
}
var $ret626627 = $Hanf_arg358631($z622623,_plus7);
++R.GAS;
return $ret626627;
};
var $Hanf_arg358631 = function(anf_arg146630,_plus7) {
var $z634635 = D;
var $f640641 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg146630,(")")):R.ffi.throwNonFunApp(L[28],_plus7,[anf_arg146630,(")")]);
};
try {
if(--R.GAS > 0) {
$z634635 = $f640641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f640641,
"from":L[28]});
}
} catch($e632633) {
if(R.isCont($e632633)) {
var $ss636637 = {"from":L[28],
"go":function(anf_arg147642) {
return $Hanf_arg357643(anf_arg147642,_plus7);
}};
$e632633.stack[R.EXN_STACKHEIGHT++] = $ss636637;
}
if(R.isPyretException($e632633)) {
$e632633.pyretStack.push(L[28]);
}
throw $e632633;
}
var $ret638639 = $Hanf_arg357643($z634635,_plus7);
++R.GAS;
return $ret638639;
};
var $Hanf_arg357643 = function(anf_arg147642,_plus7) {
var $z646647 = D;
var $f652653 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg147642):R.ffi.throwNonFunApp(L[28],_plus7,[("("),anf_arg147642]);
};
try {
if(--R.GAS > 0) {
$z646647 = $f652653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f652653,
"from":L[28]});
}
} catch($e644645) {
if(R.isCont($e644645)) {
var $ss648649 = {"from":L[28],
"go":function(anf_arg148654) {
return $Hanf_arg356655(anf_arg148654,_plus7);
}};
$e644645.stack[R.EXN_STACKHEIGHT++] = $ss648649;
}
if(R.isPyretException($e644645)) {
$e644645.pyretStack.push(L[28]);
}
throw $e644645;
}
var $ret650651 = $Hanf_arg356655($z646647,_plus7);
++R.GAS;
return $ret650651;
};
var $Hanf_arg356655 = function(anf_arg148654,_plus7) {
var $z658659 = D;
var $f664665 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("missing-field"),anf_arg148654):R.ffi.throwNonFunApp(L[28],_plus7,[("missing-field"),anf_arg148654]);
};
try {
if(--R.GAS > 0) {
$z658659 = $f664665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f664665,
"from":L[28]});
}
} catch($e656657) {
if(R.isCont($e656657)) {
var $ss660661 = {"from":L[28],
"go":function(ann_DASH_check_DASH_temp140666) {
return $Hann_DASH_check_DASH_temp355667(ann_DASH_check_DASH_temp140666);
}};
$e656657.stack[R.EXN_STACKHEIGHT++] = $ss660661;
}
if(R.isPyretException($e656657)) {
$e656657.pyretStack.push(L[28]);
}
throw $e656657;
}
var $ret662663 = $Hann_DASH_check_DASH_temp355667($z658659);
++R.GAS;
return $ret662663;
};
var $Hann_DASH_check_DASH_temp355667 = function(ann_DASH_check_DASH_temp140666) {
return ann_DASH_check_DASH_temp140666;
};
var $Hcont_tail_arg353668 = function(cont_tail_arg137669,if_helper128670) {
if(--R.GAS > 0) {
$z671672 = R.isFunction(if_helper128670)?if_helper128670.app(cont_tail_arg137669):R.ffi.throwNonFunApp(L[28],if_helper128670,[cont_tail_arg137669]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper128670)?if_helper128670.app(cont_tail_arg137669):R.ffi.throwNonFunApp(L[28],if_helper128670,[cont_tail_arg137669]);
},
"from":L[28]});
}
++R.GAS;
return $z671672;
};
var $Hcont_tail_arg354673 = function(cont_tail_arg133674,if_helper128670) {
if(--R.GAS > 0) {
$z675676 = R.isFunction(if_helper128670)?if_helper128670.app(cont_tail_arg133674):R.ffi.throwNonFunApp(L[28],if_helper128670,[cont_tail_arg133674]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper128670)?if_helper128670.app(cont_tail_arg133674):R.ffi.throwNonFunApp(L[28],if_helper128670,[cont_tail_arg133674]);
},
"from":L[28]});
}
++R.GAS;
return $z675676;
};
var $Hanf_arg352677 = function(anf_arg118678,self45679,_plus7,tostring11) {
var $z682683 = D;
var $f688689 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("At "),anf_arg118678):R.ffi.throwNonFunApp(L[29],_plus7,[("At "),anf_arg118678]);
};
try {
if(--R.GAS > 0) {
$z682683 = $f688689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f688689,
"from":L[29]});
}
} catch($e680681) {
if(R.isCont($e680681)) {
var $ss684685 = {"from":L[29],
"go":function(anf_arg119690) {
return $Hanf_arg351691(anf_arg119690,self45679,_plus7,tostring11);
}};
$e680681.stack[R.EXN_STACKHEIGHT++] = $ss684685;
}
if(R.isPyretException($e680681)) {
$e680681.pyretStack.push(L[29]);
}
throw $e680681;
}
var $ret686687 = $Hanf_arg351691($z682683,self45679,_plus7,tostring11);
++R.GAS;
return $ret686687;
};
var $Hanf_arg351691 = function(anf_arg119690,self45679,_plus7,tostring11) {
var $z694695 = D;
var $f700701 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg119690,(", field ")):R.ffi.throwNonFunApp(L[29],_plus7,[anf_arg119690,(", field ")]);
};
try {
if(--R.GAS > 0) {
$z694695 = $f700701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f700701,
"from":L[29]});
}
} catch($e692693) {
if(R.isCont($e692693)) {
var $ss696697 = {"from":L[29],
"go":function(anf_arg120702) {
return $Hanf_arg350703(anf_arg120702,self45679,_plus7,tostring11);
}};
$e692693.stack[R.EXN_STACKHEIGHT++] = $ss696697;
}
if(R.isPyretException($e692693)) {
$e692693.pyretStack.push(L[29]);
}
throw $e692693;
}
var $ret698699 = $Hanf_arg350703($z694695,self45679,_plus7,tostring11);
++R.GAS;
return $ret698699;
};
var $Hanf_arg350703 = function(anf_arg120702,self45679,_plus7,tostring11) {
var anf_arg121714 = G(self45679,"field",L[30]);
var $z706707 = D;
var $f712713 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg120702,anf_arg121714):R.ffi.throwNonFunApp(L[29],_plus7,[anf_arg120702,anf_arg121714]);
};
try {
if(--R.GAS > 0) {
$z706707 = $f712713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f712713,
"from":L[29]});
}
} catch($e704705) {
if(R.isCont($e704705)) {
var $ss708709 = {"from":L[29],
"go":function(anf_arg122715) {
return $Hanf_arg349716(anf_arg122715,self45679,_plus7,tostring11);
}};
$e704705.stack[R.EXN_STACKHEIGHT++] = $ss708709;
}
if(R.isPyretException($e704705)) {
$e704705.pyretStack.push(L[29]);
}
throw $e704705;
}
var $ret710711 = $Hanf_arg349716($z706707,self45679,_plus7,tostring11);
++R.GAS;
return $ret710711;
};
var $Hanf_arg349716 = function(anf_arg122715,self45679,_plus7,tostring11) {
var $z719720 = D;
var $f725726 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg122715,(" failed because\n")):R.ffi.throwNonFunApp(L[29],_plus7,[anf_arg122715,(" failed because\n")]);
};
try {
if(--R.GAS > 0) {
$z719720 = $f725726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f725726,
"from":L[29]});
}
} catch($e717718) {
if(R.isCont($e717718)) {
var $ss721722 = {"from":L[29],
"go":function(anf_arg123727) {
return $Hanf_arg348728(anf_arg123727,self45679,_plus7,tostring11);
}};
$e717718.stack[R.EXN_STACKHEIGHT++] = $ss721722;
}
if(R.isPyretException($e717718)) {
$e717718.pyretStack.push(L[29]);
}
throw $e717718;
}
var $ret723724 = $Hanf_arg348728($z719720,self45679,_plus7,tostring11);
++R.GAS;
return $ret723724;
};
var $Hanf_arg348728 = function(anf_arg123727,self45679,_plus7,tostring11) {
var anf_arg124739 = G(self45679,"reason",L[32]);
var $z731732 = D;
var $f737738 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg124739):R.ffi.throwNonFunApp(L[31],tostring11,[anf_arg124739]);
};
try {
if(--R.GAS > 0) {
$z731732 = $f737738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f737738,
"from":L[31]});
}
} catch($e729730) {
if(R.isCont($e729730)) {
var $ss733734 = {"from":L[31],
"go":function(anf_arg125740) {
return $Hanf_arg347741(anf_arg125740,anf_arg123727,_plus7);
}};
$e729730.stack[R.EXN_STACKHEIGHT++] = $ss733734;
}
if(R.isPyretException($e729730)) {
$e729730.pyretStack.push(L[31]);
}
throw $e729730;
}
var $ret735736 = $Hanf_arg347741($z731732,anf_arg123727,_plus7);
++R.GAS;
return $ret735736;
};
var $Hanf_arg347741 = function(anf_arg125740,anf_arg123727,_plus7) {
var $z744745 = D;
var $f750751 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg123727,anf_arg125740):R.ffi.throwNonFunApp(L[33],_plus7,[anf_arg123727,anf_arg125740]);
};
try {
if(--R.GAS > 0) {
$z744745 = $f750751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f750751,
"from":L[33]});
}
} catch($e742743) {
if(R.isCont($e742743)) {
var $ss746747 = {"from":L[33],
"go":function(ann_DASH_check_DASH_temp115752) {
return $Hann_DASH_check_DASH_temp346753(ann_DASH_check_DASH_temp115752);
}};
$e742743.stack[R.EXN_STACKHEIGHT++] = $ss746747;
}
if(R.isPyretException($e742743)) {
$e742743.pyretStack.push(L[33]);
}
throw $e742743;
}
var $ret748749 = $Hann_DASH_check_DASH_temp346753($z744745);
++R.GAS;
return $ret748749;
};
var $Hann_DASH_check_DASH_temp346753 = function(ann_DASH_check_DASH_temp115752) {
return ann_DASH_check_DASH_temp115752;
};
var $Hanf_arg345754 = function(anf_arg103755,self23756,_plus7,torepr10) {
var anf_arg104767 = G(self23756,"field",L[34]);
var $z759760 = D;
var $f765766 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg104767):R.ffi.throwNonFunApp(L[34],torepr10,[anf_arg104767]);
};
try {
if(--R.GAS > 0) {
$z759760 = $f765766();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f765766,
"from":L[34]});
}
} catch($e757758) {
if(R.isCont($e757758)) {
var $ss761762 = {"from":L[34],
"go":function(anf_arg105768) {
return $Hanf_arg344769(anf_arg105768,anf_arg103755,self23756,_plus7,torepr10);
}};
$e757758.stack[R.EXN_STACKHEIGHT++] = $ss761762;
}
if(R.isPyretException($e757758)) {
$e757758.pyretStack.push(L[34]);
}
throw $e757758;
}
var $ret763764 = $Hanf_arg344769($z759760,anf_arg103755,self23756,_plus7,torepr10);
++R.GAS;
return $ret763764;
};
var $Hanf_arg344769 = function(anf_arg105768,anf_arg103755,self23756,_plus7,torepr10) {
var $z772773 = D;
var $f778779 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg105768):R.ffi.throwNonFunApp(L[34],_plus7,[(", "),anf_arg105768]);
};
try {
if(--R.GAS > 0) {
$z772773 = $f778779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f778779,
"from":L[34]});
}
} catch($e770771) {
if(R.isCont($e770771)) {
var $ss774775 = {"from":L[34],
"go":function(anf_arg106780) {
return $Hanf_arg343781(anf_arg106780,anf_arg103755,self23756,_plus7,torepr10);
}};
$e770771.stack[R.EXN_STACKHEIGHT++] = $ss774775;
}
if(R.isPyretException($e770771)) {
$e770771.pyretStack.push(L[34]);
}
throw $e770771;
}
var $ret776777 = $Hanf_arg343781($z772773,anf_arg103755,self23756,_plus7,torepr10);
++R.GAS;
return $ret776777;
};
var $Hanf_arg343781 = function(anf_arg106780,anf_arg103755,self23756,_plus7,torepr10) {
var $z784785 = D;
var $f790791 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg103755,anf_arg106780):R.ffi.throwNonFunApp(L[34],_plus7,[anf_arg103755,anf_arg106780]);
};
try {
if(--R.GAS > 0) {
$z784785 = $f790791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f790791,
"from":L[34]});
}
} catch($e782783) {
if(R.isCont($e782783)) {
var $ss786787 = {"from":L[34],
"go":function(anf_arg107792) {
return $Hanf_arg342793(anf_arg107792,self23756,_plus7,torepr10);
}};
$e782783.stack[R.EXN_STACKHEIGHT++] = $ss786787;
}
if(R.isPyretException($e782783)) {
$e782783.pyretStack.push(L[34]);
}
throw $e782783;
}
var $ret788789 = $Hanf_arg342793($z784785,self23756,_plus7,torepr10);
++R.GAS;
return $ret788789;
};
var $Hanf_arg342793 = function(anf_arg107792,self23756,_plus7,torepr10) {
var anf_arg108804 = G(self23756,"reason",L[34]);
var $z796797 = D;
var $f802803 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg108804):R.ffi.throwNonFunApp(L[34],torepr10,[anf_arg108804]);
};
try {
if(--R.GAS > 0) {
$z796797 = $f802803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f802803,
"from":L[34]});
}
} catch($e794795) {
if(R.isCont($e794795)) {
var $ss798799 = {"from":L[34],
"go":function(anf_arg109805) {
return $Hanf_arg341806(anf_arg109805,anf_arg107792,_plus7);
}};
$e794795.stack[R.EXN_STACKHEIGHT++] = $ss798799;
}
if(R.isPyretException($e794795)) {
$e794795.pyretStack.push(L[34]);
}
throw $e794795;
}
var $ret800801 = $Hanf_arg341806($z796797,anf_arg107792,_plus7);
++R.GAS;
return $ret800801;
};
var $Hanf_arg341806 = function(anf_arg109805,anf_arg107792,_plus7) {
var $z809810 = D;
var $f815816 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg109805):R.ffi.throwNonFunApp(L[34],_plus7,[(", "),anf_arg109805]);
};
try {
if(--R.GAS > 0) {
$z809810 = $f815816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f815816,
"from":L[34]});
}
} catch($e807808) {
if(R.isCont($e807808)) {
var $ss811812 = {"from":L[34],
"go":function(anf_arg110817) {
return $Hanf_arg340818(anf_arg110817,anf_arg107792,_plus7);
}};
$e807808.stack[R.EXN_STACKHEIGHT++] = $ss811812;
}
if(R.isPyretException($e807808)) {
$e807808.pyretStack.push(L[34]);
}
throw $e807808;
}
var $ret813814 = $Hanf_arg340818($z809810,anf_arg107792,_plus7);
++R.GAS;
return $ret813814;
};
var $Hanf_arg340818 = function(anf_arg110817,anf_arg107792,_plus7) {
var $z821822 = D;
var $f827828 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg107792,anf_arg110817):R.ffi.throwNonFunApp(L[34],_plus7,[anf_arg107792,anf_arg110817]);
};
try {
if(--R.GAS > 0) {
$z821822 = $f827828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f827828,
"from":L[34]});
}
} catch($e819820) {
if(R.isCont($e819820)) {
var $ss823824 = {"from":L[34],
"go":function(anf_arg111829) {
return $Hanf_arg339830(anf_arg111829,_plus7);
}};
$e819820.stack[R.EXN_STACKHEIGHT++] = $ss823824;
}
if(R.isPyretException($e819820)) {
$e819820.pyretStack.push(L[34]);
}
throw $e819820;
}
var $ret825826 = $Hanf_arg339830($z821822,_plus7);
++R.GAS;
return $ret825826;
};
var $Hanf_arg339830 = function(anf_arg111829,_plus7) {
var $z833834 = D;
var $f839840 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg111829,(")")):R.ffi.throwNonFunApp(L[34],_plus7,[anf_arg111829,(")")]);
};
try {
if(--R.GAS > 0) {
$z833834 = $f839840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f839840,
"from":L[34]});
}
} catch($e831832) {
if(R.isCont($e831832)) {
var $ss835836 = {"from":L[34],
"go":function(anf_arg112841) {
return $Hanf_arg338842(anf_arg112841,_plus7);
}};
$e831832.stack[R.EXN_STACKHEIGHT++] = $ss835836;
}
if(R.isPyretException($e831832)) {
$e831832.pyretStack.push(L[34]);
}
throw $e831832;
}
var $ret837838 = $Hanf_arg338842($z833834,_plus7);
++R.GAS;
return $ret837838;
};
var $Hanf_arg338842 = function(anf_arg112841,_plus7) {
var $z845846 = D;
var $f851852 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg112841):R.ffi.throwNonFunApp(L[34],_plus7,[("("),anf_arg112841]);
};
try {
if(--R.GAS > 0) {
$z845846 = $f851852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f851852,
"from":L[34]});
}
} catch($e843844) {
if(R.isCont($e843844)) {
var $ss847848 = {"from":L[34],
"go":function(anf_arg113853) {
return $Hanf_arg337854(anf_arg113853,_plus7);
}};
$e843844.stack[R.EXN_STACKHEIGHT++] = $ss847848;
}
if(R.isPyretException($e843844)) {
$e843844.pyretStack.push(L[34]);
}
throw $e843844;
}
var $ret849850 = $Hanf_arg337854($z845846,_plus7);
++R.GAS;
return $ret849850;
};
var $Hanf_arg337854 = function(anf_arg113853,_plus7) {
var $z857858 = D;
var $f863864 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("field-failure"),anf_arg113853):R.ffi.throwNonFunApp(L[34],_plus7,[("field-failure"),anf_arg113853]);
};
try {
if(--R.GAS > 0) {
$z857858 = $f863864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f863864,
"from":L[34]});
}
} catch($e855856) {
if(R.isCont($e855856)) {
var $ss859860 = {"from":L[34],
"go":function(ann_DASH_check_DASH_temp101865) {
return $Hann_DASH_check_DASH_temp336866(ann_DASH_check_DASH_temp101865);
}};
$e855856.stack[R.EXN_STACKHEIGHT++] = $ss859860;
}
if(R.isPyretException($e855856)) {
$e855856.pyretStack.push(L[34]);
}
throw $e855856;
}
var $ret861862 = $Hann_DASH_check_DASH_temp336866($z857858);
++R.GAS;
return $ret861862;
};
var $Hann_DASH_check_DASH_temp336866 = function(ann_DASH_check_DASH_temp101865) {
return ann_DASH_check_DASH_temp101865;
};
var $Hcont_tail_arg334867 = function(cont_tail_arg98868,if_helper88869) {
if(--R.GAS > 0) {
$z870871 = R.isFunction(if_helper88869)?if_helper88869.app(cont_tail_arg98868):R.ffi.throwNonFunApp(L[34],if_helper88869,[cont_tail_arg98868]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper88869)?if_helper88869.app(cont_tail_arg98868):R.ffi.throwNonFunApp(L[34],if_helper88869,[cont_tail_arg98868]);
},
"from":L[34]});
}
++R.GAS;
return $z870871;
};
var $Hcont_tail_arg335872 = function(cont_tail_arg93873,if_helper88869) {
if(--R.GAS > 0) {
$z874875 = R.isFunction(if_helper88869)?if_helper88869.app(cont_tail_arg93873):R.ffi.throwNonFunApp(L[34],if_helper88869,[cont_tail_arg93873]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper88869)?if_helper88869.app(cont_tail_arg93873):R.ffi.throwNonFunApp(L[34],if_helper88869,[cont_tail_arg93873]);
},
"from":L[34]});
}
++R.GAS;
return $z874875;
};
var $Hanf_arg333876 = function(anf_arg72877,self41343,_plus7,tostring11) {
var $z880881 = D;
var $f886887 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Contract Error at "),anf_arg72877):R.ffi.throwNonFunApp(L[35],_plus7,[("Contract Error at "),anf_arg72877]);
};
try {
if(--R.GAS > 0) {
$z880881 = $f886887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f886887,
"from":L[35]});
}
} catch($e878879) {
if(R.isCont($e878879)) {
var $ss882883 = {"from":L[35],
"go":function(anf_arg73888) {
return $Hanf_arg332889(anf_arg73888,self41343,_plus7,tostring11);
}};
$e878879.stack[R.EXN_STACKHEIGHT++] = $ss882883;
}
if(R.isPyretException($e878879)) {
$e878879.pyretStack.push(L[35]);
}
throw $e878879;
}
var $ret884885 = $Hanf_arg332889($z880881,self41343,_plus7,tostring11);
++R.GAS;
return $ret884885;
};
var $Hanf_arg332889 = function(anf_arg73888,self41343,_plus7,tostring11) {
var $z892893 = D;
var $f898899 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg73888,("\n")):R.ffi.throwNonFunApp(L[35],_plus7,[anf_arg73888,("\n")]);
};
try {
if(--R.GAS > 0) {
$z892893 = $f898899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f898899,
"from":L[35]});
}
} catch($e890891) {
if(R.isCont($e890891)) {
var $ss894895 = {"from":L[35],
"go":function(anf_arg74900) {
return $Hanf_arg331901(anf_arg74900,self41343,_plus7,tostring11);
}};
$e890891.stack[R.EXN_STACKHEIGHT++] = $ss894895;
}
if(R.isPyretException($e890891)) {
$e890891.pyretStack.push(L[35]);
}
throw $e890891;
}
var $ret896897 = $Hanf_arg331901($z892893,self41343,_plus7,tostring11);
++R.GAS;
return $ret896897;
};
var $Hanf_arg331901 = function(anf_arg74900,self41343,_plus7,tostring11) {
var anf_arg75912 = G(self41343,"reason",L[37]);
var $z904905 = D;
var $f910911 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg75912):R.ffi.throwNonFunApp(L[36],tostring11,[anf_arg75912]);
};
try {
if(--R.GAS > 0) {
$z904905 = $f910911();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f910911,
"from":L[36]});
}
} catch($e902903) {
if(R.isCont($e902903)) {
var $ss906907 = {"from":L[36],
"go":function(anf_arg76913) {
return $Hanf_arg330914(anf_arg76913,anf_arg74900,_plus7);
}};
$e902903.stack[R.EXN_STACKHEIGHT++] = $ss906907;
}
if(R.isPyretException($e902903)) {
$e902903.pyretStack.push(L[36]);
}
throw $e902903;
}
var $ret908909 = $Hanf_arg330914($z904905,anf_arg74900,_plus7);
++R.GAS;
return $ret908909;
};
var $Hanf_arg330914 = function(anf_arg76913,anf_arg74900,_plus7) {
var $z917918 = D;
var $f923924 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg74900,anf_arg76913):R.ffi.throwNonFunApp(L[38],_plus7,[anf_arg74900,anf_arg76913]);
};
try {
if(--R.GAS > 0) {
$z917918 = $f923924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f923924,
"from":L[38]});
}
} catch($e915916) {
if(R.isCont($e915916)) {
var $ss919920 = {"from":L[38],
"go":function(ann_DASH_check_DASH_temp69925) {
return $Hann_DASH_check_DASH_temp329926(ann_DASH_check_DASH_temp69925);
}};
$e915916.stack[R.EXN_STACKHEIGHT++] = $ss919920;
}
if(R.isPyretException($e915916)) {
$e915916.pyretStack.push(L[38]);
}
throw $e915916;
}
var $ret921922 = $Hann_DASH_check_DASH_temp329926($z917918);
++R.GAS;
return $ret921922;
};
var $Hann_DASH_check_DASH_temp329926 = function(ann_DASH_check_DASH_temp69925) {
return ann_DASH_check_DASH_temp69925;
};
var $Hanf_arg328927 = function(anf_arg61928,self17929,_plus7,torepr10) {
var anf_arg62940 = G(self17929,"reason",L[39]);
var $z932933 = D;
var $f938939 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg62940):R.ffi.throwNonFunApp(L[39],torepr10,[anf_arg62940]);
};
try {
if(--R.GAS > 0) {
$z932933 = $f938939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f938939,
"from":L[39]});
}
} catch($e930931) {
if(R.isCont($e930931)) {
var $ss934935 = {"from":L[39],
"go":function(anf_arg63941) {
return $Hanf_arg327942(anf_arg63941,anf_arg61928,_plus7);
}};
$e930931.stack[R.EXN_STACKHEIGHT++] = $ss934935;
}
if(R.isPyretException($e930931)) {
$e930931.pyretStack.push(L[39]);
}
throw $e930931;
}
var $ret936937 = $Hanf_arg327942($z932933,anf_arg61928,_plus7);
++R.GAS;
return $ret936937;
};
var $Hanf_arg327942 = function(anf_arg63941,anf_arg61928,_plus7) {
var $z945946 = D;
var $f951952 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg63941):R.ffi.throwNonFunApp(L[39],_plus7,[(", "),anf_arg63941]);
};
try {
if(--R.GAS > 0) {
$z945946 = $f951952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f951952,
"from":L[39]});
}
} catch($e943944) {
if(R.isCont($e943944)) {
var $ss947948 = {"from":L[39],
"go":function(anf_arg64953) {
return $Hanf_arg326954(anf_arg64953,anf_arg61928,_plus7);
}};
$e943944.stack[R.EXN_STACKHEIGHT++] = $ss947948;
}
if(R.isPyretException($e943944)) {
$e943944.pyretStack.push(L[39]);
}
throw $e943944;
}
var $ret949950 = $Hanf_arg326954($z945946,anf_arg61928,_plus7);
++R.GAS;
return $ret949950;
};
var $Hanf_arg326954 = function(anf_arg64953,anf_arg61928,_plus7) {
var $z957958 = D;
var $f963964 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg61928,anf_arg64953):R.ffi.throwNonFunApp(L[39],_plus7,[anf_arg61928,anf_arg64953]);
};
try {
if(--R.GAS > 0) {
$z957958 = $f963964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f963964,
"from":L[39]});
}
} catch($e955956) {
if(R.isCont($e955956)) {
var $ss959960 = {"from":L[39],
"go":function(anf_arg65965) {
return $Hanf_arg325966(anf_arg65965,_plus7);
}};
$e955956.stack[R.EXN_STACKHEIGHT++] = $ss959960;
}
if(R.isPyretException($e955956)) {
$e955956.pyretStack.push(L[39]);
}
throw $e955956;
}
var $ret961962 = $Hanf_arg325966($z957958,_plus7);
++R.GAS;
return $ret961962;
};
var $Hanf_arg325966 = function(anf_arg65965,_plus7) {
var $z969970 = D;
var $f975976 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg65965,(")")):R.ffi.throwNonFunApp(L[39],_plus7,[anf_arg65965,(")")]);
};
try {
if(--R.GAS > 0) {
$z969970 = $f975976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f975976,
"from":L[39]});
}
} catch($e967968) {
if(R.isCont($e967968)) {
var $ss971972 = {"from":L[39],
"go":function(anf_arg66977) {
return $Hanf_arg324978(anf_arg66977,_plus7);
}};
$e967968.stack[R.EXN_STACKHEIGHT++] = $ss971972;
}
if(R.isPyretException($e967968)) {
$e967968.pyretStack.push(L[39]);
}
throw $e967968;
}
var $ret973974 = $Hanf_arg324978($z969970,_plus7);
++R.GAS;
return $ret973974;
};
var $Hanf_arg324978 = function(anf_arg66977,_plus7) {
var $z981982 = D;
var $f987988 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg66977):R.ffi.throwNonFunApp(L[39],_plus7,[("("),anf_arg66977]);
};
try {
if(--R.GAS > 0) {
$z981982 = $f987988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f987988,
"from":L[39]});
}
} catch($e979980) {
if(R.isCont($e979980)) {
var $ss983984 = {"from":L[39],
"go":function(anf_arg67989) {
return $Hanf_arg323990(anf_arg67989,_plus7);
}};
$e979980.stack[R.EXN_STACKHEIGHT++] = $ss983984;
}
if(R.isPyretException($e979980)) {
$e979980.pyretStack.push(L[39]);
}
throw $e979980;
}
var $ret985986 = $Hanf_arg323990($z981982,_plus7);
++R.GAS;
return $ret985986;
};
var $Hanf_arg323990 = function(anf_arg67989,_plus7) {
var $z993994 = D;
var $f9991000 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("fail-arg"),anf_arg67989):R.ffi.throwNonFunApp(L[39],_plus7,[("fail-arg"),anf_arg67989]);
};
try {
if(--R.GAS > 0) {
$z993994 = $f9991000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9991000,
"from":L[39]});
}
} catch($e991992) {
if(R.isCont($e991992)) {
var $ss995996 = {"from":L[39],
"go":function(ann_DASH_check_DASH_temp591001) {
return $Hann_DASH_check_DASH_temp3221002(ann_DASH_check_DASH_temp591001);
}};
$e991992.stack[R.EXN_STACKHEIGHT++] = $ss995996;
}
if(R.isPyretException($e991992)) {
$e991992.pyretStack.push(L[39]);
}
throw $e991992;
}
var $ret997998 = $Hann_DASH_check_DASH_temp3221002($z993994);
++R.GAS;
return $ret997998;
};
var $Hann_DASH_check_DASH_temp3221002 = function(ann_DASH_check_DASH_temp591001) {
return ann_DASH_check_DASH_temp591001;
};
var $Hcont_tail_arg3201003 = function(cont_tail_arg561004,if_helper471005) {
if(--R.GAS > 0) {
$z10061007 = R.isFunction(if_helper471005)?if_helper471005.app(cont_tail_arg561004):R.ffi.throwNonFunApp(L[39],if_helper471005,[cont_tail_arg561004]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper471005)?if_helper471005.app(cont_tail_arg561004):R.ffi.throwNonFunApp(L[39],if_helper471005,[cont_tail_arg561004]);
},
"from":L[39]});
}
++R.GAS;
return $z10061007;
};
var $Hcont_tail_arg3211008 = function(cont_tail_arg521009,if_helper471005) {
if(--R.GAS > 0) {
$z10101011 = R.isFunction(if_helper471005)?if_helper471005.app(cont_tail_arg521009):R.ffi.throwNonFunApp(L[39],if_helper471005,[cont_tail_arg521009]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper471005)?if_helper471005.app(cont_tail_arg521009):R.ffi.throwNonFunApp(L[39],if_helper471005,[cont_tail_arg521009]);
},
"from":L[39]});
}
++R.GAS;
return $z10101011;
};
var $Hanf_arg3191012 = function(anf_arg401013,self381014,_plus7,tostring11) {
var $z10171018 = D;
var $f10231024 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Contract Error at "),anf_arg401013):R.ffi.throwNonFunApp(L[40],_plus7,[("Contract Error at "),anf_arg401013]);
};
try {
if(--R.GAS > 0) {
$z10171018 = $f10231024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10231024,
"from":L[40]});
}
} catch($e10151016) {
if(R.isCont($e10151016)) {
var $ss10191020 = {"from":L[40],
"go":function(anf_arg411025) {
return $Hanf_arg3181026(anf_arg411025,self381014,_plus7,tostring11);
}};
$e10151016.stack[R.EXN_STACKHEIGHT++] = $ss10191020;
}
if(R.isPyretException($e10151016)) {
$e10151016.pyretStack.push(L[40]);
}
throw $e10151016;
}
var $ret10211022 = $Hanf_arg3181026($z10171018,self381014,_plus7,tostring11);
++R.GAS;
return $ret10211022;
};
var $Hanf_arg3181026 = function(anf_arg411025,self381014,_plus7,tostring11) {
var $z10291030 = D;
var $f10351036 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg411025,("\n")):R.ffi.throwNonFunApp(L[40],_plus7,[anf_arg411025,("\n")]);
};
try {
if(--R.GAS > 0) {
$z10291030 = $f10351036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10351036,
"from":L[40]});
}
} catch($e10271028) {
if(R.isCont($e10271028)) {
var $ss10311032 = {"from":L[40],
"go":function(anf_arg421037) {
return $Hanf_arg3171038(anf_arg421037,self381014,_plus7,tostring11);
}};
$e10271028.stack[R.EXN_STACKHEIGHT++] = $ss10311032;
}
if(R.isPyretException($e10271028)) {
$e10271028.pyretStack.push(L[40]);
}
throw $e10271028;
}
var $ret10331034 = $Hanf_arg3171038($z10291030,self381014,_plus7,tostring11);
++R.GAS;
return $ret10331034;
};
var $Hanf_arg3171038 = function(anf_arg421037,self381014,_plus7,tostring11) {
var anf_arg431049 = G(self381014,"reason",L[42]);
var $z10411042 = D;
var $f10471048 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg431049):R.ffi.throwNonFunApp(L[41],tostring11,[anf_arg431049]);
};
try {
if(--R.GAS > 0) {
$z10411042 = $f10471048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10471048,
"from":L[41]});
}
} catch($e10391040) {
if(R.isCont($e10391040)) {
var $ss10431044 = {"from":L[41],
"go":function(anf_arg441050) {
return $Hanf_arg3161051(anf_arg441050,anf_arg421037,_plus7);
}};
$e10391040.stack[R.EXN_STACKHEIGHT++] = $ss10431044;
}
if(R.isPyretException($e10391040)) {
$e10391040.pyretStack.push(L[41]);
}
throw $e10391040;
}
var $ret10451046 = $Hanf_arg3161051($z10411042,anf_arg421037,_plus7);
++R.GAS;
return $ret10451046;
};
var $Hanf_arg3161051 = function(anf_arg441050,anf_arg421037,_plus7) {
var $z10541055 = D;
var $f10601061 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg421037,anf_arg441050):R.ffi.throwNonFunApp(L[43],_plus7,[anf_arg421037,anf_arg441050]);
};
try {
if(--R.GAS > 0) {
$z10541055 = $f10601061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10601061,
"from":L[43]});
}
} catch($e10521053) {
if(R.isCont($e10521053)) {
var $ss10561057 = {"from":L[43],
"go":function(ann_DASH_check_DASH_temp371062) {
return $Hann_DASH_check_DASH_temp3151063(ann_DASH_check_DASH_temp371062);
}};
$e10521053.stack[R.EXN_STACKHEIGHT++] = $ss10561057;
}
if(R.isPyretException($e10521053)) {
$e10521053.pyretStack.push(L[43]);
}
throw $e10521053;
}
var $ret10581059 = $Hann_DASH_check_DASH_temp3151063($z10541055);
++R.GAS;
return $ret10581059;
};
var $Hann_DASH_check_DASH_temp3151063 = function(ann_DASH_check_DASH_temp371062) {
return ann_DASH_check_DASH_temp371062;
};
var $Hanf_arg3141064 = function(anf_arg291065,self111066,_plus7,torepr10) {
var anf_arg301077 = G(self111066,"reason",L[44]);
var $z10691070 = D;
var $f10751076 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg301077):R.ffi.throwNonFunApp(L[44],torepr10,[anf_arg301077]);
};
try {
if(--R.GAS > 0) {
$z10691070 = $f10751076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10751076,
"from":L[44]});
}
} catch($e10671068) {
if(R.isCont($e10671068)) {
var $ss10711072 = {"from":L[44],
"go":function(anf_arg311078) {
return $Hanf_arg3131079(anf_arg311078,anf_arg291065,_plus7);
}};
$e10671068.stack[R.EXN_STACKHEIGHT++] = $ss10711072;
}
if(R.isPyretException($e10671068)) {
$e10671068.pyretStack.push(L[44]);
}
throw $e10671068;
}
var $ret10731074 = $Hanf_arg3131079($z10691070,anf_arg291065,_plus7);
++R.GAS;
return $ret10731074;
};
var $Hanf_arg3131079 = function(anf_arg311078,anf_arg291065,_plus7) {
var $z10821083 = D;
var $f10881089 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg311078):R.ffi.throwNonFunApp(L[44],_plus7,[(", "),anf_arg311078]);
};
try {
if(--R.GAS > 0) {
$z10821083 = $f10881089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10881089,
"from":L[44]});
}
} catch($e10801081) {
if(R.isCont($e10801081)) {
var $ss10841085 = {"from":L[44],
"go":function(anf_arg321090) {
return $Hanf_arg3121091(anf_arg321090,anf_arg291065,_plus7);
}};
$e10801081.stack[R.EXN_STACKHEIGHT++] = $ss10841085;
}
if(R.isPyretException($e10801081)) {
$e10801081.pyretStack.push(L[44]);
}
throw $e10801081;
}
var $ret10861087 = $Hanf_arg3121091($z10821083,anf_arg291065,_plus7);
++R.GAS;
return $ret10861087;
};
var $Hanf_arg3121091 = function(anf_arg321090,anf_arg291065,_plus7) {
var $z10941095 = D;
var $f11001101 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg291065,anf_arg321090):R.ffi.throwNonFunApp(L[44],_plus7,[anf_arg291065,anf_arg321090]);
};
try {
if(--R.GAS > 0) {
$z10941095 = $f11001101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11001101,
"from":L[44]});
}
} catch($e10921093) {
if(R.isCont($e10921093)) {
var $ss10961097 = {"from":L[44],
"go":function(anf_arg331102) {
return $Hanf_arg3111103(anf_arg331102,_plus7);
}};
$e10921093.stack[R.EXN_STACKHEIGHT++] = $ss10961097;
}
if(R.isPyretException($e10921093)) {
$e10921093.pyretStack.push(L[44]);
}
throw $e10921093;
}
var $ret10981099 = $Hanf_arg3111103($z10941095,_plus7);
++R.GAS;
return $ret10981099;
};
var $Hanf_arg3111103 = function(anf_arg331102,_plus7) {
var $z11061107 = D;
var $f11121113 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg331102,(")")):R.ffi.throwNonFunApp(L[44],_plus7,[anf_arg331102,(")")]);
};
try {
if(--R.GAS > 0) {
$z11061107 = $f11121113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11121113,
"from":L[44]});
}
} catch($e11041105) {
if(R.isCont($e11041105)) {
var $ss11081109 = {"from":L[44],
"go":function(anf_arg341114) {
return $Hanf_arg3101115(anf_arg341114,_plus7);
}};
$e11041105.stack[R.EXN_STACKHEIGHT++] = $ss11081109;
}
if(R.isPyretException($e11041105)) {
$e11041105.pyretStack.push(L[44]);
}
throw $e11041105;
}
var $ret11101111 = $Hanf_arg3101115($z11061107,_plus7);
++R.GAS;
return $ret11101111;
};
var $Hanf_arg3101115 = function(anf_arg341114,_plus7) {
var $z11181119 = D;
var $f11241125 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg341114):R.ffi.throwNonFunApp(L[44],_plus7,[("("),anf_arg341114]);
};
try {
if(--R.GAS > 0) {
$z11181119 = $f11241125();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11241125,
"from":L[44]});
}
} catch($e11161117) {
if(R.isCont($e11161117)) {
var $ss11201121 = {"from":L[44],
"go":function(anf_arg351126) {
return $Hanf_arg3091127(anf_arg351126,_plus7);
}};
$e11161117.stack[R.EXN_STACKHEIGHT++] = $ss11201121;
}
if(R.isPyretException($e11161117)) {
$e11161117.pyretStack.push(L[44]);
}
throw $e11161117;
}
var $ret11221123 = $Hanf_arg3091127($z11181119,_plus7);
++R.GAS;
return $ret11221123;
};
var $Hanf_arg3091127 = function(anf_arg351126,_plus7) {
var $z11301131 = D;
var $f11361137 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("fail"),anf_arg351126):R.ffi.throwNonFunApp(L[44],_plus7,[("fail"),anf_arg351126]);
};
try {
if(--R.GAS > 0) {
$z11301131 = $f11361137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11361137,
"from":L[44]});
}
} catch($e11281129) {
if(R.isCont($e11281129)) {
var $ss11321133 = {"from":L[44],
"go":function(ann_DASH_check_DASH_temp271138) {
return $Hann_DASH_check_DASH_temp3081139(ann_DASH_check_DASH_temp271138);
}};
$e11281129.stack[R.EXN_STACKHEIGHT++] = $ss11321133;
}
if(R.isPyretException($e11281129)) {
$e11281129.pyretStack.push(L[44]);
}
throw $e11281129;
}
var $ret11341135 = $Hann_DASH_check_DASH_temp3081139($z11301131);
++R.GAS;
return $ret11341135;
};
var $Hann_DASH_check_DASH_temp3081139 = function(ann_DASH_check_DASH_temp271138) {
return ann_DASH_check_DASH_temp271138;
};
var $Hcont_tail_arg3061140 = function(cont_tail_arg241141,if_helper151142) {
if(--R.GAS > 0) {
$z11431144 = R.isFunction(if_helper151142)?if_helper151142.app(cont_tail_arg241141):R.ffi.throwNonFunApp(L[44],if_helper151142,[cont_tail_arg241141]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper151142)?if_helper151142.app(cont_tail_arg241141):R.ffi.throwNonFunApp(L[44],if_helper151142,[cont_tail_arg241141]);
},
"from":L[44]});
}
++R.GAS;
return $z11431144;
};
var $Hcont_tail_arg3071145 = function(cont_tail_arg201146,if_helper151142) {
if(--R.GAS > 0) {
$z11471148 = R.isFunction(if_helper151142)?if_helper151142.app(cont_tail_arg201146):R.ffi.throwNonFunApp(L[44],if_helper151142,[cont_tail_arg201146]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper151142)?if_helper151142.app(cont_tail_arg201146):R.ffi.throwNonFunApp(L[44],if_helper151142,[cont_tail_arg201146]);
},
"from":L[44]});
}
++R.GAS;
return $z11471148;
};
var $Hcont_tail_arg3041149 = function(cont_tail_arg91150,if_helper21151) {
if(--R.GAS > 0) {
$z11521153 = R.isFunction(if_helper21151)?if_helper21151.app(cont_tail_arg91150):R.ffi.throwNonFunApp(L[45],if_helper21151,[cont_tail_arg91150]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper21151)?if_helper21151.app(cont_tail_arg91150):R.ffi.throwNonFunApp(L[45],if_helper21151,[cont_tail_arg91150]);
},
"from":L[45]});
}
++R.GAS;
return $z11521153;
};
var $Hcont_tail_arg3051154 = function(cont_tail_arg71155,if_helper21151) {
if(--R.GAS > 0) {
$z11561157 = R.isFunction(if_helper21151)?if_helper21151.app(cont_tail_arg71155):R.ffi.throwNonFunApp(L[45],if_helper21151,[cont_tail_arg71155]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper21151)?if_helper21151.app(cont_tail_arg71155):R.ffi.throwNonFunApp(L[45],if_helper21151,[cont_tail_arg71155]);
},
"from":L[45]});
}
++R.GAS;
return $z11561157;
};
return R.loadModulesNew(NAMESPACE,[$L11316],function($L11316) {
var L113 = R.getField($L11316,"values");
var L214 = R.getField($L11316,"types");
return R.safeCall(function() {
var ContractResultT141158 = R.namedBrander("ContractResult");
var ContractResult319 = R.makeBranderAnn(ContractResultT141158,"ContractResult");
var FieldFailureT261159 = R.namedBrander("FieldFailure");
var FieldFailure521 = R.makeBranderAnn(FieldFailureT261159,"FieldFailure");
var FailureReasonT381160 = R.namedBrander("FailureReason");
var FailureReason720 = R.makeBranderAnn(FailureReasonT381160,"FailureReason");
var ContractResult491161 = {"$var":D,
"$name":"ContractResult4"};
var ContractResult101163 = {"$var":D,
"$name":"ContractResult"};
var is_DASH_ContractResult111165 = {"$var":D,
"$name":"is-ContractResult"};
var is_DASH_ok121167 = {"$var":D,
"$name":"is-ok"};
var ok131169 = {"$var":D,
"$name":"ok"};
var is_DASH_fail141171 = {"$var":D,
"$name":"is-fail"};
var fail151173 = {"$var":D,
"$name":"fail"};
var is_DASH_fail_DASH_arg161175 = {"$var":D,
"$name":"is-fail-arg"};
var fail_DASH_arg171177 = {"$var":D,
"$name":"fail-arg"};
var FieldFailure5181179 = {"$var":D,
"$name":"FieldFailure5"};
var FieldFailure191181 = {"$var":D,
"$name":"FieldFailure"};
var is_DASH_FieldFailure201183 = {"$var":D,
"$name":"is-FieldFailure"};
var is_DASH_field_DASH_failure211185 = {"$var":D,
"$name":"is-field-failure"};
var field_DASH_failure221187 = {"$var":D,
"$name":"field-failure"};
var is_DASH_missing_DASH_field231189 = {"$var":D,
"$name":"is-missing-field"};
var missing_DASH_field241191 = {"$var":D,
"$name":"missing-field"};
var FailureReason6251193 = {"$var":D,
"$name":"FailureReason6"};
var FailureReason261195 = {"$var":D,
"$name":"FailureReason"};
var is_DASH_FailureReason271197 = {"$var":D,
"$name":"is-FailureReason"};
var is_DASH_type_DASH_mismatch281199 = {"$var":D,
"$name":"is-type-mismatch"};
var type_DASH_mismatch291201 = {"$var":D,
"$name":"type-mismatch"};
var is_DASH_predicate_DASH_failure301203 = {"$var":D,
"$name":"is-predicate-failure"};
var predicate_DASH_failure311205 = {"$var":D,
"$name":"predicate-failure"};
var is_DASH_record_DASH_fields_DASH_fail321207 = {"$var":D,
"$name":"is-record-fields-fail"};
var record_DASH_fields_DASH_fail331209 = {"$var":D,
"$name":"record-fields-fail"};
var is_DASH_dot_DASH_ann_DASH_not_DASH_present341211 = {"$var":D,
"$name":"is-dot-ann-not-present"};
var dot_DASH_ann_DASH_not_DASH_present351213 = {"$var":D,
"$name":"dot-ann-not-present"};
var anf_singleton_variant_member111623 = R.makeMethod(function(self21789) {
return function(cases_DASH_funs31770,else_DASH_clause41781) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[45],2,arguments);
}
var if_DASH_61782 = R.hasField(cases_DASH_funs31770,("ok"));
var if_helper21151 = R.makeFunction(function(if_helper_arg31787) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[45],1,arguments);
}
var ann_DASH_check_DASH_temp11788 = if_helper_arg31787;
return ann_DASH_check_DASH_temp11788;
});
var anf_if61786 = R.isBoolean(if_DASH_61782);
if(R.isPyretTrue(anf_if61786)) {
if(R.isPyretTrue(if_DASH_61782)) {
var call_DASH_ok11769 = G(cases_DASH_funs31770,"ok",L[45]);
var $z17611762 = D;
var $f17671768 = function(_) {
return R.isFunction(call_DASH_ok11769)?call_DASH_ok11769.app():R.ffi.throwNonFunApp(L[45],call_DASH_ok11769,[]);
};
try {
if(--R.GAS > 0) {
$z17611762 = $f17671768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17671768,
"from":L[45]});
}
} catch($e17591760) {
if(R.isCont($e17591760)) {
var $ss17631764 = {"from":L[45],
"go":function(cont_tail_arg91150) {
return $Hcont_tail_arg3041149(cont_tail_arg91150,if_helper21151);
}};
$e17591760.stack[R.EXN_STACKHEIGHT++] = $ss17631764;
}
if(R.isPyretException($e17591760)) {
$e17591760.pyretStack.push(L[45]);
}
throw $e17591760;
}
var $ret17651766 = $Hcont_tail_arg3041149($z17611762,if_helper21151);
++R.GAS;
return $ret17651766;
} else {
var $z17731774 = D;
var $f17791780 = function(_) {
return R.isFunction(else_DASH_clause41781)?else_DASH_clause41781.app():R.ffi.throwNonFunApp(L[45],else_DASH_clause41781,[]);
};
try {
if(--R.GAS > 0) {
$z17731774 = $f17791780();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17791780,
"from":L[45]});
}
} catch($e17711772) {
if(R.isCont($e17711772)) {
var $ss17751776 = {"from":L[45],
"go":function(cont_tail_arg71155) {
return $Hcont_tail_arg3051154(cont_tail_arg71155,if_helper21151);
}};
$e17711772.stack[R.EXN_STACKHEIGHT++] = $ss17751776;
}
if(R.isPyretException($e17711772)) {
$e17711772.pyretStack.push(L[45]);
}
throw $e17711772;
}
var $ret17771778 = $Hcont_tail_arg3051154($z17731774,if_helper21151);
++R.GAS;
return $ret17771778;
}
} else {
var cont_tail_arg41785 = R.throwNonBooleanCondition(L[45],("if"),if_DASH_61782);
if(--R.GAS > 0) {
$z17831784 = R.isFunction(if_helper21151)?if_helper21151.app(cont_tail_arg41785):R.ffi.throwNonFunApp(L[45],if_helper21151,[cont_tail_arg41785]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper21151)?if_helper21151.app(cont_tail_arg41785):R.ffi.throwNonFunApp(L[45],if_helper21151,[cont_tail_arg41785]);
},
"from":L[45]});
}
++R.GAS;
return $z17831784;
}
};
},{"length":3});
var anf_singleton_variant_member131624 = R.makeMethod(function(self51758) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[45],0,arguments);
}
var ann_DASH_check_DASH_temp121757 = ("ok");
return ann_DASH_check_DASH_temp121757;
};
},{"length":1});
var anf_variant_member261630 = R.makeMethod(function(self81737) {
return function(cases_DASH_funs91738,else_DASH_clause101749) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[44],2,arguments);
}
var if_DASH_121750 = R.hasField(cases_DASH_funs91738,("fail"));
var if_helper151142 = R.makeFunction(function(if_helper_arg161755) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[44],1,arguments);
}
var ann_DASH_check_DASH_temp141756 = if_helper_arg161755;
return ann_DASH_check_DASH_temp141756;
});
var anf_if191754 = R.isBoolean(if_DASH_121750);
if(R.isPyretTrue(anf_if191754)) {
if(R.isPyretTrue(if_DASH_121750)) {
var call_DASH_fail71734 = G(cases_DASH_funs91738,"fail",L[44]);
var anf_arg221735 = G(self81737,"loc",L[92]);
var anf_arg231736 = G(self81737,"reason",L[91]);
var $z17261727 = D;
var $f17321733 = function(_) {
return R.isFunction(call_DASH_fail71734)?call_DASH_fail71734.app(anf_arg221735,anf_arg231736):R.ffi.throwNonFunApp(L[44],call_DASH_fail71734,[anf_arg221735,anf_arg231736]);
};
try {
if(--R.GAS > 0) {
$z17261727 = $f17321733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17321733,
"from":L[44]});
}
} catch($e17241725) {
if(R.isCont($e17241725)) {
var $ss17281729 = {"from":L[44],
"go":function(cont_tail_arg241141) {
return $Hcont_tail_arg3061140(cont_tail_arg241141,if_helper151142);
}};
$e17241725.stack[R.EXN_STACKHEIGHT++] = $ss17281729;
}
if(R.isPyretException($e17241725)) {
$e17241725.pyretStack.push(L[44]);
}
throw $e17241725;
}
var $ret17301731 = $Hcont_tail_arg3061140($z17261727,if_helper151142);
++R.GAS;
return $ret17301731;
} else {
var $z17411742 = D;
var $f17471748 = function(_) {
return R.isFunction(else_DASH_clause101749)?else_DASH_clause101749.app():R.ffi.throwNonFunApp(L[44],else_DASH_clause101749,[]);
};
try {
if(--R.GAS > 0) {
$z17411742 = $f17471748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17471748,
"from":L[44]});
}
} catch($e17391740) {
if(R.isCont($e17391740)) {
var $ss17431744 = {"from":L[44],
"go":function(cont_tail_arg201146) {
return $Hcont_tail_arg3071145(cont_tail_arg201146,if_helper151142);
}};
$e17391740.stack[R.EXN_STACKHEIGHT++] = $ss17431744;
}
if(R.isPyretException($e17391740)) {
$e17391740.pyretStack.push(L[44]);
}
throw $e17391740;
}
var $ret17451746 = $Hcont_tail_arg3071145($z17411742,if_helper151142);
++R.GAS;
return $ret17451746;
}
} else {
var cont_tail_arg171753 = R.throwNonBooleanCondition(L[44],("if"),if_DASH_121750);
if(--R.GAS > 0) {
$z17511752 = R.isFunction(if_helper151142)?if_helper151142.app(cont_tail_arg171753):R.ffi.throwNonFunApp(L[44],if_helper151142,[cont_tail_arg171753]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper151142)?if_helper151142.app(cont_tail_arg171753):R.ffi.throwNonFunApp(L[44],if_helper151142,[cont_tail_arg171753]);
},
"from":L[44]});
}
++R.GAS;
return $z17511752;
}
};
},{"length":3});
var anf_variant_member361631 = R.makeMethod(function(self111066) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[44],0,arguments);
}
var anf_arg281723 = G(self111066,"loc",L[44]);
var $z17151716 = D;
var $f17211722 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg281723):R.ffi.throwNonFunApp(L[44],torepr10,[anf_arg281723]);
};
try {
if(--R.GAS > 0) {
$z17151716 = $f17211722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17211722,
"from":L[44]});
}
} catch($e17131714) {
if(R.isCont($e17131714)) {
var $ss17171718 = {"from":L[44],
"go":function(anf_arg291065) {
return $Hanf_arg3141064(anf_arg291065,self111066,_plus7,torepr10);
}};
$e17131714.stack[R.EXN_STACKHEIGHT++] = $ss17171718;
}
if(R.isPyretException($e17131714)) {
$e17131714.pyretStack.push(L[44]);
}
throw $e17131714;
}
var $ret17191720 = $Hanf_arg3141064($z17151716,self111066,_plus7,torepr10);
++R.GAS;
return $ret17191720;
};
},{"length":1});
var anf_variant_member451632 = R.makeMethod(function(self381014) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[43],0,arguments);
}
var anf_bracket381712 = G(self381014,"loc",L[90]);
var anf_fun391711 = G(anf_bracket381712,"format",L[89]);
var $z17031704 = D;
var $f17091710 = function(_) {
return R.isFunction(anf_fun391711)?anf_fun391711.app((true)):R.ffi.throwNonFunApp(L[88],anf_fun391711,[(true)]);
};
try {
if(--R.GAS > 0) {
$z17031704 = $f17091710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17091710,
"from":L[88]});
}
} catch($e17011702) {
if(R.isCont($e17011702)) {
var $ss17051706 = {"from":L[88],
"go":function(anf_arg401013) {
return $Hanf_arg3191012(anf_arg401013,self381014,_plus7,tostring11);
}};
$e17011702.stack[R.EXN_STACKHEIGHT++] = $ss17051706;
}
if(R.isPyretException($e17011702)) {
$e17011702.pyretStack.push(L[88]);
}
throw $e17011702;
}
var $ret17071708 = $Hanf_arg3191012($z17031704,self381014,_plus7,tostring11);
++R.GAS;
return $ret17071708;
};
},{"length":1});
var anf_variant_member581640 = R.makeMethod(function(self141681) {
return function(cases_DASH_funs151682,else_DASH_clause161693) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[39],2,arguments);
}
var if_DASH_181694 = R.hasField(cases_DASH_funs151682,("fail-arg"));
var if_helper471005 = R.makeFunction(function(if_helper_arg481699) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[39],1,arguments);
}
var ann_DASH_check_DASH_temp461700 = if_helper_arg481699;
return ann_DASH_check_DASH_temp461700;
});
var anf_if511698 = R.isBoolean(if_DASH_181694);
if(R.isPyretTrue(anf_if511698)) {
if(R.isPyretTrue(if_DASH_181694)) {
var call_DASH_fail_DASH_arg131678 = G(cases_DASH_funs151682,"fail-arg",L[39]);
var anf_arg541679 = G(self141681,"loc",L[87]);
var anf_arg551680 = G(self141681,"reason",L[86]);
var $z16701671 = D;
var $f16761677 = function(_) {
return R.isFunction(call_DASH_fail_DASH_arg131678)?call_DASH_fail_DASH_arg131678.app(anf_arg541679,anf_arg551680):R.ffi.throwNonFunApp(L[39],call_DASH_fail_DASH_arg131678,[anf_arg541679,anf_arg551680]);
};
try {
if(--R.GAS > 0) {
$z16701671 = $f16761677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16761677,
"from":L[39]});
}
} catch($e16681669) {
if(R.isCont($e16681669)) {
var $ss16721673 = {"from":L[39],
"go":function(cont_tail_arg561004) {
return $Hcont_tail_arg3201003(cont_tail_arg561004,if_helper471005);
}};
$e16681669.stack[R.EXN_STACKHEIGHT++] = $ss16721673;
}
if(R.isPyretException($e16681669)) {
$e16681669.pyretStack.push(L[39]);
}
throw $e16681669;
}
var $ret16741675 = $Hcont_tail_arg3201003($z16701671,if_helper471005);
++R.GAS;
return $ret16741675;
} else {
var $z16851686 = D;
var $f16911692 = function(_) {
return R.isFunction(else_DASH_clause161693)?else_DASH_clause161693.app():R.ffi.throwNonFunApp(L[39],else_DASH_clause161693,[]);
};
try {
if(--R.GAS > 0) {
$z16851686 = $f16911692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16911692,
"from":L[39]});
}
} catch($e16831684) {
if(R.isCont($e16831684)) {
var $ss16871688 = {"from":L[39],
"go":function(cont_tail_arg521009) {
return $Hcont_tail_arg3211008(cont_tail_arg521009,if_helper471005);
}};
$e16831684.stack[R.EXN_STACKHEIGHT++] = $ss16871688;
}
if(R.isPyretException($e16831684)) {
$e16831684.pyretStack.push(L[39]);
}
throw $e16831684;
}
var $ret16891690 = $Hcont_tail_arg3211008($z16851686,if_helper471005);
++R.GAS;
return $ret16891690;
}
} else {
var cont_tail_arg491697 = R.throwNonBooleanCondition(L[39],("if"),if_DASH_181694);
if(--R.GAS > 0) {
$z16951696 = R.isFunction(if_helper471005)?if_helper471005.app(cont_tail_arg491697):R.ffi.throwNonFunApp(L[39],if_helper471005,[cont_tail_arg491697]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper471005)?if_helper471005.app(cont_tail_arg491697):R.ffi.throwNonFunApp(L[39],if_helper471005,[cont_tail_arg491697]);
},
"from":L[39]});
}
++R.GAS;
return $z16951696;
}
};
},{"length":3});
var anf_variant_member681641 = R.makeMethod(function(self17929) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[39],0,arguments);
}
var anf_arg601667 = G(self17929,"loc",L[39]);
var $z16591660 = D;
var $f16651666 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg601667):R.ffi.throwNonFunApp(L[39],torepr10,[anf_arg601667]);
};
try {
if(--R.GAS > 0) {
$z16591660 = $f16651666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16651666,
"from":L[39]});
}
} catch($e16571658) {
if(R.isCont($e16571658)) {
var $ss16611662 = {"from":L[39],
"go":function(anf_arg61928) {
return $Hanf_arg328927(anf_arg61928,self17929,_plus7,torepr10);
}};
$e16571658.stack[R.EXN_STACKHEIGHT++] = $ss16611662;
}
if(R.isPyretException($e16571658)) {
$e16571658.pyretStack.push(L[39]);
}
throw $e16571658;
}
var $ret16631664 = $Hanf_arg328927($z16591660,self17929,_plus7,torepr10);
++R.GAS;
return $ret16631664;
};
},{"length":1});
var anf_variant_member771642 = R.makeMethod(function(self41343) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[38],0,arguments);
}
var anf_bracket701656 = G(self41343,"loc",L[85]);
var anf_fun711655 = G(anf_bracket701656,"format",L[84]);
var $z16471648 = D;
var $f16531654 = function(_) {
return R.isFunction(anf_fun711655)?anf_fun711655.app((true)):R.ffi.throwNonFunApp(L[83],anf_fun711655,[(true)]);
};
try {
if(--R.GAS > 0) {
$z16471648 = $f16531654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16531654,
"from":L[83]});
}
} catch($e16451646) {
if(R.isCont($e16451646)) {
var $ss16491650 = {"from":L[83],
"go":function(anf_arg72877) {
return $Hanf_arg333876(anf_arg72877,self41343,_plus7,tostring11);
}};
$e16451646.stack[R.EXN_STACKHEIGHT++] = $ss16491650;
}
if(R.isPyretException($e16451646)) {
$e16451646.pyretStack.push(L[83]);
}
throw $e16451646;
}
var $ret16511652 = $Hanf_arg333876($z16471648,self41343,_plus7,tostring11);
++R.GAS;
return $ret16511652;
};
},{"length":1});
var anf_assign781162 = (function() {
var $ok_DASH_base16181619 = {"_match":anf_singleton_variant_member111623,
"_torepr":anf_singleton_variant_member131624};
var $ok_DASH_brands16211622 = {"$brand-ok1620":true};
$ok_DASH_brands16211622[ContractResultT141158._brand] = true
var $fail_DASH_base16251626 = {"_match":anf_variant_member261630,
"_torepr":anf_variant_member361631,
"tostring":anf_variant_member451632};
var $fail_DASH_brands16281629 = {"$brand-fail1627":true};
$fail_DASH_brands16281629[ContractResultT141158._brand] = true
var $fail_DASH_arg_DASH_base16351636 = {"_match":anf_variant_member581640,
"_torepr":anf_variant_member681641,
"tostring":anf_variant_member771642};
var $fail_DASH_arg_DASH_brands16381639 = {"$brand-fail-arg1637":true};
$fail_DASH_arg_DASH_brands16381639[ContractResultT141158._brand] = true
return R.makeObject({"ContractResult":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ContractResultT141158._brand));
}),
"is-ok":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[45],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-ok1620"));
}),
"ok":R.makeBrandedObject($ok_DASH_base16181619,$ok_DASH_brands16211622),
"is-fail":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[44],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-fail1627"));
}),
"fail":R.makeFunction(function(loc361633,reason371634) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[79],2,arguments);
}
return R.checkAnnArgs([FailureReason720],[reason371634],[L[80]],function() {
var dict = R.create($fail_DASH_base16251626);
dict["loc"] = loc361633
dict["reason"] = reason371634
return R.makeBrandedObject(dict,$fail_DASH_brands16281629);
});
}),
"is-fail-arg":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[39],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-fail-arg1637"));
}),
"fail-arg":R.makeFunction(function(loc391643,reason401644) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[81],2,arguments);
}
return R.checkAnnArgs([FailureReason720],[reason401644],[L[82]],function() {
var dict = R.create($fail_DASH_arg_DASH_base16351636);
dict["loc"] = loc391643
dict["reason"] = reason401644
return R.makeBrandedObject(dict,$fail_DASH_arg_DASH_brands16381639);
});
})});
})();
ContractResult491161.$var = anf_assign781162;
var anf_assign791164 = G(ContractResult491161.$var,"ContractResult",L[0]);
ContractResult101163.$var = anf_assign791164;
var anf_assign801166 = G(ContractResult491161.$var,"ContractResult",L[0]);
is_DASH_ContractResult111165.$var = anf_assign801166;
var anf_assign811168 = G(ContractResult491161.$var,"is-ok",L[45]);
is_DASH_ok121167.$var = anf_assign811168;
var anf_assign821170 = G(ContractResult491161.$var,"ok",L[45]);
ok131169.$var = anf_assign821170;
var anf_assign831172 = G(ContractResult491161.$var,"is-fail",L[44]);
is_DASH_fail141171.$var = anf_assign831172;
var anf_assign841174 = G(ContractResult491161.$var,"fail",L[44]);
fail151173.$var = anf_assign841174;
var anf_assign851176 = G(ContractResult491161.$var,"is-fail-arg",L[39]);
is_DASH_fail_DASH_arg161175.$var = anf_assign851176;
var anf_assign861178 = G(ContractResult491161.$var,"fail-arg",L[39]);
fail_DASH_arg171177.$var = anf_assign861178;
var anf_variant_member1001490 = R.makeMethod(function(self201598) {
return function(cases_DASH_funs211599,else_DASH_clause221610) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[34],2,arguments);
}
var if_DASH_241611 = R.hasField(cases_DASH_funs211599,("field-failure"));
var if_helper88869 = R.makeFunction(function(if_helper_arg891616) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[34],1,arguments);
}
var ann_DASH_check_DASH_temp871617 = if_helper_arg891616;
return ann_DASH_check_DASH_temp871617;
});
var anf_if921615 = R.isBoolean(if_DASH_241611);
if(R.isPyretTrue(anf_if921615)) {
if(R.isPyretTrue(if_DASH_241611)) {
var call_DASH_field_DASH_failure191594 = G(cases_DASH_funs211599,"field-failure",L[34]);
var anf_arg951595 = G(self201598,"loc",L[78]);
var anf_arg961596 = G(self201598,"field",L[77]);
var anf_arg971597 = G(self201598,"reason",L[76]);
var $z15861587 = D;
var $f15921593 = function(_) {
return R.isFunction(call_DASH_field_DASH_failure191594)?call_DASH_field_DASH_failure191594.app(anf_arg951595,anf_arg961596,anf_arg971597):R.ffi.throwNonFunApp(L[34],call_DASH_field_DASH_failure191594,[anf_arg951595,anf_arg961596,anf_arg971597]);
};
try {
if(--R.GAS > 0) {
$z15861587 = $f15921593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15921593,
"from":L[34]});
}
} catch($e15841585) {
if(R.isCont($e15841585)) {
var $ss15881589 = {"from":L[34],
"go":function(cont_tail_arg98868) {
return $Hcont_tail_arg334867(cont_tail_arg98868,if_helper88869);
}};
$e15841585.stack[R.EXN_STACKHEIGHT++] = $ss15881589;
}
if(R.isPyretException($e15841585)) {
$e15841585.pyretStack.push(L[34]);
}
throw $e15841585;
}
var $ret15901591 = $Hcont_tail_arg334867($z15861587,if_helper88869);
++R.GAS;
return $ret15901591;
} else {
var $z16021603 = D;
var $f16081609 = function(_) {
return R.isFunction(else_DASH_clause221610)?else_DASH_clause221610.app():R.ffi.throwNonFunApp(L[34],else_DASH_clause221610,[]);
};
try {
if(--R.GAS > 0) {
$z16021603 = $f16081609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16081609,
"from":L[34]});
}
} catch($e16001601) {
if(R.isCont($e16001601)) {
var $ss16041605 = {"from":L[34],
"go":function(cont_tail_arg93873) {
return $Hcont_tail_arg335872(cont_tail_arg93873,if_helper88869);
}};
$e16001601.stack[R.EXN_STACKHEIGHT++] = $ss16041605;
}
if(R.isPyretException($e16001601)) {
$e16001601.pyretStack.push(L[34]);
}
throw $e16001601;
}
var $ret16061607 = $Hcont_tail_arg335872($z16021603,if_helper88869);
++R.GAS;
return $ret16061607;
}
} else {
var cont_tail_arg901614 = R.throwNonBooleanCondition(L[34],("if"),if_DASH_241611);
if(--R.GAS > 0) {
$z16121613 = R.isFunction(if_helper88869)?if_helper88869.app(cont_tail_arg901614):R.ffi.throwNonFunApp(L[34],if_helper88869,[cont_tail_arg901614]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper88869)?if_helper88869.app(cont_tail_arg901614):R.ffi.throwNonFunApp(L[34],if_helper88869,[cont_tail_arg901614]);
},
"from":L[34]});
}
++R.GAS;
return $z16121613;
}
};
},{"length":3});
var anf_variant_member1141491 = R.makeMethod(function(self23756) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[34],0,arguments);
}
var anf_arg1021583 = G(self23756,"loc",L[34]);
var $z15751576 = D;
var $f15811582 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1021583):R.ffi.throwNonFunApp(L[34],torepr10,[anf_arg1021583]);
};
try {
if(--R.GAS > 0) {
$z15751576 = $f15811582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15811582,
"from":L[34]});
}
} catch($e15731574) {
if(R.isCont($e15731574)) {
var $ss15771578 = {"from":L[34],
"go":function(anf_arg103755) {
return $Hanf_arg345754(anf_arg103755,self23756,_plus7,torepr10);
}};
$e15731574.stack[R.EXN_STACKHEIGHT++] = $ss15771578;
}
if(R.isPyretException($e15731574)) {
$e15731574.pyretStack.push(L[34]);
}
throw $e15731574;
}
var $ret15791580 = $Hanf_arg345754($z15751576,self23756,_plus7,torepr10);
++R.GAS;
return $ret15791580;
};
},{"length":1});
var anf_variant_member1261492 = R.makeMethod(function(self45679) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[33],0,arguments);
}
var anf_bracket1161572 = G(self45679,"loc",L[75]);
var anf_fun1171571 = G(anf_bracket1161572,"format",L[74]);
var $z15631564 = D;
var $f15691570 = function(_) {
return R.isFunction(anf_fun1171571)?anf_fun1171571.app((true)):R.ffi.throwNonFunApp(L[73],anf_fun1171571,[(true)]);
};
try {
if(--R.GAS > 0) {
$z15631564 = $f15691570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15691570,
"from":L[73]});
}
} catch($e15611562) {
if(R.isCont($e15611562)) {
var $ss15651566 = {"from":L[73],
"go":function(anf_arg118678) {
return $Hanf_arg352677(anf_arg118678,self45679,_plus7,tostring11);
}};
$e15611562.stack[R.EXN_STACKHEIGHT++] = $ss15651566;
}
if(R.isPyretException($e15611562)) {
$e15611562.pyretStack.push(L[73]);
}
throw $e15611562;
}
var $ret15671568 = $Hanf_arg352677($z15631564,self45679,_plus7,tostring11);
++R.GAS;
return $ret15671568;
};
},{"length":1});
var anf_variant_member1391501 = R.makeMethod(function(self261541) {
return function(cases_DASH_funs271542,else_DASH_clause281553) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[28],2,arguments);
}
var if_DASH_301554 = R.hasField(cases_DASH_funs271542,("missing-field"));
var if_helper128670 = R.makeFunction(function(if_helper_arg1291559) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[28],1,arguments);
}
var ann_DASH_check_DASH_temp1271560 = if_helper_arg1291559;
return ann_DASH_check_DASH_temp1271560;
});
var anf_if1321558 = R.isBoolean(if_DASH_301554);
if(R.isPyretTrue(anf_if1321558)) {
if(R.isPyretTrue(if_DASH_301554)) {
var call_DASH_missing_DASH_field251538 = G(cases_DASH_funs271542,"missing-field",L[28]);
var anf_arg1351539 = G(self261541,"loc",L[72]);
var anf_arg1361540 = G(self261541,"field",L[71]);
var $z15301531 = D;
var $f15361537 = function(_) {
return R.isFunction(call_DASH_missing_DASH_field251538)?call_DASH_missing_DASH_field251538.app(anf_arg1351539,anf_arg1361540):R.ffi.throwNonFunApp(L[28],call_DASH_missing_DASH_field251538,[anf_arg1351539,anf_arg1361540]);
};
try {
if(--R.GAS > 0) {
$z15301531 = $f15361537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15361537,
"from":L[28]});
}
} catch($e15281529) {
if(R.isCont($e15281529)) {
var $ss15321533 = {"from":L[28],
"go":function(cont_tail_arg137669) {
return $Hcont_tail_arg353668(cont_tail_arg137669,if_helper128670);
}};
$e15281529.stack[R.EXN_STACKHEIGHT++] = $ss15321533;
}
if(R.isPyretException($e15281529)) {
$e15281529.pyretStack.push(L[28]);
}
throw $e15281529;
}
var $ret15341535 = $Hcont_tail_arg353668($z15301531,if_helper128670);
++R.GAS;
return $ret15341535;
} else {
var $z15451546 = D;
var $f15511552 = function(_) {
return R.isFunction(else_DASH_clause281553)?else_DASH_clause281553.app():R.ffi.throwNonFunApp(L[28],else_DASH_clause281553,[]);
};
try {
if(--R.GAS > 0) {
$z15451546 = $f15511552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15511552,
"from":L[28]});
}
} catch($e15431544) {
if(R.isCont($e15431544)) {
var $ss15471548 = {"from":L[28],
"go":function(cont_tail_arg133674) {
return $Hcont_tail_arg354673(cont_tail_arg133674,if_helper128670);
}};
$e15431544.stack[R.EXN_STACKHEIGHT++] = $ss15471548;
}
if(R.isPyretException($e15431544)) {
$e15431544.pyretStack.push(L[28]);
}
throw $e15431544;
}
var $ret15491550 = $Hcont_tail_arg354673($z15451546,if_helper128670);
++R.GAS;
return $ret15491550;
}
} else {
var cont_tail_arg1301557 = R.throwNonBooleanCondition(L[28],("if"),if_DASH_301554);
if(--R.GAS > 0) {
$z15551556 = R.isFunction(if_helper128670)?if_helper128670.app(cont_tail_arg1301557):R.ffi.throwNonFunApp(L[28],if_helper128670,[cont_tail_arg1301557]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper128670)?if_helper128670.app(cont_tail_arg1301557):R.ffi.throwNonFunApp(L[28],if_helper128670,[cont_tail_arg1301557]);
},
"from":L[28]});
}
++R.GAS;
return $z15551556;
}
};
},{"length":3});
var anf_variant_member1491502 = R.makeMethod(function(self29594) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[28],0,arguments);
}
var anf_arg1411527 = G(self29594,"loc",L[28]);
var $z15191520 = D;
var $f15251526 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1411527):R.ffi.throwNonFunApp(L[28],torepr10,[anf_arg1411527]);
};
try {
if(--R.GAS > 0) {
$z15191520 = $f15251526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15251526,
"from":L[28]});
}
} catch($e15171518) {
if(R.isCont($e15171518)) {
var $ss15211522 = {"from":L[28],
"go":function(anf_arg142593) {
return $Hanf_arg361592(anf_arg142593,self29594,_plus7,torepr10);
}};
$e15171518.stack[R.EXN_STACKHEIGHT++] = $ss15211522;
}
if(R.isPyretException($e15171518)) {
$e15171518.pyretStack.push(L[28]);
}
throw $e15171518;
}
var $ret15231524 = $Hanf_arg361592($z15191520,self29594,_plus7,torepr10);
++R.GAS;
return $ret15231524;
};
},{"length":1});
var anf_variant_member1571503 = R.makeMethod(function(self48553) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[27],0,arguments);
}
var anf_arg1511516 = G(self48553,"field",L[70]);
var $z15081509 = D;
var $f15141515 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Missing field "),anf_arg1511516):R.ffi.throwNonFunApp(L[23],_plus7,[("Missing field "),anf_arg1511516]);
};
try {
if(--R.GAS > 0) {
$z15081509 = $f15141515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15141515,
"from":L[23]});
}
} catch($e15061507) {
if(R.isCont($e15061507)) {
var $ss15101511 = {"from":L[23],
"go":function(anf_arg152552) {
return $Hanf_arg365551(anf_arg152552,self48553,_plus7);
}};
$e15061507.stack[R.EXN_STACKHEIGHT++] = $ss15101511;
}
if(R.isPyretException($e15061507)) {
$e15061507.pyretStack.push(L[23]);
}
throw $e15061507;
}
var $ret15121513 = $Hanf_arg365551($z15081509,self48553,_plus7);
++R.GAS;
return $ret15121513;
};
},{"length":1});
var anf_assign1581180 = (function() {
var $field_DASH_failure_DASH_base14851486 = {"_match":anf_variant_member1001490,
"_torepr":anf_variant_member1141491,
"tostring":anf_variant_member1261492};
var $field_DASH_failure_DASH_brands14881489 = {"$brand-field-failure1487":true};
$field_DASH_failure_DASH_brands14881489[FieldFailureT261159._brand] = true
var $missing_DASH_field_DASH_base14961497 = {"_match":anf_variant_member1391501,
"_torepr":anf_variant_member1491502,
"tostring":anf_variant_member1571503};
var $missing_DASH_field_DASH_brands14991500 = {"$brand-missing-field1498":true};
$missing_DASH_field_DASH_brands14991500[FieldFailureT261159._brand] = true
return R.makeObject({"FieldFailure":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[67],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,FieldFailureT261159._brand));
}),
"is-field-failure":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[34],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-field-failure1487"));
}),
"field-failure":R.makeFunction(function(loc421493,field431494,reason441495) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[68],3,arguments);
}
var dict = R.create($field_DASH_failure_DASH_base14851486);
dict["loc"] = loc421493
dict["field"] = field431494
dict["reason"] = reason441495
return R.makeBrandedObject(dict,$field_DASH_failure_DASH_brands14881489);
}),
"is-missing-field":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[28],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-missing-field1498"));
}),
"missing-field":R.makeFunction(function(loc461504,field471505) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[69],2,arguments);
}
var dict = R.create($missing_DASH_field_DASH_base14961497);
dict["loc"] = loc461504
dict["field"] = field471505
return R.makeBrandedObject(dict,$missing_DASH_field_DASH_brands14991500);
})});
})();
FieldFailure5181179.$var = anf_assign1581180;
var anf_assign1591182 = G(FieldFailure5181179.$var,"FieldFailure",L[67]);
FieldFailure191181.$var = anf_assign1591182;
var anf_assign1601184 = G(FieldFailure5181179.$var,"FieldFailure",L[67]);
is_DASH_FieldFailure201183.$var = anf_assign1601184;
var anf_assign1611186 = G(FieldFailure5181179.$var,"is-field-failure",L[34]);
is_DASH_field_DASH_failure211185.$var = anf_assign1611186;
var anf_assign1621188 = G(FieldFailure5181179.$var,"field-failure",L[34]);
field_DASH_failure221187.$var = anf_assign1621188;
var anf_assign1631190 = G(FieldFailure5181179.$var,"is-missing-field",L[28]);
is_DASH_missing_DASH_field231189.$var = anf_assign1631190;
var anf_assign1641192 = G(FieldFailure5181179.$var,"missing-field",L[28]);
missing_DASH_field241191.$var = anf_assign1641192;
var anf_variant_member1771231 = R.makeMethod(function(self321465) {
return function(cases_DASH_funs331466,else_DASH_clause341477) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[22],2,arguments);
}
var if_DASH_361478 = R.hasField(cases_DASH_funs331466,("type-mismatch"));
var if_helper166544 = R.makeFunction(function(if_helper_arg1671483) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
var ann_DASH_check_DASH_temp1651484 = if_helper_arg1671483;
return ann_DASH_check_DASH_temp1651484;
});
var anf_if1701482 = R.isBoolean(if_DASH_361478);
if(R.isPyretTrue(anf_if1701482)) {
if(R.isPyretTrue(if_DASH_361478)) {
var call_DASH_type_DASH_mismatch311462 = G(cases_DASH_funs331466,"type-mismatch",L[22]);
var anf_arg1731463 = G(self321465,"val",L[66]);
var anf_arg1741464 = G(self321465,"name",L[65]);
var $z14541455 = D;
var $f14601461 = function(_) {
return R.isFunction(call_DASH_type_DASH_mismatch311462)?call_DASH_type_DASH_mismatch311462.app(anf_arg1731463,anf_arg1741464):R.ffi.throwNonFunApp(L[22],call_DASH_type_DASH_mismatch311462,[anf_arg1731463,anf_arg1741464]);
};
try {
if(--R.GAS > 0) {
$z14541455 = $f14601461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14601461,
"from":L[22]});
}
} catch($e14521453) {
if(R.isCont($e14521453)) {
var $ss14561457 = {"from":L[22],
"go":function(cont_tail_arg175543) {
return $Hcont_tail_arg366542(cont_tail_arg175543,if_helper166544);
}};
$e14521453.stack[R.EXN_STACKHEIGHT++] = $ss14561457;
}
if(R.isPyretException($e14521453)) {
$e14521453.pyretStack.push(L[22]);
}
throw $e14521453;
}
var $ret14581459 = $Hcont_tail_arg366542($z14541455,if_helper166544);
++R.GAS;
return $ret14581459;
} else {
var $z14691470 = D;
var $f14751476 = function(_) {
return R.isFunction(else_DASH_clause341477)?else_DASH_clause341477.app():R.ffi.throwNonFunApp(L[22],else_DASH_clause341477,[]);
};
try {
if(--R.GAS > 0) {
$z14691470 = $f14751476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14751476,
"from":L[22]});
}
} catch($e14671468) {
if(R.isCont($e14671468)) {
var $ss14711472 = {"from":L[22],
"go":function(cont_tail_arg171548) {
return $Hcont_tail_arg367547(cont_tail_arg171548,if_helper166544);
}};
$e14671468.stack[R.EXN_STACKHEIGHT++] = $ss14711472;
}
if(R.isPyretException($e14671468)) {
$e14671468.pyretStack.push(L[22]);
}
throw $e14671468;
}
var $ret14731474 = $Hcont_tail_arg367547($z14691470,if_helper166544);
++R.GAS;
return $ret14731474;
}
} else {
var cont_tail_arg1681481 = R.throwNonBooleanCondition(L[22],("if"),if_DASH_361478);
if(--R.GAS > 0) {
$z14791480 = R.isFunction(if_helper166544)?if_helper166544.app(cont_tail_arg1681481):R.ffi.throwNonFunApp(L[22],if_helper166544,[cont_tail_arg1681481]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper166544)?if_helper166544.app(cont_tail_arg1681481):R.ffi.throwNonFunApp(L[22],if_helper166544,[cont_tail_arg1681481]);
},
"from":L[22]});
}
++R.GAS;
return $z14791480;
}
};
},{"length":3});
var anf_variant_member1871232 = R.makeMethod(function(self35468) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[22],0,arguments);
}
var anf_arg1791451 = G(self35468,"val",L[22]);
var $z14431444 = D;
var $f14491450 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1791451):R.ffi.throwNonFunApp(L[22],torepr10,[anf_arg1791451]);
};
try {
if(--R.GAS > 0) {
$z14431444 = $f14491450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14491450,
"from":L[22]});
}
} catch($e14411442) {
if(R.isCont($e14411442)) {
var $ss14451446 = {"from":L[22],
"go":function(anf_arg180467) {
return $Hanf_arg374466(anf_arg180467,self35468,_plus7,torepr10);
}};
$e14411442.stack[R.EXN_STACKHEIGHT++] = $ss14451446;
}
if(R.isPyretException($e14411442)) {
$e14411442.pyretStack.push(L[22]);
}
throw $e14411442;
}
var $ret14471448 = $Hanf_arg374466($z14431444,self35468,_plus7,torepr10);
++R.GAS;
return $ret14471448;
};
},{"length":1});
var anf_variant_member1941233 = R.makeMethod(function(self51428) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[21],0,arguments);
}
var anf_arg1891440 = G(self51428,"name",L[64]);
var $z14321433 = D;
var $f14381439 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Expected "),anf_arg1891440):R.ffi.throwNonFunApp(L[18],_plus7,[("Expected "),anf_arg1891440]);
};
try {
if(--R.GAS > 0) {
$z14321433 = $f14381439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14381439,
"from":L[18]});
}
} catch($e14301431) {
if(R.isCont($e14301431)) {
var $ss14341435 = {"from":L[18],
"go":function(anf_arg190427) {
return $Hanf_arg378426(anf_arg190427,self51428,_plus7,torepr10);
}};
$e14301431.stack[R.EXN_STACKHEIGHT++] = $ss14341435;
}
if(R.isPyretException($e14301431)) {
$e14301431.pyretStack.push(L[18]);
}
throw $e14301431;
}
var $ret14361437 = $Hanf_arg378426($z14321433,self51428,_plus7,torepr10);
++R.GAS;
return $ret14361437;
};
},{"length":1});
var anf_variant_member2071241 = R.makeMethod(function(self381014) {
return function(cases_DASH_funs391411,else_DASH_clause401422) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[17],2,arguments);
}
var if_DASH_421423 = R.hasField(cases_DASH_funs391411,("predicate-failure"));
var if_helper196419 = R.makeFunction(function(if_helper_arg1971428) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[17],1,arguments);
}
var ann_DASH_check_DASH_temp1951429 = if_helper_arg1971428;
return ann_DASH_check_DASH_temp1951429;
});
var anf_if2001427 = R.isBoolean(if_DASH_421423);
if(R.isPyretTrue(anf_if2001427)) {
if(R.isPyretTrue(if_DASH_421423)) {
var call_DASH_predicate_DASH_failure371408 = G(cases_DASH_funs391411,"predicate-failure",L[17]);
var anf_arg2031409 = G(self381014,"val",L[63]);
var anf_arg2041410 = G(self381014,"pred-name",L[62]);
var $z14001401 = D;
var $f14061407 = function(_) {
return R.isFunction(call_DASH_predicate_DASH_failure371408)?call_DASH_predicate_DASH_failure371408.app(anf_arg2031409,anf_arg2041410):R.ffi.throwNonFunApp(L[17],call_DASH_predicate_DASH_failure371408,[anf_arg2031409,anf_arg2041410]);
};
try {
if(--R.GAS > 0) {
$z14001401 = $f14061407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14061407,
"from":L[17]});
}
} catch($e13981399) {
if(R.isCont($e13981399)) {
var $ss14021403 = {"from":L[17],
"go":function(cont_tail_arg205418) {
return $Hcont_tail_arg379417(cont_tail_arg205418,if_helper196419);
}};
$e13981399.stack[R.EXN_STACKHEIGHT++] = $ss14021403;
}
if(R.isPyretException($e13981399)) {
$e13981399.pyretStack.push(L[17]);
}
throw $e13981399;
}
var $ret14041405 = $Hcont_tail_arg379417($z14001401,if_helper196419);
++R.GAS;
return $ret14041405;
} else {
var $z14141415 = D;
var $f14201421 = function(_) {
return R.isFunction(else_DASH_clause401422)?else_DASH_clause401422.app():R.ffi.throwNonFunApp(L[17],else_DASH_clause401422,[]);
};
try {
if(--R.GAS > 0) {
$z14141415 = $f14201421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14201421,
"from":L[17]});
}
} catch($e14121413) {
if(R.isCont($e14121413)) {
var $ss14161417 = {"from":L[17],
"go":function(cont_tail_arg201423) {
return $Hcont_tail_arg380422(cont_tail_arg201423,if_helper196419);
}};
$e14121413.stack[R.EXN_STACKHEIGHT++] = $ss14161417;
}
if(R.isPyretException($e14121413)) {
$e14121413.pyretStack.push(L[17]);
}
throw $e14121413;
}
var $ret14181419 = $Hcont_tail_arg380422($z14141415,if_helper196419);
++R.GAS;
return $ret14181419;
}
} else {
var cont_tail_arg1981426 = R.throwNonBooleanCondition(L[17],("if"),if_DASH_421423);
if(--R.GAS > 0) {
$z14241425 = R.isFunction(if_helper196419)?if_helper196419.app(cont_tail_arg1981426):R.ffi.throwNonFunApp(L[17],if_helper196419,[cont_tail_arg1981426]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper196419)?if_helper196419.app(cont_tail_arg1981426):R.ffi.throwNonFunApp(L[17],if_helper196419,[cont_tail_arg1981426]);
},
"from":L[17]});
}
++R.GAS;
return $z14241425;
}
};
},{"length":3});
var anf_variant_member2171242 = R.makeMethod(function(self41343) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[17],0,arguments);
}
var anf_arg2091397 = G(self41343,"val",L[17]);
var $z13891390 = D;
var $f13951396 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg2091397):R.ffi.throwNonFunApp(L[17],torepr10,[anf_arg2091397]);
};
try {
if(--R.GAS > 0) {
$z13891390 = $f13951396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13951396,
"from":L[17]});
}
} catch($e13871388) {
if(R.isCont($e13871388)) {
var $ss13911392 = {"from":L[17],
"go":function(anf_arg210342) {
return $Hanf_arg387341(anf_arg210342,self41343,_plus7,torepr10);
}};
$e13871388.stack[R.EXN_STACKHEIGHT++] = $ss13911392;
}
if(R.isPyretException($e13871388)) {
$e13871388.pyretStack.push(L[17]);
}
throw $e13871388;
}
var $ret13931394 = $Hanf_arg387341($z13891390,self41343,_plus7,torepr10);
++R.GAS;
return $ret13931394;
};
},{"length":1});
var anf_variant_member2241243 = R.makeMethod(function(self54303) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[16],0,arguments);
}
var anf_arg2191386 = G(self54303,"pred-name",L[61]);
var $z13781379 = D;
var $f13841385 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Predicate "),anf_arg2191386):R.ffi.throwNonFunApp(L[13],_plus7,[("Predicate "),anf_arg2191386]);
};
try {
if(--R.GAS > 0) {
$z13781379 = $f13841385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13841385,
"from":L[13]});
}
} catch($e13761377) {
if(R.isCont($e13761377)) {
var $ss13801381 = {"from":L[13],
"go":function(anf_arg220302) {
return $Hanf_arg391301(anf_arg220302,self54303,_plus7,torepr10);
}};
$e13761377.stack[R.EXN_STACKHEIGHT++] = $ss13801381;
}
if(R.isPyretException($e13761377)) {
$e13761377.pyretStack.push(L[13]);
}
throw $e13761377;
}
var $ret13821383 = $Hanf_arg391301($z13781379,self54303,_plus7,torepr10);
++R.GAS;
return $ret13821383;
};
},{"length":1});
var anf_variant_member2371251 = R.makeMethod(function(self441356) {
return function(cases_DASH_funs451357,else_DASH_clause461368) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[12],2,arguments);
}
var if_DASH_481369 = R.hasField(cases_DASH_funs451357,("record-fields-fail"));
var if_helper226294 = R.makeFunction(function(if_helper_arg2271374) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[12],1,arguments);
}
var ann_DASH_check_DASH_temp2251375 = if_helper_arg2271374;
return ann_DASH_check_DASH_temp2251375;
});
var anf_if2301373 = R.isBoolean(if_DASH_481369);
if(R.isPyretTrue(anf_if2301373)) {
if(R.isPyretTrue(if_DASH_481369)) {
var call_DASH_record_DASH_fields_DASH_fail431353 = G(cases_DASH_funs451357,"record-fields-fail",L[12]);
var anf_arg2331354 = G(self441356,"val",L[60]);
var anf_arg2341355 = G(self441356,"field-failures",L[59]);
var $z13451346 = D;
var $f13511352 = function(_) {
return R.isFunction(call_DASH_record_DASH_fields_DASH_fail431353)?call_DASH_record_DASH_fields_DASH_fail431353.app(anf_arg2331354,anf_arg2341355):R.ffi.throwNonFunApp(L[12],call_DASH_record_DASH_fields_DASH_fail431353,[anf_arg2331354,anf_arg2341355]);
};
try {
if(--R.GAS > 0) {
$z13451346 = $f13511352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13511352,
"from":L[12]});
}
} catch($e13431344) {
if(R.isCont($e13431344)) {
var $ss13471348 = {"from":L[12],
"go":function(cont_tail_arg235293) {
return $Hcont_tail_arg392292(cont_tail_arg235293,if_helper226294);
}};
$e13431344.stack[R.EXN_STACKHEIGHT++] = $ss13471348;
}
if(R.isPyretException($e13431344)) {
$e13431344.pyretStack.push(L[12]);
}
throw $e13431344;
}
var $ret13491350 = $Hcont_tail_arg392292($z13451346,if_helper226294);
++R.GAS;
return $ret13491350;
} else {
var $z13601361 = D;
var $f13661367 = function(_) {
return R.isFunction(else_DASH_clause461368)?else_DASH_clause461368.app():R.ffi.throwNonFunApp(L[12],else_DASH_clause461368,[]);
};
try {
if(--R.GAS > 0) {
$z13601361 = $f13661367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13661367,
"from":L[12]});
}
} catch($e13581359) {
if(R.isCont($e13581359)) {
var $ss13621363 = {"from":L[12],
"go":function(cont_tail_arg231298) {
return $Hcont_tail_arg393297(cont_tail_arg231298,if_helper226294);
}};
$e13581359.stack[R.EXN_STACKHEIGHT++] = $ss13621363;
}
if(R.isPyretException($e13581359)) {
$e13581359.pyretStack.push(L[12]);
}
throw $e13581359;
}
var $ret13641365 = $Hcont_tail_arg393297($z13601361,if_helper226294);
++R.GAS;
return $ret13641365;
}
} else {
var cont_tail_arg2281372 = R.throwNonBooleanCondition(L[12],("if"),if_DASH_481369);
if(--R.GAS > 0) {
$z13701371 = R.isFunction(if_helper226294)?if_helper226294.app(cont_tail_arg2281372):R.ffi.throwNonFunApp(L[12],if_helper226294,[cont_tail_arg2281372]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper226294)?if_helper226294.app(cont_tail_arg2281372):R.ffi.throwNonFunApp(L[12],if_helper226294,[cont_tail_arg2281372]);
},
"from":L[12]});
}
++R.GAS;
return $z13701371;
}
};
},{"length":3});
var anf_variant_member2471252 = R.makeMethod(function(self47218) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[12],0,arguments);
}
var anf_arg2391342 = G(self47218,"val",L[12]);
var $z13341335 = D;
var $f13401341 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg2391342):R.ffi.throwNonFunApp(L[12],torepr10,[anf_arg2391342]);
};
try {
if(--R.GAS > 0) {
$z13341335 = $f13401341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13401341,
"from":L[12]});
}
} catch($e13321333) {
if(R.isCont($e13321333)) {
var $ss13361337 = {"from":L[12],
"go":function(anf_arg240217) {
return $Hanf_arg400216(anf_arg240217,self47218,_plus7,torepr10);
}};
$e13321333.stack[R.EXN_STACKHEIGHT++] = $ss13361337;
}
if(R.isPyretException($e13321333)) {
$e13321333.pyretStack.push(L[12]);
}
throw $e13321333;
}
var $ret13381339 = $Hanf_arg400216($z13341335,self47218,_plus7,torepr10);
++R.GAS;
return $ret13381339;
};
},{"length":1});
var anf_variant_member2581253 = R.makeMethod(function(self57152) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[11],0,arguments);
}
var anf_arg2491331 = G(self57152,"val",L[58]);
var $z13231324 = D;
var $f13291330 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg2491331):R.ffi.throwNonFunApp(L[57],torepr10,[anf_arg2491331]);
};
try {
if(--R.GAS > 0) {
$z13231324 = $f13291330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13291330,
"from":L[57]});
}
} catch($e13211322) {
if(R.isCont($e13211322)) {
var $ss13251326 = {"from":L[57],
"go":function(anf_arg250151) {
return $Hanf_arg406150(anf_arg250151,self57152,_plus7,tostring11);
}};
$e13211322.stack[R.EXN_STACKHEIGHT++] = $ss13251326;
}
if(R.isPyretException($e13211322)) {
$e13211322.pyretStack.push(L[57]);
}
throw $e13211322;
}
var $ret13271328 = $Hanf_arg406150($z13231324,self57152,_plus7,tostring11);
++R.GAS;
return $ret13271328;
};
},{"length":1});
var anf_variant_member2711261 = R.makeMethod(function(self501301) {
return function(cases_DASH_funs511302,else_DASH_clause521313) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[4],2,arguments);
}
var if_DASH_541314 = R.hasField(cases_DASH_funs511302,("dot-ann-not-present"));
var if_helper260142 = R.makeFunction(function(if_helper_arg2611319) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
var ann_DASH_check_DASH_temp2591320 = if_helper_arg2611319;
return ann_DASH_check_DASH_temp2591320;
});
var anf_if2641318 = R.isBoolean(if_DASH_541314);
if(R.isPyretTrue(anf_if2641318)) {
if(R.isPyretTrue(if_DASH_541314)) {
var call_DASH_dot_DASH_ann_DASH_not_DASH_present491298 = G(cases_DASH_funs511302,"dot-ann-not-present",L[4]);
var anf_arg2671299 = G(self501301,"name",L[56]);
var anf_arg2681300 = G(self501301,"field",L[55]);
var $z12901291 = D;
var $f12961297 = function(_) {
return R.isFunction(call_DASH_dot_DASH_ann_DASH_not_DASH_present491298)?call_DASH_dot_DASH_ann_DASH_not_DASH_present491298.app(anf_arg2671299,anf_arg2681300):R.ffi.throwNonFunApp(L[4],call_DASH_dot_DASH_ann_DASH_not_DASH_present491298,[anf_arg2671299,anf_arg2681300]);
};
try {
if(--R.GAS > 0) {
$z12901291 = $f12961297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12961297,
"from":L[4]});
}
} catch($e12881289) {
if(R.isCont($e12881289)) {
var $ss12921293 = {"from":L[4],
"go":function(cont_tail_arg269141) {
return $Hcont_tail_arg407140(cont_tail_arg269141,if_helper260142);
}};
$e12881289.stack[R.EXN_STACKHEIGHT++] = $ss12921293;
}
if(R.isPyretException($e12881289)) {
$e12881289.pyretStack.push(L[4]);
}
throw $e12881289;
}
var $ret12941295 = $Hcont_tail_arg407140($z12901291,if_helper260142);
++R.GAS;
return $ret12941295;
} else {
var $z13051306 = D;
var $f13111312 = function(_) {
return R.isFunction(else_DASH_clause521313)?else_DASH_clause521313.app():R.ffi.throwNonFunApp(L[4],else_DASH_clause521313,[]);
};
try {
if(--R.GAS > 0) {
$z13051306 = $f13111312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13111312,
"from":L[4]});
}
} catch($e13031304) {
if(R.isCont($e13031304)) {
var $ss13071308 = {"from":L[4],
"go":function(cont_tail_arg265147) {
return $Hcont_tail_arg408146(cont_tail_arg265147,if_helper260142);
}};
$e13031304.stack[R.EXN_STACKHEIGHT++] = $ss13071308;
}
if(R.isPyretException($e13031304)) {
$e13031304.pyretStack.push(L[4]);
}
throw $e13031304;
}
var $ret13091310 = $Hcont_tail_arg408146($z13051306,if_helper260142);
++R.GAS;
return $ret13091310;
}
} else {
var cont_tail_arg2621317 = R.throwNonBooleanCondition(L[4],("if"),if_DASH_541314);
if(--R.GAS > 0) {
$z13151316 = R.isFunction(if_helper260142)?if_helper260142.app(cont_tail_arg2621317):R.ffi.throwNonFunApp(L[4],if_helper260142,[cont_tail_arg2621317]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored145) {
return R.isFunction(if_helper260142)?if_helper260142.app(cont_tail_arg2621317):R.ffi.throwNonFunApp(L[4],if_helper260142,[cont_tail_arg2621317]);
},
"from":L[4]});
}
++R.GAS;
return $z13151316;
}
};
},{"length":3});
var anf_variant_member2811262 = R.makeMethod(function(self5366) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4],0,arguments);
}
var anf_arg2731287 = G(self5366,"name",L[4]);
var $z12791280 = D;
var $f12851286 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg2731287):R.ffi.throwNonFunApp(L[4],torepr10,[anf_arg2731287]);
};
try {
if(--R.GAS > 0) {
$z12791280 = $f12851286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12851286,
"from":L[4]});
}
} catch($e12771278) {
if(R.isCont($e12771278)) {
var $ss12811282 = {"from":L[4],
"go":function(anf_arg27465) {
return $Hanf_arg41564(anf_arg27465,self5366,_plus7,torepr10);
}};
$e12771278.stack[R.EXN_STACKHEIGHT++] = $ss12811282;
}
if(R.isPyretException($e12771278)) {
$e12771278.pyretStack.push(L[4]);
}
throw $e12771278;
}
var $ret12831284 = $Hanf_arg41564($z12791280,self5366,_plus7,torepr10);
++R.GAS;
return $ret12831284;
};
},{"length":1});
var anf_variant_member2871263 = R.makeMethod(function(self6038) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2],0,arguments);
}
var anf_arg2831276 = G(self6038,"field",L[54]);
var $z12681269 = D;
var $f12741275 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Couldn't find the annotation field "),anf_arg2831276):R.ffi.throwNonFunApp(L[1],_plus7,[("Couldn't find the annotation field "),anf_arg2831276]);
};
try {
if(--R.GAS > 0) {
$z12681269 = $f12741275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12741275,
"from":L[1]});
}
} catch($e12661267) {
if(R.isCont($e12661267)) {
var $ss12701271 = {"from":L[1],
"go":function(anf_arg28437) {
return $Hanf_arg41836(anf_arg28437,self6038,_plus7);
}};
$e12661267.stack[R.EXN_STACKHEIGHT++] = $ss12701271;
}
if(R.isPyretException($e12661267)) {
$e12661267.pyretStack.push(L[1]);
}
throw $e12661267;
}
var $ret12721273 = $Hanf_arg41836($z12681269,self6038,_plus7);
++R.GAS;
return $ret12721273;
};
},{"length":1});
var anf_assign2881194 = (function() {
var $type_DASH_mismatch_DASH_base12261227 = {"_match":anf_variant_member1771231,
"_torepr":anf_variant_member1871232,
"tostring":anf_variant_member1941233};
var $type_DASH_mismatch_DASH_brands12291230 = {"$brand-type-mismatch1228":true};
$type_DASH_mismatch_DASH_brands12291230[FailureReasonT381160._brand] = true
var $predicate_DASH_failure_DASH_base12361237 = {"_match":anf_variant_member2071241,
"_torepr":anf_variant_member2171242,
"tostring":anf_variant_member2241243};
var $predicate_DASH_failure_DASH_brands12391240 = {"$brand-predicate-failure1238":true};
$predicate_DASH_failure_DASH_brands12391240[FailureReasonT381160._brand] = true
var $record_DASH_fields_DASH_fail_DASH_base12461247 = {"_match":anf_variant_member2371251,
"_torepr":anf_variant_member2471252,
"tostring":anf_variant_member2581253};
var $record_DASH_fields_DASH_fail_DASH_brands12491250 = {"$brand-record-fields-fail1248":true};
$record_DASH_fields_DASH_fail_DASH_brands12491250[FailureReasonT381160._brand] = true
var $dot_DASH_ann_DASH_not_DASH_present_DASH_base12561257 = {"_match":anf_variant_member2711261,
"_torepr":anf_variant_member2811262,
"tostring":anf_variant_member2871263};
var $dot_DASH_ann_DASH_not_DASH_present_DASH_brands12591260 = {"$brand-dot-ann-not-present1258":true};
$dot_DASH_ann_DASH_not_DASH_present_DASH_brands12591260[FailureReasonT381160._brand] = true
return R.makeObject({"FailureReason":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[46],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,FailureReasonT381160._brand));
}),
"is-type-mismatch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-type-mismatch1228"));
}),
"type-mismatch":R.makeFunction(function(val491234,name501235) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[47],2,arguments);
}
return R.checkAnnArgs([$type$String12],[name501235],[L[48]],function() {
var dict = R.create($type_DASH_mismatch_DASH_base12261227);
dict["val"] = val491234
dict["name"] = name501235
return R.makeBrandedObject(dict,$type_DASH_mismatch_DASH_brands12291230);
});
}),
"is-predicate-failure":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[17],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-predicate-failure1238"));
}),
"predicate-failure":R.makeFunction(function(val521244,pred_DASH_name531245) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[49],2,arguments);
}
var dict = R.create($predicate_DASH_failure_DASH_base12361237);
dict["val"] = val521244
dict["pred-name"] = pred_DASH_name531245
return R.makeBrandedObject(dict,$predicate_DASH_failure_DASH_brands12391240);
}),
"is-record-fields-fail":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[12],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-record-fields-fail1248"));
}),
"record-fields-fail":R.makeFunction(function(val551254,field_DASH_failures561255) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[50],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[51],"L",L214,"List")],[field_DASH_failures561255],[L[52]],function() {
var dict = R.create($record_DASH_fields_DASH_fail_DASH_base12461247);
dict["val"] = val551254
dict["field-failures"] = field_DASH_failures561255
return R.makeBrandedObject(dict,$record_DASH_fields_DASH_fail_DASH_brands12491250);
});
}),
"is-dot-ann-not-present":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-dot-ann-not-present1258"));
}),
"dot-ann-not-present":R.makeFunction(function(name581264,field591265) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[53],2,arguments);
}
var dict = R.create($dot_DASH_ann_DASH_not_DASH_present_DASH_base12561257);
dict["name"] = name581264
dict["field"] = field591265
return R.makeBrandedObject(dict,$dot_DASH_ann_DASH_not_DASH_present_DASH_brands12591260);
})});
})();
FailureReason6251193.$var = anf_assign2881194;
var anf_assign2891196 = G(FailureReason6251193.$var,"FailureReason",L[46]);
FailureReason261195.$var = anf_assign2891196;
var anf_assign2901198 = G(FailureReason6251193.$var,"FailureReason",L[46]);
is_DASH_FailureReason271197.$var = anf_assign2901198;
var anf_assign2911200 = G(FailureReason6251193.$var,"is-type-mismatch",L[22]);
is_DASH_type_DASH_mismatch281199.$var = anf_assign2911200;
var anf_assign2921202 = G(FailureReason6251193.$var,"type-mismatch",L[22]);
type_DASH_mismatch291201.$var = anf_assign2921202;
var anf_assign2931204 = G(FailureReason6251193.$var,"is-predicate-failure",L[17]);
is_DASH_predicate_DASH_failure301203.$var = anf_assign2931204;
var anf_assign2941206 = G(FailureReason6251193.$var,"predicate-failure",L[17]);
predicate_DASH_failure311205.$var = anf_assign2941206;
var anf_assign2951208 = G(FailureReason6251193.$var,"is-record-fields-fail",L[12]);
is_DASH_record_DASH_fields_DASH_fail321207.$var = anf_assign2951208;
var anf_assign2961210 = G(FailureReason6251193.$var,"record-fields-fail",L[12]);
record_DASH_fields_DASH_fail331209.$var = anf_assign2961210;
var anf_assign2971212 = G(FailureReason6251193.$var,"is-dot-ann-not-present",L[4]);
is_DASH_dot_DASH_ann_DASH_not_DASH_present341211.$var = anf_assign2971212;
var anf_assign2981214 = G(FailureReason6251193.$var,"dot-ann-not-present",L[4]);
dot_DASH_ann_DASH_not_DASH_present351213.$var = anf_assign2981214;
var provides29922 = R.makeObject({"ContractResult":ContractResult101163.$var,
"is-ContractResult":is_DASH_ContractResult111165.$var,
"ok":ok131169.$var,
"is-ok":is_DASH_ok121167.$var,
"fail":fail151173.$var,
"is-fail":is_DASH_fail141171.$var,
"fail-arg":fail_DASH_arg171177.$var,
"is-fail-arg":is_DASH_fail_DASH_arg161175.$var,
"FieldFailure":FieldFailure191181.$var,
"is-FieldFailure":is_DASH_FieldFailure201183.$var,
"field-failure":field_DASH_failure221187.$var,
"is-field-failure":is_DASH_field_DASH_failure211185.$var,
"missing-field":missing_DASH_field241191.$var,
"is-missing-field":is_DASH_missing_DASH_field231189.$var,
"FailureReason":FailureReason261195.$var,
"is-FailureReason":is_DASH_FailureReason271197.$var,
"type-mismatch":type_DASH_mismatch291201.$var,
"is-type-mismatch":is_DASH_type_DASH_mismatch281199.$var,
"predicate-failure":predicate_DASH_failure311205.$var,
"is-predicate-failure":is_DASH_predicate_DASH_failure301203.$var,
"record-fields-fail":record_DASH_fields_DASH_fail331209.$var,
"is-record-fields-fail":is_DASH_record_DASH_fields_DASH_fail321207.$var,
"dot-ann-not-present":dot_DASH_ann_DASH_not_DASH_present351213.$var,
"is-dot-ann-not-present":is_DASH_dot_DASH_ann_DASH_not_DASH_present341211.$var});
var anf_fun3001225 = G(builtins8,"current-checker",L[0]);
var $z12171218 = D;
var $f12231224 = function(_) {
return R.isFunction(anf_fun3001225)?anf_fun3001225.app():R.ffi.throwNonFunApp(L[0],anf_fun3001225,[]);
};
try {
if(--R.GAS > 0) {
$z12171218 = $f12231224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12231224,
"from":L[0]});
}
} catch($e12151216) {
if(R.isCont($e12151216)) {
var $ss12191220 = {"from":L[0],
"go":function(anf_bracket30118) {
return $Hanf_bracket42017(anf_bracket30118,ContractResult319,FailureReason720,FieldFailure521,provides29922,nothing9);
}};
$e12151216.stack[R.EXN_STACKHEIGHT++] = $ss12191220;
}
if(R.isPyretException($e12151216)) {
$e12151216.pyretStack.push(L[0]);
}
throw $e12151216;
}
var $ret12211222 = $Hanf_bracket42017($z12171218,ContractResult319,FailureReason720,FieldFailure521,provides29922,nothing9);
++R.GAS;
return $ret12211222;
},function(moduleVal) {
R.modules["$src/arr/base/contracts.arr15"] = moduleVal
return moduleVal;
});
});
}
};
});
define('js/ffi-helpers',["js/runtime-util", "trove/lists", "trove/option", "trove/either", "trove/error", "trove/srcloc", "trove/contracts"], function(util, listLib, optLib, eitherLib, errorLib, srclocLib, contractsLib) {
  return util.memoModule("ffi-helpers", function(runtime, namespace) {
    
    return runtime.loadModules(namespace, [listLib, optLib, eitherLib, errorLib, srclocLib, contractsLib], function(L, O, E, ERR, S, C) {

      function makeList(arr) {
        var lst = runtime.getField(L, "empty");
        for(var i = arr.length - 1; i >= 0; i--) {
          lst = runtime.getField(L, "link").app(arr[i], lst); 
        }
        return lst;
      }
      var gf = runtime.getField;

      var checkSrcloc = runtime.makeCheckType(function(val) {
        return runtime.unwrap(gf(S, "Srcloc").app(val));
      }, "Srcloc");

      function cases(pred, predName, val, casesObj) {
        if(!pred.app(val)) {
          throwTypeMismatch(val, predName);
        }
        var pyretObj = {}
        var els = runtime.makeFunction(function(v) {
          throwMessageException("No cases matched");
        });
        Object.keys(casesObj).forEach(function(k) {
          if(k !== "else") {
            pyretObj[k] = runtime.makeFunction(casesObj[k]);
          } else {
            els = runtime.makeFunction(casesObj[k]);
          }
        });
        return runtime.safeTail(function() {
          return gf(val, "_match").app(runtime.makeObject(pyretObj), els);
        });
      }

      var checkArity = runtime.checkArity;


      function err(str) { return gf(ERR, str).app; }
      function contract(str) { return gf(C, str).app; }
      function errPred(str) {
        return function(val) {
          return runtime.unwrap(gf(ERR, str).app(val));
        };
      }
      var raise = runtime.raise;

      function throwInternalError(message, otherArgs) {
        runtime.checkString(message);
        runtime.checkList(otherArgs);
        raise(err("internal-error")(runtime.makeString(message), otherArgs));
      }

      function throwFieldNotFound(loc, object, field) {
        checkSrcloc(loc);
        runtime.checkPyretVal(object);
        runtime.checkString(field);
        raise(err("field-not-found")(loc, object, runtime.makeString(field)));
      }
      function throwLookupNonObject(loc, nonObject, field) {
        checkSrcloc(loc);
        runtime.checkPyretVal(nonObject);
        runtime.checkString(field);
        raise(err("lookup-non-object")(loc, nonObject, runtime.makeString(field)));
      }

      function throwMessageException(message) {
        runtime.checkString(message);
        raise(err("message-exception")(message));
      }

      function makeMessageException(message) {
        runtime.checkString(message);
        return err("message-exception")(message);
      }

      function throwTypeMismatch(val, typeName) {
        // NOTE(joe): can't use checkPyretVal here, because it will re-enter
        // this function and blow up... so bottom out at "nothing"
        if(!runtime.isPyretVal(val)) {
          val = runtime.namespace.get("nothing");
        }
        runtime.checkString(typeName);
        raise(err("generic-type-mismatch")(val, typeName));
      }

      function throwInvalidArrayIndex(methodName, array, index, reason) {
        runtime.checkString(methodName);
        runtime.checkArray(array);
        runtime.checkNumber(index);
        runtime.checkString(reason);
        raise(err("invalid-array-index")(methodName, array, index, reason));
      }

      function throwPlusError(left, right) {
        runtime.checkPyretVal(left);
        runtime.checkPyretVal(right);
        raise(err("plus-error")(left, right));
      }

      function throwNumericBinopError(left, right, opname, methodname) {
        runtime.checkPyretVal(left);
        runtime.checkPyretVal(right);
        runtime.checkString(opname);
        runtime.checkString(methodname);
        raise(err("numeric-binop-error")(left, right, opname, methodname));
      }

      function throwUninitializedId(loc, name) {
        checkSrcloc(loc);
        runtime.checkString(name);
        raise(err("uninitialized-id")(loc, name));
      }

      function throwUninitializedIdMkLoc(loc, name) {
        throwUninitializedId(runtime.makeSrcloc(loc), name);
      }

      function throwArityError(funLoc, arity, args) {
        checkSrcloc(funLoc);
        runtime.checkNumber(arity);
        runtime.checkList(args);
        raise(err("arity-mismatch")(funLoc, arity, args));
      }

      function throwArityErrorC(funLoc, arity, args) {
        var loc = runtime.makeSrcloc(funLoc);
        var argsPyret = makeList(Array.prototype.slice.call(args, 0, args.length));
        throwArityError(loc, arity, argsPyret);
      }

      function throwNonBooleanCondition(locArray, type, val) {
        runtime.checkString(type);
        runtime.checkPyretVal(val);
        raise(err("non-boolean-condition")(runtime.makeSrcloc(locArray), type, val));
      }
      function throwNonBooleanOp(locArray, position, type, val) {
        runtime.checkString(position);
        runtime.checkString(type);
        runtime.checkPyretVal(val);
        raise(err("non-boolean-op")(runtime.makeSrcloc(locArray), position, type, val));
      }
      function throwNoBranchesMatched(locArray, type) {
        runtime.checkString(type);
        raise(err("no-branches-matched")(runtime.makeSrcloc(locArray), type));
      }
      function throwNonFunApp(locArray, funVal, args) {
        runtime.checkPyretVal(funVal);
        var argList = makeList(args);
        raise(err("non-function-app")(runtime.makeSrcloc(locArray), funVal, argList));
      }

      function throwParseErrorNextToken(loc, nextToken) {
        raise(err("parse-error-next-token")(loc, nextToken));
      }
      function throwParseErrorEOF(loc) {
        raise(err("parse-error-eof")(loc));
      }

      function throwModuleLoadFailureL(names) {
        raise(makeModuleLoadFailureL(names));
      }

      function makeModuleLoadFailureL(names) {
        var namesList = makeList(names);
        return err("module-load-failure")(namesList);
      }

      function makeRecordFieldsFail(value, failures) {
        runtime.checkPyretVal(value);
        return contract("record-fields-fail")(value, failures);
      }

      function makeFieldFailure(loc, field, reason) {
        checkSrcloc(loc);
        runtime.checkString(field);
        return contract("field-failure")(loc, field, reason);
      }

      function makeMissingField(loc, field) {
        checkSrcloc(loc);
        runtime.checkString(field);
        return contract("missing-field")(loc, field);
      }

      function makeTypeMismatch(val, name) {
        runtime.checkString(name);
        runtime.checkPyretVal(val);
        return contract("type-mismatch")(val, name);
      }

      function makePredicateFailure(val, name) {
        runtime.checkString(name);
        runtime.checkPyretVal(val);
        return contract("predicate-failure")(val, name);
      }

      function makeDotAnnNotPresent(name, field) {
        runtime.checkString(name);
        runtime.checkPyretVal(field);
        return contract("dot-ann-not-present")(name, field);
      }

      function isOk(val) {
        return contract("is-ok")(val);
      }

      function isFail(val) {
        return contract("is-fail")(val);
      }

      function isFailArg(val) {
        return contract("is-fail-arg")(val);
      }

      return {
        throwPlusError: throwPlusError,
        throwNumericBinopError: throwNumericBinopError,
        throwInternalError: throwInternalError,
        throwFieldNotFound: throwFieldNotFound,
        throwLookupNonObject: throwLookupNonObject,
        throwTypeMismatch: throwTypeMismatch,
        throwInvalidArrayIndex: throwInvalidArrayIndex,
        throwMessageException: throwMessageException,
        throwUninitializedId: throwUninitializedId,
        throwUninitializedIdMkLoc: throwUninitializedIdMkLoc,
        throwArityError: throwArityError,
        throwArityErrorC: throwArityErrorC,
        throwNonBooleanCondition: throwNonBooleanCondition,
        throwNonBooleanOp: throwNonBooleanOp,
        throwNoBranchesMatched: throwNoBranchesMatched,
        throwNonFunApp: throwNonFunApp,
        throwModuleLoadFailureL: throwModuleLoadFailureL,

        throwParseErrorNextToken: throwParseErrorNextToken,
        throwParseErrorEOF: throwParseErrorEOF,

        makeRecordFieldsFail: makeRecordFieldsFail,
        makeFieldFailure: makeFieldFailure,
        makeMissingField: makeMissingField,
        makeTypeMismatch: makeTypeMismatch,
        makePredicateFailure: makePredicateFailure,
        makeDotAnnNotPresent: makeDotAnnNotPresent,
        contractOk: gf(C, "ok"),
        contractFail: contract("fail"),
        contractFailArg: contract("fail-arg"),
        isOk: isOk,
        isFail: isFail,
        isFailArg: isFailArg,

        makeMessageException: makeMessageException,
        makeModuleLoadFailureL: makeModuleLoadFailureL,

        userBreak: gf(ERR, "user-break"),
        isUserBreak: errPred("is-user-break"),

        errPred: errPred,

        cases: cases,

        checkArity: checkArity,

        makeList: makeList,
        makeNone: function() { return runtime.getField(O, "none"); },
        makeSome: function(v) { return runtime.getField(O, "some").app(v); },
        makeLeft: function(l) { return runtime.getField(E, "left").app(l); },
        makeRight: function(r) { return runtime.getField(E, "right").app(r); },

        toArray: function(list) {
          var isList = runtime.getField(L, "List");
          var isEmpty = runtime.getField(L, "is-empty");
          var isLink = runtime.getField(L, "is-link");
          // console.error("list is " + JSON.stringify(list).substr(0, 100));
          // console.error("list is Object? " + runtime.isObject(list));
          // console.error("list.brands is " + JSON.stringify(list.brands));
          if(!(runtime.unwrap(isList.app(list)) === true)) {
            throw "Non-list given to toArray " + String(list);
          }
          var arr = [];
          try {
            while(!(runtime.unwrap(isEmpty.app(list)) === true)) {
              try {
                arr.push(runtime.getField(list, "first"));
              } catch(e) {
                console.error("***** getField first failed on list: " + JSON.stringify(list));
                console.error(e);
                throw e;
              }
              try {
                list = runtime.getField(list, "rest");
              } catch(e) {
                console.error("***** getField rest failed on list: " + JSON.stringify(list));
                console.error(e);
                throw e;
              }
            }
          } catch(e) {
            console.error("******* Calling isEmpty failed on list: " + JSON.stringify(list));
            console.error(e);
            throw e;
          }
          return arr;
        },
        isList: function(list) { return runtime.unwrap(runtime.getField(L, "List").app(list)); }
      };
    });
  });
});

define('trove/cmdline-lib',["js/runtime-util", "js/ffi-helpers"], function(util, ffi) {

  return util.memoModule("cmdline-lib", function(RUNTIME, NAMESPACE) {
    return RUNTIME.loadJSModules(NAMESPACE, [ffi], function(F) {
      return RUNTIME.makeObject({
        provide: RUNTIME.makeObject({
          "command-line-arguments": RUNTIME.makeFunction(function() {
            return F.makeList(RUNTIME.getParam("command-line-arguments").map(RUNTIME.makeString));
          }),
        }),
        answer: NAMESPACE.get("nothing")
      });
    });
  });
});



define('trove/format',["js/runtime-util", "trove/lists", "js/ffi-helpers"], function(util, L, ffiLib) {

  return util.memoModule("format", function(RUNTIME, NAMESPACE) {
    return RUNTIME.loadJSModules(NAMESPACE, [ffiLib], function(F) {
      // Stolen from https://github.com/dyoo/whalesong/blob/master\
      // /whalesong/js-assembler/runtime-src/baselib-format.js
      var formatRegexp1 = new RegExp('~[sSaA]', 'g');
      var formatRegexp2 = new RegExp("~[sSaAnevE%~]", "g");
      return RUNTIME.loadModules(NAMESPACE, [L], function(list) {
      
        // format: string [X ...] string -> string
        // String formatting.  If an exception occurs, throws
        // a plain Error whose message describes the formatting error.
        var format = function(formatStr, args, functionName) {
            var throwFormatError = function() {
                functionName = functionName || 'format';
                var matches = formatStr.match(formatRegexp1);
                var expectedNumberOfArgs = (matches === null ? 0 : matches.length);
                var errorStrBuffer = [functionName + ': format string requires '
                                      + expectedNumberOfArgs
                                      + ' arguments, given ' + args.length + '; arguments were:',
                                      toWrittenString(formatStr)];
                var i;
                for (i = 0; i < args.length; i++) {
                  if(RUNTIME.isString(args[i])) {
                    errorStrBuffer.push( RUNTIME.toReprJS(args[i], "tostring") );
                  }
                  else {
                    RUNTIME.ffi.throwTypeMismatch(args[i], "String");
                  }
                }

                throw new Error(errorStrBuffer.join(' '));
            };


            var buffer = args.slice(0);
            var onTemplate = function(s) {
                if (s === "~~") {
                    return "~";
                } else if (s === '~n' || s === '~%') {
                    return "\n";
                } else if (s === '~s' || s === "~S") {
                    if (buffer.length === 0) {
                        throwFormatError();
                    }
                    return RUNTIME.toReprJS(buffer.shift(), "tostring");
                } else if (s === '~e' || s === "~E") {
                    // FIXME: we don't yet have support for the error-print
                    // handler, and currently treat ~e just like ~s.
                    if (buffer.length === 0) {
                        throwFormatError();
                    }
                    var arg = buffer.shift();
                    if (RUNTIME.isString(arg)) {
                      return RUNTIME.toReprJS(buffer.shift(), "tostring"); 
                    }
                    else {
                      RUNTIME.ffi.throwTypeMismatch(args[i], "String");
                    }
                }
                else if (s === '~v') {
                    if (buffer.length === 0) {
                        throwFormatError();
                    }
                    // fprintf must do something more interesting here by
                    // printing the dom representation directly...
                    return toWrittenString(buffer.shift());
                } else if (s === '~a' || s === "~A") {
                    if (buffer.length === 0) {
                        throwFormatError();
                    }
                    return RUNTIME.toReprJS(buffer.shift(), "tostring");
                } else {
                    throw new Error(functionName + 
                                    ': string.replace matched invalid regexp');
                }
            };
            var result = formatStr.replace(formatRegexp2, onTemplate);
            if (buffer.length > 0) {
                throwFormatError();
            }
            return result;
        };

        function listToArr(lst) {
          var arr = [];
          var isLink = RUNTIME.unwrap(RUNTIME.getField(list, "is-link").app(lst));
          var isEmpty = RUNTIME.unwrap(RUNTIME.getField(list, "is-empty").app(lst));
          if(!(isLink || isEmpty)) {
            throw new Error("Expected list in listToArr, but got something else");
          }
          while(!(RUNTIME.unwrap(RUNTIME.getField(list, "is-empty").app(lst)))) {
            arr.push(RUNTIME.getField(lst, "first"));
            lst = RUNTIME.getField(lst, "rest");
          }
          return arr;
        }

        return RUNTIME.makeObject({
          provide: RUNTIME.makeObject({
            format: RUNTIME.makeFunction(function(str, args) {
              F.checkArity(2, arguments, "format");
              RUNTIME.checkString(str);
              return RUNTIME.makeString(format(RUNTIME.unwrap(str), listToArr(args)));
            }),
          }),
          answer: NAMESPACE.get("nothing")
        });
      });
    });
  });
});



define('trove/string-dict',["js/runtime-util", "js/namespace", "js/ffi-helpers"], function(util, Namespace, ffi) {
  return util.memoModule("string-dict", function(RUNTIME, NAMESPACE) {
    return RUNTIME.loadJSModules(NAMESPACE, [ffi], function(F) {
      var unwrap = RUNTIME.unwrap;
      var ImmutableStringDict = Namespace.Namespace;

      function StringDict(d) {
        this.d = d;
      }
      StringDict.prototype.get = function(s) { return this.d[" " + s]; }
      StringDict.prototype.set = function(s, val) { this.d[" " + s] = val; }
      StringDict.prototype.getNames = function() { 
        return Object.keys(this.d).map(function(k) {return k.slice(1);});
      }
      StringDict.prototype.hasBinding = function(s) {
        var result = Object.prototype.hasOwnProperty.call(this.d, " " + s);
        return result;
      };

      function isStringDict(sd) {
        return (sd instanceof ImmutableStringDict) || (sd instanceof StringDict);
      }

      function equalsDict(d1, d2) {
        if(((d1 instanceof StringDict) && (d2 instanceof StringDict)) ||
           ((d1 instanceof ImmutableStringDict) && (d2 instanceof ImmutableStringDict))) {
          var names1 = d1.getNames();
          var names2 = d2.getNames();
          if (names1.length !== names2.length) { return false; }
          for(var i = 0; i < names1.length; i++) {
            if(!(RUNTIME.same(d1.get(names1[i]), d2.get(names2[i])))) {
              return false;
            }
          }
        }
      }

      var hasKey = RUNTIME.makeMethodFromFun(function(self, str) {
        RUNTIME.checkString(str);
        var s = unwrap(str); 
        return RUNTIME.makeBoolean(RUNTIME.getField(self, "the-dict").val.hasBinding(s));
      });
      var get = RUNTIME.makeMethodFromFun(function(self, str) {
        RUNTIME.checkString(str);
        var s = unwrap(str); 
        var dict = RUNTIME.getField(self, "the-dict");
        if(dict.val instanceof ImmutableStringDict) {
          return dict.val.get(s);
        }
        else {
          return dict.val.get(s);
        }
      });

      var set = RUNTIME.makeMethodFromFun(function(self, str, val) {
        RUNTIME.checkString(str);
        var s = unwrap(str);
        var dict = RUNTIME.getField(self, "the-dict");
        if(dict.val instanceof ImmutableStringDict) {
          return stringDictObj(dict.val.set(s, val));
        }
        else {
          dict.val.set(s, val);
          return self;
        }
      });
      var keys = RUNTIME.makeMethodFromFun(function(self) {
        var dict = RUNTIME.getField(self, "the-dict");
        return F.makeList(dict.val.getNames().map(RUNTIME.makeString));
      });

      function stringDictObj(aDict) {
        return RUNTIME.makeObject({
            'the-dict': RUNTIME.makeOpaque(aDict, equalsDict),
            'has-key': hasKey,
            'get': get,
            'set': set,
            'keys': keys
          });
      }

      return RUNTIME.makeObject({
          "provide-plus-types": RUNTIME.makeObject({
            types: {
              StringDict: RUNTIME.makePrimitiveAnn("StringDict", function(val) {
                if (!RUNTIME.isObject(val) || !RUNTIME.hasField(val, "the-dict")) {
                  return false;
                }
                if (!RUNTIME.isOpaque(RUNTIME.getField(val, "the-dict"))) {
                  return false;
                }
                var theDict = RUNTIME.getField(val, "the-dict");
                return (theDict.val instanceof ImmutableStringDict) ||
                        (theDict.val instanceof StringDict);
              }),
            },
            values: RUNTIME.makeObject({
              'StringDict': RUNTIME.makeFunction(function() { throw RUNTIME.makeMessageException("Cannot check StringDict yet") } ),
              'to-dict': RUNTIME.makeFunction(function(dict) {
                  F.checkArity(1, arguments, "to-dict");
                  RUNTIME.checkObject(dict);
                  var fields = RUNTIME.getFields(dict);
                  var ns = new ImmutableStringDict(Object.create({}));
                  fields.forEach(function(f) { ns = ns.set(f, RUNTIME.getField(dict, f)); });
                  return stringDictObj(ns);
                }),
              'immutable-string-dict': RUNTIME.makeFunction(function() {
                  F.checkArity(0, arguments, "immutable-string-dict");
                  return stringDictObj(new ImmutableStringDict(Object.create(null)));
                }),
              'string-dict': RUNTIME.makeFunction(function() {
                  F.checkArity(0, arguments, "string-dict");
                  return stringDictObj(new StringDict(Object.create(null)));
                })
             })
          }),
          answer: NAMESPACE.get("nothing")
        });
    });
  });
});


define('trove/cmdline',["trove/cmdline-lib",
"trove/format",
"trove/string-dict",
"trove/either",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($CL12948,$F33049,$D53150,$E73251,$arrays93352,$lists113453,$option133554,$error153655,$sets173756) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/trove/cmdline.arr47"]) {
return R.modules["$src/arr/trove/cmdline.arr47"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/trove/cmdline.arr";
var D = R.undefined;
var L = [[M,37,0,774,506,3,25081],
[M,383,22,17102,383,28,17108],
[M,383,14,17094,383,21,17101],
[M,383,10,17090,383,13,17093],
[M,383,0,17080,383,32,17112],
[M,376,0,16926,380,3,17077],
[M,377,18,16957,377,43,16982],
[M,377,18,16957,377,41,16980],
[M,377,2,16941,379,5,17073],
[M,378,16,17040,378,22,17046],
[M,378,10,17034,378,15,17039],
[M,378,4,17028,378,9,17033],
[M,370,0,16768,373,3,16923],
[M,140,0,4961,368,3,16766],
[M,144,2,5265,144,32,5295],
[M,144,14,5277,144,23,5286],
[M,140,32,4993,140,44,5005],
[M,106,0,3159,136,3,4825],
[M,107,2,3206,107,34,3238],
[M,107,12,3216,107,21,3225],
[M,100,0,2994,103,3,3124],
[M,101,2,3014,102,44,3120],
[M,96,2,2854,97,114,2988],
[M,95,2,2778,95,75,2851],
[M,93,2,2639,94,114,2775],
[M,92,2,2561,92,77,2636],
[M,91,2,2511,91,49,2558],
[M,90,0,2497,98,3,2992],
[M,91,4,2513,91,49,2558],
[M,91,21,2530,91,32,2541],
[M,91,42,2551,91,48,2557],
[M,92,4,2563,92,77,2636],
[M,92,25,2584,92,35,2594],
[M,92,49,2608,92,60,2619],
[M,92,70,2629,92,76,2635],
[M,93,4,2641,94,114,2775],
[M,94,16,2677,94,26,2687],
[M,94,58,2719,94,72,2733],
[M,94,86,2747,94,97,2758],
[M,94,107,2768,94,113,2774],
[M,95,4,2780,95,75,2851],
[M,95,23,2799,95,33,2809],
[M,95,47,2823,95,58,2834],
[M,95,68,2844,95,74,2850],
[M,96,4,2856,97,114,2988],
[M,97,16,2890,97,26,2900],
[M,97,58,2932,97,72,2946],
[M,97,86,2960,97,97,2971],
[M,97,107,2981,97,113,2987],
[M,97,99,2973,97,113,2987],
[M,97,74,2948,97,97,2971],
[M,97,44,2918,97,72,2946],
[M,97,28,2902,97,42,2916],
[M,97,6,2880,97,26,2900],
[M,95,60,2836,95,74,2850],
[M,95,35,2811,95,58,2834],
[M,95,13,2789,95,33,2809],
[M,94,99,2760,94,113,2774],
[M,94,74,2735,94,97,2758],
[M,94,44,2705,94,72,2733],
[M,94,28,2689,94,42,2703],
[M,94,6,2667,94,26,2687],
[M,92,62,2621,92,76,2635],
[M,92,37,2596,92,60,2619],
[M,92,15,2574,92,35,2594],
[M,91,34,2543,91,48,2557],
[M,91,9,2518,91,32,2541],
[M,87,2,2424,87,69,2491],
[M,86,2,2355,86,68,2421],
[M,85,2,2305,85,49,2352],
[M,84,2,2246,84,58,2302],
[M,83,0,2226,88,3,2495],
[M,87,24,2446,87,69,2491],
[M,86,24,2377,86,68,2421],
[M,85,15,2318,85,49,2352],
[M,84,15,2259,84,58,2302],
[M,79,2,2153,79,68,2219],
[M,78,2,2092,78,60,2150],
[M,77,0,2068,80,3,2223],
[M,78,4,2094,78,60,2150],
[M,78,22,2112,78,34,2124],
[M,78,47,2137,78,59,2149],
[M,79,4,2155,79,68,2219],
[M,79,25,2176,79,31,2182],
[M,79,52,2203,79,67,2218],
[M,79,33,2184,79,67,2218],
[M,79,14,2165,79,31,2182],
[M,78,36,2126,78,59,2149],
[M,78,12,2102,78,34,2124],
[M,70,2,1819,74,61,2062],
[M,65,2,1655,69,38,1816],
[M,56,2,1312,64,42,1652],
[M,47,2,984,55,38,1309],
[M,46,0,965,75,3,2066],
[M,70,4,1821,70,51,1868],
[M,70,24,1841,70,30,1847],
[M,70,42,1859,70,50,1867],
[M,74,39,2040,74,56,2057],
[M,74,46,2047,74,55,2056],
[M,74,4,2005,74,61,2062],
[M,71,4,1879,73,7,1999],
[M,72,6,1954,72,17,1965],
[M,71,29,1904,71,35,1910],
[M,71,51,1926,71,57,1932],
[M,71,64,1939,71,70,1945],
[M,70,32,1849,70,50,1867],
[M,70,16,1833,70,30,1847],
[M,69,4,1782,69,38,1816],
[M,66,4,1679,68,7,1776],
[M,66,26,1701,66,32,1707],
[M,66,48,1723,66,54,1729],
[M,66,61,1736,66,67,1742],
[M,64,4,1614,64,42,1652],
[M,58,22,1433,58,32,1443],
[M,59,28,1472,59,39,1483],
[M,61,82,1578,61,91,1587],
[M,61,63,1559,61,92,1588],
[M,59,14,1458,59,27,1471],
[M,58,9,1420,58,21,1432],
[M,57,72,1402,57,79,1409],
[M,57,26,1356,57,32,1362],
[M,57,48,1378,57,54,1384],
[M,57,61,1391,57,67,1397],
[M,57,4,1334,63,7,1608],
[M,55,4,1275,55,38,1309],
[M,49,6,1090,49,28,1112],
[M,48,26,1030,48,32,1036],
[M,48,48,1052,48,54,1058],
[M,48,61,1065,48,67,1071],
[M,48,4,1008,54,7,1269],
[M,44,13,940,44,36,963],
[M,43,12,902,43,36,926],
[M,385,0,17114,506,3,25081],
[M,394,9,17323,394,26,17340],
[M,386,2,17123,391,9,17285],
[M,386,23,17144,391,5,17281],
[M,387,6,17160,390,9,17275],
[M,389,8,17229,389,44,17265],
[M,389,29,17250,389,39,17260],
[M,388,8,17196,388,32,17220],
[M,396,2,17347,396,96,17441],
[M,396,33,17378,396,47,17392],
[M,396,2,17347,396,48,17393],
[M,396,65,17410,396,84,17429],
[M,396,60,17405,396,85,17430],
[M,396,87,17432,396,95,17440],
[M,396,52,17397,396,96,17441],
[M,397,2,17444,397,100,17542],
[M,397,33,17475,397,46,17488],
[M,397,2,17444,397,47,17489],
[M,397,59,17501,397,84,17526],
[M,397,59,17501,397,82,17524],
[M,397,86,17528,397,99,17541],
[M,397,51,17493,397,100,17542],
[M,398,2,17545,398,84,17627],
[M,398,33,17576,398,48,17591],
[M,398,2,17545,398,49,17592],
[M,398,60,17603,398,84,17627],
[M,399,2,17630,399,98,17726],
[M,399,33,17661,399,55,17683],
[M,399,2,17630,399,56,17684],
[M,399,67,17695,399,98,17726],
[M,400,2,17729,400,108,17835],
[M,400,33,17760,400,54,17781],
[M,400,2,17729,400,55,17782],
[M,400,72,17799,400,91,17818],
[M,400,67,17794,400,92,17819],
[M,400,94,17821,400,107,17834],
[M,400,59,17786,400,108,17835],
[M,401,2,17838,401,108,17944],
[M,401,33,17869,401,54,17890],
[M,401,2,17838,401,55,17891],
[M,401,72,17908,401,91,17927],
[M,401,67,17903,401,92,17928],
[M,401,94,17930,401,107,17943],
[M,401,59,17895,401,108,17944],
[M,402,2,17947,402,105,18050],
[M,402,33,17978,402,47,17992],
[M,402,2,17947,402,48,17993],
[M,402,59,18004,402,105,18050],
[M,403,2,18053,403,107,18158],
[M,403,33,18084,403,48,18099],
[M,403,2,18053,403,49,18100],
[M,403,60,18111,403,107,18158],
[M,406,9,18194,406,35,18220],
[M,408,2,18227,408,96,18321],
[M,408,33,18258,408,47,18272],
[M,408,2,18227,408,48,18273],
[M,408,65,18290,408,84,18309],
[M,408,60,18285,408,85,18310],
[M,408,87,18312,408,95,18320],
[M,408,52,18277,408,96,18321],
[M,409,2,18324,409,92,18414],
[M,409,33,18355,409,46,18368],
[M,409,2,18324,409,47,18369],
[M,409,58,18380,409,92,18414],
[M,410,2,18417,410,84,18499],
[M,410,33,18448,410,48,18463],
[M,410,2,18417,410,49,18464],
[M,410,60,18475,410,84,18499],
[M,411,2,18502,411,98,18598],
[M,411,33,18533,411,55,18555],
[M,411,2,18502,411,56,18556],
[M,411,67,18567,411,98,18598],
[M,412,2,18601,412,108,18707],
[M,412,33,18632,412,54,18653],
[M,412,2,18601,412,55,18654],
[M,412,72,18671,412,91,18690],
[M,412,67,18666,412,92,18691],
[M,412,94,18693,412,107,18706],
[M,412,59,18658,412,108,18707],
[M,413,2,18710,413,108,18816],
[M,413,33,18741,413,54,18762],
[M,413,2,18710,413,55,18763],
[M,413,72,18780,413,91,18799],
[M,413,67,18775,413,92,18800],
[M,413,94,18802,413,107,18815],
[M,413,59,18767,413,108,18816],
[M,417,45,18901,417,54,18910],
[M,417,9,18865,417,77,18933],
[M,418,9,18944,418,26,18961],
[M,420,2,18968,420,106,19072],
[M,420,43,19009,420,60,19026],
[M,420,2,18968,420,61,19027],
[M,420,78,19044,420,94,19060],
[M,420,73,19039,420,95,19061],
[M,420,97,19063,420,105,19071],
[M,420,65,19031,420,106,19072],
[M,421,2,19075,421,115,19188],
[M,421,43,19116,421,62,19135],
[M,421,2,19075,421,63,19136],
[M,421,74,19147,421,115,19188],
[M,422,2,19191,422,114,19303],
[M,422,43,19232,422,71,19260],
[M,422,2,19191,422,72,19261],
[M,422,83,19272,422,114,19303],
[M,423,2,19306,423,102,19406],
[M,423,43,19347,423,55,19359],
[M,423,2,19306,423,56,19360],
[M,423,73,19377,423,90,19394],
[M,423,68,19372,423,91,19395],
[M,423,93,19397,423,101,19405],
[M,423,60,19364,423,102,19406],
[M,424,2,19409,424,105,19512],
[M,424,43,19450,424,58,19465],
[M,424,2,19409,424,59,19466],
[M,424,76,19483,424,93,19500],
[M,424,71,19478,424,94,19501],
[M,424,96,19503,424,104,19511],
[M,424,63,19470,424,105,19512],
[M,425,2,19515,425,126,19639],
[M,425,43,19556,425,66,19579],
[M,425,2,19515,425,67,19580],
[M,425,84,19597,425,114,19627],
[M,425,79,19592,425,115,19628],
[M,425,117,19630,425,125,19638],
[M,425,71,19584,425,126,19639],
[M,426,2,19642,426,126,19766],
[M,426,43,19683,426,66,19706],
[M,426,2,19642,426,67,19707],
[M,426,84,19724,426,114,19754],
[M,426,79,19719,426,115,19755],
[M,426,117,19757,426,125,19765],
[M,426,71,19711,426,126,19766],
[M,427,2,19769,427,123,19890],
[M,427,43,19810,427,63,19830],
[M,427,2,19769,427,64,19831],
[M,427,81,19848,427,111,19878],
[M,427,76,19843,427,112,19879],
[M,427,114,19881,427,122,19889],
[M,427,68,19835,427,123,19890],
[M,431,45,19971,431,54,19980],
[M,431,11,19937,431,70,19996],
[M,433,2,20003,433,122,20123],
[M,433,41,20042,433,64,20065],
[M,433,2,20003,433,65,20066],
[M,433,82,20083,433,101,20102],
[M,433,77,20078,433,102,20103],
[M,433,104,20105,433,121,20122],
[M,433,69,20070,433,122,20123],
[M,434,2,20126,434,135,20259],
[M,434,41,20165,434,76,20200],
[M,434,2,20126,434,77,20201],
[M,434,94,20218,434,114,20238],
[M,434,89,20213,434,115,20239],
[M,434,117,20241,434,134,20258],
[M,434,81,20205,434,135,20259],
[M,435,2,20262,435,116,20376],
[M,435,41,20301,435,58,20318],
[M,435,2,20262,435,59,20319],
[M,435,76,20336,435,95,20355],
[M,435,71,20331,435,96,20356],
[M,435,98,20358,435,115,20375],
[M,435,63,20323,435,116,20376],
[M,436,2,20379,436,129,20506],
[M,436,41,20418,436,72,20449],
[M,436,2,20379,436,73,20450],
[M,436,84,20461,436,129,20506],
[M,439,43,20586,439,52,20595],
[M,439,9,20552,439,75,20618],
[M,440,9,20629,440,26,20646],
[M,442,2,20653,442,107,20758],
[M,442,41,20692,442,61,20712],
[M,442,2,20653,442,62,20713],
[M,442,79,20730,442,95,20746],
[M,442,74,20725,442,96,20747],
[M,442,98,20749,442,106,20757],
[M,442,66,20717,442,107,20758],
[M,443,2,20761,443,116,20875],
[M,443,41,20800,443,63,20822],
[M,443,2,20761,443,64,20823],
[M,443,75,20834,443,116,20875],
[M,444,2,20878,444,118,20994],
[M,444,41,20917,444,75,20951],
[M,444,2,20878,444,76,20952],
[M,444,87,20963,444,118,20994],
[M,445,2,20997,445,100,21095],
[M,445,41,21036,445,53,21048],
[M,445,2,20997,445,54,21049],
[M,445,71,21066,445,88,21083],
[M,445,66,21061,445,89,21084],
[M,445,91,21086,445,99,21094],
[M,445,58,21053,445,100,21095],
[M,446,2,21098,446,103,21199],
[M,446,41,21137,446,56,21152],
[M,446,2,21098,446,57,21153],
[M,446,74,21170,446,91,21187],
[M,446,69,21165,446,92,21188],
[M,446,94,21190,446,102,21198],
[M,446,61,21157,446,103,21199],
[M,447,2,21202,447,124,21324],
[M,447,41,21241,447,64,21264],
[M,447,2,21202,447,65,21265],
[M,447,82,21282,447,112,21312],
[M,447,77,21277,447,113,21313],
[M,447,115,21315,447,123,21323],
[M,447,69,21269,447,124,21324],
[M,448,2,21327,448,121,21446],
[M,448,41,21366,448,61,21386],
[M,448,2,21327,448,62,21387],
[M,448,79,21404,448,109,21434],
[M,448,74,21399,448,110,21435],
[M,448,112,21437,448,120,21445],
[M,448,66,21391,448,121,21446],
[M,449,2,21449,449,121,21568],
[M,449,41,21488,449,61,21508],
[M,449,2,21449,449,62,21509],
[M,449,79,21526,449,109,21556],
[M,449,74,21521,449,110,21557],
[M,449,112,21559,449,120,21567],
[M,449,66,21513,449,121,21568],
[M,452,9,21604,452,26,21621],
[M,453,43,21666,453,52,21675],
[M,453,9,21632,453,66,21689],
[M,454,11,21702,454,31,21722],
[M,456,2,21729,456,132,21859],
[M,456,33,21760,456,63,21790],
[M,456,2,21729,456,64,21791],
[M,456,95,21822,456,119,21846],
[M,456,81,21808,456,120,21847],
[M,456,76,21803,456,121,21848],
[M,456,123,21850,456,131,21858],
[M,456,68,21795,456,132,21859],
[M,457,2,21862,458,91,22037],
[M,457,33,21893,457,84,21944],
[M,457,2,21862,457,85,21945],
[M,458,34,21980,458,52,21998],
[M,458,20,21966,458,79,22025],
[M,458,61,22007,458,78,22024],
[M,458,15,21961,458,80,22026],
[M,458,82,22028,458,90,22036],
[M,458,7,21953,458,91,22037],
[M,459,2,22040,460,95,22216],
[M,459,33,22071,459,81,22119],
[M,459,2,22040,459,82,22120],
[M,460,34,22155,460,52,22173],
[M,460,20,22141,460,80,22201],
[M,460,61,22182,460,79,22200],
[M,460,15,22136,460,81,22202],
[M,460,83,22204,460,94,22215],
[M,460,7,22128,460,95,22216],
[M,461,2,22219,461,109,22326],
[M,461,33,22250,461,54,22271],
[M,461,2,22219,461,55,22272],
[M,461,86,22303,461,96,22313],
[M,461,72,22289,461,97,22314],
[M,461,67,22284,461,98,22315],
[M,461,100,22317,461,108,22325],
[M,461,59,22276,461,109,22326],
[M,462,2,22329,462,132,22459],
[M,462,33,22360,462,65,22392],
[M,462,2,22329,462,66,22393],
[M,462,77,22404,462,132,22459],
[M,463,2,22462,463,109,22569],
[M,463,33,22493,463,54,22514],
[M,463,2,22462,463,55,22515],
[M,463,86,22546,463,96,22556],
[M,463,72,22532,463,97,22557],
[M,463,67,22527,463,98,22558],
[M,463,100,22560,463,108,22568],
[M,463,59,22519,463,109,22569],
[M,464,2,22572,464,134,22704],
[M,464,33,22603,464,60,22630],
[M,464,2,22572,464,61,22631],
[M,464,92,22662,464,102,22672],
[M,464,78,22648,464,122,22692],
[M,464,109,22679,464,121,22691],
[M,464,73,22643,464,123,22693],
[M,464,125,22695,464,133,22703],
[M,464,65,22635,464,134,22704],
[M,467,9,22742,467,52,22785],
[M,468,9,22796,468,26,22813],
[M,470,2,22820,470,134,22952],
[M,470,35,22853,470,70,22888],
[M,470,2,22820,470,71,22889],
[M,470,102,22920,470,121,22939],
[M,470,88,22906,470,122,22940],
[M,470,83,22901,470,123,22941],
[M,470,125,22943,470,133,22951],
[M,470,75,22893,470,134,22952],
[M,471,2,22955,471,95,23048],
[M,471,35,22988,471,49,23002],
[M,471,2,22955,471,50,23003],
[M,471,61,23014,471,95,23048],
[M,472,2,23051,472,125,23174],
[M,472,35,23084,472,50,23099],
[M,472,2,23051,472,51,23100],
[M,472,62,23111,472,125,23174],
[M,475,9,23214,475,52,23257],
[M,476,9,23268,476,26,23285],
[M,478,2,23292,478,119,23409],
[M,478,37,23327,478,60,23350],
[M,478,2,23292,478,61,23351],
[M,478,92,23382,478,106,23396],
[M,478,78,23368,478,107,23397],
[M,478,73,23363,478,108,23398],
[M,478,110,23400,478,118,23408],
[M,478,65,23355,478,119,23409],
[M,479,2,23412,479,153,23563],
[M,479,37,23447,479,60,23470],
[M,479,2,23412,479,61,23471],
[M,479,72,23482,479,153,23563],
[M,482,9,23603,482,52,23646],
[M,483,9,23657,483,26,23674],
[M,484,11,23687,484,31,23707],
[M,486,2,23714,486,153,23865],
[M,486,37,23749,486,60,23772],
[M,486,2,23714,486,61,23773],
[M,486,72,23784,486,153,23865],
[M,487,2,23868,487,113,23979],
[M,487,37,23903,487,58,23924],
[M,487,2,23868,487,59,23925],
[M,487,90,23956,487,100,23966],
[M,487,76,23942,487,101,23967],
[M,487,71,23937,487,102,23968],
[M,487,104,23970,487,112,23978],
[M,487,63,23929,487,113,23979],
[M,488,2,23982,488,138,24118],
[M,488,37,24017,488,64,24044],
[M,488,2,23982,488,65,24045],
[M,488,96,24076,488,106,24086],
[M,488,82,24062,488,126,24106],
[M,488,113,24093,488,125,24105],
[M,488,77,24057,488,127,24107],
[M,488,129,24109,488,137,24117],
[M,488,69,24049,488,138,24118],
[M,490,2,24122,496,8,24420],
[M,490,48,24168,496,7,24419],
[M,491,23,24218,491,32,24227],
[M,492,30,24258,492,41,24269],
[M,493,29,24299,493,39,24309],
[M,494,77,24387,494,88,24398],
[M,494,64,24374,494,89,24399],
[M,493,14,24284,493,28,24298],
[M,492,14,24242,492,29,24257],
[M,491,9,24204,491,22,24217],
[M,498,48,24492,498,57,24501],
[M,498,11,24455,498,73,24517],
[M,500,2,24524,500,113,24635],
[M,500,31,24553,500,55,24577],
[M,500,2,24524,500,56,24578],
[M,500,89,24611,500,100,24622],
[M,500,73,24595,500,101,24623],
[M,500,68,24590,500,102,24624],
[M,500,104,24626,500,112,24634],
[M,500,60,24582,500,113,24635],
[M,501,2,24638,502,71,24789],
[M,501,31,24667,501,80,24716],
[M,501,2,24638,501,81,24717],
[M,502,36,24754,502,58,24776],
[M,502,20,24738,502,59,24777],
[M,502,15,24733,502,60,24778],
[M,502,62,24780,502,70,24788],
[M,502,7,24725,502,71,24789],
[M,503,2,24792,503,124,24914],
[M,503,31,24821,503,55,24845],
[M,503,2,24792,503,56,24846],
[M,503,67,24857,503,124,24914],
[M,504,2,24917,505,78,25077],
[M,504,31,24946,504,82,24997],
[M,504,2,24917,504,83,24998],
[M,505,36,25035,505,59,25058],
[M,505,20,25019,505,60,25059],
[M,505,15,25014,505,61,25060],
[M,505,63,25062,505,77,25076],
[M,505,7,25006,505,78,25077],
[M,494,18,24328,494,90,24400],
[M,494,12,24322,494,91,24401],
[M,377,67,17006,377,77,17016],
[M,377,67,17006,377,75,17014],
[M,377,52,16991,377,63,17002],
[M,377,67,17006,377,82,17021],
[M,377,52,16991,377,82,17021],
[M,378,10,17034,378,22,17046],
[M,378,31,17055,378,37,17061],
[M,378,24,17048,378,29,17053],
[M,378,30,17054,378,42,17066],
[M,378,24,17048,378,42,17066],
[M,146,58,5378,146,83,5403],
[M,146,58,5378,146,81,5401],
[M,146,4,5324,172,7,6540],
[M,147,9,5443,147,26,5460],
[M,146,8,5328,146,18,5338],
[M,146,95,5415,146,111,5431],
[M,146,95,5415,146,109,5429],
[M,145,2,5298,172,7,6540],
[M,173,5,6546,173,38,6579],
[M,173,40,6581,173,59,6600],
[M,207,41,8146,207,57,8162],
[M,207,41,8146,207,55,8160],
[M,207,15,8120,210,7,8282],
[M,208,17,8182,208,35,8200],
[M,208,17,8182,208,30,8195],
[M,207,19,8124,207,31,8136],
[M,177,4,6709,206,7,8104],
[M,178,6,6766,205,9,8096],
[M,179,8,6806,203,13,8060],
[M,180,10,6846,203,13,8060],
[M,197,12,7788,202,17,8046],
[M,198,17,7824,198,45,7852],
[M,198,17,7824,198,39,7846],
[M,198,17,7824,198,31,7838],
[M,192,12,7464,196,17,7775],
[M,193,17,7500,193,45,7528],
[M,193,17,7500,193,39,7522],
[M,193,17,7500,193,31,7514],
[M,186,12,7202,191,17,7451],
[M,187,17,7229,187,45,7257],
[M,187,17,7229,187,39,7251],
[M,187,17,7229,187,31,7243],
[M,181,12,6887,185,17,7189],
[M,182,17,6914,182,45,6942],
[M,182,17,6914,182,39,6936],
[M,182,17,6914,182,31,6928],
[M,176,21,6677,176,48,6704],
[M,175,19,6628,175,46,6655],
[M,140,49,5010,140,64,5025],
[M,207,4,8109,210,7,8282],
[M,340,37,15532,340,62,15557],
[M,340,37,15532,340,60,15555],
[M,211,4,8287,339,7,15494],
[M,212,9,8340,212,30,8361],
[M,340,64,15559,340,72,15567],
[M,340,29,15524,340,73,15568],
[M,340,4,15499,340,83,15578],
[M,341,4,15583,366,7,16756],
[M,342,6,15628,364,11,16717],
[M,343,75,15731,343,91,15747],
[M,343,75,15731,343,89,15745],
[M,343,34,15690,355,11,16286],
[M,344,10,15760,354,13,16260],
[M,344,23,15773,344,36,15786],
[M,343,38,15694,343,48,15704],
[M,343,8,15664,355,11,16286],
[M,356,8,16295,358,11,16410],
[M,356,23,16310,358,11,16410],
[M,357,14,16361,357,50,16397],
[M,357,14,16361,357,45,16392],
[M,356,27,16314,356,39,16326],
[M,359,11,16422,359,33,16444],
[M,359,35,16446,359,74,16485],
[M,363,14,16656,363,45,16687],
[M,362,12,16533,363,46,16688],
[M,361,10,16510,363,63,16705],
[M,349,12,16018,352,17,16220],
[M,350,21,16091,350,37,16107],
[M,350,21,16091,350,32,16102],
[M,345,12,15805,348,17,16005],
[M,346,21,15876,346,37,15892],
[M,346,21,15876,346,32,15887],
[M,350,17,16087,350,86,16156],
[M,350,44,16114,350,85,16155],
[M,350,65,16135,350,84,16154],
[M,350,44,16114,350,62,16132],
[M,350,42,16112,350,85,16155],
[M,350,17,16087,350,38,16108],
[M,350,87,16157,350,108,16178],
[M,350,87,16157,350,94,16164],
[M,351,20,16199,351,23,16202],
[M,346,17,15872,346,86,15941],
[M,346,44,15899,346,85,15940],
[M,346,65,15920,346,84,15939],
[M,346,44,15899,346,62,15917],
[M,346,42,15897,346,85,15940],
[M,346,17,15872,346,38,15893],
[M,346,87,15942,346,108,15963],
[M,346,87,15942,346,94,15949],
[M,347,20,15984,347,23,15987],
[M,212,32,8363,212,39,8370],
[M,214,8,8391,337,11,15476],
[M,216,10,8461,336,15,15464],
[M,217,15,8504,217,44,8533],
[M,215,10,8432,215,28,8450],
[M,218,66,8609,218,86,8629],
[M,311,20,14013,311,49,14042],
[M,217,15,8504,217,53,8542],
[M,218,39,8582,218,87,8630],
[M,218,14,8557,218,100,8643],
[M,220,17,8697,220,42,8722],
[M,220,17,8697,220,37,8717],
[M,219,20,8664,219,35,8679],
[M,221,16,8740,307,19,13879],
[M,221,29,8753,221,45,8769],
[M,309,26,13926,309,65,13965],
[M,306,95,13837,306,106,13848],
[M,278,18,12091,304,23,13713],
[M,279,20,12166,304,23,13713],
[M,302,45,13602,302,66,13623],
[M,302,45,13602,302,64,13621],
[M,302,28,13585,302,95,13652],
[M,280,22,12224,299,27,13414],
[M,281,24,12259,299,27,13414],
[M,283,26,12402,298,31,13386],
[M,284,31,12454,284,53,12476],
[M,282,26,12316,282,85,12375],
[M,279,40,12186,279,54,12200],
[M,246,18,10180,277,23,12072],
[M,247,20,10235,277,23,12072],
[M,275,45,11961,275,66,11982],
[M,275,45,11961,275,64,11980],
[M,275,28,11944,275,95,12011],
[M,248,22,10293,271,27,11746],
[M,249,24,10328,271,27,11746],
[M,254,26,10643,270,31,11718],
[M,255,31,10695,255,53,10717],
[M,250,26,10385,253,38,10616],
[M,252,49,10553,252,70,10574],
[M,252,49,10553,252,68,10572],
[M,252,32,10536,252,71,10575],
[M,247,40,10255,247,54,10269],
[M,235,18,9516,245,23,10161],
[M,236,20,9593,245,23,10161],
[M,239,22,9792,244,27,10137],
[M,240,24,9834,240,70,9880],
[M,240,37,9847,240,49,9859],
[M,237,22,9651,238,107,9769],
[M,238,32,9694,238,80,9742],
[M,236,40,9613,236,54,9627],
[M,222,18,8794,234,23,9497],
[M,223,20,8851,234,23,9497],
[M,228,22,9128,233,27,9473],
[M,229,24,9170,229,70,9216],
[M,229,37,9183,229,49,9195],
[M,224,22,8909,227,34,9105],
[M,226,91,9046,226,112,9067],
[M,226,91,9046,226,110,9065],
[M,226,74,9029,226,113,9068],
[M,223,40,8871,223,54,8885],
[M,306,30,13772,306,107,13849],
[M,302,73,13630,302,94,13651],
[M,302,73,13630,302,92,13649],
[M,301,34,13481,302,96,13653],
[M,285,30,12515,285,76,12561],
[M,285,43,12528,285,55,12540],
[M,293,30,13032,293,76,13078],
[M,293,43,13045,293,55,13057],
[M,284,31,12454,284,61,12484],
[M,286,30,12592,291,33,12967],
[M,289,32,12802,290,117,12933],
[M,290,42,12858,290,90,12906],
[M,287,32,12650,288,106,12769],
[M,288,42,12705,288,84,12747],
[M,290,92,12908,290,106,12922],
[M,288,86,12749,288,100,12763],
[M,294,30,13109,297,33,13354],
[M,296,32,13285,296,67,13320],
[M,295,32,13167,295,117,13252],
[M,295,53,13188,295,95,13230],
[M,295,97,13232,295,111,13246],
[M,275,73,11989,275,94,12010],
[M,275,73,11989,275,92,12008],
[M,274,26,11840,275,96,12012],
[M,256,30,10756,256,76,10802],
[M,256,43,10769,256,55,10781],
[M,265,56,11386,265,70,11400],
[M,265,43,11373,265,55,11385],
[M,255,31,10695,255,61,10725],
[M,257,30,10833,263,33,11295],
[M,259,32,11009,262,44,11261],
[M,261,55,11192,261,76,11213],
[M,261,55,11192,261,74,11211],
[M,261,38,11175,261,77,11214],
[M,258,32,10891,258,117,10976],
[M,258,53,10912,258,95,10954],
[M,260,44,11067,261,78,11215],
[M,258,97,10956,258,111,10970],
[M,265,30,11360,265,80,11410],
[M,266,30,11441,269,33,11686],
[M,268,32,11617,268,67,11652],
[M,267,32,11499,267,117,11584],
[M,267,53,11520,267,95,11562],
[M,267,97,11564,267,111,11578],
[M,251,38,10434,252,72,10576],
[M,241,24,9905,244,27,10137],
[M,243,26,10074,243,61,10109],
[M,242,26,9957,242,116,10047],
[M,242,47,9978,242,89,10020],
[M,242,91,10022,242,105,10036],
[M,238,82,9744,238,96,9758],
[M,230,24,9241,233,27,9473],
[M,232,26,9410,232,61,9445],
[M,231,26,9293,231,116,9383],
[M,231,47,9314,231,89,9356],
[M,231,91,9358,231,105,9372],
[M,226,26,8981,226,114,9069],
[M,309,16,13916,309,74,13974],
[M,312,47,14098,312,67,14118],
[M,335,38,15373,335,66,15401],
[M,335,38,15373,335,53,15388],
[M,335,22,15357,335,36,15371],
[M,311,20,14013,311,57,14050],
[M,312,14,14065,312,68,14119],
[M,314,19,14163,314,97,14241],
[M,314,19,14163,314,41,14185],
[M,314,72,14216,314,95,14239],
[M,314,72,14216,314,90,14234],
[M,314,51,14195,314,71,14215],
[M,314,19,14163,314,46,14190],
[M,315,35,14277,315,58,14300],
[M,315,35,14277,315,53,14295],
[M,315,18,14260,315,34,14276],
[M,316,16,14318,317,39,14392],
[M,316,24,14326,316,44,14346],
[M,321,17,14478,321,34,14495],
[M,314,51,14195,314,96,14240],
[M,315,18,14260,315,59,14301],
[M,317,18,14371,317,39,14392],
[M,317,18,14371,317,34,14387],
[M,319,18,14433,319,25,14440],
[M,316,24,14326,316,49,14351],
[M,322,16,14513,330,19,15204],
[M,329,100,15162,329,111,15173],
[M,327,18,14888,328,123,15061],
[M,328,63,15001,328,86,15024],
[M,328,63,15001,328,81,15019],
[M,325,18,14694,326,123,14869],
[M,326,63,14809,326,86,14832],
[M,326,63,14809,326,81,14827],
[M,323,18,14552,324,100,14675],
[M,324,28,14603,324,73,14648],
[M,332,26,15251,332,64,15289],
[M,329,38,15100,329,112,15174],
[M,328,28,14966,328,96,15034],
[M,328,98,15036,328,112,15050],
[M,326,28,14774,326,96,14842],
[M,326,98,14844,326,112,14858],
[M,324,75,14650,324,89,14664],
[M,332,16,15241,332,73,15298],
[M,335,14,15349,335,66,15401],
[M,208,44,8209,209,64,8274],
[M,209,36,8246,209,64,8274],
[M,208,44,8209,209,33,8243],
[M,208,17,8182,208,44,8209],
[M,199,41,7895,199,65,7919],
[M,199,41,7895,199,59,7913],
[M,199,41,7895,199,55,7909],
[M,199,24,7878,199,34,7888],
[M,201,41,8006,201,52,8017],
[M,201,24,7989,201,34,7999],
[M,199,68,7922,199,79,7933],
[M,199,41,7895,199,80,7934],
[M,199,24,7878,199,80,7934],
[M,199,16,7870,199,90,7944],
[M,201,24,7989,201,53,8018],
[M,201,16,7981,201,63,8028],
[M,194,123,7653,194,156,7686],
[M,195,28,7726,195,49,7747],
[M,195,28,7726,195,38,7736],
[M,194,26,7556,194,157,7687],
[M,194,16,7546,194,167,7697],
[M,195,20,7718,195,59,7757],
[M,188,41,7300,188,65,7324],
[M,188,41,7300,188,59,7318],
[M,188,41,7300,188,55,7314],
[M,188,24,7283,188,34,7293],
[M,190,41,7411,190,52,7422],
[M,190,24,7394,190,34,7404],
[M,188,68,7327,188,79,7338],
[M,188,41,7300,188,80,7339],
[M,188,24,7283,188,80,7339],
[M,188,16,7275,188,90,7349],
[M,190,24,7394,190,53,7423],
[M,190,16,7386,190,63,7433],
[M,183,123,7067,183,156,7100],
[M,184,28,7140,184,49,7161],
[M,184,28,7140,184,38,7150],
[M,183,26,6970,183,157,7101],
[M,183,16,6960,183,167,7111],
[M,184,20,7132,184,59,7171],
[M,147,28,5462,147,31,5465],
[M,149,8,5486,149,39,5517],
[M,149,21,5499,149,34,5512],
[M,150,8,5526,170,11,6522],
[M,160,10,6030,168,15,6486],
[M,161,12,6088,168,15,6486],
[M,163,14,6164,167,19,6470],
[M,164,19,6200,164,45,6226],
[M,164,19,6200,164,38,6219],
[M,164,19,6200,164,30,6211],
[M,162,14,6136,162,27,6149],
[M,151,10,5561,159,15,6019],
[M,152,12,5621,159,15,6019],
[M,154,14,5697,158,19,6003],
[M,155,19,5733,155,45,5759],
[M,155,19,5733,155,38,5752],
[M,155,19,5733,155,30,5744],
[M,153,14,5669,153,27,5682],
[M,165,28,6256,165,89,6317],
[M,166,58,6422,166,85,6449],
[M,166,58,6422,166,73,6437],
[M,166,58,6422,166,69,6433],
[M,166,36,6400,166,47,6411],
[M,165,98,6326,165,123,6351],
[M,165,98,6326,165,121,6349],
[M,165,125,6353,165,133,6361],
[M,165,90,6318,165,134,6362],
[M,165,18,6246,165,135,6363],
[M,166,22,6386,166,86,6450],
[M,156,28,5789,156,89,5850],
[M,157,58,5955,157,85,5982],
[M,157,58,5955,157,73,5970],
[M,157,58,5955,157,69,5966],
[M,157,36,5933,157,47,5944],
[M,156,98,5859,156,123,5884],
[M,156,98,5859,156,121,5882],
[M,156,125,5886,156,133,5894],
[M,156,90,5851,156,134,5895],
[M,156,18,5779,156,135,5896],
[M,157,22,5919,157,86,5983],
[M,109,27,3283,109,41,3297],
[M,109,27,3283,109,39,3295],
[M,109,4,3260,134,7,4734],
[M,110,6,3306,133,9,4726],
[M,110,19,3319,110,30,3330],
[M,109,8,3264,109,17,3273],
[M,108,2,3241,134,7,4734],
[M,135,45,4780,135,62,4797],
[M,135,66,4801,135,86,4821],
[M,135,2,4737,135,63,4798],
[M,125,8,4223,132,13,4716],
[M,126,10,4300,132,13,4716],
[M,129,12,4493,131,99,4702],
[M,131,28,4631,131,49,4652],
[M,131,28,4631,131,47,4650],
[M,131,16,4619,131,98,4701],
[M,127,12,4346,128,124,4480],
[M,128,76,4432,128,97,4453],
[M,128,76,4432,128,95,4451],
[M,128,64,4420,128,123,4479],
[M,123,8,4086,124,90,4214],
[M,124,51,4175,124,72,4196],
[M,124,51,4175,124,70,4194],
[M,124,39,4163,124,89,4213],
[M,115,8,3582,122,13,4077],
[M,116,10,3661,122,13,4077],
[M,119,12,3854,121,99,4063],
[M,121,28,3992,121,49,4013],
[M,121,28,3992,121,47,4011],
[M,121,16,3980,121,98,4062],
[M,117,12,3707,118,124,3841],
[M,118,76,3793,118,97,3814],
[M,118,76,3793,118,95,3812],
[M,118,64,3781,118,123,3840],
[M,113,8,3443,114,90,3573],
[M,114,51,3534,114,72,3555],
[M,114,51,3534,114,70,3553],
[M,114,39,3522,114,89,3572],
[M,111,8,3345,112,63,3434],
[M,112,35,3406,112,62,3433],
[M,101,2,3014,101,12,3024],
[M,101,16,3028,101,32,3044],
[M,101,36,3048,101,60,3072],
[M,102,4,3080,102,18,3094],
[M,102,22,3098,102,44,3120],
[M,61,14,1510,61,93,1589],
[M,61,8,1504,61,94,1590],
[M,50,9,1122,50,22,1135],
[M,51,82,1219,51,91,1228],
[M,51,63,1200,51,92,1229],
[M,52,12,1244,52,19,1251],
[M,48,72,1076,48,78,1082],
[M,51,14,1151,51,93,1230],
[M,51,8,1145,51,94,1231],
[M,3,0,13,506,3,25081],
[M,42,0,841,42,48,889],
[M,42,21,862,42,46,887],
[M,40,8,832,40,15,839],
[M,39,7,817,39,13,823],
[M,38,9,801,38,17,809],
[M,37,9,783,37,17,791]];
var _divide12 = NAMESPACE.get("_divide");
var _plus13 = NAMESPACE.get("_plus");
var _times14 = NAMESPACE.get("_times");
var builtins15 = NAMESPACE.get("builtins");
var is_DASH_nothing16 = NAMESPACE.get("is-nothing");
var not17 = NAMESPACE.get("not");
var nothing18 = NAMESPACE.get("nothing");
var string_DASH_char_DASH_at19 = NAMESPACE.get("string-char-at");
var string_DASH_length20 = NAMESPACE.get("string-length");
var string_DASH_split21 = NAMESPACE.get("string-split");
var string_DASH_substring22 = NAMESPACE.get("string-substring");
var string_DASH_tonumber23 = NAMESPACE.get("string-tonumber");
var torepr24 = NAMESPACE.get("torepr");
var $type$Boolean25 = NAMESPACE.get("$type$Boolean");
var $type$Function26 = NAMESPACE.get("$type$Function");
var $type$Number27 = NAMESPACE.get("$type$Number");
var $type$String28 = NAMESPACE.get("$type$String");
var $Hall_DASH_cmdline_DASH_params276757 = function(all_DASH_cmdline_DASH_params8258,D531,D640,List1959,Option2060,Param7461,ParamRepeat7262,ParamRepeatT47363,ParamT57564,ParseParam6865,ParseParamT26966,ParsedArguments7067,ParsedArgumentsT37168,RGB7669,RGBT67770,fold5571,format7872,is_DASH_empty2873,left8074,link3175,list2776,lists1134,right8177,some6478,_divide12,_plus13,_times14,builtins15,is_DASH_nothing16,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22,string_DASH_tonumber23,torepr24,$type$Boolean25,$type$Function26,$type$Number27,$type$String28) {
var file_DASH_name83203 = G(all_DASH_cmdline_DASH_params8258,"first",L[131]);
var other_DASH_args84204 = G(all_DASH_cmdline_DASH_params8258,"rest",L[130]);
var ParseParam78579 = {"$var":D,
"$name":"ParseParam7"};
var ParseParam8681 = {"$var":D,
"$name":"ParseParam"};
var is_DASH_ParseParam8783 = {"$var":D,
"$name":"is-ParseParam"};
var is_DASH_read_DASH_number8885 = {"$var":D,
"$name":"is-read-number"};
var read_DASH_number8987 = {"$var":D,
"$name":"read-number"};
var is_DASH_read_DASH_bool9089 = {"$var":D,
"$name":"is-read-bool"};
var read_DASH_bool9191 = {"$var":D,
"$name":"read-bool"};
var is_DASH_read_DASH_string9293 = {"$var":D,
"$name":"is-read-string"};
var read_DASH_string9395 = {"$var":D,
"$name":"read-string"};
var is_DASH_read_DASH_custom9497 = {"$var":D,
"$name":"is-read-custom"};
var read_DASH_custom9599 = {"$var":D,
"$name":"read-custom"};
var ParsedArguments896101 = {"$var":D,
"$name":"ParsedArguments8"};
var ParsedArguments97103 = {"$var":D,
"$name":"ParsedArguments"};
var is_DASH_ParsedArguments98105 = {"$var":D,
"$name":"is-ParsedArguments"};
var is_DASH_success99107 = {"$var":D,
"$name":"is-success"};
var success100109 = {"$var":D,
"$name":"success"};
var is_DASH_arg_DASH_error101111 = {"$var":D,
"$name":"is-arg-error"};
var arg_DASH_error102113 = {"$var":D,
"$name":"arg-error"};
var ParamRepeat9103115 = {"$var":D,
"$name":"ParamRepeat9"};
var ParamRepeat104117 = {"$var":D,
"$name":"ParamRepeat"};
var is_DASH_ParamRepeat105119 = {"$var":D,
"$name":"is-ParamRepeat"};
var is_DASH_once106121 = {"$var":D,
"$name":"is-once"};
var once107123 = {"$var":D,
"$name":"once"};
var is_DASH_many108125 = {"$var":D,
"$name":"is-many"};
var many109127 = {"$var":D,
"$name":"many"};
var is_DASH_required_DASH_once110129 = {"$var":D,
"$name":"is-required-once"};
var required_DASH_once111131 = {"$var":D,
"$name":"required-once"};
var is_DASH_required_DASH_many112133 = {"$var":D,
"$name":"is-required-many"};
var required_DASH_many113135 = {"$var":D,
"$name":"required-many"};
var Param10114137 = {"$var":D,
"$name":"Param10"};
var Param115139 = {"$var":D,
"$name":"Param"};
var is_DASH_Param116141 = {"$var":D,
"$name":"is-Param"};
var is_DASH_flag117143 = {"$var":D,
"$name":"is-flag"};
var flag118145 = {"$var":D,
"$name":"flag"};
var is_DASH_equals_DASH_val119147 = {"$var":D,
"$name":"is-equals-val"};
var equals_DASH_val120149 = {"$var":D,
"$name":"equals-val"};
var is_DASH_equals_DASH_val_DASH_default121151 = {"$var":D,
"$name":"is-equals-val-default"};
var equals_DASH_val_DASH_default122153 = {"$var":D,
"$name":"equals-val-default"};
var is_DASH_next_DASH_val123155 = {"$var":D,
"$name":"is-next-val"};
var next_DASH_val124157 = {"$var":D,
"$name":"next-val"};
var is_DASH_next_DASH_val_DASH_default125159 = {"$var":D,
"$name":"is-next-val-default"};
var next_DASH_val_DASH_default126161 = {"$var":D,
"$name":"next-val-default"};
var is_DASH_Param_127163 = {"$var":D,
"$name":"is-Param_"};
var usage_DASH_info128165 = {"$var":D,
"$name":"usage-info"};
var parse_DASH_args129167 = {"$var":D,
"$name":"parse-args"};
var parse_DASH_cmdline130169 = {"$var":D,
"$name":"parse-cmdline"};
var dict131171 = {"$var":D,
"$name":"dict"};
var RGB11132173 = {"$var":D,
"$name":"RGB11"};
var RGB133175 = {"$var":D,
"$name":"RGB"};
var is_DASH_RGB134177 = {"$var":D,
"$name":"is-RGB"};
var is_DASH_red135179 = {"$var":D,
"$name":"is-red"};
var red136181 = {"$var":D,
"$name":"red"};
var is_DASH_green137183 = {"$var":D,
"$name":"is-green"};
var green138185 = {"$var":D,
"$name":"green"};
var is_DASH_blue139187 = {"$var":D,
"$name":"is-blue"};
var blue140189 = {"$var":D,
"$name":"blue"};
var anf_singleton_variant_member121069 = R.makeMethod(function(self21391) {
return function(cases_DASH_funs31370,else_DASH_clause41381) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[92],2,arguments);
}
var if_DASH_61384 = R.hasField(cases_DASH_funs31370,("read-number"));
var if_helper31368 = R.makeFunction(function(if_helper_arg41389) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[92],1,arguments);
}
var ann_DASH_check_DASH_temp21390 = if_helper_arg41389;
return ann_DASH_check_DASH_temp21390;
});
var anf_if71388 = R.isBoolean(if_DASH_61384);
if(R.isPyretTrue(anf_if71388)) {
if(R.isPyretTrue(if_DASH_61384)) {
var call_DASH_read_DASH_number11366 = G(cases_DASH_funs31370,"read-number",L[92]);
var $z13581359 = D;
var $f13641365 = function(_) {
return R.isFunction(call_DASH_read_DASH_number11366)?call_DASH_read_DASH_number11366.app():R.ffi.throwNonFunApp(L[92],call_DASH_read_DASH_number11366,[]);
};
try {
if(--R.GAS > 0) {
$z13581359 = $f13641365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13641365,
"from":L[92]});
}
} catch($e13561357) {
if(R.isCont($e13561357)) {
var $ss13601361 = {"from":L[92],
"go":function(cont_tail_arg101367) {
return $Hcont_tail_arg18881369(cont_tail_arg101367,if_helper31368);
}};
$e13561357.stack[R.EXN_STACKHEIGHT++] = $ss13601361;
}
if(R.isPyretException($e13561357)) {
$e13561357.pyretStack.push(L[92]);
}
throw $e13561357;
}
var $ret13621363 = $Hcont_tail_arg18881369($z13581359,if_helper31368);
++R.GAS;
return $ret13621363;
} else {
var $z13731374 = D;
var $f13791380 = function(_) {
return R.isFunction(else_DASH_clause41381)?else_DASH_clause41381.app():R.ffi.throwNonFunApp(L[92],else_DASH_clause41381,[]);
};
try {
if(--R.GAS > 0) {
$z13731374 = $f13791380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13791380,
"from":L[92]});
}
} catch($e13711372) {
if(R.isCont($e13711372)) {
var $ss13751376 = {"from":L[92],
"go":function(cont_tail_arg81382) {
return $Hcont_tail_arg18891383(cont_tail_arg81382,if_helper31368);
}};
$e13711372.stack[R.EXN_STACKHEIGHT++] = $ss13751376;
}
if(R.isPyretException($e13711372)) {
$e13711372.pyretStack.push(L[92]);
}
throw $e13711372;
}
var $ret13771378 = $Hcont_tail_arg18891383($z13731374,if_helper31368);
++R.GAS;
return $ret13771378;
}
} else {
var cont_tail_arg51387 = R.throwNonBooleanCondition(L[92],("if"),if_DASH_61384);
if(--R.GAS > 0) {
$z13851386 = R.isFunction(if_helper31368)?if_helper31368.app(cont_tail_arg51387):R.ffi.throwNonFunApp(L[92],if_helper31368,[cont_tail_arg51387]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper31368)?if_helper31368.app(cont_tail_arg51387):R.ffi.throwNonFunApp(L[92],if_helper31368,[cont_tail_arg51387]);
},
"from":L[92]});
}
++R.GAS;
return $z13851386;
}
};
},{"length":3});
var anf_singleton_variant_member141070 = R.makeMethod(function(self51355) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[92],0,arguments);
}
var ann_DASH_check_DASH_temp131354 = ("read-number");
return ann_DASH_check_DASH_temp131354;
};
},{"length":1});
var anf_singleton_variant_member291071 = R.makeMethod(function($underscore1411353) {
return function(arg_DASH_index1421352,param_DASH_name1431350,s1441348) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[129],3,arguments);
}
return R.checkAnnArgs([$type$Number27,$type$String28,$type$String28],[arg_DASH_index1421352,param_DASH_name1431350,s1441348],[L[126],L[127],L[128]],function() {
var $z13401341 = D;
var $f13461347 = function(_) {
return R.isFunction(string_DASH_tonumber23)?string_DASH_tonumber23.app(s1441348):R.ffi.throwNonFunApp(L[125],string_DASH_tonumber23,[s1441348]);
};
try {
if(--R.GAS > 0) {
$z13401341 = $f13461347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13461347,
"from":L[125]});
}
} catch($e13381339) {
if(R.isCont($e13381339)) {
var $ss13421343 = {"from":L[125],
"go":function(n1451349) {
return $Hn18961351(n1451349,format7872,left8074,list2776,param_DASH_name1431350,right8177,s1441348,is_DASH_nothing16,torepr24,$type$Number27);
}};
$e13381339.stack[R.EXN_STACKHEIGHT++] = $ss13421343;
}
if(R.isPyretException($e13381339)) {
$e13381339.pyretStack.push(L[125]);
}
throw $e13381339;
}
var $ret13441345 = $Hn18961351($z13401341,format7872,left8074,list2776,param_DASH_name1431350,right8177,s1441348,is_DASH_nothing16,torepr24,$type$Number27);
++R.GAS;
return $ret13441345;
});
};
},{"length":4});
var anf_singleton_variant_member311072 = R.makeMethod(function(self1461337) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[124],0,arguments);
}
var ann_DASH_check_DASH_temp301336 = ("<number>");
return ann_DASH_check_DASH_temp301336;
};
},{"length":1});
var anf_singleton_variant_member421078 = R.makeMethod(function(self91335) {
return function(cases_DASH_funs101314,else_DASH_clause111325) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[91],2,arguments);
}
var if_DASH_131328 = R.hasField(cases_DASH_funs101314,("read-bool"));
var if_helper331312 = R.makeFunction(function(if_helper_arg341333) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[91],1,arguments);
}
var ann_DASH_check_DASH_temp321334 = if_helper_arg341333;
return ann_DASH_check_DASH_temp321334;
});
var anf_if371332 = R.isBoolean(if_DASH_131328);
if(R.isPyretTrue(anf_if371332)) {
if(R.isPyretTrue(if_DASH_131328)) {
var call_DASH_read_DASH_bool81310 = G(cases_DASH_funs101314,"read-bool",L[91]);
var $z13021303 = D;
var $f13081309 = function(_) {
return R.isFunction(call_DASH_read_DASH_bool81310)?call_DASH_read_DASH_bool81310.app():R.ffi.throwNonFunApp(L[91],call_DASH_read_DASH_bool81310,[]);
};
try {
if(--R.GAS > 0) {
$z13021303 = $f13081309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13081309,
"from":L[91]});
}
} catch($e13001301) {
if(R.isCont($e13001301)) {
var $ss13041305 = {"from":L[91],
"go":function(cont_tail_arg401311) {
return $Hcont_tail_arg18971313(cont_tail_arg401311,if_helper331312);
}};
$e13001301.stack[R.EXN_STACKHEIGHT++] = $ss13041305;
}
if(R.isPyretException($e13001301)) {
$e13001301.pyretStack.push(L[91]);
}
throw $e13001301;
}
var $ret13061307 = $Hcont_tail_arg18971313($z13021303,if_helper331312);
++R.GAS;
return $ret13061307;
} else {
var $z13171318 = D;
var $f13231324 = function(_) {
return R.isFunction(else_DASH_clause111325)?else_DASH_clause111325.app():R.ffi.throwNonFunApp(L[91],else_DASH_clause111325,[]);
};
try {
if(--R.GAS > 0) {
$z13171318 = $f13231324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13231324,
"from":L[91]});
}
} catch($e13151316) {
if(R.isCont($e13151316)) {
var $ss13191320 = {"from":L[91],
"go":function(cont_tail_arg381326) {
return $Hcont_tail_arg18981327(cont_tail_arg381326,if_helper331312);
}};
$e13151316.stack[R.EXN_STACKHEIGHT++] = $ss13191320;
}
if(R.isPyretException($e13151316)) {
$e13151316.pyretStack.push(L[91]);
}
throw $e13151316;
}
var $ret13211322 = $Hcont_tail_arg18981327($z13171318,if_helper331312);
++R.GAS;
return $ret13211322;
}
} else {
var cont_tail_arg351331 = R.throwNonBooleanCondition(L[91],("if"),if_DASH_131328);
if(--R.GAS > 0) {
$z13291330 = R.isFunction(if_helper331312)?if_helper331312.app(cont_tail_arg351331):R.ffi.throwNonFunApp(L[91],if_helper331312,[cont_tail_arg351331]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper331312)?if_helper331312.app(cont_tail_arg351331):R.ffi.throwNonFunApp(L[91],if_helper331312,[cont_tail_arg351331]);
},
"from":L[91]});
}
++R.GAS;
return $z13291330;
}
};
},{"length":3});
var anf_singleton_variant_member441079 = R.makeMethod(function(self121299) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[91],0,arguments);
}
var ann_DASH_check_DASH_temp431298 = ("read-bool");
return ann_DASH_check_DASH_temp431298;
};
},{"length":1});
var anf_singleton_variant_member641080 = R.makeMethod(function($underscore1471297) {
return function(arg_DASH_index1481296,param_DASH_name1491282,s1501279) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[123],3,arguments);
}
return R.checkAnnArgs([$type$Number27,$type$String28,$type$String28],[arg_DASH_index1481296,param_DASH_name1491282,s1501279],[L[120],L[121],L[122]],function() {
var if_DASH_151289 = R.equiv(s1501279,("true"));
var if_helper461255 = R.makeFunction(function(if_helper_arg471294) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[118],1,arguments);
}
var ann_DASH_check_DASH_temp451295 = if_helper_arg471294;
return R.checkAnn(L[119],$type$Boolean25,ann_DASH_check_DASH_temp451295,function() {
return ann_DASH_check_DASH_temp451295;
});
});
var anf_if501293 = R.isBoolean(if_DASH_151289);
if(R.isPyretTrue(anf_if501293)) {
if(R.isPyretTrue(if_DASH_151289)) {
var $z12461247 = D;
var $f12521253 = function(_) {
return R.isFunction(left8074)?left8074.app((true)):R.ffi.throwNonFunApp(L[113],left8074,[(true)]);
};
try {
if(--R.GAS > 0) {
$z12461247 = $f12521253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12521253,
"from":L[113]});
}
} catch($e12441245) {
if(R.isCont($e12441245)) {
var $ss12481249 = {"from":L[113],
"go":function(cont_tail_arg621254) {
return $Hcont_tail_arg18991256(cont_tail_arg621254,if_helper461255);
}};
$e12441245.stack[R.EXN_STACKHEIGHT++] = $ss12481249;
}
if(R.isPyretException($e12441245)) {
$e12441245.pyretStack.push(L[113]);
}
throw $e12441245;
}
var $ret12501251 = $Hcont_tail_arg18991256($z12461247,if_helper461255);
++R.GAS;
return $ret12501251;
} else {
var if_DASH_141284 = R.equiv(s1501279,("false"));
var anf_if531288 = R.isBoolean(if_DASH_141284);
if(R.isPyretTrue(anf_if531288)) {
if(R.isPyretTrue(if_DASH_141284)) {
var $z12591260 = D;
var $f12651266 = function(_) {
return R.isFunction(left8074)?left8074.app((false)):R.ffi.throwNonFunApp(L[114],left8074,[(false)]);
};
try {
if(--R.GAS > 0) {
$z12591260 = $f12651266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12651266,
"from":L[114]});
}
} catch($e12571258) {
if(R.isCont($e12571258)) {
var $ss12611262 = {"from":L[114],
"go":function(cont_tail_arg601267) {
return $Hcont_tail_arg19001268(cont_tail_arg601267,if_helper461255);
}};
$e12571258.stack[R.EXN_STACKHEIGHT++] = $ss12611262;
}
if(R.isPyretException($e12571258)) {
$e12571258.pyretStack.push(L[114]);
}
throw $e12571258;
}
var $ret12631264 = $Hcont_tail_arg19001268($z12591260,if_helper461255);
++R.GAS;
return $ret12631264;
} else {
var anf_fun541281 = G(list2776,"make",L[116]);
var $z12711272 = D;
var $f12771278 = function(_) {
return R.isFunction(torepr24)?torepr24.app(s1501279):R.ffi.throwNonFunApp(L[115],torepr24,[s1501279]);
};
try {
if(--R.GAS > 0) {
$z12711272 = $f12771278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12771278,
"from":L[115]});
}
} catch($e12691270) {
if(R.isCont($e12691270)) {
var $ss12731274 = {"from":L[115],
"go":function(anf_array_val551280) {
return $Hanf_array_val19041283(anf_array_val551280,anf_fun541281,format7872,if_helper461255,param_DASH_name1491282,right8177);
}};
$e12691270.stack[R.EXN_STACKHEIGHT++] = $ss12731274;
}
if(R.isPyretException($e12691270)) {
$e12691270.pyretStack.push(L[115]);
}
throw $e12691270;
}
var $ret12751276 = $Hanf_array_val19041283($z12711272,anf_fun541281,format7872,if_helper461255,param_DASH_name1491282,right8177);
++R.GAS;
return $ret12751276;
}
} else {
var cont_tail_arg511287 = R.throwNonBooleanCondition(L[117],("if"),if_DASH_141284);
if(--R.GAS > 0) {
$z12851286 = R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg511287):R.ffi.throwNonFunApp(L[117],if_helper461255,[cont_tail_arg511287]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg511287):R.ffi.throwNonFunApp(L[117],if_helper461255,[cont_tail_arg511287]);
},
"from":L[117]});
}
++R.GAS;
return $z12851286;
}
}
} else {
var cont_tail_arg481292 = R.throwNonBooleanCondition(L[118],("if"),if_DASH_151289);
if(--R.GAS > 0) {
$z12901291 = R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg481292):R.ffi.throwNonFunApp(L[118],if_helper461255,[cont_tail_arg481292]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg481292):R.ffi.throwNonFunApp(L[118],if_helper461255,[cont_tail_arg481292]);
},
"from":L[118]});
}
++R.GAS;
return $z12901291;
}
});
};
},{"length":4});
var anf_singleton_variant_member661081 = R.makeMethod(function(self1511243) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[112],0,arguments);
}
var ann_DASH_check_DASH_temp651242 = ("(true|false)");
return ann_DASH_check_DASH_temp651242;
};
},{"length":1});
var anf_singleton_variant_member771087 = R.makeMethod(function(self171241) {
return function(cases_DASH_funs181220,else_DASH_clause191231) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[90],2,arguments);
}
var if_DASH_211234 = R.hasField(cases_DASH_funs181220,("read-string"));
var if_helper681218 = R.makeFunction(function(if_helper_arg691239) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[90],1,arguments);
}
var ann_DASH_check_DASH_temp671240 = if_helper_arg691239;
return ann_DASH_check_DASH_temp671240;
});
var anf_if721238 = R.isBoolean(if_DASH_211234);
if(R.isPyretTrue(anf_if721238)) {
if(R.isPyretTrue(if_DASH_211234)) {
var call_DASH_read_DASH_string161216 = G(cases_DASH_funs181220,"read-string",L[90]);
var $z12081209 = D;
var $f12141215 = function(_) {
return R.isFunction(call_DASH_read_DASH_string161216)?call_DASH_read_DASH_string161216.app():R.ffi.throwNonFunApp(L[90],call_DASH_read_DASH_string161216,[]);
};
try {
if(--R.GAS > 0) {
$z12081209 = $f12141215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12141215,
"from":L[90]});
}
} catch($e12061207) {
if(R.isCont($e12061207)) {
var $ss12101211 = {"from":L[90],
"go":function(cont_tail_arg751217) {
return $Hcont_tail_arg19051219(cont_tail_arg751217,if_helper681218);
}};
$e12061207.stack[R.EXN_STACKHEIGHT++] = $ss12101211;
}
if(R.isPyretException($e12061207)) {
$e12061207.pyretStack.push(L[90]);
}
throw $e12061207;
}
var $ret12121213 = $Hcont_tail_arg19051219($z12081209,if_helper681218);
++R.GAS;
return $ret12121213;
} else {
var $z12231224 = D;
var $f12291230 = function(_) {
return R.isFunction(else_DASH_clause191231)?else_DASH_clause191231.app():R.ffi.throwNonFunApp(L[90],else_DASH_clause191231,[]);
};
try {
if(--R.GAS > 0) {
$z12231224 = $f12291230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12291230,
"from":L[90]});
}
} catch($e12211222) {
if(R.isCont($e12211222)) {
var $ss12251226 = {"from":L[90],
"go":function(cont_tail_arg731232) {
return $Hcont_tail_arg19061233(cont_tail_arg731232,if_helper681218);
}};
$e12211222.stack[R.EXN_STACKHEIGHT++] = $ss12251226;
}
if(R.isPyretException($e12211222)) {
$e12211222.pyretStack.push(L[90]);
}
throw $e12211222;
}
var $ret12271228 = $Hcont_tail_arg19061233($z12231224,if_helper681218);
++R.GAS;
return $ret12271228;
}
} else {
var cont_tail_arg701237 = R.throwNonBooleanCondition(L[90],("if"),if_DASH_211234);
if(--R.GAS > 0) {
$z12351236 = R.isFunction(if_helper681218)?if_helper681218.app(cont_tail_arg701237):R.ffi.throwNonFunApp(L[90],if_helper681218,[cont_tail_arg701237]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper681218)?if_helper681218.app(cont_tail_arg701237):R.ffi.throwNonFunApp(L[90],if_helper681218,[cont_tail_arg701237]);
},
"from":L[90]});
}
++R.GAS;
return $z12351236;
}
};
},{"length":3});
var anf_singleton_variant_member791088 = R.makeMethod(function(self201205) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[90],0,arguments);
}
var ann_DASH_check_DASH_temp781204 = ("read-string");
return ann_DASH_check_DASH_temp781204;
};
},{"length":1});
var anf_singleton_variant_member811089 = R.makeMethod(function($underscore1521203) {
return function(arg_DASH_index1531201,param_DASH_name1541202,s1551198) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[108],3,arguments);
}
return R.checkAnnArgs([$type$Number27,$type$String28,$type$String28],[arg_DASH_index1531201,param_DASH_name1541202,s1551198],[L[109],L[110],L[111]],function() {
var $z11901191 = D;
var $f11961197 = function(_) {
return R.isFunction(left8074)?left8074.app(s1551198):R.ffi.throwNonFunApp(L[108],left8074,[s1551198]);
};
try {
if(--R.GAS > 0) {
$z11901191 = $f11961197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11961197,
"from":L[108]});
}
} catch($e11881189) {
if(R.isCont($e11881189)) {
var $ss11921193 = {"from":L[108],
"go":function(ann_DASH_check_DASH_temp801199) {
return $Hann_DASH_check_DASH_temp19071200(ann_DASH_check_DASH_temp801199,$type$String28);
}};
$e11881189.stack[R.EXN_STACKHEIGHT++] = $ss11921193;
}
if(R.isPyretException($e11881189)) {
$e11881189.pyretStack.push(L[108]);
}
throw $e11881189;
}
var $ret11941195 = $Hann_DASH_check_DASH_temp19071200($z11901191,$type$String28);
++R.GAS;
return $ret11941195;
});
};
},{"length":4});
var anf_singleton_variant_member831090 = R.makeMethod(function(self1561187) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[107],0,arguments);
}
var ann_DASH_check_DASH_temp821186 = ("<string>");
return ann_DASH_check_DASH_temp821186;
};
},{"length":1});
var anf_variant_member961096 = R.makeMethod(function(self231164) {
return function(cases_DASH_funs241165,else_DASH_clause251176) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[89],2,arguments);
}
var if_DASH_271179 = R.hasField(cases_DASH_funs241165,("read-custom"));
var if_helper851162 = R.makeFunction(function(if_helper_arg861184) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[89],1,arguments);
}
var ann_DASH_check_DASH_temp841185 = if_helper_arg861184;
return ann_DASH_check_DASH_temp841185;
});
var anf_if891183 = R.isBoolean(if_DASH_271179);
if(R.isPyretTrue(anf_if891183)) {
if(R.isPyretTrue(if_DASH_271179)) {
var call_DASH_read_DASH_custom221158 = G(cases_DASH_funs241165,"read-custom",L[89]);
var anf_arg921159 = G(self231164,"name",L[106]);
var anf_arg931160 = G(self231164,"parser",L[105]);
var $z11501151 = D;
var $f11561157 = function(_) {
return R.isFunction(call_DASH_read_DASH_custom221158)?call_DASH_read_DASH_custom221158.app(anf_arg921159,anf_arg931160):R.ffi.throwNonFunApp(L[89],call_DASH_read_DASH_custom221158,[anf_arg921159,anf_arg931160]);
};
try {
if(--R.GAS > 0) {
$z11501151 = $f11561157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11561157,
"from":L[89]});
}
} catch($e11481149) {
if(R.isCont($e11481149)) {
var $ss11521153 = {"from":L[89],
"go":function(cont_tail_arg941161) {
return $Hcont_tail_arg19081163(cont_tail_arg941161,if_helper851162);
}};
$e11481149.stack[R.EXN_STACKHEIGHT++] = $ss11521153;
}
if(R.isPyretException($e11481149)) {
$e11481149.pyretStack.push(L[89]);
}
throw $e11481149;
}
var $ret11541155 = $Hcont_tail_arg19081163($z11501151,if_helper851162);
++R.GAS;
return $ret11541155;
} else {
var $z11681169 = D;
var $f11741175 = function(_) {
return R.isFunction(else_DASH_clause251176)?else_DASH_clause251176.app():R.ffi.throwNonFunApp(L[89],else_DASH_clause251176,[]);
};
try {
if(--R.GAS > 0) {
$z11681169 = $f11741175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11741175,
"from":L[89]});
}
} catch($e11661167) {
if(R.isCont($e11661167)) {
var $ss11701171 = {"from":L[89],
"go":function(cont_tail_arg901177) {
return $Hcont_tail_arg19091178(cont_tail_arg901177,if_helper851162);
}};
$e11661167.stack[R.EXN_STACKHEIGHT++] = $ss11701171;
}
if(R.isPyretException($e11661167)) {
$e11661167.pyretStack.push(L[89]);
}
throw $e11661167;
}
var $ret11721173 = $Hcont_tail_arg19091178($z11681169,if_helper851162);
++R.GAS;
return $ret11721173;
}
} else {
var cont_tail_arg871182 = R.throwNonBooleanCondition(L[89],("if"),if_DASH_271179);
if(--R.GAS > 0) {
$z11801181 = R.isFunction(if_helper851162)?if_helper851162.app(cont_tail_arg871182):R.ffi.throwNonFunApp(L[89],if_helper851162,[cont_tail_arg871182]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper851162)?if_helper851162.app(cont_tail_arg871182):R.ffi.throwNonFunApp(L[89],if_helper851162,[cont_tail_arg871182]);
},
"from":L[89]});
}
++R.GAS;
return $z11801181;
}
};
},{"length":3});
var anf_variant_member1061097 = R.makeMethod(function(self261146) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[89],0,arguments);
}
var anf_arg981144 = G(self261146,"name",L[89]);
var $z11361137 = D;
var $f11421143 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg981144):R.ffi.throwNonFunApp(L[89],torepr24,[anf_arg981144]);
};
try {
if(--R.GAS > 0) {
$z11361137 = $f11421143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11421143,
"from":L[89]});
}
} catch($e11341135) {
if(R.isCont($e11341135)) {
var $ss11381139 = {"from":L[89],
"go":function(anf_arg991145) {
return $Hanf_arg19161147(anf_arg991145,self261146,_plus13,torepr24);
}};
$e11341135.stack[R.EXN_STACKHEIGHT++] = $ss11381139;
}
if(R.isPyretException($e11341135)) {
$e11341135.pyretStack.push(L[89]);
}
throw $e11341135;
}
var $ret11401141 = $Hanf_arg19161147($z11361137,self261146,_plus13,torepr24);
++R.GAS;
return $ret11401141;
};
},{"length":1});
var anf_variant_member1091098 = R.makeMethod(function(self1591133) {
return function(arg_DASH_index1601128,param_DASH_name1611129,s1621130) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[100],3,arguments);
}
return R.checkAnnArgs([$type$Number27,$type$String28,$type$String28],[arg_DASH_index1601128,param_DASH_name1611129,s1621130],[L[102],L[103],L[104]],function() {
var anf_fun1081127 = G(self1591133,"parser",L[101]);
var $z11191120 = D;
var $f11251126 = function(_) {
return R.isFunction(anf_fun1081127)?anf_fun1081127.app(arg_DASH_index1601128,param_DASH_name1611129,s1621130):R.ffi.throwNonFunApp(L[100],anf_fun1081127,[arg_DASH_index1601128,param_DASH_name1611129,s1621130]);
};
try {
if(--R.GAS > 0) {
$z11191120 = $f11251126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11251126,
"from":L[100]});
}
} catch($e11171118) {
if(R.isCont($e11171118)) {
var $ss11211122 = {"from":L[100],
"go":function(ann_DASH_check_DASH_temp1071131) {
return $Hann_DASH_check_DASH_temp19171132(ann_DASH_check_DASH_temp1071131);
}};
$e11171118.stack[R.EXN_STACKHEIGHT++] = $ss11211122;
}
if(R.isPyretException($e11171118)) {
$e11171118.pyretStack.push(L[100]);
}
throw $e11171118;
}
var $ret11231124 = $Hann_DASH_check_DASH_temp19171132($z11191120);
++R.GAS;
return $ret11231124;
});
};
},{"length":4});
var anf_variant_member1141099 = R.makeMethod(function(self1631116) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[99],0,arguments);
}
var anf_fun1111112 = G(list2776,"make",L[97]);
var anf_array_val1121113 = G(self1631116,"name",L[98]);
var $z11041105 = D;
var $f11101111 = function(_) {
return R.isFunction(anf_fun1111112)?anf_fun1111112.app([anf_array_val1121113]):R.ffi.throwNonFunApp(L[97],anf_fun1111112,[[anf_array_val1121113]]);
};
try {
if(--R.GAS > 0) {
$z11041105 = $f11101111();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11101111,
"from":L[97]});
}
} catch($e11021103) {
if(R.isCont($e11021103)) {
var $ss11061107 = {"from":L[97],
"go":function(anf_arg1131114) {
return $Hanf_arg19191115(anf_arg1131114,format7872);
}};
$e11021103.stack[R.EXN_STACKHEIGHT++] = $ss11061107;
}
if(R.isPyretException($e11021103)) {
$e11021103.pyretStack.push(L[97]);
}
throw $e11021103;
}
var $ret11081109 = $Hanf_arg19191115($z11041105,format7872);
++R.GAS;
return $ret11081109;
};
},{"length":1});
var anf_assign11580 = (function() {
var $read_DASH_number_DASH_base10641065 = {"_match":anf_singleton_variant_member121069,
"_torepr":anf_singleton_variant_member141070,
"parse":anf_singleton_variant_member291071,
"parse-string":anf_singleton_variant_member311072};
var $read_DASH_number_DASH_brands10671068 = {"$brand-read-number1066":true};
$read_DASH_number_DASH_brands10671068[ParseParamT26966._brand] = true
var $read_DASH_bool_DASH_base10731074 = {"_match":anf_singleton_variant_member421078,
"_torepr":anf_singleton_variant_member441079,
"parse":anf_singleton_variant_member641080,
"parse-string":anf_singleton_variant_member661081};
var $read_DASH_bool_DASH_brands10761077 = {"$brand-read-bool1075":true};
$read_DASH_bool_DASH_brands10761077[ParseParamT26966._brand] = true
var $read_DASH_string_DASH_base10821083 = {"_match":anf_singleton_variant_member771087,
"_torepr":anf_singleton_variant_member791088,
"parse":anf_singleton_variant_member811089,
"parse-string":anf_singleton_variant_member831090};
var $read_DASH_string_DASH_brands10851086 = {"$brand-read-string1084":true};
$read_DASH_string_DASH_brands10851086[ParseParamT26966._brand] = true
var $read_DASH_custom_DASH_base10911092 = {"_match":anf_variant_member961096,
"_torepr":anf_variant_member1061097,
"parse":anf_variant_member1091098,
"parse-string":anf_variant_member1141099};
var $read_DASH_custom_DASH_brands10941095 = {"$brand-read-custom1093":true};
$read_DASH_custom_DASH_brands10941095[ParseParamT26966._brand] = true
return R.makeObject({"ParseParam":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[93],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ParseParamT26966._brand));
}),
"is-read-number":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[92],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-read-number1066"));
}),
"read-number":R.makeBrandedObject($read_DASH_number_DASH_base10641065,$read_DASH_number_DASH_brands10671068),
"is-read-bool":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[91],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-read-bool1075"));
}),
"read-bool":R.makeBrandedObject($read_DASH_bool_DASH_base10731074,$read_DASH_bool_DASH_brands10761077),
"is-read-string":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[90],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-read-string1084"));
}),
"read-string":R.makeBrandedObject($read_DASH_string_DASH_base10821083,$read_DASH_string_DASH_brands10851086),
"is-read-custom":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[89],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-read-custom1093"));
}),
"read-custom":R.makeFunction(function(name1571100,parser1581101) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[94],2,arguments);
}
return R.checkAnnArgs([$type$String28,$type$Function26],[name1571100,parser1581101],[L[95],L[96]],function() {
var dict = R.create($read_DASH_custom_DASH_base10911092);
dict["name"] = name1571100
dict["parser"] = parser1581101
return R.makeBrandedObject(dict,$read_DASH_custom_DASH_brands10941095);
});
})});
})();
ParseParam78579.$var = anf_assign11580;
var anf_assign11682 = G(ParseParam78579.$var,"ParseParam",L[93]);
ParseParam8681.$var = anf_assign11682;
var anf_assign11784 = G(ParseParam78579.$var,"ParseParam",L[93]);
is_DASH_ParseParam8783.$var = anf_assign11784;
var anf_assign11886 = G(ParseParam78579.$var,"is-read-number",L[92]);
is_DASH_read_DASH_number8885.$var = anf_assign11886;
var anf_assign11988 = G(ParseParam78579.$var,"read-number",L[92]);
read_DASH_number8987.$var = anf_assign11988;
var anf_assign12090 = G(ParseParam78579.$var,"is-read-bool",L[91]);
is_DASH_read_DASH_bool9089.$var = anf_assign12090;
var anf_assign12192 = G(ParseParam78579.$var,"read-bool",L[91]);
read_DASH_bool9191.$var = anf_assign12192;
var anf_assign12294 = G(ParseParam78579.$var,"is-read-string",L[90]);
is_DASH_read_DASH_string9293.$var = anf_assign12294;
var anf_assign12396 = G(ParseParam78579.$var,"read-string",L[90]);
read_DASH_string9395.$var = anf_assign12396;
var anf_assign12498 = G(ParseParam78579.$var,"is-read-custom",L[89]);
is_DASH_read_DASH_custom9497.$var = anf_assign12498;
var anf_assign125100 = G(ParseParam78579.$var,"read-custom",L[89]);
read_DASH_custom9599.$var = anf_assign125100;
var anf_variant_member138947 = R.makeMethod(function(self291042) {
return function(cases_DASH_funs301043,else_DASH_clause311054) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[77],2,arguments);
}
var if_DASH_331057 = R.hasField(cases_DASH_funs301043,("success"));
var if_helper1271040 = R.makeFunction(function(if_helper_arg1281062) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[77],1,arguments);
}
var ann_DASH_check_DASH_temp1261063 = if_helper_arg1281062;
return ann_DASH_check_DASH_temp1261063;
});
var anf_if1311061 = R.isBoolean(if_DASH_331057);
if(R.isPyretTrue(anf_if1311061)) {
if(R.isPyretTrue(if_DASH_331057)) {
var call_DASH_success281036 = G(cases_DASH_funs301043,"success",L[77]);
var anf_arg1341037 = G(self291042,"parsed",L[88]);
var anf_arg1351038 = G(self291042,"unknown",L[87]);
var $z10281029 = D;
var $f10341035 = function(_) {
return R.isFunction(call_DASH_success281036)?call_DASH_success281036.app(anf_arg1341037,anf_arg1351038):R.ffi.throwNonFunApp(L[77],call_DASH_success281036,[anf_arg1341037,anf_arg1351038]);
};
try {
if(--R.GAS > 0) {
$z10281029 = $f10341035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10341035,
"from":L[77]});
}
} catch($e10261027) {
if(R.isCont($e10261027)) {
var $ss10301031 = {"from":L[77],
"go":function(cont_tail_arg1361039) {
return $Hcont_tail_arg19201041(cont_tail_arg1361039,if_helper1271040);
}};
$e10261027.stack[R.EXN_STACKHEIGHT++] = $ss10301031;
}
if(R.isPyretException($e10261027)) {
$e10261027.pyretStack.push(L[77]);
}
throw $e10261027;
}
var $ret10321033 = $Hcont_tail_arg19201041($z10281029,if_helper1271040);
++R.GAS;
return $ret10321033;
} else {
var $z10461047 = D;
var $f10521053 = function(_) {
return R.isFunction(else_DASH_clause311054)?else_DASH_clause311054.app():R.ffi.throwNonFunApp(L[77],else_DASH_clause311054,[]);
};
try {
if(--R.GAS > 0) {
$z10461047 = $f10521053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10521053,
"from":L[77]});
}
} catch($e10441045) {
if(R.isCont($e10441045)) {
var $ss10481049 = {"from":L[77],
"go":function(cont_tail_arg1321055) {
return $Hcont_tail_arg19211056(cont_tail_arg1321055,if_helper1271040);
}};
$e10441045.stack[R.EXN_STACKHEIGHT++] = $ss10481049;
}
if(R.isPyretException($e10441045)) {
$e10441045.pyretStack.push(L[77]);
}
throw $e10441045;
}
var $ret10501051 = $Hcont_tail_arg19211056($z10461047,if_helper1271040);
++R.GAS;
return $ret10501051;
}
} else {
var cont_tail_arg1291060 = R.throwNonBooleanCondition(L[77],("if"),if_DASH_331057);
if(--R.GAS > 0) {
$z10581059 = R.isFunction(if_helper1271040)?if_helper1271040.app(cont_tail_arg1291060):R.ffi.throwNonFunApp(L[77],if_helper1271040,[cont_tail_arg1291060]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1271040)?if_helper1271040.app(cont_tail_arg1291060):R.ffi.throwNonFunApp(L[77],if_helper1271040,[cont_tail_arg1291060]);
},
"from":L[77]});
}
++R.GAS;
return $z10581059;
}
};
},{"length":3});
var anf_variant_member148948 = R.makeMethod(function(self321024) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[77],0,arguments);
}
var anf_arg1401022 = G(self321024,"parsed",L[77]);
var $z10141015 = D;
var $f10201021 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg1401022):R.ffi.throwNonFunApp(L[77],torepr24,[anf_arg1401022]);
};
try {
if(--R.GAS > 0) {
$z10141015 = $f10201021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10201021,
"from":L[77]});
}
} catch($e10121013) {
if(R.isCont($e10121013)) {
var $ss10161017 = {"from":L[77],
"go":function(anf_arg1411023) {
return $Hanf_arg19281025(anf_arg1411023,self321024,_plus13,torepr24);
}};
$e10121013.stack[R.EXN_STACKHEIGHT++] = $ss10161017;
}
if(R.isPyretException($e10121013)) {
$e10121013.pyretStack.push(L[77]);
}
throw $e10121013;
}
var $ret10181019 = $Hanf_arg19281025($z10141015,self321024,_plus13,torepr24);
++R.GAS;
return $ret10181019;
};
},{"length":1});
var anf_variant_member161956 = R.makeMethod(function(self35990) {
return function(cases_DASH_funs36991,else_DASH_clause371002) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[76],2,arguments);
}
var if_DASH_391005 = R.hasField(cases_DASH_funs36991,("arg-error"));
var if_helper150988 = R.makeFunction(function(if_helper_arg1511010) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[76],1,arguments);
}
var ann_DASH_check_DASH_temp1491011 = if_helper_arg1511010;
return ann_DASH_check_DASH_temp1491011;
});
var anf_if1541009 = R.isBoolean(if_DASH_391005);
if(R.isPyretTrue(anf_if1541009)) {
if(R.isPyretTrue(if_DASH_391005)) {
var call_DASH_arg_DASH_error34984 = G(cases_DASH_funs36991,"arg-error",L[76]);
var anf_arg157985 = G(self35990,"message",L[86]);
var anf_arg158986 = G(self35990,"partial-results",L[85]);
var $z976977 = D;
var $f982983 = function(_) {
return R.isFunction(call_DASH_arg_DASH_error34984)?call_DASH_arg_DASH_error34984.app(anf_arg157985,anf_arg158986):R.ffi.throwNonFunApp(L[76],call_DASH_arg_DASH_error34984,[anf_arg157985,anf_arg158986]);
};
try {
if(--R.GAS > 0) {
$z976977 = $f982983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f982983,
"from":L[76]});
}
} catch($e974975) {
if(R.isCont($e974975)) {
var $ss978979 = {"from":L[76],
"go":function(cont_tail_arg159987) {
return $Hcont_tail_arg1929989(cont_tail_arg159987,if_helper150988);
}};
$e974975.stack[R.EXN_STACKHEIGHT++] = $ss978979;
}
if(R.isPyretException($e974975)) {
$e974975.pyretStack.push(L[76]);
}
throw $e974975;
}
var $ret980981 = $Hcont_tail_arg1929989($z976977,if_helper150988);
++R.GAS;
return $ret980981;
} else {
var $z994995 = D;
var $f10001001 = function(_) {
return R.isFunction(else_DASH_clause371002)?else_DASH_clause371002.app():R.ffi.throwNonFunApp(L[76],else_DASH_clause371002,[]);
};
try {
if(--R.GAS > 0) {
$z994995 = $f10001001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10001001,
"from":L[76]});
}
} catch($e992993) {
if(R.isCont($e992993)) {
var $ss996997 = {"from":L[76],
"go":function(cont_tail_arg1551003) {
return $Hcont_tail_arg19301004(cont_tail_arg1551003,if_helper150988);
}};
$e992993.stack[R.EXN_STACKHEIGHT++] = $ss996997;
}
if(R.isPyretException($e992993)) {
$e992993.pyretStack.push(L[76]);
}
throw $e992993;
}
var $ret998999 = $Hcont_tail_arg19301004($z994995,if_helper150988);
++R.GAS;
return $ret998999;
}
} else {
var cont_tail_arg1521008 = R.throwNonBooleanCondition(L[76],("if"),if_DASH_391005);
if(--R.GAS > 0) {
$z10061007 = R.isFunction(if_helper150988)?if_helper150988.app(cont_tail_arg1521008):R.ffi.throwNonFunApp(L[76],if_helper150988,[cont_tail_arg1521008]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper150988)?if_helper150988.app(cont_tail_arg1521008):R.ffi.throwNonFunApp(L[76],if_helper150988,[cont_tail_arg1521008]);
},
"from":L[76]});
}
++R.GAS;
return $z10061007;
}
};
},{"length":3});
var anf_variant_member171957 = R.makeMethod(function(self38972) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[76],0,arguments);
}
var anf_arg163970 = G(self38972,"message",L[76]);
var $z962963 = D;
var $f968969 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg163970):R.ffi.throwNonFunApp(L[76],torepr24,[anf_arg163970]);
};
try {
if(--R.GAS > 0) {
$z962963 = $f968969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f968969,
"from":L[76]});
}
} catch($e960961) {
if(R.isCont($e960961)) {
var $ss964965 = {"from":L[76],
"go":function(anf_arg164971) {
return $Hanf_arg1937973(anf_arg164971,self38972,_plus13,torepr24);
}};
$e960961.stack[R.EXN_STACKHEIGHT++] = $ss964965;
}
if(R.isPyretException($e960961)) {
$e960961.pyretStack.push(L[76]);
}
throw $e960961;
}
var $ret966967 = $Hanf_arg1937973($z962963,self38972,_plus13,torepr24);
++R.GAS;
return $ret966967;
};
},{"length":1});
var anf_assign172102 = (function() {
var $success_DASH_base942943 = {"_match":anf_variant_member138947,
"_torepr":anf_variant_member148948};
var $success_DASH_brands945946 = {"$brand-success944":true};
$success_DASH_brands945946[ParsedArgumentsT37168._brand] = true
var $arg_DASH_error_DASH_base951952 = {"_match":anf_variant_member161956,
"_torepr":anf_variant_member171957};
var $arg_DASH_error_DASH_brands954955 = {"$brand-arg-error953":true};
$arg_DASH_error_DASH_brands954955[ParsedArgumentsT37168._brand] = true
return R.makeObject({"ParsedArguments":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[78],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ParsedArgumentsT37168._brand));
}),
"is-success":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[77],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-success944"));
}),
"success":R.makeFunction(function(parsed164949,unknown165950) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[79],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[80],"D",D640,"StringDict"),List1959],[parsed164949,unknown165950],[L[80],L[81]],function() {
var dict = R.create($success_DASH_base942943);
dict["parsed"] = parsed164949
dict["unknown"] = unknown165950
return R.makeBrandedObject(dict,$success_DASH_brands945946);
});
}),
"is-arg-error":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[76],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-arg-error953"));
}),
"arg-error":R.makeFunction(function(message166958,partial_DASH_results167959) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[82],2,arguments);
}
return R.checkAnnArgs([$type$String28,ParsedArguments7067],[message166958,partial_DASH_results167959],[L[83],L[84]],function() {
var dict = R.create($arg_DASH_error_DASH_base951952);
dict["message"] = message166958
dict["partial-results"] = partial_DASH_results167959
return R.makeBrandedObject(dict,$arg_DASH_error_DASH_brands954955);
});
})});
})();
ParsedArguments896101.$var = anf_assign172102;
var anf_assign173104 = G(ParsedArguments896101.$var,"ParsedArguments",L[78]);
ParsedArguments97103.$var = anf_assign173104;
var anf_assign174106 = G(ParsedArguments896101.$var,"ParsedArguments",L[78]);
is_DASH_ParsedArguments98105.$var = anf_assign174106;
var anf_assign175108 = G(ParsedArguments896101.$var,"is-success",L[77]);
is_DASH_success99107.$var = anf_assign175108;
var anf_assign176110 = G(ParsedArguments896101.$var,"success",L[77]);
success100109.$var = anf_assign176110;
var anf_assign177112 = G(ParsedArguments896101.$var,"is-arg-error",L[76]);
is_DASH_arg_DASH_error101111.$var = anf_assign177112;
var anf_assign178114 = G(ParsedArguments896101.$var,"arg-error",L[76]);
arg_DASH_error102113.$var = anf_assign178114;
var anf_singleton_variant_member189755 = R.makeMethod(function(self41941) {
return function(cases_DASH_funs42920,else_DASH_clause43931) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[70],2,arguments);
}
var if_DASH_45934 = R.hasField(cases_DASH_funs42920,("once"));
var if_helper180918 = R.makeFunction(function(if_helper_arg181939) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[70],1,arguments);
}
var ann_DASH_check_DASH_temp179940 = if_helper_arg181939;
return ann_DASH_check_DASH_temp179940;
});
var anf_if184938 = R.isBoolean(if_DASH_45934);
if(R.isPyretTrue(anf_if184938)) {
if(R.isPyretTrue(if_DASH_45934)) {
var call_DASH_once40916 = G(cases_DASH_funs42920,"once",L[70]);
var $z908909 = D;
var $f914915 = function(_) {
return R.isFunction(call_DASH_once40916)?call_DASH_once40916.app():R.ffi.throwNonFunApp(L[70],call_DASH_once40916,[]);
};
try {
if(--R.GAS > 0) {
$z908909 = $f914915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f914915,
"from":L[70]});
}
} catch($e906907) {
if(R.isCont($e906907)) {
var $ss910911 = {"from":L[70],
"go":function(cont_tail_arg187917) {
return $Hcont_tail_arg1938919(cont_tail_arg187917,if_helper180918);
}};
$e906907.stack[R.EXN_STACKHEIGHT++] = $ss910911;
}
if(R.isPyretException($e906907)) {
$e906907.pyretStack.push(L[70]);
}
throw $e906907;
}
var $ret912913 = $Hcont_tail_arg1938919($z908909,if_helper180918);
++R.GAS;
return $ret912913;
} else {
var $z923924 = D;
var $f929930 = function(_) {
return R.isFunction(else_DASH_clause43931)?else_DASH_clause43931.app():R.ffi.throwNonFunApp(L[70],else_DASH_clause43931,[]);
};
try {
if(--R.GAS > 0) {
$z923924 = $f929930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f929930,
"from":L[70]});
}
} catch($e921922) {
if(R.isCont($e921922)) {
var $ss925926 = {"from":L[70],
"go":function(cont_tail_arg185932) {
return $Hcont_tail_arg1939933(cont_tail_arg185932,if_helper180918);
}};
$e921922.stack[R.EXN_STACKHEIGHT++] = $ss925926;
}
if(R.isPyretException($e921922)) {
$e921922.pyretStack.push(L[70]);
}
throw $e921922;
}
var $ret927928 = $Hcont_tail_arg1939933($z923924,if_helper180918);
++R.GAS;
return $ret927928;
}
} else {
var cont_tail_arg182937 = R.throwNonBooleanCondition(L[70],("if"),if_DASH_45934);
if(--R.GAS > 0) {
$z935936 = R.isFunction(if_helper180918)?if_helper180918.app(cont_tail_arg182937):R.ffi.throwNonFunApp(L[70],if_helper180918,[cont_tail_arg182937]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper180918)?if_helper180918.app(cont_tail_arg182937):R.ffi.throwNonFunApp(L[70],if_helper180918,[cont_tail_arg182937]);
},
"from":L[70]});
}
++R.GAS;
return $z935936;
}
};
},{"length":3});
var anf_singleton_variant_member191756 = R.makeMethod(function(self44905) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[70],0,arguments);
}
var ann_DASH_check_DASH_temp190904 = ("once");
return ann_DASH_check_DASH_temp190904;
};
},{"length":1});
var anf_singleton_variant_member193757 = R.makeMethod(function($underscore168903) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[75],0,arguments);
}
var ann_DASH_check_DASH_temp192902 = ("may be used at most once");
return ann_DASH_check_DASH_temp192902;
};
},{"length":1});
var anf_singleton_variant_member204763 = R.makeMethod(function(self47901) {
return function(cases_DASH_funs48880,else_DASH_clause49891) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[69],2,arguments);
}
var if_DASH_51894 = R.hasField(cases_DASH_funs48880,("many"));
var if_helper195878 = R.makeFunction(function(if_helper_arg196899) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[69],1,arguments);
}
var ann_DASH_check_DASH_temp194900 = if_helper_arg196899;
return ann_DASH_check_DASH_temp194900;
});
var anf_if199898 = R.isBoolean(if_DASH_51894);
if(R.isPyretTrue(anf_if199898)) {
if(R.isPyretTrue(if_DASH_51894)) {
var call_DASH_many46876 = G(cases_DASH_funs48880,"many",L[69]);
var $z868869 = D;
var $f874875 = function(_) {
return R.isFunction(call_DASH_many46876)?call_DASH_many46876.app():R.ffi.throwNonFunApp(L[69],call_DASH_many46876,[]);
};
try {
if(--R.GAS > 0) {
$z868869 = $f874875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f874875,
"from":L[69]});
}
} catch($e866867) {
if(R.isCont($e866867)) {
var $ss870871 = {"from":L[69],
"go":function(cont_tail_arg202877) {
return $Hcont_tail_arg1940879(cont_tail_arg202877,if_helper195878);
}};
$e866867.stack[R.EXN_STACKHEIGHT++] = $ss870871;
}
if(R.isPyretException($e866867)) {
$e866867.pyretStack.push(L[69]);
}
throw $e866867;
}
var $ret872873 = $Hcont_tail_arg1940879($z868869,if_helper195878);
++R.GAS;
return $ret872873;
} else {
var $z883884 = D;
var $f889890 = function(_) {
return R.isFunction(else_DASH_clause49891)?else_DASH_clause49891.app():R.ffi.throwNonFunApp(L[69],else_DASH_clause49891,[]);
};
try {
if(--R.GAS > 0) {
$z883884 = $f889890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f889890,
"from":L[69]});
}
} catch($e881882) {
if(R.isCont($e881882)) {
var $ss885886 = {"from":L[69],
"go":function(cont_tail_arg200892) {
return $Hcont_tail_arg1941893(cont_tail_arg200892,if_helper195878);
}};
$e881882.stack[R.EXN_STACKHEIGHT++] = $ss885886;
}
if(R.isPyretException($e881882)) {
$e881882.pyretStack.push(L[69]);
}
throw $e881882;
}
var $ret887888 = $Hcont_tail_arg1941893($z883884,if_helper195878);
++R.GAS;
return $ret887888;
}
} else {
var cont_tail_arg197897 = R.throwNonBooleanCondition(L[69],("if"),if_DASH_51894);
if(--R.GAS > 0) {
$z895896 = R.isFunction(if_helper195878)?if_helper195878.app(cont_tail_arg197897):R.ffi.throwNonFunApp(L[69],if_helper195878,[cont_tail_arg197897]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper195878)?if_helper195878.app(cont_tail_arg197897):R.ffi.throwNonFunApp(L[69],if_helper195878,[cont_tail_arg197897]);
},
"from":L[69]});
}
++R.GAS;
return $z895896;
}
};
},{"length":3});
var anf_singleton_variant_member206764 = R.makeMethod(function(self50865) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[69],0,arguments);
}
var ann_DASH_check_DASH_temp205864 = ("many");
return ann_DASH_check_DASH_temp205864;
};
},{"length":1});
var anf_singleton_variant_member208765 = R.makeMethod(function($underscore169863) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[74],0,arguments);
}
var ann_DASH_check_DASH_temp207862 = ("may be repeated");
return ann_DASH_check_DASH_temp207862;
};
},{"length":1});
var anf_singleton_variant_member219771 = R.makeMethod(function(self53861) {
return function(cases_DASH_funs54840,else_DASH_clause55851) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[68],2,arguments);
}
var if_DASH_57854 = R.hasField(cases_DASH_funs54840,("required-once"));
var if_helper210838 = R.makeFunction(function(if_helper_arg211859) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[68],1,arguments);
}
var ann_DASH_check_DASH_temp209860 = if_helper_arg211859;
return ann_DASH_check_DASH_temp209860;
});
var anf_if214858 = R.isBoolean(if_DASH_57854);
if(R.isPyretTrue(anf_if214858)) {
if(R.isPyretTrue(if_DASH_57854)) {
var call_DASH_required_DASH_once52836 = G(cases_DASH_funs54840,"required-once",L[68]);
var $z828829 = D;
var $f834835 = function(_) {
return R.isFunction(call_DASH_required_DASH_once52836)?call_DASH_required_DASH_once52836.app():R.ffi.throwNonFunApp(L[68],call_DASH_required_DASH_once52836,[]);
};
try {
if(--R.GAS > 0) {
$z828829 = $f834835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f834835,
"from":L[68]});
}
} catch($e826827) {
if(R.isCont($e826827)) {
var $ss830831 = {"from":L[68],
"go":function(cont_tail_arg217837) {
return $Hcont_tail_arg1942839(cont_tail_arg217837,if_helper210838);
}};
$e826827.stack[R.EXN_STACKHEIGHT++] = $ss830831;
}
if(R.isPyretException($e826827)) {
$e826827.pyretStack.push(L[68]);
}
throw $e826827;
}
var $ret832833 = $Hcont_tail_arg1942839($z828829,if_helper210838);
++R.GAS;
return $ret832833;
} else {
var $z843844 = D;
var $f849850 = function(_) {
return R.isFunction(else_DASH_clause55851)?else_DASH_clause55851.app():R.ffi.throwNonFunApp(L[68],else_DASH_clause55851,[]);
};
try {
if(--R.GAS > 0) {
$z843844 = $f849850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f849850,
"from":L[68]});
}
} catch($e841842) {
if(R.isCont($e841842)) {
var $ss845846 = {"from":L[68],
"go":function(cont_tail_arg215852) {
return $Hcont_tail_arg1943853(cont_tail_arg215852,if_helper210838);
}};
$e841842.stack[R.EXN_STACKHEIGHT++] = $ss845846;
}
if(R.isPyretException($e841842)) {
$e841842.pyretStack.push(L[68]);
}
throw $e841842;
}
var $ret847848 = $Hcont_tail_arg1943853($z843844,if_helper210838);
++R.GAS;
return $ret847848;
}
} else {
var cont_tail_arg212857 = R.throwNonBooleanCondition(L[68],("if"),if_DASH_57854);
if(--R.GAS > 0) {
$z855856 = R.isFunction(if_helper210838)?if_helper210838.app(cont_tail_arg212857):R.ffi.throwNonFunApp(L[68],if_helper210838,[cont_tail_arg212857]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper210838)?if_helper210838.app(cont_tail_arg212857):R.ffi.throwNonFunApp(L[68],if_helper210838,[cont_tail_arg212857]);
},
"from":L[68]});
}
++R.GAS;
return $z855856;
}
};
},{"length":3});
var anf_singleton_variant_member221772 = R.makeMethod(function(self56825) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[68],0,arguments);
}
var ann_DASH_check_DASH_temp220824 = ("required-once");
return ann_DASH_check_DASH_temp220824;
};
},{"length":1});
var anf_singleton_variant_member223773 = R.makeMethod(function($underscore170823) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[73],0,arguments);
}
var ann_DASH_check_DASH_temp222822 = ("must be used exactly once");
return ann_DASH_check_DASH_temp222822;
};
},{"length":1});
var anf_singleton_variant_member234779 = R.makeMethod(function(self59821) {
return function(cases_DASH_funs60800,else_DASH_clause61811) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[67],2,arguments);
}
var if_DASH_63814 = R.hasField(cases_DASH_funs60800,("required-many"));
var if_helper225798 = R.makeFunction(function(if_helper_arg226819) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[67],1,arguments);
}
var ann_DASH_check_DASH_temp224820 = if_helper_arg226819;
return ann_DASH_check_DASH_temp224820;
});
var anf_if229818 = R.isBoolean(if_DASH_63814);
if(R.isPyretTrue(anf_if229818)) {
if(R.isPyretTrue(if_DASH_63814)) {
var call_DASH_required_DASH_many58796 = G(cases_DASH_funs60800,"required-many",L[67]);
var $z788789 = D;
var $f794795 = function(_) {
return R.isFunction(call_DASH_required_DASH_many58796)?call_DASH_required_DASH_many58796.app():R.ffi.throwNonFunApp(L[67],call_DASH_required_DASH_many58796,[]);
};
try {
if(--R.GAS > 0) {
$z788789 = $f794795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f794795,
"from":L[67]});
}
} catch($e786787) {
if(R.isCont($e786787)) {
var $ss790791 = {"from":L[67],
"go":function(cont_tail_arg232797) {
return $Hcont_tail_arg1944799(cont_tail_arg232797,if_helper225798);
}};
$e786787.stack[R.EXN_STACKHEIGHT++] = $ss790791;
}
if(R.isPyretException($e786787)) {
$e786787.pyretStack.push(L[67]);
}
throw $e786787;
}
var $ret792793 = $Hcont_tail_arg1944799($z788789,if_helper225798);
++R.GAS;
return $ret792793;
} else {
var $z803804 = D;
var $f809810 = function(_) {
return R.isFunction(else_DASH_clause61811)?else_DASH_clause61811.app():R.ffi.throwNonFunApp(L[67],else_DASH_clause61811,[]);
};
try {
if(--R.GAS > 0) {
$z803804 = $f809810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f809810,
"from":L[67]});
}
} catch($e801802) {
if(R.isCont($e801802)) {
var $ss805806 = {"from":L[67],
"go":function(cont_tail_arg230812) {
return $Hcont_tail_arg1945813(cont_tail_arg230812,if_helper225798);
}};
$e801802.stack[R.EXN_STACKHEIGHT++] = $ss805806;
}
if(R.isPyretException($e801802)) {
$e801802.pyretStack.push(L[67]);
}
throw $e801802;
}
var $ret807808 = $Hcont_tail_arg1945813($z803804,if_helper225798);
++R.GAS;
return $ret807808;
}
} else {
var cont_tail_arg227817 = R.throwNonBooleanCondition(L[67],("if"),if_DASH_63814);
if(--R.GAS > 0) {
$z815816 = R.isFunction(if_helper225798)?if_helper225798.app(cont_tail_arg227817):R.ffi.throwNonFunApp(L[67],if_helper225798,[cont_tail_arg227817]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper225798)?if_helper225798.app(cont_tail_arg227817):R.ffi.throwNonFunApp(L[67],if_helper225798,[cont_tail_arg227817]);
},
"from":L[67]});
}
++R.GAS;
return $z815816;
}
};
},{"length":3});
var anf_singleton_variant_member236780 = R.makeMethod(function(self62785) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[67],0,arguments);
}
var ann_DASH_check_DASH_temp235784 = ("required-many");
return ann_DASH_check_DASH_temp235784;
};
},{"length":1});
var anf_singleton_variant_member238781 = R.makeMethod(function($underscore171783) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[72],0,arguments);
}
var ann_DASH_check_DASH_temp237782 = ("must be used at least once");
return ann_DASH_check_DASH_temp237782;
};
},{"length":1});
var anf_assign239116 = (function() {
var $once_DASH_base750751 = {"_match":anf_singleton_variant_member189755,
"_torepr":anf_singleton_variant_member191756,
"tostring":anf_singleton_variant_member193757};
var $once_DASH_brands753754 = {"$brand-once752":true};
$once_DASH_brands753754[ParamRepeatT47363._brand] = true
var $many_DASH_base758759 = {"_match":anf_singleton_variant_member204763,
"_torepr":anf_singleton_variant_member206764,
"tostring":anf_singleton_variant_member208765};
var $many_DASH_brands761762 = {"$brand-many760":true};
$many_DASH_brands761762[ParamRepeatT47363._brand] = true
var $required_DASH_once_DASH_base766767 = {"_match":anf_singleton_variant_member219771,
"_torepr":anf_singleton_variant_member221772,
"tostring":anf_singleton_variant_member223773};
var $required_DASH_once_DASH_brands769770 = {"$brand-required-once768":true};
$required_DASH_once_DASH_brands769770[ParamRepeatT47363._brand] = true
var $required_DASH_many_DASH_base774775 = {"_match":anf_singleton_variant_member234779,
"_torepr":anf_singleton_variant_member236780,
"tostring":anf_singleton_variant_member238781};
var $required_DASH_many_DASH_brands777778 = {"$brand-required-many776":true};
$required_DASH_many_DASH_brands777778[ParamRepeatT47363._brand] = true
return R.makeObject({"ParamRepeat":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[71],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ParamRepeatT47363._brand));
}),
"is-once":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[70],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-once752"));
}),
"once":R.makeBrandedObject($once_DASH_base750751,$once_DASH_brands753754),
"is-many":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[69],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-many760"));
}),
"many":R.makeBrandedObject($many_DASH_base758759,$many_DASH_brands761762),
"is-required-once":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[68],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-required-once768"));
}),
"required-once":R.makeBrandedObject($required_DASH_once_DASH_base766767,$required_DASH_once_DASH_brands769770),
"is-required-many":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[67],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-required-many776"));
}),
"required-many":R.makeBrandedObject($required_DASH_many_DASH_base774775,$required_DASH_many_DASH_brands777778)});
})();
ParamRepeat9103115.$var = anf_assign239116;
var anf_assign240118 = G(ParamRepeat9103115.$var,"ParamRepeat",L[71]);
ParamRepeat104117.$var = anf_assign240118;
var anf_assign241120 = G(ParamRepeat9103115.$var,"ParamRepeat",L[71]);
is_DASH_ParamRepeat105119.$var = anf_assign241120;
var anf_assign242122 = G(ParamRepeat9103115.$var,"is-once",L[70]);
is_DASH_once106121.$var = anf_assign242122;
var anf_assign243124 = G(ParamRepeat9103115.$var,"once",L[70]);
once107123.$var = anf_assign243124;
var anf_assign244126 = G(ParamRepeat9103115.$var,"is-many",L[69]);
is_DASH_many108125.$var = anf_assign244126;
var anf_assign245128 = G(ParamRepeat9103115.$var,"many",L[69]);
many109127.$var = anf_assign245128;
var anf_assign246130 = G(ParamRepeat9103115.$var,"is-required-once",L[68]);
is_DASH_required_DASH_once110129.$var = anf_assign246130;
var anf_assign247132 = G(ParamRepeat9103115.$var,"required-once",L[68]);
required_DASH_once111131.$var = anf_assign247132;
var anf_assign248134 = G(ParamRepeat9103115.$var,"is-required-many",L[67]);
is_DASH_required_DASH_many112133.$var = anf_assign248134;
var anf_assign249136 = G(ParamRepeat9103115.$var,"required-many",L[67]);
required_DASH_many113135.$var = anf_assign249136;
var anf_variant_member262434 = R.makeMethod(function(self65728) {
return function(cases_DASH_funs66729,else_DASH_clause67740) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[26],2,arguments);
}
var if_DASH_69743 = R.hasField(cases_DASH_funs66729,("flag"));
var if_helper251726 = R.makeFunction(function(if_helper_arg252748) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[26],1,arguments);
}
var ann_DASH_check_DASH_temp250749 = if_helper_arg252748;
return ann_DASH_check_DASH_temp250749;
});
var anf_if255747 = R.isBoolean(if_DASH_69743);
if(R.isPyretTrue(anf_if255747)) {
if(R.isPyretTrue(if_DASH_69743)) {
var call_DASH_flag64722 = G(cases_DASH_funs66729,"flag",L[26]);
var anf_arg258723 = G(self65728,"repeated",L[66]);
var anf_arg259724 = G(self65728,"desc",L[65]);
var $z714715 = D;
var $f720721 = function(_) {
return R.isFunction(call_DASH_flag64722)?call_DASH_flag64722.app(anf_arg258723,anf_arg259724):R.ffi.throwNonFunApp(L[26],call_DASH_flag64722,[anf_arg258723,anf_arg259724]);
};
try {
if(--R.GAS > 0) {
$z714715 = $f720721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f720721,
"from":L[26]});
}
} catch($e712713) {
if(R.isCont($e712713)) {
var $ss716717 = {"from":L[26],
"go":function(cont_tail_arg260725) {
return $Hcont_tail_arg1946727(cont_tail_arg260725,if_helper251726);
}};
$e712713.stack[R.EXN_STACKHEIGHT++] = $ss716717;
}
if(R.isPyretException($e712713)) {
$e712713.pyretStack.push(L[26]);
}
throw $e712713;
}
var $ret718719 = $Hcont_tail_arg1946727($z714715,if_helper251726);
++R.GAS;
return $ret718719;
} else {
var $z732733 = D;
var $f738739 = function(_) {
return R.isFunction(else_DASH_clause67740)?else_DASH_clause67740.app():R.ffi.throwNonFunApp(L[26],else_DASH_clause67740,[]);
};
try {
if(--R.GAS > 0) {
$z732733 = $f738739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f738739,
"from":L[26]});
}
} catch($e730731) {
if(R.isCont($e730731)) {
var $ss734735 = {"from":L[26],
"go":function(cont_tail_arg256741) {
return $Hcont_tail_arg1947742(cont_tail_arg256741,if_helper251726);
}};
$e730731.stack[R.EXN_STACKHEIGHT++] = $ss734735;
}
if(R.isPyretException($e730731)) {
$e730731.pyretStack.push(L[26]);
}
throw $e730731;
}
var $ret736737 = $Hcont_tail_arg1947742($z732733,if_helper251726);
++R.GAS;
return $ret736737;
}
} else {
var cont_tail_arg253746 = R.throwNonBooleanCondition(L[26],("if"),if_DASH_69743);
if(--R.GAS > 0) {
$z744745 = R.isFunction(if_helper251726)?if_helper251726.app(cont_tail_arg253746):R.ffi.throwNonFunApp(L[26],if_helper251726,[cont_tail_arg253746]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper251726)?if_helper251726.app(cont_tail_arg253746):R.ffi.throwNonFunApp(L[26],if_helper251726,[cont_tail_arg253746]);
},
"from":L[26]});
}
++R.GAS;
return $z744745;
}
};
},{"length":3});
var anf_variant_member272435 = R.makeMethod(function(self68710) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[26],0,arguments);
}
var anf_arg264708 = G(self68710,"repeated",L[26]);
var $z700701 = D;
var $f706707 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg264708):R.ffi.throwNonFunApp(L[26],torepr24,[anf_arg264708]);
};
try {
if(--R.GAS > 0) {
$z700701 = $f706707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f706707,
"from":L[26]});
}
} catch($e698699) {
if(R.isCont($e698699)) {
var $ss702703 = {"from":L[26],
"go":function(anf_arg265709) {
return $Hanf_arg1954711(anf_arg265709,self68710,_plus13,torepr24);
}};
$e698699.stack[R.EXN_STACKHEIGHT++] = $ss702703;
}
if(R.isPyretException($e698699)) {
$e698699.pyretStack.push(L[26]);
}
throw $e698699;
}
var $ret704705 = $Hanf_arg1954711($z700701,self68710,_plus13,torepr24);
++R.GAS;
return $ret704705;
};
},{"length":1});
var anf_variant_member286443 = R.makeMethod(function(self71676) {
return function(cases_DASH_funs72677,else_DASH_clause73688) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[25],2,arguments);
}
var if_DASH_75691 = R.hasField(cases_DASH_funs72677,("equals-val"));
var if_helper274674 = R.makeFunction(function(if_helper_arg275696) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[25],1,arguments);
}
var ann_DASH_check_DASH_temp273697 = if_helper_arg275696;
return ann_DASH_check_DASH_temp273697;
});
var anf_if278695 = R.isBoolean(if_DASH_75691);
if(R.isPyretTrue(anf_if278695)) {
if(R.isPyretTrue(if_DASH_75691)) {
var call_DASH_equals_DASH_val70669 = G(cases_DASH_funs72677,"equals-val",L[25]);
var anf_arg281670 = G(self71676,"parser",L[64]);
var anf_arg282671 = G(self71676,"repeated",L[63]);
var anf_arg283672 = G(self71676,"desc",L[62]);
var $z661662 = D;
var $f667668 = function(_) {
return R.isFunction(call_DASH_equals_DASH_val70669)?call_DASH_equals_DASH_val70669.app(anf_arg281670,anf_arg282671,anf_arg283672):R.ffi.throwNonFunApp(L[25],call_DASH_equals_DASH_val70669,[anf_arg281670,anf_arg282671,anf_arg283672]);
};
try {
if(--R.GAS > 0) {
$z661662 = $f667668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f667668,
"from":L[25]});
}
} catch($e659660) {
if(R.isCont($e659660)) {
var $ss663664 = {"from":L[25],
"go":function(cont_tail_arg284673) {
return $Hcont_tail_arg1955675(cont_tail_arg284673,if_helper274674);
}};
$e659660.stack[R.EXN_STACKHEIGHT++] = $ss663664;
}
if(R.isPyretException($e659660)) {
$e659660.pyretStack.push(L[25]);
}
throw $e659660;
}
var $ret665666 = $Hcont_tail_arg1955675($z661662,if_helper274674);
++R.GAS;
return $ret665666;
} else {
var $z680681 = D;
var $f686687 = function(_) {
return R.isFunction(else_DASH_clause73688)?else_DASH_clause73688.app():R.ffi.throwNonFunApp(L[25],else_DASH_clause73688,[]);
};
try {
if(--R.GAS > 0) {
$z680681 = $f686687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f686687,
"from":L[25]});
}
} catch($e678679) {
if(R.isCont($e678679)) {
var $ss682683 = {"from":L[25],
"go":function(cont_tail_arg279689) {
return $Hcont_tail_arg1956690(cont_tail_arg279689,if_helper274674);
}};
$e678679.stack[R.EXN_STACKHEIGHT++] = $ss682683;
}
if(R.isPyretException($e678679)) {
$e678679.pyretStack.push(L[25]);
}
throw $e678679;
}
var $ret684685 = $Hcont_tail_arg1956690($z680681,if_helper274674);
++R.GAS;
return $ret684685;
}
} else {
var cont_tail_arg276694 = R.throwNonBooleanCondition(L[25],("if"),if_DASH_75691);
if(--R.GAS > 0) {
$z692693 = R.isFunction(if_helper274674)?if_helper274674.app(cont_tail_arg276694):R.ffi.throwNonFunApp(L[25],if_helper274674,[cont_tail_arg276694]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper274674)?if_helper274674.app(cont_tail_arg276694):R.ffi.throwNonFunApp(L[25],if_helper274674,[cont_tail_arg276694]);
},
"from":L[25]});
}
++R.GAS;
return $z692693;
}
};
},{"length":3});
var anf_variant_member300444 = R.makeMethod(function(self74657) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[25],0,arguments);
}
var anf_arg288655 = G(self74657,"parser",L[25]);
var $z647648 = D;
var $f653654 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg288655):R.ffi.throwNonFunApp(L[25],torepr24,[anf_arg288655]);
};
try {
if(--R.GAS > 0) {
$z647648 = $f653654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f653654,
"from":L[25]});
}
} catch($e645646) {
if(R.isCont($e645646)) {
var $ss649650 = {"from":L[25],
"go":function(anf_arg289656) {
return $Hanf_arg1966658(anf_arg289656,self74657,_plus13,torepr24);
}};
$e645646.stack[R.EXN_STACKHEIGHT++] = $ss649650;
}
if(R.isPyretException($e645646)) {
$e645646.pyretStack.push(L[25]);
}
throw $e645646;
}
var $ret651652 = $Hanf_arg1966658($z647648,self74657,_plus13,torepr24);
++R.GAS;
return $ret651652;
};
},{"length":1});
var anf_variant_member316453 = R.makeMethod(function(self77623) {
return function(cases_DASH_funs78624,else_DASH_clause79635) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[24],2,arguments);
}
var if_DASH_81638 = R.hasField(cases_DASH_funs78624,("equals-val-default"));
var if_helper302621 = R.makeFunction(function(if_helper_arg303643) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[24],1,arguments);
}
var ann_DASH_check_DASH_temp301644 = if_helper_arg303643;
return ann_DASH_check_DASH_temp301644;
});
var anf_if306642 = R.isBoolean(if_DASH_81638);
if(R.isPyretTrue(anf_if306642)) {
if(R.isPyretTrue(if_DASH_81638)) {
var call_DASH_equals_DASH_val_DASH_default76614 = G(cases_DASH_funs78624,"equals-val-default",L[24]);
var anf_arg309615 = G(self77623,"parser",L[61]);
var anf_arg310616 = G(self77623,"default",L[60]);
var anf_arg311617 = G(self77623,"short-name",L[59]);
var anf_arg312618 = G(self77623,"repeated",L[58]);
var anf_arg313619 = G(self77623,"desc",L[57]);
var $z606607 = D;
var $f612613 = function(_) {
return R.isFunction(call_DASH_equals_DASH_val_DASH_default76614)?call_DASH_equals_DASH_val_DASH_default76614.app(anf_arg309615,anf_arg310616,anf_arg311617,anf_arg312618,anf_arg313619):R.ffi.throwNonFunApp(L[24],call_DASH_equals_DASH_val_DASH_default76614,[anf_arg309615,anf_arg310616,anf_arg311617,anf_arg312618,anf_arg313619]);
};
try {
if(--R.GAS > 0) {
$z606607 = $f612613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f612613,
"from":L[24]});
}
} catch($e604605) {
if(R.isCont($e604605)) {
var $ss608609 = {"from":L[24],
"go":function(cont_tail_arg314620) {
return $Hcont_tail_arg1967622(cont_tail_arg314620,if_helper302621);
}};
$e604605.stack[R.EXN_STACKHEIGHT++] = $ss608609;
}
if(R.isPyretException($e604605)) {
$e604605.pyretStack.push(L[24]);
}
throw $e604605;
}
var $ret610611 = $Hcont_tail_arg1967622($z606607,if_helper302621);
++R.GAS;
return $ret610611;
} else {
var $z627628 = D;
var $f633634 = function(_) {
return R.isFunction(else_DASH_clause79635)?else_DASH_clause79635.app():R.ffi.throwNonFunApp(L[24],else_DASH_clause79635,[]);
};
try {
if(--R.GAS > 0) {
$z627628 = $f633634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f633634,
"from":L[24]});
}
} catch($e625626) {
if(R.isCont($e625626)) {
var $ss629630 = {"from":L[24],
"go":function(cont_tail_arg307636) {
return $Hcont_tail_arg1968637(cont_tail_arg307636,if_helper302621);
}};
$e625626.stack[R.EXN_STACKHEIGHT++] = $ss629630;
}
if(R.isPyretException($e625626)) {
$e625626.pyretStack.push(L[24]);
}
throw $e625626;
}
var $ret631632 = $Hcont_tail_arg1968637($z627628,if_helper302621);
++R.GAS;
return $ret631632;
}
} else {
var cont_tail_arg304641 = R.throwNonBooleanCondition(L[24],("if"),if_DASH_81638);
if(--R.GAS > 0) {
$z639640 = R.isFunction(if_helper302621)?if_helper302621.app(cont_tail_arg304641):R.ffi.throwNonFunApp(L[24],if_helper302621,[cont_tail_arg304641]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper302621)?if_helper302621.app(cont_tail_arg304641):R.ffi.throwNonFunApp(L[24],if_helper302621,[cont_tail_arg304641]);
},
"from":L[24]});
}
++R.GAS;
return $z639640;
}
};
},{"length":3});
var anf_variant_member338454 = R.makeMethod(function(self80602) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[24],0,arguments);
}
var anf_arg318600 = G(self80602,"parser",L[24]);
var $z592593 = D;
var $f598599 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg318600):R.ffi.throwNonFunApp(L[24],torepr24,[anf_arg318600]);
};
try {
if(--R.GAS > 0) {
$z592593 = $f598599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f598599,
"from":L[24]});
}
} catch($e590591) {
if(R.isCont($e590591)) {
var $ss594595 = {"from":L[24],
"go":function(anf_arg319601) {
return $Hanf_arg1984603(anf_arg319601,self80602,_plus13,torepr24);
}};
$e590591.stack[R.EXN_STACKHEIGHT++] = $ss594595;
}
if(R.isPyretException($e590591)) {
$e590591.pyretStack.push(L[24]);
}
throw $e590591;
}
var $ret596597 = $Hanf_arg1984603($z592593,self80602,_plus13,torepr24);
++R.GAS;
return $ret596597;
};
},{"length":1});
var anf_variant_member352465 = R.makeMethod(function(self83568) {
return function(cases_DASH_funs84569,else_DASH_clause85580) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[23],2,arguments);
}
var if_DASH_87583 = R.hasField(cases_DASH_funs84569,("next-val"));
var if_helper340566 = R.makeFunction(function(if_helper_arg341588) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
var ann_DASH_check_DASH_temp339589 = if_helper_arg341588;
return ann_DASH_check_DASH_temp339589;
});
var anf_if344587 = R.isBoolean(if_DASH_87583);
if(R.isPyretTrue(anf_if344587)) {
if(R.isPyretTrue(if_DASH_87583)) {
var call_DASH_next_DASH_val82561 = G(cases_DASH_funs84569,"next-val",L[23]);
var anf_arg347562 = G(self83568,"parser",L[56]);
var anf_arg348563 = G(self83568,"repeated",L[55]);
var anf_arg349564 = G(self83568,"desc",L[54]);
var $z553554 = D;
var $f559560 = function(_) {
return R.isFunction(call_DASH_next_DASH_val82561)?call_DASH_next_DASH_val82561.app(anf_arg347562,anf_arg348563,anf_arg349564):R.ffi.throwNonFunApp(L[23],call_DASH_next_DASH_val82561,[anf_arg347562,anf_arg348563,anf_arg349564]);
};
try {
if(--R.GAS > 0) {
$z553554 = $f559560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f559560,
"from":L[23]});
}
} catch($e551552) {
if(R.isCont($e551552)) {
var $ss555556 = {"from":L[23],
"go":function(cont_tail_arg350565) {
return $Hcont_tail_arg1985567(cont_tail_arg350565,if_helper340566);
}};
$e551552.stack[R.EXN_STACKHEIGHT++] = $ss555556;
}
if(R.isPyretException($e551552)) {
$e551552.pyretStack.push(L[23]);
}
throw $e551552;
}
var $ret557558 = $Hcont_tail_arg1985567($z553554,if_helper340566);
++R.GAS;
return $ret557558;
} else {
var $z572573 = D;
var $f578579 = function(_) {
return R.isFunction(else_DASH_clause85580)?else_DASH_clause85580.app():R.ffi.throwNonFunApp(L[23],else_DASH_clause85580,[]);
};
try {
if(--R.GAS > 0) {
$z572573 = $f578579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f578579,
"from":L[23]});
}
} catch($e570571) {
if(R.isCont($e570571)) {
var $ss574575 = {"from":L[23],
"go":function(cont_tail_arg345581) {
return $Hcont_tail_arg1986582(cont_tail_arg345581,if_helper340566);
}};
$e570571.stack[R.EXN_STACKHEIGHT++] = $ss574575;
}
if(R.isPyretException($e570571)) {
$e570571.pyretStack.push(L[23]);
}
throw $e570571;
}
var $ret576577 = $Hcont_tail_arg1986582($z572573,if_helper340566);
++R.GAS;
return $ret576577;
}
} else {
var cont_tail_arg342586 = R.throwNonBooleanCondition(L[23],("if"),if_DASH_87583);
if(--R.GAS > 0) {
$z584585 = R.isFunction(if_helper340566)?if_helper340566.app(cont_tail_arg342586):R.ffi.throwNonFunApp(L[23],if_helper340566,[cont_tail_arg342586]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper340566)?if_helper340566.app(cont_tail_arg342586):R.ffi.throwNonFunApp(L[23],if_helper340566,[cont_tail_arg342586]);
},
"from":L[23]});
}
++R.GAS;
return $z584585;
}
};
},{"length":3});
var anf_variant_member366466 = R.makeMethod(function(self86549) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[23],0,arguments);
}
var anf_arg354547 = G(self86549,"parser",L[23]);
var $z539540 = D;
var $f545546 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg354547):R.ffi.throwNonFunApp(L[23],torepr24,[anf_arg354547]);
};
try {
if(--R.GAS > 0) {
$z539540 = $f545546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f545546,
"from":L[23]});
}
} catch($e537538) {
if(R.isCont($e537538)) {
var $ss541542 = {"from":L[23],
"go":function(anf_arg355548) {
return $Hanf_arg1996550(anf_arg355548,self86549,_plus13,torepr24);
}};
$e537538.stack[R.EXN_STACKHEIGHT++] = $ss541542;
}
if(R.isPyretException($e537538)) {
$e537538.pyretStack.push(L[23]);
}
throw $e537538;
}
var $ret543544 = $Hanf_arg1996550($z539540,self86549,_plus13,torepr24);
++R.GAS;
return $ret543544;
};
},{"length":1});
var anf_variant_member382475 = R.makeMethod(function(self89515) {
return function(cases_DASH_funs90516,else_DASH_clause91527) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[22],2,arguments);
}
var if_DASH_93530 = R.hasField(cases_DASH_funs90516,("next-val-default"));
var if_helper368513 = R.makeFunction(function(if_helper_arg369535) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
var ann_DASH_check_DASH_temp367536 = if_helper_arg369535;
return ann_DASH_check_DASH_temp367536;
});
var anf_if372534 = R.isBoolean(if_DASH_93530);
if(R.isPyretTrue(anf_if372534)) {
if(R.isPyretTrue(if_DASH_93530)) {
var call_DASH_next_DASH_val_DASH_default88506 = G(cases_DASH_funs90516,"next-val-default",L[22]);
var anf_arg375507 = G(self89515,"parser",L[53]);
var anf_arg376508 = G(self89515,"default",L[52]);
var anf_arg377509 = G(self89515,"short-name",L[51]);
var anf_arg378510 = G(self89515,"repeated",L[50]);
var anf_arg379511 = G(self89515,"desc",L[49]);
var $z498499 = D;
var $f504505 = function(_) {
return R.isFunction(call_DASH_next_DASH_val_DASH_default88506)?call_DASH_next_DASH_val_DASH_default88506.app(anf_arg375507,anf_arg376508,anf_arg377509,anf_arg378510,anf_arg379511):R.ffi.throwNonFunApp(L[22],call_DASH_next_DASH_val_DASH_default88506,[anf_arg375507,anf_arg376508,anf_arg377509,anf_arg378510,anf_arg379511]);
};
try {
if(--R.GAS > 0) {
$z498499 = $f504505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f504505,
"from":L[22]});
}
} catch($e496497) {
if(R.isCont($e496497)) {
var $ss500501 = {"from":L[22],
"go":function(cont_tail_arg380512) {
return $Hcont_tail_arg1997514(cont_tail_arg380512,if_helper368513);
}};
$e496497.stack[R.EXN_STACKHEIGHT++] = $ss500501;
}
if(R.isPyretException($e496497)) {
$e496497.pyretStack.push(L[22]);
}
throw $e496497;
}
var $ret502503 = $Hcont_tail_arg1997514($z498499,if_helper368513);
++R.GAS;
return $ret502503;
} else {
var $z519520 = D;
var $f525526 = function(_) {
return R.isFunction(else_DASH_clause91527)?else_DASH_clause91527.app():R.ffi.throwNonFunApp(L[22],else_DASH_clause91527,[]);
};
try {
if(--R.GAS > 0) {
$z519520 = $f525526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f525526,
"from":L[22]});
}
} catch($e517518) {
if(R.isCont($e517518)) {
var $ss521522 = {"from":L[22],
"go":function(cont_tail_arg373528) {
return $Hcont_tail_arg1998529(cont_tail_arg373528,if_helper368513);
}};
$e517518.stack[R.EXN_STACKHEIGHT++] = $ss521522;
}
if(R.isPyretException($e517518)) {
$e517518.pyretStack.push(L[22]);
}
throw $e517518;
}
var $ret523524 = $Hcont_tail_arg1998529($z519520,if_helper368513);
++R.GAS;
return $ret523524;
}
} else {
var cont_tail_arg370533 = R.throwNonBooleanCondition(L[22],("if"),if_DASH_93530);
if(--R.GAS > 0) {
$z531532 = R.isFunction(if_helper368513)?if_helper368513.app(cont_tail_arg370533):R.ffi.throwNonFunApp(L[22],if_helper368513,[cont_tail_arg370533]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper368513)?if_helper368513.app(cont_tail_arg370533):R.ffi.throwNonFunApp(L[22],if_helper368513,[cont_tail_arg370533]);
},
"from":L[22]});
}
++R.GAS;
return $z531532;
}
};
},{"length":3});
var anf_variant_member404476 = R.makeMethod(function(self92494) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[22],0,arguments);
}
var anf_arg384492 = G(self92494,"parser",L[22]);
var $z484485 = D;
var $f490491 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg384492):R.ffi.throwNonFunApp(L[22],torepr24,[anf_arg384492]);
};
try {
if(--R.GAS > 0) {
$z484485 = $f490491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f490491,
"from":L[22]});
}
} catch($e482483) {
if(R.isCont($e482483)) {
var $ss486487 = {"from":L[22],
"go":function(anf_arg385493) {
return $Hanf_arg2014495(anf_arg385493,self92494,_plus13,torepr24);
}};
$e482483.stack[R.EXN_STACKHEIGHT++] = $ss486487;
}
if(R.isPyretException($e482483)) {
$e482483.pyretStack.push(L[22]);
}
throw $e482483;
}
var $ret488489 = $Hanf_arg2014495($z484485,self92494,_plus13,torepr24);
++R.GAS;
return $ret488489;
};
},{"length":1});
var anf_assign405138 = (function() {
var $flag_DASH_base429430 = {"_match":anf_variant_member262434,
"_torepr":anf_variant_member272435};
var $flag_DASH_brands432433 = {"$brand-flag431":true};
$flag_DASH_brands432433[ParamT57564._brand] = true
var $equals_DASH_val_DASH_base438439 = {"_match":anf_variant_member286443,
"_torepr":anf_variant_member300444};
var $equals_DASH_val_DASH_brands441442 = {"$brand-equals-val440":true};
$equals_DASH_val_DASH_brands441442[ParamT57564._brand] = true
var $equals_DASH_val_DASH_default_DASH_base448449 = {"_match":anf_variant_member316453,
"_torepr":anf_variant_member338454};
var $equals_DASH_val_DASH_default_DASH_brands451452 = {"$brand-equals-val-default450":true};
$equals_DASH_val_DASH_default_DASH_brands451452[ParamT57564._brand] = true
var $next_DASH_val_DASH_base460461 = {"_match":anf_variant_member352465,
"_torepr":anf_variant_member366466};
var $next_DASH_val_DASH_brands463464 = {"$brand-next-val462":true};
$next_DASH_val_DASH_brands463464[ParamT57564._brand] = true
var $next_DASH_val_DASH_default_DASH_base470471 = {"_match":anf_variant_member382475,
"_torepr":anf_variant_member404476};
var $next_DASH_val_DASH_default_DASH_brands473474 = {"$brand-next-val-default472":true};
$next_DASH_val_DASH_default_DASH_brands473474[ParamT57564._brand] = true
return R.makeObject({"Param":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[27],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ParamT57564._brand));
}),
"is-flag":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[26],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-flag431"));
}),
"flag":R.makeFunction(function(repeated172436,desc173437) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[28],2,arguments);
}
return R.checkAnnArgs([ParamRepeat7262,$type$String28],[repeated172436,desc173437],[L[29],L[30]],function() {
var dict = R.create($flag_DASH_base429430);
dict["repeated"] = repeated172436
dict["desc"] = desc173437
return R.makeBrandedObject(dict,$flag_DASH_brands432433);
});
}),
"is-equals-val":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[25],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-equals-val440"));
}),
"equals-val":R.makeFunction(function(parser174445,repeated175446,desc176447) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[31],3,arguments);
}
return R.checkAnnArgs([ParseParam6865,ParamRepeat7262,$type$String28],[parser174445,repeated175446,desc176447],[L[32],L[33],L[34]],function() {
var dict = R.create($equals_DASH_val_DASH_base438439);
dict["parser"] = parser174445
dict["repeated"] = repeated175446
dict["desc"] = desc176447
return R.makeBrandedObject(dict,$equals_DASH_val_DASH_brands441442);
});
}),
"is-equals-val-default":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[24],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-equals-val-default450"));
}),
"equals-val-default":R.makeFunction(function(parser177455,default178456,short_DASH_name179457,repeated180458,desc181459) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[35],5,arguments);
}
return R.checkAnnArgs([ParseParam6865,Option2060,ParamRepeat7262,$type$String28],[parser177455,short_DASH_name179457,repeated180458,desc181459],[L[36],L[37],L[38],L[39]],function() {
var dict = R.create($equals_DASH_val_DASH_default_DASH_base448449);
dict["parser"] = parser177455
dict["default"] = default178456
dict["short-name"] = short_DASH_name179457
dict["repeated"] = repeated180458
dict["desc"] = desc181459
return R.makeBrandedObject(dict,$equals_DASH_val_DASH_default_DASH_brands451452);
});
}),
"is-next-val":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-next-val462"));
}),
"next-val":R.makeFunction(function(parser182467,repeated183468,desc184469) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[40],3,arguments);
}
return R.checkAnnArgs([ParseParam6865,ParamRepeat7262,$type$String28],[parser182467,repeated183468,desc184469],[L[41],L[42],L[43]],function() {
var dict = R.create($next_DASH_val_DASH_base460461);
dict["parser"] = parser182467
dict["repeated"] = repeated183468
dict["desc"] = desc184469
return R.makeBrandedObject(dict,$next_DASH_val_DASH_brands463464);
});
}),
"is-next-val-default":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-next-val-default472"));
}),
"next-val-default":R.makeFunction(function(parser185477,default186478,short_DASH_name187479,repeated188480,desc189481) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[44],5,arguments);
}
return R.checkAnnArgs([ParseParam6865,Option2060,ParamRepeat7262,$type$String28],[parser185477,short_DASH_name187479,repeated188480,desc189481],[L[45],L[46],L[47],L[48]],function() {
var dict = R.create($next_DASH_val_DASH_default_DASH_base470471);
dict["parser"] = parser185477
dict["default"] = default186478
dict["short-name"] = short_DASH_name187479
dict["repeated"] = repeated188480
dict["desc"] = desc189481
return R.makeBrandedObject(dict,$next_DASH_val_DASH_default_DASH_brands473474);
});
})});
})();
Param10114137.$var = anf_assign405138;
var anf_assign406140 = G(Param10114137.$var,"Param",L[27]);
Param115139.$var = anf_assign406140;
var anf_assign407142 = G(Param10114137.$var,"Param",L[27]);
is_DASH_Param116141.$var = anf_assign407142;
var anf_assign408144 = G(Param10114137.$var,"is-flag",L[26]);
is_DASH_flag117143.$var = anf_assign408144;
var anf_assign409146 = G(Param10114137.$var,"flag",L[26]);
flag118145.$var = anf_assign409146;
var anf_assign410148 = G(Param10114137.$var,"is-equals-val",L[25]);
is_DASH_equals_DASH_val119147.$var = anf_assign410148;
var anf_assign411150 = G(Param10114137.$var,"equals-val",L[25]);
equals_DASH_val120149.$var = anf_assign411150;
var anf_assign412152 = G(Param10114137.$var,"is-equals-val-default",L[24]);
is_DASH_equals_DASH_val_DASH_default121151.$var = anf_assign412152;
var anf_assign413154 = G(Param10114137.$var,"equals-val-default",L[24]);
equals_DASH_val_DASH_default122153.$var = anf_assign413154;
var anf_assign414156 = G(Param10114137.$var,"is-next-val",L[23]);
is_DASH_next_DASH_val123155.$var = anf_assign414156;
var anf_assign415158 = G(Param10114137.$var,"next-val",L[23]);
next_DASH_val124157.$var = anf_assign415158;
var anf_assign416160 = G(Param10114137.$var,"is-next-val-default",L[22]);
is_DASH_next_DASH_val_DASH_default125159.$var = anf_assign416160;
var anf_assign417162 = G(Param10114137.$var,"next-val-default",L[22]);
next_DASH_val_DASH_default126161.$var = anf_assign417162;
var anf_assign441164 = R.makeFunction(function(l190416) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[20],1,arguments);
}
var $z419420 = D;
var $f425426 = function(_) {
return R.isFunction(is_DASH_flag117143.$var)?is_DASH_flag117143.$var.app(l190416):R.ffi.throwNonFunApp(L[21],is_DASH_flag117143.$var,[l190416]);
};
try {
if(--R.GAS > 0) {
$z419420 = $f425426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f425426,
"from":L[21]});
}
} catch($e417418) {
if(R.isCont($e417418)) {
var $ss421422 = {"from":L[21],
"go":function(or_DASH_oper_DASH_94427) {
return $Hor_DASH_oper_DASH_2024428(or_DASH_oper_DASH_94427,is_DASH_equals_DASH_val_DASH_default121151,is_DASH_equals_DASH_val119147,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416);
}};
$e417418.stack[R.EXN_STACKHEIGHT++] = $ss421422;
}
if(R.isPyretException($e417418)) {
$e417418.pyretStack.push(L[21]);
}
throw $e417418;
}
var $ret423424 = $Hor_DASH_oper_DASH_2024428($z419420,is_DASH_equals_DASH_val_DASH_default121151,is_DASH_equals_DASH_val119147,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416);
++R.GAS;
return $ret423424;
});
is_DASH_Param_127163.$var = anf_assign441164;
var anf_assign511166 = R.makeFunction(function(options_DASH_raw191402) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[17],1,arguments);
}
var anf_fun443413 = G(D531,"to-dict",L[19]);
var $z405406 = D;
var $f411412 = function(_) {
return R.isFunction(anf_fun443413)?anf_fun443413.app(options_DASH_raw191402):R.ffi.throwNonFunApp(L[18],anf_fun443413,[options_DASH_raw191402]);
};
try {
if(--R.GAS > 0) {
$z405406 = $f411412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f411412,
"from":L[18]});
}
} catch($e403404) {
if(R.isCont($e403404)) {
var $ss407408 = {"from":L[18],
"go":function(options192414) {
return $Hoptions2055415(options192414,List1959,file_DASH_name83203,format7872,link3175,list2776,lists1134,$type$String28);
}};
$e403404.stack[R.EXN_STACKHEIGHT++] = $ss407408;
}
if(R.isPyretException($e403404)) {
$e403404.pyretStack.push(L[18]);
}
throw $e403404;
}
var $ret409410 = $Hoptions2055415($z405406,List1959,file_DASH_name83203,format7872,link3175,list2776,lists1134,$type$String28);
++R.GAS;
return $ret409410;
});
usage_DASH_info128165.$var = anf_assign511166;
var anf_assign1112168 = R.makeFunction(function(options215387,args216388) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[13],2,arguments);
}
return R.checkAnnArgs([List1959],[args216388],[L[16]],function() {
var anf_fun513399 = G(D531,"to-dict",L[15]);
var $z391392 = D;
var $f397398 = function(_) {
return R.isFunction(anf_fun513399)?anf_fun513399.app(options215387):R.ffi.throwNonFunApp(L[14],anf_fun513399,[options215387]);
};
try {
if(--R.GAS > 0) {
$z391392 = $f397398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f397398,
"from":L[14]});
}
} catch($e389390) {
if(R.isCont($e389390)) {
var $ss393394 = {"from":L[14],
"go":function(opts_DASH_dict217400) {
return $Hopts_DASH_dict2271401(opts_DASH_dict217400,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e389390.stack[R.EXN_STACKHEIGHT++] = $ss393394;
}
if(R.isPyretException($e389390)) {
$e389390.pyretStack.push(L[14]);
}
throw $e389390;
}
var $ret395396 = $Hopts_DASH_dict2271401($z391392,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret395396;
});
});
parse_DASH_args129167.$var = anf_assign1112168;
var anf_assign1114170 = R.makeFunction(function(options328374) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[12],1,arguments);
}
var $z377378 = D;
var $f383384 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(options328374,other_DASH_args84204):R.ffi.throwNonFunApp(L[12],parse_DASH_args129167.$var,[options328374,other_DASH_args84204]);
};
try {
if(--R.GAS > 0) {
$z377378 = $f383384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f383384,
"from":L[12]});
}
} catch($e375376) {
if(R.isCont($e375376)) {
var $ss379380 = {"from":L[12],
"go":function(ann_DASH_check_DASH_temp1113385) {
return $Hann_DASH_check_DASH_temp2272386(ann_DASH_check_DASH_temp1113385);
}};
$e375376.stack[R.EXN_STACKHEIGHT++] = $ss379380;
}
if(R.isPyretException($e375376)) {
$e375376.pyretStack.push(L[12]);
}
throw $e375376;
}
var $ret381382 = $Hann_DASH_check_DASH_temp2272386($z377378);
++R.GAS;
return $ret381382;
});
parse_DASH_cmdline130169.$var = anf_assign1114170;
var anf_assign1133172 = R.makeFunction(function(l329343) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[5],1,arguments);
}
var anf_arg1125356 = R.makeFunction(function(d330358,i331359) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[8],2,arguments);
}
var anf_fun1117371 = G(d330358,"set",L[11]);
var anf_fun1118372 = G(l329343,"get",L[10]);
var $z362363 = D;
var $f368369 = function(_) {
return R.isFunction(_times14)?_times14.app((2),i331359):R.ffi.throwNonFunApp(L[9],_times14,[(2),i331359]);
};
try {
if(--R.GAS > 0) {
$z362363 = $f368369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f368369,
"from":L[9]});
}
} catch($e360361) {
if(R.isCont($e360361)) {
var $ss364365 = {"from":L[9],
"go":function(anf_arg1119370) {
return $Hanf_arg2278373(anf_arg1119370,anf_fun1117371,anf_fun1118372,i331359,l329343,_plus13,_times14);
}};
$e360361.stack[R.EXN_STACKHEIGHT++] = $ss364365;
}
if(R.isPyretException($e360361)) {
$e360361.pyretStack.push(L[9]);
}
throw $e360361;
}
var $ret366367 = $Hanf_arg2278373($z362363,anf_fun1117371,anf_fun1118372,i331359,l329343,_plus13,_times14);
++R.GAS;
return $ret366367;
});
var anf_fun1126354 = G(D531,"immutable-string-dict",L[7]);
var $z346347 = D;
var $f352353 = function(_) {
return R.isFunction(anf_fun1126354)?anf_fun1126354.app():R.ffi.throwNonFunApp(L[6],anf_fun1126354,[]);
};
try {
if(--R.GAS > 0) {
$z346347 = $f352353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f352353,
"from":L[6]});
}
} catch($e344345) {
if(R.isCont($e344345)) {
var $ss348349 = {"from":L[6],
"go":function(anf_arg1127355) {
return $Hanf_arg2283357(anf_arg1127355,anf_arg1125356,fold5571,l329343,lists1134,_divide12);
}};
$e344345.stack[R.EXN_STACKHEIGHT++] = $ss348349;
}
if(R.isPyretException($e344345)) {
$e344345.pyretStack.push(L[6]);
}
throw $e344345;
}
var $ret350351 = $Hanf_arg2283357($z346347,anf_arg1125356,fold5571,l329343,lists1134,_divide12);
++R.GAS;
return $ret350351;
});
dict131171.$var = anf_assign1133172;
var anf_singleton_variant_member1144212 = R.makeMethod(function(self158342) {
return function(cases_DASH_funs159321,else_DASH_clause160332) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3],2,arguments);
}
var if_DASH_162335 = R.hasField(cases_DASH_funs159321,("red"));
var if_helper1135319 = R.makeFunction(function(if_helper_arg1136340) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
var ann_DASH_check_DASH_temp1134341 = if_helper_arg1136340;
return ann_DASH_check_DASH_temp1134341;
});
var anf_if1139339 = R.isBoolean(if_DASH_162335);
if(R.isPyretTrue(anf_if1139339)) {
if(R.isPyretTrue(if_DASH_162335)) {
var call_DASH_red157317 = G(cases_DASH_funs159321,"red",L[3]);
var $z309310 = D;
var $f315316 = function(_) {
return R.isFunction(call_DASH_red157317)?call_DASH_red157317.app():R.ffi.throwNonFunApp(L[3],call_DASH_red157317,[]);
};
try {
if(--R.GAS > 0) {
$z309310 = $f315316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f315316,
"from":L[3]});
}
} catch($e307308) {
if(R.isCont($e307308)) {
var $ss311312 = {"from":L[3],
"go":function(cont_tail_arg1142318) {
return $Hcont_tail_arg2284320(cont_tail_arg1142318,if_helper1135319);
}};
$e307308.stack[R.EXN_STACKHEIGHT++] = $ss311312;
}
if(R.isPyretException($e307308)) {
$e307308.pyretStack.push(L[3]);
}
throw $e307308;
}
var $ret313314 = $Hcont_tail_arg2284320($z309310,if_helper1135319);
++R.GAS;
return $ret313314;
} else {
var $z324325 = D;
var $f330331 = function(_) {
return R.isFunction(else_DASH_clause160332)?else_DASH_clause160332.app():R.ffi.throwNonFunApp(L[3],else_DASH_clause160332,[]);
};
try {
if(--R.GAS > 0) {
$z324325 = $f330331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f330331,
"from":L[3]});
}
} catch($e322323) {
if(R.isCont($e322323)) {
var $ss326327 = {"from":L[3],
"go":function(cont_tail_arg1140333) {
return $Hcont_tail_arg2285334(cont_tail_arg1140333,if_helper1135319);
}};
$e322323.stack[R.EXN_STACKHEIGHT++] = $ss326327;
}
if(R.isPyretException($e322323)) {
$e322323.pyretStack.push(L[3]);
}
throw $e322323;
}
var $ret328329 = $Hcont_tail_arg2285334($z324325,if_helper1135319);
++R.GAS;
return $ret328329;
}
} else {
var cont_tail_arg1137338 = R.throwNonBooleanCondition(L[3],("if"),if_DASH_162335);
if(--R.GAS > 0) {
$z336337 = R.isFunction(if_helper1135319)?if_helper1135319.app(cont_tail_arg1137338):R.ffi.throwNonFunApp(L[3],if_helper1135319,[cont_tail_arg1137338]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1135319)?if_helper1135319.app(cont_tail_arg1137338):R.ffi.throwNonFunApp(L[3],if_helper1135319,[cont_tail_arg1137338]);
},
"from":L[3]});
}
++R.GAS;
return $z336337;
}
};
},{"length":3});
var anf_singleton_variant_member1146213 = R.makeMethod(function(self161306) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3],0,arguments);
}
var ann_DASH_check_DASH_temp1145305 = ("red");
return ann_DASH_check_DASH_temp1145305;
};
},{"length":1});
var anf_singleton_variant_member1157219 = R.makeMethod(function(self164304) {
return function(cases_DASH_funs165283,else_DASH_clause166294) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2],2,arguments);
}
var if_DASH_168297 = R.hasField(cases_DASH_funs165283,("green"));
var if_helper1148281 = R.makeFunction(function(if_helper_arg1149302) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
var ann_DASH_check_DASH_temp1147303 = if_helper_arg1149302;
return ann_DASH_check_DASH_temp1147303;
});
var anf_if1152301 = R.isBoolean(if_DASH_168297);
if(R.isPyretTrue(anf_if1152301)) {
if(R.isPyretTrue(if_DASH_168297)) {
var call_DASH_green163279 = G(cases_DASH_funs165283,"green",L[2]);
var $z271272 = D;
var $f277278 = function(_) {
return R.isFunction(call_DASH_green163279)?call_DASH_green163279.app():R.ffi.throwNonFunApp(L[2],call_DASH_green163279,[]);
};
try {
if(--R.GAS > 0) {
$z271272 = $f277278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f277278,
"from":L[2]});
}
} catch($e269270) {
if(R.isCont($e269270)) {
var $ss273274 = {"from":L[2],
"go":function(cont_tail_arg1155280) {
return $Hcont_tail_arg2286282(cont_tail_arg1155280,if_helper1148281);
}};
$e269270.stack[R.EXN_STACKHEIGHT++] = $ss273274;
}
if(R.isPyretException($e269270)) {
$e269270.pyretStack.push(L[2]);
}
throw $e269270;
}
var $ret275276 = $Hcont_tail_arg2286282($z271272,if_helper1148281);
++R.GAS;
return $ret275276;
} else {
var $z286287 = D;
var $f292293 = function(_) {
return R.isFunction(else_DASH_clause166294)?else_DASH_clause166294.app():R.ffi.throwNonFunApp(L[2],else_DASH_clause166294,[]);
};
try {
if(--R.GAS > 0) {
$z286287 = $f292293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f292293,
"from":L[2]});
}
} catch($e284285) {
if(R.isCont($e284285)) {
var $ss288289 = {"from":L[2],
"go":function(cont_tail_arg1153295) {
return $Hcont_tail_arg2287296(cont_tail_arg1153295,if_helper1148281);
}};
$e284285.stack[R.EXN_STACKHEIGHT++] = $ss288289;
}
if(R.isPyretException($e284285)) {
$e284285.pyretStack.push(L[2]);
}
throw $e284285;
}
var $ret290291 = $Hcont_tail_arg2287296($z286287,if_helper1148281);
++R.GAS;
return $ret290291;
}
} else {
var cont_tail_arg1150300 = R.throwNonBooleanCondition(L[2],("if"),if_DASH_168297);
if(--R.GAS > 0) {
$z298299 = R.isFunction(if_helper1148281)?if_helper1148281.app(cont_tail_arg1150300):R.ffi.throwNonFunApp(L[2],if_helper1148281,[cont_tail_arg1150300]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1148281)?if_helper1148281.app(cont_tail_arg1150300):R.ffi.throwNonFunApp(L[2],if_helper1148281,[cont_tail_arg1150300]);
},
"from":L[2]});
}
++R.GAS;
return $z298299;
}
};
},{"length":3});
var anf_singleton_variant_member1159220 = R.makeMethod(function(self167268) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2],0,arguments);
}
var ann_DASH_check_DASH_temp1158267 = ("green");
return ann_DASH_check_DASH_temp1158267;
};
},{"length":1});
var anf_singleton_variant_member1170226 = R.makeMethod(function(self170266) {
return function(cases_DASH_funs171244,else_DASH_clause172255) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
var if_DASH_174258 = R.hasField(cases_DASH_funs171244,("blue"));
var if_helper1161242 = R.makeFunction(function(if_helper_arg1162264) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
var ann_DASH_check_DASH_temp1160265 = if_helper_arg1162264;
return ann_DASH_check_DASH_temp1160265;
});
var anf_if1165263 = R.isBoolean(if_DASH_174258);
if(R.isPyretTrue(anf_if1165263)) {
if(R.isPyretTrue(if_DASH_174258)) {
var call_DASH_blue169240 = G(cases_DASH_funs171244,"blue",L[1]);
var $z232233 = D;
var $f238239 = function(_) {
return R.isFunction(call_DASH_blue169240)?call_DASH_blue169240.app():R.ffi.throwNonFunApp(L[1],call_DASH_blue169240,[]);
};
try {
if(--R.GAS > 0) {
$z232233 = $f238239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f238239,
"from":L[1]});
}
} catch($e230231) {
if(R.isCont($e230231)) {
var $ss234235 = {"from":L[1],
"go":function(cont_tail_arg1168241) {
return $Hcont_tail_arg2288243(cont_tail_arg1168241,if_helper1161242);
}};
$e230231.stack[R.EXN_STACKHEIGHT++] = $ss234235;
}
if(R.isPyretException($e230231)) {
$e230231.pyretStack.push(L[1]);
}
throw $e230231;
}
var $ret236237 = $Hcont_tail_arg2288243($z232233,if_helper1161242);
++R.GAS;
return $ret236237;
} else {
var $z247248 = D;
var $f253254 = function(_) {
return R.isFunction(else_DASH_clause172255)?else_DASH_clause172255.app():R.ffi.throwNonFunApp(L[1],else_DASH_clause172255,[]);
};
try {
if(--R.GAS > 0) {
$z247248 = $f253254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f253254,
"from":L[1]});
}
} catch($e245246) {
if(R.isCont($e245246)) {
var $ss249250 = {"from":L[1],
"go":function(cont_tail_arg1166256) {
return $Hcont_tail_arg2289257(cont_tail_arg1166256,if_helper1161242);
}};
$e245246.stack[R.EXN_STACKHEIGHT++] = $ss249250;
}
if(R.isPyretException($e245246)) {
$e245246.pyretStack.push(L[1]);
}
throw $e245246;
}
var $ret251252 = $Hcont_tail_arg2289257($z247248,if_helper1161242);
++R.GAS;
return $ret251252;
}
} else {
var cont_tail_arg1163261 = R.throwNonBooleanCondition(L[1],("if"),if_DASH_174258);
if(--R.GAS > 0) {
$z259260 = R.isFunction(if_helper1161242)?if_helper1161242.app(cont_tail_arg1163261):R.ffi.throwNonFunApp(L[1],if_helper1161242,[cont_tail_arg1163261]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1161242)?if_helper1161242.app(cont_tail_arg1163261):R.ffi.throwNonFunApp(L[1],if_helper1161242,[cont_tail_arg1163261]);
},
"from":L[1]});
}
++R.GAS;
return $z259260;
}
};
},{"length":3});
var anf_singleton_variant_member1172227 = R.makeMethod(function(self173229) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1],0,arguments);
}
var ann_DASH_check_DASH_temp1171228 = ("blue");
return ann_DASH_check_DASH_temp1171228;
};
},{"length":1});
var anf_assign1173174 = (function() {
var $red_DASH_base207208 = {"_match":anf_singleton_variant_member1144212,
"_torepr":anf_singleton_variant_member1146213};
var $red_DASH_brands210211 = {"$brand-red209":true};
$red_DASH_brands210211[RGBT67770._brand] = true
var $green_DASH_base214215 = {"_match":anf_singleton_variant_member1157219,
"_torepr":anf_singleton_variant_member1159220};
var $green_DASH_brands217218 = {"$brand-green216":true};
$green_DASH_brands217218[RGBT67770._brand] = true
var $blue_DASH_base221222 = {"_match":anf_singleton_variant_member1170226,
"_torepr":anf_singleton_variant_member1172227};
var $blue_DASH_brands224225 = {"$brand-blue223":true};
$blue_DASH_brands224225[RGBT67770._brand] = true
return R.makeObject({"RGB":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,RGBT67770._brand));
}),
"is-red":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-red209"));
}),
"red":R.makeBrandedObject($red_DASH_base207208,$red_DASH_brands210211),
"is-green":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-green216"));
}),
"green":R.makeBrandedObject($green_DASH_base214215,$green_DASH_brands217218),
"is-blue":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-blue223"));
}),
"blue":R.makeBrandedObject($blue_DASH_base221222,$blue_DASH_brands224225)});
})();
RGB11132173.$var = anf_assign1173174;
var anf_assign1174176 = G(RGB11132173.$var,"RGB",L[4]);
RGB133175.$var = anf_assign1174176;
var anf_assign1175178 = G(RGB11132173.$var,"RGB",L[4]);
is_DASH_RGB134177.$var = anf_assign1175178;
var anf_assign1176180 = G(RGB11132173.$var,"is-red",L[3]);
is_DASH_red135179.$var = anf_assign1176180;
var anf_assign1177182 = G(RGB11132173.$var,"red",L[3]);
red136181.$var = anf_assign1177182;
var anf_assign1178184 = G(RGB11132173.$var,"is-green",L[2]);
is_DASH_green137183.$var = anf_assign1178184;
var anf_assign1179186 = G(RGB11132173.$var,"green",L[2]);
green138185.$var = anf_assign1179186;
var anf_assign1180188 = G(RGB11132173.$var,"is-blue",L[1]);
is_DASH_blue139187.$var = anf_assign1180188;
var anf_assign1181190 = G(RGB11132173.$var,"blue",L[1]);
blue140189.$var = anf_assign1181190;
nothing18;
var result_DASH_after_DASH_checks1332205 = nothing18;
var anf_fun1182201 = G(builtins15,"current-checker",L[0]);
var $z193194 = D;
var $f199200 = function(_) {
return R.isFunction(anf_fun1182201)?anf_fun1182201.app():R.ffi.throwNonFunApp(L[0],anf_fun1182201,[]);
};
try {
if(--R.GAS > 0) {
$z193194 = $f199200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f199200,
"from":L[0]});
}
} catch($e191192) {
if(R.isCont($e191192)) {
var $ss195196 = {"from":L[0],
"go":function(anf_bracket1183202) {
return $Hanf_bracket2766206(anf_bracket1183202,D531,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,format7872,green138185,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,some6478,success100109,usage_DASH_info128165,builtins15,torepr24);
}};
$e191192.stack[R.EXN_STACKHEIGHT++] = $ss195196;
}
if(R.isPyretException($e191192)) {
$e191192.pyretStack.push(L[0]);
}
throw $e191192;
}
var $ret197198 = $Hanf_bracket2766206($z193194,D531,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,format7872,green138185,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,some6478,success100109,usage_DASH_info128165,builtins15,torepr24);
++R.GAS;
return $ret197198;
};
var $Hanf_bracket2766206 = function(anf_bracket1183202,D531,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,format7872,green138185,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,some6478,success100109,usage_DASH_info128165,builtins15,torepr24) {
var anf_fun11841405 = G(anf_bracket1183202,"run-checks",L[0]);
var anf_fun11851402 = G(list2776,"make",L[0]);
var anf_obj18791407 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[132],0,arguments);
}
var error_DASH_text3331409 = {"$var":D,
"$name":"error-text"};
var anf_assign11981410 = R.makeFunction(function(msg3341423) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[134],1,arguments);
}
var ann_DASH_check_DASH_temp11871424 = R.makeFunction(function(val3351425) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[135],1,arguments);
}
var cases_DASH_val1751462 = val3351425;
var anf_fun11891436 = G(cases_DASH_val1751462,"_match",L[136]);
var anf_obj11911442 = R.makeFunction(function($underscore3361459,$underscore3371460) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[139],2,arguments);
}
var ann_DASH_check_DASH_temp11901461 = (false);
return ann_DASH_check_DASH_temp11901461;
});
var anf_obj11941443 = R.makeFunction(function(m3381444,$underscore3391445) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[137],2,arguments);
}
var anf_fun11931456 = G(m3381444,"contains",L[138]);
var $z14481449 = D;
var $f14541455 = function(_) {
return R.isFunction(anf_fun11931456)?anf_fun11931456.app(msg3341423):R.ffi.throwNonFunApp(L[137],anf_fun11931456,[msg3341423]);
};
try {
if(--R.GAS > 0) {
$z14481449 = $f14541455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14541455,
"from":L[137]});
}
} catch($e14461447) {
if(R.isCont($e14461447)) {
var $ss14501451 = {"from":L[137],
"go":function(ann_DASH_check_DASH_temp11921457) {
return $Hann_DASH_check_DASH_temp22901458(ann_DASH_check_DASH_temp11921457);
}};
$e14461447.stack[R.EXN_STACKHEIGHT++] = $ss14501451;
}
if(R.isPyretException($e14461447)) {
$e14461447.pyretStack.push(L[137]);
}
throw $e14461447;
}
var $ret14521453 = $Hann_DASH_check_DASH_temp22901458($z14481449);
++R.GAS;
return $ret14521453;
});
var anf_arg11951437 = R.makeObject({"success":anf_obj11911442,
"arg-error":anf_obj11941443});
var anf_arg11971438 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[136],0,arguments);
}
var ann_DASH_check_DASH_temp11961441 = R.throwNoBranchesMatched(L[136],("cases"));
return ann_DASH_check_DASH_temp11961441;
});
var $z14281429 = D;
var $f14341435 = function(_) {
return R.isFunction(anf_fun11891436)?anf_fun11891436.app(anf_arg11951437,anf_arg11971438):R.ffi.throwNonFunApp(L[135],anf_fun11891436,[anf_arg11951437,anf_arg11971438]);
};
try {
if(--R.GAS > 0) {
$z14281429 = $f14341435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14341435,
"from":L[135]});
}
} catch($e14261427) {
if(R.isCont($e14261427)) {
var $ss14301431 = {"from":L[135],
"go":function(ann_DASH_check_DASH_temp11881439) {
return $Hann_DASH_check_DASH_temp22911440(ann_DASH_check_DASH_temp11881439);
}};
$e14261427.stack[R.EXN_STACKHEIGHT++] = $ss14301431;
}
if(R.isPyretException($e14261427)) {
$e14261427.pyretStack.push(L[135]);
}
throw $e14261427;
}
var $ret14321433 = $Hann_DASH_check_DASH_temp22911440($z14281429);
++R.GAS;
return $ret14321433;
});
return ann_DASH_check_DASH_temp11871424;
});
error_DASH_text3331409.$var = anf_assign11981410;
var $z14131414 = D;
var $f14191420 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(once107123.$var,("Foo")):R.ffi.throwNonFunApp(L[133],flag118145.$var,[once107123.$var,("Foo")]);
};
try {
if(--R.GAS > 0) {
$z14131414 = $f14191420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14191420,
"from":L[133]});
}
} catch($e14111412) {
if(R.isCont($e14111412)) {
var $ss14151416 = {"from":L[133],
"go":function(anf_obj11991421) {
return $Hanf_obj27601422(anf_obj11991421,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e14111412.stack[R.EXN_STACKHEIGHT++] = $ss14151416;
}
if(R.isPyretException($e14111412)) {
$e14111412.pyretStack.push(L[133]);
}
throw $e14111412;
}
var $ret14171418 = $Hanf_obj27601422($z14131414,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret14171418;
});
var anf_obj18801408 = R.makeSrcloc(L[132]);
var anf_array_val18811403 = R.makeObject({"name":("check-block-1"),
"run":anf_obj18791407,
"location":anf_obj18801408});
var $z13941395 = D;
var $f14001401 = function(_) {
return R.isFunction(anf_fun11851402)?anf_fun11851402.app([anf_array_val18811403]):R.ffi.throwNonFunApp(L[0],anf_fun11851402,[[anf_array_val18811403]]);
};
try {
if(--R.GAS > 0) {
$z13941395 = $f14001401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14001401,
"from":L[0]});
}
} catch($e13921393) {
if(R.isCont($e13921393)) {
var $ss13961397 = {"from":L[0],
"go":function(anf_arg18821404) {
return $Hanf_arg27651406(anf_arg18821404,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,anf_fun11841405,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,usage_DASH_info128165,builtins15);
}};
$e13921393.stack[R.EXN_STACKHEIGHT++] = $ss13961397;
}
if(R.isPyretException($e13921393)) {
$e13921393.pyretStack.push(L[0]);
}
throw $e13921393;
}
var $ret13981399 = $Hanf_arg27651406($z13941395,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,anf_fun11841405,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,usage_DASH_info128165,builtins15);
++R.GAS;
return $ret13981399;
};
var $Hanf_arg27651406 = function(anf_arg18821404,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,anf_fun11841405,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,usage_DASH_info128165,builtins15) {
var $z14651466 = D;
var $f14711472 = function(_) {
return R.isFunction(anf_fun11841405)?anf_fun11841405.app(("src/arr/trove/cmdline.arr"),anf_arg18821404):R.ffi.throwNonFunApp(L[0],anf_fun11841405,[("src/arr/trove/cmdline.arr"),anf_arg18821404]);
};
try {
if(--R.GAS > 0) {
$z14651466 = $f14711472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14711472,
"from":L[0]});
}
} catch($e14631464) {
if(R.isCont($e14631464)) {
var $ss14671468 = {"from":L[0],
"go":function(anf_begin_app_dropped27611473) {
return $Hanf_begin_app_dropped27641474(anf_begin_app_dropped27611473,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,usage_DASH_info128165,builtins15);
}};
$e14631464.stack[R.EXN_STACKHEIGHT++] = $ss14671468;
}
if(R.isPyretException($e14631464)) {
$e14631464.pyretStack.push(L[0]);
}
throw $e14631464;
}
var $ret14691470 = $Hanf_begin_app_dropped27641474($z14651466,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,usage_DASH_info128165,builtins15);
++R.GAS;
return $ret14691470;
};
var $Hanf_begin_app_dropped27641474 = function(anf_begin_app_dropped27611473,Param115139,Param7461,ParamRepeat104117,ParamRepeat7262,ParseParam6865,ParseParam8681,ParsedArguments7067,ParsedArguments97103,RGB7669,equals_DASH_val_DASH_default122153,equals_DASH_val120149,file_DASH_name83203,flag118145,is_DASH_arg_DASH_error101111,is_DASH_success99107,left8074,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,other_DASH_args84204,parse_DASH_args129167,parse_DASH_cmdline130169,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,required_DASH_many113135,required_DASH_once111131,result_DASH_after_DASH_checks1332205,right8177,usage_DASH_info128165,builtins15) {
var provides18831487 = R.makeObject({"file-name":file_DASH_name83203,
"args":other_DASH_args84204,
"Number":read_DASH_number8987.$var,
"Bool":read_DASH_bool9191.$var,
"String":read_DASH_string9395.$var,
"Custom":read_DASH_custom9599.$var,
"ParseParam":ParseParam8681.$var,
"ParamRepeat":ParamRepeat104117.$var,
"Param":Param115139.$var,
"parse-args":parse_DASH_args129167.$var,
"parse-cmdline":parse_DASH_cmdline130169.$var,
"usage-info":usage_DASH_info128165.$var,
"flag":flag118145.$var,
"equals-val":equals_DASH_val120149.$var,
"equals-val-default":equals_DASH_val_DASH_default122153.$var,
"next-val":next_DASH_val124157.$var,
"next-val-default":next_DASH_val_DASH_default126161.$var,
"once":once107123.$var,
"many":many109127.$var,
"left":left8074,
"right":right8177,
"required-once":required_DASH_once111131.$var,
"required-many":required_DASH_many113135.$var,
"ParsedArguments":ParsedArguments97103.$var,
"is-success":is_DASH_success99107.$var,
"is-arg-error":is_DASH_arg_DASH_error101111.$var});
var anf_fun18841485 = G(builtins15,"current-checker",L[93]);
var $z14771478 = D;
var $f14831484 = function(_) {
return R.isFunction(anf_fun18841485)?anf_fun18841485.app():R.ffi.throwNonFunApp(L[93],anf_fun18841485,[]);
};
try {
if(--R.GAS > 0) {
$z14771478 = $f14831484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14831484,
"from":L[93]});
}
} catch($e14751476) {
if(R.isCont($e14751476)) {
var $ss14791480 = {"from":L[93],
"go":function(anf_bracket18851486) {
return $Hanf_bracket27631488(anf_bracket18851486,Param7461,ParamRepeat7262,ParseParam6865,ParsedArguments7067,RGB7669,provides18831487,result_DASH_after_DASH_checks1332205);
}};
$e14751476.stack[R.EXN_STACKHEIGHT++] = $ss14791480;
}
if(R.isPyretException($e14751476)) {
$e14751476.pyretStack.push(L[93]);
}
throw $e14751476;
}
var $ret14811482 = $Hanf_bracket27631488($z14771478,Param7461,ParamRepeat7262,ParseParam6865,ParsedArguments7067,RGB7669,provides18831487,result_DASH_after_DASH_checks1332205);
++R.GAS;
return $ret14811482;
};
var $Hanf_bracket27631488 = function(anf_bracket18851486,Param7461,ParamRepeat7262,ParseParam6865,ParsedArguments7067,RGB7669,provides18831487,result_DASH_after_DASH_checks1332205) {
var anf_fun18861499 = G(anf_bracket18851486,"results",L[93]);
var $z14911492 = D;
var $f14971498 = function(_) {
return R.isFunction(anf_fun18861499)?anf_fun18861499.app():R.ffi.throwNonFunApp(L[93],anf_fun18861499,[]);
};
try {
if(--R.GAS > 0) {
$z14911492 = $f14971498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14971498,
"from":L[93]});
}
} catch($e14891490) {
if(R.isCont($e14891490)) {
var $ss14931494 = {"from":L[93],
"go":function(checks18871500) {
return $Hchecks27621501(checks18871500,Param7461,ParamRepeat7262,ParseParam6865,ParsedArguments7067,RGB7669,provides18831487,result_DASH_after_DASH_checks1332205);
}};
$e14891490.stack[R.EXN_STACKHEIGHT++] = $ss14931494;
}
if(R.isPyretException($e14891490)) {
$e14891490.pyretStack.push(L[93]);
}
throw $e14891490;
}
var $ret14951496 = $Hchecks27621501($z14911492,Param7461,ParamRepeat7262,ParseParam6865,ParsedArguments7067,RGB7669,provides18831487,result_DASH_after_DASH_checks1332205);
++R.GAS;
return $ret14951496;
};
var $Hchecks27621501 = function(checks18871500,Param7461,ParamRepeat7262,ParseParam6865,ParsedArguments7067,RGB7669,provides18831487,result_DASH_after_DASH_checks1332205) {
return R.makeObject({"answer":result_DASH_after_DASH_checks1332205,
"provide-plus-types":R.makeObject({"values":provides18831487,
"types":{"ParseParam":ParseParam6865,
"ParsedArguments":ParsedArguments7067,
"ParamRepeat":ParamRepeat7262,
"Param":Param7461,
"RGB":RGB7669}}),
"checks":checks18871500});
};
var $Hanf_obj27601422 = function(anf_obj11991421,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var once_DASH_optional_DASH_flag3401514 = R.makeObject({"foo":anf_obj11991421});
var anf_fun12001512 = G(builtins15,"current-checker",L[140]);
var $z15041505 = D;
var $f15101511 = function(_) {
return R.isFunction(anf_fun12001512)?anf_fun12001512.app():R.ffi.throwNonFunApp(L[140],anf_fun12001512,[]);
};
try {
if(--R.GAS > 0) {
$z15041505 = $f15101511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15101511,
"from":L[140]});
}
} catch($e15021503) {
if(R.isCont($e15021503)) {
var $ss15061507 = {"from":L[140],
"go":function(anf_bracket12011513) {
return $Hanf_bracket27591515(anf_bracket12011513,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e15021503.stack[R.EXN_STACKHEIGHT++] = $ss15061507;
}
if(R.isPyretException($e15021503)) {
$e15021503.pyretStack.push(L[140]);
}
throw $e15021503;
}
var $ret15081509 = $Hanf_bracket27591515($z15041505,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret15081509;
};
var $Hanf_bracket27591515 = function(anf_bracket12011513,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12021528 = G(anf_bracket12011513,"check-is",L[140]);
var anf_fun12031526 = G(list2776,"make",L[141]);
var $z15181519 = D;
var $f15241525 = function(_) {
return R.isFunction(anf_fun12031526)?anf_fun12031526.app([("-foo")]):R.ffi.throwNonFunApp(L[141],anf_fun12031526,[[("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z15181519 = $f15241525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15241525,
"from":L[141]});
}
} catch($e15161517) {
if(R.isCont($e15161517)) {
var $ss15201521 = {"from":L[141],
"go":function(anf_arg12041527) {
return $Hanf_arg27581529(anf_arg12041527,D531,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e15161517.stack[R.EXN_STACKHEIGHT++] = $ss15201521;
}
if(R.isPyretException($e15161517)) {
$e15161517.pyretStack.push(L[141]);
}
throw $e15161517;
}
var $ret15221523 = $Hanf_arg27581529($z15181519,D531,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret15221523;
};
var $Hanf_arg27581529 = function(anf_arg12041527,D531,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z15321533 = D;
var $f15381539 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_flag3401514,anf_arg12041527):R.ffi.throwNonFunApp(L[142],parse_DASH_args129167.$var,[once_DASH_optional_DASH_flag3401514,anf_arg12041527]);
};
try {
if(--R.GAS > 0) {
$z15321533 = $f15381539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15381539,
"from":L[142]});
}
} catch($e15301531) {
if(R.isCont($e15301531)) {
var $ss15341535 = {"from":L[142],
"go":function(anf_arg12051540) {
return $Hanf_arg27571541(anf_arg12051540,D531,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e15301531.stack[R.EXN_STACKHEIGHT++] = $ss15341535;
}
if(R.isPyretException($e15301531)) {
$e15301531.pyretStack.push(L[142]);
}
throw $e15301531;
}
var $ret15361537 = $Hanf_arg27571541($z15321533,D531,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret15361537;
};
var $Hanf_arg27571541 = function(anf_arg12051540,D531,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12061552 = G(list2776,"make",L[143]);
var $z15441545 = D;
var $f15501551 = function(_) {
return R.isFunction(anf_fun12061552)?anf_fun12061552.app([("foo"),(true)]):R.ffi.throwNonFunApp(L[143],anf_fun12061552,[[("foo"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z15441545 = $f15501551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15501551,
"from":L[143]});
}
} catch($e15421543) {
if(R.isCont($e15421543)) {
var $ss15461547 = {"from":L[143],
"go":function(anf_arg12071553) {
return $Hanf_arg27561554(anf_arg12071553,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e15421543.stack[R.EXN_STACKHEIGHT++] = $ss15461547;
}
if(R.isPyretException($e15421543)) {
$e15421543.pyretStack.push(L[143]);
}
throw $e15421543;
}
var $ret15481549 = $Hanf_arg27561554($z15441545,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret15481549;
};
var $Hanf_arg27561554 = function(anf_arg12071553,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z15571558 = D;
var $f15631564 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg12071553):R.ffi.throwNonFunApp(L[144],dict131171.$var,[anf_arg12071553]);
};
try {
if(--R.GAS > 0) {
$z15571558 = $f15631564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15631564,
"from":L[144]});
}
} catch($e15551556) {
if(R.isCont($e15551556)) {
var $ss15591560 = {"from":L[144],
"go":function(anf_arg12081565) {
return $Hanf_arg27551566(anf_arg12081565,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e15551556.stack[R.EXN_STACKHEIGHT++] = $ss15591560;
}
if(R.isPyretException($e15551556)) {
$e15551556.pyretStack.push(L[144]);
}
throw $e15551556;
}
var $ret15611562 = $Hanf_arg27551566($z15571558,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret15611562;
};
var $Hanf_arg27551566 = function(anf_arg12081565,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12091577 = G(list2776,"make",L[145]);
var $z15691570 = D;
var $f15751576 = function(_) {
return R.isFunction(anf_fun12091577)?anf_fun12091577.app([]):R.ffi.throwNonFunApp(L[145],anf_fun12091577,[[]]);
};
try {
if(--R.GAS > 0) {
$z15691570 = $f15751576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15751576,
"from":L[145]});
}
} catch($e15671568) {
if(R.isCont($e15671568)) {
var $ss15711572 = {"from":L[145],
"go":function(anf_arg12101578) {
return $Hanf_arg27541579(anf_arg12101578,D531,anf_arg12051540,anf_arg12081565,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e15671568.stack[R.EXN_STACKHEIGHT++] = $ss15711572;
}
if(R.isPyretException($e15671568)) {
$e15671568.pyretStack.push(L[145]);
}
throw $e15671568;
}
var $ret15731574 = $Hanf_arg27541579($z15691570,D531,anf_arg12051540,anf_arg12081565,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret15731574;
};
var $Hanf_arg27541579 = function(anf_arg12101578,D531,anf_arg12051540,anf_arg12081565,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z15821583 = D;
var $f15881589 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg12081565,anf_arg12101578):R.ffi.throwNonFunApp(L[146],success100109.$var,[anf_arg12081565,anf_arg12101578]);
};
try {
if(--R.GAS > 0) {
$z15821583 = $f15881589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15881589,
"from":L[146]});
}
} catch($e15801581) {
if(R.isCont($e15801581)) {
var $ss15841585 = {"from":L[146],
"go":function(anf_arg12111590) {
return $Hanf_arg27531591(anf_arg12111590,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e15801581.stack[R.EXN_STACKHEIGHT++] = $ss15841585;
}
if(R.isPyretException($e15801581)) {
$e15801581.pyretStack.push(L[146]);
}
throw $e15801581;
}
var $ret15861587 = $Hanf_arg27531591($z15821583,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret15861587;
};
var $Hanf_arg27531591 = function(anf_arg12111590,D531,anf_arg12051540,anf_fun12021528,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12121602 = R.makeSrcloc(L[140]);
var $z15941595 = D;
var $f16001601 = function(_) {
return R.isFunction(anf_fun12021528)?anf_fun12021528.app(("parse-args(once-optional-flag, [list: \"-foo\"]) is\n  success(dict([list: \"foo\", true]), [list: ])"),anf_arg12051540,anf_arg12111590,anf_arg12121602):R.ffi.throwNonFunApp(L[140],anf_fun12021528,[("parse-args(once-optional-flag, [list: \"-foo\"]) is\n  success(dict([list: \"foo\", true]), [list: ])"),anf_arg12051540,anf_arg12111590,anf_arg12121602]);
};
try {
if(--R.GAS > 0) {
$z15941595 = $f16001601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16001601,
"from":L[140]});
}
} catch($e15921593) {
if(R.isCont($e15921593)) {
var $ss15961597 = {"from":L[140],
"go":function(anf_begin_app_dropped22921603) {
return $Hanf_begin_app_dropped27521604(anf_begin_app_dropped22921603,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e15921593.stack[R.EXN_STACKHEIGHT++] = $ss15961597;
}
if(R.isPyretException($e15921593)) {
$e15921593.pyretStack.push(L[140]);
}
throw $e15921593;
}
var $ret15981599 = $Hanf_begin_app_dropped27521604($z15941595,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret15981599;
};
var $Hanf_begin_app_dropped27521604 = function(anf_begin_app_dropped22921603,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12131615 = G(builtins15,"current-checker",L[147]);
var $z16071608 = D;
var $f16131614 = function(_) {
return R.isFunction(anf_fun12131615)?anf_fun12131615.app():R.ffi.throwNonFunApp(L[147],anf_fun12131615,[]);
};
try {
if(--R.GAS > 0) {
$z16071608 = $f16131614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16131614,
"from":L[147]});
}
} catch($e16051606) {
if(R.isCont($e16051606)) {
var $ss16091610 = {"from":L[147],
"go":function(anf_bracket12141616) {
return $Hanf_bracket27511617(anf_bracket12141616,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e16051606.stack[R.EXN_STACKHEIGHT++] = $ss16091610;
}
if(R.isPyretException($e16051606)) {
$e16051606.pyretStack.push(L[147]);
}
throw $e16051606;
}
var $ret16111612 = $Hanf_bracket27511617($z16071608,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret16111612;
};
var $Hanf_bracket27511617 = function(anf_bracket12141616,D531,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12151630 = G(anf_bracket12141616,"check-is",L[147]);
var anf_fun12161628 = G(list2776,"make",L[148]);
var $z16201621 = D;
var $f16261627 = function(_) {
return R.isFunction(anf_fun12161628)?anf_fun12161628.app([("bar")]):R.ffi.throwNonFunApp(L[148],anf_fun12161628,[[("bar")]]);
};
try {
if(--R.GAS > 0) {
$z16201621 = $f16261627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16261627,
"from":L[148]});
}
} catch($e16181619) {
if(R.isCont($e16181619)) {
var $ss16221623 = {"from":L[148],
"go":function(anf_arg12171629) {
return $Hanf_arg27501631(anf_arg12171629,D531,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e16181619.stack[R.EXN_STACKHEIGHT++] = $ss16221623;
}
if(R.isPyretException($e16181619)) {
$e16181619.pyretStack.push(L[148]);
}
throw $e16181619;
}
var $ret16241625 = $Hanf_arg27501631($z16201621,D531,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret16241625;
};
var $Hanf_arg27501631 = function(anf_arg12171629,D531,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z16341635 = D;
var $f16401641 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_flag3401514,anf_arg12171629):R.ffi.throwNonFunApp(L[149],parse_DASH_args129167.$var,[once_DASH_optional_DASH_flag3401514,anf_arg12171629]);
};
try {
if(--R.GAS > 0) {
$z16341635 = $f16401641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16401641,
"from":L[149]});
}
} catch($e16321633) {
if(R.isCont($e16321633)) {
var $ss16361637 = {"from":L[149],
"go":function(anf_arg12181642) {
return $Hanf_arg27491643(anf_arg12181642,D531,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e16321633.stack[R.EXN_STACKHEIGHT++] = $ss16361637;
}
if(R.isPyretException($e16321633)) {
$e16321633.pyretStack.push(L[149]);
}
throw $e16321633;
}
var $ret16381639 = $Hanf_arg27491643($z16341635,D531,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret16381639;
};
var $Hanf_arg27491643 = function(anf_arg12181642,D531,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12191654 = G(D531,"immutable-string-dict",L[151]);
var $z16461647 = D;
var $f16521653 = function(_) {
return R.isFunction(anf_fun12191654)?anf_fun12191654.app():R.ffi.throwNonFunApp(L[150],anf_fun12191654,[]);
};
try {
if(--R.GAS > 0) {
$z16461647 = $f16521653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16521653,
"from":L[150]});
}
} catch($e16441645) {
if(R.isCont($e16441645)) {
var $ss16481649 = {"from":L[150],
"go":function(anf_arg12201655) {
return $Hanf_arg27481656(anf_arg12201655,anf_arg12181642,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e16441645.stack[R.EXN_STACKHEIGHT++] = $ss16481649;
}
if(R.isPyretException($e16441645)) {
$e16441645.pyretStack.push(L[150]);
}
throw $e16441645;
}
var $ret16501651 = $Hanf_arg27481656($z16461647,anf_arg12181642,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret16501651;
};
var $Hanf_arg27481656 = function(anf_arg12201655,anf_arg12181642,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12211667 = G(list2776,"make",L[152]);
var $z16591660 = D;
var $f16651666 = function(_) {
return R.isFunction(anf_fun12211667)?anf_fun12211667.app([("bar")]):R.ffi.throwNonFunApp(L[152],anf_fun12211667,[[("bar")]]);
};
try {
if(--R.GAS > 0) {
$z16591660 = $f16651666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16651666,
"from":L[152]});
}
} catch($e16571658) {
if(R.isCont($e16571658)) {
var $ss16611662 = {"from":L[152],
"go":function(anf_arg12221668) {
return $Hanf_arg27471669(anf_arg12221668,anf_arg12181642,anf_arg12201655,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e16571658.stack[R.EXN_STACKHEIGHT++] = $ss16611662;
}
if(R.isPyretException($e16571658)) {
$e16571658.pyretStack.push(L[152]);
}
throw $e16571658;
}
var $ret16631664 = $Hanf_arg27471669($z16591660,anf_arg12181642,anf_arg12201655,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret16631664;
};
var $Hanf_arg27471669 = function(anf_arg12221668,anf_arg12181642,anf_arg12201655,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z16721673 = D;
var $f16781679 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg12201655,anf_arg12221668):R.ffi.throwNonFunApp(L[153],success100109.$var,[anf_arg12201655,anf_arg12221668]);
};
try {
if(--R.GAS > 0) {
$z16721673 = $f16781679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16781679,
"from":L[153]});
}
} catch($e16701671) {
if(R.isCont($e16701671)) {
var $ss16741675 = {"from":L[153],
"go":function(anf_arg12231680) {
return $Hanf_arg27461681(anf_arg12231680,anf_arg12181642,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e16701671.stack[R.EXN_STACKHEIGHT++] = $ss16741675;
}
if(R.isPyretException($e16701671)) {
$e16701671.pyretStack.push(L[153]);
}
throw $e16701671;
}
var $ret16761677 = $Hanf_arg27461681($z16721673,anf_arg12181642,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret16761677;
};
var $Hanf_arg27461681 = function(anf_arg12231680,anf_arg12181642,anf_fun12151630,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12241692 = R.makeSrcloc(L[147]);
var $z16841685 = D;
var $f16901691 = function(_) {
return R.isFunction(anf_fun12151630)?anf_fun12151630.app(("parse-args(once-optional-flag, [list: \"bar\"]) is\n  success(D.immutable-string-dict(), [list: \"bar\"])"),anf_arg12181642,anf_arg12231680,anf_arg12241692):R.ffi.throwNonFunApp(L[147],anf_fun12151630,[("parse-args(once-optional-flag, [list: \"bar\"]) is\n  success(D.immutable-string-dict(), [list: \"bar\"])"),anf_arg12181642,anf_arg12231680,anf_arg12241692]);
};
try {
if(--R.GAS > 0) {
$z16841685 = $f16901691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16901691,
"from":L[147]});
}
} catch($e16821683) {
if(R.isCont($e16821683)) {
var $ss16861687 = {"from":L[147],
"go":function(anf_begin_app_dropped22931693) {
return $Hanf_begin_app_dropped27451694(anf_begin_app_dropped22931693,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e16821683.stack[R.EXN_STACKHEIGHT++] = $ss16861687;
}
if(R.isPyretException($e16821683)) {
$e16821683.pyretStack.push(L[147]);
}
throw $e16821683;
}
var $ret16881689 = $Hanf_begin_app_dropped27451694($z16841685,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret16881689;
};
var $Hanf_begin_app_dropped27451694 = function(anf_begin_app_dropped22931693,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12251705 = G(builtins15,"current-checker",L[154]);
var $z16971698 = D;
var $f17031704 = function(_) {
return R.isFunction(anf_fun12251705)?anf_fun12251705.app():R.ffi.throwNonFunApp(L[154],anf_fun12251705,[]);
};
try {
if(--R.GAS > 0) {
$z16971698 = $f17031704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17031704,
"from":L[154]});
}
} catch($e16951696) {
if(R.isCont($e16951696)) {
var $ss16991700 = {"from":L[154],
"go":function(anf_bracket12261706) {
return $Hanf_bracket27441707(anf_bracket12261706,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e16951696.stack[R.EXN_STACKHEIGHT++] = $ss16991700;
}
if(R.isPyretException($e16951696)) {
$e16951696.pyretStack.push(L[154]);
}
throw $e16951696;
}
var $ret17011702 = $Hanf_bracket27441707($z16971698,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret17011702;
};
var $Hanf_bracket27441707 = function(anf_bracket12261706,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12271720 = G(anf_bracket12261706,"check-satisfies",L[154]);
var anf_fun12281718 = G(list2776,"make",L[155]);
var $z17101711 = D;
var $f17161717 = function(_) {
return R.isFunction(anf_fun12281718)?anf_fun12281718.app([("--foo")]):R.ffi.throwNonFunApp(L[155],anf_fun12281718,[[("--foo")]]);
};
try {
if(--R.GAS > 0) {
$z17101711 = $f17161717();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17161717,
"from":L[155]});
}
} catch($e17081709) {
if(R.isCont($e17081709)) {
var $ss17121713 = {"from":L[155],
"go":function(anf_arg12291719) {
return $Hanf_arg27431721(anf_arg12291719,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e17081709.stack[R.EXN_STACKHEIGHT++] = $ss17121713;
}
if(R.isPyretException($e17081709)) {
$e17081709.pyretStack.push(L[155]);
}
throw $e17081709;
}
var $ret17141715 = $Hanf_arg27431721($z17101711,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret17141715;
};
var $Hanf_arg27431721 = function(anf_arg12291719,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z17241725 = D;
var $f17301731 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_flag3401514,anf_arg12291719):R.ffi.throwNonFunApp(L[156],parse_DASH_args129167.$var,[once_DASH_optional_DASH_flag3401514,anf_arg12291719]);
};
try {
if(--R.GAS > 0) {
$z17241725 = $f17301731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17301731,
"from":L[156]});
}
} catch($e17221723) {
if(R.isCont($e17221723)) {
var $ss17261727 = {"from":L[156],
"go":function(anf_arg12301732) {
return $Hanf_arg27421733(anf_arg12301732,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e17221723.stack[R.EXN_STACKHEIGHT++] = $ss17261727;
}
if(R.isPyretException($e17221723)) {
$e17221723.pyretStack.push(L[156]);
}
throw $e17221723;
}
var $ret17281729 = $Hanf_arg27421733($z17241725,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret17281729;
};
var $Hanf_arg27421733 = function(anf_arg12301732,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z17361737 = D;
var $f17421743 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("two dashes")):R.ffi.throwNonFunApp(L[157],error_DASH_text3331409.$var,[("two dashes")]);
};
try {
if(--R.GAS > 0) {
$z17361737 = $f17421743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17421743,
"from":L[157]});
}
} catch($e17341735) {
if(R.isCont($e17341735)) {
var $ss17381739 = {"from":L[157],
"go":function(anf_arg12311744) {
return $Hanf_arg27411745(anf_arg12311744,anf_arg12301732,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e17341735.stack[R.EXN_STACKHEIGHT++] = $ss17381739;
}
if(R.isPyretException($e17341735)) {
$e17341735.pyretStack.push(L[157]);
}
throw $e17341735;
}
var $ret17401741 = $Hanf_arg27411745($z17361737,anf_arg12301732,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret17401741;
};
var $Hanf_arg27411745 = function(anf_arg12311744,anf_arg12301732,anf_fun12271720,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12321756 = R.makeSrcloc(L[154]);
var $z17481749 = D;
var $f17541755 = function(_) {
return R.isFunction(anf_fun12271720)?anf_fun12271720.app(("parse-args(once-optional-flag, [list: \"--foo\"]) satisfies\n  error-text(\"two dashes\")"),anf_arg12301732,anf_arg12311744,anf_arg12321756):R.ffi.throwNonFunApp(L[154],anf_fun12271720,[("parse-args(once-optional-flag, [list: \"--foo\"]) satisfies\n  error-text(\"two dashes\")"),anf_arg12301732,anf_arg12311744,anf_arg12321756]);
};
try {
if(--R.GAS > 0) {
$z17481749 = $f17541755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17541755,
"from":L[154]});
}
} catch($e17461747) {
if(R.isCont($e17461747)) {
var $ss17501751 = {"from":L[154],
"go":function(anf_begin_app_dropped22941757) {
return $Hanf_begin_app_dropped27401758(anf_begin_app_dropped22941757,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e17461747.stack[R.EXN_STACKHEIGHT++] = $ss17501751;
}
if(R.isPyretException($e17461747)) {
$e17461747.pyretStack.push(L[154]);
}
throw $e17461747;
}
var $ret17521753 = $Hanf_begin_app_dropped27401758($z17481749,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret17521753;
};
var $Hanf_begin_app_dropped27401758 = function(anf_begin_app_dropped22941757,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12331769 = G(builtins15,"current-checker",L[158]);
var $z17611762 = D;
var $f17671768 = function(_) {
return R.isFunction(anf_fun12331769)?anf_fun12331769.app():R.ffi.throwNonFunApp(L[158],anf_fun12331769,[]);
};
try {
if(--R.GAS > 0) {
$z17611762 = $f17671768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17671768,
"from":L[158]});
}
} catch($e17591760) {
if(R.isCont($e17591760)) {
var $ss17631764 = {"from":L[158],
"go":function(anf_bracket12341770) {
return $Hanf_bracket27391771(anf_bracket12341770,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e17591760.stack[R.EXN_STACKHEIGHT++] = $ss17631764;
}
if(R.isPyretException($e17591760)) {
$e17591760.pyretStack.push(L[158]);
}
throw $e17591760;
}
var $ret17651766 = $Hanf_bracket27391771($z17611762,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret17651766;
};
var $Hanf_bracket27391771 = function(anf_bracket12341770,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12351784 = G(anf_bracket12341770,"check-satisfies",L[158]);
var anf_fun12361782 = G(list2776,"make",L[159]);
var $z17741775 = D;
var $f17801781 = function(_) {
return R.isFunction(anf_fun12361782)?anf_fun12361782.app([("-foo"),("-foo")]):R.ffi.throwNonFunApp(L[159],anf_fun12361782,[[("-foo"),("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z17741775 = $f17801781();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17801781,
"from":L[159]});
}
} catch($e17721773) {
if(R.isCont($e17721773)) {
var $ss17761777 = {"from":L[159],
"go":function(anf_arg12371783) {
return $Hanf_arg27381785(anf_arg12371783,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e17721773.stack[R.EXN_STACKHEIGHT++] = $ss17761777;
}
if(R.isPyretException($e17721773)) {
$e17721773.pyretStack.push(L[159]);
}
throw $e17721773;
}
var $ret17781779 = $Hanf_arg27381785($z17741775,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret17781779;
};
var $Hanf_arg27381785 = function(anf_arg12371783,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z17881789 = D;
var $f17941795 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_flag3401514,anf_arg12371783):R.ffi.throwNonFunApp(L[160],parse_DASH_args129167.$var,[once_DASH_optional_DASH_flag3401514,anf_arg12371783]);
};
try {
if(--R.GAS > 0) {
$z17881789 = $f17941795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17941795,
"from":L[160]});
}
} catch($e17861787) {
if(R.isCont($e17861787)) {
var $ss17901791 = {"from":L[160],
"go":function(anf_arg12381796) {
return $Hanf_arg27371797(anf_arg12381796,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e17861787.stack[R.EXN_STACKHEIGHT++] = $ss17901791;
}
if(R.isPyretException($e17861787)) {
$e17861787.pyretStack.push(L[160]);
}
throw $e17861787;
}
var $ret17921793 = $Hanf_arg27371797($z17881789,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret17921793;
};
var $Hanf_arg27371797 = function(anf_arg12381796,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z18001801 = D;
var $f18061807 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("already been used")):R.ffi.throwNonFunApp(L[161],error_DASH_text3331409.$var,[("already been used")]);
};
try {
if(--R.GAS > 0) {
$z18001801 = $f18061807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18061807,
"from":L[161]});
}
} catch($e17981799) {
if(R.isCont($e17981799)) {
var $ss18021803 = {"from":L[161],
"go":function(anf_arg12391808) {
return $Hanf_arg27361809(anf_arg12391808,anf_arg12381796,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e17981799.stack[R.EXN_STACKHEIGHT++] = $ss18021803;
}
if(R.isPyretException($e17981799)) {
$e17981799.pyretStack.push(L[161]);
}
throw $e17981799;
}
var $ret18041805 = $Hanf_arg27361809($z18001801,anf_arg12381796,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret18041805;
};
var $Hanf_arg27361809 = function(anf_arg12391808,anf_arg12381796,anf_fun12351784,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12401820 = R.makeSrcloc(L[158]);
var $z18121813 = D;
var $f18181819 = function(_) {
return R.isFunction(anf_fun12351784)?anf_fun12351784.app(("parse-args(once-optional-flag, [list: \"-foo\", \"-foo\"]) satisfies\n  error-text(\"already been used\")"),anf_arg12381796,anf_arg12391808,anf_arg12401820):R.ffi.throwNonFunApp(L[158],anf_fun12351784,[("parse-args(once-optional-flag, [list: \"-foo\", \"-foo\"]) satisfies\n  error-text(\"already been used\")"),anf_arg12381796,anf_arg12391808,anf_arg12401820]);
};
try {
if(--R.GAS > 0) {
$z18121813 = $f18181819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18181819,
"from":L[158]});
}
} catch($e18101811) {
if(R.isCont($e18101811)) {
var $ss18141815 = {"from":L[158],
"go":function(anf_begin_app_dropped22951821) {
return $Hanf_begin_app_dropped27351822(anf_begin_app_dropped22951821,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e18101811.stack[R.EXN_STACKHEIGHT++] = $ss18141815;
}
if(R.isPyretException($e18101811)) {
$e18101811.pyretStack.push(L[158]);
}
throw $e18101811;
}
var $ret18161817 = $Hanf_begin_app_dropped27351822($z18121813,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret18161817;
};
var $Hanf_begin_app_dropped27351822 = function(anf_begin_app_dropped22951821,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12411833 = G(builtins15,"current-checker",L[162]);
var $z18251826 = D;
var $f18311832 = function(_) {
return R.isFunction(anf_fun12411833)?anf_fun12411833.app():R.ffi.throwNonFunApp(L[162],anf_fun12411833,[]);
};
try {
if(--R.GAS > 0) {
$z18251826 = $f18311832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18311832,
"from":L[162]});
}
} catch($e18231824) {
if(R.isCont($e18231824)) {
var $ss18271828 = {"from":L[162],
"go":function(anf_bracket12421834) {
return $Hanf_bracket27341835(anf_bracket12421834,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e18231824.stack[R.EXN_STACKHEIGHT++] = $ss18271828;
}
if(R.isPyretException($e18231824)) {
$e18231824.pyretStack.push(L[162]);
}
throw $e18231824;
}
var $ret18291830 = $Hanf_bracket27341835($z18251826,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret18291830;
};
var $Hanf_bracket27341835 = function(anf_bracket12421834,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12431848 = G(anf_bracket12421834,"check-is",L[162]);
var anf_fun12441846 = G(list2776,"make",L[163]);
var $z18381839 = D;
var $f18441845 = function(_) {
return R.isFunction(anf_fun12441846)?anf_fun12441846.app([("-foo"),("bar")]):R.ffi.throwNonFunApp(L[163],anf_fun12441846,[[("-foo"),("bar")]]);
};
try {
if(--R.GAS > 0) {
$z18381839 = $f18441845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18441845,
"from":L[163]});
}
} catch($e18361837) {
if(R.isCont($e18361837)) {
var $ss18401841 = {"from":L[163],
"go":function(anf_arg12451847) {
return $Hanf_arg27331849(anf_arg12451847,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e18361837.stack[R.EXN_STACKHEIGHT++] = $ss18401841;
}
if(R.isPyretException($e18361837)) {
$e18361837.pyretStack.push(L[163]);
}
throw $e18361837;
}
var $ret18421843 = $Hanf_arg27331849($z18381839,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret18421843;
};
var $Hanf_arg27331849 = function(anf_arg12451847,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z18521853 = D;
var $f18581859 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_flag3401514,anf_arg12451847):R.ffi.throwNonFunApp(L[164],parse_DASH_args129167.$var,[once_DASH_optional_DASH_flag3401514,anf_arg12451847]);
};
try {
if(--R.GAS > 0) {
$z18521853 = $f18581859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18581859,
"from":L[164]});
}
} catch($e18501851) {
if(R.isCont($e18501851)) {
var $ss18541855 = {"from":L[164],
"go":function(anf_arg12461860) {
return $Hanf_arg27321861(anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e18501851.stack[R.EXN_STACKHEIGHT++] = $ss18541855;
}
if(R.isPyretException($e18501851)) {
$e18501851.pyretStack.push(L[164]);
}
throw $e18501851;
}
var $ret18561857 = $Hanf_arg27321861($z18521853,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret18561857;
};
var $Hanf_arg27321861 = function(anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12471872 = G(list2776,"make",L[165]);
var $z18641865 = D;
var $f18701871 = function(_) {
return R.isFunction(anf_fun12471872)?anf_fun12471872.app([("foo"),(true)]):R.ffi.throwNonFunApp(L[165],anf_fun12471872,[[("foo"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z18641865 = $f18701871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18701871,
"from":L[165]});
}
} catch($e18621863) {
if(R.isCont($e18621863)) {
var $ss18661867 = {"from":L[165],
"go":function(anf_arg12481873) {
return $Hanf_arg27311874(anf_arg12481873,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e18621863.stack[R.EXN_STACKHEIGHT++] = $ss18661867;
}
if(R.isPyretException($e18621863)) {
$e18621863.pyretStack.push(L[165]);
}
throw $e18621863;
}
var $ret18681869 = $Hanf_arg27311874($z18641865,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret18681869;
};
var $Hanf_arg27311874 = function(anf_arg12481873,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z18771878 = D;
var $f18831884 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg12481873):R.ffi.throwNonFunApp(L[166],dict131171.$var,[anf_arg12481873]);
};
try {
if(--R.GAS > 0) {
$z18771878 = $f18831884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18831884,
"from":L[166]});
}
} catch($e18751876) {
if(R.isCont($e18751876)) {
var $ss18791880 = {"from":L[166],
"go":function(anf_arg12491885) {
return $Hanf_arg27301886(anf_arg12491885,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e18751876.stack[R.EXN_STACKHEIGHT++] = $ss18791880;
}
if(R.isPyretException($e18751876)) {
$e18751876.pyretStack.push(L[166]);
}
throw $e18751876;
}
var $ret18811882 = $Hanf_arg27301886($z18771878,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret18811882;
};
var $Hanf_arg27301886 = function(anf_arg12491885,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12501897 = G(list2776,"make",L[167]);
var $z18891890 = D;
var $f18951896 = function(_) {
return R.isFunction(anf_fun12501897)?anf_fun12501897.app([("bar")]):R.ffi.throwNonFunApp(L[167],anf_fun12501897,[[("bar")]]);
};
try {
if(--R.GAS > 0) {
$z18891890 = $f18951896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18951896,
"from":L[167]});
}
} catch($e18871888) {
if(R.isCont($e18871888)) {
var $ss18911892 = {"from":L[167],
"go":function(anf_arg12511898) {
return $Hanf_arg27291899(anf_arg12511898,anf_arg12461860,anf_arg12491885,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e18871888.stack[R.EXN_STACKHEIGHT++] = $ss18911892;
}
if(R.isPyretException($e18871888)) {
$e18871888.pyretStack.push(L[167]);
}
throw $e18871888;
}
var $ret18931894 = $Hanf_arg27291899($z18891890,anf_arg12461860,anf_arg12491885,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret18931894;
};
var $Hanf_arg27291899 = function(anf_arg12511898,anf_arg12461860,anf_arg12491885,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z19021903 = D;
var $f19081909 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg12491885,anf_arg12511898):R.ffi.throwNonFunApp(L[168],success100109.$var,[anf_arg12491885,anf_arg12511898]);
};
try {
if(--R.GAS > 0) {
$z19021903 = $f19081909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19081909,
"from":L[168]});
}
} catch($e19001901) {
if(R.isCont($e19001901)) {
var $ss19041905 = {"from":L[168],
"go":function(anf_arg12521910) {
return $Hanf_arg27281911(anf_arg12521910,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e19001901.stack[R.EXN_STACKHEIGHT++] = $ss19041905;
}
if(R.isPyretException($e19001901)) {
$e19001901.pyretStack.push(L[168]);
}
throw $e19001901;
}
var $ret19061907 = $Hanf_arg27281911($z19021903,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret19061907;
};
var $Hanf_arg27281911 = function(anf_arg12521910,anf_arg12461860,anf_fun12431848,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12531922 = R.makeSrcloc(L[162]);
var $z19141915 = D;
var $f19201921 = function(_) {
return R.isFunction(anf_fun12431848)?anf_fun12431848.app(("parse-args(once-optional-flag, [list: \"-foo\", \"bar\"]) is\n  success(dict([list: \"foo\", true]), [list: \"bar\"])"),anf_arg12461860,anf_arg12521910,anf_arg12531922):R.ffi.throwNonFunApp(L[162],anf_fun12431848,[("parse-args(once-optional-flag, [list: \"-foo\", \"bar\"]) is\n  success(dict([list: \"foo\", true]), [list: \"bar\"])"),anf_arg12461860,anf_arg12521910,anf_arg12531922]);
};
try {
if(--R.GAS > 0) {
$z19141915 = $f19201921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19201921,
"from":L[162]});
}
} catch($e19121913) {
if(R.isCont($e19121913)) {
var $ss19161917 = {"from":L[162],
"go":function(anf_begin_app_dropped22961923) {
return $Hanf_begin_app_dropped27271924(anf_begin_app_dropped22961923,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e19121913.stack[R.EXN_STACKHEIGHT++] = $ss19161917;
}
if(R.isPyretException($e19121913)) {
$e19121913.pyretStack.push(L[162]);
}
throw $e19121913;
}
var $ret19181919 = $Hanf_begin_app_dropped27271924($z19141915,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret19181919;
};
var $Hanf_begin_app_dropped27271924 = function(anf_begin_app_dropped22961923,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12541935 = G(builtins15,"current-checker",L[169]);
var $z19271928 = D;
var $f19331934 = function(_) {
return R.isFunction(anf_fun12541935)?anf_fun12541935.app():R.ffi.throwNonFunApp(L[169],anf_fun12541935,[]);
};
try {
if(--R.GAS > 0) {
$z19271928 = $f19331934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19331934,
"from":L[169]});
}
} catch($e19251926) {
if(R.isCont($e19251926)) {
var $ss19291930 = {"from":L[169],
"go":function(anf_bracket12551936) {
return $Hanf_bracket27261937(anf_bracket12551936,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e19251926.stack[R.EXN_STACKHEIGHT++] = $ss19291930;
}
if(R.isPyretException($e19251926)) {
$e19251926.pyretStack.push(L[169]);
}
throw $e19251926;
}
var $ret19311932 = $Hanf_bracket27261937($z19271928,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret19311932;
};
var $Hanf_bracket27261937 = function(anf_bracket12551936,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12561950 = G(anf_bracket12551936,"check-is",L[169]);
var anf_fun12571948 = G(list2776,"make",L[170]);
var $z19401941 = D;
var $f19461947 = function(_) {
return R.isFunction(anf_fun12571948)?anf_fun12571948.app([("bar"),("-foo")]):R.ffi.throwNonFunApp(L[170],anf_fun12571948,[[("bar"),("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z19401941 = $f19461947();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19461947,
"from":L[170]});
}
} catch($e19381939) {
if(R.isCont($e19381939)) {
var $ss19421943 = {"from":L[170],
"go":function(anf_arg12581949) {
return $Hanf_arg27251951(anf_arg12581949,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e19381939.stack[R.EXN_STACKHEIGHT++] = $ss19421943;
}
if(R.isPyretException($e19381939)) {
$e19381939.pyretStack.push(L[170]);
}
throw $e19381939;
}
var $ret19441945 = $Hanf_arg27251951($z19401941,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret19441945;
};
var $Hanf_arg27251951 = function(anf_arg12581949,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z19541955 = D;
var $f19601961 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_flag3401514,anf_arg12581949):R.ffi.throwNonFunApp(L[171],parse_DASH_args129167.$var,[once_DASH_optional_DASH_flag3401514,anf_arg12581949]);
};
try {
if(--R.GAS > 0) {
$z19541955 = $f19601961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19601961,
"from":L[171]});
}
} catch($e19521953) {
if(R.isCont($e19521953)) {
var $ss19561957 = {"from":L[171],
"go":function(anf_arg12591962) {
return $Hanf_arg27241963(anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e19521953.stack[R.EXN_STACKHEIGHT++] = $ss19561957;
}
if(R.isPyretException($e19521953)) {
$e19521953.pyretStack.push(L[171]);
}
throw $e19521953;
}
var $ret19581959 = $Hanf_arg27241963($z19541955,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret19581959;
};
var $Hanf_arg27241963 = function(anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12601974 = G(list2776,"make",L[172]);
var $z19661967 = D;
var $f19721973 = function(_) {
return R.isFunction(anf_fun12601974)?anf_fun12601974.app([("foo"),(true)]):R.ffi.throwNonFunApp(L[172],anf_fun12601974,[[("foo"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z19661967 = $f19721973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19721973,
"from":L[172]});
}
} catch($e19641965) {
if(R.isCont($e19641965)) {
var $ss19681969 = {"from":L[172],
"go":function(anf_arg12611975) {
return $Hanf_arg27231976(anf_arg12611975,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e19641965.stack[R.EXN_STACKHEIGHT++] = $ss19681969;
}
if(R.isPyretException($e19641965)) {
$e19641965.pyretStack.push(L[172]);
}
throw $e19641965;
}
var $ret19701971 = $Hanf_arg27231976($z19661967,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret19701971;
};
var $Hanf_arg27231976 = function(anf_arg12611975,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z19791980 = D;
var $f19851986 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg12611975):R.ffi.throwNonFunApp(L[173],dict131171.$var,[anf_arg12611975]);
};
try {
if(--R.GAS > 0) {
$z19791980 = $f19851986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19851986,
"from":L[173]});
}
} catch($e19771978) {
if(R.isCont($e19771978)) {
var $ss19811982 = {"from":L[173],
"go":function(anf_arg12621987) {
return $Hanf_arg27221988(anf_arg12621987,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e19771978.stack[R.EXN_STACKHEIGHT++] = $ss19811982;
}
if(R.isPyretException($e19771978)) {
$e19771978.pyretStack.push(L[173]);
}
throw $e19771978;
}
var $ret19831984 = $Hanf_arg27221988($z19791980,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret19831984;
};
var $Hanf_arg27221988 = function(anf_arg12621987,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12631999 = G(list2776,"make",L[174]);
var $z19911992 = D;
var $f19971998 = function(_) {
return R.isFunction(anf_fun12631999)?anf_fun12631999.app([("bar")]):R.ffi.throwNonFunApp(L[174],anf_fun12631999,[[("bar")]]);
};
try {
if(--R.GAS > 0) {
$z19911992 = $f19971998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19971998,
"from":L[174]});
}
} catch($e19891990) {
if(R.isCont($e19891990)) {
var $ss19931994 = {"from":L[174],
"go":function(anf_arg12642000) {
return $Hanf_arg27212001(anf_arg12642000,anf_arg12591962,anf_arg12621987,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e19891990.stack[R.EXN_STACKHEIGHT++] = $ss19931994;
}
if(R.isPyretException($e19891990)) {
$e19891990.pyretStack.push(L[174]);
}
throw $e19891990;
}
var $ret19951996 = $Hanf_arg27212001($z19911992,anf_arg12591962,anf_arg12621987,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret19951996;
};
var $Hanf_arg27212001 = function(anf_arg12642000,anf_arg12591962,anf_arg12621987,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z20042005 = D;
var $f20102011 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg12621987,anf_arg12642000):R.ffi.throwNonFunApp(L[175],success100109.$var,[anf_arg12621987,anf_arg12642000]);
};
try {
if(--R.GAS > 0) {
$z20042005 = $f20102011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20102011,
"from":L[175]});
}
} catch($e20022003) {
if(R.isCont($e20022003)) {
var $ss20062007 = {"from":L[175],
"go":function(anf_arg12652012) {
return $Hanf_arg27202013(anf_arg12652012,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e20022003.stack[R.EXN_STACKHEIGHT++] = $ss20062007;
}
if(R.isPyretException($e20022003)) {
$e20022003.pyretStack.push(L[175]);
}
throw $e20022003;
}
var $ret20082009 = $Hanf_arg27202013($z20042005,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret20082009;
};
var $Hanf_arg27202013 = function(anf_arg12652012,anf_arg12591962,anf_fun12561950,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12662024 = R.makeSrcloc(L[169]);
var $z20162017 = D;
var $f20222023 = function(_) {
return R.isFunction(anf_fun12561950)?anf_fun12561950.app(("parse-args(once-optional-flag, [list: \"bar\", \"-foo\"]) is\n  success(dict([list: \"foo\", true]), [list: \"bar\"])"),anf_arg12591962,anf_arg12652012,anf_arg12662024):R.ffi.throwNonFunApp(L[169],anf_fun12561950,[("parse-args(once-optional-flag, [list: \"bar\", \"-foo\"]) is\n  success(dict([list: \"foo\", true]), [list: \"bar\"])"),anf_arg12591962,anf_arg12652012,anf_arg12662024]);
};
try {
if(--R.GAS > 0) {
$z20162017 = $f20222023();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20222023,
"from":L[169]});
}
} catch($e20142015) {
if(R.isCont($e20142015)) {
var $ss20182019 = {"from":L[169],
"go":function(anf_begin_app_dropped22972025) {
return $Hanf_begin_app_dropped27192026(anf_begin_app_dropped22972025,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e20142015.stack[R.EXN_STACKHEIGHT++] = $ss20182019;
}
if(R.isPyretException($e20142015)) {
$e20142015.pyretStack.push(L[169]);
}
throw $e20142015;
}
var $ret20202021 = $Hanf_begin_app_dropped27192026($z20162017,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret20202021;
};
var $Hanf_begin_app_dropped27192026 = function(anf_begin_app_dropped22972025,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12672037 = G(builtins15,"current-checker",L[176]);
var $z20292030 = D;
var $f20352036 = function(_) {
return R.isFunction(anf_fun12672037)?anf_fun12672037.app():R.ffi.throwNonFunApp(L[176],anf_fun12672037,[]);
};
try {
if(--R.GAS > 0) {
$z20292030 = $f20352036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20352036,
"from":L[176]});
}
} catch($e20272028) {
if(R.isCont($e20272028)) {
var $ss20312032 = {"from":L[176],
"go":function(anf_bracket12682038) {
return $Hanf_bracket27182039(anf_bracket12682038,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e20272028.stack[R.EXN_STACKHEIGHT++] = $ss20312032;
}
if(R.isPyretException($e20272028)) {
$e20272028.pyretStack.push(L[176]);
}
throw $e20272028;
}
var $ret20332034 = $Hanf_bracket27182039($z20292030,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret20332034;
};
var $Hanf_bracket27182039 = function(anf_bracket12682038,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12692052 = G(anf_bracket12682038,"check-satisfies",L[176]);
var anf_fun12702050 = G(list2776,"make",L[177]);
var $z20422043 = D;
var $f20482049 = function(_) {
return R.isFunction(anf_fun12702050)?anf_fun12702050.app([("-bar")]):R.ffi.throwNonFunApp(L[177],anf_fun12702050,[[("-bar")]]);
};
try {
if(--R.GAS > 0) {
$z20422043 = $f20482049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20482049,
"from":L[177]});
}
} catch($e20402041) {
if(R.isCont($e20402041)) {
var $ss20442045 = {"from":L[177],
"go":function(anf_arg12712051) {
return $Hanf_arg27172053(anf_arg12712051,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e20402041.stack[R.EXN_STACKHEIGHT++] = $ss20442045;
}
if(R.isPyretException($e20402041)) {
$e20402041.pyretStack.push(L[177]);
}
throw $e20402041;
}
var $ret20462047 = $Hanf_arg27172053($z20422043,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret20462047;
};
var $Hanf_arg27172053 = function(anf_arg12712051,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z20562057 = D;
var $f20622063 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_flag3401514,anf_arg12712051):R.ffi.throwNonFunApp(L[178],parse_DASH_args129167.$var,[once_DASH_optional_DASH_flag3401514,anf_arg12712051]);
};
try {
if(--R.GAS > 0) {
$z20562057 = $f20622063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20622063,
"from":L[178]});
}
} catch($e20542055) {
if(R.isCont($e20542055)) {
var $ss20582059 = {"from":L[178],
"go":function(anf_arg12722064) {
return $Hanf_arg27162065(anf_arg12722064,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e20542055.stack[R.EXN_STACKHEIGHT++] = $ss20582059;
}
if(R.isPyretException($e20542055)) {
$e20542055.pyretStack.push(L[178]);
}
throw $e20542055;
}
var $ret20602061 = $Hanf_arg27162065($z20562057,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret20602061;
};
var $Hanf_arg27162065 = function(anf_arg12722064,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z20682069 = D;
var $f20742075 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("Unknown command line option -bar")):R.ffi.throwNonFunApp(L[179],error_DASH_text3331409.$var,[("Unknown command line option -bar")]);
};
try {
if(--R.GAS > 0) {
$z20682069 = $f20742075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20742075,
"from":L[179]});
}
} catch($e20662067) {
if(R.isCont($e20662067)) {
var $ss20702071 = {"from":L[179],
"go":function(anf_arg12732076) {
return $Hanf_arg27152077(anf_arg12732076,anf_arg12722064,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e20662067.stack[R.EXN_STACKHEIGHT++] = $ss20702071;
}
if(R.isPyretException($e20662067)) {
$e20662067.pyretStack.push(L[179]);
}
throw $e20662067;
}
var $ret20722073 = $Hanf_arg27152077($z20682069,anf_arg12722064,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret20722073;
};
var $Hanf_arg27152077 = function(anf_arg12732076,anf_arg12722064,anf_fun12692052,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12742088 = R.makeSrcloc(L[176]);
var $z20802081 = D;
var $f20862087 = function(_) {
return R.isFunction(anf_fun12692052)?anf_fun12692052.app(("parse-args(once-optional-flag, [list: \"-bar\"]) satisfies\n  error-text(\"Unknown command line option -bar\")"),anf_arg12722064,anf_arg12732076,anf_arg12742088):R.ffi.throwNonFunApp(L[176],anf_fun12692052,[("parse-args(once-optional-flag, [list: \"-bar\"]) satisfies\n  error-text(\"Unknown command line option -bar\")"),anf_arg12722064,anf_arg12732076,anf_arg12742088]);
};
try {
if(--R.GAS > 0) {
$z20802081 = $f20862087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20862087,
"from":L[176]});
}
} catch($e20782079) {
if(R.isCont($e20782079)) {
var $ss20822083 = {"from":L[176],
"go":function(anf_begin_app_dropped22982089) {
return $Hanf_begin_app_dropped27142090(anf_begin_app_dropped22982089,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e20782079.stack[R.EXN_STACKHEIGHT++] = $ss20822083;
}
if(R.isPyretException($e20782079)) {
$e20782079.pyretStack.push(L[176]);
}
throw $e20782079;
}
var $ret20842085 = $Hanf_begin_app_dropped27142090($z20802081,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret20842085;
};
var $Hanf_begin_app_dropped27142090 = function(anf_begin_app_dropped22982089,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12752101 = G(builtins15,"current-checker",L[180]);
var $z20932094 = D;
var $f20992100 = function(_) {
return R.isFunction(anf_fun12752101)?anf_fun12752101.app():R.ffi.throwNonFunApp(L[180],anf_fun12752101,[]);
};
try {
if(--R.GAS > 0) {
$z20932094 = $f20992100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20992100,
"from":L[180]});
}
} catch($e20912092) {
if(R.isCont($e20912092)) {
var $ss20952096 = {"from":L[180],
"go":function(anf_bracket12762102) {
return $Hanf_bracket27132103(anf_bracket12762102,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e20912092.stack[R.EXN_STACKHEIGHT++] = $ss20952096;
}
if(R.isPyretException($e20912092)) {
$e20912092.pyretStack.push(L[180]);
}
throw $e20912092;
}
var $ret20972098 = $Hanf_bracket27132103($z20932094,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret20972098;
};
var $Hanf_bracket27132103 = function(anf_bracket12762102,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12772116 = G(anf_bracket12762102,"check-satisfies",L[180]);
var anf_fun12782114 = G(list2776,"make",L[181]);
var $z21062107 = D;
var $f21122113 = function(_) {
return R.isFunction(anf_fun12782114)?anf_fun12782114.app([("--bar")]):R.ffi.throwNonFunApp(L[181],anf_fun12782114,[[("--bar")]]);
};
try {
if(--R.GAS > 0) {
$z21062107 = $f21122113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21122113,
"from":L[181]});
}
} catch($e21042105) {
if(R.isCont($e21042105)) {
var $ss21082109 = {"from":L[181],
"go":function(anf_arg12792115) {
return $Hanf_arg27122117(anf_arg12792115,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e21042105.stack[R.EXN_STACKHEIGHT++] = $ss21082109;
}
if(R.isPyretException($e21042105)) {
$e21042105.pyretStack.push(L[181]);
}
throw $e21042105;
}
var $ret21102111 = $Hanf_arg27122117($z21062107,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret21102111;
};
var $Hanf_arg27122117 = function(anf_arg12792115,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_flag3401514,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z21202121 = D;
var $f21262127 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_flag3401514,anf_arg12792115):R.ffi.throwNonFunApp(L[182],parse_DASH_args129167.$var,[once_DASH_optional_DASH_flag3401514,anf_arg12792115]);
};
try {
if(--R.GAS > 0) {
$z21202121 = $f21262127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21262127,
"from":L[182]});
}
} catch($e21182119) {
if(R.isCont($e21182119)) {
var $ss21222123 = {"from":L[182],
"go":function(anf_arg12802128) {
return $Hanf_arg27112129(anf_arg12802128,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e21182119.stack[R.EXN_STACKHEIGHT++] = $ss21222123;
}
if(R.isPyretException($e21182119)) {
$e21182119.pyretStack.push(L[182]);
}
throw $e21182119;
}
var $ret21242125 = $Hanf_arg27112129($z21202121,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret21242125;
};
var $Hanf_arg27112129 = function(anf_arg12802128,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z21322133 = D;
var $f21382139 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("Unknown command line option --bar")):R.ffi.throwNonFunApp(L[183],error_DASH_text3331409.$var,[("Unknown command line option --bar")]);
};
try {
if(--R.GAS > 0) {
$z21322133 = $f21382139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21382139,
"from":L[183]});
}
} catch($e21302131) {
if(R.isCont($e21302131)) {
var $ss21342135 = {"from":L[183],
"go":function(anf_arg12812140) {
return $Hanf_arg27102141(anf_arg12812140,anf_arg12802128,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e21302131.stack[R.EXN_STACKHEIGHT++] = $ss21342135;
}
if(R.isPyretException($e21302131)) {
$e21302131.pyretStack.push(L[183]);
}
throw $e21302131;
}
var $ret21362137 = $Hanf_arg27102141($z21322133,anf_arg12802128,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret21362137;
};
var $Hanf_arg27102141 = function(anf_arg12812140,anf_arg12802128,anf_fun12772116,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12822152 = R.makeSrcloc(L[180]);
var $z21442145 = D;
var $f21502151 = function(_) {
return R.isFunction(anf_fun12772116)?anf_fun12772116.app(("parse-args(once-optional-flag, [list: \"--bar\"]) satisfies\n  error-text(\"Unknown command line option --bar\")"),anf_arg12802128,anf_arg12812140,anf_arg12822152):R.ffi.throwNonFunApp(L[180],anf_fun12772116,[("parse-args(once-optional-flag, [list: \"--bar\"]) satisfies\n  error-text(\"Unknown command line option --bar\")"),anf_arg12802128,anf_arg12812140,anf_arg12822152]);
};
try {
if(--R.GAS > 0) {
$z21442145 = $f21502151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21502151,
"from":L[180]});
}
} catch($e21422143) {
if(R.isCont($e21422143)) {
var $ss21462147 = {"from":L[180],
"go":function(anf_begin_app_dropped22992153) {
return $Hanf_begin_app_dropped27092154(anf_begin_app_dropped22992153,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e21422143.stack[R.EXN_STACKHEIGHT++] = $ss21462147;
}
if(R.isPyretException($e21422143)) {
$e21422143.pyretStack.push(L[180]);
}
throw $e21422143;
}
var $ret21482149 = $Hanf_begin_app_dropped27092154($z21442145,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret21482149;
};
var $Hanf_begin_app_dropped27092154 = function(anf_begin_app_dropped22992153,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z21572158 = D;
var $f21632164 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(required_DASH_once111131.$var,("Foo")):R.ffi.throwNonFunApp(L[184],flag118145.$var,[required_DASH_once111131.$var,("Foo")]);
};
try {
if(--R.GAS > 0) {
$z21572158 = $f21632164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21632164,
"from":L[184]});
}
} catch($e21552156) {
if(R.isCont($e21552156)) {
var $ss21592160 = {"from":L[184],
"go":function(anf_obj12832165) {
return $Hanf_obj27082166(anf_obj12832165,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e21552156.stack[R.EXN_STACKHEIGHT++] = $ss21592160;
}
if(R.isPyretException($e21552156)) {
$e21552156.pyretStack.push(L[184]);
}
throw $e21552156;
}
var $ret21612162 = $Hanf_obj27082166($z21572158,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret21612162;
};
var $Hanf_obj27082166 = function(anf_obj12832165,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var once_DASH_required_DASH_flag3412179 = R.makeObject({"foo":anf_obj12832165});
var anf_fun12842177 = G(builtins15,"current-checker",L[185]);
var $z21692170 = D;
var $f21752176 = function(_) {
return R.isFunction(anf_fun12842177)?anf_fun12842177.app():R.ffi.throwNonFunApp(L[185],anf_fun12842177,[]);
};
try {
if(--R.GAS > 0) {
$z21692170 = $f21752176();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21752176,
"from":L[185]});
}
} catch($e21672168) {
if(R.isCont($e21672168)) {
var $ss21712172 = {"from":L[185],
"go":function(anf_bracket12852178) {
return $Hanf_bracket27072180(anf_bracket12852178,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e21672168.stack[R.EXN_STACKHEIGHT++] = $ss21712172;
}
if(R.isPyretException($e21672168)) {
$e21672168.pyretStack.push(L[185]);
}
throw $e21672168;
}
var $ret21732174 = $Hanf_bracket27072180($z21692170,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret21732174;
};
var $Hanf_bracket27072180 = function(anf_bracket12852178,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12862193 = G(anf_bracket12852178,"check-is",L[185]);
var anf_fun12872191 = G(list2776,"make",L[186]);
var $z21832184 = D;
var $f21892190 = function(_) {
return R.isFunction(anf_fun12872191)?anf_fun12872191.app([("-foo")]):R.ffi.throwNonFunApp(L[186],anf_fun12872191,[[("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z21832184 = $f21892190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21892190,
"from":L[186]});
}
} catch($e21812182) {
if(R.isCont($e21812182)) {
var $ss21852186 = {"from":L[186],
"go":function(anf_arg12882192) {
return $Hanf_arg27062194(anf_arg12882192,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e21812182.stack[R.EXN_STACKHEIGHT++] = $ss21852186;
}
if(R.isPyretException($e21812182)) {
$e21812182.pyretStack.push(L[186]);
}
throw $e21812182;
}
var $ret21872188 = $Hanf_arg27062194($z21832184,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret21872188;
};
var $Hanf_arg27062194 = function(anf_arg12882192,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z21972198 = D;
var $f22032204 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_flag3412179,anf_arg12882192):R.ffi.throwNonFunApp(L[187],parse_DASH_args129167.$var,[once_DASH_required_DASH_flag3412179,anf_arg12882192]);
};
try {
if(--R.GAS > 0) {
$z21972198 = $f22032204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22032204,
"from":L[187]});
}
} catch($e21952196) {
if(R.isCont($e21952196)) {
var $ss21992200 = {"from":L[187],
"go":function(anf_arg12892205) {
return $Hanf_arg27052206(anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e21952196.stack[R.EXN_STACKHEIGHT++] = $ss21992200;
}
if(R.isPyretException($e21952196)) {
$e21952196.pyretStack.push(L[187]);
}
throw $e21952196;
}
var $ret22012202 = $Hanf_arg27052206($z21972198,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret22012202;
};
var $Hanf_arg27052206 = function(anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12902217 = G(list2776,"make",L[188]);
var $z22092210 = D;
var $f22152216 = function(_) {
return R.isFunction(anf_fun12902217)?anf_fun12902217.app([("foo"),(true)]):R.ffi.throwNonFunApp(L[188],anf_fun12902217,[[("foo"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z22092210 = $f22152216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22152216,
"from":L[188]});
}
} catch($e22072208) {
if(R.isCont($e22072208)) {
var $ss22112212 = {"from":L[188],
"go":function(anf_arg12912218) {
return $Hanf_arg27042219(anf_arg12912218,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e22072208.stack[R.EXN_STACKHEIGHT++] = $ss22112212;
}
if(R.isPyretException($e22072208)) {
$e22072208.pyretStack.push(L[188]);
}
throw $e22072208;
}
var $ret22132214 = $Hanf_arg27042219($z22092210,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret22132214;
};
var $Hanf_arg27042219 = function(anf_arg12912218,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z22222223 = D;
var $f22282229 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg12912218):R.ffi.throwNonFunApp(L[189],dict131171.$var,[anf_arg12912218]);
};
try {
if(--R.GAS > 0) {
$z22222223 = $f22282229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22282229,
"from":L[189]});
}
} catch($e22202221) {
if(R.isCont($e22202221)) {
var $ss22242225 = {"from":L[189],
"go":function(anf_arg12922230) {
return $Hanf_arg27032231(anf_arg12922230,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e22202221.stack[R.EXN_STACKHEIGHT++] = $ss22242225;
}
if(R.isPyretException($e22202221)) {
$e22202221.pyretStack.push(L[189]);
}
throw $e22202221;
}
var $ret22262227 = $Hanf_arg27032231($z22222223,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret22262227;
};
var $Hanf_arg27032231 = function(anf_arg12922230,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12932242 = G(list2776,"make",L[190]);
var $z22342235 = D;
var $f22402241 = function(_) {
return R.isFunction(anf_fun12932242)?anf_fun12932242.app([]):R.ffi.throwNonFunApp(L[190],anf_fun12932242,[[]]);
};
try {
if(--R.GAS > 0) {
$z22342235 = $f22402241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22402241,
"from":L[190]});
}
} catch($e22322233) {
if(R.isCont($e22322233)) {
var $ss22362237 = {"from":L[190],
"go":function(anf_arg12942243) {
return $Hanf_arg27022244(anf_arg12942243,anf_arg12892205,anf_arg12922230,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e22322233.stack[R.EXN_STACKHEIGHT++] = $ss22362237;
}
if(R.isPyretException($e22322233)) {
$e22322233.pyretStack.push(L[190]);
}
throw $e22322233;
}
var $ret22382239 = $Hanf_arg27022244($z22342235,anf_arg12892205,anf_arg12922230,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret22382239;
};
var $Hanf_arg27022244 = function(anf_arg12942243,anf_arg12892205,anf_arg12922230,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z22472248 = D;
var $f22532254 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg12922230,anf_arg12942243):R.ffi.throwNonFunApp(L[191],success100109.$var,[anf_arg12922230,anf_arg12942243]);
};
try {
if(--R.GAS > 0) {
$z22472248 = $f22532254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22532254,
"from":L[191]});
}
} catch($e22452246) {
if(R.isCont($e22452246)) {
var $ss22492250 = {"from":L[191],
"go":function(anf_arg12952255) {
return $Hanf_arg27012256(anf_arg12952255,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e22452246.stack[R.EXN_STACKHEIGHT++] = $ss22492250;
}
if(R.isPyretException($e22452246)) {
$e22452246.pyretStack.push(L[191]);
}
throw $e22452246;
}
var $ret22512252 = $Hanf_arg27012256($z22472248,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret22512252;
};
var $Hanf_arg27012256 = function(anf_arg12952255,anf_arg12892205,anf_fun12862193,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg12962267 = R.makeSrcloc(L[185]);
var $z22592260 = D;
var $f22652266 = function(_) {
return R.isFunction(anf_fun12862193)?anf_fun12862193.app(("parse-args(once-required-flag, [list: \"-foo\"]) is\n  success(dict([list: \"foo\", true]), [list: ])"),anf_arg12892205,anf_arg12952255,anf_arg12962267):R.ffi.throwNonFunApp(L[185],anf_fun12862193,[("parse-args(once-required-flag, [list: \"-foo\"]) is\n  success(dict([list: \"foo\", true]), [list: ])"),anf_arg12892205,anf_arg12952255,anf_arg12962267]);
};
try {
if(--R.GAS > 0) {
$z22592260 = $f22652266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22652266,
"from":L[185]});
}
} catch($e22572258) {
if(R.isCont($e22572258)) {
var $ss22612262 = {"from":L[185],
"go":function(anf_begin_app_dropped23002268) {
return $Hanf_begin_app_dropped27002269(anf_begin_app_dropped23002268,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e22572258.stack[R.EXN_STACKHEIGHT++] = $ss22612262;
}
if(R.isPyretException($e22572258)) {
$e22572258.pyretStack.push(L[185]);
}
throw $e22572258;
}
var $ret22632264 = $Hanf_begin_app_dropped27002269($z22592260,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret22632264;
};
var $Hanf_begin_app_dropped27002269 = function(anf_begin_app_dropped23002268,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12972280 = G(builtins15,"current-checker",L[192]);
var $z22722273 = D;
var $f22782279 = function(_) {
return R.isFunction(anf_fun12972280)?anf_fun12972280.app():R.ffi.throwNonFunApp(L[192],anf_fun12972280,[]);
};
try {
if(--R.GAS > 0) {
$z22722273 = $f22782279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22782279,
"from":L[192]});
}
} catch($e22702271) {
if(R.isCont($e22702271)) {
var $ss22742275 = {"from":L[192],
"go":function(anf_bracket12982281) {
return $Hanf_bracket26992282(anf_bracket12982281,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e22702271.stack[R.EXN_STACKHEIGHT++] = $ss22742275;
}
if(R.isPyretException($e22702271)) {
$e22702271.pyretStack.push(L[192]);
}
throw $e22702271;
}
var $ret22762277 = $Hanf_bracket26992282($z22722273,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret22762277;
};
var $Hanf_bracket26992282 = function(anf_bracket12982281,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun12992295 = G(anf_bracket12982281,"check-satisfies",L[192]);
var anf_fun13002293 = G(list2776,"make",L[193]);
var $z22852286 = D;
var $f22912292 = function(_) {
return R.isFunction(anf_fun13002293)?anf_fun13002293.app([("bar")]):R.ffi.throwNonFunApp(L[193],anf_fun13002293,[[("bar")]]);
};
try {
if(--R.GAS > 0) {
$z22852286 = $f22912292();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22912292,
"from":L[193]});
}
} catch($e22832284) {
if(R.isCont($e22832284)) {
var $ss22872288 = {"from":L[193],
"go":function(anf_arg13012294) {
return $Hanf_arg26982296(anf_arg13012294,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e22832284.stack[R.EXN_STACKHEIGHT++] = $ss22872288;
}
if(R.isPyretException($e22832284)) {
$e22832284.pyretStack.push(L[193]);
}
throw $e22832284;
}
var $ret22892290 = $Hanf_arg26982296($z22852286,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret22892290;
};
var $Hanf_arg26982296 = function(anf_arg13012294,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z22992300 = D;
var $f23052306 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_flag3412179,anf_arg13012294):R.ffi.throwNonFunApp(L[194],parse_DASH_args129167.$var,[once_DASH_required_DASH_flag3412179,anf_arg13012294]);
};
try {
if(--R.GAS > 0) {
$z22992300 = $f23052306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23052306,
"from":L[194]});
}
} catch($e22972298) {
if(R.isCont($e22972298)) {
var $ss23012302 = {"from":L[194],
"go":function(anf_arg13022307) {
return $Hanf_arg26972308(anf_arg13022307,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e22972298.stack[R.EXN_STACKHEIGHT++] = $ss23012302;
}
if(R.isPyretException($e22972298)) {
$e22972298.pyretStack.push(L[194]);
}
throw $e22972298;
}
var $ret23032304 = $Hanf_arg26972308($z22992300,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret23032304;
};
var $Hanf_arg26972308 = function(anf_arg13022307,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z23112312 = D;
var $f23172318 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("options are required")):R.ffi.throwNonFunApp(L[195],error_DASH_text3331409.$var,[("options are required")]);
};
try {
if(--R.GAS > 0) {
$z23112312 = $f23172318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23172318,
"from":L[195]});
}
} catch($e23092310) {
if(R.isCont($e23092310)) {
var $ss23132314 = {"from":L[195],
"go":function(anf_arg13032319) {
return $Hanf_arg26962320(anf_arg13032319,anf_arg13022307,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e23092310.stack[R.EXN_STACKHEIGHT++] = $ss23132314;
}
if(R.isPyretException($e23092310)) {
$e23092310.pyretStack.push(L[195]);
}
throw $e23092310;
}
var $ret23152316 = $Hanf_arg26962320($z23112312,anf_arg13022307,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret23152316;
};
var $Hanf_arg26962320 = function(anf_arg13032319,anf_arg13022307,anf_fun12992295,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13042331 = R.makeSrcloc(L[192]);
var $z23232324 = D;
var $f23292330 = function(_) {
return R.isFunction(anf_fun12992295)?anf_fun12992295.app(("parse-args(once-required-flag, [list: \"bar\"]) satisfies\n  error-text(\"options are required\")"),anf_arg13022307,anf_arg13032319,anf_arg13042331):R.ffi.throwNonFunApp(L[192],anf_fun12992295,[("parse-args(once-required-flag, [list: \"bar\"]) satisfies\n  error-text(\"options are required\")"),anf_arg13022307,anf_arg13032319,anf_arg13042331]);
};
try {
if(--R.GAS > 0) {
$z23232324 = $f23292330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23292330,
"from":L[192]});
}
} catch($e23212322) {
if(R.isCont($e23212322)) {
var $ss23252326 = {"from":L[192],
"go":function(anf_begin_app_dropped23012332) {
return $Hanf_begin_app_dropped26952333(anf_begin_app_dropped23012332,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e23212322.stack[R.EXN_STACKHEIGHT++] = $ss23252326;
}
if(R.isPyretException($e23212322)) {
$e23212322.pyretStack.push(L[192]);
}
throw $e23212322;
}
var $ret23272328 = $Hanf_begin_app_dropped26952333($z23232324,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret23272328;
};
var $Hanf_begin_app_dropped26952333 = function(anf_begin_app_dropped23012332,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13052344 = G(builtins15,"current-checker",L[196]);
var $z23362337 = D;
var $f23422343 = function(_) {
return R.isFunction(anf_fun13052344)?anf_fun13052344.app():R.ffi.throwNonFunApp(L[196],anf_fun13052344,[]);
};
try {
if(--R.GAS > 0) {
$z23362337 = $f23422343();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23422343,
"from":L[196]});
}
} catch($e23342335) {
if(R.isCont($e23342335)) {
var $ss23382339 = {"from":L[196],
"go":function(anf_bracket13062345) {
return $Hanf_bracket26942346(anf_bracket13062345,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e23342335.stack[R.EXN_STACKHEIGHT++] = $ss23382339;
}
if(R.isPyretException($e23342335)) {
$e23342335.pyretStack.push(L[196]);
}
throw $e23342335;
}
var $ret23402341 = $Hanf_bracket26942346($z23362337,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret23402341;
};
var $Hanf_bracket26942346 = function(anf_bracket13062345,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13072359 = G(anf_bracket13062345,"check-satisfies",L[196]);
var anf_fun13082357 = G(list2776,"make",L[197]);
var $z23492350 = D;
var $f23552356 = function(_) {
return R.isFunction(anf_fun13082357)?anf_fun13082357.app([("--foo")]):R.ffi.throwNonFunApp(L[197],anf_fun13082357,[[("--foo")]]);
};
try {
if(--R.GAS > 0) {
$z23492350 = $f23552356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23552356,
"from":L[197]});
}
} catch($e23472348) {
if(R.isCont($e23472348)) {
var $ss23512352 = {"from":L[197],
"go":function(anf_arg13092358) {
return $Hanf_arg26932360(anf_arg13092358,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e23472348.stack[R.EXN_STACKHEIGHT++] = $ss23512352;
}
if(R.isPyretException($e23472348)) {
$e23472348.pyretStack.push(L[197]);
}
throw $e23472348;
}
var $ret23532354 = $Hanf_arg26932360($z23492350,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret23532354;
};
var $Hanf_arg26932360 = function(anf_arg13092358,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z23632364 = D;
var $f23692370 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_flag3412179,anf_arg13092358):R.ffi.throwNonFunApp(L[198],parse_DASH_args129167.$var,[once_DASH_required_DASH_flag3412179,anf_arg13092358]);
};
try {
if(--R.GAS > 0) {
$z23632364 = $f23692370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23692370,
"from":L[198]});
}
} catch($e23612362) {
if(R.isCont($e23612362)) {
var $ss23652366 = {"from":L[198],
"go":function(anf_arg13102371) {
return $Hanf_arg26922372(anf_arg13102371,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e23612362.stack[R.EXN_STACKHEIGHT++] = $ss23652366;
}
if(R.isPyretException($e23612362)) {
$e23612362.pyretStack.push(L[198]);
}
throw $e23612362;
}
var $ret23672368 = $Hanf_arg26922372($z23632364,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret23672368;
};
var $Hanf_arg26922372 = function(anf_arg13102371,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z23752376 = D;
var $f23812382 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("two dashes")):R.ffi.throwNonFunApp(L[199],error_DASH_text3331409.$var,[("two dashes")]);
};
try {
if(--R.GAS > 0) {
$z23752376 = $f23812382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23812382,
"from":L[199]});
}
} catch($e23732374) {
if(R.isCont($e23732374)) {
var $ss23772378 = {"from":L[199],
"go":function(anf_arg13112383) {
return $Hanf_arg26912384(anf_arg13112383,anf_arg13102371,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e23732374.stack[R.EXN_STACKHEIGHT++] = $ss23772378;
}
if(R.isPyretException($e23732374)) {
$e23732374.pyretStack.push(L[199]);
}
throw $e23732374;
}
var $ret23792380 = $Hanf_arg26912384($z23752376,anf_arg13102371,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret23792380;
};
var $Hanf_arg26912384 = function(anf_arg13112383,anf_arg13102371,anf_fun13072359,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13122395 = R.makeSrcloc(L[196]);
var $z23872388 = D;
var $f23932394 = function(_) {
return R.isFunction(anf_fun13072359)?anf_fun13072359.app(("parse-args(once-required-flag, [list: \"--foo\"]) satisfies\n  error-text(\"two dashes\")"),anf_arg13102371,anf_arg13112383,anf_arg13122395):R.ffi.throwNonFunApp(L[196],anf_fun13072359,[("parse-args(once-required-flag, [list: \"--foo\"]) satisfies\n  error-text(\"two dashes\")"),anf_arg13102371,anf_arg13112383,anf_arg13122395]);
};
try {
if(--R.GAS > 0) {
$z23872388 = $f23932394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23932394,
"from":L[196]});
}
} catch($e23852386) {
if(R.isCont($e23852386)) {
var $ss23892390 = {"from":L[196],
"go":function(anf_begin_app_dropped23022396) {
return $Hanf_begin_app_dropped26902397(anf_begin_app_dropped23022396,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e23852386.stack[R.EXN_STACKHEIGHT++] = $ss23892390;
}
if(R.isPyretException($e23852386)) {
$e23852386.pyretStack.push(L[196]);
}
throw $e23852386;
}
var $ret23912392 = $Hanf_begin_app_dropped26902397($z23872388,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret23912392;
};
var $Hanf_begin_app_dropped26902397 = function(anf_begin_app_dropped23022396,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13132408 = G(builtins15,"current-checker",L[200]);
var $z24002401 = D;
var $f24062407 = function(_) {
return R.isFunction(anf_fun13132408)?anf_fun13132408.app():R.ffi.throwNonFunApp(L[200],anf_fun13132408,[]);
};
try {
if(--R.GAS > 0) {
$z24002401 = $f24062407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24062407,
"from":L[200]});
}
} catch($e23982399) {
if(R.isCont($e23982399)) {
var $ss24022403 = {"from":L[200],
"go":function(anf_bracket13142409) {
return $Hanf_bracket26892410(anf_bracket13142409,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e23982399.stack[R.EXN_STACKHEIGHT++] = $ss24022403;
}
if(R.isPyretException($e23982399)) {
$e23982399.pyretStack.push(L[200]);
}
throw $e23982399;
}
var $ret24042405 = $Hanf_bracket26892410($z24002401,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret24042405;
};
var $Hanf_bracket26892410 = function(anf_bracket13142409,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13152423 = G(anf_bracket13142409,"check-satisfies",L[200]);
var anf_fun13162421 = G(list2776,"make",L[201]);
var $z24132414 = D;
var $f24192420 = function(_) {
return R.isFunction(anf_fun13162421)?anf_fun13162421.app([("-foo"),("-foo")]):R.ffi.throwNonFunApp(L[201],anf_fun13162421,[[("-foo"),("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z24132414 = $f24192420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24192420,
"from":L[201]});
}
} catch($e24112412) {
if(R.isCont($e24112412)) {
var $ss24152416 = {"from":L[201],
"go":function(anf_arg13172422) {
return $Hanf_arg26882424(anf_arg13172422,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e24112412.stack[R.EXN_STACKHEIGHT++] = $ss24152416;
}
if(R.isPyretException($e24112412)) {
$e24112412.pyretStack.push(L[201]);
}
throw $e24112412;
}
var $ret24172418 = $Hanf_arg26882424($z24132414,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret24172418;
};
var $Hanf_arg26882424 = function(anf_arg13172422,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z24272428 = D;
var $f24332434 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_flag3412179,anf_arg13172422):R.ffi.throwNonFunApp(L[202],parse_DASH_args129167.$var,[once_DASH_required_DASH_flag3412179,anf_arg13172422]);
};
try {
if(--R.GAS > 0) {
$z24272428 = $f24332434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24332434,
"from":L[202]});
}
} catch($e24252426) {
if(R.isCont($e24252426)) {
var $ss24292430 = {"from":L[202],
"go":function(anf_arg13182435) {
return $Hanf_arg26872436(anf_arg13182435,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e24252426.stack[R.EXN_STACKHEIGHT++] = $ss24292430;
}
if(R.isPyretException($e24252426)) {
$e24252426.pyretStack.push(L[202]);
}
throw $e24252426;
}
var $ret24312432 = $Hanf_arg26872436($z24272428,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret24312432;
};
var $Hanf_arg26872436 = function(anf_arg13182435,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z24392440 = D;
var $f24452446 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("already been used")):R.ffi.throwNonFunApp(L[203],error_DASH_text3331409.$var,[("already been used")]);
};
try {
if(--R.GAS > 0) {
$z24392440 = $f24452446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24452446,
"from":L[203]});
}
} catch($e24372438) {
if(R.isCont($e24372438)) {
var $ss24412442 = {"from":L[203],
"go":function(anf_arg13192447) {
return $Hanf_arg26862448(anf_arg13192447,anf_arg13182435,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e24372438.stack[R.EXN_STACKHEIGHT++] = $ss24412442;
}
if(R.isPyretException($e24372438)) {
$e24372438.pyretStack.push(L[203]);
}
throw $e24372438;
}
var $ret24432444 = $Hanf_arg26862448($z24392440,anf_arg13182435,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret24432444;
};
var $Hanf_arg26862448 = function(anf_arg13192447,anf_arg13182435,anf_fun13152423,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13202459 = R.makeSrcloc(L[200]);
var $z24512452 = D;
var $f24572458 = function(_) {
return R.isFunction(anf_fun13152423)?anf_fun13152423.app(("parse-args(once-required-flag, [list: \"-foo\", \"-foo\"]) satisfies\n  error-text(\"already been used\")"),anf_arg13182435,anf_arg13192447,anf_arg13202459):R.ffi.throwNonFunApp(L[200],anf_fun13152423,[("parse-args(once-required-flag, [list: \"-foo\", \"-foo\"]) satisfies\n  error-text(\"already been used\")"),anf_arg13182435,anf_arg13192447,anf_arg13202459]);
};
try {
if(--R.GAS > 0) {
$z24512452 = $f24572458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24572458,
"from":L[200]});
}
} catch($e24492450) {
if(R.isCont($e24492450)) {
var $ss24532454 = {"from":L[200],
"go":function(anf_begin_app_dropped23032460) {
return $Hanf_begin_app_dropped26852461(anf_begin_app_dropped23032460,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e24492450.stack[R.EXN_STACKHEIGHT++] = $ss24532454;
}
if(R.isPyretException($e24492450)) {
$e24492450.pyretStack.push(L[200]);
}
throw $e24492450;
}
var $ret24552456 = $Hanf_begin_app_dropped26852461($z24512452,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret24552456;
};
var $Hanf_begin_app_dropped26852461 = function(anf_begin_app_dropped23032460,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13212472 = G(builtins15,"current-checker",L[204]);
var $z24642465 = D;
var $f24702471 = function(_) {
return R.isFunction(anf_fun13212472)?anf_fun13212472.app():R.ffi.throwNonFunApp(L[204],anf_fun13212472,[]);
};
try {
if(--R.GAS > 0) {
$z24642465 = $f24702471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24702471,
"from":L[204]});
}
} catch($e24622463) {
if(R.isCont($e24622463)) {
var $ss24662467 = {"from":L[204],
"go":function(anf_bracket13222473) {
return $Hanf_bracket26842474(anf_bracket13222473,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e24622463.stack[R.EXN_STACKHEIGHT++] = $ss24662467;
}
if(R.isPyretException($e24622463)) {
$e24622463.pyretStack.push(L[204]);
}
throw $e24622463;
}
var $ret24682469 = $Hanf_bracket26842474($z24642465,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret24682469;
};
var $Hanf_bracket26842474 = function(anf_bracket13222473,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13232487 = G(anf_bracket13222473,"check-is",L[204]);
var anf_fun13242485 = G(list2776,"make",L[205]);
var $z24772478 = D;
var $f24832484 = function(_) {
return R.isFunction(anf_fun13242485)?anf_fun13242485.app([("-foo"),("bar")]):R.ffi.throwNonFunApp(L[205],anf_fun13242485,[[("-foo"),("bar")]]);
};
try {
if(--R.GAS > 0) {
$z24772478 = $f24832484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24832484,
"from":L[205]});
}
} catch($e24752476) {
if(R.isCont($e24752476)) {
var $ss24792480 = {"from":L[205],
"go":function(anf_arg13252486) {
return $Hanf_arg26832488(anf_arg13252486,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e24752476.stack[R.EXN_STACKHEIGHT++] = $ss24792480;
}
if(R.isPyretException($e24752476)) {
$e24752476.pyretStack.push(L[205]);
}
throw $e24752476;
}
var $ret24812482 = $Hanf_arg26832488($z24772478,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret24812482;
};
var $Hanf_arg26832488 = function(anf_arg13252486,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z24912492 = D;
var $f24972498 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_flag3412179,anf_arg13252486):R.ffi.throwNonFunApp(L[206],parse_DASH_args129167.$var,[once_DASH_required_DASH_flag3412179,anf_arg13252486]);
};
try {
if(--R.GAS > 0) {
$z24912492 = $f24972498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24972498,
"from":L[206]});
}
} catch($e24892490) {
if(R.isCont($e24892490)) {
var $ss24932494 = {"from":L[206],
"go":function(anf_arg13262499) {
return $Hanf_arg26822500(anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e24892490.stack[R.EXN_STACKHEIGHT++] = $ss24932494;
}
if(R.isPyretException($e24892490)) {
$e24892490.pyretStack.push(L[206]);
}
throw $e24892490;
}
var $ret24952496 = $Hanf_arg26822500($z24912492,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret24952496;
};
var $Hanf_arg26822500 = function(anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13272511 = G(list2776,"make",L[207]);
var $z25032504 = D;
var $f25092510 = function(_) {
return R.isFunction(anf_fun13272511)?anf_fun13272511.app([("foo"),(true)]):R.ffi.throwNonFunApp(L[207],anf_fun13272511,[[("foo"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z25032504 = $f25092510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25092510,
"from":L[207]});
}
} catch($e25012502) {
if(R.isCont($e25012502)) {
var $ss25052506 = {"from":L[207],
"go":function(anf_arg13282512) {
return $Hanf_arg26812513(anf_arg13282512,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e25012502.stack[R.EXN_STACKHEIGHT++] = $ss25052506;
}
if(R.isPyretException($e25012502)) {
$e25012502.pyretStack.push(L[207]);
}
throw $e25012502;
}
var $ret25072508 = $Hanf_arg26812513($z25032504,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret25072508;
};
var $Hanf_arg26812513 = function(anf_arg13282512,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z25162517 = D;
var $f25222523 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg13282512):R.ffi.throwNonFunApp(L[208],dict131171.$var,[anf_arg13282512]);
};
try {
if(--R.GAS > 0) {
$z25162517 = $f25222523();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25222523,
"from":L[208]});
}
} catch($e25142515) {
if(R.isCont($e25142515)) {
var $ss25182519 = {"from":L[208],
"go":function(anf_arg13292524) {
return $Hanf_arg26802525(anf_arg13292524,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e25142515.stack[R.EXN_STACKHEIGHT++] = $ss25182519;
}
if(R.isPyretException($e25142515)) {
$e25142515.pyretStack.push(L[208]);
}
throw $e25142515;
}
var $ret25202521 = $Hanf_arg26802525($z25162517,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret25202521;
};
var $Hanf_arg26802525 = function(anf_arg13292524,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13302536 = G(list2776,"make",L[209]);
var $z25282529 = D;
var $f25342535 = function(_) {
return R.isFunction(anf_fun13302536)?anf_fun13302536.app([("bar")]):R.ffi.throwNonFunApp(L[209],anf_fun13302536,[[("bar")]]);
};
try {
if(--R.GAS > 0) {
$z25282529 = $f25342535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25342535,
"from":L[209]});
}
} catch($e25262527) {
if(R.isCont($e25262527)) {
var $ss25302531 = {"from":L[209],
"go":function(anf_arg13312537) {
return $Hanf_arg26792538(anf_arg13312537,anf_arg13262499,anf_arg13292524,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e25262527.stack[R.EXN_STACKHEIGHT++] = $ss25302531;
}
if(R.isPyretException($e25262527)) {
$e25262527.pyretStack.push(L[209]);
}
throw $e25262527;
}
var $ret25322533 = $Hanf_arg26792538($z25282529,anf_arg13262499,anf_arg13292524,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret25322533;
};
var $Hanf_arg26792538 = function(anf_arg13312537,anf_arg13262499,anf_arg13292524,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z25412542 = D;
var $f25472548 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg13292524,anf_arg13312537):R.ffi.throwNonFunApp(L[210],success100109.$var,[anf_arg13292524,anf_arg13312537]);
};
try {
if(--R.GAS > 0) {
$z25412542 = $f25472548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25472548,
"from":L[210]});
}
} catch($e25392540) {
if(R.isCont($e25392540)) {
var $ss25432544 = {"from":L[210],
"go":function(anf_arg13322549) {
return $Hanf_arg26782550(anf_arg13322549,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e25392540.stack[R.EXN_STACKHEIGHT++] = $ss25432544;
}
if(R.isPyretException($e25392540)) {
$e25392540.pyretStack.push(L[210]);
}
throw $e25392540;
}
var $ret25452546 = $Hanf_arg26782550($z25412542,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret25452546;
};
var $Hanf_arg26782550 = function(anf_arg13322549,anf_arg13262499,anf_fun13232487,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13332561 = R.makeSrcloc(L[204]);
var $z25532554 = D;
var $f25592560 = function(_) {
return R.isFunction(anf_fun13232487)?anf_fun13232487.app(("parse-args(once-required-flag, [list: \"-foo\", \"bar\"]) is\n  success(dict([list: \"foo\", true]), [list: \"bar\"])"),anf_arg13262499,anf_arg13322549,anf_arg13332561):R.ffi.throwNonFunApp(L[204],anf_fun13232487,[("parse-args(once-required-flag, [list: \"-foo\", \"bar\"]) is\n  success(dict([list: \"foo\", true]), [list: \"bar\"])"),anf_arg13262499,anf_arg13322549,anf_arg13332561]);
};
try {
if(--R.GAS > 0) {
$z25532554 = $f25592560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25592560,
"from":L[204]});
}
} catch($e25512552) {
if(R.isCont($e25512552)) {
var $ss25552556 = {"from":L[204],
"go":function(anf_begin_app_dropped23042562) {
return $Hanf_begin_app_dropped26772563(anf_begin_app_dropped23042562,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e25512552.stack[R.EXN_STACKHEIGHT++] = $ss25552556;
}
if(R.isPyretException($e25512552)) {
$e25512552.pyretStack.push(L[204]);
}
throw $e25512552;
}
var $ret25572558 = $Hanf_begin_app_dropped26772563($z25532554,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret25572558;
};
var $Hanf_begin_app_dropped26772563 = function(anf_begin_app_dropped23042562,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13342574 = G(builtins15,"current-checker",L[211]);
var $z25662567 = D;
var $f25722573 = function(_) {
return R.isFunction(anf_fun13342574)?anf_fun13342574.app():R.ffi.throwNonFunApp(L[211],anf_fun13342574,[]);
};
try {
if(--R.GAS > 0) {
$z25662567 = $f25722573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25722573,
"from":L[211]});
}
} catch($e25642565) {
if(R.isCont($e25642565)) {
var $ss25682569 = {"from":L[211],
"go":function(anf_bracket13352575) {
return $Hanf_bracket26762576(anf_bracket13352575,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e25642565.stack[R.EXN_STACKHEIGHT++] = $ss25682569;
}
if(R.isPyretException($e25642565)) {
$e25642565.pyretStack.push(L[211]);
}
throw $e25642565;
}
var $ret25702571 = $Hanf_bracket26762576($z25662567,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret25702571;
};
var $Hanf_bracket26762576 = function(anf_bracket13352575,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13362589 = G(anf_bracket13352575,"check-is",L[211]);
var anf_fun13372587 = G(list2776,"make",L[212]);
var $z25792580 = D;
var $f25852586 = function(_) {
return R.isFunction(anf_fun13372587)?anf_fun13372587.app([("bar"),("-foo")]):R.ffi.throwNonFunApp(L[212],anf_fun13372587,[[("bar"),("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z25792580 = $f25852586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25852586,
"from":L[212]});
}
} catch($e25772578) {
if(R.isCont($e25772578)) {
var $ss25812582 = {"from":L[212],
"go":function(anf_arg13382588) {
return $Hanf_arg26752590(anf_arg13382588,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e25772578.stack[R.EXN_STACKHEIGHT++] = $ss25812582;
}
if(R.isPyretException($e25772578)) {
$e25772578.pyretStack.push(L[212]);
}
throw $e25772578;
}
var $ret25832584 = $Hanf_arg26752590($z25792580,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret25832584;
};
var $Hanf_arg26752590 = function(anf_arg13382588,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_flag3412179,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z25932594 = D;
var $f25992600 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_flag3412179,anf_arg13382588):R.ffi.throwNonFunApp(L[213],parse_DASH_args129167.$var,[once_DASH_required_DASH_flag3412179,anf_arg13382588]);
};
try {
if(--R.GAS > 0) {
$z25932594 = $f25992600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25992600,
"from":L[213]});
}
} catch($e25912592) {
if(R.isCont($e25912592)) {
var $ss25952596 = {"from":L[213],
"go":function(anf_arg13392601) {
return $Hanf_arg26742602(anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e25912592.stack[R.EXN_STACKHEIGHT++] = $ss25952596;
}
if(R.isPyretException($e25912592)) {
$e25912592.pyretStack.push(L[213]);
}
throw $e25912592;
}
var $ret25972598 = $Hanf_arg26742602($z25932594,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret25972598;
};
var $Hanf_arg26742602 = function(anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13402613 = G(list2776,"make",L[214]);
var $z26052606 = D;
var $f26112612 = function(_) {
return R.isFunction(anf_fun13402613)?anf_fun13402613.app([("foo"),(true)]):R.ffi.throwNonFunApp(L[214],anf_fun13402613,[[("foo"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z26052606 = $f26112612();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26112612,
"from":L[214]});
}
} catch($e26032604) {
if(R.isCont($e26032604)) {
var $ss26072608 = {"from":L[214],
"go":function(anf_arg13412614) {
return $Hanf_arg26732615(anf_arg13412614,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e26032604.stack[R.EXN_STACKHEIGHT++] = $ss26072608;
}
if(R.isPyretException($e26032604)) {
$e26032604.pyretStack.push(L[214]);
}
throw $e26032604;
}
var $ret26092610 = $Hanf_arg26732615($z26052606,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret26092610;
};
var $Hanf_arg26732615 = function(anf_arg13412614,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z26182619 = D;
var $f26242625 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg13412614):R.ffi.throwNonFunApp(L[215],dict131171.$var,[anf_arg13412614]);
};
try {
if(--R.GAS > 0) {
$z26182619 = $f26242625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26242625,
"from":L[215]});
}
} catch($e26162617) {
if(R.isCont($e26162617)) {
var $ss26202621 = {"from":L[215],
"go":function(anf_arg13422626) {
return $Hanf_arg26722627(anf_arg13422626,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e26162617.stack[R.EXN_STACKHEIGHT++] = $ss26202621;
}
if(R.isPyretException($e26162617)) {
$e26162617.pyretStack.push(L[215]);
}
throw $e26162617;
}
var $ret26222623 = $Hanf_arg26722627($z26182619,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret26222623;
};
var $Hanf_arg26722627 = function(anf_arg13422626,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13432638 = G(list2776,"make",L[216]);
var $z26302631 = D;
var $f26362637 = function(_) {
return R.isFunction(anf_fun13432638)?anf_fun13432638.app([("bar")]):R.ffi.throwNonFunApp(L[216],anf_fun13432638,[[("bar")]]);
};
try {
if(--R.GAS > 0) {
$z26302631 = $f26362637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26362637,
"from":L[216]});
}
} catch($e26282629) {
if(R.isCont($e26282629)) {
var $ss26322633 = {"from":L[216],
"go":function(anf_arg13442639) {
return $Hanf_arg26712640(anf_arg13442639,anf_arg13392601,anf_arg13422626,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e26282629.stack[R.EXN_STACKHEIGHT++] = $ss26322633;
}
if(R.isPyretException($e26282629)) {
$e26282629.pyretStack.push(L[216]);
}
throw $e26282629;
}
var $ret26342635 = $Hanf_arg26712640($z26302631,anf_arg13392601,anf_arg13422626,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret26342635;
};
var $Hanf_arg26712640 = function(anf_arg13442639,anf_arg13392601,anf_arg13422626,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z26432644 = D;
var $f26492650 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg13422626,anf_arg13442639):R.ffi.throwNonFunApp(L[217],success100109.$var,[anf_arg13422626,anf_arg13442639]);
};
try {
if(--R.GAS > 0) {
$z26432644 = $f26492650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26492650,
"from":L[217]});
}
} catch($e26412642) {
if(R.isCont($e26412642)) {
var $ss26452646 = {"from":L[217],
"go":function(anf_arg13452651) {
return $Hanf_arg26702652(anf_arg13452651,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e26412642.stack[R.EXN_STACKHEIGHT++] = $ss26452646;
}
if(R.isPyretException($e26412642)) {
$e26412642.pyretStack.push(L[217]);
}
throw $e26412642;
}
var $ret26472648 = $Hanf_arg26702652($z26432644,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret26472648;
};
var $Hanf_arg26702652 = function(anf_arg13452651,anf_arg13392601,anf_fun13362589,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13462663 = R.makeSrcloc(L[211]);
var $z26552656 = D;
var $f26612662 = function(_) {
return R.isFunction(anf_fun13362589)?anf_fun13362589.app(("parse-args(once-required-flag, [list: \"bar\", \"-foo\"]) is\n  success(dict([list: \"foo\", true]), [list: \"bar\"])"),anf_arg13392601,anf_arg13452651,anf_arg13462663):R.ffi.throwNonFunApp(L[211],anf_fun13362589,[("parse-args(once-required-flag, [list: \"bar\", \"-foo\"]) is\n  success(dict([list: \"foo\", true]), [list: \"bar\"])"),anf_arg13392601,anf_arg13452651,anf_arg13462663]);
};
try {
if(--R.GAS > 0) {
$z26552656 = $f26612662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26612662,
"from":L[211]});
}
} catch($e26532654) {
if(R.isCont($e26532654)) {
var $ss26572658 = {"from":L[211],
"go":function(anf_begin_app_dropped23052664) {
return $Hanf_begin_app_dropped26692665(anf_begin_app_dropped23052664,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e26532654.stack[R.EXN_STACKHEIGHT++] = $ss26572658;
}
if(R.isPyretException($e26532654)) {
$e26532654.pyretStack.push(L[211]);
}
throw $e26532654;
}
var $ret26592660 = $Hanf_begin_app_dropped26692665($z26552656,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret26592660;
};
var $Hanf_begin_app_dropped26692665 = function(anf_begin_app_dropped23052664,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z26682669 = D;
var $f26742675 = function(_) {
return R.isFunction(some6478)?some6478.app(("f")):R.ffi.throwNonFunApp(L[218],some6478,[("f")]);
};
try {
if(--R.GAS > 0) {
$z26682669 = $f26742675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26742675,
"from":L[218]});
}
} catch($e26662667) {
if(R.isCont($e26662667)) {
var $ss26702671 = {"from":L[218],
"go":function(anf_arg13472676) {
return $Hanf_arg26682677(anf_arg13472676,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e26662667.stack[R.EXN_STACKHEIGHT++] = $ss26702671;
}
if(R.isPyretException($e26662667)) {
$e26662667.pyretStack.push(L[218]);
}
throw $e26662667;
}
var $ret26722673 = $Hanf_arg26682677($z26682669,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret26722673;
};
var $Hanf_arg26682677 = function(anf_arg13472676,blue140189,dict131171,equals_DASH_val_DASH_default122153,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z26802681 = D;
var $f26862687 = function(_) {
return R.isFunction(equals_DASH_val_DASH_default122153.$var)?equals_DASH_val_DASH_default122153.$var.app(read_DASH_number8987.$var,(42),anf_arg13472676,required_DASH_once111131.$var,("Foo")):R.ffi.throwNonFunApp(L[219],equals_DASH_val_DASH_default122153.$var,[read_DASH_number8987.$var,(42),anf_arg13472676,required_DASH_once111131.$var,("Foo")]);
};
try {
if(--R.GAS > 0) {
$z26802681 = $f26862687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26862687,
"from":L[219]});
}
} catch($e26782679) {
if(R.isCont($e26782679)) {
var $ss26822683 = {"from":L[219],
"go":function(anf_obj13482688) {
return $Hanf_obj26672689(anf_obj13482688,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e26782679.stack[R.EXN_STACKHEIGHT++] = $ss26822683;
}
if(R.isPyretException($e26782679)) {
$e26782679.pyretStack.push(L[219]);
}
throw $e26782679;
}
var $ret26842685 = $Hanf_obj26672689($z26802681,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret26842685;
};
var $Hanf_obj26672689 = function(anf_obj13482688,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z26922693 = D;
var $f26982699 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(once107123.$var,("Bar")):R.ffi.throwNonFunApp(L[220],flag118145.$var,[once107123.$var,("Bar")]);
};
try {
if(--R.GAS > 0) {
$z26922693 = $f26982699();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26982699,
"from":L[220]});
}
} catch($e26902691) {
if(R.isCont($e26902691)) {
var $ss26942695 = {"from":L[220],
"go":function(anf_obj13492700) {
return $Hanf_obj26662701(anf_obj13492700,anf_obj13482688,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e26902691.stack[R.EXN_STACKHEIGHT++] = $ss26942695;
}
if(R.isPyretException($e26902691)) {
$e26902691.pyretStack.push(L[220]);
}
throw $e26902691;
}
var $ret26962697 = $Hanf_obj26662701($z26922693,anf_obj13482688,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret26962697;
};
var $Hanf_obj26662701 = function(anf_obj13492700,anf_obj13482688,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var once_DASH_required_DASH_equals_DASH_default3422714 = R.makeObject({"foo":anf_obj13482688,
"bar":anf_obj13492700});
var anf_fun13502712 = G(builtins15,"current-checker",L[221]);
var $z27042705 = D;
var $f27102711 = function(_) {
return R.isFunction(anf_fun13502712)?anf_fun13502712.app():R.ffi.throwNonFunApp(L[221],anf_fun13502712,[]);
};
try {
if(--R.GAS > 0) {
$z27042705 = $f27102711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27102711,
"from":L[221]});
}
} catch($e27022703) {
if(R.isCont($e27022703)) {
var $ss27062707 = {"from":L[221],
"go":function(anf_bracket13512713) {
return $Hanf_bracket26652715(anf_bracket13512713,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e27022703.stack[R.EXN_STACKHEIGHT++] = $ss27062707;
}
if(R.isPyretException($e27022703)) {
$e27022703.pyretStack.push(L[221]);
}
throw $e27022703;
}
var $ret27082709 = $Hanf_bracket26652715($z27042705,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret27082709;
};
var $Hanf_bracket26652715 = function(anf_bracket13512713,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13522728 = G(anf_bracket13512713,"check-is",L[221]);
var anf_fun13532726 = G(list2776,"make",L[222]);
var $z27182719 = D;
var $f27242725 = function(_) {
return R.isFunction(anf_fun13532726)?anf_fun13532726.app([("--foo=3")]):R.ffi.throwNonFunApp(L[222],anf_fun13532726,[[("--foo=3")]]);
};
try {
if(--R.GAS > 0) {
$z27182719 = $f27242725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27242725,
"from":L[222]});
}
} catch($e27162717) {
if(R.isCont($e27162717)) {
var $ss27202721 = {"from":L[222],
"go":function(anf_arg13542727) {
return $Hanf_arg26642729(anf_arg13542727,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e27162717.stack[R.EXN_STACKHEIGHT++] = $ss27202721;
}
if(R.isPyretException($e27162717)) {
$e27162717.pyretStack.push(L[222]);
}
throw $e27162717;
}
var $ret27222723 = $Hanf_arg26642729($z27182719,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret27222723;
};
var $Hanf_arg26642729 = function(anf_arg13542727,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z27322733 = D;
var $f27382739 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13542727):R.ffi.throwNonFunApp(L[223],parse_DASH_args129167.$var,[once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13542727]);
};
try {
if(--R.GAS > 0) {
$z27322733 = $f27382739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27382739,
"from":L[223]});
}
} catch($e27302731) {
if(R.isCont($e27302731)) {
var $ss27342735 = {"from":L[223],
"go":function(anf_arg13552740) {
return $Hanf_arg26632741(anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e27302731.stack[R.EXN_STACKHEIGHT++] = $ss27342735;
}
if(R.isPyretException($e27302731)) {
$e27302731.pyretStack.push(L[223]);
}
throw $e27302731;
}
var $ret27362737 = $Hanf_arg26632741($z27322733,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret27362737;
};
var $Hanf_arg26632741 = function(anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13562752 = G(list2776,"make",L[224]);
var $z27442745 = D;
var $f27502751 = function(_) {
return R.isFunction(anf_fun13562752)?anf_fun13562752.app([("foo"),(3)]):R.ffi.throwNonFunApp(L[224],anf_fun13562752,[[("foo"),(3)]]);
};
try {
if(--R.GAS > 0) {
$z27442745 = $f27502751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27502751,
"from":L[224]});
}
} catch($e27422743) {
if(R.isCont($e27422743)) {
var $ss27462747 = {"from":L[224],
"go":function(anf_arg13572753) {
return $Hanf_arg26622754(anf_arg13572753,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e27422743.stack[R.EXN_STACKHEIGHT++] = $ss27462747;
}
if(R.isPyretException($e27422743)) {
$e27422743.pyretStack.push(L[224]);
}
throw $e27422743;
}
var $ret27482749 = $Hanf_arg26622754($z27442745,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret27482749;
};
var $Hanf_arg26622754 = function(anf_arg13572753,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z27572758 = D;
var $f27632764 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg13572753):R.ffi.throwNonFunApp(L[225],dict131171.$var,[anf_arg13572753]);
};
try {
if(--R.GAS > 0) {
$z27572758 = $f27632764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27632764,
"from":L[225]});
}
} catch($e27552756) {
if(R.isCont($e27552756)) {
var $ss27592760 = {"from":L[225],
"go":function(anf_arg13582765) {
return $Hanf_arg26612766(anf_arg13582765,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e27552756.stack[R.EXN_STACKHEIGHT++] = $ss27592760;
}
if(R.isPyretException($e27552756)) {
$e27552756.pyretStack.push(L[225]);
}
throw $e27552756;
}
var $ret27612762 = $Hanf_arg26612766($z27572758,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret27612762;
};
var $Hanf_arg26612766 = function(anf_arg13582765,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13592777 = G(list2776,"make",L[226]);
var $z27692770 = D;
var $f27752776 = function(_) {
return R.isFunction(anf_fun13592777)?anf_fun13592777.app([]):R.ffi.throwNonFunApp(L[226],anf_fun13592777,[[]]);
};
try {
if(--R.GAS > 0) {
$z27692770 = $f27752776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27752776,
"from":L[226]});
}
} catch($e27672768) {
if(R.isCont($e27672768)) {
var $ss27712772 = {"from":L[226],
"go":function(anf_arg13602778) {
return $Hanf_arg26602779(anf_arg13602778,anf_arg13552740,anf_arg13582765,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e27672768.stack[R.EXN_STACKHEIGHT++] = $ss27712772;
}
if(R.isPyretException($e27672768)) {
$e27672768.pyretStack.push(L[226]);
}
throw $e27672768;
}
var $ret27732774 = $Hanf_arg26602779($z27692770,anf_arg13552740,anf_arg13582765,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret27732774;
};
var $Hanf_arg26602779 = function(anf_arg13602778,anf_arg13552740,anf_arg13582765,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z27822783 = D;
var $f27882789 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg13582765,anf_arg13602778):R.ffi.throwNonFunApp(L[227],success100109.$var,[anf_arg13582765,anf_arg13602778]);
};
try {
if(--R.GAS > 0) {
$z27822783 = $f27882789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27882789,
"from":L[227]});
}
} catch($e27802781) {
if(R.isCont($e27802781)) {
var $ss27842785 = {"from":L[227],
"go":function(anf_arg13612790) {
return $Hanf_arg26592791(anf_arg13612790,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e27802781.stack[R.EXN_STACKHEIGHT++] = $ss27842785;
}
if(R.isPyretException($e27802781)) {
$e27802781.pyretStack.push(L[227]);
}
throw $e27802781;
}
var $ret27862787 = $Hanf_arg26592791($z27822783,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret27862787;
};
var $Hanf_arg26592791 = function(anf_arg13612790,anf_arg13552740,anf_fun13522728,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13622802 = R.makeSrcloc(L[221]);
var $z27942795 = D;
var $f28002801 = function(_) {
return R.isFunction(anf_fun13522728)?anf_fun13522728.app(("parse-args(once-required-equals-default, [list: \"--foo=3\"]) is\n  success(dict([list: \"foo\", 3]), [list: ])"),anf_arg13552740,anf_arg13612790,anf_arg13622802):R.ffi.throwNonFunApp(L[221],anf_fun13522728,[("parse-args(once-required-equals-default, [list: \"--foo=3\"]) is\n  success(dict([list: \"foo\", 3]), [list: ])"),anf_arg13552740,anf_arg13612790,anf_arg13622802]);
};
try {
if(--R.GAS > 0) {
$z27942795 = $f28002801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28002801,
"from":L[221]});
}
} catch($e27922793) {
if(R.isCont($e27922793)) {
var $ss27962797 = {"from":L[221],
"go":function(anf_begin_app_dropped23062803) {
return $Hanf_begin_app_dropped26582804(anf_begin_app_dropped23062803,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e27922793.stack[R.EXN_STACKHEIGHT++] = $ss27962797;
}
if(R.isPyretException($e27922793)) {
$e27922793.pyretStack.push(L[221]);
}
throw $e27922793;
}
var $ret27982799 = $Hanf_begin_app_dropped26582804($z27942795,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret27982799;
};
var $Hanf_begin_app_dropped26582804 = function(anf_begin_app_dropped23062803,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13632815 = G(builtins15,"current-checker",L[228]);
var $z28072808 = D;
var $f28132814 = function(_) {
return R.isFunction(anf_fun13632815)?anf_fun13632815.app():R.ffi.throwNonFunApp(L[228],anf_fun13632815,[]);
};
try {
if(--R.GAS > 0) {
$z28072808 = $f28132814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28132814,
"from":L[228]});
}
} catch($e28052806) {
if(R.isCont($e28052806)) {
var $ss28092810 = {"from":L[228],
"go":function(anf_bracket13642816) {
return $Hanf_bracket26572817(anf_bracket13642816,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e28052806.stack[R.EXN_STACKHEIGHT++] = $ss28092810;
}
if(R.isPyretException($e28052806)) {
$e28052806.pyretStack.push(L[228]);
}
throw $e28052806;
}
var $ret28112812 = $Hanf_bracket26572817($z28072808,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret28112812;
};
var $Hanf_bracket26572817 = function(anf_bracket13642816,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13652830 = G(anf_bracket13642816,"check-satisfies",L[228]);
var anf_fun13662828 = G(list2776,"make",L[229]);
var $z28202821 = D;
var $f28262827 = function(_) {
return R.isFunction(anf_fun13662828)?anf_fun13662828.app([("--foo=bar")]):R.ffi.throwNonFunApp(L[229],anf_fun13662828,[[("--foo=bar")]]);
};
try {
if(--R.GAS > 0) {
$z28202821 = $f28262827();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28262827,
"from":L[229]});
}
} catch($e28182819) {
if(R.isCont($e28182819)) {
var $ss28222823 = {"from":L[229],
"go":function(anf_arg13672829) {
return $Hanf_arg26562831(anf_arg13672829,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e28182819.stack[R.EXN_STACKHEIGHT++] = $ss28222823;
}
if(R.isPyretException($e28182819)) {
$e28182819.pyretStack.push(L[229]);
}
throw $e28182819;
}
var $ret28242825 = $Hanf_arg26562831($z28202821,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret28242825;
};
var $Hanf_arg26562831 = function(anf_arg13672829,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z28342835 = D;
var $f28402841 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13672829):R.ffi.throwNonFunApp(L[230],parse_DASH_args129167.$var,[once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13672829]);
};
try {
if(--R.GAS > 0) {
$z28342835 = $f28402841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28402841,
"from":L[230]});
}
} catch($e28322833) {
if(R.isCont($e28322833)) {
var $ss28362837 = {"from":L[230],
"go":function(anf_arg13682842) {
return $Hanf_arg26552843(anf_arg13682842,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e28322833.stack[R.EXN_STACKHEIGHT++] = $ss28362837;
}
if(R.isPyretException($e28322833)) {
$e28322833.pyretStack.push(L[230]);
}
throw $e28322833;
}
var $ret28382839 = $Hanf_arg26552843($z28342835,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret28382839;
};
var $Hanf_arg26552843 = function(anf_arg13682842,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z28462847 = D;
var $f28522853 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("expected a numeric argument")):R.ffi.throwNonFunApp(L[231],error_DASH_text3331409.$var,[("expected a numeric argument")]);
};
try {
if(--R.GAS > 0) {
$z28462847 = $f28522853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28522853,
"from":L[231]});
}
} catch($e28442845) {
if(R.isCont($e28442845)) {
var $ss28482849 = {"from":L[231],
"go":function(anf_arg13692854) {
return $Hanf_arg26542855(anf_arg13692854,anf_arg13682842,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e28442845.stack[R.EXN_STACKHEIGHT++] = $ss28482849;
}
if(R.isPyretException($e28442845)) {
$e28442845.pyretStack.push(L[231]);
}
throw $e28442845;
}
var $ret28502851 = $Hanf_arg26542855($z28462847,anf_arg13682842,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret28502851;
};
var $Hanf_arg26542855 = function(anf_arg13692854,anf_arg13682842,anf_fun13652830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13702866 = R.makeSrcloc(L[228]);
var $z28582859 = D;
var $f28642865 = function(_) {
return R.isFunction(anf_fun13652830)?anf_fun13652830.app(("parse-args(once-required-equals-default, [list: \"--foo=bar\"]) satisfies\n  error-text(\"expected a numeric argument\")"),anf_arg13682842,anf_arg13692854,anf_arg13702866):R.ffi.throwNonFunApp(L[228],anf_fun13652830,[("parse-args(once-required-equals-default, [list: \"--foo=bar\"]) satisfies\n  error-text(\"expected a numeric argument\")"),anf_arg13682842,anf_arg13692854,anf_arg13702866]);
};
try {
if(--R.GAS > 0) {
$z28582859 = $f28642865();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28642865,
"from":L[228]});
}
} catch($e28562857) {
if(R.isCont($e28562857)) {
var $ss28602861 = {"from":L[228],
"go":function(anf_begin_app_dropped23072867) {
return $Hanf_begin_app_dropped26532868(anf_begin_app_dropped23072867,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e28562857.stack[R.EXN_STACKHEIGHT++] = $ss28602861;
}
if(R.isPyretException($e28562857)) {
$e28562857.pyretStack.push(L[228]);
}
throw $e28562857;
}
var $ret28622863 = $Hanf_begin_app_dropped26532868($z28582859,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret28622863;
};
var $Hanf_begin_app_dropped26532868 = function(anf_begin_app_dropped23072867,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13712879 = G(builtins15,"current-checker",L[232]);
var $z28712872 = D;
var $f28772878 = function(_) {
return R.isFunction(anf_fun13712879)?anf_fun13712879.app():R.ffi.throwNonFunApp(L[232],anf_fun13712879,[]);
};
try {
if(--R.GAS > 0) {
$z28712872 = $f28772878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28772878,
"from":L[232]});
}
} catch($e28692870) {
if(R.isCont($e28692870)) {
var $ss28732874 = {"from":L[232],
"go":function(anf_bracket13722880) {
return $Hanf_bracket26522881(anf_bracket13722880,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e28692870.stack[R.EXN_STACKHEIGHT++] = $ss28732874;
}
if(R.isPyretException($e28692870)) {
$e28692870.pyretStack.push(L[232]);
}
throw $e28692870;
}
var $ret28752876 = $Hanf_bracket26522881($z28712872,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret28752876;
};
var $Hanf_bracket26522881 = function(anf_bracket13722880,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13732894 = G(anf_bracket13722880,"check-satisfies",L[232]);
var anf_fun13742892 = G(list2776,"make",L[233]);
var $z28842885 = D;
var $f28902891 = function(_) {
return R.isFunction(anf_fun13742892)?anf_fun13742892.app([("--foo=3"),("--foo=4")]):R.ffi.throwNonFunApp(L[233],anf_fun13742892,[[("--foo=3"),("--foo=4")]]);
};
try {
if(--R.GAS > 0) {
$z28842885 = $f28902891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28902891,
"from":L[233]});
}
} catch($e28822883) {
if(R.isCont($e28822883)) {
var $ss28862887 = {"from":L[233],
"go":function(anf_arg13752893) {
return $Hanf_arg26512895(anf_arg13752893,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e28822883.stack[R.EXN_STACKHEIGHT++] = $ss28862887;
}
if(R.isPyretException($e28822883)) {
$e28822883.pyretStack.push(L[233]);
}
throw $e28822883;
}
var $ret28882889 = $Hanf_arg26512895($z28842885,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret28882889;
};
var $Hanf_arg26512895 = function(anf_arg13752893,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z28982899 = D;
var $f29042905 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13752893):R.ffi.throwNonFunApp(L[234],parse_DASH_args129167.$var,[once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13752893]);
};
try {
if(--R.GAS > 0) {
$z28982899 = $f29042905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29042905,
"from":L[234]});
}
} catch($e28962897) {
if(R.isCont($e28962897)) {
var $ss29002901 = {"from":L[234],
"go":function(anf_arg13762906) {
return $Hanf_arg26502907(anf_arg13762906,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e28962897.stack[R.EXN_STACKHEIGHT++] = $ss29002901;
}
if(R.isPyretException($e28962897)) {
$e28962897.pyretStack.push(L[234]);
}
throw $e28962897;
}
var $ret29022903 = $Hanf_arg26502907($z28982899,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret29022903;
};
var $Hanf_arg26502907 = function(anf_arg13762906,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z29102911 = D;
var $f29162917 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("already been used")):R.ffi.throwNonFunApp(L[235],error_DASH_text3331409.$var,[("already been used")]);
};
try {
if(--R.GAS > 0) {
$z29102911 = $f29162917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29162917,
"from":L[235]});
}
} catch($e29082909) {
if(R.isCont($e29082909)) {
var $ss29122913 = {"from":L[235],
"go":function(anf_arg13772918) {
return $Hanf_arg26492919(anf_arg13772918,anf_arg13762906,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e29082909.stack[R.EXN_STACKHEIGHT++] = $ss29122913;
}
if(R.isPyretException($e29082909)) {
$e29082909.pyretStack.push(L[235]);
}
throw $e29082909;
}
var $ret29142915 = $Hanf_arg26492919($z29102911,anf_arg13762906,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret29142915;
};
var $Hanf_arg26492919 = function(anf_arg13772918,anf_arg13762906,anf_fun13732894,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13782930 = R.makeSrcloc(L[232]);
var $z29222923 = D;
var $f29282929 = function(_) {
return R.isFunction(anf_fun13732894)?anf_fun13732894.app(("parse-args(once-required-equals-default, [list: \"--foo=3\", \"--foo=4\"]) satisfies\n  error-text(\"already been used\")"),anf_arg13762906,anf_arg13772918,anf_arg13782930):R.ffi.throwNonFunApp(L[232],anf_fun13732894,[("parse-args(once-required-equals-default, [list: \"--foo=3\", \"--foo=4\"]) satisfies\n  error-text(\"already been used\")"),anf_arg13762906,anf_arg13772918,anf_arg13782930]);
};
try {
if(--R.GAS > 0) {
$z29222923 = $f29282929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29282929,
"from":L[232]});
}
} catch($e29202921) {
if(R.isCont($e29202921)) {
var $ss29242925 = {"from":L[232],
"go":function(anf_begin_app_dropped23082931) {
return $Hanf_begin_app_dropped26482932(anf_begin_app_dropped23082931,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e29202921.stack[R.EXN_STACKHEIGHT++] = $ss29242925;
}
if(R.isPyretException($e29202921)) {
$e29202921.pyretStack.push(L[232]);
}
throw $e29202921;
}
var $ret29262927 = $Hanf_begin_app_dropped26482932($z29222923,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret29262927;
};
var $Hanf_begin_app_dropped26482932 = function(anf_begin_app_dropped23082931,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13792943 = G(builtins15,"current-checker",L[236]);
var $z29352936 = D;
var $f29412942 = function(_) {
return R.isFunction(anf_fun13792943)?anf_fun13792943.app():R.ffi.throwNonFunApp(L[236],anf_fun13792943,[]);
};
try {
if(--R.GAS > 0) {
$z29352936 = $f29412942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29412942,
"from":L[236]});
}
} catch($e29332934) {
if(R.isCont($e29332934)) {
var $ss29372938 = {"from":L[236],
"go":function(anf_bracket13802944) {
return $Hanf_bracket26472945(anf_bracket13802944,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e29332934.stack[R.EXN_STACKHEIGHT++] = $ss29372938;
}
if(R.isPyretException($e29332934)) {
$e29332934.pyretStack.push(L[236]);
}
throw $e29332934;
}
var $ret29392940 = $Hanf_bracket26472945($z29352936,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret29392940;
};
var $Hanf_bracket26472945 = function(anf_bracket13802944,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13812958 = G(anf_bracket13802944,"check-is",L[236]);
var anf_fun13822956 = G(list2776,"make",L[237]);
var $z29482949 = D;
var $f29542955 = function(_) {
return R.isFunction(anf_fun13822956)?anf_fun13822956.app([("-f")]):R.ffi.throwNonFunApp(L[237],anf_fun13822956,[[("-f")]]);
};
try {
if(--R.GAS > 0) {
$z29482949 = $f29542955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29542955,
"from":L[237]});
}
} catch($e29462947) {
if(R.isCont($e29462947)) {
var $ss29502951 = {"from":L[237],
"go":function(anf_arg13832957) {
return $Hanf_arg26462959(anf_arg13832957,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e29462947.stack[R.EXN_STACKHEIGHT++] = $ss29502951;
}
if(R.isPyretException($e29462947)) {
$e29462947.pyretStack.push(L[237]);
}
throw $e29462947;
}
var $ret29522953 = $Hanf_arg26462959($z29482949,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret29522953;
};
var $Hanf_arg26462959 = function(anf_arg13832957,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z29622963 = D;
var $f29682969 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13832957):R.ffi.throwNonFunApp(L[238],parse_DASH_args129167.$var,[once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13832957]);
};
try {
if(--R.GAS > 0) {
$z29622963 = $f29682969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29682969,
"from":L[238]});
}
} catch($e29602961) {
if(R.isCont($e29602961)) {
var $ss29642965 = {"from":L[238],
"go":function(anf_arg13842970) {
return $Hanf_arg26452971(anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e29602961.stack[R.EXN_STACKHEIGHT++] = $ss29642965;
}
if(R.isPyretException($e29602961)) {
$e29602961.pyretStack.push(L[238]);
}
throw $e29602961;
}
var $ret29662967 = $Hanf_arg26452971($z29622963,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret29662967;
};
var $Hanf_arg26452971 = function(anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13852982 = G(list2776,"make",L[239]);
var $z29742975 = D;
var $f29802981 = function(_) {
return R.isFunction(anf_fun13852982)?anf_fun13852982.app([("foo"),(42)]):R.ffi.throwNonFunApp(L[239],anf_fun13852982,[[("foo"),(42)]]);
};
try {
if(--R.GAS > 0) {
$z29742975 = $f29802981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29802981,
"from":L[239]});
}
} catch($e29722973) {
if(R.isCont($e29722973)) {
var $ss29762977 = {"from":L[239],
"go":function(anf_arg13862983) {
return $Hanf_arg26442984(anf_arg13862983,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e29722973.stack[R.EXN_STACKHEIGHT++] = $ss29762977;
}
if(R.isPyretException($e29722973)) {
$e29722973.pyretStack.push(L[239]);
}
throw $e29722973;
}
var $ret29782979 = $Hanf_arg26442984($z29742975,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret29782979;
};
var $Hanf_arg26442984 = function(anf_arg13862983,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z29872988 = D;
var $f29932994 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg13862983):R.ffi.throwNonFunApp(L[240],dict131171.$var,[anf_arg13862983]);
};
try {
if(--R.GAS > 0) {
$z29872988 = $f29932994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29932994,
"from":L[240]});
}
} catch($e29852986) {
if(R.isCont($e29852986)) {
var $ss29892990 = {"from":L[240],
"go":function(anf_arg13872995) {
return $Hanf_arg26432996(anf_arg13872995,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e29852986.stack[R.EXN_STACKHEIGHT++] = $ss29892990;
}
if(R.isPyretException($e29852986)) {
$e29852986.pyretStack.push(L[240]);
}
throw $e29852986;
}
var $ret29912992 = $Hanf_arg26432996($z29872988,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret29912992;
};
var $Hanf_arg26432996 = function(anf_arg13872995,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13883007 = G(list2776,"make",L[241]);
var $z29993000 = D;
var $f30053006 = function(_) {
return R.isFunction(anf_fun13883007)?anf_fun13883007.app([]):R.ffi.throwNonFunApp(L[241],anf_fun13883007,[[]]);
};
try {
if(--R.GAS > 0) {
$z29993000 = $f30053006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30053006,
"from":L[241]});
}
} catch($e29972998) {
if(R.isCont($e29972998)) {
var $ss30013002 = {"from":L[241],
"go":function(anf_arg13893008) {
return $Hanf_arg26423009(anf_arg13893008,anf_arg13842970,anf_arg13872995,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e29972998.stack[R.EXN_STACKHEIGHT++] = $ss30013002;
}
if(R.isPyretException($e29972998)) {
$e29972998.pyretStack.push(L[241]);
}
throw $e29972998;
}
var $ret30033004 = $Hanf_arg26423009($z29993000,anf_arg13842970,anf_arg13872995,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret30033004;
};
var $Hanf_arg26423009 = function(anf_arg13893008,anf_arg13842970,anf_arg13872995,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z30123013 = D;
var $f30183019 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg13872995,anf_arg13893008):R.ffi.throwNonFunApp(L[242],success100109.$var,[anf_arg13872995,anf_arg13893008]);
};
try {
if(--R.GAS > 0) {
$z30123013 = $f30183019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30183019,
"from":L[242]});
}
} catch($e30103011) {
if(R.isCont($e30103011)) {
var $ss30143015 = {"from":L[242],
"go":function(anf_arg13903020) {
return $Hanf_arg26413021(anf_arg13903020,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e30103011.stack[R.EXN_STACKHEIGHT++] = $ss30143015;
}
if(R.isPyretException($e30103011)) {
$e30103011.pyretStack.push(L[242]);
}
throw $e30103011;
}
var $ret30163017 = $Hanf_arg26413021($z30123013,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret30163017;
};
var $Hanf_arg26413021 = function(anf_arg13903020,anf_arg13842970,anf_fun13812958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg13913032 = R.makeSrcloc(L[236]);
var $z30243025 = D;
var $f30303031 = function(_) {
return R.isFunction(anf_fun13812958)?anf_fun13812958.app(("parse-args(once-required-equals-default, [list: \"-f\"]) is\n  success(dict([list: \"foo\", 42]), [list: ])"),anf_arg13842970,anf_arg13903020,anf_arg13913032):R.ffi.throwNonFunApp(L[236],anf_fun13812958,[("parse-args(once-required-equals-default, [list: \"-f\"]) is\n  success(dict([list: \"foo\", 42]), [list: ])"),anf_arg13842970,anf_arg13903020,anf_arg13913032]);
};
try {
if(--R.GAS > 0) {
$z30243025 = $f30303031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30303031,
"from":L[236]});
}
} catch($e30223023) {
if(R.isCont($e30223023)) {
var $ss30263027 = {"from":L[236],
"go":function(anf_begin_app_dropped23093033) {
return $Hanf_begin_app_dropped26403034(anf_begin_app_dropped23093033,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e30223023.stack[R.EXN_STACKHEIGHT++] = $ss30263027;
}
if(R.isPyretException($e30223023)) {
$e30223023.pyretStack.push(L[236]);
}
throw $e30223023;
}
var $ret30283029 = $Hanf_begin_app_dropped26403034($z30243025,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret30283029;
};
var $Hanf_begin_app_dropped26403034 = function(anf_begin_app_dropped23093033,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13923045 = G(builtins15,"current-checker",L[243]);
var $z30373038 = D;
var $f30433044 = function(_) {
return R.isFunction(anf_fun13923045)?anf_fun13923045.app():R.ffi.throwNonFunApp(L[243],anf_fun13923045,[]);
};
try {
if(--R.GAS > 0) {
$z30373038 = $f30433044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30433044,
"from":L[243]});
}
} catch($e30353036) {
if(R.isCont($e30353036)) {
var $ss30393040 = {"from":L[243],
"go":function(anf_bracket13933046) {
return $Hanf_bracket26393047(anf_bracket13933046,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e30353036.stack[R.EXN_STACKHEIGHT++] = $ss30393040;
}
if(R.isPyretException($e30353036)) {
$e30353036.pyretStack.push(L[243]);
}
throw $e30353036;
}
var $ret30413042 = $Hanf_bracket26393047($z30373038,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret30413042;
};
var $Hanf_bracket26393047 = function(anf_bracket13933046,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13943060 = G(anf_bracket13933046,"check-is",L[243]);
var anf_fun13953058 = G(list2776,"make",L[244]);
var $z30503051 = D;
var $f30563057 = function(_) {
return R.isFunction(anf_fun13953058)?anf_fun13953058.app([("--foo")]):R.ffi.throwNonFunApp(L[244],anf_fun13953058,[[("--foo")]]);
};
try {
if(--R.GAS > 0) {
$z30503051 = $f30563057();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30563057,
"from":L[244]});
}
} catch($e30483049) {
if(R.isCont($e30483049)) {
var $ss30523053 = {"from":L[244],
"go":function(anf_arg13963059) {
return $Hanf_arg26383061(anf_arg13963059,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e30483049.stack[R.EXN_STACKHEIGHT++] = $ss30523053;
}
if(R.isPyretException($e30483049)) {
$e30483049.pyretStack.push(L[244]);
}
throw $e30483049;
}
var $ret30543055 = $Hanf_arg26383061($z30503051,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret30543055;
};
var $Hanf_arg26383061 = function(anf_arg13963059,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z30643065 = D;
var $f30703071 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13963059):R.ffi.throwNonFunApp(L[245],parse_DASH_args129167.$var,[once_DASH_required_DASH_equals_DASH_default3422714,anf_arg13963059]);
};
try {
if(--R.GAS > 0) {
$z30643065 = $f30703071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30703071,
"from":L[245]});
}
} catch($e30623063) {
if(R.isCont($e30623063)) {
var $ss30663067 = {"from":L[245],
"go":function(anf_arg13973072) {
return $Hanf_arg26373073(anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e30623063.stack[R.EXN_STACKHEIGHT++] = $ss30663067;
}
if(R.isPyretException($e30623063)) {
$e30623063.pyretStack.push(L[245]);
}
throw $e30623063;
}
var $ret30683069 = $Hanf_arg26373073($z30643065,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret30683069;
};
var $Hanf_arg26373073 = function(anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun13983084 = G(list2776,"make",L[246]);
var $z30763077 = D;
var $f30823083 = function(_) {
return R.isFunction(anf_fun13983084)?anf_fun13983084.app([("foo"),(42)]):R.ffi.throwNonFunApp(L[246],anf_fun13983084,[[("foo"),(42)]]);
};
try {
if(--R.GAS > 0) {
$z30763077 = $f30823083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30823083,
"from":L[246]});
}
} catch($e30743075) {
if(R.isCont($e30743075)) {
var $ss30783079 = {"from":L[246],
"go":function(anf_arg13993085) {
return $Hanf_arg26363086(anf_arg13993085,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e30743075.stack[R.EXN_STACKHEIGHT++] = $ss30783079;
}
if(R.isPyretException($e30743075)) {
$e30743075.pyretStack.push(L[246]);
}
throw $e30743075;
}
var $ret30803081 = $Hanf_arg26363086($z30763077,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret30803081;
};
var $Hanf_arg26363086 = function(anf_arg13993085,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z30893090 = D;
var $f30953096 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg13993085):R.ffi.throwNonFunApp(L[247],dict131171.$var,[anf_arg13993085]);
};
try {
if(--R.GAS > 0) {
$z30893090 = $f30953096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30953096,
"from":L[247]});
}
} catch($e30873088) {
if(R.isCont($e30873088)) {
var $ss30913092 = {"from":L[247],
"go":function(anf_arg14003097) {
return $Hanf_arg26353098(anf_arg14003097,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e30873088.stack[R.EXN_STACKHEIGHT++] = $ss30913092;
}
if(R.isPyretException($e30873088)) {
$e30873088.pyretStack.push(L[247]);
}
throw $e30873088;
}
var $ret30933094 = $Hanf_arg26353098($z30893090,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret30933094;
};
var $Hanf_arg26353098 = function(anf_arg14003097,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14013109 = G(list2776,"make",L[248]);
var $z31013102 = D;
var $f31073108 = function(_) {
return R.isFunction(anf_fun14013109)?anf_fun14013109.app([]):R.ffi.throwNonFunApp(L[248],anf_fun14013109,[[]]);
};
try {
if(--R.GAS > 0) {
$z31013102 = $f31073108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31073108,
"from":L[248]});
}
} catch($e30993100) {
if(R.isCont($e30993100)) {
var $ss31033104 = {"from":L[248],
"go":function(anf_arg14023110) {
return $Hanf_arg26343111(anf_arg14023110,anf_arg13973072,anf_arg14003097,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e30993100.stack[R.EXN_STACKHEIGHT++] = $ss31033104;
}
if(R.isPyretException($e30993100)) {
$e30993100.pyretStack.push(L[248]);
}
throw $e30993100;
}
var $ret31053106 = $Hanf_arg26343111($z31013102,anf_arg13973072,anf_arg14003097,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret31053106;
};
var $Hanf_arg26343111 = function(anf_arg14023110,anf_arg13973072,anf_arg14003097,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z31143115 = D;
var $f31203121 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg14003097,anf_arg14023110):R.ffi.throwNonFunApp(L[249],success100109.$var,[anf_arg14003097,anf_arg14023110]);
};
try {
if(--R.GAS > 0) {
$z31143115 = $f31203121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31203121,
"from":L[249]});
}
} catch($e31123113) {
if(R.isCont($e31123113)) {
var $ss31163117 = {"from":L[249],
"go":function(anf_arg14033122) {
return $Hanf_arg26333123(anf_arg14033122,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e31123113.stack[R.EXN_STACKHEIGHT++] = $ss31163117;
}
if(R.isPyretException($e31123113)) {
$e31123113.pyretStack.push(L[249]);
}
throw $e31123113;
}
var $ret31183119 = $Hanf_arg26333123($z31143115,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret31183119;
};
var $Hanf_arg26333123 = function(anf_arg14033122,anf_arg13973072,anf_fun13943060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg14043134 = R.makeSrcloc(L[243]);
var $z31263127 = D;
var $f31323133 = function(_) {
return R.isFunction(anf_fun13943060)?anf_fun13943060.app(("parse-args(once-required-equals-default, [list: \"--foo\"]) is\n  success(dict([list: \"foo\", 42]), [list: ])"),anf_arg13973072,anf_arg14033122,anf_arg14043134):R.ffi.throwNonFunApp(L[243],anf_fun13943060,[("parse-args(once-required-equals-default, [list: \"--foo\"]) is\n  success(dict([list: \"foo\", 42]), [list: ])"),anf_arg13973072,anf_arg14033122,anf_arg14043134]);
};
try {
if(--R.GAS > 0) {
$z31263127 = $f31323133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31323133,
"from":L[243]});
}
} catch($e31243125) {
if(R.isCont($e31243125)) {
var $ss31283129 = {"from":L[243],
"go":function(anf_begin_app_dropped23103135) {
return $Hanf_begin_app_dropped26323136(anf_begin_app_dropped23103135,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e31243125.stack[R.EXN_STACKHEIGHT++] = $ss31283129;
}
if(R.isPyretException($e31243125)) {
$e31243125.pyretStack.push(L[243]);
}
throw $e31243125;
}
var $ret31303131 = $Hanf_begin_app_dropped26323136($z31263127,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret31303131;
};
var $Hanf_begin_app_dropped26323136 = function(anf_begin_app_dropped23103135,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14053147 = G(builtins15,"current-checker",L[250]);
var $z31393140 = D;
var $f31453146 = function(_) {
return R.isFunction(anf_fun14053147)?anf_fun14053147.app():R.ffi.throwNonFunApp(L[250],anf_fun14053147,[]);
};
try {
if(--R.GAS > 0) {
$z31393140 = $f31453146();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31453146,
"from":L[250]});
}
} catch($e31373138) {
if(R.isCont($e31373138)) {
var $ss31413142 = {"from":L[250],
"go":function(anf_bracket14063148) {
return $Hanf_bracket26313149(anf_bracket14063148,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e31373138.stack[R.EXN_STACKHEIGHT++] = $ss31413142;
}
if(R.isPyretException($e31373138)) {
$e31373138.pyretStack.push(L[250]);
}
throw $e31373138;
}
var $ret31433144 = $Hanf_bracket26313149($z31393140,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret31433144;
};
var $Hanf_bracket26313149 = function(anf_bracket14063148,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14073162 = G(anf_bracket14063148,"check-is",L[250]);
var anf_fun14083160 = G(list2776,"make",L[251]);
var $z31523153 = D;
var $f31583159 = function(_) {
return R.isFunction(anf_fun14083160)?anf_fun14083160.app([("--foo"),("-bar")]):R.ffi.throwNonFunApp(L[251],anf_fun14083160,[[("--foo"),("-bar")]]);
};
try {
if(--R.GAS > 0) {
$z31523153 = $f31583159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31583159,
"from":L[251]});
}
} catch($e31503151) {
if(R.isCont($e31503151)) {
var $ss31543155 = {"from":L[251],
"go":function(anf_arg14093161) {
return $Hanf_arg26303163(anf_arg14093161,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e31503151.stack[R.EXN_STACKHEIGHT++] = $ss31543155;
}
if(R.isPyretException($e31503151)) {
$e31503151.pyretStack.push(L[251]);
}
throw $e31503151;
}
var $ret31563157 = $Hanf_arg26303163($z31523153,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret31563157;
};
var $Hanf_arg26303163 = function(anf_arg14093161,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z31663167 = D;
var $f31723173 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_equals_DASH_default3422714,anf_arg14093161):R.ffi.throwNonFunApp(L[252],parse_DASH_args129167.$var,[once_DASH_required_DASH_equals_DASH_default3422714,anf_arg14093161]);
};
try {
if(--R.GAS > 0) {
$z31663167 = $f31723173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31723173,
"from":L[252]});
}
} catch($e31643165) {
if(R.isCont($e31643165)) {
var $ss31683169 = {"from":L[252],
"go":function(anf_arg14103174) {
return $Hanf_arg26293175(anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e31643165.stack[R.EXN_STACKHEIGHT++] = $ss31683169;
}
if(R.isPyretException($e31643165)) {
$e31643165.pyretStack.push(L[252]);
}
throw $e31643165;
}
var $ret31703171 = $Hanf_arg26293175($z31663167,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret31703171;
};
var $Hanf_arg26293175 = function(anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14113186 = G(list2776,"make",L[253]);
var $z31783179 = D;
var $f31843185 = function(_) {
return R.isFunction(anf_fun14113186)?anf_fun14113186.app([("foo"),(42),("bar"),(true)]):R.ffi.throwNonFunApp(L[253],anf_fun14113186,[[("foo"),(42),("bar"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z31783179 = $f31843185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31843185,
"from":L[253]});
}
} catch($e31763177) {
if(R.isCont($e31763177)) {
var $ss31803181 = {"from":L[253],
"go":function(anf_arg14123187) {
return $Hanf_arg26283188(anf_arg14123187,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e31763177.stack[R.EXN_STACKHEIGHT++] = $ss31803181;
}
if(R.isPyretException($e31763177)) {
$e31763177.pyretStack.push(L[253]);
}
throw $e31763177;
}
var $ret31823183 = $Hanf_arg26283188($z31783179,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret31823183;
};
var $Hanf_arg26283188 = function(anf_arg14123187,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z31913192 = D;
var $f31973198 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg14123187):R.ffi.throwNonFunApp(L[254],dict131171.$var,[anf_arg14123187]);
};
try {
if(--R.GAS > 0) {
$z31913192 = $f31973198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31973198,
"from":L[254]});
}
} catch($e31893190) {
if(R.isCont($e31893190)) {
var $ss31933194 = {"from":L[254],
"go":function(anf_arg14133199) {
return $Hanf_arg26273200(anf_arg14133199,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e31893190.stack[R.EXN_STACKHEIGHT++] = $ss31933194;
}
if(R.isPyretException($e31893190)) {
$e31893190.pyretStack.push(L[254]);
}
throw $e31893190;
}
var $ret31953196 = $Hanf_arg26273200($z31913192,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret31953196;
};
var $Hanf_arg26273200 = function(anf_arg14133199,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14143211 = G(list2776,"make",L[255]);
var $z32033204 = D;
var $f32093210 = function(_) {
return R.isFunction(anf_fun14143211)?anf_fun14143211.app([]):R.ffi.throwNonFunApp(L[255],anf_fun14143211,[[]]);
};
try {
if(--R.GAS > 0) {
$z32033204 = $f32093210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32093210,
"from":L[255]});
}
} catch($e32013202) {
if(R.isCont($e32013202)) {
var $ss32053206 = {"from":L[255],
"go":function(anf_arg14153212) {
return $Hanf_arg26263213(anf_arg14153212,anf_arg14103174,anf_arg14133199,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e32013202.stack[R.EXN_STACKHEIGHT++] = $ss32053206;
}
if(R.isPyretException($e32013202)) {
$e32013202.pyretStack.push(L[255]);
}
throw $e32013202;
}
var $ret32073208 = $Hanf_arg26263213($z32033204,anf_arg14103174,anf_arg14133199,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret32073208;
};
var $Hanf_arg26263213 = function(anf_arg14153212,anf_arg14103174,anf_arg14133199,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z32163217 = D;
var $f32223223 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg14133199,anf_arg14153212):R.ffi.throwNonFunApp(L[256],success100109.$var,[anf_arg14133199,anf_arg14153212]);
};
try {
if(--R.GAS > 0) {
$z32163217 = $f32223223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32223223,
"from":L[256]});
}
} catch($e32143215) {
if(R.isCont($e32143215)) {
var $ss32183219 = {"from":L[256],
"go":function(anf_arg14163224) {
return $Hanf_arg26253225(anf_arg14163224,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e32143215.stack[R.EXN_STACKHEIGHT++] = $ss32183219;
}
if(R.isPyretException($e32143215)) {
$e32143215.pyretStack.push(L[256]);
}
throw $e32143215;
}
var $ret32203221 = $Hanf_arg26253225($z32163217,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret32203221;
};
var $Hanf_arg26253225 = function(anf_arg14163224,anf_arg14103174,anf_fun14073162,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg14173236 = R.makeSrcloc(L[250]);
var $z32283229 = D;
var $f32343235 = function(_) {
return R.isFunction(anf_fun14073162)?anf_fun14073162.app(("parse-args(once-required-equals-default, [list: \"--foo\", \"-bar\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg14103174,anf_arg14163224,anf_arg14173236):R.ffi.throwNonFunApp(L[250],anf_fun14073162,[("parse-args(once-required-equals-default, [list: \"--foo\", \"-bar\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg14103174,anf_arg14163224,anf_arg14173236]);
};
try {
if(--R.GAS > 0) {
$z32283229 = $f32343235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32343235,
"from":L[250]});
}
} catch($e32263227) {
if(R.isCont($e32263227)) {
var $ss32303231 = {"from":L[250],
"go":function(anf_begin_app_dropped23113237) {
return $Hanf_begin_app_dropped26243238(anf_begin_app_dropped23113237,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e32263227.stack[R.EXN_STACKHEIGHT++] = $ss32303231;
}
if(R.isPyretException($e32263227)) {
$e32263227.pyretStack.push(L[250]);
}
throw $e32263227;
}
var $ret32323233 = $Hanf_begin_app_dropped26243238($z32283229,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret32323233;
};
var $Hanf_begin_app_dropped26243238 = function(anf_begin_app_dropped23113237,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14183249 = G(builtins15,"current-checker",L[257]);
var $z32413242 = D;
var $f32473248 = function(_) {
return R.isFunction(anf_fun14183249)?anf_fun14183249.app():R.ffi.throwNonFunApp(L[257],anf_fun14183249,[]);
};
try {
if(--R.GAS > 0) {
$z32413242 = $f32473248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32473248,
"from":L[257]});
}
} catch($e32393240) {
if(R.isCont($e32393240)) {
var $ss32433244 = {"from":L[257],
"go":function(anf_bracket14193250) {
return $Hanf_bracket26233251(anf_bracket14193250,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e32393240.stack[R.EXN_STACKHEIGHT++] = $ss32433244;
}
if(R.isPyretException($e32393240)) {
$e32393240.pyretStack.push(L[257]);
}
throw $e32393240;
}
var $ret32453246 = $Hanf_bracket26233251($z32413242,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret32453246;
};
var $Hanf_bracket26233251 = function(anf_bracket14193250,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14203264 = G(anf_bracket14193250,"check-is",L[257]);
var anf_fun14213262 = G(list2776,"make",L[258]);
var $z32543255 = D;
var $f32603261 = function(_) {
return R.isFunction(anf_fun14213262)?anf_fun14213262.app([("-bar"),("--foo")]):R.ffi.throwNonFunApp(L[258],anf_fun14213262,[[("-bar"),("--foo")]]);
};
try {
if(--R.GAS > 0) {
$z32543255 = $f32603261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32603261,
"from":L[258]});
}
} catch($e32523253) {
if(R.isCont($e32523253)) {
var $ss32563257 = {"from":L[258],
"go":function(anf_arg14223263) {
return $Hanf_arg26223265(anf_arg14223263,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e32523253.stack[R.EXN_STACKHEIGHT++] = $ss32563257;
}
if(R.isPyretException($e32523253)) {
$e32523253.pyretStack.push(L[258]);
}
throw $e32523253;
}
var $ret32583259 = $Hanf_arg26223265($z32543255,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret32583259;
};
var $Hanf_arg26223265 = function(anf_arg14223263,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z32683269 = D;
var $f32743275 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_equals_DASH_default3422714,anf_arg14223263):R.ffi.throwNonFunApp(L[259],parse_DASH_args129167.$var,[once_DASH_required_DASH_equals_DASH_default3422714,anf_arg14223263]);
};
try {
if(--R.GAS > 0) {
$z32683269 = $f32743275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32743275,
"from":L[259]});
}
} catch($e32663267) {
if(R.isCont($e32663267)) {
var $ss32703271 = {"from":L[259],
"go":function(anf_arg14233276) {
return $Hanf_arg26213277(anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e32663267.stack[R.EXN_STACKHEIGHT++] = $ss32703271;
}
if(R.isPyretException($e32663267)) {
$e32663267.pyretStack.push(L[259]);
}
throw $e32663267;
}
var $ret32723273 = $Hanf_arg26213277($z32683269,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret32723273;
};
var $Hanf_arg26213277 = function(anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14243288 = G(list2776,"make",L[260]);
var $z32803281 = D;
var $f32863287 = function(_) {
return R.isFunction(anf_fun14243288)?anf_fun14243288.app([("foo"),(42),("bar"),(true)]):R.ffi.throwNonFunApp(L[260],anf_fun14243288,[[("foo"),(42),("bar"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z32803281 = $f32863287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32863287,
"from":L[260]});
}
} catch($e32783279) {
if(R.isCont($e32783279)) {
var $ss32823283 = {"from":L[260],
"go":function(anf_arg14253289) {
return $Hanf_arg26203290(anf_arg14253289,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e32783279.stack[R.EXN_STACKHEIGHT++] = $ss32823283;
}
if(R.isPyretException($e32783279)) {
$e32783279.pyretStack.push(L[260]);
}
throw $e32783279;
}
var $ret32843285 = $Hanf_arg26203290($z32803281,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret32843285;
};
var $Hanf_arg26203290 = function(anf_arg14253289,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z32933294 = D;
var $f32993300 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg14253289):R.ffi.throwNonFunApp(L[261],dict131171.$var,[anf_arg14253289]);
};
try {
if(--R.GAS > 0) {
$z32933294 = $f32993300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32993300,
"from":L[261]});
}
} catch($e32913292) {
if(R.isCont($e32913292)) {
var $ss32953296 = {"from":L[261],
"go":function(anf_arg14263301) {
return $Hanf_arg26193302(anf_arg14263301,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e32913292.stack[R.EXN_STACKHEIGHT++] = $ss32953296;
}
if(R.isPyretException($e32913292)) {
$e32913292.pyretStack.push(L[261]);
}
throw $e32913292;
}
var $ret32973298 = $Hanf_arg26193302($z32933294,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret32973298;
};
var $Hanf_arg26193302 = function(anf_arg14263301,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14273313 = G(list2776,"make",L[262]);
var $z33053306 = D;
var $f33113312 = function(_) {
return R.isFunction(anf_fun14273313)?anf_fun14273313.app([]):R.ffi.throwNonFunApp(L[262],anf_fun14273313,[[]]);
};
try {
if(--R.GAS > 0) {
$z33053306 = $f33113312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33113312,
"from":L[262]});
}
} catch($e33033304) {
if(R.isCont($e33033304)) {
var $ss33073308 = {"from":L[262],
"go":function(anf_arg14283314) {
return $Hanf_arg26183315(anf_arg14283314,anf_arg14233276,anf_arg14263301,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e33033304.stack[R.EXN_STACKHEIGHT++] = $ss33073308;
}
if(R.isPyretException($e33033304)) {
$e33033304.pyretStack.push(L[262]);
}
throw $e33033304;
}
var $ret33093310 = $Hanf_arg26183315($z33053306,anf_arg14233276,anf_arg14263301,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret33093310;
};
var $Hanf_arg26183315 = function(anf_arg14283314,anf_arg14233276,anf_arg14263301,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z33183319 = D;
var $f33243325 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg14263301,anf_arg14283314):R.ffi.throwNonFunApp(L[263],success100109.$var,[anf_arg14263301,anf_arg14283314]);
};
try {
if(--R.GAS > 0) {
$z33183319 = $f33243325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33243325,
"from":L[263]});
}
} catch($e33163317) {
if(R.isCont($e33163317)) {
var $ss33203321 = {"from":L[263],
"go":function(anf_arg14293326) {
return $Hanf_arg26173327(anf_arg14293326,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e33163317.stack[R.EXN_STACKHEIGHT++] = $ss33203321;
}
if(R.isPyretException($e33163317)) {
$e33163317.pyretStack.push(L[263]);
}
throw $e33163317;
}
var $ret33223323 = $Hanf_arg26173327($z33183319,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret33223323;
};
var $Hanf_arg26173327 = function(anf_arg14293326,anf_arg14233276,anf_fun14203264,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg14303338 = R.makeSrcloc(L[257]);
var $z33303331 = D;
var $f33363337 = function(_) {
return R.isFunction(anf_fun14203264)?anf_fun14203264.app(("parse-args(once-required-equals-default, [list: \"-bar\", \"--foo\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg14233276,anf_arg14293326,anf_arg14303338):R.ffi.throwNonFunApp(L[257],anf_fun14203264,[("parse-args(once-required-equals-default, [list: \"-bar\", \"--foo\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg14233276,anf_arg14293326,anf_arg14303338]);
};
try {
if(--R.GAS > 0) {
$z33303331 = $f33363337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33363337,
"from":L[257]});
}
} catch($e33283329) {
if(R.isCont($e33283329)) {
var $ss33323333 = {"from":L[257],
"go":function(anf_begin_app_dropped23123339) {
return $Hanf_begin_app_dropped26163340(anf_begin_app_dropped23123339,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e33283329.stack[R.EXN_STACKHEIGHT++] = $ss33323333;
}
if(R.isPyretException($e33283329)) {
$e33283329.pyretStack.push(L[257]);
}
throw $e33283329;
}
var $ret33343335 = $Hanf_begin_app_dropped26163340($z33303331,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret33343335;
};
var $Hanf_begin_app_dropped26163340 = function(anf_begin_app_dropped23123339,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14313351 = G(builtins15,"current-checker",L[264]);
var $z33433344 = D;
var $f33493350 = function(_) {
return R.isFunction(anf_fun14313351)?anf_fun14313351.app():R.ffi.throwNonFunApp(L[264],anf_fun14313351,[]);
};
try {
if(--R.GAS > 0) {
$z33433344 = $f33493350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33493350,
"from":L[264]});
}
} catch($e33413342) {
if(R.isCont($e33413342)) {
var $ss33453346 = {"from":L[264],
"go":function(anf_bracket14323352) {
return $Hanf_bracket26153353(anf_bracket14323352,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e33413342.stack[R.EXN_STACKHEIGHT++] = $ss33453346;
}
if(R.isPyretException($e33413342)) {
$e33413342.pyretStack.push(L[264]);
}
throw $e33413342;
}
var $ret33473348 = $Hanf_bracket26153353($z33433344,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret33473348;
};
var $Hanf_bracket26153353 = function(anf_bracket14323352,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14333366 = G(anf_bracket14323352,"check-is",L[264]);
var anf_fun14343364 = G(list2776,"make",L[265]);
var $z33563357 = D;
var $f33623363 = function(_) {
return R.isFunction(anf_fun14343364)?anf_fun14343364.app([("-bar"),("-f")]):R.ffi.throwNonFunApp(L[265],anf_fun14343364,[[("-bar"),("-f")]]);
};
try {
if(--R.GAS > 0) {
$z33563357 = $f33623363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33623363,
"from":L[265]});
}
} catch($e33543355) {
if(R.isCont($e33543355)) {
var $ss33583359 = {"from":L[265],
"go":function(anf_arg14353365) {
return $Hanf_arg26143367(anf_arg14353365,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e33543355.stack[R.EXN_STACKHEIGHT++] = $ss33583359;
}
if(R.isPyretException($e33543355)) {
$e33543355.pyretStack.push(L[265]);
}
throw $e33543355;
}
var $ret33603361 = $Hanf_arg26143367($z33563357,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret33603361;
};
var $Hanf_arg26143367 = function(anf_arg14353365,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_equals_DASH_default3422714,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z33703371 = D;
var $f33763377 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_equals_DASH_default3422714,anf_arg14353365):R.ffi.throwNonFunApp(L[266],parse_DASH_args129167.$var,[once_DASH_required_DASH_equals_DASH_default3422714,anf_arg14353365]);
};
try {
if(--R.GAS > 0) {
$z33703371 = $f33763377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33763377,
"from":L[266]});
}
} catch($e33683369) {
if(R.isCont($e33683369)) {
var $ss33723373 = {"from":L[266],
"go":function(anf_arg14363378) {
return $Hanf_arg26133379(anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e33683369.stack[R.EXN_STACKHEIGHT++] = $ss33723373;
}
if(R.isPyretException($e33683369)) {
$e33683369.pyretStack.push(L[266]);
}
throw $e33683369;
}
var $ret33743375 = $Hanf_arg26133379($z33703371,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret33743375;
};
var $Hanf_arg26133379 = function(anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14373390 = G(list2776,"make",L[267]);
var $z33823383 = D;
var $f33883389 = function(_) {
return R.isFunction(anf_fun14373390)?anf_fun14373390.app([("foo"),(42),("bar"),(true)]):R.ffi.throwNonFunApp(L[267],anf_fun14373390,[[("foo"),(42),("bar"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z33823383 = $f33883389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33883389,
"from":L[267]});
}
} catch($e33803381) {
if(R.isCont($e33803381)) {
var $ss33843385 = {"from":L[267],
"go":function(anf_arg14383391) {
return $Hanf_arg26123392(anf_arg14383391,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e33803381.stack[R.EXN_STACKHEIGHT++] = $ss33843385;
}
if(R.isPyretException($e33803381)) {
$e33803381.pyretStack.push(L[267]);
}
throw $e33803381;
}
var $ret33863387 = $Hanf_arg26123392($z33823383,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret33863387;
};
var $Hanf_arg26123392 = function(anf_arg14383391,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z33953396 = D;
var $f34013402 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg14383391):R.ffi.throwNonFunApp(L[268],dict131171.$var,[anf_arg14383391]);
};
try {
if(--R.GAS > 0) {
$z33953396 = $f34013402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34013402,
"from":L[268]});
}
} catch($e33933394) {
if(R.isCont($e33933394)) {
var $ss33973398 = {"from":L[268],
"go":function(anf_arg14393403) {
return $Hanf_arg26113404(anf_arg14393403,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e33933394.stack[R.EXN_STACKHEIGHT++] = $ss33973398;
}
if(R.isPyretException($e33933394)) {
$e33933394.pyretStack.push(L[268]);
}
throw $e33933394;
}
var $ret33993400 = $Hanf_arg26113404($z33953396,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret33993400;
};
var $Hanf_arg26113404 = function(anf_arg14393403,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14403415 = G(list2776,"make",L[269]);
var $z34073408 = D;
var $f34133414 = function(_) {
return R.isFunction(anf_fun14403415)?anf_fun14403415.app([]):R.ffi.throwNonFunApp(L[269],anf_fun14403415,[[]]);
};
try {
if(--R.GAS > 0) {
$z34073408 = $f34133414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34133414,
"from":L[269]});
}
} catch($e34053406) {
if(R.isCont($e34053406)) {
var $ss34093410 = {"from":L[269],
"go":function(anf_arg14413416) {
return $Hanf_arg26103417(anf_arg14413416,anf_arg14363378,anf_arg14393403,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e34053406.stack[R.EXN_STACKHEIGHT++] = $ss34093410;
}
if(R.isPyretException($e34053406)) {
$e34053406.pyretStack.push(L[269]);
}
throw $e34053406;
}
var $ret34113412 = $Hanf_arg26103417($z34073408,anf_arg14363378,anf_arg14393403,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret34113412;
};
var $Hanf_arg26103417 = function(anf_arg14413416,anf_arg14363378,anf_arg14393403,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z34203421 = D;
var $f34263427 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg14393403,anf_arg14413416):R.ffi.throwNonFunApp(L[270],success100109.$var,[anf_arg14393403,anf_arg14413416]);
};
try {
if(--R.GAS > 0) {
$z34203421 = $f34263427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34263427,
"from":L[270]});
}
} catch($e34183419) {
if(R.isCont($e34183419)) {
var $ss34223423 = {"from":L[270],
"go":function(anf_arg14423428) {
return $Hanf_arg26093429(anf_arg14423428,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e34183419.stack[R.EXN_STACKHEIGHT++] = $ss34223423;
}
if(R.isPyretException($e34183419)) {
$e34183419.pyretStack.push(L[270]);
}
throw $e34183419;
}
var $ret34243425 = $Hanf_arg26093429($z34203421,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret34243425;
};
var $Hanf_arg26093429 = function(anf_arg14423428,anf_arg14363378,anf_fun14333366,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg14433440 = R.makeSrcloc(L[264]);
var $z34323433 = D;
var $f34383439 = function(_) {
return R.isFunction(anf_fun14333366)?anf_fun14333366.app(("parse-args(once-required-equals-default, [list: \"-bar\", \"-f\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg14363378,anf_arg14423428,anf_arg14433440):R.ffi.throwNonFunApp(L[264],anf_fun14333366,[("parse-args(once-required-equals-default, [list: \"-bar\", \"-f\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg14363378,anf_arg14423428,anf_arg14433440]);
};
try {
if(--R.GAS > 0) {
$z34323433 = $f34383439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34383439,
"from":L[264]});
}
} catch($e34303431) {
if(R.isCont($e34303431)) {
var $ss34343435 = {"from":L[264],
"go":function(anf_begin_app_dropped23133441) {
return $Hanf_begin_app_dropped26083442(anf_begin_app_dropped23133441,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e34303431.stack[R.EXN_STACKHEIGHT++] = $ss34343435;
}
if(R.isPyretException($e34303431)) {
$e34303431.pyretStack.push(L[264]);
}
throw $e34303431;
}
var $ret34363437 = $Hanf_begin_app_dropped26083442($z34323433,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret34363437;
};
var $Hanf_begin_app_dropped26083442 = function(anf_begin_app_dropped23133441,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z34453446 = D;
var $f34513452 = function(_) {
return R.isFunction(some6478)?some6478.app(("w")):R.ffi.throwNonFunApp(L[271],some6478,[("w")]);
};
try {
if(--R.GAS > 0) {
$z34453446 = $f34513452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34513452,
"from":L[271]});
}
} catch($e34433444) {
if(R.isCont($e34433444)) {
var $ss34473448 = {"from":L[271],
"go":function(anf_arg14443453) {
return $Hanf_arg26073454(anf_arg14443453,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e34433444.stack[R.EXN_STACKHEIGHT++] = $ss34473448;
}
if(R.isPyretException($e34433444)) {
$e34433444.pyretStack.push(L[271]);
}
throw $e34433444;
}
var $ret34493450 = $Hanf_arg26073454($z34453446,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret34493450;
};
var $Hanf_arg26073454 = function(anf_arg14443453,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z34573458 = D;
var $f34633464 = function(_) {
return R.isFunction(next_DASH_val_DASH_default126161.$var)?next_DASH_val_DASH_default126161.$var.app(read_DASH_number8987.$var,(80),anf_arg14443453,once107123.$var,("Width")):R.ffi.throwNonFunApp(L[272],next_DASH_val_DASH_default126161.$var,[read_DASH_number8987.$var,(80),anf_arg14443453,once107123.$var,("Width")]);
};
try {
if(--R.GAS > 0) {
$z34573458 = $f34633464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34633464,
"from":L[272]});
}
} catch($e34553456) {
if(R.isCont($e34553456)) {
var $ss34593460 = {"from":L[272],
"go":function(anf_obj14453465) {
return $Hanf_obj26063466(anf_obj14453465,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e34553456.stack[R.EXN_STACKHEIGHT++] = $ss34593460;
}
if(R.isPyretException($e34553456)) {
$e34553456.pyretStack.push(L[272]);
}
throw $e34553456;
}
var $ret34613462 = $Hanf_obj26063466($z34573458,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret34613462;
};
var $Hanf_obj26063466 = function(anf_obj14453465,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var once_DASH_optional_DASH_next_DASH_default3433479 = R.makeObject({"width":anf_obj14453465});
var anf_fun14463477 = G(builtins15,"current-checker",L[273]);
var $z34693470 = D;
var $f34753476 = function(_) {
return R.isFunction(anf_fun14463477)?anf_fun14463477.app():R.ffi.throwNonFunApp(L[273],anf_fun14463477,[]);
};
try {
if(--R.GAS > 0) {
$z34693470 = $f34753476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34753476,
"from":L[273]});
}
} catch($e34673468) {
if(R.isCont($e34673468)) {
var $ss34713472 = {"from":L[273],
"go":function(anf_bracket14473478) {
return $Hanf_bracket26053480(anf_bracket14473478,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e34673468.stack[R.EXN_STACKHEIGHT++] = $ss34713472;
}
if(R.isPyretException($e34673468)) {
$e34673468.pyretStack.push(L[273]);
}
throw $e34673468;
}
var $ret34733474 = $Hanf_bracket26053480($z34693470,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret34733474;
};
var $Hanf_bracket26053480 = function(anf_bracket14473478,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14483493 = G(anf_bracket14473478,"check-is",L[273]);
var anf_fun14493491 = G(list2776,"make",L[274]);
var $z34833484 = D;
var $f34893490 = function(_) {
return R.isFunction(anf_fun14493491)?anf_fun14493491.app([("-w"),("foo.txt")]):R.ffi.throwNonFunApp(L[274],anf_fun14493491,[[("-w"),("foo.txt")]]);
};
try {
if(--R.GAS > 0) {
$z34833484 = $f34893490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34893490,
"from":L[274]});
}
} catch($e34813482) {
if(R.isCont($e34813482)) {
var $ss34853486 = {"from":L[274],
"go":function(anf_arg14503492) {
return $Hanf_arg26043494(anf_arg14503492,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e34813482.stack[R.EXN_STACKHEIGHT++] = $ss34853486;
}
if(R.isPyretException($e34813482)) {
$e34813482.pyretStack.push(L[274]);
}
throw $e34813482;
}
var $ret34873488 = $Hanf_arg26043494($z34833484,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret34873488;
};
var $Hanf_arg26043494 = function(anf_arg14503492,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z34973498 = D;
var $f35033504 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_next_DASH_default3433479,anf_arg14503492):R.ffi.throwNonFunApp(L[275],parse_DASH_args129167.$var,[once_DASH_optional_DASH_next_DASH_default3433479,anf_arg14503492]);
};
try {
if(--R.GAS > 0) {
$z34973498 = $f35033504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35033504,
"from":L[275]});
}
} catch($e34953496) {
if(R.isCont($e34953496)) {
var $ss34993500 = {"from":L[275],
"go":function(anf_arg14513505) {
return $Hanf_arg26033506(anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e34953496.stack[R.EXN_STACKHEIGHT++] = $ss34993500;
}
if(R.isPyretException($e34953496)) {
$e34953496.pyretStack.push(L[275]);
}
throw $e34953496;
}
var $ret35013502 = $Hanf_arg26033506($z34973498,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret35013502;
};
var $Hanf_arg26033506 = function(anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14523517 = G(list2776,"make",L[276]);
var $z35093510 = D;
var $f35153516 = function(_) {
return R.isFunction(anf_fun14523517)?anf_fun14523517.app([("width"),(80)]):R.ffi.throwNonFunApp(L[276],anf_fun14523517,[[("width"),(80)]]);
};
try {
if(--R.GAS > 0) {
$z35093510 = $f35153516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35153516,
"from":L[276]});
}
} catch($e35073508) {
if(R.isCont($e35073508)) {
var $ss35113512 = {"from":L[276],
"go":function(anf_arg14533518) {
return $Hanf_arg26023519(anf_arg14533518,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e35073508.stack[R.EXN_STACKHEIGHT++] = $ss35113512;
}
if(R.isPyretException($e35073508)) {
$e35073508.pyretStack.push(L[276]);
}
throw $e35073508;
}
var $ret35133514 = $Hanf_arg26023519($z35093510,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret35133514;
};
var $Hanf_arg26023519 = function(anf_arg14533518,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z35223523 = D;
var $f35283529 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg14533518):R.ffi.throwNonFunApp(L[277],dict131171.$var,[anf_arg14533518]);
};
try {
if(--R.GAS > 0) {
$z35223523 = $f35283529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35283529,
"from":L[277]});
}
} catch($e35203521) {
if(R.isCont($e35203521)) {
var $ss35243525 = {"from":L[277],
"go":function(anf_arg14543530) {
return $Hanf_arg26013531(anf_arg14543530,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e35203521.stack[R.EXN_STACKHEIGHT++] = $ss35243525;
}
if(R.isPyretException($e35203521)) {
$e35203521.pyretStack.push(L[277]);
}
throw $e35203521;
}
var $ret35263527 = $Hanf_arg26013531($z35223523,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret35263527;
};
var $Hanf_arg26013531 = function(anf_arg14543530,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14553542 = G(list2776,"make",L[278]);
var $z35343535 = D;
var $f35403541 = function(_) {
return R.isFunction(anf_fun14553542)?anf_fun14553542.app([("foo.txt")]):R.ffi.throwNonFunApp(L[278],anf_fun14553542,[[("foo.txt")]]);
};
try {
if(--R.GAS > 0) {
$z35343535 = $f35403541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35403541,
"from":L[278]});
}
} catch($e35323533) {
if(R.isCont($e35323533)) {
var $ss35363537 = {"from":L[278],
"go":function(anf_arg14563543) {
return $Hanf_arg26003544(anf_arg14563543,anf_arg14513505,anf_arg14543530,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e35323533.stack[R.EXN_STACKHEIGHT++] = $ss35363537;
}
if(R.isPyretException($e35323533)) {
$e35323533.pyretStack.push(L[278]);
}
throw $e35323533;
}
var $ret35383539 = $Hanf_arg26003544($z35343535,anf_arg14513505,anf_arg14543530,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret35383539;
};
var $Hanf_arg26003544 = function(anf_arg14563543,anf_arg14513505,anf_arg14543530,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z35473548 = D;
var $f35533554 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg14543530,anf_arg14563543):R.ffi.throwNonFunApp(L[279],success100109.$var,[anf_arg14543530,anf_arg14563543]);
};
try {
if(--R.GAS > 0) {
$z35473548 = $f35533554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35533554,
"from":L[279]});
}
} catch($e35453546) {
if(R.isCont($e35453546)) {
var $ss35493550 = {"from":L[279],
"go":function(anf_arg14573555) {
return $Hanf_arg25993556(anf_arg14573555,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e35453546.stack[R.EXN_STACKHEIGHT++] = $ss35493550;
}
if(R.isPyretException($e35453546)) {
$e35453546.pyretStack.push(L[279]);
}
throw $e35453546;
}
var $ret35513552 = $Hanf_arg25993556($z35473548,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret35513552;
};
var $Hanf_arg25993556 = function(anf_arg14573555,anf_arg14513505,anf_fun14483493,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg14583567 = R.makeSrcloc(L[273]);
var $z35593560 = D;
var $f35653566 = function(_) {
return R.isFunction(anf_fun14483493)?anf_fun14483493.app(("parse-args(once-optional-next-default, [list: \"-w\", \"foo.txt\"]) is\n  success(dict([list: \"width\", 80]), [list: \"foo.txt\"])"),anf_arg14513505,anf_arg14573555,anf_arg14583567):R.ffi.throwNonFunApp(L[273],anf_fun14483493,[("parse-args(once-optional-next-default, [list: \"-w\", \"foo.txt\"]) is\n  success(dict([list: \"width\", 80]), [list: \"foo.txt\"])"),anf_arg14513505,anf_arg14573555,anf_arg14583567]);
};
try {
if(--R.GAS > 0) {
$z35593560 = $f35653566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35653566,
"from":L[273]});
}
} catch($e35573558) {
if(R.isCont($e35573558)) {
var $ss35613562 = {"from":L[273],
"go":function(anf_begin_app_dropped23143568) {
return $Hanf_begin_app_dropped25983569(anf_begin_app_dropped23143568,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e35573558.stack[R.EXN_STACKHEIGHT++] = $ss35613562;
}
if(R.isPyretException($e35573558)) {
$e35573558.pyretStack.push(L[273]);
}
throw $e35573558;
}
var $ret35633564 = $Hanf_begin_app_dropped25983569($z35593560,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret35633564;
};
var $Hanf_begin_app_dropped25983569 = function(anf_begin_app_dropped23143568,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14593580 = G(builtins15,"current-checker",L[280]);
var $z35723573 = D;
var $f35783579 = function(_) {
return R.isFunction(anf_fun14593580)?anf_fun14593580.app():R.ffi.throwNonFunApp(L[280],anf_fun14593580,[]);
};
try {
if(--R.GAS > 0) {
$z35723573 = $f35783579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35783579,
"from":L[280]});
}
} catch($e35703571) {
if(R.isCont($e35703571)) {
var $ss35743575 = {"from":L[280],
"go":function(anf_bracket14603581) {
return $Hanf_bracket25973582(anf_bracket14603581,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e35703571.stack[R.EXN_STACKHEIGHT++] = $ss35743575;
}
if(R.isPyretException($e35703571)) {
$e35703571.pyretStack.push(L[280]);
}
throw $e35703571;
}
var $ret35763577 = $Hanf_bracket25973582($z35723573,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret35763577;
};
var $Hanf_bracket25973582 = function(anf_bracket14603581,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14613595 = G(anf_bracket14603581,"check-is",L[280]);
var anf_fun14623593 = G(list2776,"make",L[281]);
var $z35853586 = D;
var $f35913592 = function(_) {
return R.isFunction(anf_fun14623593)?anf_fun14623593.app([("--width"),("120"),("foo.txt")]):R.ffi.throwNonFunApp(L[281],anf_fun14623593,[[("--width"),("120"),("foo.txt")]]);
};
try {
if(--R.GAS > 0) {
$z35853586 = $f35913592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35913592,
"from":L[281]});
}
} catch($e35833584) {
if(R.isCont($e35833584)) {
var $ss35873588 = {"from":L[281],
"go":function(anf_arg14633594) {
return $Hanf_arg25963596(anf_arg14633594,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e35833584.stack[R.EXN_STACKHEIGHT++] = $ss35873588;
}
if(R.isPyretException($e35833584)) {
$e35833584.pyretStack.push(L[281]);
}
throw $e35833584;
}
var $ret35893590 = $Hanf_arg25963596($z35853586,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret35893590;
};
var $Hanf_arg25963596 = function(anf_arg14633594,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z35993600 = D;
var $f36053606 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_next_DASH_default3433479,anf_arg14633594):R.ffi.throwNonFunApp(L[282],parse_DASH_args129167.$var,[once_DASH_optional_DASH_next_DASH_default3433479,anf_arg14633594]);
};
try {
if(--R.GAS > 0) {
$z35993600 = $f36053606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36053606,
"from":L[282]});
}
} catch($e35973598) {
if(R.isCont($e35973598)) {
var $ss36013602 = {"from":L[282],
"go":function(anf_arg14643607) {
return $Hanf_arg25953608(anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e35973598.stack[R.EXN_STACKHEIGHT++] = $ss36013602;
}
if(R.isPyretException($e35973598)) {
$e35973598.pyretStack.push(L[282]);
}
throw $e35973598;
}
var $ret36033604 = $Hanf_arg25953608($z35993600,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret36033604;
};
var $Hanf_arg25953608 = function(anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14653619 = G(list2776,"make",L[283]);
var $z36113612 = D;
var $f36173618 = function(_) {
return R.isFunction(anf_fun14653619)?anf_fun14653619.app([("width"),(120)]):R.ffi.throwNonFunApp(L[283],anf_fun14653619,[[("width"),(120)]]);
};
try {
if(--R.GAS > 0) {
$z36113612 = $f36173618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36173618,
"from":L[283]});
}
} catch($e36093610) {
if(R.isCont($e36093610)) {
var $ss36133614 = {"from":L[283],
"go":function(anf_arg14663620) {
return $Hanf_arg25943621(anf_arg14663620,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e36093610.stack[R.EXN_STACKHEIGHT++] = $ss36133614;
}
if(R.isPyretException($e36093610)) {
$e36093610.pyretStack.push(L[283]);
}
throw $e36093610;
}
var $ret36153616 = $Hanf_arg25943621($z36113612,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret36153616;
};
var $Hanf_arg25943621 = function(anf_arg14663620,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z36243625 = D;
var $f36303631 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg14663620):R.ffi.throwNonFunApp(L[284],dict131171.$var,[anf_arg14663620]);
};
try {
if(--R.GAS > 0) {
$z36243625 = $f36303631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36303631,
"from":L[284]});
}
} catch($e36223623) {
if(R.isCont($e36223623)) {
var $ss36263627 = {"from":L[284],
"go":function(anf_arg14673632) {
return $Hanf_arg25933633(anf_arg14673632,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e36223623.stack[R.EXN_STACKHEIGHT++] = $ss36263627;
}
if(R.isPyretException($e36223623)) {
$e36223623.pyretStack.push(L[284]);
}
throw $e36223623;
}
var $ret36283629 = $Hanf_arg25933633($z36243625,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret36283629;
};
var $Hanf_arg25933633 = function(anf_arg14673632,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14683644 = G(list2776,"make",L[285]);
var $z36363637 = D;
var $f36423643 = function(_) {
return R.isFunction(anf_fun14683644)?anf_fun14683644.app([("foo.txt")]):R.ffi.throwNonFunApp(L[285],anf_fun14683644,[[("foo.txt")]]);
};
try {
if(--R.GAS > 0) {
$z36363637 = $f36423643();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36423643,
"from":L[285]});
}
} catch($e36343635) {
if(R.isCont($e36343635)) {
var $ss36383639 = {"from":L[285],
"go":function(anf_arg14693645) {
return $Hanf_arg25923646(anf_arg14693645,anf_arg14643607,anf_arg14673632,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e36343635.stack[R.EXN_STACKHEIGHT++] = $ss36383639;
}
if(R.isPyretException($e36343635)) {
$e36343635.pyretStack.push(L[285]);
}
throw $e36343635;
}
var $ret36403641 = $Hanf_arg25923646($z36363637,anf_arg14643607,anf_arg14673632,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret36403641;
};
var $Hanf_arg25923646 = function(anf_arg14693645,anf_arg14643607,anf_arg14673632,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z36493650 = D;
var $f36553656 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg14673632,anf_arg14693645):R.ffi.throwNonFunApp(L[286],success100109.$var,[anf_arg14673632,anf_arg14693645]);
};
try {
if(--R.GAS > 0) {
$z36493650 = $f36553656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36553656,
"from":L[286]});
}
} catch($e36473648) {
if(R.isCont($e36473648)) {
var $ss36513652 = {"from":L[286],
"go":function(anf_arg14703657) {
return $Hanf_arg25913658(anf_arg14703657,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e36473648.stack[R.EXN_STACKHEIGHT++] = $ss36513652;
}
if(R.isPyretException($e36473648)) {
$e36473648.pyretStack.push(L[286]);
}
throw $e36473648;
}
var $ret36533654 = $Hanf_arg25913658($z36493650,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret36533654;
};
var $Hanf_arg25913658 = function(anf_arg14703657,anf_arg14643607,anf_fun14613595,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg14713669 = R.makeSrcloc(L[280]);
var $z36613662 = D;
var $f36673668 = function(_) {
return R.isFunction(anf_fun14613595)?anf_fun14613595.app(("parse-args(once-optional-next-default, [list: \"--width\", \"120\", \"foo.txt\"]) is\n  success(dict([list: \"width\", 120]), [list: \"foo.txt\"])"),anf_arg14643607,anf_arg14703657,anf_arg14713669):R.ffi.throwNonFunApp(L[280],anf_fun14613595,[("parse-args(once-optional-next-default, [list: \"--width\", \"120\", \"foo.txt\"]) is\n  success(dict([list: \"width\", 120]), [list: \"foo.txt\"])"),anf_arg14643607,anf_arg14703657,anf_arg14713669]);
};
try {
if(--R.GAS > 0) {
$z36613662 = $f36673668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36673668,
"from":L[280]});
}
} catch($e36593660) {
if(R.isCont($e36593660)) {
var $ss36633664 = {"from":L[280],
"go":function(anf_begin_app_dropped23153670) {
return $Hanf_begin_app_dropped25903671(anf_begin_app_dropped23153670,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e36593660.stack[R.EXN_STACKHEIGHT++] = $ss36633664;
}
if(R.isPyretException($e36593660)) {
$e36593660.pyretStack.push(L[280]);
}
throw $e36593660;
}
var $ret36653666 = $Hanf_begin_app_dropped25903671($z36613662,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret36653666;
};
var $Hanf_begin_app_dropped25903671 = function(anf_begin_app_dropped23153670,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14723682 = G(builtins15,"current-checker",L[287]);
var $z36743675 = D;
var $f36803681 = function(_) {
return R.isFunction(anf_fun14723682)?anf_fun14723682.app():R.ffi.throwNonFunApp(L[287],anf_fun14723682,[]);
};
try {
if(--R.GAS > 0) {
$z36743675 = $f36803681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36803681,
"from":L[287]});
}
} catch($e36723673) {
if(R.isCont($e36723673)) {
var $ss36763677 = {"from":L[287],
"go":function(anf_bracket14733683) {
return $Hanf_bracket25893684(anf_bracket14733683,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e36723673.stack[R.EXN_STACKHEIGHT++] = $ss36763677;
}
if(R.isPyretException($e36723673)) {
$e36723673.pyretStack.push(L[287]);
}
throw $e36723673;
}
var $ret36783679 = $Hanf_bracket25893684($z36743675,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret36783679;
};
var $Hanf_bracket25893684 = function(anf_bracket14733683,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14743697 = G(anf_bracket14733683,"check-is",L[287]);
var anf_fun14753695 = G(list2776,"make",L[288]);
var $z36873688 = D;
var $f36933694 = function(_) {
return R.isFunction(anf_fun14753695)?anf_fun14753695.app([("foo.txt")]):R.ffi.throwNonFunApp(L[288],anf_fun14753695,[[("foo.txt")]]);
};
try {
if(--R.GAS > 0) {
$z36873688 = $f36933694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36933694,
"from":L[288]});
}
} catch($e36853686) {
if(R.isCont($e36853686)) {
var $ss36893690 = {"from":L[288],
"go":function(anf_arg14763696) {
return $Hanf_arg25883698(anf_arg14763696,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e36853686.stack[R.EXN_STACKHEIGHT++] = $ss36893690;
}
if(R.isPyretException($e36853686)) {
$e36853686.pyretStack.push(L[288]);
}
throw $e36853686;
}
var $ret36913692 = $Hanf_arg25883698($z36873688,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret36913692;
};
var $Hanf_arg25883698 = function(anf_arg14763696,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z37013702 = D;
var $f37073708 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_next_DASH_default3433479,anf_arg14763696):R.ffi.throwNonFunApp(L[289],parse_DASH_args129167.$var,[once_DASH_optional_DASH_next_DASH_default3433479,anf_arg14763696]);
};
try {
if(--R.GAS > 0) {
$z37013702 = $f37073708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37073708,
"from":L[289]});
}
} catch($e36993700) {
if(R.isCont($e36993700)) {
var $ss37033704 = {"from":L[289],
"go":function(anf_arg14773709) {
return $Hanf_arg25873710(anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e36993700.stack[R.EXN_STACKHEIGHT++] = $ss37033704;
}
if(R.isPyretException($e36993700)) {
$e36993700.pyretStack.push(L[289]);
}
throw $e36993700;
}
var $ret37053706 = $Hanf_arg25873710($z37013702,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret37053706;
};
var $Hanf_arg25873710 = function(anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14783721 = G(list2776,"make",L[290]);
var $z37133714 = D;
var $f37193720 = function(_) {
return R.isFunction(anf_fun14783721)?anf_fun14783721.app([("width"),(80)]):R.ffi.throwNonFunApp(L[290],anf_fun14783721,[[("width"),(80)]]);
};
try {
if(--R.GAS > 0) {
$z37133714 = $f37193720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37193720,
"from":L[290]});
}
} catch($e37113712) {
if(R.isCont($e37113712)) {
var $ss37153716 = {"from":L[290],
"go":function(anf_arg14793722) {
return $Hanf_arg25863723(anf_arg14793722,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e37113712.stack[R.EXN_STACKHEIGHT++] = $ss37153716;
}
if(R.isPyretException($e37113712)) {
$e37113712.pyretStack.push(L[290]);
}
throw $e37113712;
}
var $ret37173718 = $Hanf_arg25863723($z37133714,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret37173718;
};
var $Hanf_arg25863723 = function(anf_arg14793722,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z37263727 = D;
var $f37323733 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg14793722):R.ffi.throwNonFunApp(L[291],dict131171.$var,[anf_arg14793722]);
};
try {
if(--R.GAS > 0) {
$z37263727 = $f37323733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37323733,
"from":L[291]});
}
} catch($e37243725) {
if(R.isCont($e37243725)) {
var $ss37283729 = {"from":L[291],
"go":function(anf_arg14803734) {
return $Hanf_arg25853735(anf_arg14803734,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e37243725.stack[R.EXN_STACKHEIGHT++] = $ss37283729;
}
if(R.isPyretException($e37243725)) {
$e37243725.pyretStack.push(L[291]);
}
throw $e37243725;
}
var $ret37303731 = $Hanf_arg25853735($z37263727,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret37303731;
};
var $Hanf_arg25853735 = function(anf_arg14803734,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14813746 = G(list2776,"make",L[292]);
var $z37383739 = D;
var $f37443745 = function(_) {
return R.isFunction(anf_fun14813746)?anf_fun14813746.app([("foo.txt")]):R.ffi.throwNonFunApp(L[292],anf_fun14813746,[[("foo.txt")]]);
};
try {
if(--R.GAS > 0) {
$z37383739 = $f37443745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37443745,
"from":L[292]});
}
} catch($e37363737) {
if(R.isCont($e37363737)) {
var $ss37403741 = {"from":L[292],
"go":function(anf_arg14823747) {
return $Hanf_arg25843748(anf_arg14823747,anf_arg14773709,anf_arg14803734,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e37363737.stack[R.EXN_STACKHEIGHT++] = $ss37403741;
}
if(R.isPyretException($e37363737)) {
$e37363737.pyretStack.push(L[292]);
}
throw $e37363737;
}
var $ret37423743 = $Hanf_arg25843748($z37383739,anf_arg14773709,anf_arg14803734,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret37423743;
};
var $Hanf_arg25843748 = function(anf_arg14823747,anf_arg14773709,anf_arg14803734,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z37513752 = D;
var $f37573758 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg14803734,anf_arg14823747):R.ffi.throwNonFunApp(L[293],success100109.$var,[anf_arg14803734,anf_arg14823747]);
};
try {
if(--R.GAS > 0) {
$z37513752 = $f37573758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37573758,
"from":L[293]});
}
} catch($e37493750) {
if(R.isCont($e37493750)) {
var $ss37533754 = {"from":L[293],
"go":function(anf_arg14833759) {
return $Hanf_arg25833760(anf_arg14833759,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e37493750.stack[R.EXN_STACKHEIGHT++] = $ss37533754;
}
if(R.isPyretException($e37493750)) {
$e37493750.pyretStack.push(L[293]);
}
throw $e37493750;
}
var $ret37553756 = $Hanf_arg25833760($z37513752,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret37553756;
};
var $Hanf_arg25833760 = function(anf_arg14833759,anf_arg14773709,anf_fun14743697,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg14843771 = R.makeSrcloc(L[287]);
var $z37633764 = D;
var $f37693770 = function(_) {
return R.isFunction(anf_fun14743697)?anf_fun14743697.app(("parse-args(once-optional-next-default, [list: \"foo.txt\"]) is\n  success(dict([list: \"width\", 80]), [list: \"foo.txt\"])"),anf_arg14773709,anf_arg14833759,anf_arg14843771):R.ffi.throwNonFunApp(L[287],anf_fun14743697,[("parse-args(once-optional-next-default, [list: \"foo.txt\"]) is\n  success(dict([list: \"width\", 80]), [list: \"foo.txt\"])"),anf_arg14773709,anf_arg14833759,anf_arg14843771]);
};
try {
if(--R.GAS > 0) {
$z37633764 = $f37693770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37693770,
"from":L[287]});
}
} catch($e37613762) {
if(R.isCont($e37613762)) {
var $ss37653766 = {"from":L[287],
"go":function(anf_begin_app_dropped23163772) {
return $Hanf_begin_app_dropped25823773(anf_begin_app_dropped23163772,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e37613762.stack[R.EXN_STACKHEIGHT++] = $ss37653766;
}
if(R.isPyretException($e37613762)) {
$e37613762.pyretStack.push(L[287]);
}
throw $e37613762;
}
var $ret37673768 = $Hanf_begin_app_dropped25823773($z37633764,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret37673768;
};
var $Hanf_begin_app_dropped25823773 = function(anf_begin_app_dropped23163772,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14853784 = G(builtins15,"current-checker",L[294]);
var $z37763777 = D;
var $f37823783 = function(_) {
return R.isFunction(anf_fun14853784)?anf_fun14853784.app():R.ffi.throwNonFunApp(L[294],anf_fun14853784,[]);
};
try {
if(--R.GAS > 0) {
$z37763777 = $f37823783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37823783,
"from":L[294]});
}
} catch($e37743775) {
if(R.isCont($e37743775)) {
var $ss37783779 = {"from":L[294],
"go":function(anf_bracket14863785) {
return $Hanf_bracket25813786(anf_bracket14863785,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e37743775.stack[R.EXN_STACKHEIGHT++] = $ss37783779;
}
if(R.isPyretException($e37743775)) {
$e37743775.pyretStack.push(L[294]);
}
throw $e37743775;
}
var $ret37803781 = $Hanf_bracket25813786($z37763777,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret37803781;
};
var $Hanf_bracket25813786 = function(anf_bracket14863785,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14873799 = G(anf_bracket14863785,"check-satisfies",L[294]);
var anf_fun14883797 = G(list2776,"make",L[295]);
var $z37893790 = D;
var $f37953796 = function(_) {
return R.isFunction(anf_fun14883797)?anf_fun14883797.app([("--w"),("120"),("foo.txt")]):R.ffi.throwNonFunApp(L[295],anf_fun14883797,[[("--w"),("120"),("foo.txt")]]);
};
try {
if(--R.GAS > 0) {
$z37893790 = $f37953796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37953796,
"from":L[295]});
}
} catch($e37873788) {
if(R.isCont($e37873788)) {
var $ss37913792 = {"from":L[295],
"go":function(anf_arg14893798) {
return $Hanf_arg25803800(anf_arg14893798,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e37873788.stack[R.EXN_STACKHEIGHT++] = $ss37913792;
}
if(R.isPyretException($e37873788)) {
$e37873788.pyretStack.push(L[295]);
}
throw $e37873788;
}
var $ret37933794 = $Hanf_arg25803800($z37893790,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret37933794;
};
var $Hanf_arg25803800 = function(anf_arg14893798,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_optional_DASH_next_DASH_default3433479,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z38033804 = D;
var $f38093810 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_optional_DASH_next_DASH_default3433479,anf_arg14893798):R.ffi.throwNonFunApp(L[296],parse_DASH_args129167.$var,[once_DASH_optional_DASH_next_DASH_default3433479,anf_arg14893798]);
};
try {
if(--R.GAS > 0) {
$z38033804 = $f38093810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38093810,
"from":L[296]});
}
} catch($e38013802) {
if(R.isCont($e38013802)) {
var $ss38053806 = {"from":L[296],
"go":function(anf_arg14903811) {
return $Hanf_arg25793812(anf_arg14903811,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e38013802.stack[R.EXN_STACKHEIGHT++] = $ss38053806;
}
if(R.isPyretException($e38013802)) {
$e38013802.pyretStack.push(L[296]);
}
throw $e38013802;
}
var $ret38073808 = $Hanf_arg25793812($z38033804,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret38073808;
};
var $Hanf_arg25793812 = function(anf_arg14903811,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z38153816 = D;
var $f38213822 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("Unknown command line option --w")):R.ffi.throwNonFunApp(L[297],error_DASH_text3331409.$var,[("Unknown command line option --w")]);
};
try {
if(--R.GAS > 0) {
$z38153816 = $f38213822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38213822,
"from":L[297]});
}
} catch($e38133814) {
if(R.isCont($e38133814)) {
var $ss38173818 = {"from":L[297],
"go":function(anf_arg14913823) {
return $Hanf_arg25783824(anf_arg14913823,anf_arg14903811,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e38133814.stack[R.EXN_STACKHEIGHT++] = $ss38173818;
}
if(R.isPyretException($e38133814)) {
$e38133814.pyretStack.push(L[297]);
}
throw $e38133814;
}
var $ret38193820 = $Hanf_arg25783824($z38153816,anf_arg14903811,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret38193820;
};
var $Hanf_arg25783824 = function(anf_arg14913823,anf_arg14903811,anf_fun14873799,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg14923835 = R.makeSrcloc(L[294]);
var $z38273828 = D;
var $f38333834 = function(_) {
return R.isFunction(anf_fun14873799)?anf_fun14873799.app(("parse-args(once-optional-next-default, [list: \"--w\", \"120\", \"foo.txt\"]) satisfies\n  error-text(\"Unknown command line option --w\")"),anf_arg14903811,anf_arg14913823,anf_arg14923835):R.ffi.throwNonFunApp(L[294],anf_fun14873799,[("parse-args(once-optional-next-default, [list: \"--w\", \"120\", \"foo.txt\"]) satisfies\n  error-text(\"Unknown command line option --w\")"),anf_arg14903811,anf_arg14913823,anf_arg14923835]);
};
try {
if(--R.GAS > 0) {
$z38273828 = $f38333834();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38333834,
"from":L[294]});
}
} catch($e38253826) {
if(R.isCont($e38253826)) {
var $ss38293830 = {"from":L[294],
"go":function(anf_begin_app_dropped23173836) {
return $Hanf_begin_app_dropped25773837(anf_begin_app_dropped23173836,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e38253826.stack[R.EXN_STACKHEIGHT++] = $ss38293830;
}
if(R.isPyretException($e38253826)) {
$e38253826.pyretStack.push(L[294]);
}
throw $e38253826;
}
var $ret38313832 = $Hanf_begin_app_dropped25773837($z38273828,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret38313832;
};
var $Hanf_begin_app_dropped25773837 = function(anf_begin_app_dropped23173836,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z38403841 = D;
var $f38463847 = function(_) {
return R.isFunction(some6478)?some6478.app(("f")):R.ffi.throwNonFunApp(L[298],some6478,[("f")]);
};
try {
if(--R.GAS > 0) {
$z38403841 = $f38463847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38463847,
"from":L[298]});
}
} catch($e38383839) {
if(R.isCont($e38383839)) {
var $ss38423843 = {"from":L[298],
"go":function(anf_arg14933848) {
return $Hanf_arg25763849(anf_arg14933848,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
}};
$e38383839.stack[R.EXN_STACKHEIGHT++] = $ss38423843;
}
if(R.isPyretException($e38383839)) {
$e38383839.pyretStack.push(L[298]);
}
throw $e38383839;
}
var $ret38443845 = $Hanf_arg25763849($z38403841,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret38443845;
};
var $Hanf_arg25763849 = function(anf_arg14933848,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,required_DASH_once111131,right8177,some6478,success100109,builtins15,torepr24) {
var $z38523853 = D;
var $f38583859 = function(_) {
return R.isFunction(next_DASH_val_DASH_default126161.$var)?next_DASH_val_DASH_default126161.$var.app(read_DASH_number8987.$var,(42),anf_arg14933848,required_DASH_once111131.$var,("Foo")):R.ffi.throwNonFunApp(L[299],next_DASH_val_DASH_default126161.$var,[read_DASH_number8987.$var,(42),anf_arg14933848,required_DASH_once111131.$var,("Foo")]);
};
try {
if(--R.GAS > 0) {
$z38523853 = $f38583859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38583859,
"from":L[299]});
}
} catch($e38503851) {
if(R.isCont($e38503851)) {
var $ss38543855 = {"from":L[299],
"go":function(anf_obj14943860) {
return $Hanf_obj25753861(anf_obj14943860,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e38503851.stack[R.EXN_STACKHEIGHT++] = $ss38543855;
}
if(R.isPyretException($e38503851)) {
$e38503851.pyretStack.push(L[299]);
}
throw $e38503851;
}
var $ret38563857 = $Hanf_obj25753861($z38523853,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret38563857;
};
var $Hanf_obj25753861 = function(anf_obj14943860,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once107123,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z38643865 = D;
var $f38703871 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(once107123.$var,("Bar")):R.ffi.throwNonFunApp(L[300],flag118145.$var,[once107123.$var,("Bar")]);
};
try {
if(--R.GAS > 0) {
$z38643865 = $f38703871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38703871,
"from":L[300]});
}
} catch($e38623863) {
if(R.isCont($e38623863)) {
var $ss38663867 = {"from":L[300],
"go":function(anf_obj14953872) {
return $Hanf_obj25743873(anf_obj14953872,anf_obj14943860,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e38623863.stack[R.EXN_STACKHEIGHT++] = $ss38663867;
}
if(R.isPyretException($e38623863)) {
$e38623863.pyretStack.push(L[300]);
}
throw $e38623863;
}
var $ret38683869 = $Hanf_obj25743873($z38643865,anf_obj14943860,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret38683869;
};
var $Hanf_obj25743873 = function(anf_obj14953872,anf_obj14943860,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var once_DASH_required_DASH_next_DASH_default3443886 = R.makeObject({"foo":anf_obj14943860,
"bar":anf_obj14953872});
var anf_fun14963884 = G(builtins15,"current-checker",L[301]);
var $z38763877 = D;
var $f38823883 = function(_) {
return R.isFunction(anf_fun14963884)?anf_fun14963884.app():R.ffi.throwNonFunApp(L[301],anf_fun14963884,[]);
};
try {
if(--R.GAS > 0) {
$z38763877 = $f38823883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38823883,
"from":L[301]});
}
} catch($e38743875) {
if(R.isCont($e38743875)) {
var $ss38783879 = {"from":L[301],
"go":function(anf_bracket14973885) {
return $Hanf_bracket25733887(anf_bracket14973885,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e38743875.stack[R.EXN_STACKHEIGHT++] = $ss38783879;
}
if(R.isPyretException($e38743875)) {
$e38743875.pyretStack.push(L[301]);
}
throw $e38743875;
}
var $ret38803881 = $Hanf_bracket25733887($z38763877,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret38803881;
};
var $Hanf_bracket25733887 = function(anf_bracket14973885,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun14983900 = G(anf_bracket14973885,"check-is",L[301]);
var anf_fun14993898 = G(list2776,"make",L[302]);
var $z38903891 = D;
var $f38963897 = function(_) {
return R.isFunction(anf_fun14993898)?anf_fun14993898.app([("--foo"),("3")]):R.ffi.throwNonFunApp(L[302],anf_fun14993898,[[("--foo"),("3")]]);
};
try {
if(--R.GAS > 0) {
$z38903891 = $f38963897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38963897,
"from":L[302]});
}
} catch($e38883889) {
if(R.isCont($e38883889)) {
var $ss38923893 = {"from":L[302],
"go":function(anf_arg15003899) {
return $Hanf_arg25723901(anf_arg15003899,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e38883889.stack[R.EXN_STACKHEIGHT++] = $ss38923893;
}
if(R.isPyretException($e38883889)) {
$e38883889.pyretStack.push(L[302]);
}
throw $e38883889;
}
var $ret38943895 = $Hanf_arg25723901($z38903891,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret38943895;
};
var $Hanf_arg25723901 = function(anf_arg15003899,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z39043905 = D;
var $f39103911 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_next_DASH_default3443886,anf_arg15003899):R.ffi.throwNonFunApp(L[303],parse_DASH_args129167.$var,[once_DASH_required_DASH_next_DASH_default3443886,anf_arg15003899]);
};
try {
if(--R.GAS > 0) {
$z39043905 = $f39103911();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39103911,
"from":L[303]});
}
} catch($e39023903) {
if(R.isCont($e39023903)) {
var $ss39063907 = {"from":L[303],
"go":function(anf_arg15013912) {
return $Hanf_arg25713913(anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e39023903.stack[R.EXN_STACKHEIGHT++] = $ss39063907;
}
if(R.isPyretException($e39023903)) {
$e39023903.pyretStack.push(L[303]);
}
throw $e39023903;
}
var $ret39083909 = $Hanf_arg25713913($z39043905,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret39083909;
};
var $Hanf_arg25713913 = function(anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15023924 = G(list2776,"make",L[304]);
var $z39163917 = D;
var $f39223923 = function(_) {
return R.isFunction(anf_fun15023924)?anf_fun15023924.app([("foo"),(3)]):R.ffi.throwNonFunApp(L[304],anf_fun15023924,[[("foo"),(3)]]);
};
try {
if(--R.GAS > 0) {
$z39163917 = $f39223923();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39223923,
"from":L[304]});
}
} catch($e39143915) {
if(R.isCont($e39143915)) {
var $ss39183919 = {"from":L[304],
"go":function(anf_arg15033925) {
return $Hanf_arg25703926(anf_arg15033925,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e39143915.stack[R.EXN_STACKHEIGHT++] = $ss39183919;
}
if(R.isPyretException($e39143915)) {
$e39143915.pyretStack.push(L[304]);
}
throw $e39143915;
}
var $ret39203921 = $Hanf_arg25703926($z39163917,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret39203921;
};
var $Hanf_arg25703926 = function(anf_arg15033925,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z39293930 = D;
var $f39353936 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg15033925):R.ffi.throwNonFunApp(L[305],dict131171.$var,[anf_arg15033925]);
};
try {
if(--R.GAS > 0) {
$z39293930 = $f39353936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39353936,
"from":L[305]});
}
} catch($e39273928) {
if(R.isCont($e39273928)) {
var $ss39313932 = {"from":L[305],
"go":function(anf_arg15043937) {
return $Hanf_arg25693938(anf_arg15043937,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e39273928.stack[R.EXN_STACKHEIGHT++] = $ss39313932;
}
if(R.isPyretException($e39273928)) {
$e39273928.pyretStack.push(L[305]);
}
throw $e39273928;
}
var $ret39333934 = $Hanf_arg25693938($z39293930,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret39333934;
};
var $Hanf_arg25693938 = function(anf_arg15043937,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15053949 = G(list2776,"make",L[306]);
var $z39413942 = D;
var $f39473948 = function(_) {
return R.isFunction(anf_fun15053949)?anf_fun15053949.app([]):R.ffi.throwNonFunApp(L[306],anf_fun15053949,[[]]);
};
try {
if(--R.GAS > 0) {
$z39413942 = $f39473948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39473948,
"from":L[306]});
}
} catch($e39393940) {
if(R.isCont($e39393940)) {
var $ss39433944 = {"from":L[306],
"go":function(anf_arg15063950) {
return $Hanf_arg25683951(anf_arg15063950,anf_arg15013912,anf_arg15043937,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e39393940.stack[R.EXN_STACKHEIGHT++] = $ss39433944;
}
if(R.isPyretException($e39393940)) {
$e39393940.pyretStack.push(L[306]);
}
throw $e39393940;
}
var $ret39453946 = $Hanf_arg25683951($z39413942,anf_arg15013912,anf_arg15043937,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret39453946;
};
var $Hanf_arg25683951 = function(anf_arg15063950,anf_arg15013912,anf_arg15043937,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z39543955 = D;
var $f39603961 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg15043937,anf_arg15063950):R.ffi.throwNonFunApp(L[307],success100109.$var,[anf_arg15043937,anf_arg15063950]);
};
try {
if(--R.GAS > 0) {
$z39543955 = $f39603961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39603961,
"from":L[307]});
}
} catch($e39523953) {
if(R.isCont($e39523953)) {
var $ss39563957 = {"from":L[307],
"go":function(anf_arg15073962) {
return $Hanf_arg25673963(anf_arg15073962,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e39523953.stack[R.EXN_STACKHEIGHT++] = $ss39563957;
}
if(R.isPyretException($e39523953)) {
$e39523953.pyretStack.push(L[307]);
}
throw $e39523953;
}
var $ret39583959 = $Hanf_arg25673963($z39543955,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret39583959;
};
var $Hanf_arg25673963 = function(anf_arg15073962,anf_arg15013912,anf_fun14983900,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg15083974 = R.makeSrcloc(L[301]);
var $z39663967 = D;
var $f39723973 = function(_) {
return R.isFunction(anf_fun14983900)?anf_fun14983900.app(("parse-args(once-required-next-default, [list: \"--foo\", \"3\"]) is\n  success(dict([list: \"foo\", 3]), [list: ])"),anf_arg15013912,anf_arg15073962,anf_arg15083974):R.ffi.throwNonFunApp(L[301],anf_fun14983900,[("parse-args(once-required-next-default, [list: \"--foo\", \"3\"]) is\n  success(dict([list: \"foo\", 3]), [list: ])"),anf_arg15013912,anf_arg15073962,anf_arg15083974]);
};
try {
if(--R.GAS > 0) {
$z39663967 = $f39723973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39723973,
"from":L[301]});
}
} catch($e39643965) {
if(R.isCont($e39643965)) {
var $ss39683969 = {"from":L[301],
"go":function(anf_begin_app_dropped23183975) {
return $Hanf_begin_app_dropped25663976(anf_begin_app_dropped23183975,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e39643965.stack[R.EXN_STACKHEIGHT++] = $ss39683969;
}
if(R.isPyretException($e39643965)) {
$e39643965.pyretStack.push(L[301]);
}
throw $e39643965;
}
var $ret39703971 = $Hanf_begin_app_dropped25663976($z39663967,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret39703971;
};
var $Hanf_begin_app_dropped25663976 = function(anf_begin_app_dropped23183975,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15093987 = G(builtins15,"current-checker",L[308]);
var $z39793980 = D;
var $f39853986 = function(_) {
return R.isFunction(anf_fun15093987)?anf_fun15093987.app():R.ffi.throwNonFunApp(L[308],anf_fun15093987,[]);
};
try {
if(--R.GAS > 0) {
$z39793980 = $f39853986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39853986,
"from":L[308]});
}
} catch($e39773978) {
if(R.isCont($e39773978)) {
var $ss39813982 = {"from":L[308],
"go":function(anf_bracket15103988) {
return $Hanf_bracket25653989(anf_bracket15103988,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e39773978.stack[R.EXN_STACKHEIGHT++] = $ss39813982;
}
if(R.isPyretException($e39773978)) {
$e39773978.pyretStack.push(L[308]);
}
throw $e39773978;
}
var $ret39833984 = $Hanf_bracket25653989($z39793980,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret39833984;
};
var $Hanf_bracket25653989 = function(anf_bracket15103988,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15114002 = G(anf_bracket15103988,"check-satisfies",L[308]);
var anf_fun15124000 = G(list2776,"make",L[309]);
var $z39923993 = D;
var $f39983999 = function(_) {
return R.isFunction(anf_fun15124000)?anf_fun15124000.app([("--foo"),("bar")]):R.ffi.throwNonFunApp(L[309],anf_fun15124000,[[("--foo"),("bar")]]);
};
try {
if(--R.GAS > 0) {
$z39923993 = $f39983999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39983999,
"from":L[309]});
}
} catch($e39903991) {
if(R.isCont($e39903991)) {
var $ss39943995 = {"from":L[309],
"go":function(anf_arg15134001) {
return $Hanf_arg25644003(anf_arg15134001,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e39903991.stack[R.EXN_STACKHEIGHT++] = $ss39943995;
}
if(R.isPyretException($e39903991)) {
$e39903991.pyretStack.push(L[309]);
}
throw $e39903991;
}
var $ret39963997 = $Hanf_arg25644003($z39923993,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret39963997;
};
var $Hanf_arg25644003 = function(anf_arg15134001,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z40064007 = D;
var $f40124013 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_next_DASH_default3443886,anf_arg15134001):R.ffi.throwNonFunApp(L[310],parse_DASH_args129167.$var,[once_DASH_required_DASH_next_DASH_default3443886,anf_arg15134001]);
};
try {
if(--R.GAS > 0) {
$z40064007 = $f40124013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40124013,
"from":L[310]});
}
} catch($e40044005) {
if(R.isCont($e40044005)) {
var $ss40084009 = {"from":L[310],
"go":function(anf_arg15144014) {
return $Hanf_arg25634015(anf_arg15144014,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e40044005.stack[R.EXN_STACKHEIGHT++] = $ss40084009;
}
if(R.isPyretException($e40044005)) {
$e40044005.pyretStack.push(L[310]);
}
throw $e40044005;
}
var $ret40104011 = $Hanf_arg25634015($z40064007,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret40104011;
};
var $Hanf_arg25634015 = function(anf_arg15144014,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z40184019 = D;
var $f40244025 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("expected a numeric argument")):R.ffi.throwNonFunApp(L[311],error_DASH_text3331409.$var,[("expected a numeric argument")]);
};
try {
if(--R.GAS > 0) {
$z40184019 = $f40244025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40244025,
"from":L[311]});
}
} catch($e40164017) {
if(R.isCont($e40164017)) {
var $ss40204021 = {"from":L[311],
"go":function(anf_arg15154026) {
return $Hanf_arg25624027(anf_arg15154026,anf_arg15144014,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e40164017.stack[R.EXN_STACKHEIGHT++] = $ss40204021;
}
if(R.isPyretException($e40164017)) {
$e40164017.pyretStack.push(L[311]);
}
throw $e40164017;
}
var $ret40224023 = $Hanf_arg25624027($z40184019,anf_arg15144014,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret40224023;
};
var $Hanf_arg25624027 = function(anf_arg15154026,anf_arg15144014,anf_fun15114002,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg15164038 = R.makeSrcloc(L[308]);
var $z40304031 = D;
var $f40364037 = function(_) {
return R.isFunction(anf_fun15114002)?anf_fun15114002.app(("parse-args(once-required-next-default, [list: \"--foo\", \"bar\"]) satisfies\n  error-text(\"expected a numeric argument\")"),anf_arg15144014,anf_arg15154026,anf_arg15164038):R.ffi.throwNonFunApp(L[308],anf_fun15114002,[("parse-args(once-required-next-default, [list: \"--foo\", \"bar\"]) satisfies\n  error-text(\"expected a numeric argument\")"),anf_arg15144014,anf_arg15154026,anf_arg15164038]);
};
try {
if(--R.GAS > 0) {
$z40304031 = $f40364037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40364037,
"from":L[308]});
}
} catch($e40284029) {
if(R.isCont($e40284029)) {
var $ss40324033 = {"from":L[308],
"go":function(anf_begin_app_dropped23194039) {
return $Hanf_begin_app_dropped25614040(anf_begin_app_dropped23194039,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e40284029.stack[R.EXN_STACKHEIGHT++] = $ss40324033;
}
if(R.isPyretException($e40284029)) {
$e40284029.pyretStack.push(L[308]);
}
throw $e40284029;
}
var $ret40344035 = $Hanf_begin_app_dropped25614040($z40304031,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret40344035;
};
var $Hanf_begin_app_dropped25614040 = function(anf_begin_app_dropped23194039,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15174051 = G(builtins15,"current-checker",L[312]);
var $z40434044 = D;
var $f40494050 = function(_) {
return R.isFunction(anf_fun15174051)?anf_fun15174051.app():R.ffi.throwNonFunApp(L[312],anf_fun15174051,[]);
};
try {
if(--R.GAS > 0) {
$z40434044 = $f40494050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40494050,
"from":L[312]});
}
} catch($e40414042) {
if(R.isCont($e40414042)) {
var $ss40454046 = {"from":L[312],
"go":function(anf_bracket15184052) {
return $Hanf_bracket25604053(anf_bracket15184052,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e40414042.stack[R.EXN_STACKHEIGHT++] = $ss40454046;
}
if(R.isPyretException($e40414042)) {
$e40414042.pyretStack.push(L[312]);
}
throw $e40414042;
}
var $ret40474048 = $Hanf_bracket25604053($z40434044,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret40474048;
};
var $Hanf_bracket25604053 = function(anf_bracket15184052,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15194066 = G(anf_bracket15184052,"check-satisfies",L[312]);
var anf_fun15204064 = G(list2776,"make",L[313]);
var $z40564057 = D;
var $f40624063 = function(_) {
return R.isFunction(anf_fun15204064)?anf_fun15204064.app([("--foo"),("3"),("--foo"),("4")]):R.ffi.throwNonFunApp(L[313],anf_fun15204064,[[("--foo"),("3"),("--foo"),("4")]]);
};
try {
if(--R.GAS > 0) {
$z40564057 = $f40624063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40624063,
"from":L[313]});
}
} catch($e40544055) {
if(R.isCont($e40544055)) {
var $ss40584059 = {"from":L[313],
"go":function(anf_arg15214065) {
return $Hanf_arg25594067(anf_arg15214065,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e40544055.stack[R.EXN_STACKHEIGHT++] = $ss40584059;
}
if(R.isPyretException($e40544055)) {
$e40544055.pyretStack.push(L[313]);
}
throw $e40544055;
}
var $ret40604061 = $Hanf_arg25594067($z40564057,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret40604061;
};
var $Hanf_arg25594067 = function(anf_arg15214065,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z40704071 = D;
var $f40764077 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_next_DASH_default3443886,anf_arg15214065):R.ffi.throwNonFunApp(L[314],parse_DASH_args129167.$var,[once_DASH_required_DASH_next_DASH_default3443886,anf_arg15214065]);
};
try {
if(--R.GAS > 0) {
$z40704071 = $f40764077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40764077,
"from":L[314]});
}
} catch($e40684069) {
if(R.isCont($e40684069)) {
var $ss40724073 = {"from":L[314],
"go":function(anf_arg15224078) {
return $Hanf_arg25584079(anf_arg15224078,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e40684069.stack[R.EXN_STACKHEIGHT++] = $ss40724073;
}
if(R.isPyretException($e40684069)) {
$e40684069.pyretStack.push(L[314]);
}
throw $e40684069;
}
var $ret40744075 = $Hanf_arg25584079($z40704071,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret40744075;
};
var $Hanf_arg25584079 = function(anf_arg15224078,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z40824083 = D;
var $f40884089 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("already been used")):R.ffi.throwNonFunApp(L[315],error_DASH_text3331409.$var,[("already been used")]);
};
try {
if(--R.GAS > 0) {
$z40824083 = $f40884089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40884089,
"from":L[315]});
}
} catch($e40804081) {
if(R.isCont($e40804081)) {
var $ss40844085 = {"from":L[315],
"go":function(anf_arg15234090) {
return $Hanf_arg25574091(anf_arg15234090,anf_arg15224078,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e40804081.stack[R.EXN_STACKHEIGHT++] = $ss40844085;
}
if(R.isPyretException($e40804081)) {
$e40804081.pyretStack.push(L[315]);
}
throw $e40804081;
}
var $ret40864087 = $Hanf_arg25574091($z40824083,anf_arg15224078,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret40864087;
};
var $Hanf_arg25574091 = function(anf_arg15234090,anf_arg15224078,anf_fun15194066,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg15244102 = R.makeSrcloc(L[312]);
var $z40944095 = D;
var $f41004101 = function(_) {
return R.isFunction(anf_fun15194066)?anf_fun15194066.app(("parse-args(once-required-next-default, [list: \"--foo\", \"3\", \"--foo\", \"4\"]) satisfies\n  error-text(\"already been used\")"),anf_arg15224078,anf_arg15234090,anf_arg15244102):R.ffi.throwNonFunApp(L[312],anf_fun15194066,[("parse-args(once-required-next-default, [list: \"--foo\", \"3\", \"--foo\", \"4\"]) satisfies\n  error-text(\"already been used\")"),anf_arg15224078,anf_arg15234090,anf_arg15244102]);
};
try {
if(--R.GAS > 0) {
$z40944095 = $f41004101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41004101,
"from":L[312]});
}
} catch($e40924093) {
if(R.isCont($e40924093)) {
var $ss40964097 = {"from":L[312],
"go":function(anf_begin_app_dropped23204103) {
return $Hanf_begin_app_dropped25564104(anf_begin_app_dropped23204103,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e40924093.stack[R.EXN_STACKHEIGHT++] = $ss40964097;
}
if(R.isPyretException($e40924093)) {
$e40924093.pyretStack.push(L[312]);
}
throw $e40924093;
}
var $ret40984099 = $Hanf_begin_app_dropped25564104($z40944095,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret40984099;
};
var $Hanf_begin_app_dropped25564104 = function(anf_begin_app_dropped23204103,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15254115 = G(builtins15,"current-checker",L[316]);
var $z41074108 = D;
var $f41134114 = function(_) {
return R.isFunction(anf_fun15254115)?anf_fun15254115.app():R.ffi.throwNonFunApp(L[316],anf_fun15254115,[]);
};
try {
if(--R.GAS > 0) {
$z41074108 = $f41134114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41134114,
"from":L[316]});
}
} catch($e41054106) {
if(R.isCont($e41054106)) {
var $ss41094110 = {"from":L[316],
"go":function(anf_bracket15264116) {
return $Hanf_bracket25554117(anf_bracket15264116,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e41054106.stack[R.EXN_STACKHEIGHT++] = $ss41094110;
}
if(R.isPyretException($e41054106)) {
$e41054106.pyretStack.push(L[316]);
}
throw $e41054106;
}
var $ret41114112 = $Hanf_bracket25554117($z41074108,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret41114112;
};
var $Hanf_bracket25554117 = function(anf_bracket15264116,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15274130 = G(anf_bracket15264116,"check-is",L[316]);
var anf_fun15284128 = G(list2776,"make",L[317]);
var $z41204121 = D;
var $f41264127 = function(_) {
return R.isFunction(anf_fun15284128)?anf_fun15284128.app([("-f")]):R.ffi.throwNonFunApp(L[317],anf_fun15284128,[[("-f")]]);
};
try {
if(--R.GAS > 0) {
$z41204121 = $f41264127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41264127,
"from":L[317]});
}
} catch($e41184119) {
if(R.isCont($e41184119)) {
var $ss41224123 = {"from":L[317],
"go":function(anf_arg15294129) {
return $Hanf_arg25544131(anf_arg15294129,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e41184119.stack[R.EXN_STACKHEIGHT++] = $ss41224123;
}
if(R.isPyretException($e41184119)) {
$e41184119.pyretStack.push(L[317]);
}
throw $e41184119;
}
var $ret41244125 = $Hanf_arg25544131($z41204121,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret41244125;
};
var $Hanf_arg25544131 = function(anf_arg15294129,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z41344135 = D;
var $f41404141 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_next_DASH_default3443886,anf_arg15294129):R.ffi.throwNonFunApp(L[318],parse_DASH_args129167.$var,[once_DASH_required_DASH_next_DASH_default3443886,anf_arg15294129]);
};
try {
if(--R.GAS > 0) {
$z41344135 = $f41404141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41404141,
"from":L[318]});
}
} catch($e41324133) {
if(R.isCont($e41324133)) {
var $ss41364137 = {"from":L[318],
"go":function(anf_arg15304142) {
return $Hanf_arg25534143(anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e41324133.stack[R.EXN_STACKHEIGHT++] = $ss41364137;
}
if(R.isPyretException($e41324133)) {
$e41324133.pyretStack.push(L[318]);
}
throw $e41324133;
}
var $ret41384139 = $Hanf_arg25534143($z41344135,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret41384139;
};
var $Hanf_arg25534143 = function(anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15314154 = G(list2776,"make",L[319]);
var $z41464147 = D;
var $f41524153 = function(_) {
return R.isFunction(anf_fun15314154)?anf_fun15314154.app([("foo"),(42)]):R.ffi.throwNonFunApp(L[319],anf_fun15314154,[[("foo"),(42)]]);
};
try {
if(--R.GAS > 0) {
$z41464147 = $f41524153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41524153,
"from":L[319]});
}
} catch($e41444145) {
if(R.isCont($e41444145)) {
var $ss41484149 = {"from":L[319],
"go":function(anf_arg15324155) {
return $Hanf_arg25524156(anf_arg15324155,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e41444145.stack[R.EXN_STACKHEIGHT++] = $ss41484149;
}
if(R.isPyretException($e41444145)) {
$e41444145.pyretStack.push(L[319]);
}
throw $e41444145;
}
var $ret41504151 = $Hanf_arg25524156($z41464147,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret41504151;
};
var $Hanf_arg25524156 = function(anf_arg15324155,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z41594160 = D;
var $f41654166 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg15324155):R.ffi.throwNonFunApp(L[320],dict131171.$var,[anf_arg15324155]);
};
try {
if(--R.GAS > 0) {
$z41594160 = $f41654166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41654166,
"from":L[320]});
}
} catch($e41574158) {
if(R.isCont($e41574158)) {
var $ss41614162 = {"from":L[320],
"go":function(anf_arg15334167) {
return $Hanf_arg25514168(anf_arg15334167,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e41574158.stack[R.EXN_STACKHEIGHT++] = $ss41614162;
}
if(R.isPyretException($e41574158)) {
$e41574158.pyretStack.push(L[320]);
}
throw $e41574158;
}
var $ret41634164 = $Hanf_arg25514168($z41594160,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret41634164;
};
var $Hanf_arg25514168 = function(anf_arg15334167,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15344179 = G(list2776,"make",L[321]);
var $z41714172 = D;
var $f41774178 = function(_) {
return R.isFunction(anf_fun15344179)?anf_fun15344179.app([]):R.ffi.throwNonFunApp(L[321],anf_fun15344179,[[]]);
};
try {
if(--R.GAS > 0) {
$z41714172 = $f41774178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41774178,
"from":L[321]});
}
} catch($e41694170) {
if(R.isCont($e41694170)) {
var $ss41734174 = {"from":L[321],
"go":function(anf_arg15354180) {
return $Hanf_arg25504181(anf_arg15354180,anf_arg15304142,anf_arg15334167,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e41694170.stack[R.EXN_STACKHEIGHT++] = $ss41734174;
}
if(R.isPyretException($e41694170)) {
$e41694170.pyretStack.push(L[321]);
}
throw $e41694170;
}
var $ret41754176 = $Hanf_arg25504181($z41714172,anf_arg15304142,anf_arg15334167,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret41754176;
};
var $Hanf_arg25504181 = function(anf_arg15354180,anf_arg15304142,anf_arg15334167,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z41844185 = D;
var $f41904191 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg15334167,anf_arg15354180):R.ffi.throwNonFunApp(L[322],success100109.$var,[anf_arg15334167,anf_arg15354180]);
};
try {
if(--R.GAS > 0) {
$z41844185 = $f41904191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41904191,
"from":L[322]});
}
} catch($e41824183) {
if(R.isCont($e41824183)) {
var $ss41864187 = {"from":L[322],
"go":function(anf_arg15364192) {
return $Hanf_arg25494193(anf_arg15364192,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e41824183.stack[R.EXN_STACKHEIGHT++] = $ss41864187;
}
if(R.isPyretException($e41824183)) {
$e41824183.pyretStack.push(L[322]);
}
throw $e41824183;
}
var $ret41884189 = $Hanf_arg25494193($z41844185,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret41884189;
};
var $Hanf_arg25494193 = function(anf_arg15364192,anf_arg15304142,anf_fun15274130,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg15374204 = R.makeSrcloc(L[316]);
var $z41964197 = D;
var $f42024203 = function(_) {
return R.isFunction(anf_fun15274130)?anf_fun15274130.app(("parse-args(once-required-next-default, [list: \"-f\"]) is\n  success(dict([list: \"foo\", 42]), [list: ])"),anf_arg15304142,anf_arg15364192,anf_arg15374204):R.ffi.throwNonFunApp(L[316],anf_fun15274130,[("parse-args(once-required-next-default, [list: \"-f\"]) is\n  success(dict([list: \"foo\", 42]), [list: ])"),anf_arg15304142,anf_arg15364192,anf_arg15374204]);
};
try {
if(--R.GAS > 0) {
$z41964197 = $f42024203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42024203,
"from":L[316]});
}
} catch($e41944195) {
if(R.isCont($e41944195)) {
var $ss41984199 = {"from":L[316],
"go":function(anf_begin_app_dropped23214205) {
return $Hanf_begin_app_dropped25484206(anf_begin_app_dropped23214205,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e41944195.stack[R.EXN_STACKHEIGHT++] = $ss41984199;
}
if(R.isPyretException($e41944195)) {
$e41944195.pyretStack.push(L[316]);
}
throw $e41944195;
}
var $ret42004201 = $Hanf_begin_app_dropped25484206($z41964197,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret42004201;
};
var $Hanf_begin_app_dropped25484206 = function(anf_begin_app_dropped23214205,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15384217 = G(builtins15,"current-checker",L[323]);
var $z42094210 = D;
var $f42154216 = function(_) {
return R.isFunction(anf_fun15384217)?anf_fun15384217.app():R.ffi.throwNonFunApp(L[323],anf_fun15384217,[]);
};
try {
if(--R.GAS > 0) {
$z42094210 = $f42154216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42154216,
"from":L[323]});
}
} catch($e42074208) {
if(R.isCont($e42074208)) {
var $ss42114212 = {"from":L[323],
"go":function(anf_bracket15394218) {
return $Hanf_bracket25474219(anf_bracket15394218,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e42074208.stack[R.EXN_STACKHEIGHT++] = $ss42114212;
}
if(R.isPyretException($e42074208)) {
$e42074208.pyretStack.push(L[323]);
}
throw $e42074208;
}
var $ret42134214 = $Hanf_bracket25474219($z42094210,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret42134214;
};
var $Hanf_bracket25474219 = function(anf_bracket15394218,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15404232 = G(anf_bracket15394218,"check-is",L[323]);
var anf_fun15414230 = G(list2776,"make",L[324]);
var $z42224223 = D;
var $f42284229 = function(_) {
return R.isFunction(anf_fun15414230)?anf_fun15414230.app([("--foo")]):R.ffi.throwNonFunApp(L[324],anf_fun15414230,[[("--foo")]]);
};
try {
if(--R.GAS > 0) {
$z42224223 = $f42284229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42284229,
"from":L[324]});
}
} catch($e42204221) {
if(R.isCont($e42204221)) {
var $ss42244225 = {"from":L[324],
"go":function(anf_arg15424231) {
return $Hanf_arg25464233(anf_arg15424231,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e42204221.stack[R.EXN_STACKHEIGHT++] = $ss42244225;
}
if(R.isPyretException($e42204221)) {
$e42204221.pyretStack.push(L[324]);
}
throw $e42204221;
}
var $ret42264227 = $Hanf_arg25464233($z42224223,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret42264227;
};
var $Hanf_arg25464233 = function(anf_arg15424231,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z42364237 = D;
var $f42424243 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_next_DASH_default3443886,anf_arg15424231):R.ffi.throwNonFunApp(L[325],parse_DASH_args129167.$var,[once_DASH_required_DASH_next_DASH_default3443886,anf_arg15424231]);
};
try {
if(--R.GAS > 0) {
$z42364237 = $f42424243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42424243,
"from":L[325]});
}
} catch($e42344235) {
if(R.isCont($e42344235)) {
var $ss42384239 = {"from":L[325],
"go":function(anf_arg15434244) {
return $Hanf_arg25454245(anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e42344235.stack[R.EXN_STACKHEIGHT++] = $ss42384239;
}
if(R.isPyretException($e42344235)) {
$e42344235.pyretStack.push(L[325]);
}
throw $e42344235;
}
var $ret42404241 = $Hanf_arg25454245($z42364237,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret42404241;
};
var $Hanf_arg25454245 = function(anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15444256 = G(list2776,"make",L[326]);
var $z42484249 = D;
var $f42544255 = function(_) {
return R.isFunction(anf_fun15444256)?anf_fun15444256.app([("foo"),(42)]):R.ffi.throwNonFunApp(L[326],anf_fun15444256,[[("foo"),(42)]]);
};
try {
if(--R.GAS > 0) {
$z42484249 = $f42544255();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42544255,
"from":L[326]});
}
} catch($e42464247) {
if(R.isCont($e42464247)) {
var $ss42504251 = {"from":L[326],
"go":function(anf_arg15454257) {
return $Hanf_arg25444258(anf_arg15454257,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e42464247.stack[R.EXN_STACKHEIGHT++] = $ss42504251;
}
if(R.isPyretException($e42464247)) {
$e42464247.pyretStack.push(L[326]);
}
throw $e42464247;
}
var $ret42524253 = $Hanf_arg25444258($z42484249,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret42524253;
};
var $Hanf_arg25444258 = function(anf_arg15454257,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z42614262 = D;
var $f42674268 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg15454257):R.ffi.throwNonFunApp(L[327],dict131171.$var,[anf_arg15454257]);
};
try {
if(--R.GAS > 0) {
$z42614262 = $f42674268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42674268,
"from":L[327]});
}
} catch($e42594260) {
if(R.isCont($e42594260)) {
var $ss42634264 = {"from":L[327],
"go":function(anf_arg15464269) {
return $Hanf_arg25434270(anf_arg15464269,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e42594260.stack[R.EXN_STACKHEIGHT++] = $ss42634264;
}
if(R.isPyretException($e42594260)) {
$e42594260.pyretStack.push(L[327]);
}
throw $e42594260;
}
var $ret42654266 = $Hanf_arg25434270($z42614262,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret42654266;
};
var $Hanf_arg25434270 = function(anf_arg15464269,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15474281 = G(list2776,"make",L[328]);
var $z42734274 = D;
var $f42794280 = function(_) {
return R.isFunction(anf_fun15474281)?anf_fun15474281.app([]):R.ffi.throwNonFunApp(L[328],anf_fun15474281,[[]]);
};
try {
if(--R.GAS > 0) {
$z42734274 = $f42794280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42794280,
"from":L[328]});
}
} catch($e42714272) {
if(R.isCont($e42714272)) {
var $ss42754276 = {"from":L[328],
"go":function(anf_arg15484282) {
return $Hanf_arg25424283(anf_arg15484282,anf_arg15434244,anf_arg15464269,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e42714272.stack[R.EXN_STACKHEIGHT++] = $ss42754276;
}
if(R.isPyretException($e42714272)) {
$e42714272.pyretStack.push(L[328]);
}
throw $e42714272;
}
var $ret42774278 = $Hanf_arg25424283($z42734274,anf_arg15434244,anf_arg15464269,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret42774278;
};
var $Hanf_arg25424283 = function(anf_arg15484282,anf_arg15434244,anf_arg15464269,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z42864287 = D;
var $f42924293 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg15464269,anf_arg15484282):R.ffi.throwNonFunApp(L[329],success100109.$var,[anf_arg15464269,anf_arg15484282]);
};
try {
if(--R.GAS > 0) {
$z42864287 = $f42924293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42924293,
"from":L[329]});
}
} catch($e42844285) {
if(R.isCont($e42844285)) {
var $ss42884289 = {"from":L[329],
"go":function(anf_arg15494294) {
return $Hanf_arg25414295(anf_arg15494294,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e42844285.stack[R.EXN_STACKHEIGHT++] = $ss42884289;
}
if(R.isPyretException($e42844285)) {
$e42844285.pyretStack.push(L[329]);
}
throw $e42844285;
}
var $ret42904291 = $Hanf_arg25414295($z42864287,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret42904291;
};
var $Hanf_arg25414295 = function(anf_arg15494294,anf_arg15434244,anf_fun15404232,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg15504306 = R.makeSrcloc(L[323]);
var $z42984299 = D;
var $f43044305 = function(_) {
return R.isFunction(anf_fun15404232)?anf_fun15404232.app(("parse-args(once-required-next-default, [list: \"--foo\"]) is\n  success(dict([list: \"foo\", 42]), [list: ])"),anf_arg15434244,anf_arg15494294,anf_arg15504306):R.ffi.throwNonFunApp(L[323],anf_fun15404232,[("parse-args(once-required-next-default, [list: \"--foo\"]) is\n  success(dict([list: \"foo\", 42]), [list: ])"),anf_arg15434244,anf_arg15494294,anf_arg15504306]);
};
try {
if(--R.GAS > 0) {
$z42984299 = $f43044305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43044305,
"from":L[323]});
}
} catch($e42964297) {
if(R.isCont($e42964297)) {
var $ss43004301 = {"from":L[323],
"go":function(anf_begin_app_dropped23224307) {
return $Hanf_begin_app_dropped25404308(anf_begin_app_dropped23224307,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e42964297.stack[R.EXN_STACKHEIGHT++] = $ss43004301;
}
if(R.isPyretException($e42964297)) {
$e42964297.pyretStack.push(L[323]);
}
throw $e42964297;
}
var $ret43024303 = $Hanf_begin_app_dropped25404308($z42984299,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret43024303;
};
var $Hanf_begin_app_dropped25404308 = function(anf_begin_app_dropped23224307,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15514319 = G(builtins15,"current-checker",L[330]);
var $z43114312 = D;
var $f43174318 = function(_) {
return R.isFunction(anf_fun15514319)?anf_fun15514319.app():R.ffi.throwNonFunApp(L[330],anf_fun15514319,[]);
};
try {
if(--R.GAS > 0) {
$z43114312 = $f43174318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43174318,
"from":L[330]});
}
} catch($e43094310) {
if(R.isCont($e43094310)) {
var $ss43134314 = {"from":L[330],
"go":function(anf_bracket15524320) {
return $Hanf_bracket25394321(anf_bracket15524320,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e43094310.stack[R.EXN_STACKHEIGHT++] = $ss43134314;
}
if(R.isPyretException($e43094310)) {
$e43094310.pyretStack.push(L[330]);
}
throw $e43094310;
}
var $ret43154316 = $Hanf_bracket25394321($z43114312,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret43154316;
};
var $Hanf_bracket25394321 = function(anf_bracket15524320,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15534334 = G(anf_bracket15524320,"check-is",L[330]);
var anf_fun15544332 = G(list2776,"make",L[331]);
var $z43244325 = D;
var $f43304331 = function(_) {
return R.isFunction(anf_fun15544332)?anf_fun15544332.app([("--foo"),("-bar")]):R.ffi.throwNonFunApp(L[331],anf_fun15544332,[[("--foo"),("-bar")]]);
};
try {
if(--R.GAS > 0) {
$z43244325 = $f43304331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43304331,
"from":L[331]});
}
} catch($e43224323) {
if(R.isCont($e43224323)) {
var $ss43264327 = {"from":L[331],
"go":function(anf_arg15554333) {
return $Hanf_arg25384335(anf_arg15554333,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e43224323.stack[R.EXN_STACKHEIGHT++] = $ss43264327;
}
if(R.isPyretException($e43224323)) {
$e43224323.pyretStack.push(L[331]);
}
throw $e43224323;
}
var $ret43284329 = $Hanf_arg25384335($z43244325,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret43284329;
};
var $Hanf_arg25384335 = function(anf_arg15554333,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z43384339 = D;
var $f43444345 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_next_DASH_default3443886,anf_arg15554333):R.ffi.throwNonFunApp(L[332],parse_DASH_args129167.$var,[once_DASH_required_DASH_next_DASH_default3443886,anf_arg15554333]);
};
try {
if(--R.GAS > 0) {
$z43384339 = $f43444345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43444345,
"from":L[332]});
}
} catch($e43364337) {
if(R.isCont($e43364337)) {
var $ss43404341 = {"from":L[332],
"go":function(anf_arg15564346) {
return $Hanf_arg25374347(anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e43364337.stack[R.EXN_STACKHEIGHT++] = $ss43404341;
}
if(R.isPyretException($e43364337)) {
$e43364337.pyretStack.push(L[332]);
}
throw $e43364337;
}
var $ret43424343 = $Hanf_arg25374347($z43384339,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret43424343;
};
var $Hanf_arg25374347 = function(anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15574358 = G(list2776,"make",L[333]);
var $z43504351 = D;
var $f43564357 = function(_) {
return R.isFunction(anf_fun15574358)?anf_fun15574358.app([("foo"),(42),("bar"),(true)]):R.ffi.throwNonFunApp(L[333],anf_fun15574358,[[("foo"),(42),("bar"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z43504351 = $f43564357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43564357,
"from":L[333]});
}
} catch($e43484349) {
if(R.isCont($e43484349)) {
var $ss43524353 = {"from":L[333],
"go":function(anf_arg15584359) {
return $Hanf_arg25364360(anf_arg15584359,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e43484349.stack[R.EXN_STACKHEIGHT++] = $ss43524353;
}
if(R.isPyretException($e43484349)) {
$e43484349.pyretStack.push(L[333]);
}
throw $e43484349;
}
var $ret43544355 = $Hanf_arg25364360($z43504351,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret43544355;
};
var $Hanf_arg25364360 = function(anf_arg15584359,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z43634364 = D;
var $f43694370 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg15584359):R.ffi.throwNonFunApp(L[334],dict131171.$var,[anf_arg15584359]);
};
try {
if(--R.GAS > 0) {
$z43634364 = $f43694370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43694370,
"from":L[334]});
}
} catch($e43614362) {
if(R.isCont($e43614362)) {
var $ss43654366 = {"from":L[334],
"go":function(anf_arg15594371) {
return $Hanf_arg25354372(anf_arg15594371,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e43614362.stack[R.EXN_STACKHEIGHT++] = $ss43654366;
}
if(R.isPyretException($e43614362)) {
$e43614362.pyretStack.push(L[334]);
}
throw $e43614362;
}
var $ret43674368 = $Hanf_arg25354372($z43634364,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret43674368;
};
var $Hanf_arg25354372 = function(anf_arg15594371,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15604383 = G(list2776,"make",L[335]);
var $z43754376 = D;
var $f43814382 = function(_) {
return R.isFunction(anf_fun15604383)?anf_fun15604383.app([]):R.ffi.throwNonFunApp(L[335],anf_fun15604383,[[]]);
};
try {
if(--R.GAS > 0) {
$z43754376 = $f43814382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43814382,
"from":L[335]});
}
} catch($e43734374) {
if(R.isCont($e43734374)) {
var $ss43774378 = {"from":L[335],
"go":function(anf_arg15614384) {
return $Hanf_arg25344385(anf_arg15614384,anf_arg15564346,anf_arg15594371,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e43734374.stack[R.EXN_STACKHEIGHT++] = $ss43774378;
}
if(R.isPyretException($e43734374)) {
$e43734374.pyretStack.push(L[335]);
}
throw $e43734374;
}
var $ret43794380 = $Hanf_arg25344385($z43754376,anf_arg15564346,anf_arg15594371,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret43794380;
};
var $Hanf_arg25344385 = function(anf_arg15614384,anf_arg15564346,anf_arg15594371,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z43884389 = D;
var $f43944395 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg15594371,anf_arg15614384):R.ffi.throwNonFunApp(L[336],success100109.$var,[anf_arg15594371,anf_arg15614384]);
};
try {
if(--R.GAS > 0) {
$z43884389 = $f43944395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43944395,
"from":L[336]});
}
} catch($e43864387) {
if(R.isCont($e43864387)) {
var $ss43904391 = {"from":L[336],
"go":function(anf_arg15624396) {
return $Hanf_arg25334397(anf_arg15624396,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e43864387.stack[R.EXN_STACKHEIGHT++] = $ss43904391;
}
if(R.isPyretException($e43864387)) {
$e43864387.pyretStack.push(L[336]);
}
throw $e43864387;
}
var $ret43924393 = $Hanf_arg25334397($z43884389,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret43924393;
};
var $Hanf_arg25334397 = function(anf_arg15624396,anf_arg15564346,anf_fun15534334,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg15634408 = R.makeSrcloc(L[330]);
var $z44004401 = D;
var $f44064407 = function(_) {
return R.isFunction(anf_fun15534334)?anf_fun15534334.app(("parse-args(once-required-next-default, [list: \"--foo\", \"-bar\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg15564346,anf_arg15624396,anf_arg15634408):R.ffi.throwNonFunApp(L[330],anf_fun15534334,[("parse-args(once-required-next-default, [list: \"--foo\", \"-bar\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg15564346,anf_arg15624396,anf_arg15634408]);
};
try {
if(--R.GAS > 0) {
$z44004401 = $f44064407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44064407,
"from":L[330]});
}
} catch($e43984399) {
if(R.isCont($e43984399)) {
var $ss44024403 = {"from":L[330],
"go":function(anf_begin_app_dropped23234409) {
return $Hanf_begin_app_dropped25324410(anf_begin_app_dropped23234409,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e43984399.stack[R.EXN_STACKHEIGHT++] = $ss44024403;
}
if(R.isPyretException($e43984399)) {
$e43984399.pyretStack.push(L[330]);
}
throw $e43984399;
}
var $ret44044405 = $Hanf_begin_app_dropped25324410($z44004401,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret44044405;
};
var $Hanf_begin_app_dropped25324410 = function(anf_begin_app_dropped23234409,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15644421 = G(builtins15,"current-checker",L[337]);
var $z44134414 = D;
var $f44194420 = function(_) {
return R.isFunction(anf_fun15644421)?anf_fun15644421.app():R.ffi.throwNonFunApp(L[337],anf_fun15644421,[]);
};
try {
if(--R.GAS > 0) {
$z44134414 = $f44194420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44194420,
"from":L[337]});
}
} catch($e44114412) {
if(R.isCont($e44114412)) {
var $ss44154416 = {"from":L[337],
"go":function(anf_bracket15654422) {
return $Hanf_bracket25314423(anf_bracket15654422,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e44114412.stack[R.EXN_STACKHEIGHT++] = $ss44154416;
}
if(R.isPyretException($e44114412)) {
$e44114412.pyretStack.push(L[337]);
}
throw $e44114412;
}
var $ret44174418 = $Hanf_bracket25314423($z44134414,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret44174418;
};
var $Hanf_bracket25314423 = function(anf_bracket15654422,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15664436 = G(anf_bracket15654422,"check-is",L[337]);
var anf_fun15674434 = G(list2776,"make",L[338]);
var $z44264427 = D;
var $f44324433 = function(_) {
return R.isFunction(anf_fun15674434)?anf_fun15674434.app([("-f"),("-bar")]):R.ffi.throwNonFunApp(L[338],anf_fun15674434,[[("-f"),("-bar")]]);
};
try {
if(--R.GAS > 0) {
$z44264427 = $f44324433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44324433,
"from":L[338]});
}
} catch($e44244425) {
if(R.isCont($e44244425)) {
var $ss44284429 = {"from":L[338],
"go":function(anf_arg15684435) {
return $Hanf_arg25304437(anf_arg15684435,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e44244425.stack[R.EXN_STACKHEIGHT++] = $ss44284429;
}
if(R.isPyretException($e44244425)) {
$e44244425.pyretStack.push(L[338]);
}
throw $e44244425;
}
var $ret44304431 = $Hanf_arg25304437($z44264427,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret44304431;
};
var $Hanf_arg25304437 = function(anf_arg15684435,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z44404441 = D;
var $f44464447 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_next_DASH_default3443886,anf_arg15684435):R.ffi.throwNonFunApp(L[339],parse_DASH_args129167.$var,[once_DASH_required_DASH_next_DASH_default3443886,anf_arg15684435]);
};
try {
if(--R.GAS > 0) {
$z44404441 = $f44464447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44464447,
"from":L[339]});
}
} catch($e44384439) {
if(R.isCont($e44384439)) {
var $ss44424443 = {"from":L[339],
"go":function(anf_arg15694448) {
return $Hanf_arg25294449(anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e44384439.stack[R.EXN_STACKHEIGHT++] = $ss44424443;
}
if(R.isPyretException($e44384439)) {
$e44384439.pyretStack.push(L[339]);
}
throw $e44384439;
}
var $ret44444445 = $Hanf_arg25294449($z44404441,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret44444445;
};
var $Hanf_arg25294449 = function(anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15704460 = G(list2776,"make",L[340]);
var $z44524453 = D;
var $f44584459 = function(_) {
return R.isFunction(anf_fun15704460)?anf_fun15704460.app([("foo"),(42),("bar"),(true)]):R.ffi.throwNonFunApp(L[340],anf_fun15704460,[[("foo"),(42),("bar"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z44524453 = $f44584459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44584459,
"from":L[340]});
}
} catch($e44504451) {
if(R.isCont($e44504451)) {
var $ss44544455 = {"from":L[340],
"go":function(anf_arg15714461) {
return $Hanf_arg25284462(anf_arg15714461,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e44504451.stack[R.EXN_STACKHEIGHT++] = $ss44544455;
}
if(R.isPyretException($e44504451)) {
$e44504451.pyretStack.push(L[340]);
}
throw $e44504451;
}
var $ret44564457 = $Hanf_arg25284462($z44524453,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret44564457;
};
var $Hanf_arg25284462 = function(anf_arg15714461,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z44654466 = D;
var $f44714472 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg15714461):R.ffi.throwNonFunApp(L[341],dict131171.$var,[anf_arg15714461]);
};
try {
if(--R.GAS > 0) {
$z44654466 = $f44714472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44714472,
"from":L[341]});
}
} catch($e44634464) {
if(R.isCont($e44634464)) {
var $ss44674468 = {"from":L[341],
"go":function(anf_arg15724473) {
return $Hanf_arg25274474(anf_arg15724473,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e44634464.stack[R.EXN_STACKHEIGHT++] = $ss44674468;
}
if(R.isPyretException($e44634464)) {
$e44634464.pyretStack.push(L[341]);
}
throw $e44634464;
}
var $ret44694470 = $Hanf_arg25274474($z44654466,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret44694470;
};
var $Hanf_arg25274474 = function(anf_arg15724473,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15734485 = G(list2776,"make",L[342]);
var $z44774478 = D;
var $f44834484 = function(_) {
return R.isFunction(anf_fun15734485)?anf_fun15734485.app([]):R.ffi.throwNonFunApp(L[342],anf_fun15734485,[[]]);
};
try {
if(--R.GAS > 0) {
$z44774478 = $f44834484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44834484,
"from":L[342]});
}
} catch($e44754476) {
if(R.isCont($e44754476)) {
var $ss44794480 = {"from":L[342],
"go":function(anf_arg15744486) {
return $Hanf_arg25264487(anf_arg15744486,anf_arg15694448,anf_arg15724473,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e44754476.stack[R.EXN_STACKHEIGHT++] = $ss44794480;
}
if(R.isPyretException($e44754476)) {
$e44754476.pyretStack.push(L[342]);
}
throw $e44754476;
}
var $ret44814482 = $Hanf_arg25264487($z44774478,anf_arg15694448,anf_arg15724473,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret44814482;
};
var $Hanf_arg25264487 = function(anf_arg15744486,anf_arg15694448,anf_arg15724473,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z44904491 = D;
var $f44964497 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg15724473,anf_arg15744486):R.ffi.throwNonFunApp(L[343],success100109.$var,[anf_arg15724473,anf_arg15744486]);
};
try {
if(--R.GAS > 0) {
$z44904491 = $f44964497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44964497,
"from":L[343]});
}
} catch($e44884489) {
if(R.isCont($e44884489)) {
var $ss44924493 = {"from":L[343],
"go":function(anf_arg15754498) {
return $Hanf_arg25254499(anf_arg15754498,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e44884489.stack[R.EXN_STACKHEIGHT++] = $ss44924493;
}
if(R.isPyretException($e44884489)) {
$e44884489.pyretStack.push(L[343]);
}
throw $e44884489;
}
var $ret44944495 = $Hanf_arg25254499($z44904491,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret44944495;
};
var $Hanf_arg25254499 = function(anf_arg15754498,anf_arg15694448,anf_fun15664436,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg15764510 = R.makeSrcloc(L[337]);
var $z45024503 = D;
var $f45084509 = function(_) {
return R.isFunction(anf_fun15664436)?anf_fun15664436.app(("parse-args(once-required-next-default, [list: \"-f\", \"-bar\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg15694448,anf_arg15754498,anf_arg15764510):R.ffi.throwNonFunApp(L[337],anf_fun15664436,[("parse-args(once-required-next-default, [list: \"-f\", \"-bar\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg15694448,anf_arg15754498,anf_arg15764510]);
};
try {
if(--R.GAS > 0) {
$z45024503 = $f45084509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45084509,
"from":L[337]});
}
} catch($e45004501) {
if(R.isCont($e45004501)) {
var $ss45044505 = {"from":L[337],
"go":function(anf_begin_app_dropped23244511) {
return $Hanf_begin_app_dropped25244512(anf_begin_app_dropped23244511,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e45004501.stack[R.EXN_STACKHEIGHT++] = $ss45044505;
}
if(R.isPyretException($e45004501)) {
$e45004501.pyretStack.push(L[337]);
}
throw $e45004501;
}
var $ret45064507 = $Hanf_begin_app_dropped25244512($z45024503,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret45064507;
};
var $Hanf_begin_app_dropped25244512 = function(anf_begin_app_dropped23244511,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15774523 = G(builtins15,"current-checker",L[344]);
var $z45154516 = D;
var $f45214522 = function(_) {
return R.isFunction(anf_fun15774523)?anf_fun15774523.app():R.ffi.throwNonFunApp(L[344],anf_fun15774523,[]);
};
try {
if(--R.GAS > 0) {
$z45154516 = $f45214522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45214522,
"from":L[344]});
}
} catch($e45134514) {
if(R.isCont($e45134514)) {
var $ss45174518 = {"from":L[344],
"go":function(anf_bracket15784524) {
return $Hanf_bracket25234525(anf_bracket15784524,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e45134514.stack[R.EXN_STACKHEIGHT++] = $ss45174518;
}
if(R.isPyretException($e45134514)) {
$e45134514.pyretStack.push(L[344]);
}
throw $e45134514;
}
var $ret45194520 = $Hanf_bracket25234525($z45154516,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret45194520;
};
var $Hanf_bracket25234525 = function(anf_bracket15784524,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15794538 = G(anf_bracket15784524,"check-is",L[344]);
var anf_fun15804536 = G(list2776,"make",L[345]);
var $z45284529 = D;
var $f45344535 = function(_) {
return R.isFunction(anf_fun15804536)?anf_fun15804536.app([("-bar"),("-f")]):R.ffi.throwNonFunApp(L[345],anf_fun15804536,[[("-bar"),("-f")]]);
};
try {
if(--R.GAS > 0) {
$z45284529 = $f45344535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45344535,
"from":L[345]});
}
} catch($e45264527) {
if(R.isCont($e45264527)) {
var $ss45304531 = {"from":L[345],
"go":function(anf_arg15814537) {
return $Hanf_arg25224539(anf_arg15814537,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e45264527.stack[R.EXN_STACKHEIGHT++] = $ss45304531;
}
if(R.isPyretException($e45264527)) {
$e45264527.pyretStack.push(L[345]);
}
throw $e45264527;
}
var $ret45324533 = $Hanf_arg25224539($z45284529,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret45324533;
};
var $Hanf_arg25224539 = function(anf_arg15814537,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,once_DASH_required_DASH_next_DASH_default3443886,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z45424543 = D;
var $f45484549 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(once_DASH_required_DASH_next_DASH_default3443886,anf_arg15814537):R.ffi.throwNonFunApp(L[346],parse_DASH_args129167.$var,[once_DASH_required_DASH_next_DASH_default3443886,anf_arg15814537]);
};
try {
if(--R.GAS > 0) {
$z45424543 = $f45484549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45484549,
"from":L[346]});
}
} catch($e45404541) {
if(R.isCont($e45404541)) {
var $ss45444545 = {"from":L[346],
"go":function(anf_arg15824550) {
return $Hanf_arg25214551(anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e45404541.stack[R.EXN_STACKHEIGHT++] = $ss45444545;
}
if(R.isPyretException($e45404541)) {
$e45404541.pyretStack.push(L[346]);
}
throw $e45404541;
}
var $ret45464547 = $Hanf_arg25214551($z45424543,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret45464547;
};
var $Hanf_arg25214551 = function(anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15834562 = G(list2776,"make",L[347]);
var $z45544555 = D;
var $f45604561 = function(_) {
return R.isFunction(anf_fun15834562)?anf_fun15834562.app([("foo"),(42),("bar"),(true)]):R.ffi.throwNonFunApp(L[347],anf_fun15834562,[[("foo"),(42),("bar"),(true)]]);
};
try {
if(--R.GAS > 0) {
$z45544555 = $f45604561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45604561,
"from":L[347]});
}
} catch($e45524553) {
if(R.isCont($e45524553)) {
var $ss45564557 = {"from":L[347],
"go":function(anf_arg15844563) {
return $Hanf_arg25204564(anf_arg15844563,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e45524553.stack[R.EXN_STACKHEIGHT++] = $ss45564557;
}
if(R.isPyretException($e45524553)) {
$e45524553.pyretStack.push(L[347]);
}
throw $e45524553;
}
var $ret45584559 = $Hanf_arg25204564($z45544555,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret45584559;
};
var $Hanf_arg25204564 = function(anf_arg15844563,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z45674568 = D;
var $f45734574 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg15844563):R.ffi.throwNonFunApp(L[348],dict131171.$var,[anf_arg15844563]);
};
try {
if(--R.GAS > 0) {
$z45674568 = $f45734574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45734574,
"from":L[348]});
}
} catch($e45654566) {
if(R.isCont($e45654566)) {
var $ss45694570 = {"from":L[348],
"go":function(anf_arg15854575) {
return $Hanf_arg25194576(anf_arg15854575,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e45654566.stack[R.EXN_STACKHEIGHT++] = $ss45694570;
}
if(R.isPyretException($e45654566)) {
$e45654566.pyretStack.push(L[348]);
}
throw $e45654566;
}
var $ret45714572 = $Hanf_arg25194576($z45674568,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret45714572;
};
var $Hanf_arg25194576 = function(anf_arg15854575,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15864587 = G(list2776,"make",L[349]);
var $z45794580 = D;
var $f45854586 = function(_) {
return R.isFunction(anf_fun15864587)?anf_fun15864587.app([]):R.ffi.throwNonFunApp(L[349],anf_fun15864587,[[]]);
};
try {
if(--R.GAS > 0) {
$z45794580 = $f45854586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45854586,
"from":L[349]});
}
} catch($e45774578) {
if(R.isCont($e45774578)) {
var $ss45814582 = {"from":L[349],
"go":function(anf_arg15874588) {
return $Hanf_arg25184589(anf_arg15874588,anf_arg15824550,anf_arg15854575,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e45774578.stack[R.EXN_STACKHEIGHT++] = $ss45814582;
}
if(R.isPyretException($e45774578)) {
$e45774578.pyretStack.push(L[349]);
}
throw $e45774578;
}
var $ret45834584 = $Hanf_arg25184589($z45794580,anf_arg15824550,anf_arg15854575,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret45834584;
};
var $Hanf_arg25184589 = function(anf_arg15874588,anf_arg15824550,anf_arg15854575,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z45924593 = D;
var $f45984599 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg15854575,anf_arg15874588):R.ffi.throwNonFunApp(L[350],success100109.$var,[anf_arg15854575,anf_arg15874588]);
};
try {
if(--R.GAS > 0) {
$z45924593 = $f45984599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45984599,
"from":L[350]});
}
} catch($e45904591) {
if(R.isCont($e45904591)) {
var $ss45944595 = {"from":L[350],
"go":function(anf_arg15884600) {
return $Hanf_arg25174601(anf_arg15884600,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e45904591.stack[R.EXN_STACKHEIGHT++] = $ss45944595;
}
if(R.isPyretException($e45904591)) {
$e45904591.pyretStack.push(L[350]);
}
throw $e45904591;
}
var $ret45964597 = $Hanf_arg25174601($z45924593,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret45964597;
};
var $Hanf_arg25174601 = function(anf_arg15884600,anf_arg15824550,anf_fun15794538,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg15894612 = R.makeSrcloc(L[344]);
var $z46044605 = D;
var $f46104611 = function(_) {
return R.isFunction(anf_fun15794538)?anf_fun15794538.app(("parse-args(once-required-next-default, [list: \"-bar\", \"-f\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg15824550,anf_arg15884600,anf_arg15894612):R.ffi.throwNonFunApp(L[344],anf_fun15794538,[("parse-args(once-required-next-default, [list: \"-bar\", \"-f\"]) is\n  success(dict([list: \"foo\", 42, \"bar\", true]), [list: ])"),anf_arg15824550,anf_arg15884600,anf_arg15894612]);
};
try {
if(--R.GAS > 0) {
$z46044605 = $f46104611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46104611,
"from":L[344]});
}
} catch($e46024603) {
if(R.isCont($e46024603)) {
var $ss46064607 = {"from":L[344],
"go":function(anf_begin_app_dropped23254613) {
return $Hanf_begin_app_dropped25164614(anf_begin_app_dropped23254613,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e46024603.stack[R.EXN_STACKHEIGHT++] = $ss46064607;
}
if(R.isPyretException($e46024603)) {
$e46024603.pyretStack.push(L[344]);
}
throw $e46024603;
}
var $ret46084609 = $Hanf_begin_app_dropped25164614($z46044605,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret46084609;
};
var $Hanf_begin_app_dropped25164614 = function(anf_begin_app_dropped23254613,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z46174618 = D;
var $f46234624 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(many109127.$var,("Foo")):R.ffi.throwNonFunApp(L[351],flag118145.$var,[many109127.$var,("Foo")]);
};
try {
if(--R.GAS > 0) {
$z46174618 = $f46234624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46234624,
"from":L[351]});
}
} catch($e46154616) {
if(R.isCont($e46154616)) {
var $ss46194620 = {"from":L[351],
"go":function(anf_obj15904625) {
return $Hanf_obj25154626(anf_obj15904625,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e46154616.stack[R.EXN_STACKHEIGHT++] = $ss46194620;
}
if(R.isPyretException($e46154616)) {
$e46154616.pyretStack.push(L[351]);
}
throw $e46154616;
}
var $ret46214622 = $Hanf_obj25154626($z46174618,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret46214622;
};
var $Hanf_obj25154626 = function(anf_obj15904625,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z46294630 = D;
var $f46354636 = function(_) {
return R.isFunction(some6478)?some6478.app(("b")):R.ffi.throwNonFunApp(L[352],some6478,[("b")]);
};
try {
if(--R.GAS > 0) {
$z46294630 = $f46354636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46354636,
"from":L[352]});
}
} catch($e46274628) {
if(R.isCont($e46274628)) {
var $ss46314632 = {"from":L[352],
"go":function(anf_arg15914637) {
return $Hanf_arg25144638(anf_arg15914637,anf_obj15904625,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e46274628.stack[R.EXN_STACKHEIGHT++] = $ss46314632;
}
if(R.isPyretException($e46274628)) {
$e46274628.pyretStack.push(L[352]);
}
throw $e46274628;
}
var $ret46334634 = $Hanf_arg25144638($z46294630,anf_obj15904625,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret46334634;
};
var $Hanf_arg25144638 = function(anf_arg15914637,anf_obj15904625,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z46414642 = D;
var $f46474648 = function(_) {
return R.isFunction(next_DASH_val_DASH_default126161.$var)?next_DASH_val_DASH_default126161.$var.app(read_DASH_number8987.$var,(42),anf_arg15914637,many109127.$var,("Bar")):R.ffi.throwNonFunApp(L[353],next_DASH_val_DASH_default126161.$var,[read_DASH_number8987.$var,(42),anf_arg15914637,many109127.$var,("Bar")]);
};
try {
if(--R.GAS > 0) {
$z46414642 = $f46474648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46474648,
"from":L[353]});
}
} catch($e46394640) {
if(R.isCont($e46394640)) {
var $ss46434644 = {"from":L[353],
"go":function(anf_obj15924649) {
return $Hanf_obj25134650(anf_obj15924649,anf_obj15904625,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e46394640.stack[R.EXN_STACKHEIGHT++] = $ss46434644;
}
if(R.isPyretException($e46394640)) {
$e46394640.pyretStack.push(L[353]);
}
throw $e46394640;
}
var $ret46454646 = $Hanf_obj25134650($z46414642,anf_obj15904625,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret46454646;
};
var $Hanf_obj25134650 = function(anf_obj15924649,anf_obj15904625,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z46534654 = D;
var $f46594660 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(many109127.$var,("Flag-4")):R.ffi.throwNonFunApp(L[354],flag118145.$var,[many109127.$var,("Flag-4")]);
};
try {
if(--R.GAS > 0) {
$z46534654 = $f46594660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46594660,
"from":L[354]});
}
} catch($e46514652) {
if(R.isCont($e46514652)) {
var $ss46554656 = {"from":L[354],
"go":function(anf_obj15934661) {
return $Hanf_obj25124662(anf_obj15934661,anf_obj15904625,anf_obj15924649,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e46514652.stack[R.EXN_STACKHEIGHT++] = $ss46554656;
}
if(R.isPyretException($e46514652)) {
$e46514652.pyretStack.push(L[354]);
}
throw $e46514652;
}
var $ret46574658 = $Hanf_obj25124662($z46534654,anf_obj15904625,anf_obj15924649,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret46574658;
};
var $Hanf_obj25124662 = function(anf_obj15934661,anf_obj15904625,anf_obj15924649,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var many_DASH_optional_DASH_flag3454675 = R.makeObject({"foo":anf_obj15904625,
"bar":anf_obj15924649,
"4":anf_obj15934661});
var anf_fun15944673 = G(builtins15,"current-checker",L[355]);
var $z46654666 = D;
var $f46714672 = function(_) {
return R.isFunction(anf_fun15944673)?anf_fun15944673.app():R.ffi.throwNonFunApp(L[355],anf_fun15944673,[]);
};
try {
if(--R.GAS > 0) {
$z46654666 = $f46714672();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46714672,
"from":L[355]});
}
} catch($e46634664) {
if(R.isCont($e46634664)) {
var $ss46674668 = {"from":L[355],
"go":function(anf_bracket15954674) {
return $Hanf_bracket25114676(anf_bracket15954674,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e46634664.stack[R.EXN_STACKHEIGHT++] = $ss46674668;
}
if(R.isPyretException($e46634664)) {
$e46634664.pyretStack.push(L[355]);
}
throw $e46634664;
}
var $ret46694670 = $Hanf_bracket25114676($z46654666,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret46694670;
};
var $Hanf_bracket25114676 = function(anf_bracket15954674,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun15964689 = G(anf_bracket15954674,"check-is",L[355]);
var anf_fun15974687 = G(list2776,"make",L[356]);
var $z46794680 = D;
var $f46854686 = function(_) {
return R.isFunction(anf_fun15974687)?anf_fun15974687.app([("-foo"),("-foo"),("-foo")]):R.ffi.throwNonFunApp(L[356],anf_fun15974687,[[("-foo"),("-foo"),("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z46794680 = $f46854686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46854686,
"from":L[356]});
}
} catch($e46774678) {
if(R.isCont($e46774678)) {
var $ss46814682 = {"from":L[356],
"go":function(anf_arg15984688) {
return $Hanf_arg25104690(anf_arg15984688,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e46774678.stack[R.EXN_STACKHEIGHT++] = $ss46814682;
}
if(R.isPyretException($e46774678)) {
$e46774678.pyretStack.push(L[356]);
}
throw $e46774678;
}
var $ret46834684 = $Hanf_arg25104690($z46794680,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret46834684;
};
var $Hanf_arg25104690 = function(anf_arg15984688,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z46934694 = D;
var $f46994700 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_optional_DASH_flag3454675,anf_arg15984688):R.ffi.throwNonFunApp(L[357],parse_DASH_args129167.$var,[many_DASH_optional_DASH_flag3454675,anf_arg15984688]);
};
try {
if(--R.GAS > 0) {
$z46934694 = $f46994700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46994700,
"from":L[357]});
}
} catch($e46914692) {
if(R.isCont($e46914692)) {
var $ss46954696 = {"from":L[357],
"go":function(anf_arg15994701) {
return $Hanf_arg25094702(anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e46914692.stack[R.EXN_STACKHEIGHT++] = $ss46954696;
}
if(R.isPyretException($e46914692)) {
$e46914692.pyretStack.push(L[357]);
}
throw $e46914692;
}
var $ret46974698 = $Hanf_arg25094702($z46934694,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret46974698;
};
var $Hanf_arg25094702 = function(anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16004715 = G(list2776,"make",L[359]);
var anf_fun16014713 = G(list2776,"make",L[358]);
var $z47054706 = D;
var $f47114712 = function(_) {
return R.isFunction(anf_fun16014713)?anf_fun16014713.app([(true),(true),(true)]):R.ffi.throwNonFunApp(L[358],anf_fun16014713,[[(true),(true),(true)]]);
};
try {
if(--R.GAS > 0) {
$z47054706 = $f47114712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47114712,
"from":L[358]});
}
} catch($e47034704) {
if(R.isCont($e47034704)) {
var $ss47074708 = {"from":L[358],
"go":function(anf_array_val16024714) {
return $Hanf_array_val25084716(anf_array_val16024714,anf_arg15994701,anf_fun15964689,anf_fun16004715,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e47034704.stack[R.EXN_STACKHEIGHT++] = $ss47074708;
}
if(R.isPyretException($e47034704)) {
$e47034704.pyretStack.push(L[358]);
}
throw $e47034704;
}
var $ret47094710 = $Hanf_array_val25084716($z47054706,anf_arg15994701,anf_fun15964689,anf_fun16004715,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret47094710;
};
var $Hanf_array_val25084716 = function(anf_array_val16024714,anf_arg15994701,anf_fun15964689,anf_fun16004715,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z47194720 = D;
var $f47254726 = function(_) {
return R.isFunction(anf_fun16004715)?anf_fun16004715.app([("foo"),anf_array_val16024714]):R.ffi.throwNonFunApp(L[359],anf_fun16004715,[[("foo"),anf_array_val16024714]]);
};
try {
if(--R.GAS > 0) {
$z47194720 = $f47254726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47254726,
"from":L[359]});
}
} catch($e47174718) {
if(R.isCont($e47174718)) {
var $ss47214722 = {"from":L[359],
"go":function(anf_arg16034727) {
return $Hanf_arg25074728(anf_arg16034727,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e47174718.stack[R.EXN_STACKHEIGHT++] = $ss47214722;
}
if(R.isPyretException($e47174718)) {
$e47174718.pyretStack.push(L[359]);
}
throw $e47174718;
}
var $ret47234724 = $Hanf_arg25074728($z47194720,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret47234724;
};
var $Hanf_arg25074728 = function(anf_arg16034727,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z47314732 = D;
var $f47374738 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg16034727):R.ffi.throwNonFunApp(L[360],dict131171.$var,[anf_arg16034727]);
};
try {
if(--R.GAS > 0) {
$z47314732 = $f47374738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47374738,
"from":L[360]});
}
} catch($e47294730) {
if(R.isCont($e47294730)) {
var $ss47334734 = {"from":L[360],
"go":function(anf_arg16044739) {
return $Hanf_arg25064740(anf_arg16044739,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e47294730.stack[R.EXN_STACKHEIGHT++] = $ss47334734;
}
if(R.isPyretException($e47294730)) {
$e47294730.pyretStack.push(L[360]);
}
throw $e47294730;
}
var $ret47354736 = $Hanf_arg25064740($z47314732,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret47354736;
};
var $Hanf_arg25064740 = function(anf_arg16044739,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16054751 = G(list2776,"make",L[361]);
var $z47434744 = D;
var $f47494750 = function(_) {
return R.isFunction(anf_fun16054751)?anf_fun16054751.app([]):R.ffi.throwNonFunApp(L[361],anf_fun16054751,[[]]);
};
try {
if(--R.GAS > 0) {
$z47434744 = $f47494750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47494750,
"from":L[361]});
}
} catch($e47414742) {
if(R.isCont($e47414742)) {
var $ss47454746 = {"from":L[361],
"go":function(anf_arg16064752) {
return $Hanf_arg25054753(anf_arg16064752,anf_arg15994701,anf_arg16044739,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e47414742.stack[R.EXN_STACKHEIGHT++] = $ss47454746;
}
if(R.isPyretException($e47414742)) {
$e47414742.pyretStack.push(L[361]);
}
throw $e47414742;
}
var $ret47474748 = $Hanf_arg25054753($z47434744,anf_arg15994701,anf_arg16044739,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret47474748;
};
var $Hanf_arg25054753 = function(anf_arg16064752,anf_arg15994701,anf_arg16044739,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z47564757 = D;
var $f47624763 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg16044739,anf_arg16064752):R.ffi.throwNonFunApp(L[362],success100109.$var,[anf_arg16044739,anf_arg16064752]);
};
try {
if(--R.GAS > 0) {
$z47564757 = $f47624763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47624763,
"from":L[362]});
}
} catch($e47544755) {
if(R.isCont($e47544755)) {
var $ss47584759 = {"from":L[362],
"go":function(anf_arg16074764) {
return $Hanf_arg25044765(anf_arg16074764,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e47544755.stack[R.EXN_STACKHEIGHT++] = $ss47584759;
}
if(R.isPyretException($e47544755)) {
$e47544755.pyretStack.push(L[362]);
}
throw $e47544755;
}
var $ret47604761 = $Hanf_arg25044765($z47564757,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret47604761;
};
var $Hanf_arg25044765 = function(anf_arg16074764,anf_arg15994701,anf_fun15964689,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg16084776 = R.makeSrcloc(L[355]);
var $z47684769 = D;
var $f47744775 = function(_) {
return R.isFunction(anf_fun15964689)?anf_fun15964689.app(("parse-args(many-optional-flag, [list: \"-foo\", \"-foo\", \"-foo\"]) is\n  success(dict([list: \"foo\", [list: true, true, true]]), [list: ])"),anf_arg15994701,anf_arg16074764,anf_arg16084776):R.ffi.throwNonFunApp(L[355],anf_fun15964689,[("parse-args(many-optional-flag, [list: \"-foo\", \"-foo\", \"-foo\"]) is\n  success(dict([list: \"foo\", [list: true, true, true]]), [list: ])"),anf_arg15994701,anf_arg16074764,anf_arg16084776]);
};
try {
if(--R.GAS > 0) {
$z47684769 = $f47744775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47744775,
"from":L[355]});
}
} catch($e47664767) {
if(R.isCont($e47664767)) {
var $ss47704771 = {"from":L[355],
"go":function(anf_begin_app_dropped23264777) {
return $Hanf_begin_app_dropped25034778(anf_begin_app_dropped23264777,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e47664767.stack[R.EXN_STACKHEIGHT++] = $ss47704771;
}
if(R.isPyretException($e47664767)) {
$e47664767.pyretStack.push(L[355]);
}
throw $e47664767;
}
var $ret47724773 = $Hanf_begin_app_dropped25034778($z47684769,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret47724773;
};
var $Hanf_begin_app_dropped25034778 = function(anf_begin_app_dropped23264777,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16094789 = G(builtins15,"current-checker",L[363]);
var $z47814782 = D;
var $f47874788 = function(_) {
return R.isFunction(anf_fun16094789)?anf_fun16094789.app():R.ffi.throwNonFunApp(L[363],anf_fun16094789,[]);
};
try {
if(--R.GAS > 0) {
$z47814782 = $f47874788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47874788,
"from":L[363]});
}
} catch($e47794780) {
if(R.isCont($e47794780)) {
var $ss47834784 = {"from":L[363],
"go":function(anf_bracket16104790) {
return $Hanf_bracket25024791(anf_bracket16104790,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e47794780.stack[R.EXN_STACKHEIGHT++] = $ss47834784;
}
if(R.isPyretException($e47794780)) {
$e47794780.pyretStack.push(L[363]);
}
throw $e47794780;
}
var $ret47854786 = $Hanf_bracket25024791($z47814782,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret47854786;
};
var $Hanf_bracket25024791 = function(anf_bracket16104790,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16114804 = G(anf_bracket16104790,"check-is",L[363]);
var anf_fun16124802 = G(list2776,"make",L[364]);
var $z47944795 = D;
var $f48004801 = function(_) {
return R.isFunction(anf_fun16124802)?anf_fun16124802.app([("-b"),("-foo"),("--bar"),("3"),("--bar"),("-foo")]):R.ffi.throwNonFunApp(L[364],anf_fun16124802,[[("-b"),("-foo"),("--bar"),("3"),("--bar"),("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z47944795 = $f48004801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48004801,
"from":L[364]});
}
} catch($e47924793) {
if(R.isCont($e47924793)) {
var $ss47964797 = {"from":L[364],
"go":function(anf_arg16134803) {
return $Hanf_arg25014805(anf_arg16134803,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e47924793.stack[R.EXN_STACKHEIGHT++] = $ss47964797;
}
if(R.isPyretException($e47924793)) {
$e47924793.pyretStack.push(L[364]);
}
throw $e47924793;
}
var $ret47984799 = $Hanf_arg25014805($z47944795,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret47984799;
};
var $Hanf_arg25014805 = function(anf_arg16134803,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z48084809 = D;
var $f48144815 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_optional_DASH_flag3454675,anf_arg16134803):R.ffi.throwNonFunApp(L[365],parse_DASH_args129167.$var,[many_DASH_optional_DASH_flag3454675,anf_arg16134803]);
};
try {
if(--R.GAS > 0) {
$z48084809 = $f48144815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48144815,
"from":L[365]});
}
} catch($e48064807) {
if(R.isCont($e48064807)) {
var $ss48104811 = {"from":L[365],
"go":function(anf_arg16144816) {
return $Hanf_arg25004817(anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e48064807.stack[R.EXN_STACKHEIGHT++] = $ss48104811;
}
if(R.isPyretException($e48064807)) {
$e48064807.pyretStack.push(L[365]);
}
throw $e48064807;
}
var $ret48124813 = $Hanf_arg25004817($z48084809,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret48124813;
};
var $Hanf_arg25004817 = function(anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16154830 = G(list2776,"make",L[367]);
var anf_fun16164828 = G(list2776,"make",L[366]);
var $z48204821 = D;
var $f48264827 = function(_) {
return R.isFunction(anf_fun16164828)?anf_fun16164828.app([(true),(true)]):R.ffi.throwNonFunApp(L[366],anf_fun16164828,[[(true),(true)]]);
};
try {
if(--R.GAS > 0) {
$z48204821 = $f48264827();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48264827,
"from":L[366]});
}
} catch($e48184819) {
if(R.isCont($e48184819)) {
var $ss48224823 = {"from":L[366],
"go":function(anf_array_val16174829) {
return $Hanf_array_val24994831(anf_array_val16174829,anf_arg16144816,anf_fun16114804,anf_fun16154830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e48184819.stack[R.EXN_STACKHEIGHT++] = $ss48224823;
}
if(R.isPyretException($e48184819)) {
$e48184819.pyretStack.push(L[366]);
}
throw $e48184819;
}
var $ret48244825 = $Hanf_array_val24994831($z48204821,anf_arg16144816,anf_fun16114804,anf_fun16154830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret48244825;
};
var $Hanf_array_val24994831 = function(anf_array_val16174829,anf_arg16144816,anf_fun16114804,anf_fun16154830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16184842 = G(list2776,"make",L[368]);
var $z48344835 = D;
var $f48404841 = function(_) {
return R.isFunction(anf_fun16184842)?anf_fun16184842.app([(42),(3),(42)]):R.ffi.throwNonFunApp(L[368],anf_fun16184842,[[(42),(3),(42)]]);
};
try {
if(--R.GAS > 0) {
$z48344835 = $f48404841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48404841,
"from":L[368]});
}
} catch($e48324833) {
if(R.isCont($e48324833)) {
var $ss48364837 = {"from":L[368],
"go":function(anf_array_val16194843) {
return $Hanf_array_val24984844(anf_array_val16194843,anf_arg16144816,anf_array_val16174829,anf_fun16114804,anf_fun16154830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e48324833.stack[R.EXN_STACKHEIGHT++] = $ss48364837;
}
if(R.isPyretException($e48324833)) {
$e48324833.pyretStack.push(L[368]);
}
throw $e48324833;
}
var $ret48384839 = $Hanf_array_val24984844($z48344835,anf_arg16144816,anf_array_val16174829,anf_fun16114804,anf_fun16154830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret48384839;
};
var $Hanf_array_val24984844 = function(anf_array_val16194843,anf_arg16144816,anf_array_val16174829,anf_fun16114804,anf_fun16154830,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z48474848 = D;
var $f48534854 = function(_) {
return R.isFunction(anf_fun16154830)?anf_fun16154830.app([("foo"),anf_array_val16174829,("bar"),anf_array_val16194843]):R.ffi.throwNonFunApp(L[367],anf_fun16154830,[[("foo"),anf_array_val16174829,("bar"),anf_array_val16194843]]);
};
try {
if(--R.GAS > 0) {
$z48474848 = $f48534854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48534854,
"from":L[367]});
}
} catch($e48454846) {
if(R.isCont($e48454846)) {
var $ss48494850 = {"from":L[367],
"go":function(anf_arg16204855) {
return $Hanf_arg24974856(anf_arg16204855,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e48454846.stack[R.EXN_STACKHEIGHT++] = $ss48494850;
}
if(R.isPyretException($e48454846)) {
$e48454846.pyretStack.push(L[367]);
}
throw $e48454846;
}
var $ret48514852 = $Hanf_arg24974856($z48474848,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret48514852;
};
var $Hanf_arg24974856 = function(anf_arg16204855,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z48594860 = D;
var $f48654866 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg16204855):R.ffi.throwNonFunApp(L[369],dict131171.$var,[anf_arg16204855]);
};
try {
if(--R.GAS > 0) {
$z48594860 = $f48654866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48654866,
"from":L[369]});
}
} catch($e48574858) {
if(R.isCont($e48574858)) {
var $ss48614862 = {"from":L[369],
"go":function(anf_arg16214867) {
return $Hanf_arg24964868(anf_arg16214867,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e48574858.stack[R.EXN_STACKHEIGHT++] = $ss48614862;
}
if(R.isPyretException($e48574858)) {
$e48574858.pyretStack.push(L[369]);
}
throw $e48574858;
}
var $ret48634864 = $Hanf_arg24964868($z48594860,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret48634864;
};
var $Hanf_arg24964868 = function(anf_arg16214867,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16224879 = G(list2776,"make",L[370]);
var $z48714872 = D;
var $f48774878 = function(_) {
return R.isFunction(anf_fun16224879)?anf_fun16224879.app([]):R.ffi.throwNonFunApp(L[370],anf_fun16224879,[[]]);
};
try {
if(--R.GAS > 0) {
$z48714872 = $f48774878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48774878,
"from":L[370]});
}
} catch($e48694870) {
if(R.isCont($e48694870)) {
var $ss48734874 = {"from":L[370],
"go":function(anf_arg16234880) {
return $Hanf_arg24954881(anf_arg16234880,anf_arg16144816,anf_arg16214867,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e48694870.stack[R.EXN_STACKHEIGHT++] = $ss48734874;
}
if(R.isPyretException($e48694870)) {
$e48694870.pyretStack.push(L[370]);
}
throw $e48694870;
}
var $ret48754876 = $Hanf_arg24954881($z48714872,anf_arg16144816,anf_arg16214867,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret48754876;
};
var $Hanf_arg24954881 = function(anf_arg16234880,anf_arg16144816,anf_arg16214867,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z48844885 = D;
var $f48904891 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg16214867,anf_arg16234880):R.ffi.throwNonFunApp(L[371],success100109.$var,[anf_arg16214867,anf_arg16234880]);
};
try {
if(--R.GAS > 0) {
$z48844885 = $f48904891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48904891,
"from":L[371]});
}
} catch($e48824883) {
if(R.isCont($e48824883)) {
var $ss48864887 = {"from":L[371],
"go":function(anf_arg16244892) {
return $Hanf_arg24944893(anf_arg16244892,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e48824883.stack[R.EXN_STACKHEIGHT++] = $ss48864887;
}
if(R.isPyretException($e48824883)) {
$e48824883.pyretStack.push(L[371]);
}
throw $e48824883;
}
var $ret48884889 = $Hanf_arg24944893($z48844885,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret48884889;
};
var $Hanf_arg24944893 = function(anf_arg16244892,anf_arg16144816,anf_fun16114804,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg16254904 = R.makeSrcloc(L[363]);
var $z48964897 = D;
var $f49024903 = function(_) {
return R.isFunction(anf_fun16114804)?anf_fun16114804.app(("parse-args(many-optional-flag,\n  [list: \"-b\", \"-foo\", \"--bar\", \"3\", \"--bar\", \"-foo\"]) is\n  success(dict([list: \"foo\", [list: true, true], \"bar\", [list: 42, 3, 42]]),\n    [list: ])"),anf_arg16144816,anf_arg16244892,anf_arg16254904):R.ffi.throwNonFunApp(L[363],anf_fun16114804,[("parse-args(many-optional-flag,\n  [list: \"-b\", \"-foo\", \"--bar\", \"3\", \"--bar\", \"-foo\"]) is\n  success(dict([list: \"foo\", [list: true, true], \"bar\", [list: 42, 3, 42]]),\n    [list: ])"),anf_arg16144816,anf_arg16244892,anf_arg16254904]);
};
try {
if(--R.GAS > 0) {
$z48964897 = $f49024903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49024903,
"from":L[363]});
}
} catch($e48944895) {
if(R.isCont($e48944895)) {
var $ss48984899 = {"from":L[363],
"go":function(anf_begin_app_dropped23274905) {
return $Hanf_begin_app_dropped24934906(anf_begin_app_dropped23274905,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e48944895.stack[R.EXN_STACKHEIGHT++] = $ss48984899;
}
if(R.isPyretException($e48944895)) {
$e48944895.pyretStack.push(L[363]);
}
throw $e48944895;
}
var $ret49004901 = $Hanf_begin_app_dropped24934906($z48964897,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret49004901;
};
var $Hanf_begin_app_dropped24934906 = function(anf_begin_app_dropped23274905,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16264917 = G(builtins15,"current-checker",L[372]);
var $z49094910 = D;
var $f49154916 = function(_) {
return R.isFunction(anf_fun16264917)?anf_fun16264917.app():R.ffi.throwNonFunApp(L[372],anf_fun16264917,[]);
};
try {
if(--R.GAS > 0) {
$z49094910 = $f49154916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49154916,
"from":L[372]});
}
} catch($e49074908) {
if(R.isCont($e49074908)) {
var $ss49114912 = {"from":L[372],
"go":function(anf_bracket16274918) {
return $Hanf_bracket24924919(anf_bracket16274918,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e49074908.stack[R.EXN_STACKHEIGHT++] = $ss49114912;
}
if(R.isPyretException($e49074908)) {
$e49074908.pyretStack.push(L[372]);
}
throw $e49074908;
}
var $ret49134914 = $Hanf_bracket24924919($z49094910,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret49134914;
};
var $Hanf_bracket24924919 = function(anf_bracket16274918,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16284932 = G(anf_bracket16274918,"check-is",L[372]);
var anf_fun16294930 = G(list2776,"make",L[373]);
var $z49224923 = D;
var $f49284929 = function(_) {
return R.isFunction(anf_fun16294930)?anf_fun16294930.app([("-b"),("-foo"),("-b"),("3"),("--bar"),("-foo")]):R.ffi.throwNonFunApp(L[373],anf_fun16294930,[[("-b"),("-foo"),("-b"),("3"),("--bar"),("-foo")]]);
};
try {
if(--R.GAS > 0) {
$z49224923 = $f49284929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49284929,
"from":L[373]});
}
} catch($e49204921) {
if(R.isCont($e49204921)) {
var $ss49244925 = {"from":L[373],
"go":function(anf_arg16304931) {
return $Hanf_arg24914933(anf_arg16304931,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e49204921.stack[R.EXN_STACKHEIGHT++] = $ss49244925;
}
if(R.isPyretException($e49204921)) {
$e49204921.pyretStack.push(L[373]);
}
throw $e49204921;
}
var $ret49264927 = $Hanf_arg24914933($z49224923,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret49264927;
};
var $Hanf_arg24914933 = function(anf_arg16304931,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z49364937 = D;
var $f49424943 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_optional_DASH_flag3454675,anf_arg16304931):R.ffi.throwNonFunApp(L[374],parse_DASH_args129167.$var,[many_DASH_optional_DASH_flag3454675,anf_arg16304931]);
};
try {
if(--R.GAS > 0) {
$z49364937 = $f49424943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49424943,
"from":L[374]});
}
} catch($e49344935) {
if(R.isCont($e49344935)) {
var $ss49384939 = {"from":L[374],
"go":function(anf_arg16314944) {
return $Hanf_arg24904945(anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e49344935.stack[R.EXN_STACKHEIGHT++] = $ss49384939;
}
if(R.isPyretException($e49344935)) {
$e49344935.pyretStack.push(L[374]);
}
throw $e49344935;
}
var $ret49404941 = $Hanf_arg24904945($z49364937,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret49404941;
};
var $Hanf_arg24904945 = function(anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16324958 = G(list2776,"make",L[376]);
var anf_fun16334956 = G(list2776,"make",L[375]);
var $z49484949 = D;
var $f49544955 = function(_) {
return R.isFunction(anf_fun16334956)?anf_fun16334956.app([(true),(true)]):R.ffi.throwNonFunApp(L[375],anf_fun16334956,[[(true),(true)]]);
};
try {
if(--R.GAS > 0) {
$z49484949 = $f49544955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49544955,
"from":L[375]});
}
} catch($e49464947) {
if(R.isCont($e49464947)) {
var $ss49504951 = {"from":L[375],
"go":function(anf_array_val16344957) {
return $Hanf_array_val24894959(anf_array_val16344957,anf_arg16314944,anf_fun16284932,anf_fun16324958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e49464947.stack[R.EXN_STACKHEIGHT++] = $ss49504951;
}
if(R.isPyretException($e49464947)) {
$e49464947.pyretStack.push(L[375]);
}
throw $e49464947;
}
var $ret49524953 = $Hanf_array_val24894959($z49484949,anf_arg16314944,anf_fun16284932,anf_fun16324958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret49524953;
};
var $Hanf_array_val24894959 = function(anf_array_val16344957,anf_arg16314944,anf_fun16284932,anf_fun16324958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16354970 = G(list2776,"make",L[377]);
var $z49624963 = D;
var $f49684969 = function(_) {
return R.isFunction(anf_fun16354970)?anf_fun16354970.app([(42),(42),(42)]):R.ffi.throwNonFunApp(L[377],anf_fun16354970,[[(42),(42),(42)]]);
};
try {
if(--R.GAS > 0) {
$z49624963 = $f49684969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49684969,
"from":L[377]});
}
} catch($e49604961) {
if(R.isCont($e49604961)) {
var $ss49644965 = {"from":L[377],
"go":function(anf_array_val16364971) {
return $Hanf_array_val24884972(anf_array_val16364971,anf_arg16314944,anf_array_val16344957,anf_fun16284932,anf_fun16324958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e49604961.stack[R.EXN_STACKHEIGHT++] = $ss49644965;
}
if(R.isPyretException($e49604961)) {
$e49604961.pyretStack.push(L[377]);
}
throw $e49604961;
}
var $ret49664967 = $Hanf_array_val24884972($z49624963,anf_arg16314944,anf_array_val16344957,anf_fun16284932,anf_fun16324958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret49664967;
};
var $Hanf_array_val24884972 = function(anf_array_val16364971,anf_arg16314944,anf_array_val16344957,anf_fun16284932,anf_fun16324958,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z49754976 = D;
var $f49814982 = function(_) {
return R.isFunction(anf_fun16324958)?anf_fun16324958.app([("foo"),anf_array_val16344957,("bar"),anf_array_val16364971]):R.ffi.throwNonFunApp(L[376],anf_fun16324958,[[("foo"),anf_array_val16344957,("bar"),anf_array_val16364971]]);
};
try {
if(--R.GAS > 0) {
$z49754976 = $f49814982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49814982,
"from":L[376]});
}
} catch($e49734974) {
if(R.isCont($e49734974)) {
var $ss49774978 = {"from":L[376],
"go":function(anf_arg16374983) {
return $Hanf_arg24874984(anf_arg16374983,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e49734974.stack[R.EXN_STACKHEIGHT++] = $ss49774978;
}
if(R.isPyretException($e49734974)) {
$e49734974.pyretStack.push(L[376]);
}
throw $e49734974;
}
var $ret49794980 = $Hanf_arg24874984($z49754976,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret49794980;
};
var $Hanf_arg24874984 = function(anf_arg16374983,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z49874988 = D;
var $f49934994 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg16374983):R.ffi.throwNonFunApp(L[378],dict131171.$var,[anf_arg16374983]);
};
try {
if(--R.GAS > 0) {
$z49874988 = $f49934994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49934994,
"from":L[378]});
}
} catch($e49854986) {
if(R.isCont($e49854986)) {
var $ss49894990 = {"from":L[378],
"go":function(anf_arg16384995) {
return $Hanf_arg24864996(anf_arg16384995,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e49854986.stack[R.EXN_STACKHEIGHT++] = $ss49894990;
}
if(R.isPyretException($e49854986)) {
$e49854986.pyretStack.push(L[378]);
}
throw $e49854986;
}
var $ret49914992 = $Hanf_arg24864996($z49874988,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret49914992;
};
var $Hanf_arg24864996 = function(anf_arg16384995,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16395007 = G(list2776,"make",L[379]);
var $z49995000 = D;
var $f50055006 = function(_) {
return R.isFunction(anf_fun16395007)?anf_fun16395007.app([("3")]):R.ffi.throwNonFunApp(L[379],anf_fun16395007,[[("3")]]);
};
try {
if(--R.GAS > 0) {
$z49995000 = $f50055006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50055006,
"from":L[379]});
}
} catch($e49974998) {
if(R.isCont($e49974998)) {
var $ss50015002 = {"from":L[379],
"go":function(anf_arg16405008) {
return $Hanf_arg24855009(anf_arg16405008,anf_arg16314944,anf_arg16384995,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e49974998.stack[R.EXN_STACKHEIGHT++] = $ss50015002;
}
if(R.isPyretException($e49974998)) {
$e49974998.pyretStack.push(L[379]);
}
throw $e49974998;
}
var $ret50035004 = $Hanf_arg24855009($z49995000,anf_arg16314944,anf_arg16384995,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret50035004;
};
var $Hanf_arg24855009 = function(anf_arg16405008,anf_arg16314944,anf_arg16384995,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z50125013 = D;
var $f50185019 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg16384995,anf_arg16405008):R.ffi.throwNonFunApp(L[380],success100109.$var,[anf_arg16384995,anf_arg16405008]);
};
try {
if(--R.GAS > 0) {
$z50125013 = $f50185019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50185019,
"from":L[380]});
}
} catch($e50105011) {
if(R.isCont($e50105011)) {
var $ss50145015 = {"from":L[380],
"go":function(anf_arg16415020) {
return $Hanf_arg24845021(anf_arg16415020,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e50105011.stack[R.EXN_STACKHEIGHT++] = $ss50145015;
}
if(R.isPyretException($e50105011)) {
$e50105011.pyretStack.push(L[380]);
}
throw $e50105011;
}
var $ret50165017 = $Hanf_arg24845021($z50125013,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret50165017;
};
var $Hanf_arg24845021 = function(anf_arg16415020,anf_arg16314944,anf_fun16284932,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg16425032 = R.makeSrcloc(L[372]);
var $z50245025 = D;
var $f50305031 = function(_) {
return R.isFunction(anf_fun16284932)?anf_fun16284932.app(("parse-args(many-optional-flag, [list: \"-b\", \"-foo\", \"-b\", \"3\", \"--bar\", \"-foo\"]) is\n  success(dict([list: \"foo\", [list: true, true], \"bar\", [list: 42, 42, 42]]),\n    [list: \"3\"])"),anf_arg16314944,anf_arg16415020,anf_arg16425032):R.ffi.throwNonFunApp(L[372],anf_fun16284932,[("parse-args(many-optional-flag, [list: \"-b\", \"-foo\", \"-b\", \"3\", \"--bar\", \"-foo\"]) is\n  success(dict([list: \"foo\", [list: true, true], \"bar\", [list: 42, 42, 42]]),\n    [list: \"3\"])"),anf_arg16314944,anf_arg16415020,anf_arg16425032]);
};
try {
if(--R.GAS > 0) {
$z50245025 = $f50305031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50305031,
"from":L[372]});
}
} catch($e50225023) {
if(R.isCont($e50225023)) {
var $ss50265027 = {"from":L[372],
"go":function(anf_begin_app_dropped23285033) {
return $Hanf_begin_app_dropped24835034(anf_begin_app_dropped23285033,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e50225023.stack[R.EXN_STACKHEIGHT++] = $ss50265027;
}
if(R.isPyretException($e50225023)) {
$e50225023.pyretStack.push(L[372]);
}
throw $e50225023;
}
var $ret50285029 = $Hanf_begin_app_dropped24835034($z50245025,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret50285029;
};
var $Hanf_begin_app_dropped24835034 = function(anf_begin_app_dropped23285033,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16435045 = G(builtins15,"current-checker",L[381]);
var $z50375038 = D;
var $f50435044 = function(_) {
return R.isFunction(anf_fun16435045)?anf_fun16435045.app():R.ffi.throwNonFunApp(L[381],anf_fun16435045,[]);
};
try {
if(--R.GAS > 0) {
$z50375038 = $f50435044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50435044,
"from":L[381]});
}
} catch($e50355036) {
if(R.isCont($e50355036)) {
var $ss50395040 = {"from":L[381],
"go":function(anf_bracket16445046) {
return $Hanf_bracket24825047(anf_bracket16445046,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e50355036.stack[R.EXN_STACKHEIGHT++] = $ss50395040;
}
if(R.isPyretException($e50355036)) {
$e50355036.pyretStack.push(L[381]);
}
throw $e50355036;
}
var $ret50415042 = $Hanf_bracket24825047($z50375038,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret50415042;
};
var $Hanf_bracket24825047 = function(anf_bracket16445046,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16455060 = G(anf_bracket16445046,"check-is",L[381]);
var anf_fun16465058 = G(list2776,"make",L[382]);
var $z50505051 = D;
var $f50565057 = function(_) {
return R.isFunction(anf_fun16465058)?anf_fun16465058.app([("--bar"),("-4")]):R.ffi.throwNonFunApp(L[382],anf_fun16465058,[[("--bar"),("-4")]]);
};
try {
if(--R.GAS > 0) {
$z50505051 = $f50565057();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50565057,
"from":L[382]});
}
} catch($e50485049) {
if(R.isCont($e50485049)) {
var $ss50525053 = {"from":L[382],
"go":function(anf_arg16475059) {
return $Hanf_arg24815061(anf_arg16475059,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e50485049.stack[R.EXN_STACKHEIGHT++] = $ss50525053;
}
if(R.isPyretException($e50485049)) {
$e50485049.pyretStack.push(L[382]);
}
throw $e50485049;
}
var $ret50545055 = $Hanf_arg24815061($z50505051,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret50545055;
};
var $Hanf_arg24815061 = function(anf_arg16475059,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z50645065 = D;
var $f50705071 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_optional_DASH_flag3454675,anf_arg16475059):R.ffi.throwNonFunApp(L[383],parse_DASH_args129167.$var,[many_DASH_optional_DASH_flag3454675,anf_arg16475059]);
};
try {
if(--R.GAS > 0) {
$z50645065 = $f50705071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50705071,
"from":L[383]});
}
} catch($e50625063) {
if(R.isCont($e50625063)) {
var $ss50665067 = {"from":L[383],
"go":function(anf_arg16485072) {
return $Hanf_arg24805073(anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e50625063.stack[R.EXN_STACKHEIGHT++] = $ss50665067;
}
if(R.isPyretException($e50625063)) {
$e50625063.pyretStack.push(L[383]);
}
throw $e50625063;
}
var $ret50685069 = $Hanf_arg24805073($z50645065,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret50685069;
};
var $Hanf_arg24805073 = function(anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16495086 = G(list2776,"make",L[385]);
var anf_fun16505084 = G(list2776,"make",L[384]);
var $z50765077 = D;
var $f50825083 = function(_) {
return R.isFunction(anf_fun16505084)?anf_fun16505084.app([(-4)]):R.ffi.throwNonFunApp(L[384],anf_fun16505084,[[(-4)]]);
};
try {
if(--R.GAS > 0) {
$z50765077 = $f50825083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50825083,
"from":L[384]});
}
} catch($e50745075) {
if(R.isCont($e50745075)) {
var $ss50785079 = {"from":L[384],
"go":function(anf_array_val16515085) {
return $Hanf_array_val24795087(anf_array_val16515085,anf_arg16485072,anf_fun16455060,anf_fun16495086,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e50745075.stack[R.EXN_STACKHEIGHT++] = $ss50785079;
}
if(R.isPyretException($e50745075)) {
$e50745075.pyretStack.push(L[384]);
}
throw $e50745075;
}
var $ret50805081 = $Hanf_array_val24795087($z50765077,anf_arg16485072,anf_fun16455060,anf_fun16495086,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret50805081;
};
var $Hanf_array_val24795087 = function(anf_array_val16515085,anf_arg16485072,anf_fun16455060,anf_fun16495086,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z50905091 = D;
var $f50965097 = function(_) {
return R.isFunction(anf_fun16495086)?anf_fun16495086.app([("bar"),anf_array_val16515085]):R.ffi.throwNonFunApp(L[385],anf_fun16495086,[[("bar"),anf_array_val16515085]]);
};
try {
if(--R.GAS > 0) {
$z50905091 = $f50965097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50965097,
"from":L[385]});
}
} catch($e50885089) {
if(R.isCont($e50885089)) {
var $ss50925093 = {"from":L[385],
"go":function(anf_arg16525098) {
return $Hanf_arg24785099(anf_arg16525098,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e50885089.stack[R.EXN_STACKHEIGHT++] = $ss50925093;
}
if(R.isPyretException($e50885089)) {
$e50885089.pyretStack.push(L[385]);
}
throw $e50885089;
}
var $ret50945095 = $Hanf_arg24785099($z50905091,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret50945095;
};
var $Hanf_arg24785099 = function(anf_arg16525098,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z51025103 = D;
var $f51085109 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg16525098):R.ffi.throwNonFunApp(L[386],dict131171.$var,[anf_arg16525098]);
};
try {
if(--R.GAS > 0) {
$z51025103 = $f51085109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51085109,
"from":L[386]});
}
} catch($e51005101) {
if(R.isCont($e51005101)) {
var $ss51045105 = {"from":L[386],
"go":function(anf_arg16535110) {
return $Hanf_arg24775111(anf_arg16535110,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e51005101.stack[R.EXN_STACKHEIGHT++] = $ss51045105;
}
if(R.isPyretException($e51005101)) {
$e51005101.pyretStack.push(L[386]);
}
throw $e51005101;
}
var $ret51065107 = $Hanf_arg24775111($z51025103,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret51065107;
};
var $Hanf_arg24775111 = function(anf_arg16535110,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16545122 = G(list2776,"make",L[387]);
var $z51145115 = D;
var $f51205121 = function(_) {
return R.isFunction(anf_fun16545122)?anf_fun16545122.app([]):R.ffi.throwNonFunApp(L[387],anf_fun16545122,[[]]);
};
try {
if(--R.GAS > 0) {
$z51145115 = $f51205121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51205121,
"from":L[387]});
}
} catch($e51125113) {
if(R.isCont($e51125113)) {
var $ss51165117 = {"from":L[387],
"go":function(anf_arg16555123) {
return $Hanf_arg24765124(anf_arg16555123,anf_arg16485072,anf_arg16535110,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e51125113.stack[R.EXN_STACKHEIGHT++] = $ss51165117;
}
if(R.isPyretException($e51125113)) {
$e51125113.pyretStack.push(L[387]);
}
throw $e51125113;
}
var $ret51185119 = $Hanf_arg24765124($z51145115,anf_arg16485072,anf_arg16535110,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret51185119;
};
var $Hanf_arg24765124 = function(anf_arg16555123,anf_arg16485072,anf_arg16535110,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z51275128 = D;
var $f51335134 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg16535110,anf_arg16555123):R.ffi.throwNonFunApp(L[388],success100109.$var,[anf_arg16535110,anf_arg16555123]);
};
try {
if(--R.GAS > 0) {
$z51275128 = $f51335134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51335134,
"from":L[388]});
}
} catch($e51255126) {
if(R.isCont($e51255126)) {
var $ss51295130 = {"from":L[388],
"go":function(anf_arg16565135) {
return $Hanf_arg24755136(anf_arg16565135,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e51255126.stack[R.EXN_STACKHEIGHT++] = $ss51295130;
}
if(R.isPyretException($e51255126)) {
$e51255126.pyretStack.push(L[388]);
}
throw $e51255126;
}
var $ret51315132 = $Hanf_arg24755136($z51275128,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret51315132;
};
var $Hanf_arg24755136 = function(anf_arg16565135,anf_arg16485072,anf_fun16455060,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg16575147 = R.makeSrcloc(L[381]);
var $z51395140 = D;
var $f51455146 = function(_) {
return R.isFunction(anf_fun16455060)?anf_fun16455060.app(("parse-args(many-optional-flag, [list: \"--bar\", \"-4\"]) is\n  success(dict([list: \"bar\", [list: -4]]), [list: ])"),anf_arg16485072,anf_arg16565135,anf_arg16575147):R.ffi.throwNonFunApp(L[381],anf_fun16455060,[("parse-args(many-optional-flag, [list: \"--bar\", \"-4\"]) is\n  success(dict([list: \"bar\", [list: -4]]), [list: ])"),anf_arg16485072,anf_arg16565135,anf_arg16575147]);
};
try {
if(--R.GAS > 0) {
$z51395140 = $f51455146();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51455146,
"from":L[381]});
}
} catch($e51375138) {
if(R.isCont($e51375138)) {
var $ss51415142 = {"from":L[381],
"go":function(anf_begin_app_dropped23295148) {
return $Hanf_begin_app_dropped24745149(anf_begin_app_dropped23295148,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e51375138.stack[R.EXN_STACKHEIGHT++] = $ss51415142;
}
if(R.isPyretException($e51375138)) {
$e51375138.pyretStack.push(L[381]);
}
throw $e51375138;
}
var $ret51435144 = $Hanf_begin_app_dropped24745149($z51395140,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret51435144;
};
var $Hanf_begin_app_dropped24745149 = function(anf_begin_app_dropped23295148,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16585160 = G(builtins15,"current-checker",L[389]);
var $z51525153 = D;
var $f51585159 = function(_) {
return R.isFunction(anf_fun16585160)?anf_fun16585160.app():R.ffi.throwNonFunApp(L[389],anf_fun16585160,[]);
};
try {
if(--R.GAS > 0) {
$z51525153 = $f51585159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51585159,
"from":L[389]});
}
} catch($e51505151) {
if(R.isCont($e51505151)) {
var $ss51545155 = {"from":L[389],
"go":function(anf_bracket16595161) {
return $Hanf_bracket24735162(anf_bracket16595161,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e51505151.stack[R.EXN_STACKHEIGHT++] = $ss51545155;
}
if(R.isPyretException($e51505151)) {
$e51505151.pyretStack.push(L[389]);
}
throw $e51505151;
}
var $ret51565157 = $Hanf_bracket24735162($z51525153,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret51565157;
};
var $Hanf_bracket24735162 = function(anf_bracket16595161,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16605175 = G(anf_bracket16595161,"check-satisfies",L[389]);
var anf_fun16615173 = G(list2776,"make",L[390]);
var $z51655166 = D;
var $f51715172 = function(_) {
return R.isFunction(anf_fun16615173)?anf_fun16615173.app([("--bar"),("-not-a-number")]):R.ffi.throwNonFunApp(L[390],anf_fun16615173,[[("--bar"),("-not-a-number")]]);
};
try {
if(--R.GAS > 0) {
$z51655166 = $f51715172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51715172,
"from":L[390]});
}
} catch($e51635164) {
if(R.isCont($e51635164)) {
var $ss51675168 = {"from":L[390],
"go":function(anf_arg16625174) {
return $Hanf_arg24725176(anf_arg16625174,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e51635164.stack[R.EXN_STACKHEIGHT++] = $ss51675168;
}
if(R.isPyretException($e51635164)) {
$e51635164.pyretStack.push(L[390]);
}
throw $e51635164;
}
var $ret51695170 = $Hanf_arg24725176($z51655166,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret51695170;
};
var $Hanf_arg24725176 = function(anf_arg16625174,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z51795180 = D;
var $f51855186 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_optional_DASH_flag3454675,anf_arg16625174):R.ffi.throwNonFunApp(L[391],parse_DASH_args129167.$var,[many_DASH_optional_DASH_flag3454675,anf_arg16625174]);
};
try {
if(--R.GAS > 0) {
$z51795180 = $f51855186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51855186,
"from":L[391]});
}
} catch($e51775178) {
if(R.isCont($e51775178)) {
var $ss51815182 = {"from":L[391],
"go":function(anf_arg16635187) {
return $Hanf_arg24715188(anf_arg16635187,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e51775178.stack[R.EXN_STACKHEIGHT++] = $ss51815182;
}
if(R.isPyretException($e51775178)) {
$e51775178.pyretStack.push(L[391]);
}
throw $e51775178;
}
var $ret51835184 = $Hanf_arg24715188($z51795180,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret51835184;
};
var $Hanf_arg24715188 = function(anf_arg16635187,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z51915192 = D;
var $f51975198 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("Unknown command line option -not-a-number")):R.ffi.throwNonFunApp(L[392],error_DASH_text3331409.$var,[("Unknown command line option -not-a-number")]);
};
try {
if(--R.GAS > 0) {
$z51915192 = $f51975198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51975198,
"from":L[392]});
}
} catch($e51895190) {
if(R.isCont($e51895190)) {
var $ss51935194 = {"from":L[392],
"go":function(anf_arg16645199) {
return $Hanf_arg24705200(anf_arg16645199,anf_arg16635187,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e51895190.stack[R.EXN_STACKHEIGHT++] = $ss51935194;
}
if(R.isPyretException($e51895190)) {
$e51895190.pyretStack.push(L[392]);
}
throw $e51895190;
}
var $ret51955196 = $Hanf_arg24705200($z51915192,anf_arg16635187,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret51955196;
};
var $Hanf_arg24705200 = function(anf_arg16645199,anf_arg16635187,anf_fun16605175,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg16655211 = R.makeSrcloc(L[389]);
var $z52035204 = D;
var $f52095210 = function(_) {
return R.isFunction(anf_fun16605175)?anf_fun16605175.app(("parse-args(many-optional-flag, [list: \"--bar\", \"-not-a-number\"]) satisfies\n  error-text(\"Unknown command line option -not-a-number\")"),anf_arg16635187,anf_arg16645199,anf_arg16655211):R.ffi.throwNonFunApp(L[389],anf_fun16605175,[("parse-args(many-optional-flag, [list: \"--bar\", \"-not-a-number\"]) satisfies\n  error-text(\"Unknown command line option -not-a-number\")"),anf_arg16635187,anf_arg16645199,anf_arg16655211]);
};
try {
if(--R.GAS > 0) {
$z52035204 = $f52095210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52095210,
"from":L[389]});
}
} catch($e52015202) {
if(R.isCont($e52015202)) {
var $ss52055206 = {"from":L[389],
"go":function(anf_begin_app_dropped23305212) {
return $Hanf_begin_app_dropped24695213(anf_begin_app_dropped23305212,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e52015202.stack[R.EXN_STACKHEIGHT++] = $ss52055206;
}
if(R.isPyretException($e52015202)) {
$e52015202.pyretStack.push(L[389]);
}
throw $e52015202;
}
var $ret52075208 = $Hanf_begin_app_dropped24695213($z52035204,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret52075208;
};
var $Hanf_begin_app_dropped24695213 = function(anf_begin_app_dropped23305212,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16665224 = G(builtins15,"current-checker",L[393]);
var $z52165217 = D;
var $f52225223 = function(_) {
return R.isFunction(anf_fun16665224)?anf_fun16665224.app():R.ffi.throwNonFunApp(L[393],anf_fun16665224,[]);
};
try {
if(--R.GAS > 0) {
$z52165217 = $f52225223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52225223,
"from":L[393]});
}
} catch($e52145215) {
if(R.isCont($e52145215)) {
var $ss52185219 = {"from":L[393],
"go":function(anf_bracket16675225) {
return $Hanf_bracket24685226(anf_bracket16675225,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e52145215.stack[R.EXN_STACKHEIGHT++] = $ss52185219;
}
if(R.isPyretException($e52145215)) {
$e52145215.pyretStack.push(L[393]);
}
throw $e52145215;
}
var $ret52205221 = $Hanf_bracket24685226($z52165217,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret52205221;
};
var $Hanf_bracket24685226 = function(anf_bracket16675225,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16685239 = G(anf_bracket16675225,"check-is",L[393]);
var anf_fun16695237 = G(list2776,"make",L[394]);
var $z52295230 = D;
var $f52355236 = function(_) {
return R.isFunction(anf_fun16695237)?anf_fun16695237.app([("--bar"),("-4")]):R.ffi.throwNonFunApp(L[394],anf_fun16695237,[[("--bar"),("-4")]]);
};
try {
if(--R.GAS > 0) {
$z52295230 = $f52355236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52355236,
"from":L[394]});
}
} catch($e52275228) {
if(R.isCont($e52275228)) {
var $ss52315232 = {"from":L[394],
"go":function(anf_arg16705238) {
return $Hanf_arg24675240(anf_arg16705238,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e52275228.stack[R.EXN_STACKHEIGHT++] = $ss52315232;
}
if(R.isPyretException($e52275228)) {
$e52275228.pyretStack.push(L[394]);
}
throw $e52275228;
}
var $ret52335234 = $Hanf_arg24675240($z52295230,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret52335234;
};
var $Hanf_arg24675240 = function(anf_arg16705238,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z52435244 = D;
var $f52495250 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_optional_DASH_flag3454675,anf_arg16705238):R.ffi.throwNonFunApp(L[395],parse_DASH_args129167.$var,[many_DASH_optional_DASH_flag3454675,anf_arg16705238]);
};
try {
if(--R.GAS > 0) {
$z52435244 = $f52495250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52495250,
"from":L[395]});
}
} catch($e52415242) {
if(R.isCont($e52415242)) {
var $ss52455246 = {"from":L[395],
"go":function(anf_arg16715251) {
return $Hanf_arg24665252(anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e52415242.stack[R.EXN_STACKHEIGHT++] = $ss52455246;
}
if(R.isPyretException($e52415242)) {
$e52415242.pyretStack.push(L[395]);
}
throw $e52415242;
}
var $ret52475248 = $Hanf_arg24665252($z52435244,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret52475248;
};
var $Hanf_arg24665252 = function(anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16725265 = G(list2776,"make",L[397]);
var anf_fun16735263 = G(list2776,"make",L[396]);
var $z52555256 = D;
var $f52615262 = function(_) {
return R.isFunction(anf_fun16735263)?anf_fun16735263.app([(-4)]):R.ffi.throwNonFunApp(L[396],anf_fun16735263,[[(-4)]]);
};
try {
if(--R.GAS > 0) {
$z52555256 = $f52615262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52615262,
"from":L[396]});
}
} catch($e52535254) {
if(R.isCont($e52535254)) {
var $ss52575258 = {"from":L[396],
"go":function(anf_array_val16745264) {
return $Hanf_array_val24655266(anf_array_val16745264,anf_arg16715251,anf_fun16685239,anf_fun16725265,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e52535254.stack[R.EXN_STACKHEIGHT++] = $ss52575258;
}
if(R.isPyretException($e52535254)) {
$e52535254.pyretStack.push(L[396]);
}
throw $e52535254;
}
var $ret52595260 = $Hanf_array_val24655266($z52555256,anf_arg16715251,anf_fun16685239,anf_fun16725265,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret52595260;
};
var $Hanf_array_val24655266 = function(anf_array_val16745264,anf_arg16715251,anf_fun16685239,anf_fun16725265,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z52695270 = D;
var $f52755276 = function(_) {
return R.isFunction(anf_fun16725265)?anf_fun16725265.app([("bar"),anf_array_val16745264]):R.ffi.throwNonFunApp(L[397],anf_fun16725265,[[("bar"),anf_array_val16745264]]);
};
try {
if(--R.GAS > 0) {
$z52695270 = $f52755276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52755276,
"from":L[397]});
}
} catch($e52675268) {
if(R.isCont($e52675268)) {
var $ss52715272 = {"from":L[397],
"go":function(anf_arg16755277) {
return $Hanf_arg24645278(anf_arg16755277,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e52675268.stack[R.EXN_STACKHEIGHT++] = $ss52715272;
}
if(R.isPyretException($e52675268)) {
$e52675268.pyretStack.push(L[397]);
}
throw $e52675268;
}
var $ret52735274 = $Hanf_arg24645278($z52695270,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret52735274;
};
var $Hanf_arg24645278 = function(anf_arg16755277,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z52815282 = D;
var $f52875288 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg16755277):R.ffi.throwNonFunApp(L[398],dict131171.$var,[anf_arg16755277]);
};
try {
if(--R.GAS > 0) {
$z52815282 = $f52875288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52875288,
"from":L[398]});
}
} catch($e52795280) {
if(R.isCont($e52795280)) {
var $ss52835284 = {"from":L[398],
"go":function(anf_arg16765289) {
return $Hanf_arg24635290(anf_arg16765289,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e52795280.stack[R.EXN_STACKHEIGHT++] = $ss52835284;
}
if(R.isPyretException($e52795280)) {
$e52795280.pyretStack.push(L[398]);
}
throw $e52795280;
}
var $ret52855286 = $Hanf_arg24635290($z52815282,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret52855286;
};
var $Hanf_arg24635290 = function(anf_arg16765289,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16775301 = G(list2776,"make",L[399]);
var $z52935294 = D;
var $f52995300 = function(_) {
return R.isFunction(anf_fun16775301)?anf_fun16775301.app([]):R.ffi.throwNonFunApp(L[399],anf_fun16775301,[[]]);
};
try {
if(--R.GAS > 0) {
$z52935294 = $f52995300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52995300,
"from":L[399]});
}
} catch($e52915292) {
if(R.isCont($e52915292)) {
var $ss52955296 = {"from":L[399],
"go":function(anf_arg16785302) {
return $Hanf_arg24625303(anf_arg16785302,anf_arg16715251,anf_arg16765289,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e52915292.stack[R.EXN_STACKHEIGHT++] = $ss52955296;
}
if(R.isPyretException($e52915292)) {
$e52915292.pyretStack.push(L[399]);
}
throw $e52915292;
}
var $ret52975298 = $Hanf_arg24625303($z52935294,anf_arg16715251,anf_arg16765289,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret52975298;
};
var $Hanf_arg24625303 = function(anf_arg16785302,anf_arg16715251,anf_arg16765289,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z53065307 = D;
var $f53125313 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg16765289,anf_arg16785302):R.ffi.throwNonFunApp(L[400],success100109.$var,[anf_arg16765289,anf_arg16785302]);
};
try {
if(--R.GAS > 0) {
$z53065307 = $f53125313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53125313,
"from":L[400]});
}
} catch($e53045305) {
if(R.isCont($e53045305)) {
var $ss53085309 = {"from":L[400],
"go":function(anf_arg16795314) {
return $Hanf_arg24615315(anf_arg16795314,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e53045305.stack[R.EXN_STACKHEIGHT++] = $ss53085309;
}
if(R.isPyretException($e53045305)) {
$e53045305.pyretStack.push(L[400]);
}
throw $e53045305;
}
var $ret53105311 = $Hanf_arg24615315($z53065307,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret53105311;
};
var $Hanf_arg24615315 = function(anf_arg16795314,anf_arg16715251,anf_fun16685239,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg16805326 = R.makeSrcloc(L[393]);
var $z53185319 = D;
var $f53245325 = function(_) {
return R.isFunction(anf_fun16685239)?anf_fun16685239.app(("parse-args(many-optional-flag, [list: \"--bar\", \"-4\"]) is\n  success(dict([list: \"bar\", [list: -4]]), [list: ])"),anf_arg16715251,anf_arg16795314,anf_arg16805326):R.ffi.throwNonFunApp(L[393],anf_fun16685239,[("parse-args(many-optional-flag, [list: \"--bar\", \"-4\"]) is\n  success(dict([list: \"bar\", [list: -4]]), [list: ])"),anf_arg16715251,anf_arg16795314,anf_arg16805326]);
};
try {
if(--R.GAS > 0) {
$z53185319 = $f53245325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53245325,
"from":L[393]});
}
} catch($e53165317) {
if(R.isCont($e53165317)) {
var $ss53205321 = {"from":L[393],
"go":function(anf_begin_app_dropped23315327) {
return $Hanf_begin_app_dropped24605328(anf_begin_app_dropped23315327,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e53165317.stack[R.EXN_STACKHEIGHT++] = $ss53205321;
}
if(R.isPyretException($e53165317)) {
$e53165317.pyretStack.push(L[393]);
}
throw $e53165317;
}
var $ret53225323 = $Hanf_begin_app_dropped24605328($z53185319,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret53225323;
};
var $Hanf_begin_app_dropped24605328 = function(anf_begin_app_dropped23315327,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16815339 = G(builtins15,"current-checker",L[401]);
var $z53315332 = D;
var $f53375338 = function(_) {
return R.isFunction(anf_fun16815339)?anf_fun16815339.app():R.ffi.throwNonFunApp(L[401],anf_fun16815339,[]);
};
try {
if(--R.GAS > 0) {
$z53315332 = $f53375338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53375338,
"from":L[401]});
}
} catch($e53295330) {
if(R.isCont($e53295330)) {
var $ss53335334 = {"from":L[401],
"go":function(anf_bracket16825340) {
return $Hanf_bracket24595341(anf_bracket16825340,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e53295330.stack[R.EXN_STACKHEIGHT++] = $ss53335334;
}
if(R.isPyretException($e53295330)) {
$e53295330.pyretStack.push(L[401]);
}
throw $e53295330;
}
var $ret53355336 = $Hanf_bracket24595341($z53315332,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret53355336;
};
var $Hanf_bracket24595341 = function(anf_bracket16825340,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16835354 = G(anf_bracket16825340,"check-is",L[401]);
var anf_fun16845352 = G(list2776,"make",L[402]);
var $z53445345 = D;
var $f53505351 = function(_) {
return R.isFunction(anf_fun16845352)?anf_fun16845352.app([("--bar"),("-4"),("-4")]):R.ffi.throwNonFunApp(L[402],anf_fun16845352,[[("--bar"),("-4"),("-4")]]);
};
try {
if(--R.GAS > 0) {
$z53445345 = $f53505351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53505351,
"from":L[402]});
}
} catch($e53425343) {
if(R.isCont($e53425343)) {
var $ss53465347 = {"from":L[402],
"go":function(anf_arg16855353) {
return $Hanf_arg24585355(anf_arg16855353,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e53425343.stack[R.EXN_STACKHEIGHT++] = $ss53465347;
}
if(R.isPyretException($e53425343)) {
$e53425343.pyretStack.push(L[402]);
}
throw $e53425343;
}
var $ret53485349 = $Hanf_arg24585355($z53445345,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret53485349;
};
var $Hanf_arg24585355 = function(anf_arg16855353,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_optional_DASH_flag3454675,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z53585359 = D;
var $f53645365 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_optional_DASH_flag3454675,anf_arg16855353):R.ffi.throwNonFunApp(L[403],parse_DASH_args129167.$var,[many_DASH_optional_DASH_flag3454675,anf_arg16855353]);
};
try {
if(--R.GAS > 0) {
$z53585359 = $f53645365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53645365,
"from":L[403]});
}
} catch($e53565357) {
if(R.isCont($e53565357)) {
var $ss53605361 = {"from":L[403],
"go":function(anf_arg16865366) {
return $Hanf_arg24575367(anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e53565357.stack[R.EXN_STACKHEIGHT++] = $ss53605361;
}
if(R.isPyretException($e53565357)) {
$e53565357.pyretStack.push(L[403]);
}
throw $e53565357;
}
var $ret53625363 = $Hanf_arg24575367($z53585359,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret53625363;
};
var $Hanf_arg24575367 = function(anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16875380 = G(list2776,"make",L[405]);
var anf_fun16885378 = G(list2776,"make",L[404]);
var $z53705371 = D;
var $f53765377 = function(_) {
return R.isFunction(anf_fun16885378)?anf_fun16885378.app([(-4)]):R.ffi.throwNonFunApp(L[404],anf_fun16885378,[[(-4)]]);
};
try {
if(--R.GAS > 0) {
$z53705371 = $f53765377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53765377,
"from":L[404]});
}
} catch($e53685369) {
if(R.isCont($e53685369)) {
var $ss53725373 = {"from":L[404],
"go":function(anf_array_val16895379) {
return $Hanf_array_val24565381(anf_array_val16895379,anf_arg16865366,anf_fun16835354,anf_fun16875380,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e53685369.stack[R.EXN_STACKHEIGHT++] = $ss53725373;
}
if(R.isPyretException($e53685369)) {
$e53685369.pyretStack.push(L[404]);
}
throw $e53685369;
}
var $ret53745375 = $Hanf_array_val24565381($z53705371,anf_arg16865366,anf_fun16835354,anf_fun16875380,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret53745375;
};
var $Hanf_array_val24565381 = function(anf_array_val16895379,anf_arg16865366,anf_fun16835354,anf_fun16875380,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16905392 = G(list2776,"make",L[406]);
var $z53845385 = D;
var $f53905391 = function(_) {
return R.isFunction(anf_fun16905392)?anf_fun16905392.app([(true)]):R.ffi.throwNonFunApp(L[406],anf_fun16905392,[[(true)]]);
};
try {
if(--R.GAS > 0) {
$z53845385 = $f53905391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53905391,
"from":L[406]});
}
} catch($e53825383) {
if(R.isCont($e53825383)) {
var $ss53865387 = {"from":L[406],
"go":function(anf_array_val16915393) {
return $Hanf_array_val24555394(anf_array_val16915393,anf_arg16865366,anf_array_val16895379,anf_fun16835354,anf_fun16875380,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e53825383.stack[R.EXN_STACKHEIGHT++] = $ss53865387;
}
if(R.isPyretException($e53825383)) {
$e53825383.pyretStack.push(L[406]);
}
throw $e53825383;
}
var $ret53885389 = $Hanf_array_val24555394($z53845385,anf_arg16865366,anf_array_val16895379,anf_fun16835354,anf_fun16875380,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret53885389;
};
var $Hanf_array_val24555394 = function(anf_array_val16915393,anf_arg16865366,anf_array_val16895379,anf_fun16835354,anf_fun16875380,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z53975398 = D;
var $f54035404 = function(_) {
return R.isFunction(anf_fun16875380)?anf_fun16875380.app([("bar"),anf_array_val16895379,("4"),anf_array_val16915393]):R.ffi.throwNonFunApp(L[405],anf_fun16875380,[[("bar"),anf_array_val16895379,("4"),anf_array_val16915393]]);
};
try {
if(--R.GAS > 0) {
$z53975398 = $f54035404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54035404,
"from":L[405]});
}
} catch($e53955396) {
if(R.isCont($e53955396)) {
var $ss53995400 = {"from":L[405],
"go":function(anf_arg16925405) {
return $Hanf_arg24545406(anf_arg16925405,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e53955396.stack[R.EXN_STACKHEIGHT++] = $ss53995400;
}
if(R.isPyretException($e53955396)) {
$e53955396.pyretStack.push(L[405]);
}
throw $e53955396;
}
var $ret54015402 = $Hanf_arg24545406($z53975398,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret54015402;
};
var $Hanf_arg24545406 = function(anf_arg16925405,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z54095410 = D;
var $f54155416 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg16925405):R.ffi.throwNonFunApp(L[407],dict131171.$var,[anf_arg16925405]);
};
try {
if(--R.GAS > 0) {
$z54095410 = $f54155416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54155416,
"from":L[407]});
}
} catch($e54075408) {
if(R.isCont($e54075408)) {
var $ss54115412 = {"from":L[407],
"go":function(anf_arg16935417) {
return $Hanf_arg24535418(anf_arg16935417,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e54075408.stack[R.EXN_STACKHEIGHT++] = $ss54115412;
}
if(R.isPyretException($e54075408)) {
$e54075408.pyretStack.push(L[407]);
}
throw $e54075408;
}
var $ret54135414 = $Hanf_arg24535418($z54095410,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret54135414;
};
var $Hanf_arg24535418 = function(anf_arg16935417,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun16945429 = G(list2776,"make",L[408]);
var $z54215422 = D;
var $f54275428 = function(_) {
return R.isFunction(anf_fun16945429)?anf_fun16945429.app([]):R.ffi.throwNonFunApp(L[408],anf_fun16945429,[[]]);
};
try {
if(--R.GAS > 0) {
$z54215422 = $f54275428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54275428,
"from":L[408]});
}
} catch($e54195420) {
if(R.isCont($e54195420)) {
var $ss54235424 = {"from":L[408],
"go":function(anf_arg16955430) {
return $Hanf_arg24525431(anf_arg16955430,anf_arg16865366,anf_arg16935417,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e54195420.stack[R.EXN_STACKHEIGHT++] = $ss54235424;
}
if(R.isPyretException($e54195420)) {
$e54195420.pyretStack.push(L[408]);
}
throw $e54195420;
}
var $ret54255426 = $Hanf_arg24525431($z54215422,anf_arg16865366,anf_arg16935417,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret54255426;
};
var $Hanf_arg24525431 = function(anf_arg16955430,anf_arg16865366,anf_arg16935417,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z54345435 = D;
var $f54405441 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg16935417,anf_arg16955430):R.ffi.throwNonFunApp(L[409],success100109.$var,[anf_arg16935417,anf_arg16955430]);
};
try {
if(--R.GAS > 0) {
$z54345435 = $f54405441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54405441,
"from":L[409]});
}
} catch($e54325433) {
if(R.isCont($e54325433)) {
var $ss54365437 = {"from":L[409],
"go":function(anf_arg16965442) {
return $Hanf_arg24515443(anf_arg16965442,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e54325433.stack[R.EXN_STACKHEIGHT++] = $ss54365437;
}
if(R.isPyretException($e54325433)) {
$e54325433.pyretStack.push(L[409]);
}
throw $e54325433;
}
var $ret54385439 = $Hanf_arg24515443($z54345435,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret54385439;
};
var $Hanf_arg24515443 = function(anf_arg16965442,anf_arg16865366,anf_fun16835354,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg16975454 = R.makeSrcloc(L[401]);
var $z54465447 = D;
var $f54525453 = function(_) {
return R.isFunction(anf_fun16835354)?anf_fun16835354.app(("parse-args(many-optional-flag, [list: \"--bar\", \"-4\", \"-4\"]) is\n  success(dict([list: \"bar\", [list: -4], \"4\", [list: true]]), [list: ])"),anf_arg16865366,anf_arg16965442,anf_arg16975454):R.ffi.throwNonFunApp(L[401],anf_fun16835354,[("parse-args(many-optional-flag, [list: \"--bar\", \"-4\", \"-4\"]) is\n  success(dict([list: \"bar\", [list: -4], \"4\", [list: true]]), [list: ])"),anf_arg16865366,anf_arg16965442,anf_arg16975454]);
};
try {
if(--R.GAS > 0) {
$z54465447 = $f54525453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54525453,
"from":L[401]});
}
} catch($e54445445) {
if(R.isCont($e54445445)) {
var $ss54485449 = {"from":L[401],
"go":function(anf_begin_app_dropped23325455) {
return $Hanf_begin_app_dropped24505456(anf_begin_app_dropped23325455,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e54445445.stack[R.EXN_STACKHEIGHT++] = $ss54485449;
}
if(R.isPyretException($e54445445)) {
$e54445445.pyretStack.push(L[401]);
}
throw $e54445445;
}
var $ret54505451 = $Hanf_begin_app_dropped24505456($z54465447,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret54505451;
};
var $Hanf_begin_app_dropped24505456 = function(anf_begin_app_dropped23325455,blue140189,dict131171,equals_DASH_val120149,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_bool9191,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z54595460 = D;
var $f54655466 = function(_) {
return R.isFunction(equals_DASH_val120149.$var)?equals_DASH_val120149.$var.app(read_DASH_bool9191.$var,required_DASH_many113135.$var,("Foo")):R.ffi.throwNonFunApp(L[410],equals_DASH_val120149.$var,[read_DASH_bool9191.$var,required_DASH_many113135.$var,("Foo")]);
};
try {
if(--R.GAS > 0) {
$z54595460 = $f54655466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54655466,
"from":L[410]});
}
} catch($e54575458) {
if(R.isCont($e54575458)) {
var $ss54615462 = {"from":L[410],
"go":function(anf_obj16985467) {
return $Hanf_obj24495468(anf_obj16985467,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e54575458.stack[R.EXN_STACKHEIGHT++] = $ss54615462;
}
if(R.isPyretException($e54575458)) {
$e54575458.pyretStack.push(L[410]);
}
throw $e54575458;
}
var $ret54635464 = $Hanf_obj24495468($z54595460,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret54635464;
};
var $Hanf_obj24495468 = function(anf_obj16985467,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z54715472 = D;
var $f54775478 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(many109127.$var,("Bar")):R.ffi.throwNonFunApp(L[411],flag118145.$var,[many109127.$var,("Bar")]);
};
try {
if(--R.GAS > 0) {
$z54715472 = $f54775478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54775478,
"from":L[411]});
}
} catch($e54695470) {
if(R.isCont($e54695470)) {
var $ss54735474 = {"from":L[411],
"go":function(anf_obj16995479) {
return $Hanf_obj24485480(anf_obj16995479,anf_obj16985467,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e54695470.stack[R.EXN_STACKHEIGHT++] = $ss54735474;
}
if(R.isPyretException($e54695470)) {
$e54695470.pyretStack.push(L[411]);
}
throw $e54695470;
}
var $ret54755476 = $Hanf_obj24485480($z54715472,anf_obj16985467,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret54755476;
};
var $Hanf_obj24485480 = function(anf_obj16995479,anf_obj16985467,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var many_DASH_required_DASH_equals3465493 = R.makeObject({"foo":anf_obj16985467,
"bar":anf_obj16995479});
var anf_fun17005491 = G(builtins15,"current-checker",L[412]);
var $z54835484 = D;
var $f54895490 = function(_) {
return R.isFunction(anf_fun17005491)?anf_fun17005491.app():R.ffi.throwNonFunApp(L[412],anf_fun17005491,[]);
};
try {
if(--R.GAS > 0) {
$z54835484 = $f54895490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54895490,
"from":L[412]});
}
} catch($e54815482) {
if(R.isCont($e54815482)) {
var $ss54855486 = {"from":L[412],
"go":function(anf_bracket17015492) {
return $Hanf_bracket24475494(anf_bracket17015492,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e54815482.stack[R.EXN_STACKHEIGHT++] = $ss54855486;
}
if(R.isPyretException($e54815482)) {
$e54815482.pyretStack.push(L[412]);
}
throw $e54815482;
}
var $ret54875488 = $Hanf_bracket24475494($z54835484,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret54875488;
};
var $Hanf_bracket24475494 = function(anf_bracket17015492,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17025507 = G(anf_bracket17015492,"check-is",L[412]);
var anf_fun17035505 = G(list2776,"make",L[413]);
var $z54975498 = D;
var $f55035504 = function(_) {
return R.isFunction(anf_fun17035505)?anf_fun17035505.app([("--foo=false"),("--foo=true")]):R.ffi.throwNonFunApp(L[413],anf_fun17035505,[[("--foo=false"),("--foo=true")]]);
};
try {
if(--R.GAS > 0) {
$z54975498 = $f55035504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55035504,
"from":L[413]});
}
} catch($e54955496) {
if(R.isCont($e54955496)) {
var $ss54995500 = {"from":L[413],
"go":function(anf_arg17045506) {
return $Hanf_arg24465508(anf_arg17045506,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e54955496.stack[R.EXN_STACKHEIGHT++] = $ss54995500;
}
if(R.isPyretException($e54955496)) {
$e54955496.pyretStack.push(L[413]);
}
throw $e54955496;
}
var $ret55015502 = $Hanf_arg24465508($z54975498,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret55015502;
};
var $Hanf_arg24465508 = function(anf_arg17045506,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z55115512 = D;
var $f55175518 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_required_DASH_equals3465493,anf_arg17045506):R.ffi.throwNonFunApp(L[414],parse_DASH_args129167.$var,[many_DASH_required_DASH_equals3465493,anf_arg17045506]);
};
try {
if(--R.GAS > 0) {
$z55115512 = $f55175518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55175518,
"from":L[414]});
}
} catch($e55095510) {
if(R.isCont($e55095510)) {
var $ss55135514 = {"from":L[414],
"go":function(anf_arg17055519) {
return $Hanf_arg24455520(anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e55095510.stack[R.EXN_STACKHEIGHT++] = $ss55135514;
}
if(R.isPyretException($e55095510)) {
$e55095510.pyretStack.push(L[414]);
}
throw $e55095510;
}
var $ret55155516 = $Hanf_arg24455520($z55115512,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret55155516;
};
var $Hanf_arg24455520 = function(anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17065533 = G(list2776,"make",L[416]);
var anf_fun17075531 = G(list2776,"make",L[415]);
var $z55235524 = D;
var $f55295530 = function(_) {
return R.isFunction(anf_fun17075531)?anf_fun17075531.app([(false),(true)]):R.ffi.throwNonFunApp(L[415],anf_fun17075531,[[(false),(true)]]);
};
try {
if(--R.GAS > 0) {
$z55235524 = $f55295530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55295530,
"from":L[415]});
}
} catch($e55215522) {
if(R.isCont($e55215522)) {
var $ss55255526 = {"from":L[415],
"go":function(anf_array_val17085532) {
return $Hanf_array_val24445534(anf_array_val17085532,anf_arg17055519,anf_fun17025507,anf_fun17065533,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e55215522.stack[R.EXN_STACKHEIGHT++] = $ss55255526;
}
if(R.isPyretException($e55215522)) {
$e55215522.pyretStack.push(L[415]);
}
throw $e55215522;
}
var $ret55275528 = $Hanf_array_val24445534($z55235524,anf_arg17055519,anf_fun17025507,anf_fun17065533,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret55275528;
};
var $Hanf_array_val24445534 = function(anf_array_val17085532,anf_arg17055519,anf_fun17025507,anf_fun17065533,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z55375538 = D;
var $f55435544 = function(_) {
return R.isFunction(anf_fun17065533)?anf_fun17065533.app([("foo"),anf_array_val17085532]):R.ffi.throwNonFunApp(L[416],anf_fun17065533,[[("foo"),anf_array_val17085532]]);
};
try {
if(--R.GAS > 0) {
$z55375538 = $f55435544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55435544,
"from":L[416]});
}
} catch($e55355536) {
if(R.isCont($e55355536)) {
var $ss55395540 = {"from":L[416],
"go":function(anf_arg17095545) {
return $Hanf_arg24435546(anf_arg17095545,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e55355536.stack[R.EXN_STACKHEIGHT++] = $ss55395540;
}
if(R.isPyretException($e55355536)) {
$e55355536.pyretStack.push(L[416]);
}
throw $e55355536;
}
var $ret55415542 = $Hanf_arg24435546($z55375538,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret55415542;
};
var $Hanf_arg24435546 = function(anf_arg17095545,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z55495550 = D;
var $f55555556 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg17095545):R.ffi.throwNonFunApp(L[417],dict131171.$var,[anf_arg17095545]);
};
try {
if(--R.GAS > 0) {
$z55495550 = $f55555556();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55555556,
"from":L[417]});
}
} catch($e55475548) {
if(R.isCont($e55475548)) {
var $ss55515552 = {"from":L[417],
"go":function(anf_arg17105557) {
return $Hanf_arg24425558(anf_arg17105557,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e55475548.stack[R.EXN_STACKHEIGHT++] = $ss55515552;
}
if(R.isPyretException($e55475548)) {
$e55475548.pyretStack.push(L[417]);
}
throw $e55475548;
}
var $ret55535554 = $Hanf_arg24425558($z55495550,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret55535554;
};
var $Hanf_arg24425558 = function(anf_arg17105557,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17115569 = G(list2776,"make",L[418]);
var $z55615562 = D;
var $f55675568 = function(_) {
return R.isFunction(anf_fun17115569)?anf_fun17115569.app([]):R.ffi.throwNonFunApp(L[418],anf_fun17115569,[[]]);
};
try {
if(--R.GAS > 0) {
$z55615562 = $f55675568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55675568,
"from":L[418]});
}
} catch($e55595560) {
if(R.isCont($e55595560)) {
var $ss55635564 = {"from":L[418],
"go":function(anf_arg17125570) {
return $Hanf_arg24415571(anf_arg17125570,anf_arg17055519,anf_arg17105557,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e55595560.stack[R.EXN_STACKHEIGHT++] = $ss55635564;
}
if(R.isPyretException($e55595560)) {
$e55595560.pyretStack.push(L[418]);
}
throw $e55595560;
}
var $ret55655566 = $Hanf_arg24415571($z55615562,anf_arg17055519,anf_arg17105557,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret55655566;
};
var $Hanf_arg24415571 = function(anf_arg17125570,anf_arg17055519,anf_arg17105557,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z55745575 = D;
var $f55805581 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg17105557,anf_arg17125570):R.ffi.throwNonFunApp(L[419],success100109.$var,[anf_arg17105557,anf_arg17125570]);
};
try {
if(--R.GAS > 0) {
$z55745575 = $f55805581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55805581,
"from":L[419]});
}
} catch($e55725573) {
if(R.isCont($e55725573)) {
var $ss55765577 = {"from":L[419],
"go":function(anf_arg17135582) {
return $Hanf_arg24405583(anf_arg17135582,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e55725573.stack[R.EXN_STACKHEIGHT++] = $ss55765577;
}
if(R.isPyretException($e55725573)) {
$e55725573.pyretStack.push(L[419]);
}
throw $e55725573;
}
var $ret55785579 = $Hanf_arg24405583($z55745575,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret55785579;
};
var $Hanf_arg24405583 = function(anf_arg17135582,anf_arg17055519,anf_fun17025507,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg17145594 = R.makeSrcloc(L[412]);
var $z55865587 = D;
var $f55925593 = function(_) {
return R.isFunction(anf_fun17025507)?anf_fun17025507.app(("parse-args(many-required-equals, [list: \"--foo=false\", \"--foo=true\"]) is\n  success(dict([list: \"foo\", [list: false, true]]), [list: ])"),anf_arg17055519,anf_arg17135582,anf_arg17145594):R.ffi.throwNonFunApp(L[412],anf_fun17025507,[("parse-args(many-required-equals, [list: \"--foo=false\", \"--foo=true\"]) is\n  success(dict([list: \"foo\", [list: false, true]]), [list: ])"),anf_arg17055519,anf_arg17135582,anf_arg17145594]);
};
try {
if(--R.GAS > 0) {
$z55865587 = $f55925593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55925593,
"from":L[412]});
}
} catch($e55845585) {
if(R.isCont($e55845585)) {
var $ss55885589 = {"from":L[412],
"go":function(anf_begin_app_dropped23335595) {
return $Hanf_begin_app_dropped24395596(anf_begin_app_dropped23335595,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e55845585.stack[R.EXN_STACKHEIGHT++] = $ss55885589;
}
if(R.isPyretException($e55845585)) {
$e55845585.pyretStack.push(L[412]);
}
throw $e55845585;
}
var $ret55905591 = $Hanf_begin_app_dropped24395596($z55865587,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret55905591;
};
var $Hanf_begin_app_dropped24395596 = function(anf_begin_app_dropped23335595,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17155607 = G(builtins15,"current-checker",L[420]);
var $z55995600 = D;
var $f56055606 = function(_) {
return R.isFunction(anf_fun17155607)?anf_fun17155607.app():R.ffi.throwNonFunApp(L[420],anf_fun17155607,[]);
};
try {
if(--R.GAS > 0) {
$z55995600 = $f56055606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56055606,
"from":L[420]});
}
} catch($e55975598) {
if(R.isCont($e55975598)) {
var $ss56015602 = {"from":L[420],
"go":function(anf_bracket17165608) {
return $Hanf_bracket24385609(anf_bracket17165608,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e55975598.stack[R.EXN_STACKHEIGHT++] = $ss56015602;
}
if(R.isPyretException($e55975598)) {
$e55975598.pyretStack.push(L[420]);
}
throw $e55975598;
}
var $ret56035604 = $Hanf_bracket24385609($z55995600,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret56035604;
};
var $Hanf_bracket24385609 = function(anf_bracket17165608,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17175622 = G(anf_bracket17165608,"check-satisfies",L[420]);
var anf_fun17185620 = G(list2776,"make",L[421]);
var $z56125613 = D;
var $f56185619 = function(_) {
return R.isFunction(anf_fun17185620)?anf_fun17185620.app([("-bar")]):R.ffi.throwNonFunApp(L[421],anf_fun17185620,[[("-bar")]]);
};
try {
if(--R.GAS > 0) {
$z56125613 = $f56185619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56185619,
"from":L[421]});
}
} catch($e56105611) {
if(R.isCont($e56105611)) {
var $ss56145615 = {"from":L[421],
"go":function(anf_arg17195621) {
return $Hanf_arg24375623(anf_arg17195621,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e56105611.stack[R.EXN_STACKHEIGHT++] = $ss56145615;
}
if(R.isPyretException($e56105611)) {
$e56105611.pyretStack.push(L[421]);
}
throw $e56105611;
}
var $ret56165617 = $Hanf_arg24375623($z56125613,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret56165617;
};
var $Hanf_arg24375623 = function(anf_arg17195621,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z56265627 = D;
var $f56325633 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_required_DASH_equals3465493,anf_arg17195621):R.ffi.throwNonFunApp(L[422],parse_DASH_args129167.$var,[many_DASH_required_DASH_equals3465493,anf_arg17195621]);
};
try {
if(--R.GAS > 0) {
$z56265627 = $f56325633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56325633,
"from":L[422]});
}
} catch($e56245625) {
if(R.isCont($e56245625)) {
var $ss56285629 = {"from":L[422],
"go":function(anf_arg17205634) {
return $Hanf_arg24365635(anf_arg17205634,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e56245625.stack[R.EXN_STACKHEIGHT++] = $ss56285629;
}
if(R.isPyretException($e56245625)) {
$e56245625.pyretStack.push(L[422]);
}
throw $e56245625;
}
var $ret56305631 = $Hanf_arg24365635($z56265627,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret56305631;
};
var $Hanf_arg24365635 = function(anf_arg17205634,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z56385639 = D;
var $f56445645 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("options are required")):R.ffi.throwNonFunApp(L[423],error_DASH_text3331409.$var,[("options are required")]);
};
try {
if(--R.GAS > 0) {
$z56385639 = $f56445645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56445645,
"from":L[423]});
}
} catch($e56365637) {
if(R.isCont($e56365637)) {
var $ss56405641 = {"from":L[423],
"go":function(anf_arg17215646) {
return $Hanf_arg24355647(anf_arg17215646,anf_arg17205634,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e56365637.stack[R.EXN_STACKHEIGHT++] = $ss56405641;
}
if(R.isPyretException($e56365637)) {
$e56365637.pyretStack.push(L[423]);
}
throw $e56365637;
}
var $ret56425643 = $Hanf_arg24355647($z56385639,anf_arg17205634,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret56425643;
};
var $Hanf_arg24355647 = function(anf_arg17215646,anf_arg17205634,anf_fun17175622,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg17225658 = R.makeSrcloc(L[420]);
var $z56505651 = D;
var $f56565657 = function(_) {
return R.isFunction(anf_fun17175622)?anf_fun17175622.app(("parse-args(many-required-equals, [list: \"-bar\"]) satisfies\n  error-text(\"options are required\")"),anf_arg17205634,anf_arg17215646,anf_arg17225658):R.ffi.throwNonFunApp(L[420],anf_fun17175622,[("parse-args(many-required-equals, [list: \"-bar\"]) satisfies\n  error-text(\"options are required\")"),anf_arg17205634,anf_arg17215646,anf_arg17225658]);
};
try {
if(--R.GAS > 0) {
$z56505651 = $f56565657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56565657,
"from":L[420]});
}
} catch($e56485649) {
if(R.isCont($e56485649)) {
var $ss56525653 = {"from":L[420],
"go":function(anf_begin_app_dropped23345659) {
return $Hanf_begin_app_dropped24345660(anf_begin_app_dropped23345659,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e56485649.stack[R.EXN_STACKHEIGHT++] = $ss56525653;
}
if(R.isPyretException($e56485649)) {
$e56485649.pyretStack.push(L[420]);
}
throw $e56485649;
}
var $ret56545655 = $Hanf_begin_app_dropped24345660($z56505651,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret56545655;
};
var $Hanf_begin_app_dropped24345660 = function(anf_begin_app_dropped23345659,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17235671 = G(builtins15,"current-checker",L[424]);
var $z56635664 = D;
var $f56695670 = function(_) {
return R.isFunction(anf_fun17235671)?anf_fun17235671.app():R.ffi.throwNonFunApp(L[424],anf_fun17235671,[]);
};
try {
if(--R.GAS > 0) {
$z56635664 = $f56695670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56695670,
"from":L[424]});
}
} catch($e56615662) {
if(R.isCont($e56615662)) {
var $ss56655666 = {"from":L[424],
"go":function(anf_bracket17245672) {
return $Hanf_bracket24335673(anf_bracket17245672,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e56615662.stack[R.EXN_STACKHEIGHT++] = $ss56655666;
}
if(R.isPyretException($e56615662)) {
$e56615662.pyretStack.push(L[424]);
}
throw $e56615662;
}
var $ret56675668 = $Hanf_bracket24335673($z56635664,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret56675668;
};
var $Hanf_bracket24335673 = function(anf_bracket17245672,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17255686 = G(anf_bracket17245672,"check-satisfies",L[424]);
var anf_fun17265684 = G(list2776,"make",L[425]);
var $z56765677 = D;
var $f56825683 = function(_) {
return R.isFunction(anf_fun17265684)?anf_fun17265684.app([("--foo")]):R.ffi.throwNonFunApp(L[425],anf_fun17265684,[[("--foo")]]);
};
try {
if(--R.GAS > 0) {
$z56765677 = $f56825683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56825683,
"from":L[425]});
}
} catch($e56745675) {
if(R.isCont($e56745675)) {
var $ss56785679 = {"from":L[425],
"go":function(anf_arg17275685) {
return $Hanf_arg24325687(anf_arg17275685,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e56745675.stack[R.EXN_STACKHEIGHT++] = $ss56785679;
}
if(R.isPyretException($e56745675)) {
$e56745675.pyretStack.push(L[425]);
}
throw $e56745675;
}
var $ret56805681 = $Hanf_arg24325687($z56765677,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret56805681;
};
var $Hanf_arg24325687 = function(anf_arg17275685,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_equals3465493,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z56905691 = D;
var $f56965697 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_required_DASH_equals3465493,anf_arg17275685):R.ffi.throwNonFunApp(L[426],parse_DASH_args129167.$var,[many_DASH_required_DASH_equals3465493,anf_arg17275685]);
};
try {
if(--R.GAS > 0) {
$z56905691 = $f56965697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56965697,
"from":L[426]});
}
} catch($e56885689) {
if(R.isCont($e56885689)) {
var $ss56925693 = {"from":L[426],
"go":function(anf_arg17285698) {
return $Hanf_arg24315699(anf_arg17285698,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e56885689.stack[R.EXN_STACKHEIGHT++] = $ss56925693;
}
if(R.isPyretException($e56885689)) {
$e56885689.pyretStack.push(L[426]);
}
throw $e56885689;
}
var $ret56945695 = $Hanf_arg24315699($z56905691,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret56945695;
};
var $Hanf_arg24315699 = function(anf_arg17285698,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z57025703 = D;
var $f57085709 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("Option foo must be of the form --foo=(true|false)")):R.ffi.throwNonFunApp(L[427],error_DASH_text3331409.$var,[("Option foo must be of the form --foo=(true|false)")]);
};
try {
if(--R.GAS > 0) {
$z57025703 = $f57085709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57085709,
"from":L[427]});
}
} catch($e57005701) {
if(R.isCont($e57005701)) {
var $ss57045705 = {"from":L[427],
"go":function(anf_arg17295710) {
return $Hanf_arg24305711(anf_arg17295710,anf_arg17285698,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e57005701.stack[R.EXN_STACKHEIGHT++] = $ss57045705;
}
if(R.isPyretException($e57005701)) {
$e57005701.pyretStack.push(L[427]);
}
throw $e57005701;
}
var $ret57065707 = $Hanf_arg24305711($z57025703,anf_arg17285698,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret57065707;
};
var $Hanf_arg24305711 = function(anf_arg17295710,anf_arg17285698,anf_fun17255686,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg17305722 = R.makeSrcloc(L[424]);
var $z57145715 = D;
var $f57205721 = function(_) {
return R.isFunction(anf_fun17255686)?anf_fun17255686.app(("parse-args(many-required-equals, [list: \"--foo\"]) satisfies\n  error-text(\"Option foo must be of the form --foo=(true|false)\")"),anf_arg17285698,anf_arg17295710,anf_arg17305722):R.ffi.throwNonFunApp(L[424],anf_fun17255686,[("parse-args(many-required-equals, [list: \"--foo\"]) satisfies\n  error-text(\"Option foo must be of the form --foo=(true|false)\")"),anf_arg17285698,anf_arg17295710,anf_arg17305722]);
};
try {
if(--R.GAS > 0) {
$z57145715 = $f57205721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57205721,
"from":L[424]});
}
} catch($e57125713) {
if(R.isCont($e57125713)) {
var $ss57165717 = {"from":L[424],
"go":function(anf_begin_app_dropped23355723) {
return $Hanf_begin_app_dropped24295724(anf_begin_app_dropped23355723,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e57125713.stack[R.EXN_STACKHEIGHT++] = $ss57165717;
}
if(R.isPyretException($e57125713)) {
$e57125713.pyretStack.push(L[424]);
}
throw $e57125713;
}
var $ret57185719 = $Hanf_begin_app_dropped24295724($z57145715,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret57185719;
};
var $Hanf_begin_app_dropped24295724 = function(anf_begin_app_dropped23355723,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,read_DASH_string9395,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z57275728 = D;
var $f57335734 = function(_) {
return R.isFunction(next_DASH_val124157.$var)?next_DASH_val124157.$var.app(read_DASH_string9395.$var,required_DASH_many113135.$var,("Foo")):R.ffi.throwNonFunApp(L[428],next_DASH_val124157.$var,[read_DASH_string9395.$var,required_DASH_many113135.$var,("Foo")]);
};
try {
if(--R.GAS > 0) {
$z57275728 = $f57335734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57335734,
"from":L[428]});
}
} catch($e57255726) {
if(R.isCont($e57255726)) {
var $ss57295730 = {"from":L[428],
"go":function(anf_obj17315735) {
return $Hanf_obj24285736(anf_obj17315735,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e57255726.stack[R.EXN_STACKHEIGHT++] = $ss57295730;
}
if(R.isPyretException($e57255726)) {
$e57255726.pyretStack.push(L[428]);
}
throw $e57255726;
}
var $ret57315732 = $Hanf_obj24285736($z57275728,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret57315732;
};
var $Hanf_obj24285736 = function(anf_obj17315735,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z57395740 = D;
var $f57455746 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(many109127.$var,("Bar")):R.ffi.throwNonFunApp(L[429],flag118145.$var,[many109127.$var,("Bar")]);
};
try {
if(--R.GAS > 0) {
$z57395740 = $f57455746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57455746,
"from":L[429]});
}
} catch($e57375738) {
if(R.isCont($e57375738)) {
var $ss57415742 = {"from":L[429],
"go":function(anf_obj17325747) {
return $Hanf_obj24275748(anf_obj17325747,anf_obj17315735,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e57375738.stack[R.EXN_STACKHEIGHT++] = $ss57415742;
}
if(R.isPyretException($e57375738)) {
$e57375738.pyretStack.push(L[429]);
}
throw $e57375738;
}
var $ret57435744 = $Hanf_obj24275748($z57395740,anf_obj17315735,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret57435744;
};
var $Hanf_obj24275748 = function(anf_obj17325747,anf_obj17315735,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var many_DASH_required_DASH_next_DASH_str3475761 = R.makeObject({"foo":anf_obj17315735,
"bar":anf_obj17325747});
var anf_fun17335759 = G(builtins15,"current-checker",L[430]);
var $z57515752 = D;
var $f57575758 = function(_) {
return R.isFunction(anf_fun17335759)?anf_fun17335759.app():R.ffi.throwNonFunApp(L[430],anf_fun17335759,[]);
};
try {
if(--R.GAS > 0) {
$z57515752 = $f57575758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57575758,
"from":L[430]});
}
} catch($e57495750) {
if(R.isCont($e57495750)) {
var $ss57535754 = {"from":L[430],
"go":function(anf_bracket17345760) {
return $Hanf_bracket24265762(anf_bracket17345760,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e57495750.stack[R.EXN_STACKHEIGHT++] = $ss57535754;
}
if(R.isPyretException($e57495750)) {
$e57495750.pyretStack.push(L[430]);
}
throw $e57495750;
}
var $ret57555756 = $Hanf_bracket24265762($z57515752,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret57555756;
};
var $Hanf_bracket24265762 = function(anf_bracket17345760,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17355775 = G(anf_bracket17345760,"check-is",L[430]);
var anf_fun17365773 = G(list2776,"make",L[431]);
var $z57655766 = D;
var $f57715772 = function(_) {
return R.isFunction(anf_fun17365773)?anf_fun17365773.app([("--foo"),("-bar")]):R.ffi.throwNonFunApp(L[431],anf_fun17365773,[[("--foo"),("-bar")]]);
};
try {
if(--R.GAS > 0) {
$z57655766 = $f57715772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57715772,
"from":L[431]});
}
} catch($e57635764) {
if(R.isCont($e57635764)) {
var $ss57675768 = {"from":L[431],
"go":function(anf_arg17375774) {
return $Hanf_arg24255776(anf_arg17375774,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e57635764.stack[R.EXN_STACKHEIGHT++] = $ss57675768;
}
if(R.isPyretException($e57635764)) {
$e57635764.pyretStack.push(L[431]);
}
throw $e57635764;
}
var $ret57695770 = $Hanf_arg24255776($z57655766,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret57695770;
};
var $Hanf_arg24255776 = function(anf_arg17375774,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z57795780 = D;
var $f57855786 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_required_DASH_next_DASH_str3475761,anf_arg17375774):R.ffi.throwNonFunApp(L[432],parse_DASH_args129167.$var,[many_DASH_required_DASH_next_DASH_str3475761,anf_arg17375774]);
};
try {
if(--R.GAS > 0) {
$z57795780 = $f57855786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57855786,
"from":L[432]});
}
} catch($e57775778) {
if(R.isCont($e57775778)) {
var $ss57815782 = {"from":L[432],
"go":function(anf_arg17385787) {
return $Hanf_arg24245788(anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e57775778.stack[R.EXN_STACKHEIGHT++] = $ss57815782;
}
if(R.isPyretException($e57775778)) {
$e57775778.pyretStack.push(L[432]);
}
throw $e57775778;
}
var $ret57835784 = $Hanf_arg24245788($z57795780,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret57835784;
};
var $Hanf_arg24245788 = function(anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17395801 = G(list2776,"make",L[434]);
var anf_fun17405799 = G(list2776,"make",L[433]);
var $z57915792 = D;
var $f57975798 = function(_) {
return R.isFunction(anf_fun17405799)?anf_fun17405799.app([("-bar")]):R.ffi.throwNonFunApp(L[433],anf_fun17405799,[[("-bar")]]);
};
try {
if(--R.GAS > 0) {
$z57915792 = $f57975798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57975798,
"from":L[433]});
}
} catch($e57895790) {
if(R.isCont($e57895790)) {
var $ss57935794 = {"from":L[433],
"go":function(anf_array_val17415800) {
return $Hanf_array_val24235802(anf_array_val17415800,anf_arg17385787,anf_fun17355775,anf_fun17395801,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e57895790.stack[R.EXN_STACKHEIGHT++] = $ss57935794;
}
if(R.isPyretException($e57895790)) {
$e57895790.pyretStack.push(L[433]);
}
throw $e57895790;
}
var $ret57955796 = $Hanf_array_val24235802($z57915792,anf_arg17385787,anf_fun17355775,anf_fun17395801,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret57955796;
};
var $Hanf_array_val24235802 = function(anf_array_val17415800,anf_arg17385787,anf_fun17355775,anf_fun17395801,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z58055806 = D;
var $f58115812 = function(_) {
return R.isFunction(anf_fun17395801)?anf_fun17395801.app([("foo"),anf_array_val17415800]):R.ffi.throwNonFunApp(L[434],anf_fun17395801,[[("foo"),anf_array_val17415800]]);
};
try {
if(--R.GAS > 0) {
$z58055806 = $f58115812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58115812,
"from":L[434]});
}
} catch($e58035804) {
if(R.isCont($e58035804)) {
var $ss58075808 = {"from":L[434],
"go":function(anf_arg17425813) {
return $Hanf_arg24225814(anf_arg17425813,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e58035804.stack[R.EXN_STACKHEIGHT++] = $ss58075808;
}
if(R.isPyretException($e58035804)) {
$e58035804.pyretStack.push(L[434]);
}
throw $e58035804;
}
var $ret58095810 = $Hanf_arg24225814($z58055806,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret58095810;
};
var $Hanf_arg24225814 = function(anf_arg17425813,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z58175818 = D;
var $f58235824 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg17425813):R.ffi.throwNonFunApp(L[435],dict131171.$var,[anf_arg17425813]);
};
try {
if(--R.GAS > 0) {
$z58175818 = $f58235824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58235824,
"from":L[435]});
}
} catch($e58155816) {
if(R.isCont($e58155816)) {
var $ss58195820 = {"from":L[435],
"go":function(anf_arg17435825) {
return $Hanf_arg24215826(anf_arg17435825,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e58155816.stack[R.EXN_STACKHEIGHT++] = $ss58195820;
}
if(R.isPyretException($e58155816)) {
$e58155816.pyretStack.push(L[435]);
}
throw $e58155816;
}
var $ret58215822 = $Hanf_arg24215826($z58175818,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret58215822;
};
var $Hanf_arg24215826 = function(anf_arg17435825,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17445837 = G(list2776,"make",L[436]);
var $z58295830 = D;
var $f58355836 = function(_) {
return R.isFunction(anf_fun17445837)?anf_fun17445837.app([]):R.ffi.throwNonFunApp(L[436],anf_fun17445837,[[]]);
};
try {
if(--R.GAS > 0) {
$z58295830 = $f58355836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58355836,
"from":L[436]});
}
} catch($e58275828) {
if(R.isCont($e58275828)) {
var $ss58315832 = {"from":L[436],
"go":function(anf_arg17455838) {
return $Hanf_arg24205839(anf_arg17455838,anf_arg17385787,anf_arg17435825,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e58275828.stack[R.EXN_STACKHEIGHT++] = $ss58315832;
}
if(R.isPyretException($e58275828)) {
$e58275828.pyretStack.push(L[436]);
}
throw $e58275828;
}
var $ret58335834 = $Hanf_arg24205839($z58295830,anf_arg17385787,anf_arg17435825,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret58335834;
};
var $Hanf_arg24205839 = function(anf_arg17455838,anf_arg17385787,anf_arg17435825,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z58425843 = D;
var $f58485849 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg17435825,anf_arg17455838):R.ffi.throwNonFunApp(L[437],success100109.$var,[anf_arg17435825,anf_arg17455838]);
};
try {
if(--R.GAS > 0) {
$z58425843 = $f58485849();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58485849,
"from":L[437]});
}
} catch($e58405841) {
if(R.isCont($e58405841)) {
var $ss58445845 = {"from":L[437],
"go":function(anf_arg17465850) {
return $Hanf_arg24195851(anf_arg17465850,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e58405841.stack[R.EXN_STACKHEIGHT++] = $ss58445845;
}
if(R.isPyretException($e58405841)) {
$e58405841.pyretStack.push(L[437]);
}
throw $e58405841;
}
var $ret58465847 = $Hanf_arg24195851($z58425843,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret58465847;
};
var $Hanf_arg24195851 = function(anf_arg17465850,anf_arg17385787,anf_fun17355775,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg17475862 = R.makeSrcloc(L[430]);
var $z58545855 = D;
var $f58605861 = function(_) {
return R.isFunction(anf_fun17355775)?anf_fun17355775.app(("parse-args(many-required-next-str, [list: \"--foo\", \"-bar\"]) is\n  success(dict([list: \"foo\", [list: \"-bar\"]]), [list: ])"),anf_arg17385787,anf_arg17465850,anf_arg17475862):R.ffi.throwNonFunApp(L[430],anf_fun17355775,[("parse-args(many-required-next-str, [list: \"--foo\", \"-bar\"]) is\n  success(dict([list: \"foo\", [list: \"-bar\"]]), [list: ])"),anf_arg17385787,anf_arg17465850,anf_arg17475862]);
};
try {
if(--R.GAS > 0) {
$z58545855 = $f58605861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58605861,
"from":L[430]});
}
} catch($e58525853) {
if(R.isCont($e58525853)) {
var $ss58565857 = {"from":L[430],
"go":function(anf_begin_app_dropped23365863) {
return $Hanf_begin_app_dropped24185864(anf_begin_app_dropped23365863,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e58525853.stack[R.EXN_STACKHEIGHT++] = $ss58565857;
}
if(R.isPyretException($e58525853)) {
$e58525853.pyretStack.push(L[430]);
}
throw $e58525853;
}
var $ret58585859 = $Hanf_begin_app_dropped24185864($z58545855,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret58585859;
};
var $Hanf_begin_app_dropped24185864 = function(anf_begin_app_dropped23365863,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17485875 = G(builtins15,"current-checker",L[438]);
var $z58675868 = D;
var $f58735874 = function(_) {
return R.isFunction(anf_fun17485875)?anf_fun17485875.app():R.ffi.throwNonFunApp(L[438],anf_fun17485875,[]);
};
try {
if(--R.GAS > 0) {
$z58675868 = $f58735874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58735874,
"from":L[438]});
}
} catch($e58655866) {
if(R.isCont($e58655866)) {
var $ss58695870 = {"from":L[438],
"go":function(anf_bracket17495876) {
return $Hanf_bracket24175877(anf_bracket17495876,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e58655866.stack[R.EXN_STACKHEIGHT++] = $ss58695870;
}
if(R.isPyretException($e58655866)) {
$e58655866.pyretStack.push(L[438]);
}
throw $e58655866;
}
var $ret58715872 = $Hanf_bracket24175877($z58675868,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret58715872;
};
var $Hanf_bracket24175877 = function(anf_bracket17495876,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17505890 = G(anf_bracket17495876,"check-satisfies",L[438]);
var anf_fun17515888 = G(list2776,"make",L[439]);
var $z58805881 = D;
var $f58865887 = function(_) {
return R.isFunction(anf_fun17515888)?anf_fun17515888.app([("-bar"),("--foo")]):R.ffi.throwNonFunApp(L[439],anf_fun17515888,[[("-bar"),("--foo")]]);
};
try {
if(--R.GAS > 0) {
$z58805881 = $f58865887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58865887,
"from":L[439]});
}
} catch($e58785879) {
if(R.isCont($e58785879)) {
var $ss58825883 = {"from":L[439],
"go":function(anf_arg17525889) {
return $Hanf_arg24165891(anf_arg17525889,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e58785879.stack[R.EXN_STACKHEIGHT++] = $ss58825883;
}
if(R.isPyretException($e58785879)) {
$e58785879.pyretStack.push(L[439]);
}
throw $e58785879;
}
var $ret58845885 = $Hanf_arg24165891($z58805881,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret58845885;
};
var $Hanf_arg24165891 = function(anf_arg17525889,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_str3475761,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z58945895 = D;
var $f59005901 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_required_DASH_next_DASH_str3475761,anf_arg17525889):R.ffi.throwNonFunApp(L[440],parse_DASH_args129167.$var,[many_DASH_required_DASH_next_DASH_str3475761,anf_arg17525889]);
};
try {
if(--R.GAS > 0) {
$z58945895 = $f59005901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59005901,
"from":L[440]});
}
} catch($e58925893) {
if(R.isCont($e58925893)) {
var $ss58965897 = {"from":L[440],
"go":function(anf_arg17535902) {
return $Hanf_arg24155903(anf_arg17535902,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e58925893.stack[R.EXN_STACKHEIGHT++] = $ss58965897;
}
if(R.isPyretException($e58925893)) {
$e58925893.pyretStack.push(L[440]);
}
throw $e58925893;
}
var $ret58985899 = $Hanf_arg24155903($z58945895,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret58985899;
};
var $Hanf_arg24155903 = function(anf_arg17535902,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z59065907 = D;
var $f59125913 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("Missing value for option foo; it must be of the form --foo <string>")):R.ffi.throwNonFunApp(L[441],error_DASH_text3331409.$var,[("Missing value for option foo; it must be of the form --foo <string>")]);
};
try {
if(--R.GAS > 0) {
$z59065907 = $f59125913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59125913,
"from":L[441]});
}
} catch($e59045905) {
if(R.isCont($e59045905)) {
var $ss59085909 = {"from":L[441],
"go":function(anf_arg17545914) {
return $Hanf_arg24145915(anf_arg17545914,anf_arg17535902,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e59045905.stack[R.EXN_STACKHEIGHT++] = $ss59085909;
}
if(R.isPyretException($e59045905)) {
$e59045905.pyretStack.push(L[441]);
}
throw $e59045905;
}
var $ret59105911 = $Hanf_arg24145915($z59065907,anf_arg17535902,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret59105911;
};
var $Hanf_arg24145915 = function(anf_arg17545914,anf_arg17535902,anf_fun17505890,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg17555926 = R.makeSrcloc(L[438]);
var $z59185919 = D;
var $f59245925 = function(_) {
return R.isFunction(anf_fun17505890)?anf_fun17505890.app(("parse-args(many-required-next-str, [list: \"-bar\", \"--foo\"]) satisfies\n  error-text(\"Missing value for option foo; it must be of the form --foo <string>\")"),anf_arg17535902,anf_arg17545914,anf_arg17555926):R.ffi.throwNonFunApp(L[438],anf_fun17505890,[("parse-args(many-required-next-str, [list: \"-bar\", \"--foo\"]) satisfies\n  error-text(\"Missing value for option foo; it must be of the form --foo <string>\")"),anf_arg17535902,anf_arg17545914,anf_arg17555926]);
};
try {
if(--R.GAS > 0) {
$z59185919 = $f59245925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59245925,
"from":L[438]});
}
} catch($e59165917) {
if(R.isCont($e59165917)) {
var $ss59205921 = {"from":L[438],
"go":function(anf_begin_app_dropped23375927) {
return $Hanf_begin_app_dropped24135928(anf_begin_app_dropped23375927,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
}};
$e59165917.stack[R.EXN_STACKHEIGHT++] = $ss59205921;
}
if(R.isPyretException($e59165917)) {
$e59165917.pyretStack.push(L[438]);
}
throw $e59165917;
}
var $ret59225923 = $Hanf_begin_app_dropped24135928($z59185919,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret59225923;
};
var $Hanf_begin_app_dropped24135928 = function(anf_begin_app_dropped23375927,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,next_DASH_val124157,parse_DASH_args129167,read_DASH_custom9599,read_DASH_number8987,red136181,required_DASH_many113135,right8177,some6478,success100109,builtins15,torepr24) {
var $z59315932 = D;
var $f59375938 = function(_) {
return R.isFunction(next_DASH_val124157.$var)?next_DASH_val124157.$var.app(read_DASH_number8987.$var,required_DASH_many113135.$var,("Foo")):R.ffi.throwNonFunApp(L[442],next_DASH_val124157.$var,[read_DASH_number8987.$var,required_DASH_many113135.$var,("Foo")]);
};
try {
if(--R.GAS > 0) {
$z59315932 = $f59375938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59375938,
"from":L[442]});
}
} catch($e59295930) {
if(R.isCont($e59295930)) {
var $ss59335934 = {"from":L[442],
"go":function(anf_obj17565939) {
return $Hanf_obj24125940(anf_obj17565939,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e59295930.stack[R.EXN_STACKHEIGHT++] = $ss59335934;
}
if(R.isPyretException($e59295930)) {
$e59295930.pyretStack.push(L[442]);
}
throw $e59295930;
}
var $ret59355936 = $Hanf_obj24125940($z59315932,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret59355936;
};
var $Hanf_obj24125940 = function(anf_obj17565939,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z59435944 = D;
var $f59495950 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(many109127.$var,("Bar")):R.ffi.throwNonFunApp(L[443],flag118145.$var,[many109127.$var,("Bar")]);
};
try {
if(--R.GAS > 0) {
$z59435944 = $f59495950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59495950,
"from":L[443]});
}
} catch($e59415942) {
if(R.isCont($e59415942)) {
var $ss59455946 = {"from":L[443],
"go":function(anf_obj17575951) {
return $Hanf_obj24115952(anf_obj17575951,anf_obj17565939,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e59415942.stack[R.EXN_STACKHEIGHT++] = $ss59455946;
}
if(R.isPyretException($e59415942)) {
$e59415942.pyretStack.push(L[443]);
}
throw $e59415942;
}
var $ret59475948 = $Hanf_obj24115952($z59435944,anf_obj17565939,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret59475948;
};
var $Hanf_obj24115952 = function(anf_obj17575951,anf_obj17565939,blue140189,dict131171,error_DASH_text3331409,flag118145,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z59555956 = D;
var $f59615962 = function(_) {
return R.isFunction(flag118145.$var)?flag118145.$var.app(many109127.$var,("Flag-4")):R.ffi.throwNonFunApp(L[444],flag118145.$var,[many109127.$var,("Flag-4")]);
};
try {
if(--R.GAS > 0) {
$z59555956 = $f59615962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59615962,
"from":L[444]});
}
} catch($e59535954) {
if(R.isCont($e59535954)) {
var $ss59575958 = {"from":L[444],
"go":function(anf_obj17585963) {
return $Hanf_obj24105964(anf_obj17585963,anf_obj17565939,anf_obj17575951,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e59535954.stack[R.EXN_STACKHEIGHT++] = $ss59575958;
}
if(R.isPyretException($e59535954)) {
$e59535954.pyretStack.push(L[444]);
}
throw $e59535954;
}
var $ret59595960 = $Hanf_obj24105964($z59555956,anf_obj17565939,anf_obj17575951,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret59595960;
};
var $Hanf_obj24105964 = function(anf_obj17585963,anf_obj17565939,anf_obj17575951,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var many_DASH_required_DASH_next_DASH_num3485977 = R.makeObject({"foo":anf_obj17565939,
"bar":anf_obj17575951,
"4":anf_obj17585963});
var anf_fun17595975 = G(builtins15,"current-checker",L[445]);
var $z59675968 = D;
var $f59735974 = function(_) {
return R.isFunction(anf_fun17595975)?anf_fun17595975.app():R.ffi.throwNonFunApp(L[445],anf_fun17595975,[]);
};
try {
if(--R.GAS > 0) {
$z59675968 = $f59735974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59735974,
"from":L[445]});
}
} catch($e59655966) {
if(R.isCont($e59655966)) {
var $ss59695970 = {"from":L[445],
"go":function(anf_bracket17605976) {
return $Hanf_bracket24095978(anf_bracket17605976,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e59655966.stack[R.EXN_STACKHEIGHT++] = $ss59695970;
}
if(R.isPyretException($e59655966)) {
$e59655966.pyretStack.push(L[445]);
}
throw $e59655966;
}
var $ret59715972 = $Hanf_bracket24095978($z59675968,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret59715972;
};
var $Hanf_bracket24095978 = function(anf_bracket17605976,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17615991 = G(anf_bracket17605976,"check-satisfies",L[445]);
var anf_fun17625989 = G(list2776,"make",L[446]);
var $z59815982 = D;
var $f59875988 = function(_) {
return R.isFunction(anf_fun17625989)?anf_fun17625989.app([("--foo"),("-bar")]):R.ffi.throwNonFunApp(L[446],anf_fun17625989,[[("--foo"),("-bar")]]);
};
try {
if(--R.GAS > 0) {
$z59815982 = $f59875988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59875988,
"from":L[446]});
}
} catch($e59795980) {
if(R.isCont($e59795980)) {
var $ss59835984 = {"from":L[446],
"go":function(anf_arg17635990) {
return $Hanf_arg24085992(anf_arg17635990,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e59795980.stack[R.EXN_STACKHEIGHT++] = $ss59835984;
}
if(R.isPyretException($e59795980)) {
$e59795980.pyretStack.push(L[446]);
}
throw $e59795980;
}
var $ret59855986 = $Hanf_arg24085992($z59815982,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret59855986;
};
var $Hanf_arg24085992 = function(anf_arg17635990,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z59955996 = D;
var $f60016002 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_required_DASH_next_DASH_num3485977,anf_arg17635990):R.ffi.throwNonFunApp(L[447],parse_DASH_args129167.$var,[many_DASH_required_DASH_next_DASH_num3485977,anf_arg17635990]);
};
try {
if(--R.GAS > 0) {
$z59955996 = $f60016002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60016002,
"from":L[447]});
}
} catch($e59935994) {
if(R.isCont($e59935994)) {
var $ss59975998 = {"from":L[447],
"go":function(anf_arg17646003) {
return $Hanf_arg24076004(anf_arg17646003,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e59935994.stack[R.EXN_STACKHEIGHT++] = $ss59975998;
}
if(R.isPyretException($e59935994)) {
$e59935994.pyretStack.push(L[447]);
}
throw $e59935994;
}
var $ret59996000 = $Hanf_arg24076004($z59955996,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret59996000;
};
var $Hanf_arg24076004 = function(anf_arg17646003,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z60076008 = D;
var $f60136014 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("Missing value for option foo; it must be of the form --foo <number>")):R.ffi.throwNonFunApp(L[448],error_DASH_text3331409.$var,[("Missing value for option foo; it must be of the form --foo <number>")]);
};
try {
if(--R.GAS > 0) {
$z60076008 = $f60136014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60136014,
"from":L[448]});
}
} catch($e60056006) {
if(R.isCont($e60056006)) {
var $ss60096010 = {"from":L[448],
"go":function(anf_arg17656015) {
return $Hanf_arg24066016(anf_arg17656015,anf_arg17646003,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e60056006.stack[R.EXN_STACKHEIGHT++] = $ss60096010;
}
if(R.isPyretException($e60056006)) {
$e60056006.pyretStack.push(L[448]);
}
throw $e60056006;
}
var $ret60116012 = $Hanf_arg24066016($z60076008,anf_arg17646003,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret60116012;
};
var $Hanf_arg24066016 = function(anf_arg17656015,anf_arg17646003,anf_fun17615991,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg17666027 = R.makeSrcloc(L[445]);
var $z60196020 = D;
var $f60256026 = function(_) {
return R.isFunction(anf_fun17615991)?anf_fun17615991.app(("parse-args(many-required-next-num, [list: \"--foo\", \"-bar\"]) satisfies\n  error-text(\"Missing value for option foo; it must be of the form --foo <number>\")"),anf_arg17646003,anf_arg17656015,anf_arg17666027):R.ffi.throwNonFunApp(L[445],anf_fun17615991,[("parse-args(many-required-next-num, [list: \"--foo\", \"-bar\"]) satisfies\n  error-text(\"Missing value for option foo; it must be of the form --foo <number>\")"),anf_arg17646003,anf_arg17656015,anf_arg17666027]);
};
try {
if(--R.GAS > 0) {
$z60196020 = $f60256026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60256026,
"from":L[445]});
}
} catch($e60176018) {
if(R.isCont($e60176018)) {
var $ss60216022 = {"from":L[445],
"go":function(anf_begin_app_dropped23386028) {
return $Hanf_begin_app_dropped24056029(anf_begin_app_dropped23386028,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e60176018.stack[R.EXN_STACKHEIGHT++] = $ss60216022;
}
if(R.isPyretException($e60176018)) {
$e60176018.pyretStack.push(L[445]);
}
throw $e60176018;
}
var $ret60236024 = $Hanf_begin_app_dropped24056029($z60196020,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret60236024;
};
var $Hanf_begin_app_dropped24056029 = function(anf_begin_app_dropped23386028,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17676040 = G(builtins15,"current-checker",L[449]);
var $z60326033 = D;
var $f60386039 = function(_) {
return R.isFunction(anf_fun17676040)?anf_fun17676040.app():R.ffi.throwNonFunApp(L[449],anf_fun17676040,[]);
};
try {
if(--R.GAS > 0) {
$z60326033 = $f60386039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60386039,
"from":L[449]});
}
} catch($e60306031) {
if(R.isCont($e60306031)) {
var $ss60346035 = {"from":L[449],
"go":function(anf_bracket17686041) {
return $Hanf_bracket24046042(anf_bracket17686041,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e60306031.stack[R.EXN_STACKHEIGHT++] = $ss60346035;
}
if(R.isPyretException($e60306031)) {
$e60306031.pyretStack.push(L[449]);
}
throw $e60306031;
}
var $ret60366037 = $Hanf_bracket24046042($z60326033,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret60366037;
};
var $Hanf_bracket24046042 = function(anf_bracket17686041,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17696055 = G(anf_bracket17686041,"check-is",L[449]);
var anf_fun17706053 = G(list2776,"make",L[450]);
var $z60456046 = D;
var $f60516052 = function(_) {
return R.isFunction(anf_fun17706053)?anf_fun17706053.app([("--foo"),("-4")]):R.ffi.throwNonFunApp(L[450],anf_fun17706053,[[("--foo"),("-4")]]);
};
try {
if(--R.GAS > 0) {
$z60456046 = $f60516052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60516052,
"from":L[450]});
}
} catch($e60436044) {
if(R.isCont($e60436044)) {
var $ss60476048 = {"from":L[450],
"go":function(anf_arg17716054) {
return $Hanf_arg24036056(anf_arg17716054,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e60436044.stack[R.EXN_STACKHEIGHT++] = $ss60476048;
}
if(R.isPyretException($e60436044)) {
$e60436044.pyretStack.push(L[450]);
}
throw $e60436044;
}
var $ret60496050 = $Hanf_arg24036056($z60456046,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret60496050;
};
var $Hanf_arg24036056 = function(anf_arg17716054,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z60596060 = D;
var $f60656066 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_required_DASH_next_DASH_num3485977,anf_arg17716054):R.ffi.throwNonFunApp(L[451],parse_DASH_args129167.$var,[many_DASH_required_DASH_next_DASH_num3485977,anf_arg17716054]);
};
try {
if(--R.GAS > 0) {
$z60596060 = $f60656066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60656066,
"from":L[451]});
}
} catch($e60576058) {
if(R.isCont($e60576058)) {
var $ss60616062 = {"from":L[451],
"go":function(anf_arg17726067) {
return $Hanf_arg24026068(anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e60576058.stack[R.EXN_STACKHEIGHT++] = $ss60616062;
}
if(R.isPyretException($e60576058)) {
$e60576058.pyretStack.push(L[451]);
}
throw $e60576058;
}
var $ret60636064 = $Hanf_arg24026068($z60596060,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret60636064;
};
var $Hanf_arg24026068 = function(anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17736081 = G(list2776,"make",L[453]);
var anf_fun17746079 = G(list2776,"make",L[452]);
var $z60716072 = D;
var $f60776078 = function(_) {
return R.isFunction(anf_fun17746079)?anf_fun17746079.app([(-4)]):R.ffi.throwNonFunApp(L[452],anf_fun17746079,[[(-4)]]);
};
try {
if(--R.GAS > 0) {
$z60716072 = $f60776078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60776078,
"from":L[452]});
}
} catch($e60696070) {
if(R.isCont($e60696070)) {
var $ss60736074 = {"from":L[452],
"go":function(anf_array_val17756080) {
return $Hanf_array_val24016082(anf_array_val17756080,anf_arg17726067,anf_fun17696055,anf_fun17736081,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e60696070.stack[R.EXN_STACKHEIGHT++] = $ss60736074;
}
if(R.isPyretException($e60696070)) {
$e60696070.pyretStack.push(L[452]);
}
throw $e60696070;
}
var $ret60756076 = $Hanf_array_val24016082($z60716072,anf_arg17726067,anf_fun17696055,anf_fun17736081,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret60756076;
};
var $Hanf_array_val24016082 = function(anf_array_val17756080,anf_arg17726067,anf_fun17696055,anf_fun17736081,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z60856086 = D;
var $f60916092 = function(_) {
return R.isFunction(anf_fun17736081)?anf_fun17736081.app([("foo"),anf_array_val17756080]):R.ffi.throwNonFunApp(L[453],anf_fun17736081,[[("foo"),anf_array_val17756080]]);
};
try {
if(--R.GAS > 0) {
$z60856086 = $f60916092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60916092,
"from":L[453]});
}
} catch($e60836084) {
if(R.isCont($e60836084)) {
var $ss60876088 = {"from":L[453],
"go":function(anf_arg17766093) {
return $Hanf_arg24006094(anf_arg17766093,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e60836084.stack[R.EXN_STACKHEIGHT++] = $ss60876088;
}
if(R.isPyretException($e60836084)) {
$e60836084.pyretStack.push(L[453]);
}
throw $e60836084;
}
var $ret60896090 = $Hanf_arg24006094($z60856086,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret60896090;
};
var $Hanf_arg24006094 = function(anf_arg17766093,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z60976098 = D;
var $f61036104 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg17766093):R.ffi.throwNonFunApp(L[454],dict131171.$var,[anf_arg17766093]);
};
try {
if(--R.GAS > 0) {
$z60976098 = $f61036104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61036104,
"from":L[454]});
}
} catch($e60956096) {
if(R.isCont($e60956096)) {
var $ss60996100 = {"from":L[454],
"go":function(anf_arg17776105) {
return $Hanf_arg23996106(anf_arg17776105,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e60956096.stack[R.EXN_STACKHEIGHT++] = $ss60996100;
}
if(R.isPyretException($e60956096)) {
$e60956096.pyretStack.push(L[454]);
}
throw $e60956096;
}
var $ret61016102 = $Hanf_arg23996106($z60976098,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret61016102;
};
var $Hanf_arg23996106 = function(anf_arg17776105,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17786117 = G(list2776,"make",L[455]);
var $z61096110 = D;
var $f61156116 = function(_) {
return R.isFunction(anf_fun17786117)?anf_fun17786117.app([]):R.ffi.throwNonFunApp(L[455],anf_fun17786117,[[]]);
};
try {
if(--R.GAS > 0) {
$z61096110 = $f61156116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61156116,
"from":L[455]});
}
} catch($e61076108) {
if(R.isCont($e61076108)) {
var $ss61116112 = {"from":L[455],
"go":function(anf_arg17796118) {
return $Hanf_arg23986119(anf_arg17796118,anf_arg17726067,anf_arg17776105,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e61076108.stack[R.EXN_STACKHEIGHT++] = $ss61116112;
}
if(R.isPyretException($e61076108)) {
$e61076108.pyretStack.push(L[455]);
}
throw $e61076108;
}
var $ret61136114 = $Hanf_arg23986119($z61096110,anf_arg17726067,anf_arg17776105,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret61136114;
};
var $Hanf_arg23986119 = function(anf_arg17796118,anf_arg17726067,anf_arg17776105,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z61226123 = D;
var $f61286129 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg17776105,anf_arg17796118):R.ffi.throwNonFunApp(L[456],success100109.$var,[anf_arg17776105,anf_arg17796118]);
};
try {
if(--R.GAS > 0) {
$z61226123 = $f61286129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61286129,
"from":L[456]});
}
} catch($e61206121) {
if(R.isCont($e61206121)) {
var $ss61246125 = {"from":L[456],
"go":function(anf_arg17806130) {
return $Hanf_arg23976131(anf_arg17806130,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e61206121.stack[R.EXN_STACKHEIGHT++] = $ss61246125;
}
if(R.isPyretException($e61206121)) {
$e61206121.pyretStack.push(L[456]);
}
throw $e61206121;
}
var $ret61266127 = $Hanf_arg23976131($z61226123,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret61266127;
};
var $Hanf_arg23976131 = function(anf_arg17806130,anf_arg17726067,anf_fun17696055,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg17816142 = R.makeSrcloc(L[449]);
var $z61346135 = D;
var $f61406141 = function(_) {
return R.isFunction(anf_fun17696055)?anf_fun17696055.app(("parse-args(many-required-next-num, [list: \"--foo\", \"-4\"]) is\n  success(dict([list: \"foo\", [list: -4]]), [list: ])"),anf_arg17726067,anf_arg17806130,anf_arg17816142):R.ffi.throwNonFunApp(L[449],anf_fun17696055,[("parse-args(many-required-next-num, [list: \"--foo\", \"-4\"]) is\n  success(dict([list: \"foo\", [list: -4]]), [list: ])"),anf_arg17726067,anf_arg17806130,anf_arg17816142]);
};
try {
if(--R.GAS > 0) {
$z61346135 = $f61406141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61406141,
"from":L[449]});
}
} catch($e61326133) {
if(R.isCont($e61326133)) {
var $ss61366137 = {"from":L[449],
"go":function(anf_begin_app_dropped23396143) {
return $Hanf_begin_app_dropped23966144(anf_begin_app_dropped23396143,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e61326133.stack[R.EXN_STACKHEIGHT++] = $ss61366137;
}
if(R.isPyretException($e61326133)) {
$e61326133.pyretStack.push(L[449]);
}
throw $e61326133;
}
var $ret61386139 = $Hanf_begin_app_dropped23966144($z61346135,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret61386139;
};
var $Hanf_begin_app_dropped23966144 = function(anf_begin_app_dropped23396143,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17826155 = G(builtins15,"current-checker",L[457]);
var $z61476148 = D;
var $f61536154 = function(_) {
return R.isFunction(anf_fun17826155)?anf_fun17826155.app():R.ffi.throwNonFunApp(L[457],anf_fun17826155,[]);
};
try {
if(--R.GAS > 0) {
$z61476148 = $f61536154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61536154,
"from":L[457]});
}
} catch($e61456146) {
if(R.isCont($e61456146)) {
var $ss61496150 = {"from":L[457],
"go":function(anf_bracket17836156) {
return $Hanf_bracket23956157(anf_bracket17836156,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e61456146.stack[R.EXN_STACKHEIGHT++] = $ss61496150;
}
if(R.isPyretException($e61456146)) {
$e61456146.pyretStack.push(L[457]);
}
throw $e61456146;
}
var $ret61516152 = $Hanf_bracket23956157($z61476148,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret61516152;
};
var $Hanf_bracket23956157 = function(anf_bracket17836156,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17846170 = G(anf_bracket17836156,"check-is",L[457]);
var anf_fun17856168 = G(list2776,"make",L[458]);
var $z61606161 = D;
var $f61666167 = function(_) {
return R.isFunction(anf_fun17856168)?anf_fun17856168.app([("--foo"),("-4"),("-4")]):R.ffi.throwNonFunApp(L[458],anf_fun17856168,[[("--foo"),("-4"),("-4")]]);
};
try {
if(--R.GAS > 0) {
$z61606161 = $f61666167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61666167,
"from":L[458]});
}
} catch($e61586159) {
if(R.isCont($e61586159)) {
var $ss61626163 = {"from":L[458],
"go":function(anf_arg17866169) {
return $Hanf_arg23946171(anf_arg17866169,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e61586159.stack[R.EXN_STACKHEIGHT++] = $ss61626163;
}
if(R.isPyretException($e61586159)) {
$e61586159.pyretStack.push(L[458]);
}
throw $e61586159;
}
var $ret61646165 = $Hanf_arg23946171($z61606161,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret61646165;
};
var $Hanf_arg23946171 = function(anf_arg17866169,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many_DASH_required_DASH_next_DASH_num3485977,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z61746175 = D;
var $f61806181 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_required_DASH_next_DASH_num3485977,anf_arg17866169):R.ffi.throwNonFunApp(L[459],parse_DASH_args129167.$var,[many_DASH_required_DASH_next_DASH_num3485977,anf_arg17866169]);
};
try {
if(--R.GAS > 0) {
$z61746175 = $f61806181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61806181,
"from":L[459]});
}
} catch($e61726173) {
if(R.isCont($e61726173)) {
var $ss61766177 = {"from":L[459],
"go":function(anf_arg17876182) {
return $Hanf_arg23936183(anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e61726173.stack[R.EXN_STACKHEIGHT++] = $ss61766177;
}
if(R.isPyretException($e61726173)) {
$e61726173.pyretStack.push(L[459]);
}
throw $e61726173;
}
var $ret61786179 = $Hanf_arg23936183($z61746175,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret61786179;
};
var $Hanf_arg23936183 = function(anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17886196 = G(list2776,"make",L[461]);
var anf_fun17896194 = G(list2776,"make",L[460]);
var $z61866187 = D;
var $f61926193 = function(_) {
return R.isFunction(anf_fun17896194)?anf_fun17896194.app([(-4)]):R.ffi.throwNonFunApp(L[460],anf_fun17896194,[[(-4)]]);
};
try {
if(--R.GAS > 0) {
$z61866187 = $f61926193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61926193,
"from":L[460]});
}
} catch($e61846185) {
if(R.isCont($e61846185)) {
var $ss61886189 = {"from":L[460],
"go":function(anf_array_val17906195) {
return $Hanf_array_val23926197(anf_array_val17906195,anf_arg17876182,anf_fun17846170,anf_fun17886196,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e61846185.stack[R.EXN_STACKHEIGHT++] = $ss61886189;
}
if(R.isPyretException($e61846185)) {
$e61846185.pyretStack.push(L[460]);
}
throw $e61846185;
}
var $ret61906191 = $Hanf_array_val23926197($z61866187,anf_arg17876182,anf_fun17846170,anf_fun17886196,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret61906191;
};
var $Hanf_array_val23926197 = function(anf_array_val17906195,anf_arg17876182,anf_fun17846170,anf_fun17886196,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17916208 = G(list2776,"make",L[462]);
var $z62006201 = D;
var $f62066207 = function(_) {
return R.isFunction(anf_fun17916208)?anf_fun17916208.app([(true)]):R.ffi.throwNonFunApp(L[462],anf_fun17916208,[[(true)]]);
};
try {
if(--R.GAS > 0) {
$z62006201 = $f62066207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62066207,
"from":L[462]});
}
} catch($e61986199) {
if(R.isCont($e61986199)) {
var $ss62026203 = {"from":L[462],
"go":function(anf_array_val17926209) {
return $Hanf_array_val23916210(anf_array_val17926209,anf_arg17876182,anf_array_val17906195,anf_fun17846170,anf_fun17886196,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e61986199.stack[R.EXN_STACKHEIGHT++] = $ss62026203;
}
if(R.isPyretException($e61986199)) {
$e61986199.pyretStack.push(L[462]);
}
throw $e61986199;
}
var $ret62046205 = $Hanf_array_val23916210($z62006201,anf_arg17876182,anf_array_val17906195,anf_fun17846170,anf_fun17886196,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret62046205;
};
var $Hanf_array_val23916210 = function(anf_array_val17926209,anf_arg17876182,anf_array_val17906195,anf_fun17846170,anf_fun17886196,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z62136214 = D;
var $f62196220 = function(_) {
return R.isFunction(anf_fun17886196)?anf_fun17886196.app([("foo"),anf_array_val17906195,("4"),anf_array_val17926209]):R.ffi.throwNonFunApp(L[461],anf_fun17886196,[[("foo"),anf_array_val17906195,("4"),anf_array_val17926209]]);
};
try {
if(--R.GAS > 0) {
$z62136214 = $f62196220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62196220,
"from":L[461]});
}
} catch($e62116212) {
if(R.isCont($e62116212)) {
var $ss62156216 = {"from":L[461],
"go":function(anf_arg17936221) {
return $Hanf_arg23906222(anf_arg17936221,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e62116212.stack[R.EXN_STACKHEIGHT++] = $ss62156216;
}
if(R.isPyretException($e62116212)) {
$e62116212.pyretStack.push(L[461]);
}
throw $e62116212;
}
var $ret62176218 = $Hanf_arg23906222($z62136214,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret62176218;
};
var $Hanf_arg23906222 = function(anf_arg17936221,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z62256226 = D;
var $f62316232 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg17936221):R.ffi.throwNonFunApp(L[463],dict131171.$var,[anf_arg17936221]);
};
try {
if(--R.GAS > 0) {
$z62256226 = $f62316232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62316232,
"from":L[463]});
}
} catch($e62236224) {
if(R.isCont($e62236224)) {
var $ss62276228 = {"from":L[463],
"go":function(anf_arg17946233) {
return $Hanf_arg23896234(anf_arg17946233,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e62236224.stack[R.EXN_STACKHEIGHT++] = $ss62276228;
}
if(R.isPyretException($e62236224)) {
$e62236224.pyretStack.push(L[463]);
}
throw $e62236224;
}
var $ret62296230 = $Hanf_arg23896234($z62256226,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret62296230;
};
var $Hanf_arg23896234 = function(anf_arg17946233,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_fun17956245 = G(list2776,"make",L[464]);
var $z62376238 = D;
var $f62436244 = function(_) {
return R.isFunction(anf_fun17956245)?anf_fun17956245.app([]):R.ffi.throwNonFunApp(L[464],anf_fun17956245,[[]]);
};
try {
if(--R.GAS > 0) {
$z62376238 = $f62436244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62436244,
"from":L[464]});
}
} catch($e62356236) {
if(R.isCont($e62356236)) {
var $ss62396240 = {"from":L[464],
"go":function(anf_arg17966246) {
return $Hanf_arg23886247(anf_arg17966246,anf_arg17876182,anf_arg17946233,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e62356236.stack[R.EXN_STACKHEIGHT++] = $ss62396240;
}
if(R.isPyretException($e62356236)) {
$e62356236.pyretStack.push(L[464]);
}
throw $e62356236;
}
var $ret62416242 = $Hanf_arg23886247($z62376238,anf_arg17876182,anf_arg17946233,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret62416242;
};
var $Hanf_arg23886247 = function(anf_arg17966246,anf_arg17876182,anf_arg17946233,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var $z62506251 = D;
var $f62566257 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg17946233,anf_arg17966246):R.ffi.throwNonFunApp(L[465],success100109.$var,[anf_arg17946233,anf_arg17966246]);
};
try {
if(--R.GAS > 0) {
$z62506251 = $f62566257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62566257,
"from":L[465]});
}
} catch($e62486249) {
if(R.isCont($e62486249)) {
var $ss62526253 = {"from":L[465],
"go":function(anf_arg17976258) {
return $Hanf_arg23876259(anf_arg17976258,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e62486249.stack[R.EXN_STACKHEIGHT++] = $ss62526253;
}
if(R.isPyretException($e62486249)) {
$e62486249.pyretStack.push(L[465]);
}
throw $e62486249;
}
var $ret62546255 = $Hanf_arg23876259($z62506251,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret62546255;
};
var $Hanf_arg23876259 = function(anf_arg17976258,anf_arg17876182,anf_fun17846170,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg17986270 = R.makeSrcloc(L[457]);
var $z62626263 = D;
var $f62686269 = function(_) {
return R.isFunction(anf_fun17846170)?anf_fun17846170.app(("parse-args(many-required-next-num, [list: \"--foo\", \"-4\", \"-4\"]) is\n  success(dict([list: \"foo\", [list: -4], \"4\", [list: true]]), [list: ])"),anf_arg17876182,anf_arg17976258,anf_arg17986270):R.ffi.throwNonFunApp(L[457],anf_fun17846170,[("parse-args(many-required-next-num, [list: \"--foo\", \"-4\", \"-4\"]) is\n  success(dict([list: \"foo\", [list: -4], \"4\", [list: true]]), [list: ])"),anf_arg17876182,anf_arg17976258,anf_arg17986270]);
};
try {
if(--R.GAS > 0) {
$z62626263 = $f62686269();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62686269,
"from":L[457]});
}
} catch($e62606261) {
if(R.isCont($e62606261)) {
var $ss62646265 = {"from":L[457],
"go":function(anf_begin_app_dropped23406271) {
return $Hanf_begin_app_dropped23866272(anf_begin_app_dropped23406271,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
}};
$e62606261.stack[R.EXN_STACKHEIGHT++] = $ss62646265;
}
if(R.isPyretException($e62606261)) {
$e62606261.pyretStack.push(L[457]);
}
throw $e62606261;
}
var $ret62666267 = $Hanf_begin_app_dropped23866272($z62626263,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24);
++R.GAS;
return $ret62666267;
};
var $Hanf_begin_app_dropped23866272 = function(anf_begin_app_dropped23406271,blue140189,dict131171,error_DASH_text3331409,format7872,green138185,left8074,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,read_DASH_custom9599,red136181,right8177,some6478,success100109,builtins15,torepr24) {
var anf_arg18236283 = R.makeFunction(function(arg_DASH_index3506286,name3516287,val3526288) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[467],3,arguments);
}
var if_DASH_1786349 = R.equiv(val3526288,("red"));
var if_helper18006300 = R.makeFunction(function(if_helper_arg18016354) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[475],1,arguments);
}
var ann_DASH_check_DASH_temp17996355 = if_helper_arg18016354;
return ann_DASH_check_DASH_temp17996355;
});
var anf_if18046353 = R.isBoolean(if_DASH_1786349);
if(R.isPyretTrue(anf_if18046353)) {
if(R.isPyretTrue(if_DASH_1786349)) {
var $z62916292 = D;
var $f62976298 = function(_) {
return R.isFunction(left8074)?left8074.app(red136181.$var):R.ffi.throwNonFunApp(L[468],left8074,[red136181.$var]);
};
try {
if(--R.GAS > 0) {
$z62916292 = $f62976298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62976298,
"from":L[468]});
}
} catch($e62896290) {
if(R.isCont($e62896290)) {
var $ss62936294 = {"from":L[468],
"go":function(cont_tail_arg18216299) {
return $Hcont_tail_arg23416301(cont_tail_arg18216299,if_helper18006300);
}};
$e62896290.stack[R.EXN_STACKHEIGHT++] = $ss62936294;
}
if(R.isPyretException($e62896290)) {
$e62896290.pyretStack.push(L[468]);
}
throw $e62896290;
}
var $ret62956296 = $Hcont_tail_arg23416301($z62916292,if_helper18006300);
++R.GAS;
return $ret62956296;
} else {
var if_DASH_1776344 = R.equiv(val3526288,("green"));
var anf_if18076348 = R.isBoolean(if_DASH_1776344);
if(R.isPyretTrue(anf_if18076348)) {
if(R.isPyretTrue(if_DASH_1776344)) {
var $z63046305 = D;
var $f63106311 = function(_) {
return R.isFunction(left8074)?left8074.app(green138185.$var):R.ffi.throwNonFunApp(L[469],left8074,[green138185.$var]);
};
try {
if(--R.GAS > 0) {
$z63046305 = $f63106311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63106311,
"from":L[469]});
}
} catch($e63026303) {
if(R.isCont($e63026303)) {
var $ss63066307 = {"from":L[469],
"go":function(cont_tail_arg18196312) {
return $Hcont_tail_arg23426313(cont_tail_arg18196312,if_helper18006300);
}};
$e63026303.stack[R.EXN_STACKHEIGHT++] = $ss63066307;
}
if(R.isPyretException($e63026303)) {
$e63026303.pyretStack.push(L[469]);
}
throw $e63026303;
}
var $ret63086309 = $Hcont_tail_arg23426313($z63046305,if_helper18006300);
++R.GAS;
return $ret63086309;
} else {
var if_DASH_1766339 = R.equiv(val3526288,("blue"));
var anf_if18106343 = R.isBoolean(if_DASH_1766339);
if(R.isPyretTrue(anf_if18106343)) {
if(R.isPyretTrue(if_DASH_1766339)) {
var $z63166317 = D;
var $f63226323 = function(_) {
return R.isFunction(left8074)?left8074.app(blue140189.$var):R.ffi.throwNonFunApp(L[470],left8074,[blue140189.$var]);
};
try {
if(--R.GAS > 0) {
$z63166317 = $f63226323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63226323,
"from":L[470]});
}
} catch($e63146315) {
if(R.isCont($e63146315)) {
var $ss63186319 = {"from":L[470],
"go":function(cont_tail_arg18176324) {
return $Hcont_tail_arg23436325(cont_tail_arg18176324,if_helper18006300);
}};
$e63146315.stack[R.EXN_STACKHEIGHT++] = $ss63186319;
}
if(R.isPyretException($e63146315)) {
$e63146315.pyretStack.push(L[470]);
}
throw $e63146315;
}
var $ret63206321 = $Hcont_tail_arg23436325($z63166317,if_helper18006300);
++R.GAS;
return $ret63206321;
} else {
var anf_fun18116337 = G(list2776,"make",L[472]);
var $z63286329 = D;
var $f63346335 = function(_) {
return R.isFunction(torepr24)?torepr24.app(val3526288):R.ffi.throwNonFunApp(L[471],torepr24,[val3526288]);
};
try {
if(--R.GAS > 0) {
$z63286329 = $f63346335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63346335,
"from":L[471]});
}
} catch($e63266327) {
if(R.isCont($e63266327)) {
var $ss63306331 = {"from":L[471],
"go":function(anf_array_val18126336) {
return $Hanf_array_val23476338(anf_array_val18126336,anf_fun18116337,format7872,if_helper18006300,name3516287,right8177);
}};
$e63266327.stack[R.EXN_STACKHEIGHT++] = $ss63306331;
}
if(R.isPyretException($e63266327)) {
$e63266327.pyretStack.push(L[471]);
}
throw $e63266327;
}
var $ret63326333 = $Hanf_array_val23476338($z63286329,anf_fun18116337,format7872,if_helper18006300,name3516287,right8177);
++R.GAS;
return $ret63326333;
}
} else {
var cont_tail_arg18086342 = R.throwNonBooleanCondition(L[473],("if"),if_DASH_1766339);
if(--R.GAS > 0) {
$z63406341 = R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18086342):R.ffi.throwNonFunApp(L[473],if_helper18006300,[cont_tail_arg18086342]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18086342):R.ffi.throwNonFunApp(L[473],if_helper18006300,[cont_tail_arg18086342]);
},
"from":L[473]});
}
++R.GAS;
return $z63406341;
}
}
} else {
var cont_tail_arg18056347 = R.throwNonBooleanCondition(L[474],("if"),if_DASH_1776344);
if(--R.GAS > 0) {
$z63456346 = R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18056347):R.ffi.throwNonFunApp(L[474],if_helper18006300,[cont_tail_arg18056347]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18056347):R.ffi.throwNonFunApp(L[474],if_helper18006300,[cont_tail_arg18056347]);
},
"from":L[474]});
}
++R.GAS;
return $z63456346;
}
}
} else {
var cont_tail_arg18026352 = R.throwNonBooleanCondition(L[475],("if"),if_DASH_1786349);
if(--R.GAS > 0) {
$z63506351 = R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18026352):R.ffi.throwNonFunApp(L[475],if_helper18006300,[cont_tail_arg18026352]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18026352):R.ffi.throwNonFunApp(L[475],if_helper18006300,[cont_tail_arg18026352]);
},
"from":L[475]});
}
++R.GAS;
return $z63506351;
}
});
var $z62756276 = D;
var $f62816282 = function(_) {
return R.isFunction(read_DASH_custom9599.$var)?read_DASH_custom9599.$var.app(("red|green|blue"),anf_arg18236283):R.ffi.throwNonFunApp(L[466],read_DASH_custom9599.$var,[("red|green|blue"),anf_arg18236283]);
};
try {
if(--R.GAS > 0) {
$z62756276 = $f62816282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62816282,
"from":L[466]});
}
} catch($e62736274) {
if(R.isCont($e62736274)) {
var $ss62776278 = {"from":L[466],
"go":function(custom_DASH_parser3496284) {
return $Hcustom_DASH_parser23856285(custom_DASH_parser3496284,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,red136181,some6478,success100109,builtins15);
}};
$e62736274.stack[R.EXN_STACKHEIGHT++] = $ss62776278;
}
if(R.isPyretException($e62736274)) {
$e62736274.pyretStack.push(L[466]);
}
throw $e62736274;
}
var $ret62796280 = $Hcustom_DASH_parser23856285($z62756276,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,red136181,some6478,success100109,builtins15);
++R.GAS;
return $ret62796280;
};
var $Hcustom_DASH_parser23856285 = function(custom_DASH_parser3496284,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,red136181,some6478,success100109,builtins15) {
var $z63586359 = D;
var $f63646365 = function(_) {
return R.isFunction(some6478)?some6478.app(("c")):R.ffi.throwNonFunApp(L[476],some6478,[("c")]);
};
try {
if(--R.GAS > 0) {
$z63586359 = $f63646365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63646365,
"from":L[476]});
}
} catch($e63566357) {
if(R.isCont($e63566357)) {
var $ss63606361 = {"from":L[476],
"go":function(anf_arg18246366) {
return $Hanf_arg23846367(anf_arg18246366,blue140189,custom_DASH_parser3496284,dict131171,error_DASH_text3331409,green138185,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e63566357.stack[R.EXN_STACKHEIGHT++] = $ss63606361;
}
if(R.isPyretException($e63566357)) {
$e63566357.pyretStack.push(L[476]);
}
throw $e63566357;
}
var $ret63626363 = $Hanf_arg23846367($z63586359,blue140189,custom_DASH_parser3496284,dict131171,error_DASH_text3331409,green138185,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret63626363;
};
var $Hanf_arg23846367 = function(anf_arg18246366,blue140189,custom_DASH_parser3496284,dict131171,error_DASH_text3331409,green138185,list2776,many109127,next_DASH_val_DASH_default126161,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z63706371 = D;
var $f63766377 = function(_) {
return R.isFunction(next_DASH_val_DASH_default126161.$var)?next_DASH_val_DASH_default126161.$var.app(custom_DASH_parser3496284,red136181.$var,anf_arg18246366,many109127.$var,("Color")):R.ffi.throwNonFunApp(L[477],next_DASH_val_DASH_default126161.$var,[custom_DASH_parser3496284,red136181.$var,anf_arg18246366,many109127.$var,("Color")]);
};
try {
if(--R.GAS > 0) {
$z63706371 = $f63766377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63766377,
"from":L[477]});
}
} catch($e63686369) {
if(R.isCont($e63686369)) {
var $ss63726373 = {"from":L[477],
"go":function(anf_obj18256378) {
return $Hanf_obj23836379(anf_obj18256378,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e63686369.stack[R.EXN_STACKHEIGHT++] = $ss63726373;
}
if(R.isPyretException($e63686369)) {
$e63686369.pyretStack.push(L[477]);
}
throw $e63686369;
}
var $ret63746375 = $Hanf_obj23836379($z63706371,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret63746375;
};
var $Hanf_obj23836379 = function(anf_obj18256378,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,parse_DASH_args129167,red136181,success100109,builtins15) {
var many_DASH_next_DASH_colors3536392 = R.makeObject({"color":anf_obj18256378});
var anf_fun18266390 = G(builtins15,"current-checker",L[478]);
var $z63826383 = D;
var $f63886389 = function(_) {
return R.isFunction(anf_fun18266390)?anf_fun18266390.app():R.ffi.throwNonFunApp(L[478],anf_fun18266390,[]);
};
try {
if(--R.GAS > 0) {
$z63826383 = $f63886389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63886389,
"from":L[478]});
}
} catch($e63806381) {
if(R.isCont($e63806381)) {
var $ss63846385 = {"from":L[478],
"go":function(anf_bracket18276391) {
return $Hanf_bracket23826393(anf_bracket18276391,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e63806381.stack[R.EXN_STACKHEIGHT++] = $ss63846385;
}
if(R.isPyretException($e63806381)) {
$e63806381.pyretStack.push(L[478]);
}
throw $e63806381;
}
var $ret63866387 = $Hanf_bracket23826393($z63826383,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret63866387;
};
var $Hanf_bracket23826393 = function(anf_bracket18276391,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18286406 = G(anf_bracket18276391,"check-is",L[478]);
var anf_fun18296404 = G(list2776,"make",L[479]);
var $z63966397 = D;
var $f64026403 = function(_) {
return R.isFunction(anf_fun18296404)?anf_fun18296404.app([("--color"),("red")]):R.ffi.throwNonFunApp(L[479],anf_fun18296404,[[("--color"),("red")]]);
};
try {
if(--R.GAS > 0) {
$z63966397 = $f64026403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64026403,
"from":L[479]});
}
} catch($e63946395) {
if(R.isCont($e63946395)) {
var $ss63986399 = {"from":L[479],
"go":function(anf_arg18306405) {
return $Hanf_arg23816407(anf_arg18306405,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e63946395.stack[R.EXN_STACKHEIGHT++] = $ss63986399;
}
if(R.isPyretException($e63946395)) {
$e63946395.pyretStack.push(L[479]);
}
throw $e63946395;
}
var $ret64006401 = $Hanf_arg23816407($z63966397,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret64006401;
};
var $Hanf_arg23816407 = function(anf_arg18306405,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z64106411 = D;
var $f64166417 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_next_DASH_colors3536392,anf_arg18306405):R.ffi.throwNonFunApp(L[480],parse_DASH_args129167.$var,[many_DASH_next_DASH_colors3536392,anf_arg18306405]);
};
try {
if(--R.GAS > 0) {
$z64106411 = $f64166417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64166417,
"from":L[480]});
}
} catch($e64086409) {
if(R.isCont($e64086409)) {
var $ss64126413 = {"from":L[480],
"go":function(anf_arg18316418) {
return $Hanf_arg23806419(anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e64086409.stack[R.EXN_STACKHEIGHT++] = $ss64126413;
}
if(R.isPyretException($e64086409)) {
$e64086409.pyretStack.push(L[480]);
}
throw $e64086409;
}
var $ret64146415 = $Hanf_arg23806419($z64106411,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret64146415;
};
var $Hanf_arg23806419 = function(anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18326432 = G(list2776,"make",L[482]);
var anf_fun18336430 = G(list2776,"make",L[481]);
var $z64226423 = D;
var $f64286429 = function(_) {
return R.isFunction(anf_fun18336430)?anf_fun18336430.app([red136181.$var]):R.ffi.throwNonFunApp(L[481],anf_fun18336430,[[red136181.$var]]);
};
try {
if(--R.GAS > 0) {
$z64226423 = $f64286429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64286429,
"from":L[481]});
}
} catch($e64206421) {
if(R.isCont($e64206421)) {
var $ss64246425 = {"from":L[481],
"go":function(anf_array_val18346431) {
return $Hanf_array_val23796433(anf_array_val18346431,anf_arg18316418,anf_fun18286406,anf_fun18326432,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e64206421.stack[R.EXN_STACKHEIGHT++] = $ss64246425;
}
if(R.isPyretException($e64206421)) {
$e64206421.pyretStack.push(L[481]);
}
throw $e64206421;
}
var $ret64266427 = $Hanf_array_val23796433($z64226423,anf_arg18316418,anf_fun18286406,anf_fun18326432,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret64266427;
};
var $Hanf_array_val23796433 = function(anf_array_val18346431,anf_arg18316418,anf_fun18286406,anf_fun18326432,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z64366437 = D;
var $f64426443 = function(_) {
return R.isFunction(anf_fun18326432)?anf_fun18326432.app([("color"),anf_array_val18346431]):R.ffi.throwNonFunApp(L[482],anf_fun18326432,[[("color"),anf_array_val18346431]]);
};
try {
if(--R.GAS > 0) {
$z64366437 = $f64426443();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64426443,
"from":L[482]});
}
} catch($e64346435) {
if(R.isCont($e64346435)) {
var $ss64386439 = {"from":L[482],
"go":function(anf_arg18356444) {
return $Hanf_arg23786445(anf_arg18356444,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e64346435.stack[R.EXN_STACKHEIGHT++] = $ss64386439;
}
if(R.isPyretException($e64346435)) {
$e64346435.pyretStack.push(L[482]);
}
throw $e64346435;
}
var $ret64406441 = $Hanf_arg23786445($z64366437,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret64406441;
};
var $Hanf_arg23786445 = function(anf_arg18356444,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z64486449 = D;
var $f64546455 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg18356444):R.ffi.throwNonFunApp(L[483],dict131171.$var,[anf_arg18356444]);
};
try {
if(--R.GAS > 0) {
$z64486449 = $f64546455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64546455,
"from":L[483]});
}
} catch($e64466447) {
if(R.isCont($e64466447)) {
var $ss64506451 = {"from":L[483],
"go":function(anf_arg18366456) {
return $Hanf_arg23776457(anf_arg18366456,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e64466447.stack[R.EXN_STACKHEIGHT++] = $ss64506451;
}
if(R.isPyretException($e64466447)) {
$e64466447.pyretStack.push(L[483]);
}
throw $e64466447;
}
var $ret64526453 = $Hanf_arg23776457($z64486449,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret64526453;
};
var $Hanf_arg23776457 = function(anf_arg18366456,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18376468 = G(list2776,"make",L[484]);
var $z64606461 = D;
var $f64666467 = function(_) {
return R.isFunction(anf_fun18376468)?anf_fun18376468.app([]):R.ffi.throwNonFunApp(L[484],anf_fun18376468,[[]]);
};
try {
if(--R.GAS > 0) {
$z64606461 = $f64666467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64666467,
"from":L[484]});
}
} catch($e64586459) {
if(R.isCont($e64586459)) {
var $ss64626463 = {"from":L[484],
"go":function(anf_arg18386469) {
return $Hanf_arg23766470(anf_arg18386469,anf_arg18316418,anf_arg18366456,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e64586459.stack[R.EXN_STACKHEIGHT++] = $ss64626463;
}
if(R.isPyretException($e64586459)) {
$e64586459.pyretStack.push(L[484]);
}
throw $e64586459;
}
var $ret64646465 = $Hanf_arg23766470($z64606461,anf_arg18316418,anf_arg18366456,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret64646465;
};
var $Hanf_arg23766470 = function(anf_arg18386469,anf_arg18316418,anf_arg18366456,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z64736474 = D;
var $f64796480 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg18366456,anf_arg18386469):R.ffi.throwNonFunApp(L[485],success100109.$var,[anf_arg18366456,anf_arg18386469]);
};
try {
if(--R.GAS > 0) {
$z64736474 = $f64796480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64796480,
"from":L[485]});
}
} catch($e64716472) {
if(R.isCont($e64716472)) {
var $ss64756476 = {"from":L[485],
"go":function(anf_arg18396481) {
return $Hanf_arg23756482(anf_arg18396481,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e64716472.stack[R.EXN_STACKHEIGHT++] = $ss64756476;
}
if(R.isPyretException($e64716472)) {
$e64716472.pyretStack.push(L[485]);
}
throw $e64716472;
}
var $ret64776478 = $Hanf_arg23756482($z64736474,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret64776478;
};
var $Hanf_arg23756482 = function(anf_arg18396481,anf_arg18316418,anf_fun18286406,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_arg18406493 = R.makeSrcloc(L[478]);
var $z64856486 = D;
var $f64916492 = function(_) {
return R.isFunction(anf_fun18286406)?anf_fun18286406.app(("parse-args(many-next-colors, [list: \"--color\", \"red\"]) is\n  success(dict([list: \"color\", [list: red]]), [list: ])"),anf_arg18316418,anf_arg18396481,anf_arg18406493):R.ffi.throwNonFunApp(L[478],anf_fun18286406,[("parse-args(many-next-colors, [list: \"--color\", \"red\"]) is\n  success(dict([list: \"color\", [list: red]]), [list: ])"),anf_arg18316418,anf_arg18396481,anf_arg18406493]);
};
try {
if(--R.GAS > 0) {
$z64856486 = $f64916492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64916492,
"from":L[478]});
}
} catch($e64836484) {
if(R.isCont($e64836484)) {
var $ss64876488 = {"from":L[478],
"go":function(anf_begin_app_dropped23486494) {
return $Hanf_begin_app_dropped23746495(anf_begin_app_dropped23486494,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e64836484.stack[R.EXN_STACKHEIGHT++] = $ss64876488;
}
if(R.isPyretException($e64836484)) {
$e64836484.pyretStack.push(L[478]);
}
throw $e64836484;
}
var $ret64896490 = $Hanf_begin_app_dropped23746495($z64856486,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret64896490;
};
var $Hanf_begin_app_dropped23746495 = function(anf_begin_app_dropped23486494,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18416506 = G(builtins15,"current-checker",L[486]);
var $z64986499 = D;
var $f65046505 = function(_) {
return R.isFunction(anf_fun18416506)?anf_fun18416506.app():R.ffi.throwNonFunApp(L[486],anf_fun18416506,[]);
};
try {
if(--R.GAS > 0) {
$z64986499 = $f65046505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65046505,
"from":L[486]});
}
} catch($e64966497) {
if(R.isCont($e64966497)) {
var $ss65006501 = {"from":L[486],
"go":function(anf_bracket18426507) {
return $Hanf_bracket23736508(anf_bracket18426507,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e64966497.stack[R.EXN_STACKHEIGHT++] = $ss65006501;
}
if(R.isPyretException($e64966497)) {
$e64966497.pyretStack.push(L[486]);
}
throw $e64966497;
}
var $ret65026503 = $Hanf_bracket23736508($z64986499,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret65026503;
};
var $Hanf_bracket23736508 = function(anf_bracket18426507,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18436521 = G(anf_bracket18426507,"check-is",L[486]);
var anf_fun18446519 = G(list2776,"make",L[487]);
var $z65116512 = D;
var $f65176518 = function(_) {
return R.isFunction(anf_fun18446519)?anf_fun18446519.app([("--color"),("red"),("-c"),("--color"),("blue")]):R.ffi.throwNonFunApp(L[487],anf_fun18446519,[[("--color"),("red"),("-c"),("--color"),("blue")]]);
};
try {
if(--R.GAS > 0) {
$z65116512 = $f65176518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65176518,
"from":L[487]});
}
} catch($e65096510) {
if(R.isCont($e65096510)) {
var $ss65136514 = {"from":L[487],
"go":function(anf_arg18456520) {
return $Hanf_arg23726522(anf_arg18456520,anf_fun18436521,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e65096510.stack[R.EXN_STACKHEIGHT++] = $ss65136514;
}
if(R.isPyretException($e65096510)) {
$e65096510.pyretStack.push(L[487]);
}
throw $e65096510;
}
var $ret65156516 = $Hanf_arg23726522($z65116512,anf_fun18436521,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret65156516;
};
var $Hanf_arg23726522 = function(anf_arg18456520,anf_fun18436521,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z65256526 = D;
var $f65316532 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_next_DASH_colors3536392,anf_arg18456520):R.ffi.throwNonFunApp(L[488],parse_DASH_args129167.$var,[many_DASH_next_DASH_colors3536392,anf_arg18456520]);
};
try {
if(--R.GAS > 0) {
$z65256526 = $f65316532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65316532,
"from":L[488]});
}
} catch($e65236524) {
if(R.isCont($e65236524)) {
var $ss65276528 = {"from":L[488],
"go":function(anf_arg18466533) {
return $Hanf_arg23716534(anf_arg18466533,anf_fun18436521,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e65236524.stack[R.EXN_STACKHEIGHT++] = $ss65276528;
}
if(R.isPyretException($e65236524)) {
$e65236524.pyretStack.push(L[488]);
}
throw $e65236524;
}
var $ret65296530 = $Hanf_arg23716534($z65256526,anf_fun18436521,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret65296530;
};
var $Hanf_arg23716534 = function(anf_arg18466533,anf_fun18436521,blue140189,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18476547 = G(list2776,"make",L[490]);
var anf_fun18486545 = G(list2776,"make",L[489]);
var $z65376538 = D;
var $f65436544 = function(_) {
return R.isFunction(anf_fun18486545)?anf_fun18486545.app([red136181.$var,red136181.$var,blue140189.$var]):R.ffi.throwNonFunApp(L[489],anf_fun18486545,[[red136181.$var,red136181.$var,blue140189.$var]]);
};
try {
if(--R.GAS > 0) {
$z65376538 = $f65436544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65436544,
"from":L[489]});
}
} catch($e65356536) {
if(R.isCont($e65356536)) {
var $ss65396540 = {"from":L[489],
"go":function(anf_array_val18496546) {
return $Hanf_array_val23706548(anf_array_val18496546,anf_arg18466533,anf_fun18436521,anf_fun18476547,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e65356536.stack[R.EXN_STACKHEIGHT++] = $ss65396540;
}
if(R.isPyretException($e65356536)) {
$e65356536.pyretStack.push(L[489]);
}
throw $e65356536;
}
var $ret65416542 = $Hanf_array_val23706548($z65376538,anf_arg18466533,anf_fun18436521,anf_fun18476547,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret65416542;
};
var $Hanf_array_val23706548 = function(anf_array_val18496546,anf_arg18466533,anf_fun18436521,anf_fun18476547,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z65516552 = D;
var $f65576558 = function(_) {
return R.isFunction(anf_fun18476547)?anf_fun18476547.app([("color"),anf_array_val18496546]):R.ffi.throwNonFunApp(L[490],anf_fun18476547,[[("color"),anf_array_val18496546]]);
};
try {
if(--R.GAS > 0) {
$z65516552 = $f65576558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65576558,
"from":L[490]});
}
} catch($e65496550) {
if(R.isCont($e65496550)) {
var $ss65536554 = {"from":L[490],
"go":function(anf_arg18506559) {
return $Hanf_arg23696560(anf_arg18506559,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e65496550.stack[R.EXN_STACKHEIGHT++] = $ss65536554;
}
if(R.isPyretException($e65496550)) {
$e65496550.pyretStack.push(L[490]);
}
throw $e65496550;
}
var $ret65556556 = $Hanf_arg23696560($z65516552,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret65556556;
};
var $Hanf_arg23696560 = function(anf_arg18506559,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z65636564 = D;
var $f65696570 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg18506559):R.ffi.throwNonFunApp(L[491],dict131171.$var,[anf_arg18506559]);
};
try {
if(--R.GAS > 0) {
$z65636564 = $f65696570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65696570,
"from":L[491]});
}
} catch($e65616562) {
if(R.isCont($e65616562)) {
var $ss65656566 = {"from":L[491],
"go":function(anf_arg18516571) {
return $Hanf_arg23686572(anf_arg18516571,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e65616562.stack[R.EXN_STACKHEIGHT++] = $ss65656566;
}
if(R.isPyretException($e65616562)) {
$e65616562.pyretStack.push(L[491]);
}
throw $e65616562;
}
var $ret65676568 = $Hanf_arg23686572($z65636564,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret65676568;
};
var $Hanf_arg23686572 = function(anf_arg18516571,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18526583 = G(list2776,"make",L[492]);
var $z65756576 = D;
var $f65816582 = function(_) {
return R.isFunction(anf_fun18526583)?anf_fun18526583.app([]):R.ffi.throwNonFunApp(L[492],anf_fun18526583,[[]]);
};
try {
if(--R.GAS > 0) {
$z65756576 = $f65816582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65816582,
"from":L[492]});
}
} catch($e65736574) {
if(R.isCont($e65736574)) {
var $ss65776578 = {"from":L[492],
"go":function(anf_arg18536584) {
return $Hanf_arg23676585(anf_arg18536584,anf_arg18466533,anf_arg18516571,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e65736574.stack[R.EXN_STACKHEIGHT++] = $ss65776578;
}
if(R.isPyretException($e65736574)) {
$e65736574.pyretStack.push(L[492]);
}
throw $e65736574;
}
var $ret65796580 = $Hanf_arg23676585($z65756576,anf_arg18466533,anf_arg18516571,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret65796580;
};
var $Hanf_arg23676585 = function(anf_arg18536584,anf_arg18466533,anf_arg18516571,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z65886589 = D;
var $f65946595 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg18516571,anf_arg18536584):R.ffi.throwNonFunApp(L[493],success100109.$var,[anf_arg18516571,anf_arg18536584]);
};
try {
if(--R.GAS > 0) {
$z65886589 = $f65946595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65946595,
"from":L[493]});
}
} catch($e65866587) {
if(R.isCont($e65866587)) {
var $ss65906591 = {"from":L[493],
"go":function(anf_arg18546596) {
return $Hanf_arg23666597(anf_arg18546596,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e65866587.stack[R.EXN_STACKHEIGHT++] = $ss65906591;
}
if(R.isPyretException($e65866587)) {
$e65866587.pyretStack.push(L[493]);
}
throw $e65866587;
}
var $ret65926593 = $Hanf_arg23666597($z65886589,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret65926593;
};
var $Hanf_arg23666597 = function(anf_arg18546596,anf_arg18466533,anf_fun18436521,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_arg18556608 = R.makeSrcloc(L[486]);
var $z66006601 = D;
var $f66066607 = function(_) {
return R.isFunction(anf_fun18436521)?anf_fun18436521.app(("parse-args(many-next-colors, [list: \"--color\", \"red\", \"-c\", \"--color\", \"blue\"]) is\n  success(dict([list: \"color\", [list: red, red, blue]]), [list: ])"),anf_arg18466533,anf_arg18546596,anf_arg18556608):R.ffi.throwNonFunApp(L[486],anf_fun18436521,[("parse-args(many-next-colors, [list: \"--color\", \"red\", \"-c\", \"--color\", \"blue\"]) is\n  success(dict([list: \"color\", [list: red, red, blue]]), [list: ])"),anf_arg18466533,anf_arg18546596,anf_arg18556608]);
};
try {
if(--R.GAS > 0) {
$z66006601 = $f66066607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66066607,
"from":L[486]});
}
} catch($e65986599) {
if(R.isCont($e65986599)) {
var $ss66026603 = {"from":L[486],
"go":function(anf_begin_app_dropped23496609) {
return $Hanf_begin_app_dropped23656610(anf_begin_app_dropped23496609,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e65986599.stack[R.EXN_STACKHEIGHT++] = $ss66026603;
}
if(R.isPyretException($e65986599)) {
$e65986599.pyretStack.push(L[486]);
}
throw $e65986599;
}
var $ret66046605 = $Hanf_begin_app_dropped23656610($z66006601,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret66046605;
};
var $Hanf_begin_app_dropped23656610 = function(anf_begin_app_dropped23496609,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18566621 = G(builtins15,"current-checker",L[494]);
var $z66136614 = D;
var $f66196620 = function(_) {
return R.isFunction(anf_fun18566621)?anf_fun18566621.app():R.ffi.throwNonFunApp(L[494],anf_fun18566621,[]);
};
try {
if(--R.GAS > 0) {
$z66136614 = $f66196620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66196620,
"from":L[494]});
}
} catch($e66116612) {
if(R.isCont($e66116612)) {
var $ss66156616 = {"from":L[494],
"go":function(anf_bracket18576622) {
return $Hanf_bracket23646623(anf_bracket18576622,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e66116612.stack[R.EXN_STACKHEIGHT++] = $ss66156616;
}
if(R.isPyretException($e66116612)) {
$e66116612.pyretStack.push(L[494]);
}
throw $e66116612;
}
var $ret66176618 = $Hanf_bracket23646623($z66136614,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret66176618;
};
var $Hanf_bracket23646623 = function(anf_bracket18576622,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18586636 = G(anf_bracket18576622,"check-satisfies",L[494]);
var anf_fun18596634 = G(list2776,"make",L[495]);
var $z66266627 = D;
var $f66326633 = function(_) {
return R.isFunction(anf_fun18596634)?anf_fun18596634.app([("--color"),("bad")]):R.ffi.throwNonFunApp(L[495],anf_fun18596634,[[("--color"),("bad")]]);
};
try {
if(--R.GAS > 0) {
$z66266627 = $f66326633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66326633,
"from":L[495]});
}
} catch($e66246625) {
if(R.isCont($e66246625)) {
var $ss66286629 = {"from":L[495],
"go":function(anf_arg18606635) {
return $Hanf_arg23636637(anf_arg18606635,anf_fun18586636,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e66246625.stack[R.EXN_STACKHEIGHT++] = $ss66286629;
}
if(R.isPyretException($e66246625)) {
$e66246625.pyretStack.push(L[495]);
}
throw $e66246625;
}
var $ret66306631 = $Hanf_arg23636637($z66266627,anf_fun18586636,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret66306631;
};
var $Hanf_arg23636637 = function(anf_arg18606635,anf_fun18586636,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z66406641 = D;
var $f66466647 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_next_DASH_colors3536392,anf_arg18606635):R.ffi.throwNonFunApp(L[496],parse_DASH_args129167.$var,[many_DASH_next_DASH_colors3536392,anf_arg18606635]);
};
try {
if(--R.GAS > 0) {
$z66406641 = $f66466647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66466647,
"from":L[496]});
}
} catch($e66386639) {
if(R.isCont($e66386639)) {
var $ss66426643 = {"from":L[496],
"go":function(anf_arg18616648) {
return $Hanf_arg23626649(anf_arg18616648,anf_fun18586636,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e66386639.stack[R.EXN_STACKHEIGHT++] = $ss66426643;
}
if(R.isPyretException($e66386639)) {
$e66386639.pyretStack.push(L[496]);
}
throw $e66386639;
}
var $ret66446645 = $Hanf_arg23626649($z66406641,anf_fun18586636,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret66446645;
};
var $Hanf_arg23626649 = function(anf_arg18616648,anf_fun18586636,dict131171,error_DASH_text3331409,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var $z66526653 = D;
var $f66586659 = function(_) {
return R.isFunction(error_DASH_text3331409.$var)?error_DASH_text3331409.$var.app(("color expected an RGB argument, got \"bad\"")):R.ffi.throwNonFunApp(L[497],error_DASH_text3331409.$var,[("color expected an RGB argument, got \"bad\"")]);
};
try {
if(--R.GAS > 0) {
$z66526653 = $f66586659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66586659,
"from":L[497]});
}
} catch($e66506651) {
if(R.isCont($e66506651)) {
var $ss66546655 = {"from":L[497],
"go":function(anf_arg18626660) {
return $Hanf_arg23616661(anf_arg18626660,anf_arg18616648,anf_fun18586636,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e66506651.stack[R.EXN_STACKHEIGHT++] = $ss66546655;
}
if(R.isPyretException($e66506651)) {
$e66506651.pyretStack.push(L[497]);
}
throw $e66506651;
}
var $ret66566657 = $Hanf_arg23616661($z66526653,anf_arg18616648,anf_fun18586636,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret66566657;
};
var $Hanf_arg23616661 = function(anf_arg18626660,anf_arg18616648,anf_fun18586636,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_arg18636672 = R.makeSrcloc(L[494]);
var $z66646665 = D;
var $f66706671 = function(_) {
return R.isFunction(anf_fun18586636)?anf_fun18586636.app(("parse-args(many-next-colors, [list: \"--color\", \"bad\"]) satisfies\n  error-text(\"color expected an RGB argument, got \\\"bad\\\"\")"),anf_arg18616648,anf_arg18626660,anf_arg18636672):R.ffi.throwNonFunApp(L[494],anf_fun18586636,[("parse-args(many-next-colors, [list: \"--color\", \"bad\"]) satisfies\n  error-text(\"color expected an RGB argument, got \\\"bad\\\"\")"),anf_arg18616648,anf_arg18626660,anf_arg18636672]);
};
try {
if(--R.GAS > 0) {
$z66646665 = $f66706671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66706671,
"from":L[494]});
}
} catch($e66626663) {
if(R.isCont($e66626663)) {
var $ss66666667 = {"from":L[494],
"go":function(anf_begin_app_dropped23506673) {
return $Hanf_begin_app_dropped23606674(anf_begin_app_dropped23506673,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
}};
$e66626663.stack[R.EXN_STACKHEIGHT++] = $ss66666667;
}
if(R.isPyretException($e66626663)) {
$e66626663.pyretStack.push(L[494]);
}
throw $e66626663;
}
var $ret66686669 = $Hanf_begin_app_dropped23606674($z66646665,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15);
++R.GAS;
return $ret66686669;
};
var $Hanf_begin_app_dropped23606674 = function(anf_begin_app_dropped23506673,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109,builtins15) {
var anf_fun18646685 = G(builtins15,"current-checker",L[498]);
var $z66776678 = D;
var $f66836684 = function(_) {
return R.isFunction(anf_fun18646685)?anf_fun18646685.app():R.ffi.throwNonFunApp(L[498],anf_fun18646685,[]);
};
try {
if(--R.GAS > 0) {
$z66776678 = $f66836684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66836684,
"from":L[498]});
}
} catch($e66756676) {
if(R.isCont($e66756676)) {
var $ss66796680 = {"from":L[498],
"go":function(anf_bracket18656686) {
return $Hanf_bracket23596687(anf_bracket18656686,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109);
}};
$e66756676.stack[R.EXN_STACKHEIGHT++] = $ss66796680;
}
if(R.isPyretException($e66756676)) {
$e66756676.pyretStack.push(L[498]);
}
throw $e66756676;
}
var $ret66816682 = $Hanf_bracket23596687($z66776678,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109);
++R.GAS;
return $ret66816682;
};
var $Hanf_bracket23596687 = function(anf_bracket18656686,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109) {
var anf_fun18666700 = G(anf_bracket18656686,"check-is",L[498]);
var anf_fun18676698 = G(list2776,"make",L[499]);
var $z66906691 = D;
var $f66966697 = function(_) {
return R.isFunction(anf_fun18676698)?anf_fun18676698.app([("--color"),("green"),("--color"),("-c"),("blue")]):R.ffi.throwNonFunApp(L[499],anf_fun18676698,[[("--color"),("green"),("--color"),("-c"),("blue")]]);
};
try {
if(--R.GAS > 0) {
$z66906691 = $f66966697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66966697,
"from":L[499]});
}
} catch($e66886689) {
if(R.isCont($e66886689)) {
var $ss66926693 = {"from":L[499],
"go":function(anf_arg18686699) {
return $Hanf_arg23586701(anf_arg18686699,anf_fun18666700,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109);
}};
$e66886689.stack[R.EXN_STACKHEIGHT++] = $ss66926693;
}
if(R.isPyretException($e66886689)) {
$e66886689.pyretStack.push(L[499]);
}
throw $e66886689;
}
var $ret66946695 = $Hanf_arg23586701($z66906691,anf_fun18666700,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109);
++R.GAS;
return $ret66946695;
};
var $Hanf_arg23586701 = function(anf_arg18686699,anf_fun18666700,dict131171,green138185,list2776,many_DASH_next_DASH_colors3536392,parse_DASH_args129167,red136181,success100109) {
var $z67046705 = D;
var $f67106711 = function(_) {
return R.isFunction(parse_DASH_args129167.$var)?parse_DASH_args129167.$var.app(many_DASH_next_DASH_colors3536392,anf_arg18686699):R.ffi.throwNonFunApp(L[500],parse_DASH_args129167.$var,[many_DASH_next_DASH_colors3536392,anf_arg18686699]);
};
try {
if(--R.GAS > 0) {
$z67046705 = $f67106711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67106711,
"from":L[500]});
}
} catch($e67026703) {
if(R.isCont($e67026703)) {
var $ss67066707 = {"from":L[500],
"go":function(anf_arg18696712) {
return $Hanf_arg23576713(anf_arg18696712,anf_fun18666700,dict131171,green138185,list2776,red136181,success100109);
}};
$e67026703.stack[R.EXN_STACKHEIGHT++] = $ss67066707;
}
if(R.isPyretException($e67026703)) {
$e67026703.pyretStack.push(L[500]);
}
throw $e67026703;
}
var $ret67086709 = $Hanf_arg23576713($z67046705,anf_fun18666700,dict131171,green138185,list2776,red136181,success100109);
++R.GAS;
return $ret67086709;
};
var $Hanf_arg23576713 = function(anf_arg18696712,anf_fun18666700,dict131171,green138185,list2776,red136181,success100109) {
var anf_fun18706726 = G(list2776,"make",L[502]);
var anf_fun18716724 = G(list2776,"make",L[501]);
var $z67166717 = D;
var $f67226723 = function(_) {
return R.isFunction(anf_fun18716724)?anf_fun18716724.app([green138185.$var,red136181.$var,red136181.$var]):R.ffi.throwNonFunApp(L[501],anf_fun18716724,[[green138185.$var,red136181.$var,red136181.$var]]);
};
try {
if(--R.GAS > 0) {
$z67166717 = $f67226723();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67226723,
"from":L[501]});
}
} catch($e67146715) {
if(R.isCont($e67146715)) {
var $ss67186719 = {"from":L[501],
"go":function(anf_array_val18726725) {
return $Hanf_array_val23566727(anf_array_val18726725,anf_arg18696712,anf_fun18666700,anf_fun18706726,dict131171,list2776,success100109);
}};
$e67146715.stack[R.EXN_STACKHEIGHT++] = $ss67186719;
}
if(R.isPyretException($e67146715)) {
$e67146715.pyretStack.push(L[501]);
}
throw $e67146715;
}
var $ret67206721 = $Hanf_array_val23566727($z67166717,anf_arg18696712,anf_fun18666700,anf_fun18706726,dict131171,list2776,success100109);
++R.GAS;
return $ret67206721;
};
var $Hanf_array_val23566727 = function(anf_array_val18726725,anf_arg18696712,anf_fun18666700,anf_fun18706726,dict131171,list2776,success100109) {
var $z67306731 = D;
var $f67366737 = function(_) {
return R.isFunction(anf_fun18706726)?anf_fun18706726.app([("color"),anf_array_val18726725]):R.ffi.throwNonFunApp(L[502],anf_fun18706726,[[("color"),anf_array_val18726725]]);
};
try {
if(--R.GAS > 0) {
$z67306731 = $f67366737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67366737,
"from":L[502]});
}
} catch($e67286729) {
if(R.isCont($e67286729)) {
var $ss67326733 = {"from":L[502],
"go":function(anf_arg18736738) {
return $Hanf_arg23556739(anf_arg18736738,anf_arg18696712,anf_fun18666700,dict131171,list2776,success100109);
}};
$e67286729.stack[R.EXN_STACKHEIGHT++] = $ss67326733;
}
if(R.isPyretException($e67286729)) {
$e67286729.pyretStack.push(L[502]);
}
throw $e67286729;
}
var $ret67346735 = $Hanf_arg23556739($z67306731,anf_arg18696712,anf_fun18666700,dict131171,list2776,success100109);
++R.GAS;
return $ret67346735;
};
var $Hanf_arg23556739 = function(anf_arg18736738,anf_arg18696712,anf_fun18666700,dict131171,list2776,success100109) {
var $z67426743 = D;
var $f67486749 = function(_) {
return R.isFunction(dict131171.$var)?dict131171.$var.app(anf_arg18736738):R.ffi.throwNonFunApp(L[503],dict131171.$var,[anf_arg18736738]);
};
try {
if(--R.GAS > 0) {
$z67426743 = $f67486749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67486749,
"from":L[503]});
}
} catch($e67406741) {
if(R.isCont($e67406741)) {
var $ss67446745 = {"from":L[503],
"go":function(anf_arg18746750) {
return $Hanf_arg23546751(anf_arg18746750,anf_arg18696712,anf_fun18666700,list2776,success100109);
}};
$e67406741.stack[R.EXN_STACKHEIGHT++] = $ss67446745;
}
if(R.isPyretException($e67406741)) {
$e67406741.pyretStack.push(L[503]);
}
throw $e67406741;
}
var $ret67466747 = $Hanf_arg23546751($z67426743,anf_arg18696712,anf_fun18666700,list2776,success100109);
++R.GAS;
return $ret67466747;
};
var $Hanf_arg23546751 = function(anf_arg18746750,anf_arg18696712,anf_fun18666700,list2776,success100109) {
var anf_fun18756762 = G(list2776,"make",L[504]);
var $z67546755 = D;
var $f67606761 = function(_) {
return R.isFunction(anf_fun18756762)?anf_fun18756762.app([("blue")]):R.ffi.throwNonFunApp(L[504],anf_fun18756762,[[("blue")]]);
};
try {
if(--R.GAS > 0) {
$z67546755 = $f67606761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67606761,
"from":L[504]});
}
} catch($e67526753) {
if(R.isCont($e67526753)) {
var $ss67566757 = {"from":L[504],
"go":function(anf_arg18766763) {
return $Hanf_arg23536764(anf_arg18766763,anf_arg18696712,anf_arg18746750,anf_fun18666700,success100109);
}};
$e67526753.stack[R.EXN_STACKHEIGHT++] = $ss67566757;
}
if(R.isPyretException($e67526753)) {
$e67526753.pyretStack.push(L[504]);
}
throw $e67526753;
}
var $ret67586759 = $Hanf_arg23536764($z67546755,anf_arg18696712,anf_arg18746750,anf_fun18666700,success100109);
++R.GAS;
return $ret67586759;
};
var $Hanf_arg23536764 = function(anf_arg18766763,anf_arg18696712,anf_arg18746750,anf_fun18666700,success100109) {
var $z67676768 = D;
var $f67736774 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg18746750,anf_arg18766763):R.ffi.throwNonFunApp(L[505],success100109.$var,[anf_arg18746750,anf_arg18766763]);
};
try {
if(--R.GAS > 0) {
$z67676768 = $f67736774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67736774,
"from":L[505]});
}
} catch($e67656766) {
if(R.isCont($e67656766)) {
var $ss67696770 = {"from":L[505],
"go":function(anf_arg18776775) {
return $Hanf_arg23526776(anf_arg18776775,anf_arg18696712,anf_fun18666700);
}};
$e67656766.stack[R.EXN_STACKHEIGHT++] = $ss67696770;
}
if(R.isPyretException($e67656766)) {
$e67656766.pyretStack.push(L[505]);
}
throw $e67656766;
}
var $ret67716772 = $Hanf_arg23526776($z67676768,anf_arg18696712,anf_fun18666700);
++R.GAS;
return $ret67716772;
};
var $Hanf_arg23526776 = function(anf_arg18776775,anf_arg18696712,anf_fun18666700) {
var anf_arg18786787 = R.makeSrcloc(L[498]);
var $z67796780 = D;
var $f67856786 = function(_) {
return R.isFunction(anf_fun18666700)?anf_fun18666700.app(("parse-args(many-next-colors,\n  [list: \"--color\", \"green\", \"--color\", \"-c\", \"blue\"]) is\n  success(dict([list: \"color\", [list: green, red, red]]), [list: \"blue\"])"),anf_arg18696712,anf_arg18776775,anf_arg18786787):R.ffi.throwNonFunApp(L[132],anf_fun18666700,[("parse-args(many-next-colors,\n  [list: \"--color\", \"green\", \"--color\", \"-c\", \"blue\"]) is\n  success(dict([list: \"color\", [list: green, red, red]]), [list: \"blue\"])"),anf_arg18696712,anf_arg18776775,anf_arg18786787]);
};
try {
if(--R.GAS > 0) {
$z67796780 = $f67856786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67856786,
"from":L[132]});
}
} catch($e67776778) {
if(R.isCont($e67776778)) {
var $ss67816782 = {"from":L[132],
"go":function(ann_DASH_check_DASH_temp11866788) {
return $Hann_DASH_check_DASH_temp23516789(ann_DASH_check_DASH_temp11866788);
}};
$e67776778.stack[R.EXN_STACKHEIGHT++] = $ss67816782;
}
if(R.isPyretException($e67776778)) {
$e67776778.pyretStack.push(L[132]);
}
throw $e67776778;
}
var $ret67836784 = $Hann_DASH_check_DASH_temp23516789($z67796780);
++R.GAS;
return $ret67836784;
};
var $Hann_DASH_check_DASH_temp23516789 = function(ann_DASH_check_DASH_temp11866788) {
return ann_DASH_check_DASH_temp11866788;
};
var $Hcont_tail_arg23416301 = function(cont_tail_arg18216299,if_helper18006300) {
if(--R.GAS > 0) {
$z67906791 = R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18216299):R.ffi.throwNonFunApp(L[468],if_helper18006300,[cont_tail_arg18216299]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18216299):R.ffi.throwNonFunApp(L[468],if_helper18006300,[cont_tail_arg18216299]);
},
"from":L[468]});
}
++R.GAS;
return $z67906791;
};
var $Hcont_tail_arg23426313 = function(cont_tail_arg18196312,if_helper18006300) {
if(--R.GAS > 0) {
$z67926793 = R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18196312):R.ffi.throwNonFunApp(L[469],if_helper18006300,[cont_tail_arg18196312]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18196312):R.ffi.throwNonFunApp(L[469],if_helper18006300,[cont_tail_arg18196312]);
},
"from":L[469]});
}
++R.GAS;
return $z67926793;
};
var $Hcont_tail_arg23436325 = function(cont_tail_arg18176324,if_helper18006300) {
if(--R.GAS > 0) {
$z67946795 = R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18176324):R.ffi.throwNonFunApp(L[470],if_helper18006300,[cont_tail_arg18176324]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18176324):R.ffi.throwNonFunApp(L[470],if_helper18006300,[cont_tail_arg18176324]);
},
"from":L[470]});
}
++R.GAS;
return $z67946795;
};
var $Hanf_array_val23476338 = function(anf_array_val18126336,anf_fun18116337,format7872,if_helper18006300,name3516287,right8177) {
var $z67986799 = D;
var $f68046805 = function(_) {
return R.isFunction(anf_fun18116337)?anf_fun18116337.app([name3516287,anf_array_val18126336]):R.ffi.throwNonFunApp(L[472],anf_fun18116337,[[name3516287,anf_array_val18126336]]);
};
try {
if(--R.GAS > 0) {
$z67986799 = $f68046805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68046805,
"from":L[472]});
}
} catch($e67966797) {
if(R.isCont($e67966797)) {
var $ss68006801 = {"from":L[472],
"go":function(anf_arg18136806) {
return $Hanf_arg23466807(anf_arg18136806,format7872,if_helper18006300,right8177);
}};
$e67966797.stack[R.EXN_STACKHEIGHT++] = $ss68006801;
}
if(R.isPyretException($e67966797)) {
$e67966797.pyretStack.push(L[472]);
}
throw $e67966797;
}
var $ret68026803 = $Hanf_arg23466807($z67986799,format7872,if_helper18006300,right8177);
++R.GAS;
return $ret68026803;
};
var $Hanf_arg23466807 = function(anf_arg18136806,format7872,if_helper18006300,right8177) {
var $z68106811 = D;
var $f68166817 = function(_) {
return R.isFunction(format7872)?format7872.app(("~a expected an RGB argument, got ~a"),anf_arg18136806):R.ffi.throwNonFunApp(L[506],format7872,[("~a expected an RGB argument, got ~a"),anf_arg18136806]);
};
try {
if(--R.GAS > 0) {
$z68106811 = $f68166817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68166817,
"from":L[506]});
}
} catch($e68086809) {
if(R.isCont($e68086809)) {
var $ss68126813 = {"from":L[506],
"go":function(anf_arg18146818) {
return $Hanf_arg23456819(anf_arg18146818,if_helper18006300,right8177);
}};
$e68086809.stack[R.EXN_STACKHEIGHT++] = $ss68126813;
}
if(R.isPyretException($e68086809)) {
$e68086809.pyretStack.push(L[506]);
}
throw $e68086809;
}
var $ret68146815 = $Hanf_arg23456819($z68106811,if_helper18006300,right8177);
++R.GAS;
return $ret68146815;
};
var $Hanf_arg23456819 = function(anf_arg18146818,if_helper18006300,right8177) {
var $z68226823 = D;
var $f68286829 = function(_) {
return R.isFunction(right8177)?right8177.app(anf_arg18146818):R.ffi.throwNonFunApp(L[507],right8177,[anf_arg18146818]);
};
try {
if(--R.GAS > 0) {
$z68226823 = $f68286829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68286829,
"from":L[507]});
}
} catch($e68206821) {
if(R.isCont($e68206821)) {
var $ss68246825 = {"from":L[507],
"go":function(cont_tail_arg18156830) {
return $Hcont_tail_arg23446831(cont_tail_arg18156830,if_helper18006300);
}};
$e68206821.stack[R.EXN_STACKHEIGHT++] = $ss68246825;
}
if(R.isPyretException($e68206821)) {
$e68206821.pyretStack.push(L[507]);
}
throw $e68206821;
}
var $ret68266827 = $Hcont_tail_arg23446831($z68226823,if_helper18006300);
++R.GAS;
return $ret68266827;
};
var $Hcont_tail_arg23446831 = function(cont_tail_arg18156830,if_helper18006300) {
if(--R.GAS > 0) {
$z68326833 = R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18156830):R.ffi.throwNonFunApp(L[507],if_helper18006300,[cont_tail_arg18156830]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper18006300)?if_helper18006300.app(cont_tail_arg18156830):R.ffi.throwNonFunApp(L[507],if_helper18006300,[cont_tail_arg18156830]);
},
"from":L[507]});
}
++R.GAS;
return $z68326833;
};
var $Hann_DASH_check_DASH_temp22911440 = function(ann_DASH_check_DASH_temp11881439) {
return ann_DASH_check_DASH_temp11881439;
};
var $Hann_DASH_check_DASH_temp22901458 = function(ann_DASH_check_DASH_temp11921457) {
return ann_DASH_check_DASH_temp11921457;
};
var $Hcont_tail_arg2288243 = function(cont_tail_arg1168241,if_helper1161242) {
if(--R.GAS > 0) {
$z68346835 = R.isFunction(if_helper1161242)?if_helper1161242.app(cont_tail_arg1168241):R.ffi.throwNonFunApp(L[1],if_helper1161242,[cont_tail_arg1168241]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1161242)?if_helper1161242.app(cont_tail_arg1168241):R.ffi.throwNonFunApp(L[1],if_helper1161242,[cont_tail_arg1168241]);
},
"from":L[1]});
}
++R.GAS;
return $z68346835;
};
var $Hcont_tail_arg2289257 = function(cont_tail_arg1166256,if_helper1161242) {
if(--R.GAS > 0) {
$z68366837 = R.isFunction(if_helper1161242)?if_helper1161242.app(cont_tail_arg1166256):R.ffi.throwNonFunApp(L[1],if_helper1161242,[cont_tail_arg1166256]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1161242)?if_helper1161242.app(cont_tail_arg1166256):R.ffi.throwNonFunApp(L[1],if_helper1161242,[cont_tail_arg1166256]);
},
"from":L[1]});
}
++R.GAS;
return $z68366837;
};
var $Hcont_tail_arg2286282 = function(cont_tail_arg1155280,if_helper1148281) {
if(--R.GAS > 0) {
$z68386839 = R.isFunction(if_helper1148281)?if_helper1148281.app(cont_tail_arg1155280):R.ffi.throwNonFunApp(L[2],if_helper1148281,[cont_tail_arg1155280]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1148281)?if_helper1148281.app(cont_tail_arg1155280):R.ffi.throwNonFunApp(L[2],if_helper1148281,[cont_tail_arg1155280]);
},
"from":L[2]});
}
++R.GAS;
return $z68386839;
};
var $Hcont_tail_arg2287296 = function(cont_tail_arg1153295,if_helper1148281) {
if(--R.GAS > 0) {
$z68406841 = R.isFunction(if_helper1148281)?if_helper1148281.app(cont_tail_arg1153295):R.ffi.throwNonFunApp(L[2],if_helper1148281,[cont_tail_arg1153295]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1148281)?if_helper1148281.app(cont_tail_arg1153295):R.ffi.throwNonFunApp(L[2],if_helper1148281,[cont_tail_arg1153295]);
},
"from":L[2]});
}
++R.GAS;
return $z68406841;
};
var $Hcont_tail_arg2284320 = function(cont_tail_arg1142318,if_helper1135319) {
if(--R.GAS > 0) {
$z68426843 = R.isFunction(if_helper1135319)?if_helper1135319.app(cont_tail_arg1142318):R.ffi.throwNonFunApp(L[3],if_helper1135319,[cont_tail_arg1142318]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1135319)?if_helper1135319.app(cont_tail_arg1142318):R.ffi.throwNonFunApp(L[3],if_helper1135319,[cont_tail_arg1142318]);
},
"from":L[3]});
}
++R.GAS;
return $z68426843;
};
var $Hcont_tail_arg2285334 = function(cont_tail_arg1140333,if_helper1135319) {
if(--R.GAS > 0) {
$z68446845 = R.isFunction(if_helper1135319)?if_helper1135319.app(cont_tail_arg1140333):R.ffi.throwNonFunApp(L[3],if_helper1135319,[cont_tail_arg1140333]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1135319)?if_helper1135319.app(cont_tail_arg1140333):R.ffi.throwNonFunApp(L[3],if_helper1135319,[cont_tail_arg1140333]);
},
"from":L[3]});
}
++R.GAS;
return $z68446845;
};
var $Hanf_arg2283357 = function(anf_arg1127355,anf_arg1125356,fold5571,l329343,lists1134,_divide12) {
var anf_fun11286858 = G(lists1134,"range",L[510]);
var anf_fun11296856 = G(l329343,"length",L[509]);
var $z68486849 = D;
var $f68546855 = function(_) {
return R.isFunction(anf_fun11296856)?anf_fun11296856.app():R.ffi.throwNonFunApp(L[508],anf_fun11296856,[]);
};
try {
if(--R.GAS > 0) {
$z68486849 = $f68546855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68546855,
"from":L[508]});
}
} catch($e68466847) {
if(R.isCont($e68466847)) {
var $ss68506851 = {"from":L[508],
"go":function(anf_arg11306857) {
return $Hanf_arg22826859(anf_arg11306857,anf_arg1125356,anf_arg1127355,anf_fun11286858,fold5571,_divide12);
}};
$e68466847.stack[R.EXN_STACKHEIGHT++] = $ss68506851;
}
if(R.isPyretException($e68466847)) {
$e68466847.pyretStack.push(L[508]);
}
throw $e68466847;
}
var $ret68526853 = $Hanf_arg22826859($z68486849,anf_arg1125356,anf_arg1127355,anf_fun11286858,fold5571,_divide12);
++R.GAS;
return $ret68526853;
};
var $Hanf_arg22826859 = function(anf_arg11306857,anf_arg1125356,anf_arg1127355,anf_fun11286858,fold5571,_divide12) {
var $z68626863 = D;
var $f68686869 = function(_) {
return R.isFunction(_divide12)?_divide12.app(anf_arg11306857,(2)):R.ffi.throwNonFunApp(L[511],_divide12,[anf_arg11306857,(2)]);
};
try {
if(--R.GAS > 0) {
$z68626863 = $f68686869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68686869,
"from":L[511]});
}
} catch($e68606861) {
if(R.isCont($e68606861)) {
var $ss68646865 = {"from":L[511],
"go":function(anf_arg11316870) {
return $Hanf_arg22816871(anf_arg11316870,anf_arg1125356,anf_arg1127355,anf_fun11286858,fold5571);
}};
$e68606861.stack[R.EXN_STACKHEIGHT++] = $ss68646865;
}
if(R.isPyretException($e68606861)) {
$e68606861.pyretStack.push(L[511]);
}
throw $e68606861;
}
var $ret68666867 = $Hanf_arg22816871($z68626863,anf_arg1125356,anf_arg1127355,anf_fun11286858,fold5571);
++R.GAS;
return $ret68666867;
};
var $Hanf_arg22816871 = function(anf_arg11316870,anf_arg1125356,anf_arg1127355,anf_fun11286858,fold5571) {
var $z68746875 = D;
var $f68806881 = function(_) {
return R.isFunction(anf_fun11286858)?anf_fun11286858.app((0),anf_arg11316870):R.ffi.throwNonFunApp(L[512],anf_fun11286858,[(0),anf_arg11316870]);
};
try {
if(--R.GAS > 0) {
$z68746875 = $f68806881();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68806881,
"from":L[512]});
}
} catch($e68726873) {
if(R.isCont($e68726873)) {
var $ss68766877 = {"from":L[512],
"go":function(anf_arg11326882) {
return $Hanf_arg22806883(anf_arg11326882,anf_arg1125356,anf_arg1127355,fold5571);
}};
$e68726873.stack[R.EXN_STACKHEIGHT++] = $ss68766877;
}
if(R.isPyretException($e68726873)) {
$e68726873.pyretStack.push(L[512]);
}
throw $e68726873;
}
var $ret68786879 = $Hanf_arg22806883($z68746875,anf_arg1125356,anf_arg1127355,fold5571);
++R.GAS;
return $ret68786879;
};
var $Hanf_arg22806883 = function(anf_arg11326882,anf_arg1125356,anf_arg1127355,fold5571) {
var $z68866887 = D;
var $f68926893 = function(_) {
return R.isFunction(fold5571)?fold5571.app(anf_arg1125356,anf_arg1127355,anf_arg11326882):R.ffi.throwNonFunApp(L[5],fold5571,[anf_arg1125356,anf_arg1127355,anf_arg11326882]);
};
try {
if(--R.GAS > 0) {
$z68866887 = $f68926893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68926893,
"from":L[5]});
}
} catch($e68846885) {
if(R.isCont($e68846885)) {
var $ss68886889 = {"from":L[5],
"go":function(ann_DASH_check_DASH_temp11156894) {
return $Hann_DASH_check_DASH_temp22796895(ann_DASH_check_DASH_temp11156894);
}};
$e68846885.stack[R.EXN_STACKHEIGHT++] = $ss68886889;
}
if(R.isPyretException($e68846885)) {
$e68846885.pyretStack.push(L[5]);
}
throw $e68846885;
}
var $ret68906891 = $Hann_DASH_check_DASH_temp22796895($z68866887);
++R.GAS;
return $ret68906891;
};
var $Hann_DASH_check_DASH_temp22796895 = function(ann_DASH_check_DASH_temp11156894) {
return ann_DASH_check_DASH_temp11156894;
};
var $Hanf_arg2278373 = function(anf_arg1119370,anf_fun1117371,anf_fun1118372,i331359,l329343,_plus13,_times14) {
var $z68986899 = D;
var $f69046905 = function(_) {
return R.isFunction(anf_fun1118372)?anf_fun1118372.app(anf_arg1119370):R.ffi.throwNonFunApp(L[513],anf_fun1118372,[anf_arg1119370]);
};
try {
if(--R.GAS > 0) {
$z68986899 = $f69046905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69046905,
"from":L[513]});
}
} catch($e68966897) {
if(R.isCont($e68966897)) {
var $ss69006901 = {"from":L[513],
"go":function(anf_arg11206906) {
return $Hanf_arg22776907(anf_arg11206906,anf_fun1117371,i331359,l329343,_plus13,_times14);
}};
$e68966897.stack[R.EXN_STACKHEIGHT++] = $ss69006901;
}
if(R.isPyretException($e68966897)) {
$e68966897.pyretStack.push(L[513]);
}
throw $e68966897;
}
var $ret69026903 = $Hanf_arg22776907($z68986899,anf_fun1117371,i331359,l329343,_plus13,_times14);
++R.GAS;
return $ret69026903;
};
var $Hanf_arg22776907 = function(anf_arg11206906,anf_fun1117371,i331359,l329343,_plus13,_times14) {
var anf_fun11216919 = G(l329343,"get",L[515]);
var $z69106911 = D;
var $f69166917 = function(_) {
return R.isFunction(_times14)?_times14.app((2),i331359):R.ffi.throwNonFunApp(L[514],_times14,[(2),i331359]);
};
try {
if(--R.GAS > 0) {
$z69106911 = $f69166917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69166917,
"from":L[514]});
}
} catch($e69086909) {
if(R.isCont($e69086909)) {
var $ss69126913 = {"from":L[514],
"go":function(anf_arg11226918) {
return $Hanf_arg22766920(anf_arg11226918,anf_arg11206906,anf_fun1117371,anf_fun11216919,_plus13);
}};
$e69086909.stack[R.EXN_STACKHEIGHT++] = $ss69126913;
}
if(R.isPyretException($e69086909)) {
$e69086909.pyretStack.push(L[514]);
}
throw $e69086909;
}
var $ret69146915 = $Hanf_arg22766920($z69106911,anf_arg11206906,anf_fun1117371,anf_fun11216919,_plus13);
++R.GAS;
return $ret69146915;
};
var $Hanf_arg22766920 = function(anf_arg11226918,anf_arg11206906,anf_fun1117371,anf_fun11216919,_plus13) {
var $z69236924 = D;
var $f69296930 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg11226918,(1)):R.ffi.throwNonFunApp(L[516],_plus13,[anf_arg11226918,(1)]);
};
try {
if(--R.GAS > 0) {
$z69236924 = $f69296930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69296930,
"from":L[516]});
}
} catch($e69216922) {
if(R.isCont($e69216922)) {
var $ss69256926 = {"from":L[516],
"go":function(anf_arg11236931) {
return $Hanf_arg22756932(anf_arg11236931,anf_arg11206906,anf_fun1117371,anf_fun11216919);
}};
$e69216922.stack[R.EXN_STACKHEIGHT++] = $ss69256926;
}
if(R.isPyretException($e69216922)) {
$e69216922.pyretStack.push(L[516]);
}
throw $e69216922;
}
var $ret69276928 = $Hanf_arg22756932($z69236924,anf_arg11206906,anf_fun1117371,anf_fun11216919);
++R.GAS;
return $ret69276928;
};
var $Hanf_arg22756932 = function(anf_arg11236931,anf_arg11206906,anf_fun1117371,anf_fun11216919) {
var $z69356936 = D;
var $f69416942 = function(_) {
return R.isFunction(anf_fun11216919)?anf_fun11216919.app(anf_arg11236931):R.ffi.throwNonFunApp(L[517],anf_fun11216919,[anf_arg11236931]);
};
try {
if(--R.GAS > 0) {
$z69356936 = $f69416942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69416942,
"from":L[517]});
}
} catch($e69336934) {
if(R.isCont($e69336934)) {
var $ss69376938 = {"from":L[517],
"go":function(anf_arg11246943) {
return $Hanf_arg22746944(anf_arg11246943,anf_arg11206906,anf_fun1117371);
}};
$e69336934.stack[R.EXN_STACKHEIGHT++] = $ss69376938;
}
if(R.isPyretException($e69336934)) {
$e69336934.pyretStack.push(L[517]);
}
throw $e69336934;
}
var $ret69396940 = $Hanf_arg22746944($z69356936,anf_arg11206906,anf_fun1117371);
++R.GAS;
return $ret69396940;
};
var $Hanf_arg22746944 = function(anf_arg11246943,anf_arg11206906,anf_fun1117371) {
var $z69476948 = D;
var $f69536954 = function(_) {
return R.isFunction(anf_fun1117371)?anf_fun1117371.app(anf_arg11206906,anf_arg11246943):R.ffi.throwNonFunApp(L[8],anf_fun1117371,[anf_arg11206906,anf_arg11246943]);
};
try {
if(--R.GAS > 0) {
$z69476948 = $f69536954();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69536954,
"from":L[8]});
}
} catch($e69456946) {
if(R.isCont($e69456946)) {
var $ss69496950 = {"from":L[8],
"go":function(ann_DASH_check_DASH_temp11166955) {
return $Hann_DASH_check_DASH_temp22736956(ann_DASH_check_DASH_temp11166955);
}};
$e69456946.stack[R.EXN_STACKHEIGHT++] = $ss69496950;
}
if(R.isPyretException($e69456946)) {
$e69456946.pyretStack.push(L[8]);
}
throw $e69456946;
}
var $ret69516952 = $Hann_DASH_check_DASH_temp22736956($z69476948);
++R.GAS;
return $ret69516952;
};
var $Hann_DASH_check_DASH_temp22736956 = function(ann_DASH_check_DASH_temp11166955) {
return ann_DASH_check_DASH_temp11166955;
};
var $Hann_DASH_check_DASH_temp2272386 = function(ann_DASH_check_DASH_temp1113385) {
return ann_DASH_check_DASH_temp1113385;
};
var $Hopts_DASH_dict2271401 = function(opts_DASH_dict217400,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var anf_fun5146970 = G(lists1134,"fold",L[522]);
var anf_arg5916969 = R.makeFunction(function(acc2196972,key2206973) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[520],2,arguments);
}
var $z69766977 = D;
var $f69826983 = function(_) {
return R.isFunction(is_DASH_arg_DASH_error101111.$var)?is_DASH_arg_DASH_error101111.$var.app(acc2196972):R.ffi.throwNonFunApp(L[521],is_DASH_arg_DASH_error101111.$var,[acc2196972]);
};
try {
if(--R.GAS > 0) {
$z69766977 = $f69826983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69826983,
"from":L[521]});
}
} catch($e69746975) {
if(R.isCont($e69746975)) {
var $ss69786979 = {"from":L[521],
"go":function(if_DASH_1086984) {
return $Hif_DASH_20756985(if_DASH_1086984,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,opts_DASH_dict217400,success100109,_plus13);
}};
$e69746975.stack[R.EXN_STACKHEIGHT++] = $ss69786979;
}
if(R.isPyretException($e69746975)) {
$e69746975.pyretStack.push(L[521]);
}
throw $e69746975;
}
var $ret69806981 = $Hif_DASH_20756985($z69766977,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,opts_DASH_dict217400,success100109,_plus13);
++R.GAS;
return $ret69806981;
});
var anf_fun5926967 = G(D531,"immutable-string-dict",L[519]);
var $z69596960 = D;
var $f69656966 = function(_) {
return R.isFunction(anf_fun5926967)?anf_fun5926967.app():R.ffi.throwNonFunApp(L[518],anf_fun5926967,[]);
};
try {
if(--R.GAS > 0) {
$z69596960 = $f69656966();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69656966,
"from":L[518]});
}
} catch($e69576958) {
if(R.isCont($e69576958)) {
var $ss69616962 = {"from":L[518],
"go":function(anf_obj5936968) {
return $Hanf_obj22706971(anf_obj5936968,D531,ParsedArguments7067,anf_arg5916969,anf_fun5146970,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e69576958.stack[R.EXN_STACKHEIGHT++] = $ss69616962;
}
if(R.isPyretException($e69576958)) {
$e69576958.pyretStack.push(L[518]);
}
throw $e69576958;
}
var $ret69636964 = $Hanf_obj22706971($z69596960,D531,ParsedArguments7067,anf_arg5916969,anf_fun5146970,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret69636964;
};
var $Hanf_obj22706971 = function(anf_obj5936968,D531,ParsedArguments7067,anf_arg5916969,anf_fun5146970,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var anf_arg5946998 = R.makeObject({"options":opts_DASH_dict217400,
"aliases":anf_obj5936968});
var anf_fun5956996 = G(opts_DASH_dict217400,"keys",L[524]);
var $z69886989 = D;
var $f69946995 = function(_) {
return R.isFunction(anf_fun5956996)?anf_fun5956996.app():R.ffi.throwNonFunApp(L[523],anf_fun5956996,[]);
};
try {
if(--R.GAS > 0) {
$z69886989 = $f69946995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69946995,
"from":L[523]});
}
} catch($e69866987) {
if(R.isCont($e69866987)) {
var $ss69906991 = {"from":L[523],
"go":function(anf_arg5966997) {
return $Hanf_arg22696999(anf_arg5966997,D531,ParsedArguments7067,anf_arg5916969,anf_arg5946998,anf_fun5146970,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e69866987.stack[R.EXN_STACKHEIGHT++] = $ss69906991;
}
if(R.isPyretException($e69866987)) {
$e69866987.pyretStack.push(L[523]);
}
throw $e69866987;
}
var $ret69926993 = $Hanf_arg22696999($z69886989,D531,ParsedArguments7067,anf_arg5916969,anf_arg5946998,anf_fun5146970,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret69926993;
};
var $Hanf_arg22696999 = function(anf_arg5966997,D531,ParsedArguments7067,anf_arg5916969,anf_arg5946998,anf_fun5146970,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var $z70027003 = D;
var $f70087009 = function(_) {
return R.isFunction(anf_fun5146970)?anf_fun5146970.app(anf_arg5916969,anf_arg5946998,anf_arg5966997):R.ffi.throwNonFunApp(L[525],anf_fun5146970,[anf_arg5916969,anf_arg5946998,anf_arg5966997]);
};
try {
if(--R.GAS > 0) {
$z70027003 = $f70087009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70087009,
"from":L[525]});
}
} catch($e70007001) {
if(R.isCont($e70007001)) {
var $ss70047005 = {"from":L[525],
"go":function(options_DASH_and_DASH_aliases2187010) {
return $Hoptions_DASH_and_DASH_aliases22687011(options_DASH_and_DASH_aliases2187010,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e70007001.stack[R.EXN_STACKHEIGHT++] = $ss70047005;
}
if(R.isPyretException($e70007001)) {
$e70007001.pyretStack.push(L[525]);
}
throw $e70007001;
}
var $ret70067007 = $Hoptions_DASH_and_DASH_aliases22687011($z70027003,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret70067007;
};
var $Hoptions_DASH_and_DASH_aliases22687011 = function(options_DASH_and_DASH_aliases2187010,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var $z70147015 = D;
var $f70207021 = function(_) {
return R.isFunction(is_DASH_arg_DASH_error101111.$var)?is_DASH_arg_DASH_error101111.$var.app(options_DASH_and_DASH_aliases2187010):R.ffi.throwNonFunApp(L[526],is_DASH_arg_DASH_error101111.$var,[options_DASH_and_DASH_aliases2187010]);
};
try {
if(--R.GAS > 0) {
$z70147015 = $f70207021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70207021,
"from":L[526]});
}
} catch($e70127013) {
if(R.isCont($e70127013)) {
var $ss70167017 = {"from":L[526],
"go":function(if_DASH_1567022) {
return $Hif_DASH_22677023(if_DASH_1567022,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,options_DASH_and_DASH_aliases2187010,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e70127013.stack[R.EXN_STACKHEIGHT++] = $ss70167017;
}
if(R.isPyretException($e70127013)) {
$e70127013.pyretStack.push(L[526]);
}
throw $e70127013;
}
var $ret70187019 = $Hif_DASH_22677023($z70147015,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,options_DASH_and_DASH_aliases2187010,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret70187019;
};
var $Hif_DASH_22677023 = function(if_DASH_1567022,D531,ParsedArguments7067,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,options_DASH_and_DASH_aliases2187010,opts_DASH_dict217400,required_DASH_many113135,required_DASH_once111131,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var if_helper5977034 = R.makeFunction(function(if_helper_arg5987175) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[526],1,arguments);
}
var ann_DASH_check_DASH_temp5127176 = if_helper_arg5987175;
return R.checkAnn(L[556],ParsedArguments7067,ann_DASH_check_DASH_temp5127176,function() {
return ann_DASH_check_DASH_temp5127176;
});
});
var anf_if6017174 = R.isBoolean(if_DASH_1567022);
if(R.isPyretTrue(anf_if6017174)) {
if(R.isPyretTrue(if_DASH_1567022)) {
var $z70267027 = D;
var $f70327033 = function(_) {
return R.isFunction(if_helper5977034)?if_helper5977034.app(options_DASH_and_DASH_aliases2187010):R.ffi.throwNonFunApp(L[527],if_helper5977034,[options_DASH_and_DASH_aliases2187010]);
};
try {
if(--R.GAS > 0) {
$z70267027 = $f70327033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70327033,
"from":L[527]});
}
} catch($e70247025) {
if(R.isCont($e70247025)) {
var $ss70287029 = {"from":L[527],
"go":function(cont_tail_app11117035) {
return $Hcont_tail_app20767036(cont_tail_app11117035);
}};
$e70247025.stack[R.EXN_STACKHEIGHT++] = $ss70287029;
}
if(R.isPyretException($e70247025)) {
$e70247025.pyretStack.push(L[527]);
}
throw $e70247025;
}
var $ret70307031 = $Hcont_tail_app20767036($z70267027);
++R.GAS;
return $ret70307031;
} else {
var full_DASH_options2347053 = G(options_DASH_and_DASH_aliases2187010,"options",L[555]);
var option_DASH_aliases2357054 = G(options_DASH_and_DASH_aliases2187010,"aliases",L[554]);
var handle_DASH_repeated2367037 = {"$var":D,
"$name":"handle-repeated"};
var anf_assign6997038 = R.makeFunction(function(results2377070,repeated2387071,name2397072,val2407073) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[534],4,arguments);
}
var cases_DASH_val1147170 = results2377070;
var anf_fun6037084 = G(cases_DASH_val1147170,"_match",L[535]);
var anf_obj6957090 = R.makeFunction(function(parsed2417091,unknown2427092) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[536],2,arguments);
}
var cases_DASH_val1137169 = repeated2387071;
var anf_fun6057103 = G(cases_DASH_val1137169,"_match",L[537]);
var anf_obj6237109 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[550],0,arguments);
}
var anf_bracket6077168 = G(results2377070,"parsed",L[553]);
var anf_fun6087165 = G(anf_bracket6077168,"has-key",L[552]);
var $z71577158 = D;
var $f71637164 = function(_) {
return R.isFunction(anf_fun6087165)?anf_fun6087165.app(name2397072):R.ffi.throwNonFunApp(L[551],anf_fun6087165,[name2397072]);
};
try {
if(--R.GAS > 0) {
$z71577158 = $f71637164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71637164,
"from":L[551]});
}
} catch($e71557156) {
if(R.isCont($e71557156)) {
var $ss71597160 = {"from":L[551],
"go":function(if_DASH_1097166) {
return $Hif_DASH_20827167(if_DASH_1097166,arg_DASH_error102113,file_DASH_name83203,format7872,list2776,name2397072,parsed2417091,repeated2387071,results2377070,success100109,unknown2427092,val2407073);
}};
$e71557156.stack[R.EXN_STACKHEIGHT++] = $ss71597160;
}
if(R.isPyretException($e71557156)) {
$e71557156.pyretStack.push(L[551]);
}
throw $e71557156;
}
var $ret71617162 = $Hif_DASH_20827167($z71577158,arg_DASH_error102113,file_DASH_name83203,format7872,list2776,name2397072,parsed2417091,repeated2387071,results2377070,success100109,unknown2427092,val2407073);
++R.GAS;
return $ret71617162;
});
var anf_obj6487110 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[546],0,arguments);
}
var anf_bracket6257154 = G(results2377070,"parsed",L[549]);
var anf_fun6267151 = G(anf_bracket6257154,"has-key",L[548]);
var $z71437144 = D;
var $f71497150 = function(_) {
return R.isFunction(anf_fun6267151)?anf_fun6267151.app(name2397072):R.ffi.throwNonFunApp(L[547],anf_fun6267151,[name2397072]);
};
try {
if(--R.GAS > 0) {
$z71437144 = $f71497150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71497150,
"from":L[547]});
}
} catch($e71417142) {
if(R.isCont($e71417142)) {
var $ss71457146 = {"from":L[547],
"go":function(if_DASH_1107152) {
return $Hif_DASH_20917153(if_DASH_1107152,list2776,name2397072,parsed2417091,results2377070,success100109,unknown2427092,val2407073,_plus13);
}};
$e71417142.stack[R.EXN_STACKHEIGHT++] = $ss71457146;
}
if(R.isPyretException($e71417142)) {
$e71417142.pyretStack.push(L[547]);
}
throw $e71417142;
}
var $ret71477148 = $Hif_DASH_20917153($z71437144,list2776,name2397072,parsed2417091,results2377070,success100109,unknown2427092,val2407073,_plus13);
++R.GAS;
return $ret71477148;
});
var anf_obj6667111 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[542],0,arguments);
}
var anf_bracket6507140 = G(results2377070,"parsed",L[545]);
var anf_fun6517137 = G(anf_bracket6507140,"has-key",L[544]);
var $z71297130 = D;
var $f71357136 = function(_) {
return R.isFunction(anf_fun6517137)?anf_fun6517137.app(name2397072):R.ffi.throwNonFunApp(L[543],anf_fun6517137,[name2397072]);
};
try {
if(--R.GAS > 0) {
$z71297130 = $f71357136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71357136,
"from":L[543]});
}
} catch($e71277128) {
if(R.isCont($e71277128)) {
var $ss71317132 = {"from":L[543],
"go":function(if_DASH_1117138) {
return $Hif_DASH_20977139(if_DASH_1117138,arg_DASH_error102113,file_DASH_name83203,format7872,list2776,name2397072,parsed2417091,repeated2387071,results2377070,success100109,unknown2427092,val2407073);
}};
$e71277128.stack[R.EXN_STACKHEIGHT++] = $ss71317132;
}
if(R.isPyretException($e71277128)) {
$e71277128.pyretStack.push(L[543]);
}
throw $e71277128;
}
var $ret71337134 = $Hif_DASH_20977139($z71297130,arg_DASH_error102113,file_DASH_name83203,format7872,list2776,name2397072,parsed2417091,repeated2387071,results2377070,success100109,unknown2427092,val2407073);
++R.GAS;
return $ret71337134;
});
var anf_obj6917112 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[538],0,arguments);
}
var anf_bracket6687126 = G(results2377070,"parsed",L[541]);
var anf_fun6697123 = G(anf_bracket6687126,"has-key",L[540]);
var $z71157116 = D;
var $f71217122 = function(_) {
return R.isFunction(anf_fun6697123)?anf_fun6697123.app(name2397072):R.ffi.throwNonFunApp(L[539],anf_fun6697123,[name2397072]);
};
try {
if(--R.GAS > 0) {
$z71157116 = $f71217122();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71217122,
"from":L[539]});
}
} catch($e71137114) {
if(R.isCont($e71137114)) {
var $ss71177118 = {"from":L[539],
"go":function(if_DASH_1127124) {
return $Hif_DASH_21067125(if_DASH_1127124,list2776,name2397072,parsed2417091,results2377070,success100109,unknown2427092,val2407073,_plus13);
}};
$e71137114.stack[R.EXN_STACKHEIGHT++] = $ss71177118;
}
if(R.isPyretException($e71137114)) {
$e71137114.pyretStack.push(L[539]);
}
throw $e71137114;
}
var $ret71197120 = $Hif_DASH_21067125($z71157116,list2776,name2397072,parsed2417091,results2377070,success100109,unknown2427092,val2407073,_plus13);
++R.GAS;
return $ret71197120;
});
var anf_arg6927104 = R.makeObject({"once":anf_obj6237109,
"many":anf_obj6487110,
"required-once":anf_obj6667111,
"required-many":anf_obj6917112});
var anf_arg6947105 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[537],0,arguments);
}
var ann_DASH_check_DASH_temp6937108 = R.throwNoBranchesMatched(L[537],("cases"));
return ann_DASH_check_DASH_temp6937108;
});
var $z70957096 = D;
var $f71017102 = function(_) {
return R.isFunction(anf_fun6057103)?anf_fun6057103.app(anf_arg6927104,anf_arg6947105):R.ffi.throwNonFunApp(L[536],anf_fun6057103,[anf_arg6927104,anf_arg6947105]);
};
try {
if(--R.GAS > 0) {
$z70957096 = $f71017102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71017102,
"from":L[536]});
}
} catch($e70937094) {
if(R.isCont($e70937094)) {
var $ss70977098 = {"from":L[536],
"go":function(ann_DASH_check_DASH_temp6047106) {
return $Hann_DASH_check_DASH_temp21077107(ann_DASH_check_DASH_temp6047106);
}};
$e70937094.stack[R.EXN_STACKHEIGHT++] = $ss70977098;
}
if(R.isPyretException($e70937094)) {
$e70937094.pyretStack.push(L[536]);
}
throw $e70937094;
}
var $ret70997100 = $Hann_DASH_check_DASH_temp21077107($z70957096);
++R.GAS;
return $ret70997100;
});
var anf_arg6967085 = R.makeObject({"success":anf_obj6957090});
var anf_arg6987086 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[535],0,arguments);
}
var ann_DASH_check_DASH_temp6977089 = results2377070;
return ann_DASH_check_DASH_temp6977089;
});
var $z70767077 = D;
var $f70827083 = function(_) {
return R.isFunction(anf_fun6037084)?anf_fun6037084.app(anf_arg6967085,anf_arg6987086):R.ffi.throwNonFunApp(L[534],anf_fun6037084,[anf_arg6967085,anf_arg6987086]);
};
try {
if(--R.GAS > 0) {
$z70767077 = $f70827083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70827083,
"from":L[534]});
}
} catch($e70747075) {
if(R.isCont($e70747075)) {
var $ss70787079 = {"from":L[534],
"go":function(ann_DASH_check_DASH_temp6027087) {
return $Hann_DASH_check_DASH_temp21087088(ann_DASH_check_DASH_temp6027087);
}};
$e70747075.stack[R.EXN_STACKHEIGHT++] = $ss70787079;
}
if(R.isPyretException($e70747075)) {
$e70747075.pyretStack.push(L[534]);
}
throw $e70747075;
}
var $ret70807081 = $Hann_DASH_check_DASH_temp21087088($z70767077);
++R.GAS;
return $ret70807081;
});
handle_DASH_repeated2367037.$var = anf_assign6997038;
var anf_fun7007052 = G(lists1134,"filter",L[533]);
var anf_arg7147051 = R.makeFunction(function(key2447056) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[530],1,arguments);
}
var anf_fun7027067 = G(opts_DASH_dict217400,"get",L[532]);
var $z70597060 = D;
var $f70657066 = function(_) {
return R.isFunction(anf_fun7027067)?anf_fun7027067.app(key2447056):R.ffi.throwNonFunApp(L[531],anf_fun7027067,[key2447056]);
};
try {
if(--R.GAS > 0) {
$z70597060 = $f70657066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70657066,
"from":L[531]});
}
} catch($e70577058) {
if(R.isCont($e70577058)) {
var $ss70617062 = {"from":L[531],
"go":function(anf_bracket7037068) {
return $Hanf_bracket21117069(anf_bracket7037068,required_DASH_many113135,required_DASH_once111131);
}};
$e70577058.stack[R.EXN_STACKHEIGHT++] = $ss70617062;
}
if(R.isPyretException($e70577058)) {
$e70577058.pyretStack.push(L[531]);
}
throw $e70577058;
}
var $ret70637064 = $Hanf_bracket21117069($z70597060,required_DASH_many113135,required_DASH_once111131);
++R.GAS;
return $ret70637064;
});
var anf_fun7157049 = G(opts_DASH_dict217400,"keys",L[529]);
var $z70417042 = D;
var $f70477048 = function(_) {
return R.isFunction(anf_fun7157049)?anf_fun7157049.app():R.ffi.throwNonFunApp(L[528],anf_fun7157049,[]);
};
try {
if(--R.GAS > 0) {
$z70417042 = $f70477048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70477048,
"from":L[528]});
}
} catch($e70397040) {
if(R.isCont($e70397040)) {
var $ss70437044 = {"from":L[528],
"go":function(anf_arg7167050) {
return $Hanf_arg22667055(anf_arg7167050,D531,anf_arg7147051,anf_fun7007052,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper5977034,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,option_DASH_aliases2357054,opts_DASH_dict217400,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e70397040.stack[R.EXN_STACKHEIGHT++] = $ss70437044;
}
if(R.isPyretException($e70397040)) {
$e70397040.pyretStack.push(L[528]);
}
throw $e70397040;
}
var $ret70457046 = $Hanf_arg22667055($z70417042,D531,anf_arg7147051,anf_fun7007052,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper5977034,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,option_DASH_aliases2357054,opts_DASH_dict217400,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret70457046;
}
} else {
var cont_tail_arg5997173 = R.throwNonBooleanCondition(L[526],("if"),if_DASH_1567022);
if(--R.GAS > 0) {
$z71717172 = R.isFunction(if_helper5977034)?if_helper5977034.app(cont_tail_arg5997173):R.ffi.throwNonFunApp(L[526],if_helper5977034,[cont_tail_arg5997173]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper5977034)?if_helper5977034.app(cont_tail_arg5997173):R.ffi.throwNonFunApp(L[526],if_helper5977034,[cont_tail_arg5997173]);
},
"from":L[526]});
}
++R.GAS;
return $z71717172;
}
};
var $Hcont_tail_app20767036 = function(cont_tail_app11117035) {
return cont_tail_app11117035;
};
var $Hanf_arg22667055 = function(anf_arg7167050,D531,anf_arg7147051,anf_fun7007052,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper5977034,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,option_DASH_aliases2357054,opts_DASH_dict217400,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var $z71797180 = D;
var $f71857186 = function(_) {
return R.isFunction(anf_fun7007052)?anf_fun7007052.app(anf_arg7147051,anf_arg7167050):R.ffi.throwNonFunApp(L[557],anf_fun7007052,[anf_arg7147051,anf_arg7167050]);
};
try {
if(--R.GAS > 0) {
$z71797180 = $f71857186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71857186,
"from":L[557]});
}
} catch($e71777178) {
if(R.isCont($e71777178)) {
var $ss71817182 = {"from":L[557],
"go":function(required2437187) {
return $Hrequired22657188(required2437187,D531,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper5977034,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,option_DASH_aliases2357054,opts_DASH_dict217400,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e71777178.stack[R.EXN_STACKHEIGHT++] = $ss71817182;
}
if(R.isPyretException($e71777178)) {
$e71777178.pyretStack.push(L[557]);
}
throw $e71777178;
}
var $ret71837184 = $Hrequired22657188($z71797180,D531,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper5977034,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,option_DASH_aliases2357054,opts_DASH_dict217400,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret71837184;
};
var $Hrequired22657188 = function(required2437187,D531,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper5977034,is_DASH_Param_127163,is_DASH_arg_DASH_error101111,is_DASH_empty2873,list2776,lists1134,many109127,once107123,option_DASH_aliases2357054,opts_DASH_dict217400,success100109,_plus13,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var process2467189 = {"$var":D,
"$name":"process"};
var anf_assign10047190 = R.makeFunction(function(results2477204,cur_DASH_index2487205,remaining2497206) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[560],3,arguments);
}
var $z72097210 = D;
var $f72157216 = function(_) {
return R.isFunction(is_DASH_arg_DASH_error101111.$var)?is_DASH_arg_DASH_error101111.$var.app(results2477204):R.ffi.throwNonFunApp(L[561],is_DASH_arg_DASH_error101111.$var,[results2477204]);
};
try {
if(--R.GAS > 0) {
$z72097210 = $f72157216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72157216,
"from":L[561]});
}
} catch($e72077208) {
if(R.isCont($e72077208)) {
var $ss72117212 = {"from":L[561],
"go":function(if_DASH_1427217) {
return $Hif_DASH_22317218(if_DASH_1427217,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,is_DASH_Param_127163,list2776,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e72077208.stack[R.EXN_STACKHEIGHT++] = $ss72117212;
}
if(R.isPyretException($e72077208)) {
$e72077208.pyretStack.push(L[561]);
}
throw $e72077208;
}
var $ret72137214 = $Hif_DASH_22317218($z72097210,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,is_DASH_Param_127163,list2776,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret72137214;
});
process2467189.$var = anf_assign10047190;
var anf_fun10057201 = G(D531,"immutable-string-dict",L[559]);
var $z71937194 = D;
var $f71997200 = function(_) {
return R.isFunction(anf_fun10057201)?anf_fun10057201.app():R.ffi.throwNonFunApp(L[558],anf_fun10057201,[]);
};
try {
if(--R.GAS > 0) {
$z71937194 = $f71997200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71997200,
"from":L[558]});
}
} catch($e71917192) {
if(R.isCont($e71917192)) {
var $ss71957196 = {"from":L[558],
"go":function(anf_arg10067202) {
return $Hanf_arg22647203(anf_arg10067202,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17);
}};
$e71917192.stack[R.EXN_STACKHEIGHT++] = $ss71957196;
}
if(R.isPyretException($e71917192)) {
$e71917192.pyretStack.push(L[558]);
}
throw $e71917192;
}
var $ret71977198 = $Hanf_arg22647203($z71937194,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17);
++R.GAS;
return $ret71977198;
};
var $Hanf_arg22647203 = function(anf_arg10067202,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17) {
var anf_fun10077229 = G(list2776,"make",L[562]);
var $z72217222 = D;
var $f72277228 = function(_) {
return R.isFunction(anf_fun10077229)?anf_fun10077229.app([]):R.ffi.throwNonFunApp(L[562],anf_fun10077229,[[]]);
};
try {
if(--R.GAS > 0) {
$z72217222 = $f72277228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72277228,
"from":L[562]});
}
} catch($e72197220) {
if(R.isCont($e72197220)) {
var $ss72237224 = {"from":L[562],
"go":function(anf_arg10087230) {
return $Hanf_arg22637231(anf_arg10087230,anf_arg10067202,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17);
}};
$e72197220.stack[R.EXN_STACKHEIGHT++] = $ss72237224;
}
if(R.isPyretException($e72197220)) {
$e72197220.pyretStack.push(L[562]);
}
throw $e72197220;
}
var $ret72257226 = $Hanf_arg22637231($z72217222,anf_arg10067202,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17);
++R.GAS;
return $ret72257226;
};
var $Hanf_arg22637231 = function(anf_arg10087230,anf_arg10067202,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17) {
var $z72347235 = D;
var $f72407241 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg10067202,anf_arg10087230):R.ffi.throwNonFunApp(L[563],success100109.$var,[anf_arg10067202,anf_arg10087230]);
};
try {
if(--R.GAS > 0) {
$z72347235 = $f72407241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72407241,
"from":L[563]});
}
} catch($e72327233) {
if(R.isCont($e72327233)) {
var $ss72367237 = {"from":L[563],
"go":function(anf_arg10097242) {
return $Hanf_arg22627243(anf_arg10097242,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17);
}};
$e72327233.stack[R.EXN_STACKHEIGHT++] = $ss72367237;
}
if(R.isPyretException($e72327233)) {
$e72327233.pyretStack.push(L[563]);
}
throw $e72327233;
}
var $ret72387239 = $Hanf_arg22627243($z72347235,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17);
++R.GAS;
return $ret72387239;
};
var $Hanf_arg22627243 = function(anf_arg10097242,arg_DASH_error102113,args216388,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,process2467189,required2437187,success100109,not17) {
var $z72467247 = D;
var $f72527253 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg10097242,(1),args216388):R.ffi.throwNonFunApp(L[564],process2467189.$var,[anf_arg10097242,(1),args216388]);
};
try {
if(--R.GAS > 0) {
$z72467247 = $f72527253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72527253,
"from":L[564]});
}
} catch($e72447245) {
if(R.isCont($e72447245)) {
var $ss72487249 = {"from":L[564],
"go":function(parsed_DASH_results3107254) {
return $Hparsed_DASH_results22617255(parsed_DASH_results3107254,arg_DASH_error102113,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required2437187,success100109,not17);
}};
$e72447245.stack[R.EXN_STACKHEIGHT++] = $ss72487249;
}
if(R.isPyretException($e72447245)) {
$e72447245.pyretStack.push(L[564]);
}
throw $e72447245;
}
var $ret72507251 = $Hparsed_DASH_results22617255($z72467247,arg_DASH_error102113,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required2437187,success100109,not17);
++R.GAS;
return $ret72507251;
};
var $Hparsed_DASH_results22617255 = function(parsed_DASH_results3107254,arg_DASH_error102113,file_DASH_name83203,format7872,if_helper5977034,is_DASH_empty2873,list2776,lists1134,many109127,once107123,opts_DASH_dict217400,required2437187,success100109,not17) {
var cases_DASH_val1557305 = parsed_DASH_results3107254;
var anf_fun10107266 = G(cases_DASH_val1557305,"_match",L[565]);
var anf_obj11057272 = R.makeFunction(function(parsed3117273,other3127274) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[566],2,arguments);
}
var anf_fun10127288 = G(lists1134,"fold",L[572]);
var anf_arg10857287 = R.makeFunction(function(acc3147290,key3157291) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[569],2,arguments);
}
var anf_fun10147302 = G(opts_DASH_dict217400,"get",L[571]);
var $z72947295 = D;
var $f73007301 = function(_) {
return R.isFunction(anf_fun10147302)?anf_fun10147302.app(key3157291):R.ffi.throwNonFunApp(L[570],anf_fun10147302,[key3157291]);
};
try {
if(--R.GAS > 0) {
$z72947295 = $f73007301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73007301,
"from":L[570]});
}
} catch($e72927293) {
if(R.isCont($e72927293)) {
var $ss72967297 = {"from":L[570],
"go":function(cases_DASH_val1537303) {
return $Hcases_DASH_val22497304(cases_DASH_val1537303,acc3147290,key3157291,many109127,once107123,not17);
}};
$e72927293.stack[R.EXN_STACKHEIGHT++] = $ss72967297;
}
if(R.isPyretException($e72927293)) {
$e72927293.pyretStack.push(L[570]);
}
throw $e72927293;
}
var $ret72987299 = $Hcases_DASH_val22497304($z72947295,acc3147290,key3157291,many109127,once107123,not17);
++R.GAS;
return $ret72987299;
});
var anf_fun10867285 = G(opts_DASH_dict217400,"keys",L[568]);
var $z72777278 = D;
var $f72837284 = function(_) {
return R.isFunction(anf_fun10867285)?anf_fun10867285.app():R.ffi.throwNonFunApp(L[567],anf_fun10867285,[]);
};
try {
if(--R.GAS > 0) {
$z72777278 = $f72837284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72837284,
"from":L[567]});
}
} catch($e72757276) {
if(R.isCont($e72757276)) {
var $ss72797280 = {"from":L[567],
"go":function(anf_arg10877286) {
return $Hanf_arg22597289(anf_arg10877286,anf_arg10857287,anf_fun10127288,arg_DASH_error102113,file_DASH_name83203,format7872,is_DASH_empty2873,list2776,lists1134,other3127274,parsed_DASH_results3107254,parsed3117273,required2437187,success100109,not17);
}};
$e72757276.stack[R.EXN_STACKHEIGHT++] = $ss72797280;
}
if(R.isPyretException($e72757276)) {
$e72757276.pyretStack.push(L[567]);
}
throw $e72757276;
}
var $ret72817282 = $Hanf_arg22597289($z72777278,anf_arg10857287,anf_fun10127288,arg_DASH_error102113,file_DASH_name83203,format7872,is_DASH_empty2873,list2776,lists1134,other3127274,parsed_DASH_results3107254,parsed3117273,required2437187,success100109,not17);
++R.GAS;
return $ret72817282;
});
var anf_arg11067267 = R.makeObject({"success":anf_obj11057272});
var anf_arg11087268 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[565],0,arguments);
}
var ann_DASH_check_DASH_temp11077271 = parsed_DASH_results3107254;
return ann_DASH_check_DASH_temp11077271;
});
var $z72587259 = D;
var $f72647265 = function(_) {
return R.isFunction(anf_fun10107266)?anf_fun10107266.app(anf_arg11067267,anf_arg11087268):R.ffi.throwNonFunApp(L[565],anf_fun10107266,[anf_arg11067267,anf_arg11087268]);
};
try {
if(--R.GAS > 0) {
$z72587259 = $f72647265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72647265,
"from":L[565]});
}
} catch($e72567257) {
if(R.isCont($e72567257)) {
var $ss72607261 = {"from":L[565],
"go":function(cont_tail_arg11097269) {
return $Hcont_tail_arg22607270(cont_tail_arg11097269,if_helper5977034);
}};
$e72567257.stack[R.EXN_STACKHEIGHT++] = $ss72607261;
}
if(R.isPyretException($e72567257)) {
$e72567257.pyretStack.push(L[565]);
}
throw $e72567257;
}
var $ret72627263 = $Hcont_tail_arg22607270($z72587259,if_helper5977034);
++R.GAS;
return $ret72627263;
};
var $Hcont_tail_arg22607270 = function(cont_tail_arg11097269,if_helper5977034) {
if(--R.GAS > 0) {
$z73067307 = R.isFunction(if_helper5977034)?if_helper5977034.app(cont_tail_arg11097269):R.ffi.throwNonFunApp(L[565],if_helper5977034,[cont_tail_arg11097269]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper5977034)?if_helper5977034.app(cont_tail_arg11097269):R.ffi.throwNonFunApp(L[565],if_helper5977034,[cont_tail_arg11097269]);
},
"from":L[565]});
}
++R.GAS;
return $z73067307;
};
var $Hanf_arg22597289 = function(anf_arg10877286,anf_arg10857287,anf_fun10127288,arg_DASH_error102113,file_DASH_name83203,format7872,is_DASH_empty2873,list2776,lists1134,other3127274,parsed_DASH_results3107254,parsed3117273,required2437187,success100109,not17) {
var $z73107311 = D;
var $f73167317 = function(_) {
return R.isFunction(anf_fun10127288)?anf_fun10127288.app(anf_arg10857287,parsed3117273,anf_arg10877286):R.ffi.throwNonFunApp(L[573],anf_fun10127288,[anf_arg10857287,parsed3117273,anf_arg10877286]);
};
try {
if(--R.GAS > 0) {
$z73107311 = $f73167317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73167317,
"from":L[573]});
}
} catch($e73087309) {
if(R.isCont($e73087309)) {
var $ss73127313 = {"from":L[573],
"go":function(filled_DASH_missing_DASH_defaults3137318) {
return $Hfilled_DASH_missing_DASH_defaults22587319(filled_DASH_missing_DASH_defaults3137318,arg_DASH_error102113,file_DASH_name83203,format7872,is_DASH_empty2873,list2776,lists1134,other3127274,parsed_DASH_results3107254,required2437187,success100109,not17);
}};
$e73087309.stack[R.EXN_STACKHEIGHT++] = $ss73127313;
}
if(R.isPyretException($e73087309)) {
$e73087309.pyretStack.push(L[573]);
}
throw $e73087309;
}
var $ret73147315 = $Hfilled_DASH_missing_DASH_defaults22587319($z73107311,arg_DASH_error102113,file_DASH_name83203,format7872,is_DASH_empty2873,list2776,lists1134,other3127274,parsed_DASH_results3107254,required2437187,success100109,not17);
++R.GAS;
return $ret73147315;
};
var $Hfilled_DASH_missing_DASH_defaults22587319 = function(filled_DASH_missing_DASH_defaults3137318,arg_DASH_error102113,file_DASH_name83203,format7872,is_DASH_empty2873,list2776,lists1134,other3127274,parsed_DASH_results3107254,required2437187,success100109,not17) {
var anf_fun10887330 = G(lists1134,"filter",L[578]);
var anf_arg10927331 = R.makeFunction(function(key3277334) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[575],1,arguments);
}
var anf_fun10907345 = G(filled_DASH_missing_DASH_defaults3137318,"has-key",L[577]);
var $z73377338 = D;
var $f73437344 = function(_) {
return R.isFunction(anf_fun10907345)?anf_fun10907345.app(key3277334):R.ffi.throwNonFunApp(L[576],anf_fun10907345,[key3277334]);
};
try {
if(--R.GAS > 0) {
$z73377338 = $f73437344();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73437344,
"from":L[576]});
}
} catch($e73357336) {
if(R.isCont($e73357336)) {
var $ss73397340 = {"from":L[576],
"go":function(anf_arg10917346) {
return $Hanf_arg22517347(anf_arg10917346,not17);
}};
$e73357336.stack[R.EXN_STACKHEIGHT++] = $ss73397340;
}
if(R.isPyretException($e73357336)) {
$e73357336.pyretStack.push(L[576]);
}
throw $e73357336;
}
var $ret73417342 = $Hanf_arg22517347($z73377338,not17);
++R.GAS;
return $ret73417342;
});
var $z73227323 = D;
var $f73287329 = function(_) {
return R.isFunction(anf_fun10887330)?anf_fun10887330.app(anf_arg10927331,required2437187):R.ffi.throwNonFunApp(L[574],anf_fun10887330,[anf_arg10927331,required2437187]);
};
try {
if(--R.GAS > 0) {
$z73227323 = $f73287329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73287329,
"from":L[574]});
}
} catch($e73207321) {
if(R.isCont($e73207321)) {
var $ss73247325 = {"from":L[574],
"go":function(missing_DASH_args3267332) {
return $Hmissing_DASH_args22577333(missing_DASH_args3267332,arg_DASH_error102113,file_DASH_name83203,filled_DASH_missing_DASH_defaults3137318,format7872,is_DASH_empty2873,list2776,other3127274,parsed_DASH_results3107254,success100109);
}};
$e73207321.stack[R.EXN_STACKHEIGHT++] = $ss73247325;
}
if(R.isPyretException($e73207321)) {
$e73207321.pyretStack.push(L[574]);
}
throw $e73207321;
}
var $ret73267327 = $Hmissing_DASH_args22577333($z73227323,arg_DASH_error102113,file_DASH_name83203,filled_DASH_missing_DASH_defaults3137318,format7872,is_DASH_empty2873,list2776,other3127274,parsed_DASH_results3107254,success100109);
++R.GAS;
return $ret73267327;
};
var $Hmissing_DASH_args22577333 = function(missing_DASH_args3267332,arg_DASH_error102113,file_DASH_name83203,filled_DASH_missing_DASH_defaults3137318,format7872,is_DASH_empty2873,list2776,other3127274,parsed_DASH_results3107254,success100109) {
var $z73507351 = D;
var $f73567357 = function(_) {
return R.isFunction(is_DASH_empty2873)?is_DASH_empty2873.app(missing_DASH_args3267332):R.ffi.throwNonFunApp(L[579],is_DASH_empty2873,[missing_DASH_args3267332]);
};
try {
if(--R.GAS > 0) {
$z73507351 = $f73567357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73567357,
"from":L[579]});
}
} catch($e73487349) {
if(R.isCont($e73487349)) {
var $ss73527353 = {"from":L[579],
"go":function(if_DASH_1547358) {
return $Hif_DASH_22567359(if_DASH_1547358,arg_DASH_error102113,file_DASH_name83203,filled_DASH_missing_DASH_defaults3137318,format7872,list2776,missing_DASH_args3267332,other3127274,parsed_DASH_results3107254,success100109);
}};
$e73487349.stack[R.EXN_STACKHEIGHT++] = $ss73527353;
}
if(R.isPyretException($e73487349)) {
$e73487349.pyretStack.push(L[579]);
}
throw $e73487349;
}
var $ret73547355 = $Hif_DASH_22567359($z73507351,arg_DASH_error102113,file_DASH_name83203,filled_DASH_missing_DASH_defaults3137318,format7872,list2776,missing_DASH_args3267332,other3127274,parsed_DASH_results3107254,success100109);
++R.GAS;
return $ret73547355;
};
var $Hif_DASH_22567359 = function(if_DASH_1547358,arg_DASH_error102113,file_DASH_name83203,filled_DASH_missing_DASH_defaults3137318,format7872,list2776,missing_DASH_args3267332,other3127274,parsed_DASH_results3107254,success100109) {
var if_helper10937371 = R.makeFunction(function(if_helper_arg10947390) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[579],1,arguments);
}
var ann_DASH_check_DASH_temp10117391 = if_helper_arg10947390;
return ann_DASH_check_DASH_temp10117391;
});
var anf_if10977389 = R.isBoolean(if_DASH_1547358);
if(R.isPyretTrue(anf_if10977389)) {
if(R.isPyretTrue(if_DASH_1547358)) {
var $z73627363 = D;
var $f73687369 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(filled_DASH_missing_DASH_defaults3137318,other3127274):R.ffi.throwNonFunApp(L[580],success100109.$var,[filled_DASH_missing_DASH_defaults3137318,other3127274]);
};
try {
if(--R.GAS > 0) {
$z73627363 = $f73687369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73687369,
"from":L[580]});
}
} catch($e73607361) {
if(R.isCont($e73607361)) {
var $ss73647365 = {"from":L[580],
"go":function(cont_tail_arg11037370) {
return $Hcont_tail_arg22527372(cont_tail_arg11037370,if_helper10937371);
}};
$e73607361.stack[R.EXN_STACKHEIGHT++] = $ss73647365;
}
if(R.isPyretException($e73607361)) {
$e73607361.pyretStack.push(L[580]);
}
throw $e73607361;
}
var $ret73667367 = $Hcont_tail_arg22527372($z73627363,if_helper10937371);
++R.GAS;
return $ret73667367;
} else {
var anf_fun10987383 = G(list2776,"make",L[581]);
var $z73757376 = D;
var $f73817382 = function(_) {
return R.isFunction(anf_fun10987383)?anf_fun10987383.app([file_DASH_name83203,missing_DASH_args3267332]):R.ffi.throwNonFunApp(L[581],anf_fun10987383,[[file_DASH_name83203,missing_DASH_args3267332]]);
};
try {
if(--R.GAS > 0) {
$z73757376 = $f73817382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73817382,
"from":L[581]});
}
} catch($e73737374) {
if(R.isCont($e73737374)) {
var $ss73777378 = {"from":L[581],
"go":function(anf_arg10997384) {
return $Hanf_arg22557385(anf_arg10997384,arg_DASH_error102113,format7872,if_helper10937371,parsed_DASH_results3107254);
}};
$e73737374.stack[R.EXN_STACKHEIGHT++] = $ss73777378;
}
if(R.isPyretException($e73737374)) {
$e73737374.pyretStack.push(L[581]);
}
throw $e73737374;
}
var $ret73797380 = $Hanf_arg22557385($z73757376,arg_DASH_error102113,format7872,if_helper10937371,parsed_DASH_results3107254);
++R.GAS;
return $ret73797380;
}
} else {
var cont_tail_arg10957388 = R.throwNonBooleanCondition(L[579],("if"),if_DASH_1547358);
if(--R.GAS > 0) {
$z73867387 = R.isFunction(if_helper10937371)?if_helper10937371.app(cont_tail_arg10957388):R.ffi.throwNonFunApp(L[579],if_helper10937371,[cont_tail_arg10957388]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10937371)?if_helper10937371.app(cont_tail_arg10957388):R.ffi.throwNonFunApp(L[579],if_helper10937371,[cont_tail_arg10957388]);
},
"from":L[579]});
}
++R.GAS;
return $z73867387;
}
};
var $Hcont_tail_arg22527372 = function(cont_tail_arg11037370,if_helper10937371) {
if(--R.GAS > 0) {
$z73927393 = R.isFunction(if_helper10937371)?if_helper10937371.app(cont_tail_arg11037370):R.ffi.throwNonFunApp(L[580],if_helper10937371,[cont_tail_arg11037370]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10937371)?if_helper10937371.app(cont_tail_arg11037370):R.ffi.throwNonFunApp(L[580],if_helper10937371,[cont_tail_arg11037370]);
},
"from":L[580]});
}
++R.GAS;
return $z73927393;
};
var $Hanf_arg22557385 = function(anf_arg10997384,arg_DASH_error102113,format7872,if_helper10937371,parsed_DASH_results3107254) {
var $z73967397 = D;
var $f74027403 = function(_) {
return R.isFunction(format7872)?format7872.app(("Command line option validation for ~a failed: The following options are required but not found: ~a"),anf_arg10997384):R.ffi.throwNonFunApp(L[582],format7872,[("Command line option validation for ~a failed: The following options are required but not found: ~a"),anf_arg10997384]);
};
try {
if(--R.GAS > 0) {
$z73967397 = $f74027403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74027403,
"from":L[582]});
}
} catch($e73947395) {
if(R.isCont($e73947395)) {
var $ss73987399 = {"from":L[582],
"go":function(anf_arg11007404) {
return $Hanf_arg22547405(anf_arg11007404,arg_DASH_error102113,if_helper10937371,parsed_DASH_results3107254);
}};
$e73947395.stack[R.EXN_STACKHEIGHT++] = $ss73987399;
}
if(R.isPyretException($e73947395)) {
$e73947395.pyretStack.push(L[582]);
}
throw $e73947395;
}
var $ret74007401 = $Hanf_arg22547405($z73967397,arg_DASH_error102113,if_helper10937371,parsed_DASH_results3107254);
++R.GAS;
return $ret74007401;
};
var $Hanf_arg22547405 = function(anf_arg11007404,arg_DASH_error102113,if_helper10937371,parsed_DASH_results3107254) {
var $z74087409 = D;
var $f74147415 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg11007404,parsed_DASH_results3107254):R.ffi.throwNonFunApp(L[583],arg_DASH_error102113.$var,[anf_arg11007404,parsed_DASH_results3107254]);
};
try {
if(--R.GAS > 0) {
$z74087409 = $f74147415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74147415,
"from":L[583]});
}
} catch($e74067407) {
if(R.isCont($e74067407)) {
var $ss74107411 = {"from":L[583],
"go":function(cont_tail_arg11017416) {
return $Hcont_tail_arg22537417(cont_tail_arg11017416,if_helper10937371);
}};
$e74067407.stack[R.EXN_STACKHEIGHT++] = $ss74107411;
}
if(R.isPyretException($e74067407)) {
$e74067407.pyretStack.push(L[583]);
}
throw $e74067407;
}
var $ret74127413 = $Hcont_tail_arg22537417($z74087409,if_helper10937371);
++R.GAS;
return $ret74127413;
};
var $Hcont_tail_arg22537417 = function(cont_tail_arg11017416,if_helper10937371) {
if(--R.GAS > 0) {
$z74187419 = R.isFunction(if_helper10937371)?if_helper10937371.app(cont_tail_arg11017416):R.ffi.throwNonFunApp(L[583],if_helper10937371,[cont_tail_arg11017416]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10937371)?if_helper10937371.app(cont_tail_arg11017416):R.ffi.throwNonFunApp(L[583],if_helper10937371,[cont_tail_arg11017416]);
},
"from":L[583]});
}
++R.GAS;
return $z74187419;
};
var $Hanf_arg22517347 = function(anf_arg10917346,not17) {
var $z74227423 = D;
var $f74287429 = function(_) {
return R.isFunction(not17)?not17.app(anf_arg10917346):R.ffi.throwNonFunApp(L[575],not17,[anf_arg10917346]);
};
try {
if(--R.GAS > 0) {
$z74227423 = $f74287429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74287429,
"from":L[575]});
}
} catch($e74207421) {
if(R.isCont($e74207421)) {
var $ss74247425 = {"from":L[575],
"go":function(ann_DASH_check_DASH_temp10897430) {
return $Hann_DASH_check_DASH_temp22507431(ann_DASH_check_DASH_temp10897430);
}};
$e74207421.stack[R.EXN_STACKHEIGHT++] = $ss74247425;
}
if(R.isPyretException($e74207421)) {
$e74207421.pyretStack.push(L[575]);
}
throw $e74207421;
}
var $ret74267427 = $Hann_DASH_check_DASH_temp22507431($z74227423);
++R.GAS;
return $ret74267427;
};
var $Hann_DASH_check_DASH_temp22507431 = function(ann_DASH_check_DASH_temp10897430) {
return ann_DASH_check_DASH_temp10897430;
};
var $Hcases_DASH_val22497304 = function(cases_DASH_val1537303,acc3147290,key3157291,many109127,once107123,not17) {
var anf_fun10157442 = G(cases_DASH_val1537303,"_match",L[570]);
var anf_obj10487448 = R.makeFunction(function($underscore3167468,default3177469,$underscore3187470,repeated3197471,$underscore3207472) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[587],5,arguments);
}
var anf_fun10177483 = G(acc3147290,"has-key",L[589]);
var $z74757476 = D;
var $f74817482 = function(_) {
return R.isFunction(anf_fun10177483)?anf_fun10177483.app(key3157291):R.ffi.throwNonFunApp(L[588],anf_fun10177483,[key3157291]);
};
try {
if(--R.GAS > 0) {
$z74757476 = $f74817482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74817482,
"from":L[588]});
}
} catch($e74737474) {
if(R.isCont($e74737474)) {
var $ss74777478 = {"from":L[588],
"go":function(anf_arg10187484) {
return $Hanf_arg22397485(anf_arg10187484,acc3147290,default3177469,key3157291,many109127,once107123,repeated3197471,not17);
}};
$e74737474.stack[R.EXN_STACKHEIGHT++] = $ss74777478;
}
if(R.isPyretException($e74737474)) {
$e74737474.pyretStack.push(L[588]);
}
throw $e74737474;
}
var $ret74797480 = $Hanf_arg22397485($z74757476,acc3147290,default3177469,key3157291,many109127,once107123,repeated3197471,not17);
++R.GAS;
return $ret74797480;
});
var anf_obj10817449 = R.makeFunction(function($underscore3217450,default3227451,$underscore3237452,repeated3247453,$underscore3257454) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[584],5,arguments);
}
var anf_fun10507465 = G(acc3147290,"has-key",L[586]);
var $z74577458 = D;
var $f74637464 = function(_) {
return R.isFunction(anf_fun10507465)?anf_fun10507465.app(key3157291):R.ffi.throwNonFunApp(L[585],anf_fun10507465,[key3157291]);
};
try {
if(--R.GAS > 0) {
$z74577458 = $f74637464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74637464,
"from":L[585]});
}
} catch($e74557456) {
if(R.isCont($e74557456)) {
var $ss74597460 = {"from":L[585],
"go":function(anf_arg10517466) {
return $Hanf_arg22477467(anf_arg10517466,acc3147290,default3227451,key3157291,many109127,once107123,repeated3247453,not17);
}};
$e74557456.stack[R.EXN_STACKHEIGHT++] = $ss74597460;
}
if(R.isPyretException($e74557456)) {
$e74557456.pyretStack.push(L[585]);
}
throw $e74557456;
}
var $ret74617462 = $Hanf_arg22477467($z74577458,acc3147290,default3227451,key3157291,many109127,once107123,repeated3247453,not17);
++R.GAS;
return $ret74617462;
});
var anf_arg10827443 = R.makeObject({"next-val-default":anf_obj10487448,
"equals-val-default":anf_obj10817449});
var anf_arg10847444 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[570],0,arguments);
}
var ann_DASH_check_DASH_temp10837447 = acc3147290;
return ann_DASH_check_DASH_temp10837447;
});
var $z74347435 = D;
var $f74407441 = function(_) {
return R.isFunction(anf_fun10157442)?anf_fun10157442.app(anf_arg10827443,anf_arg10847444):R.ffi.throwNonFunApp(L[569],anf_fun10157442,[anf_arg10827443,anf_arg10847444]);
};
try {
if(--R.GAS > 0) {
$z74347435 = $f74407441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74407441,
"from":L[569]});
}
} catch($e74327433) {
if(R.isCont($e74327433)) {
var $ss74367437 = {"from":L[569],
"go":function(ann_DASH_check_DASH_temp10137445) {
return $Hann_DASH_check_DASH_temp22487446(ann_DASH_check_DASH_temp10137445);
}};
$e74327433.stack[R.EXN_STACKHEIGHT++] = $ss74367437;
}
if(R.isPyretException($e74327433)) {
$e74327433.pyretStack.push(L[569]);
}
throw $e74327433;
}
var $ret74387439 = $Hann_DASH_check_DASH_temp22487446($z74347435);
++R.GAS;
return $ret74387439;
};
var $Hann_DASH_check_DASH_temp22487446 = function(ann_DASH_check_DASH_temp10137445) {
return ann_DASH_check_DASH_temp10137445;
};
var $Hanf_arg22477467 = function(anf_arg10517466,acc3147290,default3227451,key3157291,many109127,once107123,repeated3247453,not17) {
var $z74887489 = D;
var $f74947495 = function(_) {
return R.isFunction(not17)?not17.app(anf_arg10517466):R.ffi.throwNonFunApp(L[590],not17,[anf_arg10517466]);
};
try {
if(--R.GAS > 0) {
$z74887489 = $f74947495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74947495,
"from":L[590]});
}
} catch($e74867487) {
if(R.isCont($e74867487)) {
var $ss74907491 = {"from":L[590],
"go":function(and_DASH_oper_DASH_1497496) {
return $Hand_DASH_oper_DASH_22467497(and_DASH_oper_DASH_1497496,acc3147290,default3227451,key3157291,many109127,once107123,repeated3247453);
}};
$e74867487.stack[R.EXN_STACKHEIGHT++] = $ss74907491;
}
if(R.isPyretException($e74867487)) {
$e74867487.pyretStack.push(L[590]);
}
throw $e74867487;
}
var $ret74927493 = $Hand_DASH_oper_DASH_22467497($z74887489,acc3147290,default3227451,key3157291,many109127,once107123,repeated3247453);
++R.GAS;
return $ret74927493;
};
var $Hand_DASH_oper_DASH_22467497 = function(and_DASH_oper_DASH_1497496,acc3147290,default3227451,key3157291,many109127,once107123,repeated3247453) {
var if_helper10527544 = R.makeFunction(function(if_helper_arg10537568) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[590],1,arguments);
}
var if_DASH_1487595 = if_helper_arg10537568;
var if_helper10547581 = R.makeFunction(function(if_helper_arg10557600) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[590],1,arguments);
}
var ann_DASH_check_DASH_temp10497601 = if_helper_arg10557600;
return ann_DASH_check_DASH_temp10497601;
});
var anf_if10587599 = R.isBoolean(if_DASH_1487595);
if(R.isPyretTrue(anf_if10587599)) {
if(R.isPyretTrue(if_DASH_1487595)) {
var anf_fun10607579 = G(acc3147290,"set",L[597]);
var $z75717572 = D;
var $f75777578 = function(_) {
return R.isFunction(anf_fun10607579)?anf_fun10607579.app(key3157291,default3227451):R.ffi.throwNonFunApp(L[596],anf_fun10607579,[key3157291,default3227451]);
};
try {
if(--R.GAS > 0) {
$z75717572 = $f75777578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75777578,
"from":L[596]});
}
} catch($e75697570) {
if(R.isCont($e75697570)) {
var $ss75737574 = {"from":L[596],
"go":function(cont_tail_arg10617580) {
return $Hcont_tail_arg22407582(cont_tail_arg10617580,if_helper10547581);
}};
$e75697570.stack[R.EXN_STACKHEIGHT++] = $ss75737574;
}
if(R.isPyretException($e75697570)) {
$e75697570.pyretStack.push(L[596]);
}
throw $e75697570;
}
var $ret75757576 = $Hcont_tail_arg22407582($z75717572,if_helper10547581);
++R.GAS;
return $ret75757576;
} else {
var $z75857586 = D;
var $f75917592 = function(_) {
return R.isFunction(if_helper10547581)?if_helper10547581.app(acc3147290):R.ffi.throwNonFunApp(L[598],if_helper10547581,[acc3147290]);
};
try {
if(--R.GAS > 0) {
$z75857586 = $f75917592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75917592,
"from":L[598]});
}
} catch($e75837584) {
if(R.isCont($e75837584)) {
var $ss75877588 = {"from":L[598],
"go":function(cont_tail_app10597593) {
return $Hcont_tail_app22417594(cont_tail_app10597593);
}};
$e75837584.stack[R.EXN_STACKHEIGHT++] = $ss75877588;
}
if(R.isPyretException($e75837584)) {
$e75837584.pyretStack.push(L[598]);
}
throw $e75837584;
}
var $ret75897590 = $Hcont_tail_app22417594($z75857586);
++R.GAS;
return $ret75897590;
}
} else {
var cont_tail_arg10567598 = R.throwNonBooleanCondition(L[590],("if"),if_DASH_1487595);
if(--R.GAS > 0) {
$z75967597 = R.isFunction(if_helper10547581)?if_helper10547581.app(cont_tail_arg10567598):R.ffi.throwNonFunApp(L[590],if_helper10547581,[cont_tail_arg10567598]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10547581)?if_helper10547581.app(cont_tail_arg10567598):R.ffi.throwNonFunApp(L[590],if_helper10547581,[cont_tail_arg10567598]);
},
"from":L[590]});
}
++R.GAS;
return $z75967597;
}
});
var anf_if10657567 = R.isBoolean(and_DASH_oper_DASH_1497496);
if(R.isPyretTrue(anf_if10657567)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1497496)) {
var or_DASH_oper_DASH_1517528 = R.equiv(repeated3247453,once107123.$var);
var if_helper10677508 = R.makeFunction(function(if_helper_arg10687533) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[591],1,arguments);
}
var and_DASH_oper_DASH_1507545 = if_helper_arg10687533;
var anf_if10717551 = R.isBoolean(and_DASH_oper_DASH_1507545);
if(R.isPyretTrue(anf_if10717551)) {
var $z75367537 = D;
var $f75427543 = function(_) {
return R.isFunction(if_helper10527544)?if_helper10527544.app(and_DASH_oper_DASH_1507545):R.ffi.throwNonFunApp(L[590],if_helper10527544,[and_DASH_oper_DASH_1507545]);
};
try {
if(--R.GAS > 0) {
$z75367537 = $f75427543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75427543,
"from":L[590]});
}
} catch($e75347535) {
if(R.isCont($e75347535)) {
var $ss75387539 = {"from":L[590],
"go":function(cont_tail_app10727546) {
return $Hcont_tail_app22427547(cont_tail_app10727546);
}};
$e75347535.stack[R.EXN_STACKHEIGHT++] = $ss75387539;
}
if(R.isPyretException($e75347535)) {
$e75347535.pyretStack.push(L[590]);
}
throw $e75347535;
}
var $ret75407541 = $Hcont_tail_app22427547($z75367537);
++R.GAS;
return $ret75407541;
} else {
var cont_tail_arg10697550 = R.throwNonBooleanOp(L[594],("second"),("and"),and_DASH_oper_DASH_1507545);
if(--R.GAS > 0) {
$z75487549 = R.isFunction(if_helper10527544)?if_helper10527544.app(cont_tail_arg10697550):R.ffi.throwNonFunApp(L[594],if_helper10527544,[cont_tail_arg10697550]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10527544)?if_helper10527544.app(cont_tail_arg10697550):R.ffi.throwNonFunApp(L[594],if_helper10527544,[cont_tail_arg10697550]);
},
"from":L[594]});
}
++R.GAS;
return $z75487549;
}
});
var anf_if10757532 = R.isBoolean(or_DASH_oper_DASH_1517528);
if(R.isPyretTrue(anf_if10757532)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1517528)) {
var $z75007501 = D;
var $f75067507 = function(_) {
return R.isFunction(if_helper10677508)?if_helper10677508.app((true)):R.ffi.throwNonFunApp(L[591],if_helper10677508,[(true)]);
};
try {
if(--R.GAS > 0) {
$z75007501 = $f75067507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75067507,
"from":L[591]});
}
} catch($e74987499) {
if(R.isCont($e74987499)) {
var $ss75027503 = {"from":L[591],
"go":function(cont_tail_app10807509) {
return $Hcont_tail_app22437510(cont_tail_app10807509);
}};
$e74987499.stack[R.EXN_STACKHEIGHT++] = $ss75027503;
}
if(R.isPyretException($e74987499)) {
$e74987499.pyretStack.push(L[591]);
}
throw $e74987499;
}
var $ret75047505 = $Hcont_tail_app22437510($z75007501);
++R.GAS;
return $ret75047505;
} else {
var or_DASH_oper_DASH_1527521 = R.equiv(repeated3247453,many109127.$var);
var anf_if10787527 = R.isBoolean(or_DASH_oper_DASH_1527521);
if(R.isPyretTrue(anf_if10787527)) {
var $z75137514 = D;
var $f75197520 = function(_) {
return R.isFunction(if_helper10677508)?if_helper10677508.app(or_DASH_oper_DASH_1527521):R.ffi.throwNonFunApp(L[591],if_helper10677508,[or_DASH_oper_DASH_1527521]);
};
try {
if(--R.GAS > 0) {
$z75137514 = $f75197520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75197520,
"from":L[591]});
}
} catch($e75117512) {
if(R.isCont($e75117512)) {
var $ss75157516 = {"from":L[591],
"go":function(cont_tail_app10797522) {
return $Hcont_tail_app22447523(cont_tail_app10797522);
}};
$e75117512.stack[R.EXN_STACKHEIGHT++] = $ss75157516;
}
if(R.isPyretException($e75117512)) {
$e75117512.pyretStack.push(L[591]);
}
throw $e75117512;
}
var $ret75177518 = $Hcont_tail_app22447523($z75137514);
++R.GAS;
return $ret75177518;
} else {
var cont_tail_arg10767526 = R.throwNonBooleanOp(L[592],("second"),("or"),or_DASH_oper_DASH_1527521);
if(--R.GAS > 0) {
$z75247525 = R.isFunction(if_helper10677508)?if_helper10677508.app(cont_tail_arg10767526):R.ffi.throwNonFunApp(L[592],if_helper10677508,[cont_tail_arg10767526]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10677508)?if_helper10677508.app(cont_tail_arg10767526):R.ffi.throwNonFunApp(L[592],if_helper10677508,[cont_tail_arg10767526]);
},
"from":L[592]});
}
++R.GAS;
return $z75247525;
}
}
} else {
var cont_tail_arg10737531 = R.throwNonBooleanOp(L[593],("first"),("or"),or_DASH_oper_DASH_1517528);
if(--R.GAS > 0) {
$z75297530 = R.isFunction(if_helper10677508)?if_helper10677508.app(cont_tail_arg10737531):R.ffi.throwNonFunApp(L[593],if_helper10677508,[cont_tail_arg10737531]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10677508)?if_helper10677508.app(cont_tail_arg10737531):R.ffi.throwNonFunApp(L[593],if_helper10677508,[cont_tail_arg10737531]);
},
"from":L[593]});
}
++R.GAS;
return $z75297530;
}
} else {
var $z75547555 = D;
var $f75607561 = function(_) {
return R.isFunction(if_helper10527544)?if_helper10527544.app((false)):R.ffi.throwNonFunApp(L[590],if_helper10527544,[(false)]);
};
try {
if(--R.GAS > 0) {
$z75547555 = $f75607561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75607561,
"from":L[590]});
}
} catch($e75527553) {
if(R.isCont($e75527553)) {
var $ss75567557 = {"from":L[590],
"go":function(cont_tail_app10667562) {
return $Hcont_tail_app22457563(cont_tail_app10667562);
}};
$e75527553.stack[R.EXN_STACKHEIGHT++] = $ss75567557;
}
if(R.isPyretException($e75527553)) {
$e75527553.pyretStack.push(L[590]);
}
throw $e75527553;
}
var $ret75587559 = $Hcont_tail_app22457563($z75547555);
++R.GAS;
return $ret75587559;
}
} else {
var cont_tail_arg10637566 = R.throwNonBooleanOp(L[595],("first"),("and"),and_DASH_oper_DASH_1497496);
if(--R.GAS > 0) {
$z75647565 = R.isFunction(if_helper10527544)?if_helper10527544.app(cont_tail_arg10637566):R.ffi.throwNonFunApp(L[595],if_helper10527544,[cont_tail_arg10637566]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10527544)?if_helper10527544.app(cont_tail_arg10637566):R.ffi.throwNonFunApp(L[595],if_helper10527544,[cont_tail_arg10637566]);
},
"from":L[595]});
}
++R.GAS;
return $z75647565;
}
};
var $Hcont_tail_app22437510 = function(cont_tail_app10807509) {
return cont_tail_app10807509;
};
var $Hcont_tail_app22447523 = function(cont_tail_app10797522) {
return cont_tail_app10797522;
};
var $Hcont_tail_app22427547 = function(cont_tail_app10727546) {
return cont_tail_app10727546;
};
var $Hcont_tail_app22457563 = function(cont_tail_app10667562) {
return cont_tail_app10667562;
};
var $Hcont_tail_arg22407582 = function(cont_tail_arg10617580,if_helper10547581) {
if(--R.GAS > 0) {
$z76027603 = R.isFunction(if_helper10547581)?if_helper10547581.app(cont_tail_arg10617580):R.ffi.throwNonFunApp(L[596],if_helper10547581,[cont_tail_arg10617580]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10547581)?if_helper10547581.app(cont_tail_arg10617580):R.ffi.throwNonFunApp(L[596],if_helper10547581,[cont_tail_arg10617580]);
},
"from":L[596]});
}
++R.GAS;
return $z76027603;
};
var $Hcont_tail_app22417594 = function(cont_tail_app10597593) {
return cont_tail_app10597593;
};
var $Hanf_arg22397485 = function(anf_arg10187484,acc3147290,default3177469,key3157291,many109127,once107123,repeated3197471,not17) {
var $z76067607 = D;
var $f76127613 = function(_) {
return R.isFunction(not17)?not17.app(anf_arg10187484):R.ffi.throwNonFunApp(L[599],not17,[anf_arg10187484]);
};
try {
if(--R.GAS > 0) {
$z76067607 = $f76127613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76127613,
"from":L[599]});
}
} catch($e76047605) {
if(R.isCont($e76047605)) {
var $ss76087609 = {"from":L[599],
"go":function(and_DASH_oper_DASH_1447614) {
return $Hand_DASH_oper_DASH_22387615(and_DASH_oper_DASH_1447614,acc3147290,default3177469,key3157291,many109127,once107123,repeated3197471);
}};
$e76047605.stack[R.EXN_STACKHEIGHT++] = $ss76087609;
}
if(R.isPyretException($e76047605)) {
$e76047605.pyretStack.push(L[599]);
}
throw $e76047605;
}
var $ret76107611 = $Hand_DASH_oper_DASH_22387615($z76067607,acc3147290,default3177469,key3157291,many109127,once107123,repeated3197471);
++R.GAS;
return $ret76107611;
};
var $Hand_DASH_oper_DASH_22387615 = function(and_DASH_oper_DASH_1447614,acc3147290,default3177469,key3157291,many109127,once107123,repeated3197471) {
var if_helper10197662 = R.makeFunction(function(if_helper_arg10207686) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[599],1,arguments);
}
var if_DASH_1437713 = if_helper_arg10207686;
var if_helper10217699 = R.makeFunction(function(if_helper_arg10227718) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[599],1,arguments);
}
var ann_DASH_check_DASH_temp10167719 = if_helper_arg10227718;
return ann_DASH_check_DASH_temp10167719;
});
var anf_if10257717 = R.isBoolean(if_DASH_1437713);
if(R.isPyretTrue(anf_if10257717)) {
if(R.isPyretTrue(if_DASH_1437713)) {
var anf_fun10277697 = G(acc3147290,"set",L[606]);
var $z76897690 = D;
var $f76957696 = function(_) {
return R.isFunction(anf_fun10277697)?anf_fun10277697.app(key3157291,default3177469):R.ffi.throwNonFunApp(L[605],anf_fun10277697,[key3157291,default3177469]);
};
try {
if(--R.GAS > 0) {
$z76897690 = $f76957696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76957696,
"from":L[605]});
}
} catch($e76877688) {
if(R.isCont($e76877688)) {
var $ss76917692 = {"from":L[605],
"go":function(cont_tail_arg10287698) {
return $Hcont_tail_arg22327700(cont_tail_arg10287698,if_helper10217699);
}};
$e76877688.stack[R.EXN_STACKHEIGHT++] = $ss76917692;
}
if(R.isPyretException($e76877688)) {
$e76877688.pyretStack.push(L[605]);
}
throw $e76877688;
}
var $ret76937694 = $Hcont_tail_arg22327700($z76897690,if_helper10217699);
++R.GAS;
return $ret76937694;
} else {
var $z77037704 = D;
var $f77097710 = function(_) {
return R.isFunction(if_helper10217699)?if_helper10217699.app(acc3147290):R.ffi.throwNonFunApp(L[607],if_helper10217699,[acc3147290]);
};
try {
if(--R.GAS > 0) {
$z77037704 = $f77097710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77097710,
"from":L[607]});
}
} catch($e77017702) {
if(R.isCont($e77017702)) {
var $ss77057706 = {"from":L[607],
"go":function(cont_tail_app10267711) {
return $Hcont_tail_app22337712(cont_tail_app10267711);
}};
$e77017702.stack[R.EXN_STACKHEIGHT++] = $ss77057706;
}
if(R.isPyretException($e77017702)) {
$e77017702.pyretStack.push(L[607]);
}
throw $e77017702;
}
var $ret77077708 = $Hcont_tail_app22337712($z77037704);
++R.GAS;
return $ret77077708;
}
} else {
var cont_tail_arg10237716 = R.throwNonBooleanCondition(L[599],("if"),if_DASH_1437713);
if(--R.GAS > 0) {
$z77147715 = R.isFunction(if_helper10217699)?if_helper10217699.app(cont_tail_arg10237716):R.ffi.throwNonFunApp(L[599],if_helper10217699,[cont_tail_arg10237716]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10217699)?if_helper10217699.app(cont_tail_arg10237716):R.ffi.throwNonFunApp(L[599],if_helper10217699,[cont_tail_arg10237716]);
},
"from":L[599]});
}
++R.GAS;
return $z77147715;
}
});
var anf_if10327685 = R.isBoolean(and_DASH_oper_DASH_1447614);
if(R.isPyretTrue(anf_if10327685)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1447614)) {
var or_DASH_oper_DASH_1467646 = R.equiv(repeated3197471,once107123.$var);
var if_helper10347626 = R.makeFunction(function(if_helper_arg10357651) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[600],1,arguments);
}
var and_DASH_oper_DASH_1457663 = if_helper_arg10357651;
var anf_if10387669 = R.isBoolean(and_DASH_oper_DASH_1457663);
if(R.isPyretTrue(anf_if10387669)) {
var $z76547655 = D;
var $f76607661 = function(_) {
return R.isFunction(if_helper10197662)?if_helper10197662.app(and_DASH_oper_DASH_1457663):R.ffi.throwNonFunApp(L[599],if_helper10197662,[and_DASH_oper_DASH_1457663]);
};
try {
if(--R.GAS > 0) {
$z76547655 = $f76607661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76607661,
"from":L[599]});
}
} catch($e76527653) {
if(R.isCont($e76527653)) {
var $ss76567657 = {"from":L[599],
"go":function(cont_tail_app10397664) {
return $Hcont_tail_app22347665(cont_tail_app10397664);
}};
$e76527653.stack[R.EXN_STACKHEIGHT++] = $ss76567657;
}
if(R.isPyretException($e76527653)) {
$e76527653.pyretStack.push(L[599]);
}
throw $e76527653;
}
var $ret76587659 = $Hcont_tail_app22347665($z76547655);
++R.GAS;
return $ret76587659;
} else {
var cont_tail_arg10367668 = R.throwNonBooleanOp(L[603],("second"),("and"),and_DASH_oper_DASH_1457663);
if(--R.GAS > 0) {
$z76667667 = R.isFunction(if_helper10197662)?if_helper10197662.app(cont_tail_arg10367668):R.ffi.throwNonFunApp(L[603],if_helper10197662,[cont_tail_arg10367668]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10197662)?if_helper10197662.app(cont_tail_arg10367668):R.ffi.throwNonFunApp(L[603],if_helper10197662,[cont_tail_arg10367668]);
},
"from":L[603]});
}
++R.GAS;
return $z76667667;
}
});
var anf_if10427650 = R.isBoolean(or_DASH_oper_DASH_1467646);
if(R.isPyretTrue(anf_if10427650)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1467646)) {
var $z76187619 = D;
var $f76247625 = function(_) {
return R.isFunction(if_helper10347626)?if_helper10347626.app((true)):R.ffi.throwNonFunApp(L[600],if_helper10347626,[(true)]);
};
try {
if(--R.GAS > 0) {
$z76187619 = $f76247625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76247625,
"from":L[600]});
}
} catch($e76167617) {
if(R.isCont($e76167617)) {
var $ss76207621 = {"from":L[600],
"go":function(cont_tail_app10477627) {
return $Hcont_tail_app22357628(cont_tail_app10477627);
}};
$e76167617.stack[R.EXN_STACKHEIGHT++] = $ss76207621;
}
if(R.isPyretException($e76167617)) {
$e76167617.pyretStack.push(L[600]);
}
throw $e76167617;
}
var $ret76227623 = $Hcont_tail_app22357628($z76187619);
++R.GAS;
return $ret76227623;
} else {
var or_DASH_oper_DASH_1477639 = R.equiv(repeated3197471,many109127.$var);
var anf_if10457645 = R.isBoolean(or_DASH_oper_DASH_1477639);
if(R.isPyretTrue(anf_if10457645)) {
var $z76317632 = D;
var $f76377638 = function(_) {
return R.isFunction(if_helper10347626)?if_helper10347626.app(or_DASH_oper_DASH_1477639):R.ffi.throwNonFunApp(L[600],if_helper10347626,[or_DASH_oper_DASH_1477639]);
};
try {
if(--R.GAS > 0) {
$z76317632 = $f76377638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76377638,
"from":L[600]});
}
} catch($e76297630) {
if(R.isCont($e76297630)) {
var $ss76337634 = {"from":L[600],
"go":function(cont_tail_app10467640) {
return $Hcont_tail_app22367641(cont_tail_app10467640);
}};
$e76297630.stack[R.EXN_STACKHEIGHT++] = $ss76337634;
}
if(R.isPyretException($e76297630)) {
$e76297630.pyretStack.push(L[600]);
}
throw $e76297630;
}
var $ret76357636 = $Hcont_tail_app22367641($z76317632);
++R.GAS;
return $ret76357636;
} else {
var cont_tail_arg10437644 = R.throwNonBooleanOp(L[601],("second"),("or"),or_DASH_oper_DASH_1477639);
if(--R.GAS > 0) {
$z76427643 = R.isFunction(if_helper10347626)?if_helper10347626.app(cont_tail_arg10437644):R.ffi.throwNonFunApp(L[601],if_helper10347626,[cont_tail_arg10437644]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10347626)?if_helper10347626.app(cont_tail_arg10437644):R.ffi.throwNonFunApp(L[601],if_helper10347626,[cont_tail_arg10437644]);
},
"from":L[601]});
}
++R.GAS;
return $z76427643;
}
}
} else {
var cont_tail_arg10407649 = R.throwNonBooleanOp(L[602],("first"),("or"),or_DASH_oper_DASH_1467646);
if(--R.GAS > 0) {
$z76477648 = R.isFunction(if_helper10347626)?if_helper10347626.app(cont_tail_arg10407649):R.ffi.throwNonFunApp(L[602],if_helper10347626,[cont_tail_arg10407649]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10347626)?if_helper10347626.app(cont_tail_arg10407649):R.ffi.throwNonFunApp(L[602],if_helper10347626,[cont_tail_arg10407649]);
},
"from":L[602]});
}
++R.GAS;
return $z76477648;
}
} else {
var $z76727673 = D;
var $f76787679 = function(_) {
return R.isFunction(if_helper10197662)?if_helper10197662.app((false)):R.ffi.throwNonFunApp(L[599],if_helper10197662,[(false)]);
};
try {
if(--R.GAS > 0) {
$z76727673 = $f76787679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76787679,
"from":L[599]});
}
} catch($e76707671) {
if(R.isCont($e76707671)) {
var $ss76747675 = {"from":L[599],
"go":function(cont_tail_app10337680) {
return $Hcont_tail_app22377681(cont_tail_app10337680);
}};
$e76707671.stack[R.EXN_STACKHEIGHT++] = $ss76747675;
}
if(R.isPyretException($e76707671)) {
$e76707671.pyretStack.push(L[599]);
}
throw $e76707671;
}
var $ret76767677 = $Hcont_tail_app22377681($z76727673);
++R.GAS;
return $ret76767677;
}
} else {
var cont_tail_arg10307684 = R.throwNonBooleanOp(L[604],("first"),("and"),and_DASH_oper_DASH_1447614);
if(--R.GAS > 0) {
$z76827683 = R.isFunction(if_helper10197662)?if_helper10197662.app(cont_tail_arg10307684):R.ffi.throwNonFunApp(L[604],if_helper10197662,[cont_tail_arg10307684]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10197662)?if_helper10197662.app(cont_tail_arg10307684):R.ffi.throwNonFunApp(L[604],if_helper10197662,[cont_tail_arg10307684]);
},
"from":L[604]});
}
++R.GAS;
return $z76827683;
}
};
var $Hcont_tail_app22357628 = function(cont_tail_app10477627) {
return cont_tail_app10477627;
};
var $Hcont_tail_app22367641 = function(cont_tail_app10467640) {
return cont_tail_app10467640;
};
var $Hcont_tail_app22347665 = function(cont_tail_app10397664) {
return cont_tail_app10397664;
};
var $Hcont_tail_app22377681 = function(cont_tail_app10337680) {
return cont_tail_app10337680;
};
var $Hcont_tail_arg22327700 = function(cont_tail_arg10287698,if_helper10217699) {
if(--R.GAS > 0) {
$z77207721 = R.isFunction(if_helper10217699)?if_helper10217699.app(cont_tail_arg10287698):R.ffi.throwNonFunApp(L[605],if_helper10217699,[cont_tail_arg10287698]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper10217699)?if_helper10217699.app(cont_tail_arg10287698):R.ffi.throwNonFunApp(L[605],if_helper10217699,[cont_tail_arg10287698]);
},
"from":L[605]});
}
++R.GAS;
return $z77207721;
};
var $Hcont_tail_app22337712 = function(cont_tail_app10267711) {
return cont_tail_app10267711;
};
var $Hif_DASH_22317218 = function(if_DASH_1427217,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,is_DASH_Param_127163,list2776,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var if_helper7187732 = R.makeFunction(function(if_helper_arg7197773) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[561],1,arguments);
}
var ann_DASH_check_DASH_temp7177774 = if_helper_arg7197773;
return ann_DASH_check_DASH_temp7177774;
});
var anf_if7227772 = R.isBoolean(if_DASH_1427217);
if(R.isPyretTrue(anf_if7227772)) {
if(R.isPyretTrue(if_DASH_1427217)) {
var $z77247725 = D;
var $f77307731 = function(_) {
return R.isFunction(if_helper7187732)?if_helper7187732.app(results2477204):R.ffi.throwNonFunApp(L[608],if_helper7187732,[results2477204]);
};
try {
if(--R.GAS > 0) {
$z77247725 = $f77307731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77307731,
"from":L[608]});
}
} catch($e77227723) {
if(R.isCont($e77227723)) {
var $ss77267727 = {"from":L[608],
"go":function(cont_tail_app10037733) {
return $Hcont_tail_app21127734(cont_tail_app10037733);
}};
$e77227723.stack[R.EXN_STACKHEIGHT++] = $ss77267727;
}
if(R.isPyretException($e77227723)) {
$e77227723.pyretStack.push(L[608]);
}
throw $e77227723;
}
var $ret77287729 = $Hcont_tail_app21127734($z77247725);
++R.GAS;
return $ret77287729;
} else {
var cases_DASH_val1417768 = remaining2497206;
var anf_fun7237745 = G(cases_DASH_val1417768,"_match",L[609]);
var anf_obj7257751 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[612],0,arguments);
}
var ann_DASH_check_DASH_temp7247767 = results2477204;
return ann_DASH_check_DASH_temp7247767;
});
var anf_obj9977752 = R.makeFunction(function(first2507753,more_DASH_args2517754) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[610],2,arguments);
}
var $z77577758 = D;
var $f77637764 = function(_) {
return R.isFunction(string_DASH_substring22)?string_DASH_substring22.app(first2507753,(0),(2)):R.ffi.throwNonFunApp(L[611],string_DASH_substring22,[first2507753,(0),(2)]);
};
try {
if(--R.GAS > 0) {
$z77577758 = $f77637764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77637764,
"from":L[611]});
}
} catch($e77557756) {
if(R.isCont($e77557756)) {
var $ss77597760 = {"from":L[611],
"go":function(anf_arg7277765) {
return $Hanf_arg22297766(anf_arg7277765,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
}};
$e77557756.stack[R.EXN_STACKHEIGHT++] = $ss77597760;
}
if(R.isPyretException($e77557756)) {
$e77557756.pyretStack.push(L[611]);
}
throw $e77557756;
}
var $ret77617762 = $Hanf_arg22297766($z77577758,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret77617762;
});
var anf_arg9987746 = R.makeObject({"empty":anf_obj7257751,
"link":anf_obj9977752});
var anf_arg10007747 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[609],0,arguments);
}
var ann_DASH_check_DASH_temp9997750 = R.throwNoBranchesMatched(L[609],("cases"));
return ann_DASH_check_DASH_temp9997750;
});
var $z77377738 = D;
var $f77437744 = function(_) {
return R.isFunction(anf_fun7237745)?anf_fun7237745.app(anf_arg9987746,anf_arg10007747):R.ffi.throwNonFunApp(L[609],anf_fun7237745,[anf_arg9987746,anf_arg10007747]);
};
try {
if(--R.GAS > 0) {
$z77377738 = $f77437744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77437744,
"from":L[609]});
}
} catch($e77357736) {
if(R.isCont($e77357736)) {
var $ss77397740 = {"from":L[609],
"go":function(cont_tail_arg10017748) {
return $Hcont_tail_arg22307749(cont_tail_arg10017748,if_helper7187732);
}};
$e77357736.stack[R.EXN_STACKHEIGHT++] = $ss77397740;
}
if(R.isPyretException($e77357736)) {
$e77357736.pyretStack.push(L[609]);
}
throw $e77357736;
}
var $ret77417742 = $Hcont_tail_arg22307749($z77377738,if_helper7187732);
++R.GAS;
return $ret77417742;
}
} else {
var cont_tail_arg7207771 = R.throwNonBooleanCondition(L[561],("if"),if_DASH_1427217);
if(--R.GAS > 0) {
$z77697770 = R.isFunction(if_helper7187732)?if_helper7187732.app(cont_tail_arg7207771):R.ffi.throwNonFunApp(L[561],if_helper7187732,[cont_tail_arg7207771]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7187732)?if_helper7187732.app(cont_tail_arg7207771):R.ffi.throwNonFunApp(L[561],if_helper7187732,[cont_tail_arg7207771]);
},
"from":L[561]});
}
++R.GAS;
return $z77697770;
}
};
var $Hcont_tail_app21127734 = function(cont_tail_app10037733) {
return cont_tail_app10037733;
};
var $Hcont_tail_arg22307749 = function(cont_tail_arg10017748,if_helper7187732) {
if(--R.GAS > 0) {
$z77757776 = R.isFunction(if_helper7187732)?if_helper7187732.app(cont_tail_arg10017748):R.ffi.throwNonFunApp(L[609],if_helper7187732,[cont_tail_arg10017748]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7187732)?if_helper7187732.app(cont_tail_arg10017748):R.ffi.throwNonFunApp(L[609],if_helper7187732,[cont_tail_arg10017748]);
},
"from":L[609]});
}
++R.GAS;
return $z77757776;
};
var $Hanf_arg22297766 = function(anf_arg7277765,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22) {
var if_DASH_1247802 = R.equiv(anf_arg7277765,("--"));
var if_helper7287788 = R.makeFunction(function(if_helper_arg7297807) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[615],1,arguments);
}
var ann_DASH_check_DASH_temp7267808 = if_helper_arg7297807;
return ann_DASH_check_DASH_temp7267808;
});
var anf_if7327806 = R.isBoolean(if_DASH_1247802);
if(R.isPyretTrue(anf_if7327806)) {
if(R.isPyretTrue(if_DASH_1247802)) {
var $z77797780 = D;
var $f77857786 = function(_) {
return R.isFunction(string_DASH_length20)?string_DASH_length20.app(first2507753):R.ffi.throwNonFunApp(L[613],string_DASH_length20,[first2507753]);
};
try {
if(--R.GAS > 0) {
$z77797780 = $f77857786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77857786,
"from":L[613]});
}
} catch($e77777778) {
if(R.isCont($e77777778)) {
var $ss77817782 = {"from":L[613],
"go":function(anf_arg8067787) {
return $Hanf_arg21957789(anf_arg8067787,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19,string_DASH_split21,string_DASH_substring22);
}};
$e77777778.stack[R.EXN_STACKHEIGHT++] = $ss77817782;
}
if(R.isPyretException($e77777778)) {
$e77777778.pyretStack.push(L[613]);
}
throw $e77777778;
}
var $ret77837784 = $Hanf_arg21957789($z77797780,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19,string_DASH_split21,string_DASH_substring22);
++R.GAS;
return $ret77837784;
} else {
var $z77927793 = D;
var $f77987799 = function(_) {
return R.isFunction(string_DASH_substring22)?string_DASH_substring22.app(first2507753,(0),(1)):R.ffi.throwNonFunApp(L[614],string_DASH_substring22,[first2507753,(0),(1)]);
};
try {
if(--R.GAS > 0) {
$z77927793 = $f77987799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77987799,
"from":L[614]});
}
} catch($e77907791) {
if(R.isCont($e77907791)) {
var $ss77947795 = {"from":L[614],
"go":function(anf_arg7337800) {
return $Hanf_arg22287801(anf_arg7337800,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_length20,string_DASH_substring22);
}};
$e77907791.stack[R.EXN_STACKHEIGHT++] = $ss77947795;
}
if(R.isPyretException($e77907791)) {
$e77907791.pyretStack.push(L[614]);
}
throw $e77907791;
}
var $ret77967797 = $Hanf_arg22287801($z77927793,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_length20,string_DASH_substring22);
++R.GAS;
return $ret77967797;
}
} else {
var cont_tail_arg7307805 = R.throwNonBooleanCondition(L[615],("if"),if_DASH_1247802);
if(--R.GAS > 0) {
$z78037804 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7307805):R.ffi.throwNonFunApp(L[615],if_helper7287788,[cont_tail_arg7307805]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7307805):R.ffi.throwNonFunApp(L[615],if_helper7287788,[cont_tail_arg7307805]);
},
"from":L[615]});
}
++R.GAS;
return $z78037804;
}
};
var $Hanf_arg21957789 = function(anf_arg8067787,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19,string_DASH_split21,string_DASH_substring22) {
var $z78117812 = D;
var $f78177818 = function(_) {
return R.isFunction(string_DASH_substring22)?string_DASH_substring22.app(first2507753,(2),anf_arg8067787):R.ffi.throwNonFunApp(L[616],string_DASH_substring22,[first2507753,(2),anf_arg8067787]);
};
try {
if(--R.GAS > 0) {
$z78117812 = $f78177818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78177818,
"from":L[616]});
}
} catch($e78097810) {
if(R.isCont($e78097810)) {
var $ss78137814 = {"from":L[616],
"go":function(anf_arg8077819) {
return $Hanf_arg21947820(anf_arg8077819,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19,string_DASH_split21);
}};
$e78097810.stack[R.EXN_STACKHEIGHT++] = $ss78137814;
}
if(R.isPyretException($e78097810)) {
$e78097810.pyretStack.push(L[616]);
}
throw $e78097810;
}
var $ret78157816 = $Hanf_arg21947820($z78117812,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19,string_DASH_split21);
++R.GAS;
return $ret78157816;
};
var $Hanf_arg21947820 = function(anf_arg8077819,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19,string_DASH_split21) {
var $z78237824 = D;
var $f78297830 = function(_) {
return R.isFunction(string_DASH_split21)?string_DASH_split21.app(anf_arg8077819,("="),(false)):R.ffi.throwNonFunApp(L[617],string_DASH_split21,[anf_arg8077819,("="),(false)]);
};
try {
if(--R.GAS > 0) {
$z78237824 = $f78297830();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78297830,
"from":L[617]});
}
} catch($e78217822) {
if(R.isCont($e78217822)) {
var $ss78257826 = {"from":L[617],
"go":function(key_DASH_parts2527831) {
return $Hkey_DASH_parts21937832(key_DASH_parts2527831,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19);
}};
$e78217822.stack[R.EXN_STACKHEIGHT++] = $ss78257826;
}
if(R.isPyretException($e78217822)) {
$e78217822.pyretStack.push(L[617]);
}
throw $e78217822;
}
var $ret78277828 = $Hkey_DASH_parts21937832($z78237824,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19);
++R.GAS;
return $ret78277828;
};
var $Hkey_DASH_parts21937832 = function(key_DASH_parts2527831,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19) {
var key2537844 = G(key_DASH_parts2527831,"first",L[620]);
var anf_fun8087843 = G(full_DASH_options2347053,"has-key",L[619]);
var $z78357836 = D;
var $f78417842 = function(_) {
return R.isFunction(anf_fun8087843)?anf_fun8087843.app(key2537844):R.ffi.throwNonFunApp(L[618],anf_fun8087843,[key2537844]);
};
try {
if(--R.GAS > 0) {
$z78357836 = $f78417842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78417842,
"from":L[618]});
}
} catch($e78337834) {
if(R.isCont($e78337834)) {
var $ss78377838 = {"from":L[618],
"go":function(if_DASH_1257845) {
return $Hif_DASH_21927846(if_DASH_1257845,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,key_DASH_parts2527831,key2537844,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19);
}};
$e78337834.stack[R.EXN_STACKHEIGHT++] = $ss78377838;
}
if(R.isPyretException($e78337834)) {
$e78337834.pyretStack.push(L[618]);
}
throw $e78337834;
}
var $ret78397840 = $Hif_DASH_21927846($z78357836,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,key_DASH_parts2527831,key2537844,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19);
++R.GAS;
return $ret78397840;
};
var $Hif_DASH_21927846 = function(if_DASH_1257845,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,key_DASH_parts2527831,key2537844,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19) {
var anf_if8117875 = R.isBoolean(if_DASH_1257845);
if(R.isPyretTrue(anf_if8117875)) {
if(R.isPyretTrue(if_DASH_1257845)) {
var anf_fun8157857 = G(full_DASH_options2347053,"get",L[622]);
var $z78497850 = D;
var $f78557856 = function(_) {
return R.isFunction(anf_fun8157857)?anf_fun8157857.app(key2537844):R.ffi.throwNonFunApp(L[621],anf_fun8157857,[key2537844]);
};
try {
if(--R.GAS > 0) {
$z78497850 = $f78557856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78557856,
"from":L[621]});
}
} catch($e78477848) {
if(R.isCont($e78477848)) {
var $ss78517852 = {"from":L[621],
"go":function(cases_DASH_val1407858) {
return $Hcases_DASH_val21897859(cases_DASH_val1407858,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper7287788,key_DASH_parts2527831,key2537844,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19);
}};
$e78477848.stack[R.EXN_STACKHEIGHT++] = $ss78517852;
}
if(R.isPyretException($e78477848)) {
$e78477848.pyretStack.push(L[621]);
}
throw $e78477848;
}
var $ret78537854 = $Hcases_DASH_val21897859($z78497850,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper7287788,key_DASH_parts2527831,key2537844,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19);
++R.GAS;
return $ret78537854;
} else {
var $z78627863 = D;
var $f78687869 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Unknown command line option --"),key2537844):R.ffi.throwNonFunApp(L[623],_plus13,[("Unknown command line option --"),key2537844]);
};
try {
if(--R.GAS > 0) {
$z78627863 = $f78687869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78687869,
"from":L[623]});
}
} catch($e78607861) {
if(R.isCont($e78607861)) {
var $ss78647865 = {"from":L[623],
"go":function(anf_arg8127870) {
return $Hanf_arg21917871(anf_arg8127870,arg_DASH_error102113,if_helper7287788,results2477204);
}};
$e78607861.stack[R.EXN_STACKHEIGHT++] = $ss78647865;
}
if(R.isPyretException($e78607861)) {
$e78607861.pyretStack.push(L[623]);
}
throw $e78607861;
}
var $ret78667867 = $Hanf_arg21917871($z78627863,arg_DASH_error102113,if_helper7287788,results2477204);
++R.GAS;
return $ret78667867;
}
} else {
var cont_tail_arg8097874 = R.throwNonBooleanCondition(L[618],("if"),if_DASH_1257845);
if(--R.GAS > 0) {
$z78727873 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg8097874):R.ffi.throwNonFunApp(L[618],if_helper7287788,[cont_tail_arg8097874]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg8097874):R.ffi.throwNonFunApp(L[618],if_helper7287788,[cont_tail_arg8097874]);
},
"from":L[618]});
}
++R.GAS;
return $z78727873;
}
};
var $Hcases_DASH_val21897859 = function(cases_DASH_val1407858,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper7287788,key_DASH_parts2527831,key2537844,list2776,more_DASH_args2517754,process2467189,results2477204,_plus13,string_DASH_char_DASH_at19) {
var anf_fun8167886 = G(cases_DASH_val1407858,"_match",L[621]);
var anf_obj8427904 = R.makeFunction(function(parser2548121,repeated2558122,$underscore2568123) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[658],3,arguments);
}
var cases_DASH_val1278171 = G(key_DASH_parts2527831,"rest",L[667]);
var anf_fun8188134 = G(cases_DASH_val1278171,"_match",L[659]);
var anf_obj8258140 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[663],0,arguments);
}
var anf_fun8208169 = G(list2776,"make",L[666]);
var anf_fun8218167 = G(parser2548121,"parse-string",L[665]);
var $z81598160 = D;
var $f81658166 = function(_) {
return R.isFunction(anf_fun8218167)?anf_fun8218167.app():R.ffi.throwNonFunApp(L[664],anf_fun8218167,[]);
};
try {
if(--R.GAS > 0) {
$z81598160 = $f81658166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81658166,
"from":L[664]});
}
} catch($e81578158) {
if(R.isCont($e81578158)) {
var $ss81618162 = {"from":L[664],
"go":function(anf_array_val8228168) {
return $Hanf_array_val21168170(anf_array_val8228168,anf_fun8208169,arg_DASH_error102113,format7872,key2537844,results2477204);
}};
$e81578158.stack[R.EXN_STACKHEIGHT++] = $ss81618162;
}
if(R.isPyretException($e81578158)) {
$e81578158.pyretStack.push(L[664]);
}
throw $e81578158;
}
var $ret81638164 = $Hanf_array_val21168170($z81598160,anf_fun8208169,arg_DASH_error102113,format7872,key2537844,results2477204);
++R.GAS;
return $ret81638164;
});
var anf_obj8388141 = R.makeFunction(function(val2578142,$underscore2588143) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[660],2,arguments);
}
var anf_fun8278154 = G(parser2548121,"parse",L[662]);
var $z81468147 = D;
var $f81528153 = function(_) {
return R.isFunction(anf_fun8278154)?anf_fun8278154.app(cur_DASH_index2487205,key2537844,val2578142):R.ffi.throwNonFunApp(L[661],anf_fun8278154,[cur_DASH_index2487205,key2537844,val2578142]);
};
try {
if(--R.GAS > 0) {
$z81468147 = $f81528153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81528153,
"from":L[661]});
}
} catch($e81448145) {
if(R.isCont($e81448145)) {
var $ss81488149 = {"from":L[661],
"go":function(parsed_DASH_val2598155) {
return $Hparsed_DASH_val21228156(parsed_DASH_val2598155,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,process2467189,repeated2558122,results2477204,_plus13);
}};
$e81448145.stack[R.EXN_STACKHEIGHT++] = $ss81488149;
}
if(R.isPyretException($e81448145)) {
$e81448145.pyretStack.push(L[661]);
}
throw $e81448145;
}
var $ret81508151 = $Hparsed_DASH_val21228156($z81468147,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,process2467189,repeated2558122,results2477204,_plus13);
++R.GAS;
return $ret81508151;
});
var anf_arg8398135 = R.makeObject({"empty":anf_obj8258140,
"link":anf_obj8388141});
var anf_arg8418136 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[659],0,arguments);
}
var ann_DASH_check_DASH_temp8408139 = R.throwNoBranchesMatched(L[659],("cases"));
return ann_DASH_check_DASH_temp8408139;
});
var $z81268127 = D;
var $f81328133 = function(_) {
return R.isFunction(anf_fun8188134)?anf_fun8188134.app(anf_arg8398135,anf_arg8418136):R.ffi.throwNonFunApp(L[658],anf_fun8188134,[anf_arg8398135,anf_arg8418136]);
};
try {
if(--R.GAS > 0) {
$z81268127 = $f81328133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81328133,
"from":L[658]});
}
} catch($e81248125) {
if(R.isCont($e81248125)) {
var $ss81288129 = {"from":L[658],
"go":function(ann_DASH_check_DASH_temp8178137) {
return $Hann_DASH_check_DASH_temp21238138(ann_DASH_check_DASH_temp8178137);
}};
$e81248125.stack[R.EXN_STACKHEIGHT++] = $ss81288129;
}
if(R.isPyretException($e81248125)) {
$e81248125.pyretStack.push(L[658]);
}
throw $e81248125;
}
var $ret81308131 = $Hann_DASH_check_DASH_temp21238138($z81268127);
++R.GAS;
return $ret81308131;
});
var anf_obj8657905 = R.makeFunction(function(parser2628070,default2638071,$underscore2648072,repeated2658073,$underscore2668074) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[650],5,arguments);
}
var cases_DASH_val1298120 = G(key_DASH_parts2527831,"rest",L[657]);
var anf_fun8448085 = G(cases_DASH_val1298120,"_match",L[651]);
var anf_obj8488091 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[655],0,arguments);
}
var $z81108111 = D;
var $f81168117 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2658073,key2537844,default2638071):R.ffi.throwNonFunApp(L[656],handle_DASH_repeated2367037.$var,[results2477204,repeated2658073,key2537844,default2638071]);
};
try {
if(--R.GAS > 0) {
$z81108111 = $f81168117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81168117,
"from":L[656]});
}
} catch($e81088109) {
if(R.isCont($e81088109)) {
var $ss81128113 = {"from":L[656],
"go":function(anf_arg8468118) {
return $Hanf_arg21268119(anf_arg8468118,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
}};
$e81088109.stack[R.EXN_STACKHEIGHT++] = $ss81128113;
}
if(R.isPyretException($e81088109)) {
$e81088109.pyretStack.push(L[656]);
}
throw $e81088109;
}
var $ret81148115 = $Hanf_arg21268119($z81108111,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
++R.GAS;
return $ret81148115;
});
var anf_obj8618092 = R.makeFunction(function(val2678093,$underscore2688094) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[652],2,arguments);
}
var anf_fun8508105 = G(parser2628070,"parse",L[654]);
var $z80978098 = D;
var $f81038104 = function(_) {
return R.isFunction(anf_fun8508105)?anf_fun8508105.app(cur_DASH_index2487205,key2537844,val2678093):R.ffi.throwNonFunApp(L[653],anf_fun8508105,[cur_DASH_index2487205,key2537844,val2678093]);
};
try {
if(--R.GAS > 0) {
$z80978098 = $f81038104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81038104,
"from":L[653]});
}
} catch($e80958096) {
if(R.isCont($e80958096)) {
var $ss80998100 = {"from":L[653],
"go":function(parsed_DASH_val2698106) {
return $Hparsed_DASH_val21328107(parsed_DASH_val2698106,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,process2467189,repeated2658073,results2477204,_plus13);
}};
$e80958096.stack[R.EXN_STACKHEIGHT++] = $ss80998100;
}
if(R.isPyretException($e80958096)) {
$e80958096.pyretStack.push(L[653]);
}
throw $e80958096;
}
var $ret81018102 = $Hparsed_DASH_val21328107($z80978098,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,process2467189,repeated2658073,results2477204,_plus13);
++R.GAS;
return $ret81018102;
});
var anf_arg8628086 = R.makeObject({"empty":anf_obj8488091,
"link":anf_obj8618092});
var anf_arg8648087 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[651],0,arguments);
}
var ann_DASH_check_DASH_temp8638090 = R.throwNoBranchesMatched(L[651],("cases"));
return ann_DASH_check_DASH_temp8638090;
});
var $z80778078 = D;
var $f80838084 = function(_) {
return R.isFunction(anf_fun8448085)?anf_fun8448085.app(anf_arg8628086,anf_arg8648087):R.ffi.throwNonFunApp(L[650],anf_fun8448085,[anf_arg8628086,anf_arg8648087]);
};
try {
if(--R.GAS > 0) {
$z80778078 = $f80838084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80838084,
"from":L[650]});
}
} catch($e80758076) {
if(R.isCont($e80758076)) {
var $ss80798080 = {"from":L[650],
"go":function(ann_DASH_check_DASH_temp8438088) {
return $Hann_DASH_check_DASH_temp21338089(ann_DASH_check_DASH_temp8438088);
}};
$e80758076.stack[R.EXN_STACKHEIGHT++] = $ss80798080;
}
if(R.isPyretException($e80758076)) {
$e80758076.pyretStack.push(L[650]);
}
throw $e80758076;
}
var $ret80818082 = $Hann_DASH_check_DASH_temp21338089($z80778078);
++R.GAS;
return $ret80818082;
});
var anf_obj9317906 = R.makeFunction(function(parser2727989,repeated2737990,$underscore2747991) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[636],3,arguments);
}
var cases_DASH_val1348069 = G(key_DASH_parts2527831,"rest",L[649]);
var anf_fun8678002 = G(cases_DASH_val1348069,"_match",L[637]);
var anf_obj9208021 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[641],0,arguments);
}
var cases_DASH_val1338068 = more_DASH_args2517754;
var anf_fun8698032 = G(cases_DASH_val1338068,"_match",L[642]);
var anf_obj8768038 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[645],0,arguments);
}
var anf_fun8718066 = G(list2776,"make",L[648]);
var anf_fun8728064 = G(parser2727989,"parse-string",L[647]);
var $z80568057 = D;
var $f80628063 = function(_) {
return R.isFunction(anf_fun8728064)?anf_fun8728064.app():R.ffi.throwNonFunApp(L[646],anf_fun8728064,[]);
};
try {
if(--R.GAS > 0) {
$z80568057 = $f80628063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80628063,
"from":L[646]});
}
} catch($e80548055) {
if(R.isCont($e80548055)) {
var $ss80588059 = {"from":L[646],
"go":function(anf_array_val8738065) {
return $Hanf_array_val21378067(anf_array_val8738065,anf_fun8718066,arg_DASH_error102113,format7872,key2537844,results2477204);
}};
$e80548055.stack[R.EXN_STACKHEIGHT++] = $ss80588059;
}
if(R.isPyretException($e80548055)) {
$e80548055.pyretStack.push(L[646]);
}
throw $e80548055;
}
var $ret80608061 = $Hanf_array_val21378067($z80568057,anf_fun8718066,arg_DASH_error102113,format7872,key2537844,results2477204);
++R.GAS;
return $ret80608061;
});
var anf_obj9168039 = R.makeFunction(function(val2758040,rest2768041) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[643],2,arguments);
}
var $z80448045 = D;
var $f80508051 = function(_) {
return R.isFunction(string_DASH_char_DASH_at19)?string_DASH_char_DASH_at19.app(val2758040,(0)):R.ffi.throwNonFunApp(L[644],string_DASH_char_DASH_at19,[val2758040,(0)]);
};
try {
if(--R.GAS > 0) {
$z80448045 = $f80508051();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80508051,
"from":L[644]});
}
} catch($e80428043) {
if(R.isCont($e80428043)) {
var $ss80468047 = {"from":L[644],
"go":function(anf_arg8788052) {
return $Hanf_arg21548053(anf_arg8788052,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,key2537844,list2776,parser2727989,process2467189,repeated2737990,rest2768041,results2477204,val2758040,_plus13);
}};
$e80428043.stack[R.EXN_STACKHEIGHT++] = $ss80468047;
}
if(R.isPyretException($e80428043)) {
$e80428043.pyretStack.push(L[644]);
}
throw $e80428043;
}
var $ret80488049 = $Hanf_arg21548053($z80448045,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,key2537844,list2776,parser2727989,process2467189,repeated2737990,rest2768041,results2477204,val2758040,_plus13);
++R.GAS;
return $ret80488049;
});
var anf_arg9178033 = R.makeObject({"empty":anf_obj8768038,
"link":anf_obj9168039});
var anf_arg9198034 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[642],0,arguments);
}
var ann_DASH_check_DASH_temp9188037 = R.throwNoBranchesMatched(L[642],("cases"));
return ann_DASH_check_DASH_temp9188037;
});
var $z80248025 = D;
var $f80308031 = function(_) {
return R.isFunction(anf_fun8698032)?anf_fun8698032.app(anf_arg9178033,anf_arg9198034):R.ffi.throwNonFunApp(L[641],anf_fun8698032,[anf_arg9178033,anf_arg9198034]);
};
try {
if(--R.GAS > 0) {
$z80248025 = $f80308031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80308031,
"from":L[641]});
}
} catch($e80228023) {
if(R.isCont($e80228023)) {
var $ss80268027 = {"from":L[641],
"go":function(ann_DASH_check_DASH_temp8688035) {
return $Hann_DASH_check_DASH_temp21558036(ann_DASH_check_DASH_temp8688035);
}};
$e80228023.stack[R.EXN_STACKHEIGHT++] = $ss80268027;
}
if(R.isPyretException($e80228023)) {
$e80228023.pyretStack.push(L[641]);
}
throw $e80228023;
}
var $ret80288029 = $Hann_DASH_check_DASH_temp21558036($z80248025);
++R.GAS;
return $ret80288029;
});
var anf_arg9218003 = R.makeObject({"empty":anf_obj9208021});
var anf_arg9308004 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[637],0,arguments);
}
var anf_fun9238019 = G(list2776,"make",L[640]);
var anf_fun9248017 = G(parser2727989,"parse-string",L[639]);
var $z80098010 = D;
var $f80158016 = function(_) {
return R.isFunction(anf_fun9248017)?anf_fun9248017.app():R.ffi.throwNonFunApp(L[638],anf_fun9248017,[]);
};
try {
if(--R.GAS > 0) {
$z80098010 = $f80158016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80158016,
"from":L[638]});
}
} catch($e80078008) {
if(R.isCont($e80078008)) {
var $ss80118012 = {"from":L[638],
"go":function(anf_array_val9258018) {
return $Hanf_array_val21608020(anf_array_val9258018,anf_fun9238019,arg_DASH_error102113,format7872,key2537844,parser2727989,results2477204);
}};
$e80078008.stack[R.EXN_STACKHEIGHT++] = $ss80118012;
}
if(R.isPyretException($e80078008)) {
$e80078008.pyretStack.push(L[638]);
}
throw $e80078008;
}
var $ret80138014 = $Hanf_array_val21608020($z80098010,anf_fun9238019,arg_DASH_error102113,format7872,key2537844,parser2727989,results2477204);
++R.GAS;
return $ret80138014;
});
var $z79947995 = D;
var $f80008001 = function(_) {
return R.isFunction(anf_fun8678002)?anf_fun8678002.app(anf_arg9218003,anf_arg9308004):R.ffi.throwNonFunApp(L[636],anf_fun8678002,[anf_arg9218003,anf_arg9308004]);
};
try {
if(--R.GAS > 0) {
$z79947995 = $f80008001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80008001,
"from":L[636]});
}
} catch($e79927993) {
if(R.isCont($e79927993)) {
var $ss79967997 = {"from":L[636],
"go":function(ann_DASH_check_DASH_temp8668005) {
return $Hann_DASH_check_DASH_temp21618006(ann_DASH_check_DASH_temp8668005);
}};
$e79927993.stack[R.EXN_STACKHEIGHT++] = $ss79967997;
}
if(R.isPyretException($e79927993)) {
$e79927993.pyretStack.push(L[636]);
}
throw $e79927993;
}
var $ret79987999 = $Hann_DASH_check_DASH_temp21618006($z79947995);
++R.GAS;
return $ret79987999;
});
var anf_obj9887907 = R.makeFunction(function(parser2837908,default2847909,$underscore2857910,repeated2867911,$underscore2877912) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[625],5,arguments);
}
var cases_DASH_val1397988 = G(key_DASH_parts2527831,"rest",L[635]);
var anf_fun9337923 = G(cases_DASH_val1397988,"_match",L[626]);
var anf_obj9777942 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[630],0,arguments);
}
var cases_DASH_val1387987 = more_DASH_args2517754;
var anf_fun9357953 = G(cases_DASH_val1387987,"_match",L[631]);
var anf_obj9377959 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[634],0,arguments);
}
var $z79777978 = D;
var $f79837984 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2867911,key2537844,default2847909):R.ffi.throwNonFunApp(L[634],handle_DASH_repeated2367037.$var,[results2477204,repeated2867911,key2537844,default2847909]);
};
try {
if(--R.GAS > 0) {
$z79777978 = $f79837984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79837984,
"from":L[634]});
}
} catch($e79757976) {
if(R.isCont($e79757976)) {
var $ss79797980 = {"from":L[634],
"go":function(ann_DASH_check_DASH_temp9367985) {
return $Hann_DASH_check_DASH_temp21627986(ann_DASH_check_DASH_temp9367985);
}};
$e79757976.stack[R.EXN_STACKHEIGHT++] = $ss79797980;
}
if(R.isPyretException($e79757976)) {
$e79757976.pyretStack.push(L[634]);
}
throw $e79757976;
}
var $ret79817982 = $Hann_DASH_check_DASH_temp21627986($z79777978);
++R.GAS;
return $ret79817982;
});
var anf_obj9737960 = R.makeFunction(function(val2887961,rest2897962) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[632],2,arguments);
}
var $z79657966 = D;
var $f79717972 = function(_) {
return R.isFunction(string_DASH_char_DASH_at19)?string_DASH_char_DASH_at19.app(val2887961,(0)):R.ffi.throwNonFunApp(L[633],string_DASH_char_DASH_at19,[val2887961,(0)]);
};
try {
if(--R.GAS > 0) {
$z79657966 = $f79717972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79717972,
"from":L[633]});
}
} catch($e79637964) {
if(R.isCont($e79637964)) {
var $ss79677968 = {"from":L[633],
"go":function(anf_arg9397973) {
return $Hanf_arg21777974(anf_arg9397973,arg_DASH_error102113,cur_DASH_index2487205,default2847909,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,parser2837908,process2467189,repeated2867911,rest2897962,results2477204,val2887961,_plus13);
}};
$e79637964.stack[R.EXN_STACKHEIGHT++] = $ss79677968;
}
if(R.isPyretException($e79637964)) {
$e79637964.pyretStack.push(L[633]);
}
throw $e79637964;
}
var $ret79697970 = $Hanf_arg21777974($z79657966,arg_DASH_error102113,cur_DASH_index2487205,default2847909,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,parser2837908,process2467189,repeated2867911,rest2897962,results2477204,val2887961,_plus13);
++R.GAS;
return $ret79697970;
});
var anf_arg9747954 = R.makeObject({"empty":anf_obj9377959,
"link":anf_obj9737960});
var anf_arg9767955 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[631],0,arguments);
}
var ann_DASH_check_DASH_temp9757958 = R.throwNoBranchesMatched(L[631],("cases"));
return ann_DASH_check_DASH_temp9757958;
});
var $z79457946 = D;
var $f79517952 = function(_) {
return R.isFunction(anf_fun9357953)?anf_fun9357953.app(anf_arg9747954,anf_arg9767955):R.ffi.throwNonFunApp(L[630],anf_fun9357953,[anf_arg9747954,anf_arg9767955]);
};
try {
if(--R.GAS > 0) {
$z79457946 = $f79517952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79517952,
"from":L[630]});
}
} catch($e79437944) {
if(R.isCont($e79437944)) {
var $ss79477948 = {"from":L[630],
"go":function(ann_DASH_check_DASH_temp9347956) {
return $Hann_DASH_check_DASH_temp21787957(ann_DASH_check_DASH_temp9347956);
}};
$e79437944.stack[R.EXN_STACKHEIGHT++] = $ss79477948;
}
if(R.isPyretException($e79437944)) {
$e79437944.pyretStack.push(L[630]);
}
throw $e79437944;
}
var $ret79497950 = $Hann_DASH_check_DASH_temp21787957($z79457946);
++R.GAS;
return $ret79497950;
});
var anf_arg9787924 = R.makeObject({"empty":anf_obj9777942});
var anf_arg9877925 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[626],0,arguments);
}
var anf_fun9807940 = G(list2776,"make",L[629]);
var anf_fun9817938 = G(parser2837908,"parse-string",L[628]);
var $z79307931 = D;
var $f79367937 = function(_) {
return R.isFunction(anf_fun9817938)?anf_fun9817938.app():R.ffi.throwNonFunApp(L[627],anf_fun9817938,[]);
};
try {
if(--R.GAS > 0) {
$z79307931 = $f79367937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79367937,
"from":L[627]});
}
} catch($e79287929) {
if(R.isCont($e79287929)) {
var $ss79327933 = {"from":L[627],
"go":function(anf_array_val9827939) {
return $Hanf_array_val21837941(anf_array_val9827939,anf_fun9807940,arg_DASH_error102113,format7872,key2537844,parser2837908,results2477204);
}};
$e79287929.stack[R.EXN_STACKHEIGHT++] = $ss79327933;
}
if(R.isPyretException($e79287929)) {
$e79287929.pyretStack.push(L[627]);
}
throw $e79287929;
}
var $ret79347935 = $Hanf_array_val21837941($z79307931,anf_fun9807940,arg_DASH_error102113,format7872,key2537844,parser2837908,results2477204);
++R.GAS;
return $ret79347935;
});
var $z79157916 = D;
var $f79217922 = function(_) {
return R.isFunction(anf_fun9337923)?anf_fun9337923.app(anf_arg9787924,anf_arg9877925):R.ffi.throwNonFunApp(L[625],anf_fun9337923,[anf_arg9787924,anf_arg9877925]);
};
try {
if(--R.GAS > 0) {
$z79157916 = $f79217922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79217922,
"from":L[625]});
}
} catch($e79137914) {
if(R.isCont($e79137914)) {
var $ss79177918 = {"from":L[625],
"go":function(ann_DASH_check_DASH_temp9327926) {
return $Hann_DASH_check_DASH_temp21847927(ann_DASH_check_DASH_temp9327926);
}};
$e79137914.stack[R.EXN_STACKHEIGHT++] = $ss79177918;
}
if(R.isPyretException($e79137914)) {
$e79137914.pyretStack.push(L[625]);
}
throw $e79137914;
}
var $ret79197920 = $Hann_DASH_check_DASH_temp21847927($z79157916);
++R.GAS;
return $ret79197920;
});
var anf_arg9897887 = R.makeObject({"equals-val":anf_obj8427904,
"equals-val-default":anf_obj8657905,
"next-val":anf_obj9317906,
"next-val-default":anf_obj9887907});
var anf_arg9947888 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[621],0,arguments);
}
var anf_fun9917901 = G(list2776,"make",L[624]);
var $z78937894 = D;
var $f78997900 = function(_) {
return R.isFunction(anf_fun9917901)?anf_fun9917901.app([key2537844]):R.ffi.throwNonFunApp(L[624],anf_fun9917901,[[key2537844]]);
};
try {
if(--R.GAS > 0) {
$z78937894 = $f78997900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78997900,
"from":L[624]});
}
} catch($e78917892) {
if(R.isCont($e78917892)) {
var $ss78957896 = {"from":L[624],
"go":function(anf_arg9927902) {
return $Hanf_arg21877903(anf_arg9927902,arg_DASH_error102113,format7872,results2477204);
}};
$e78917892.stack[R.EXN_STACKHEIGHT++] = $ss78957896;
}
if(R.isPyretException($e78917892)) {
$e78917892.pyretStack.push(L[624]);
}
throw $e78917892;
}
var $ret78977898 = $Hanf_arg21877903($z78937894,arg_DASH_error102113,format7872,results2477204);
++R.GAS;
return $ret78977898;
});
var $z78787879 = D;
var $f78847885 = function(_) {
return R.isFunction(anf_fun8167886)?anf_fun8167886.app(anf_arg9897887,anf_arg9947888):R.ffi.throwNonFunApp(L[621],anf_fun8167886,[anf_arg9897887,anf_arg9947888]);
};
try {
if(--R.GAS > 0) {
$z78787879 = $f78847885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78847885,
"from":L[621]});
}
} catch($e78767877) {
if(R.isCont($e78767877)) {
var $ss78807881 = {"from":L[621],
"go":function(cont_tail_arg9957889) {
return $Hcont_tail_arg21887890(cont_tail_arg9957889,if_helper7287788);
}};
$e78767877.stack[R.EXN_STACKHEIGHT++] = $ss78807881;
}
if(R.isPyretException($e78767877)) {
$e78767877.pyretStack.push(L[621]);
}
throw $e78767877;
}
var $ret78827883 = $Hcont_tail_arg21887890($z78787879,if_helper7287788);
++R.GAS;
return $ret78827883;
};
var $Hcont_tail_arg21887890 = function(cont_tail_arg9957889,if_helper7287788) {
if(--R.GAS > 0) {
$z81728173 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg9957889):R.ffi.throwNonFunApp(L[621],if_helper7287788,[cont_tail_arg9957889]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg9957889):R.ffi.throwNonFunApp(L[621],if_helper7287788,[cont_tail_arg9957889]);
},
"from":L[621]});
}
++R.GAS;
return $z81728173;
};
var $Hanf_arg21877903 = function(anf_arg9927902,arg_DASH_error102113,format7872,results2477204) {
var $z81768177 = D;
var $f81828183 = function(_) {
return R.isFunction(format7872)?format7872.app(("Command line option -~a does not start with two dashes"),anf_arg9927902):R.ffi.throwNonFunApp(L[668],format7872,[("Command line option -~a does not start with two dashes"),anf_arg9927902]);
};
try {
if(--R.GAS > 0) {
$z81768177 = $f81828183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81828183,
"from":L[668]});
}
} catch($e81748175) {
if(R.isCont($e81748175)) {
var $ss81788179 = {"from":L[668],
"go":function(anf_arg9938184) {
return $Hanf_arg21868185(anf_arg9938184,arg_DASH_error102113,results2477204);
}};
$e81748175.stack[R.EXN_STACKHEIGHT++] = $ss81788179;
}
if(R.isPyretException($e81748175)) {
$e81748175.pyretStack.push(L[668]);
}
throw $e81748175;
}
var $ret81808181 = $Hanf_arg21868185($z81768177,arg_DASH_error102113,results2477204);
++R.GAS;
return $ret81808181;
};
var $Hanf_arg21868185 = function(anf_arg9938184,arg_DASH_error102113,results2477204) {
var $z81888189 = D;
var $f81948195 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg9938184,results2477204):R.ffi.throwNonFunApp(L[621],arg_DASH_error102113.$var,[anf_arg9938184,results2477204]);
};
try {
if(--R.GAS > 0) {
$z81888189 = $f81948195();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81948195,
"from":L[621]});
}
} catch($e81868187) {
if(R.isCont($e81868187)) {
var $ss81908191 = {"from":L[621],
"go":function(ann_DASH_check_DASH_temp9908196) {
return $Hann_DASH_check_DASH_temp21858197(ann_DASH_check_DASH_temp9908196);
}};
$e81868187.stack[R.EXN_STACKHEIGHT++] = $ss81908191;
}
if(R.isPyretException($e81868187)) {
$e81868187.pyretStack.push(L[621]);
}
throw $e81868187;
}
var $ret81928193 = $Hann_DASH_check_DASH_temp21858197($z81888189);
++R.GAS;
return $ret81928193;
};
var $Hann_DASH_check_DASH_temp21858197 = function(ann_DASH_check_DASH_temp9908196) {
return ann_DASH_check_DASH_temp9908196;
};
var $Hann_DASH_check_DASH_temp21847927 = function(ann_DASH_check_DASH_temp9327926) {
return ann_DASH_check_DASH_temp9327926;
};
var $Hanf_array_val21837941 = function(anf_array_val9827939,anf_fun9807940,arg_DASH_error102113,format7872,key2537844,parser2837908,results2477204) {
var anf_fun9838208 = G(parser2837908,"parse-string",L[670]);
var $z82008201 = D;
var $f82068207 = function(_) {
return R.isFunction(anf_fun9838208)?anf_fun9838208.app():R.ffi.throwNonFunApp(L[669],anf_fun9838208,[]);
};
try {
if(--R.GAS > 0) {
$z82008201 = $f82068207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82068207,
"from":L[669]});
}
} catch($e81988199) {
if(R.isCont($e81988199)) {
var $ss82028203 = {"from":L[669],
"go":function(anf_array_val9848209) {
return $Hanf_array_val21828210(anf_array_val9848209,anf_array_val9827939,anf_fun9807940,arg_DASH_error102113,format7872,key2537844,results2477204);
}};
$e81988199.stack[R.EXN_STACKHEIGHT++] = $ss82028203;
}
if(R.isPyretException($e81988199)) {
$e81988199.pyretStack.push(L[669]);
}
throw $e81988199;
}
var $ret82048205 = $Hanf_array_val21828210($z82008201,anf_array_val9827939,anf_fun9807940,arg_DASH_error102113,format7872,key2537844,results2477204);
++R.GAS;
return $ret82048205;
};
var $Hanf_array_val21828210 = function(anf_array_val9848209,anf_array_val9827939,anf_fun9807940,arg_DASH_error102113,format7872,key2537844,results2477204) {
var $z82138214 = D;
var $f82198220 = function(_) {
return R.isFunction(anf_fun9807940)?anf_fun9807940.app([key2537844,key2537844,anf_array_val9827939,key2537844,anf_array_val9848209]):R.ffi.throwNonFunApp(L[629],anf_fun9807940,[[key2537844,key2537844,anf_array_val9827939,key2537844,anf_array_val9848209]]);
};
try {
if(--R.GAS > 0) {
$z82138214 = $f82198220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82198220,
"from":L[629]});
}
} catch($e82118212) {
if(R.isCont($e82118212)) {
var $ss82158216 = {"from":L[629],
"go":function(anf_arg9858221) {
return $Hanf_arg21818222(anf_arg9858221,arg_DASH_error102113,format7872,results2477204);
}};
$e82118212.stack[R.EXN_STACKHEIGHT++] = $ss82158216;
}
if(R.isPyretException($e82118212)) {
$e82118212.pyretStack.push(L[629]);
}
throw $e82118212;
}
var $ret82178218 = $Hanf_arg21818222($z82138214,arg_DASH_error102113,format7872,results2477204);
++R.GAS;
return $ret82178218;
};
var $Hanf_arg21818222 = function(anf_arg9858221,arg_DASH_error102113,format7872,results2477204) {
var $z82258226 = D;
var $f82318232 = function(_) {
return R.isFunction(format7872)?format7872.app(("Command line option --~a must be of the form --~a ~a, not --~a=~a"),anf_arg9858221):R.ffi.throwNonFunApp(L[671],format7872,[("Command line option --~a must be of the form --~a ~a, not --~a=~a"),anf_arg9858221]);
};
try {
if(--R.GAS > 0) {
$z82258226 = $f82318232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82318232,
"from":L[671]});
}
} catch($e82238224) {
if(R.isCont($e82238224)) {
var $ss82278228 = {"from":L[671],
"go":function(anf_arg9868233) {
return $Hanf_arg21808234(anf_arg9868233,arg_DASH_error102113,results2477204);
}};
$e82238224.stack[R.EXN_STACKHEIGHT++] = $ss82278228;
}
if(R.isPyretException($e82238224)) {
$e82238224.pyretStack.push(L[671]);
}
throw $e82238224;
}
var $ret82298230 = $Hanf_arg21808234($z82258226,arg_DASH_error102113,results2477204);
++R.GAS;
return $ret82298230;
};
var $Hanf_arg21808234 = function(anf_arg9868233,arg_DASH_error102113,results2477204) {
var $z82378238 = D;
var $f82438244 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg9868233,results2477204):R.ffi.throwNonFunApp(L[626],arg_DASH_error102113.$var,[anf_arg9868233,results2477204]);
};
try {
if(--R.GAS > 0) {
$z82378238 = $f82438244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82438244,
"from":L[626]});
}
} catch($e82358236) {
if(R.isCont($e82358236)) {
var $ss82398240 = {"from":L[626],
"go":function(ann_DASH_check_DASH_temp9798245) {
return $Hann_DASH_check_DASH_temp21798246(ann_DASH_check_DASH_temp9798245);
}};
$e82358236.stack[R.EXN_STACKHEIGHT++] = $ss82398240;
}
if(R.isPyretException($e82358236)) {
$e82358236.pyretStack.push(L[626]);
}
throw $e82358236;
}
var $ret82418242 = $Hann_DASH_check_DASH_temp21798246($z82378238);
++R.GAS;
return $ret82418242;
};
var $Hann_DASH_check_DASH_temp21798246 = function(ann_DASH_check_DASH_temp9798245) {
return ann_DASH_check_DASH_temp9798245;
};
var $Hann_DASH_check_DASH_temp21787957 = function(ann_DASH_check_DASH_temp9347956) {
return ann_DASH_check_DASH_temp9347956;
};
var $Hanf_arg21777974 = function(anf_arg9397973,arg_DASH_error102113,cur_DASH_index2487205,default2847909,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,parser2837908,process2467189,repeated2867911,rest2897962,results2477204,val2887961,_plus13) {
var if_DASH_1368274 = R.equiv(anf_arg9397973,("-"));
var if_helper9408259 = R.makeFunction(function(if_helper_arg9418279) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[676],1,arguments);
}
var ann_DASH_check_DASH_temp9388280 = if_helper_arg9418279;
return ann_DASH_check_DASH_temp9388280;
});
var anf_if9448278 = R.isBoolean(if_DASH_1368274);
if(R.isPyretTrue(anf_if9448278)) {
if(R.isPyretTrue(if_DASH_1368274)) {
var anf_fun9588257 = G(parser2837908,"parse",L[673]);
var $z82498250 = D;
var $f82558256 = function(_) {
return R.isFunction(anf_fun9588257)?anf_fun9588257.app(cur_DASH_index2487205,key2537844,val2887961):R.ffi.throwNonFunApp(L[672],anf_fun9588257,[cur_DASH_index2487205,key2537844,val2887961]);
};
try {
if(--R.GAS > 0) {
$z82498250 = $f82558256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82558256,
"from":L[672]});
}
} catch($e82478248) {
if(R.isCont($e82478248)) {
var $ss82518252 = {"from":L[672],
"go":function(parsed_DASH_val2908258) {
return $Hparsed_DASH_val21708260(parsed_DASH_val2908258,cur_DASH_index2487205,default2847909,handle_DASH_repeated2367037,if_helper9408259,key2537844,more_DASH_args2517754,process2467189,repeated2867911,rest2897962,results2477204,_plus13);
}};
$e82478248.stack[R.EXN_STACKHEIGHT++] = $ss82518252;
}
if(R.isPyretException($e82478248)) {
$e82478248.pyretStack.push(L[672]);
}
throw $e82478248;
}
var $ret82538254 = $Hparsed_DASH_val21708260($z82498250,cur_DASH_index2487205,default2847909,handle_DASH_repeated2367037,if_helper9408259,key2537844,more_DASH_args2517754,process2467189,repeated2867911,rest2897962,results2477204,_plus13);
++R.GAS;
return $ret82538254;
} else {
var anf_fun9458271 = G(parser2837908,"parse",L[675]);
var $z82638264 = D;
var $f82698270 = function(_) {
return R.isFunction(anf_fun9458271)?anf_fun9458271.app(cur_DASH_index2487205,key2537844,val2887961):R.ffi.throwNonFunApp(L[674],anf_fun9458271,[cur_DASH_index2487205,key2537844,val2887961]);
};
try {
if(--R.GAS > 0) {
$z82638264 = $f82698270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82698270,
"from":L[674]});
}
} catch($e82618262) {
if(R.isCont($e82618262)) {
var $ss82658266 = {"from":L[674],
"go":function(parsed_DASH_val2938272) {
return $Hparsed_DASH_val21768273(parsed_DASH_val2938272,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper9408259,key2537844,process2467189,repeated2867911,rest2897962,results2477204,_plus13);
}};
$e82618262.stack[R.EXN_STACKHEIGHT++] = $ss82658266;
}
if(R.isPyretException($e82618262)) {
$e82618262.pyretStack.push(L[674]);
}
throw $e82618262;
}
var $ret82678268 = $Hparsed_DASH_val21768273($z82638264,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper9408259,key2537844,process2467189,repeated2867911,rest2897962,results2477204,_plus13);
++R.GAS;
return $ret82678268;
}
} else {
var cont_tail_arg9428277 = R.throwNonBooleanCondition(L[676],("if"),if_DASH_1368274);
if(--R.GAS > 0) {
$z82758276 = R.isFunction(if_helper9408259)?if_helper9408259.app(cont_tail_arg9428277):R.ffi.throwNonFunApp(L[676],if_helper9408259,[cont_tail_arg9428277]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper9408259)?if_helper9408259.app(cont_tail_arg9428277):R.ffi.throwNonFunApp(L[676],if_helper9408259,[cont_tail_arg9428277]);
},
"from":L[676]});
}
++R.GAS;
return $z82758276;
}
};
var $Hparsed_DASH_val21708260 = function(parsed_DASH_val2908258,cur_DASH_index2487205,default2847909,handle_DASH_repeated2367037,if_helper9408259,key2537844,more_DASH_args2517754,process2467189,repeated2867911,rest2897962,results2477204,_plus13) {
var cases_DASH_val1378325 = parsed_DASH_val2908258;
var anf_fun9598291 = G(cases_DASH_val1378325,"_match",L[677]);
var anf_obj9638297 = R.makeFunction(function(v2918312) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[680],1,arguments);
}
var $z83158316 = D;
var $f83218322 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2867911,key2537844,v2918312):R.ffi.throwNonFunApp(L[681],handle_DASH_repeated2367037.$var,[results2477204,repeated2867911,key2537844,v2918312]);
};
try {
if(--R.GAS > 0) {
$z83158316 = $f83218322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83218322,
"from":L[681]});
}
} catch($e83138314) {
if(R.isCont($e83138314)) {
var $ss83178318 = {"from":L[681],
"go":function(anf_arg9618323) {
return $Hanf_arg21658324(anf_arg9618323,cur_DASH_index2487205,process2467189,rest2897962,_plus13);
}};
$e83138314.stack[R.EXN_STACKHEIGHT++] = $ss83178318;
}
if(R.isPyretException($e83138314)) {
$e83138314.pyretStack.push(L[681]);
}
throw $e83138314;
}
var $ret83198320 = $Hanf_arg21658324($z83158316,cur_DASH_index2487205,process2467189,rest2897962,_plus13);
++R.GAS;
return $ret83198320;
});
var anf_obj9678298 = R.makeFunction(function(e2928299) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[678],1,arguments);
}
var $z83028303 = D;
var $f83088309 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2867911,key2537844,default2847909):R.ffi.throwNonFunApp(L[679],handle_DASH_repeated2367037.$var,[results2477204,repeated2867911,key2537844,default2847909]);
};
try {
if(--R.GAS > 0) {
$z83028303 = $f83088309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83088309,
"from":L[679]});
}
} catch($e83008301) {
if(R.isCont($e83008301)) {
var $ss83048305 = {"from":L[679],
"go":function(anf_arg9658310) {
return $Hanf_arg21688311(anf_arg9658310,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
}};
$e83008301.stack[R.EXN_STACKHEIGHT++] = $ss83048305;
}
if(R.isPyretException($e83008301)) {
$e83008301.pyretStack.push(L[679]);
}
throw $e83008301;
}
var $ret83068307 = $Hanf_arg21688311($z83028303,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
++R.GAS;
return $ret83068307;
});
var anf_arg9688292 = R.makeObject({"left":anf_obj9638297,
"right":anf_obj9678298});
var anf_arg9708293 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[677],0,arguments);
}
var ann_DASH_check_DASH_temp9698296 = R.throwNoBranchesMatched(L[677],("cases"));
return ann_DASH_check_DASH_temp9698296;
});
var $z82838284 = D;
var $f82898290 = function(_) {
return R.isFunction(anf_fun9598291)?anf_fun9598291.app(anf_arg9688292,anf_arg9708293):R.ffi.throwNonFunApp(L[677],anf_fun9598291,[anf_arg9688292,anf_arg9708293]);
};
try {
if(--R.GAS > 0) {
$z82838284 = $f82898290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82898290,
"from":L[677]});
}
} catch($e82818282) {
if(R.isCont($e82818282)) {
var $ss82858286 = {"from":L[677],
"go":function(cont_tail_arg9718294) {
return $Hcont_tail_arg21698295(cont_tail_arg9718294,if_helper9408259);
}};
$e82818282.stack[R.EXN_STACKHEIGHT++] = $ss82858286;
}
if(R.isPyretException($e82818282)) {
$e82818282.pyretStack.push(L[677]);
}
throw $e82818282;
}
var $ret82878288 = $Hcont_tail_arg21698295($z82838284,if_helper9408259);
++R.GAS;
return $ret82878288;
};
var $Hcont_tail_arg21698295 = function(cont_tail_arg9718294,if_helper9408259) {
if(--R.GAS > 0) {
$z83268327 = R.isFunction(if_helper9408259)?if_helper9408259.app(cont_tail_arg9718294):R.ffi.throwNonFunApp(L[677],if_helper9408259,[cont_tail_arg9718294]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper9408259)?if_helper9408259.app(cont_tail_arg9718294):R.ffi.throwNonFunApp(L[677],if_helper9408259,[cont_tail_arg9718294]);
},
"from":L[677]});
}
++R.GAS;
return $z83268327;
};
var $Hanf_arg21688311 = function(anf_arg9658310,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13) {
var $z83308331 = D;
var $f83368337 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[682],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z83308331 = $f83368337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83368337,
"from":L[682]});
}
} catch($e83288329) {
if(R.isCont($e83288329)) {
var $ss83328333 = {"from":L[682],
"go":function(anf_arg9668338) {
return $Hanf_arg21678339(anf_arg9668338,anf_arg9658310,more_DASH_args2517754,process2467189);
}};
$e83288329.stack[R.EXN_STACKHEIGHT++] = $ss83328333;
}
if(R.isPyretException($e83288329)) {
$e83288329.pyretStack.push(L[682]);
}
throw $e83288329;
}
var $ret83348335 = $Hanf_arg21678339($z83308331,anf_arg9658310,more_DASH_args2517754,process2467189);
++R.GAS;
return $ret83348335;
};
var $Hanf_arg21678339 = function(anf_arg9668338,anf_arg9658310,more_DASH_args2517754,process2467189) {
var $z83428343 = D;
var $f83488349 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg9658310,anf_arg9668338,more_DASH_args2517754):R.ffi.throwNonFunApp(L[678],process2467189.$var,[anf_arg9658310,anf_arg9668338,more_DASH_args2517754]);
};
try {
if(--R.GAS > 0) {
$z83428343 = $f83488349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83488349,
"from":L[678]});
}
} catch($e83408341) {
if(R.isCont($e83408341)) {
var $ss83448345 = {"from":L[678],
"go":function(ann_DASH_check_DASH_temp9648350) {
return $Hann_DASH_check_DASH_temp21668351(ann_DASH_check_DASH_temp9648350);
}};
$e83408341.stack[R.EXN_STACKHEIGHT++] = $ss83448345;
}
if(R.isPyretException($e83408341)) {
$e83408341.pyretStack.push(L[678]);
}
throw $e83408341;
}
var $ret83468347 = $Hann_DASH_check_DASH_temp21668351($z83428343);
++R.GAS;
return $ret83468347;
};
var $Hann_DASH_check_DASH_temp21668351 = function(ann_DASH_check_DASH_temp9648350) {
return ann_DASH_check_DASH_temp9648350;
};
var $Hanf_arg21658324 = function(anf_arg9618323,cur_DASH_index2487205,process2467189,rest2897962,_plus13) {
var $z83548355 = D;
var $f83608361 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(2)):R.ffi.throwNonFunApp(L[683],_plus13,[cur_DASH_index2487205,(2)]);
};
try {
if(--R.GAS > 0) {
$z83548355 = $f83608361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83608361,
"from":L[683]});
}
} catch($e83528353) {
if(R.isCont($e83528353)) {
var $ss83568357 = {"from":L[683],
"go":function(anf_arg9628362) {
return $Hanf_arg21648363(anf_arg9628362,anf_arg9618323,process2467189,rest2897962);
}};
$e83528353.stack[R.EXN_STACKHEIGHT++] = $ss83568357;
}
if(R.isPyretException($e83528353)) {
$e83528353.pyretStack.push(L[683]);
}
throw $e83528353;
}
var $ret83588359 = $Hanf_arg21648363($z83548355,anf_arg9618323,process2467189,rest2897962);
++R.GAS;
return $ret83588359;
};
var $Hanf_arg21648363 = function(anf_arg9628362,anf_arg9618323,process2467189,rest2897962) {
var $z83668367 = D;
var $f83728373 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg9618323,anf_arg9628362,rest2897962):R.ffi.throwNonFunApp(L[680],process2467189.$var,[anf_arg9618323,anf_arg9628362,rest2897962]);
};
try {
if(--R.GAS > 0) {
$z83668367 = $f83728373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83728373,
"from":L[680]});
}
} catch($e83648365) {
if(R.isCont($e83648365)) {
var $ss83688369 = {"from":L[680],
"go":function(ann_DASH_check_DASH_temp9608374) {
return $Hann_DASH_check_DASH_temp21638375(ann_DASH_check_DASH_temp9608374);
}};
$e83648365.stack[R.EXN_STACKHEIGHT++] = $ss83688369;
}
if(R.isPyretException($e83648365)) {
$e83648365.pyretStack.push(L[680]);
}
throw $e83648365;
}
var $ret83708371 = $Hann_DASH_check_DASH_temp21638375($z83668367);
++R.GAS;
return $ret83708371;
};
var $Hann_DASH_check_DASH_temp21638375 = function(ann_DASH_check_DASH_temp9608374) {
return ann_DASH_check_DASH_temp9608374;
};
var $Hparsed_DASH_val21768273 = function(parsed_DASH_val2938272,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper9408259,key2537844,process2467189,repeated2867911,rest2897962,results2477204,_plus13) {
var cases_DASH_val1358420 = parsed_DASH_val2938272;
var anf_fun9468386 = G(cases_DASH_val1358420,"_match",L[684]);
var anf_obj9508392 = R.makeFunction(function(v2948407) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[686],1,arguments);
}
var $z84108411 = D;
var $f84168417 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2867911,key2537844,v2948407):R.ffi.throwNonFunApp(L[687],handle_DASH_repeated2367037.$var,[results2477204,repeated2867911,key2537844,v2948407]);
};
try {
if(--R.GAS > 0) {
$z84108411 = $f84168417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84168417,
"from":L[687]});
}
} catch($e84088409) {
if(R.isCont($e84088409)) {
var $ss84128413 = {"from":L[687],
"go":function(anf_arg9488418) {
return $Hanf_arg21738419(anf_arg9488418,cur_DASH_index2487205,process2467189,rest2897962,_plus13);
}};
$e84088409.stack[R.EXN_STACKHEIGHT++] = $ss84128413;
}
if(R.isPyretException($e84088409)) {
$e84088409.pyretStack.push(L[687]);
}
throw $e84088409;
}
var $ret84148415 = $Hanf_arg21738419($z84108411,cur_DASH_index2487205,process2467189,rest2897962,_plus13);
++R.GAS;
return $ret84148415;
});
var anf_obj9528393 = R.makeFunction(function(e2958394) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[685],1,arguments);
}
var $z83978398 = D;
var $f84038404 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(e2958394,results2477204):R.ffi.throwNonFunApp(L[685],arg_DASH_error102113.$var,[e2958394,results2477204]);
};
try {
if(--R.GAS > 0) {
$z83978398 = $f84038404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84038404,
"from":L[685]});
}
} catch($e83958396) {
if(R.isCont($e83958396)) {
var $ss83998400 = {"from":L[685],
"go":function(ann_DASH_check_DASH_temp9518405) {
return $Hann_DASH_check_DASH_temp21748406(ann_DASH_check_DASH_temp9518405);
}};
$e83958396.stack[R.EXN_STACKHEIGHT++] = $ss83998400;
}
if(R.isPyretException($e83958396)) {
$e83958396.pyretStack.push(L[685]);
}
throw $e83958396;
}
var $ret84018402 = $Hann_DASH_check_DASH_temp21748406($z83978398);
++R.GAS;
return $ret84018402;
});
var anf_arg9538387 = R.makeObject({"left":anf_obj9508392,
"right":anf_obj9528393});
var anf_arg9558388 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[684],0,arguments);
}
var ann_DASH_check_DASH_temp9548391 = R.throwNoBranchesMatched(L[684],("cases"));
return ann_DASH_check_DASH_temp9548391;
});
var $z83788379 = D;
var $f83848385 = function(_) {
return R.isFunction(anf_fun9468386)?anf_fun9468386.app(anf_arg9538387,anf_arg9558388):R.ffi.throwNonFunApp(L[684],anf_fun9468386,[anf_arg9538387,anf_arg9558388]);
};
try {
if(--R.GAS > 0) {
$z83788379 = $f83848385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83848385,
"from":L[684]});
}
} catch($e83768377) {
if(R.isCont($e83768377)) {
var $ss83808381 = {"from":L[684],
"go":function(cont_tail_arg9568389) {
return $Hcont_tail_arg21758390(cont_tail_arg9568389,if_helper9408259);
}};
$e83768377.stack[R.EXN_STACKHEIGHT++] = $ss83808381;
}
if(R.isPyretException($e83768377)) {
$e83768377.pyretStack.push(L[684]);
}
throw $e83768377;
}
var $ret83828383 = $Hcont_tail_arg21758390($z83788379,if_helper9408259);
++R.GAS;
return $ret83828383;
};
var $Hcont_tail_arg21758390 = function(cont_tail_arg9568389,if_helper9408259) {
if(--R.GAS > 0) {
$z84218422 = R.isFunction(if_helper9408259)?if_helper9408259.app(cont_tail_arg9568389):R.ffi.throwNonFunApp(L[684],if_helper9408259,[cont_tail_arg9568389]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper9408259)?if_helper9408259.app(cont_tail_arg9568389):R.ffi.throwNonFunApp(L[684],if_helper9408259,[cont_tail_arg9568389]);
},
"from":L[684]});
}
++R.GAS;
return $z84218422;
};
var $Hann_DASH_check_DASH_temp21748406 = function(ann_DASH_check_DASH_temp9518405) {
return ann_DASH_check_DASH_temp9518405;
};
var $Hanf_arg21738419 = function(anf_arg9488418,cur_DASH_index2487205,process2467189,rest2897962,_plus13) {
var $z84258426 = D;
var $f84318432 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[688],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z84258426 = $f84318432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84318432,
"from":L[688]});
}
} catch($e84238424) {
if(R.isCont($e84238424)) {
var $ss84278428 = {"from":L[688],
"go":function(anf_arg9498433) {
return $Hanf_arg21728434(anf_arg9498433,anf_arg9488418,process2467189,rest2897962);
}};
$e84238424.stack[R.EXN_STACKHEIGHT++] = $ss84278428;
}
if(R.isPyretException($e84238424)) {
$e84238424.pyretStack.push(L[688]);
}
throw $e84238424;
}
var $ret84298430 = $Hanf_arg21728434($z84258426,anf_arg9488418,process2467189,rest2897962);
++R.GAS;
return $ret84298430;
};
var $Hanf_arg21728434 = function(anf_arg9498433,anf_arg9488418,process2467189,rest2897962) {
var $z84378438 = D;
var $f84438444 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg9488418,anf_arg9498433,rest2897962):R.ffi.throwNonFunApp(L[686],process2467189.$var,[anf_arg9488418,anf_arg9498433,rest2897962]);
};
try {
if(--R.GAS > 0) {
$z84378438 = $f84438444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84438444,
"from":L[686]});
}
} catch($e84358436) {
if(R.isCont($e84358436)) {
var $ss84398440 = {"from":L[686],
"go":function(ann_DASH_check_DASH_temp9478445) {
return $Hann_DASH_check_DASH_temp21718446(ann_DASH_check_DASH_temp9478445);
}};
$e84358436.stack[R.EXN_STACKHEIGHT++] = $ss84398440;
}
if(R.isPyretException($e84358436)) {
$e84358436.pyretStack.push(L[686]);
}
throw $e84358436;
}
var $ret84418442 = $Hann_DASH_check_DASH_temp21718446($z84378438);
++R.GAS;
return $ret84418442;
};
var $Hann_DASH_check_DASH_temp21718446 = function(ann_DASH_check_DASH_temp9478445) {
return ann_DASH_check_DASH_temp9478445;
};
var $Hann_DASH_check_DASH_temp21627986 = function(ann_DASH_check_DASH_temp9367985) {
return ann_DASH_check_DASH_temp9367985;
};
var $Hann_DASH_check_DASH_temp21618006 = function(ann_DASH_check_DASH_temp8668005) {
return ann_DASH_check_DASH_temp8668005;
};
var $Hanf_array_val21608020 = function(anf_array_val9258018,anf_fun9238019,arg_DASH_error102113,format7872,key2537844,parser2727989,results2477204) {
var anf_fun9268457 = G(parser2727989,"parse-string",L[690]);
var $z84498450 = D;
var $f84558456 = function(_) {
return R.isFunction(anf_fun9268457)?anf_fun9268457.app():R.ffi.throwNonFunApp(L[689],anf_fun9268457,[]);
};
try {
if(--R.GAS > 0) {
$z84498450 = $f84558456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84558456,
"from":L[689]});
}
} catch($e84478448) {
if(R.isCont($e84478448)) {
var $ss84518452 = {"from":L[689],
"go":function(anf_array_val9278458) {
return $Hanf_array_val21598459(anf_array_val9278458,anf_array_val9258018,anf_fun9238019,arg_DASH_error102113,format7872,key2537844,results2477204);
}};
$e84478448.stack[R.EXN_STACKHEIGHT++] = $ss84518452;
}
if(R.isPyretException($e84478448)) {
$e84478448.pyretStack.push(L[689]);
}
throw $e84478448;
}
var $ret84538454 = $Hanf_array_val21598459($z84498450,anf_array_val9258018,anf_fun9238019,arg_DASH_error102113,format7872,key2537844,results2477204);
++R.GAS;
return $ret84538454;
};
var $Hanf_array_val21598459 = function(anf_array_val9278458,anf_array_val9258018,anf_fun9238019,arg_DASH_error102113,format7872,key2537844,results2477204) {
var $z84628463 = D;
var $f84688469 = function(_) {
return R.isFunction(anf_fun9238019)?anf_fun9238019.app([key2537844,key2537844,anf_array_val9258018,key2537844,anf_array_val9278458]):R.ffi.throwNonFunApp(L[640],anf_fun9238019,[[key2537844,key2537844,anf_array_val9258018,key2537844,anf_array_val9278458]]);
};
try {
if(--R.GAS > 0) {
$z84628463 = $f84688469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84688469,
"from":L[640]});
}
} catch($e84608461) {
if(R.isCont($e84608461)) {
var $ss84648465 = {"from":L[640],
"go":function(anf_arg9288470) {
return $Hanf_arg21588471(anf_arg9288470,arg_DASH_error102113,format7872,results2477204);
}};
$e84608461.stack[R.EXN_STACKHEIGHT++] = $ss84648465;
}
if(R.isPyretException($e84608461)) {
$e84608461.pyretStack.push(L[640]);
}
throw $e84608461;
}
var $ret84668467 = $Hanf_arg21588471($z84628463,arg_DASH_error102113,format7872,results2477204);
++R.GAS;
return $ret84668467;
};
var $Hanf_arg21588471 = function(anf_arg9288470,arg_DASH_error102113,format7872,results2477204) {
var $z84748475 = D;
var $f84808481 = function(_) {
return R.isFunction(format7872)?format7872.app(("Command line option --~a must be of the form --~a ~a, not --~a=~a"),anf_arg9288470):R.ffi.throwNonFunApp(L[691],format7872,[("Command line option --~a must be of the form --~a ~a, not --~a=~a"),anf_arg9288470]);
};
try {
if(--R.GAS > 0) {
$z84748475 = $f84808481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84808481,
"from":L[691]});
}
} catch($e84728473) {
if(R.isCont($e84728473)) {
var $ss84768477 = {"from":L[691],
"go":function(anf_arg9298482) {
return $Hanf_arg21578483(anf_arg9298482,arg_DASH_error102113,results2477204);
}};
$e84728473.stack[R.EXN_STACKHEIGHT++] = $ss84768477;
}
if(R.isPyretException($e84728473)) {
$e84728473.pyretStack.push(L[691]);
}
throw $e84728473;
}
var $ret84788479 = $Hanf_arg21578483($z84748475,arg_DASH_error102113,results2477204);
++R.GAS;
return $ret84788479;
};
var $Hanf_arg21578483 = function(anf_arg9298482,arg_DASH_error102113,results2477204) {
var $z84868487 = D;
var $f84928493 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg9298482,results2477204):R.ffi.throwNonFunApp(L[637],arg_DASH_error102113.$var,[anf_arg9298482,results2477204]);
};
try {
if(--R.GAS > 0) {
$z84868487 = $f84928493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84928493,
"from":L[637]});
}
} catch($e84848485) {
if(R.isCont($e84848485)) {
var $ss84888489 = {"from":L[637],
"go":function(ann_DASH_check_DASH_temp9228494) {
return $Hann_DASH_check_DASH_temp21568495(ann_DASH_check_DASH_temp9228494);
}};
$e84848485.stack[R.EXN_STACKHEIGHT++] = $ss84888489;
}
if(R.isPyretException($e84848485)) {
$e84848485.pyretStack.push(L[637]);
}
throw $e84848485;
}
var $ret84908491 = $Hann_DASH_check_DASH_temp21568495($z84868487);
++R.GAS;
return $ret84908491;
};
var $Hann_DASH_check_DASH_temp21568495 = function(ann_DASH_check_DASH_temp9228494) {
return ann_DASH_check_DASH_temp9228494;
};
var $Hann_DASH_check_DASH_temp21558036 = function(ann_DASH_check_DASH_temp8688035) {
return ann_DASH_check_DASH_temp8688035;
};
var $Hanf_arg21548053 = function(anf_arg8788052,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,key2537844,list2776,parser2727989,process2467189,repeated2737990,rest2768041,results2477204,val2758040,_plus13) {
var if_DASH_1318523 = R.equiv(anf_arg8788052,("-"));
var if_helper8798508 = R.makeFunction(function(if_helper_arg8808528) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[696],1,arguments);
}
var ann_DASH_check_DASH_temp8778529 = if_helper_arg8808528;
return ann_DASH_check_DASH_temp8778529;
});
var anf_if8838527 = R.isBoolean(if_DASH_1318523);
if(R.isPyretTrue(anf_if8838527)) {
if(R.isPyretTrue(if_DASH_1318523)) {
var anf_fun8988506 = G(parser2727989,"parse",L[693]);
var $z84988499 = D;
var $f85048505 = function(_) {
return R.isFunction(anf_fun8988506)?anf_fun8988506.app(cur_DASH_index2487205,key2537844,val2758040):R.ffi.throwNonFunApp(L[692],anf_fun8988506,[cur_DASH_index2487205,key2537844,val2758040]);
};
try {
if(--R.GAS > 0) {
$z84988499 = $f85048505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85048505,
"from":L[692]});
}
} catch($e84968497) {
if(R.isCont($e84968497)) {
var $ss85008501 = {"from":L[692],
"go":function(parsed_DASH_val2778507) {
return $Hparsed_DASH_val21468509(parsed_DASH_val2778507,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper8798508,key2537844,list2776,parser2727989,process2467189,repeated2737990,rest2768041,results2477204,_plus13);
}};
$e84968497.stack[R.EXN_STACKHEIGHT++] = $ss85008501;
}
if(R.isPyretException($e84968497)) {
$e84968497.pyretStack.push(L[692]);
}
throw $e84968497;
}
var $ret85028503 = $Hparsed_DASH_val21468509($z84988499,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper8798508,key2537844,list2776,parser2727989,process2467189,repeated2737990,rest2768041,results2477204,_plus13);
++R.GAS;
return $ret85028503;
} else {
var anf_fun8848521 = G(parser2727989,"parse",L[695]);
var $z85128513 = D;
var $f85188519 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[694],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z85128513 = $f85188519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85188519,
"from":L[694]});
}
} catch($e85108511) {
if(R.isCont($e85108511)) {
var $ss85148515 = {"from":L[694],
"go":function(anf_arg8858520) {
return $Hanf_arg21538522(anf_arg8858520,anf_fun8848521,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper8798508,key2537844,process2467189,repeated2737990,rest2768041,results2477204,val2758040,_plus13);
}};
$e85108511.stack[R.EXN_STACKHEIGHT++] = $ss85148515;
}
if(R.isPyretException($e85108511)) {
$e85108511.pyretStack.push(L[694]);
}
throw $e85108511;
}
var $ret85168517 = $Hanf_arg21538522($z85128513,anf_fun8848521,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper8798508,key2537844,process2467189,repeated2737990,rest2768041,results2477204,val2758040,_plus13);
++R.GAS;
return $ret85168517;
}
} else {
var cont_tail_arg8818526 = R.throwNonBooleanCondition(L[696],("if"),if_DASH_1318523);
if(--R.GAS > 0) {
$z85248525 = R.isFunction(if_helper8798508)?if_helper8798508.app(cont_tail_arg8818526):R.ffi.throwNonFunApp(L[696],if_helper8798508,[cont_tail_arg8818526]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper8798508)?if_helper8798508.app(cont_tail_arg8818526):R.ffi.throwNonFunApp(L[696],if_helper8798508,[cont_tail_arg8818526]);
},
"from":L[696]});
}
++R.GAS;
return $z85248525;
}
};
var $Hparsed_DASH_val21468509 = function(parsed_DASH_val2778507,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper8798508,key2537844,list2776,parser2727989,process2467189,repeated2737990,rest2768041,results2477204,_plus13) {
var cases_DASH_val1328576 = parsed_DASH_val2778507;
var anf_fun8998540 = G(cases_DASH_val1328576,"_match",L[697]);
var anf_obj9038546 = R.makeFunction(function(v2788563) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[702],1,arguments);
}
var $z85668567 = D;
var $f85728573 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2737990,key2537844,v2788563):R.ffi.throwNonFunApp(L[703],handle_DASH_repeated2367037.$var,[results2477204,repeated2737990,key2537844,v2788563]);
};
try {
if(--R.GAS > 0) {
$z85668567 = $f85728573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85728573,
"from":L[703]});
}
} catch($e85648565) {
if(R.isCont($e85648565)) {
var $ss85688569 = {"from":L[703],
"go":function(anf_arg9018574) {
return $Hanf_arg21408575(anf_arg9018574,cur_DASH_index2487205,process2467189,rest2768041,_plus13);
}};
$e85648565.stack[R.EXN_STACKHEIGHT++] = $ss85688569;
}
if(R.isPyretException($e85648565)) {
$e85648565.pyretStack.push(L[703]);
}
throw $e85648565;
}
var $ret85708571 = $Hanf_arg21408575($z85668567,cur_DASH_index2487205,process2467189,rest2768041,_plus13);
++R.GAS;
return $ret85708571;
});
var anf_obj9108547 = R.makeFunction(function($underscore2798548) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[698],1,arguments);
}
var anf_fun9058561 = G(list2776,"make",L[701]);
var anf_fun9068559 = G(parser2727989,"parse-string",L[700]);
var $z85518552 = D;
var $f85578558 = function(_) {
return R.isFunction(anf_fun9068559)?anf_fun9068559.app():R.ffi.throwNonFunApp(L[699],anf_fun9068559,[]);
};
try {
if(--R.GAS > 0) {
$z85518552 = $f85578558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85578558,
"from":L[699]});
}
} catch($e85498550) {
if(R.isCont($e85498550)) {
var $ss85538554 = {"from":L[699],
"go":function(anf_array_val9078560) {
return $Hanf_array_val21448562(anf_array_val9078560,anf_fun9058561,arg_DASH_error102113,format7872,key2537844,results2477204);
}};
$e85498550.stack[R.EXN_STACKHEIGHT++] = $ss85538554;
}
if(R.isPyretException($e85498550)) {
$e85498550.pyretStack.push(L[699]);
}
throw $e85498550;
}
var $ret85558556 = $Hanf_array_val21448562($z85518552,anf_fun9058561,arg_DASH_error102113,format7872,key2537844,results2477204);
++R.GAS;
return $ret85558556;
});
var anf_arg9118541 = R.makeObject({"left":anf_obj9038546,
"right":anf_obj9108547});
var anf_arg9138542 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[697],0,arguments);
}
var ann_DASH_check_DASH_temp9128545 = R.throwNoBranchesMatched(L[697],("cases"));
return ann_DASH_check_DASH_temp9128545;
});
var $z85328533 = D;
var $f85388539 = function(_) {
return R.isFunction(anf_fun8998540)?anf_fun8998540.app(anf_arg9118541,anf_arg9138542):R.ffi.throwNonFunApp(L[697],anf_fun8998540,[anf_arg9118541,anf_arg9138542]);
};
try {
if(--R.GAS > 0) {
$z85328533 = $f85388539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85388539,
"from":L[697]});
}
} catch($e85308531) {
if(R.isCont($e85308531)) {
var $ss85348535 = {"from":L[697],
"go":function(cont_tail_arg9148543) {
return $Hcont_tail_arg21458544(cont_tail_arg9148543,if_helper8798508);
}};
$e85308531.stack[R.EXN_STACKHEIGHT++] = $ss85348535;
}
if(R.isPyretException($e85308531)) {
$e85308531.pyretStack.push(L[697]);
}
throw $e85308531;
}
var $ret85368537 = $Hcont_tail_arg21458544($z85328533,if_helper8798508);
++R.GAS;
return $ret85368537;
};
var $Hcont_tail_arg21458544 = function(cont_tail_arg9148543,if_helper8798508) {
if(--R.GAS > 0) {
$z85778578 = R.isFunction(if_helper8798508)?if_helper8798508.app(cont_tail_arg9148543):R.ffi.throwNonFunApp(L[697],if_helper8798508,[cont_tail_arg9148543]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper8798508)?if_helper8798508.app(cont_tail_arg9148543):R.ffi.throwNonFunApp(L[697],if_helper8798508,[cont_tail_arg9148543]);
},
"from":L[697]});
}
++R.GAS;
return $z85778578;
};
var $Hanf_array_val21448562 = function(anf_array_val9078560,anf_fun9058561,arg_DASH_error102113,format7872,key2537844,results2477204) {
var $z85818582 = D;
var $f85878588 = function(_) {
return R.isFunction(anf_fun9058561)?anf_fun9058561.app([key2537844,key2537844,anf_array_val9078560]):R.ffi.throwNonFunApp(L[701],anf_fun9058561,[[key2537844,key2537844,anf_array_val9078560]]);
};
try {
if(--R.GAS > 0) {
$z85818582 = $f85878588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85878588,
"from":L[701]});
}
} catch($e85798580) {
if(R.isCont($e85798580)) {
var $ss85838584 = {"from":L[701],
"go":function(anf_arg9088589) {
return $Hanf_arg21438590(anf_arg9088589,arg_DASH_error102113,format7872,results2477204);
}};
$e85798580.stack[R.EXN_STACKHEIGHT++] = $ss85838584;
}
if(R.isPyretException($e85798580)) {
$e85798580.pyretStack.push(L[701]);
}
throw $e85798580;
}
var $ret85858586 = $Hanf_arg21438590($z85818582,arg_DASH_error102113,format7872,results2477204);
++R.GAS;
return $ret85858586;
};
var $Hanf_arg21438590 = function(anf_arg9088589,arg_DASH_error102113,format7872,results2477204) {
var $z85938594 = D;
var $f85998600 = function(_) {
return R.isFunction(format7872)?format7872.app(("Missing value for option ~a; it must be of the form --~a ~a"),anf_arg9088589):R.ffi.throwNonFunApp(L[704],format7872,[("Missing value for option ~a; it must be of the form --~a ~a"),anf_arg9088589]);
};
try {
if(--R.GAS > 0) {
$z85938594 = $f85998600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85998600,
"from":L[704]});
}
} catch($e85918592) {
if(R.isCont($e85918592)) {
var $ss85958596 = {"from":L[704],
"go":function(anf_arg9098601) {
return $Hanf_arg21428602(anf_arg9098601,arg_DASH_error102113,results2477204);
}};
$e85918592.stack[R.EXN_STACKHEIGHT++] = $ss85958596;
}
if(R.isPyretException($e85918592)) {
$e85918592.pyretStack.push(L[704]);
}
throw $e85918592;
}
var $ret85978598 = $Hanf_arg21428602($z85938594,arg_DASH_error102113,results2477204);
++R.GAS;
return $ret85978598;
};
var $Hanf_arg21428602 = function(anf_arg9098601,arg_DASH_error102113,results2477204) {
var $z86058606 = D;
var $f86118612 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg9098601,results2477204):R.ffi.throwNonFunApp(L[698],arg_DASH_error102113.$var,[anf_arg9098601,results2477204]);
};
try {
if(--R.GAS > 0) {
$z86058606 = $f86118612();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86118612,
"from":L[698]});
}
} catch($e86038604) {
if(R.isCont($e86038604)) {
var $ss86078608 = {"from":L[698],
"go":function(ann_DASH_check_DASH_temp9048613) {
return $Hann_DASH_check_DASH_temp21418614(ann_DASH_check_DASH_temp9048613);
}};
$e86038604.stack[R.EXN_STACKHEIGHT++] = $ss86078608;
}
if(R.isPyretException($e86038604)) {
$e86038604.pyretStack.push(L[698]);
}
throw $e86038604;
}
var $ret86098610 = $Hann_DASH_check_DASH_temp21418614($z86058606);
++R.GAS;
return $ret86098610;
};
var $Hann_DASH_check_DASH_temp21418614 = function(ann_DASH_check_DASH_temp9048613) {
return ann_DASH_check_DASH_temp9048613;
};
var $Hanf_arg21408575 = function(anf_arg9018574,cur_DASH_index2487205,process2467189,rest2768041,_plus13) {
var $z86178618 = D;
var $f86238624 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(2)):R.ffi.throwNonFunApp(L[705],_plus13,[cur_DASH_index2487205,(2)]);
};
try {
if(--R.GAS > 0) {
$z86178618 = $f86238624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86238624,
"from":L[705]});
}
} catch($e86158616) {
if(R.isCont($e86158616)) {
var $ss86198620 = {"from":L[705],
"go":function(anf_arg9028625) {
return $Hanf_arg21398626(anf_arg9028625,anf_arg9018574,process2467189,rest2768041);
}};
$e86158616.stack[R.EXN_STACKHEIGHT++] = $ss86198620;
}
if(R.isPyretException($e86158616)) {
$e86158616.pyretStack.push(L[705]);
}
throw $e86158616;
}
var $ret86218622 = $Hanf_arg21398626($z86178618,anf_arg9018574,process2467189,rest2768041);
++R.GAS;
return $ret86218622;
};
var $Hanf_arg21398626 = function(anf_arg9028625,anf_arg9018574,process2467189,rest2768041) {
var $z86298630 = D;
var $f86358636 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg9018574,anf_arg9028625,rest2768041):R.ffi.throwNonFunApp(L[702],process2467189.$var,[anf_arg9018574,anf_arg9028625,rest2768041]);
};
try {
if(--R.GAS > 0) {
$z86298630 = $f86358636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86358636,
"from":L[702]});
}
} catch($e86278628) {
if(R.isCont($e86278628)) {
var $ss86318632 = {"from":L[702],
"go":function(ann_DASH_check_DASH_temp9008637) {
return $Hann_DASH_check_DASH_temp21388638(ann_DASH_check_DASH_temp9008637);
}};
$e86278628.stack[R.EXN_STACKHEIGHT++] = $ss86318632;
}
if(R.isPyretException($e86278628)) {
$e86278628.pyretStack.push(L[702]);
}
throw $e86278628;
}
var $ret86338634 = $Hann_DASH_check_DASH_temp21388638($z86298630);
++R.GAS;
return $ret86338634;
};
var $Hann_DASH_check_DASH_temp21388638 = function(ann_DASH_check_DASH_temp9008637) {
return ann_DASH_check_DASH_temp9008637;
};
var $Hanf_arg21538522 = function(anf_arg8858520,anf_fun8848521,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper8798508,key2537844,process2467189,repeated2737990,rest2768041,results2477204,val2758040,_plus13) {
var $z86418642 = D;
var $f86478648 = function(_) {
return R.isFunction(anf_fun8848521)?anf_fun8848521.app(anf_arg8858520,key2537844,val2758040):R.ffi.throwNonFunApp(L[706],anf_fun8848521,[anf_arg8858520,key2537844,val2758040]);
};
try {
if(--R.GAS > 0) {
$z86418642 = $f86478648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86478648,
"from":L[706]});
}
} catch($e86398640) {
if(R.isCont($e86398640)) {
var $ss86438644 = {"from":L[706],
"go":function(parsed_DASH_val2808649) {
return $Hparsed_DASH_val21528650(parsed_DASH_val2808649,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper8798508,key2537844,process2467189,repeated2737990,rest2768041,results2477204,_plus13);
}};
$e86398640.stack[R.EXN_STACKHEIGHT++] = $ss86438644;
}
if(R.isPyretException($e86398640)) {
$e86398640.pyretStack.push(L[706]);
}
throw $e86398640;
}
var $ret86458646 = $Hparsed_DASH_val21528650($z86418642,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper8798508,key2537844,process2467189,repeated2737990,rest2768041,results2477204,_plus13);
++R.GAS;
return $ret86458646;
};
var $Hparsed_DASH_val21528650 = function(parsed_DASH_val2808649,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,if_helper8798508,key2537844,process2467189,repeated2737990,rest2768041,results2477204,_plus13) {
var cases_DASH_val1308695 = parsed_DASH_val2808649;
var anf_fun8868661 = G(cases_DASH_val1308695,"_match",L[707]);
var anf_obj8908667 = R.makeFunction(function(v2818682) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[709],1,arguments);
}
var $z86858686 = D;
var $f86918692 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2737990,key2537844,v2818682):R.ffi.throwNonFunApp(L[710],handle_DASH_repeated2367037.$var,[results2477204,repeated2737990,key2537844,v2818682]);
};
try {
if(--R.GAS > 0) {
$z86858686 = $f86918692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86918692,
"from":L[710]});
}
} catch($e86838684) {
if(R.isCont($e86838684)) {
var $ss86878688 = {"from":L[710],
"go":function(anf_arg8888693) {
return $Hanf_arg21498694(anf_arg8888693,cur_DASH_index2487205,process2467189,rest2768041,_plus13);
}};
$e86838684.stack[R.EXN_STACKHEIGHT++] = $ss86878688;
}
if(R.isPyretException($e86838684)) {
$e86838684.pyretStack.push(L[710]);
}
throw $e86838684;
}
var $ret86898690 = $Hanf_arg21498694($z86858686,cur_DASH_index2487205,process2467189,rest2768041,_plus13);
++R.GAS;
return $ret86898690;
});
var anf_obj8928668 = R.makeFunction(function(e2828669) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[708],1,arguments);
}
var $z86728673 = D;
var $f86788679 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(e2828669,results2477204):R.ffi.throwNonFunApp(L[708],arg_DASH_error102113.$var,[e2828669,results2477204]);
};
try {
if(--R.GAS > 0) {
$z86728673 = $f86788679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86788679,
"from":L[708]});
}
} catch($e86708671) {
if(R.isCont($e86708671)) {
var $ss86748675 = {"from":L[708],
"go":function(ann_DASH_check_DASH_temp8918680) {
return $Hann_DASH_check_DASH_temp21508681(ann_DASH_check_DASH_temp8918680);
}};
$e86708671.stack[R.EXN_STACKHEIGHT++] = $ss86748675;
}
if(R.isPyretException($e86708671)) {
$e86708671.pyretStack.push(L[708]);
}
throw $e86708671;
}
var $ret86768677 = $Hann_DASH_check_DASH_temp21508681($z86728673);
++R.GAS;
return $ret86768677;
});
var anf_arg8938662 = R.makeObject({"left":anf_obj8908667,
"right":anf_obj8928668});
var anf_arg8958663 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[707],0,arguments);
}
var ann_DASH_check_DASH_temp8948666 = R.throwNoBranchesMatched(L[707],("cases"));
return ann_DASH_check_DASH_temp8948666;
});
var $z86538654 = D;
var $f86598660 = function(_) {
return R.isFunction(anf_fun8868661)?anf_fun8868661.app(anf_arg8938662,anf_arg8958663):R.ffi.throwNonFunApp(L[707],anf_fun8868661,[anf_arg8938662,anf_arg8958663]);
};
try {
if(--R.GAS > 0) {
$z86538654 = $f86598660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86598660,
"from":L[707]});
}
} catch($e86518652) {
if(R.isCont($e86518652)) {
var $ss86558656 = {"from":L[707],
"go":function(cont_tail_arg8968664) {
return $Hcont_tail_arg21518665(cont_tail_arg8968664,if_helper8798508);
}};
$e86518652.stack[R.EXN_STACKHEIGHT++] = $ss86558656;
}
if(R.isPyretException($e86518652)) {
$e86518652.pyretStack.push(L[707]);
}
throw $e86518652;
}
var $ret86578658 = $Hcont_tail_arg21518665($z86538654,if_helper8798508);
++R.GAS;
return $ret86578658;
};
var $Hcont_tail_arg21518665 = function(cont_tail_arg8968664,if_helper8798508) {
if(--R.GAS > 0) {
$z86968697 = R.isFunction(if_helper8798508)?if_helper8798508.app(cont_tail_arg8968664):R.ffi.throwNonFunApp(L[707],if_helper8798508,[cont_tail_arg8968664]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper8798508)?if_helper8798508.app(cont_tail_arg8968664):R.ffi.throwNonFunApp(L[707],if_helper8798508,[cont_tail_arg8968664]);
},
"from":L[707]});
}
++R.GAS;
return $z86968697;
};
var $Hann_DASH_check_DASH_temp21508681 = function(ann_DASH_check_DASH_temp8918680) {
return ann_DASH_check_DASH_temp8918680;
};
var $Hanf_arg21498694 = function(anf_arg8888693,cur_DASH_index2487205,process2467189,rest2768041,_plus13) {
var $z87008701 = D;
var $f87068707 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(2)):R.ffi.throwNonFunApp(L[711],_plus13,[cur_DASH_index2487205,(2)]);
};
try {
if(--R.GAS > 0) {
$z87008701 = $f87068707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87068707,
"from":L[711]});
}
} catch($e86988699) {
if(R.isCont($e86988699)) {
var $ss87028703 = {"from":L[711],
"go":function(anf_arg8898708) {
return $Hanf_arg21488709(anf_arg8898708,anf_arg8888693,process2467189,rest2768041);
}};
$e86988699.stack[R.EXN_STACKHEIGHT++] = $ss87028703;
}
if(R.isPyretException($e86988699)) {
$e86988699.pyretStack.push(L[711]);
}
throw $e86988699;
}
var $ret87048705 = $Hanf_arg21488709($z87008701,anf_arg8888693,process2467189,rest2768041);
++R.GAS;
return $ret87048705;
};
var $Hanf_arg21488709 = function(anf_arg8898708,anf_arg8888693,process2467189,rest2768041) {
var $z87128713 = D;
var $f87188719 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg8888693,anf_arg8898708,rest2768041):R.ffi.throwNonFunApp(L[709],process2467189.$var,[anf_arg8888693,anf_arg8898708,rest2768041]);
};
try {
if(--R.GAS > 0) {
$z87128713 = $f87188719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87188719,
"from":L[709]});
}
} catch($e87108711) {
if(R.isCont($e87108711)) {
var $ss87148715 = {"from":L[709],
"go":function(ann_DASH_check_DASH_temp8878720) {
return $Hann_DASH_check_DASH_temp21478721(ann_DASH_check_DASH_temp8878720);
}};
$e87108711.stack[R.EXN_STACKHEIGHT++] = $ss87148715;
}
if(R.isPyretException($e87108711)) {
$e87108711.pyretStack.push(L[709]);
}
throw $e87108711;
}
var $ret87168717 = $Hann_DASH_check_DASH_temp21478721($z87128713);
++R.GAS;
return $ret87168717;
};
var $Hann_DASH_check_DASH_temp21478721 = function(ann_DASH_check_DASH_temp8878720) {
return ann_DASH_check_DASH_temp8878720;
};
var $Hanf_array_val21378067 = function(anf_array_val8738065,anf_fun8718066,arg_DASH_error102113,format7872,key2537844,results2477204) {
var $z87248725 = D;
var $f87308731 = function(_) {
return R.isFunction(anf_fun8718066)?anf_fun8718066.app([key2537844,key2537844,anf_array_val8738065]):R.ffi.throwNonFunApp(L[648],anf_fun8718066,[[key2537844,key2537844,anf_array_val8738065]]);
};
try {
if(--R.GAS > 0) {
$z87248725 = $f87308731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87308731,
"from":L[648]});
}
} catch($e87228723) {
if(R.isCont($e87228723)) {
var $ss87268727 = {"from":L[648],
"go":function(anf_arg8748732) {
return $Hanf_arg21368733(anf_arg8748732,arg_DASH_error102113,format7872,results2477204);
}};
$e87228723.stack[R.EXN_STACKHEIGHT++] = $ss87268727;
}
if(R.isPyretException($e87228723)) {
$e87228723.pyretStack.push(L[648]);
}
throw $e87228723;
}
var $ret87288729 = $Hanf_arg21368733($z87248725,arg_DASH_error102113,format7872,results2477204);
++R.GAS;
return $ret87288729;
};
var $Hanf_arg21368733 = function(anf_arg8748732,arg_DASH_error102113,format7872,results2477204) {
var $z87368737 = D;
var $f87428743 = function(_) {
return R.isFunction(format7872)?format7872.app(("Missing value for option ~a; it must be of the form --~a ~a"),anf_arg8748732):R.ffi.throwNonFunApp(L[712],format7872,[("Missing value for option ~a; it must be of the form --~a ~a"),anf_arg8748732]);
};
try {
if(--R.GAS > 0) {
$z87368737 = $f87428743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87428743,
"from":L[712]});
}
} catch($e87348735) {
if(R.isCont($e87348735)) {
var $ss87388739 = {"from":L[712],
"go":function(anf_arg8758744) {
return $Hanf_arg21358745(anf_arg8758744,arg_DASH_error102113,results2477204);
}};
$e87348735.stack[R.EXN_STACKHEIGHT++] = $ss87388739;
}
if(R.isPyretException($e87348735)) {
$e87348735.pyretStack.push(L[712]);
}
throw $e87348735;
}
var $ret87408741 = $Hanf_arg21358745($z87368737,arg_DASH_error102113,results2477204);
++R.GAS;
return $ret87408741;
};
var $Hanf_arg21358745 = function(anf_arg8758744,arg_DASH_error102113,results2477204) {
var $z87488749 = D;
var $f87548755 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg8758744,results2477204):R.ffi.throwNonFunApp(L[645],arg_DASH_error102113.$var,[anf_arg8758744,results2477204]);
};
try {
if(--R.GAS > 0) {
$z87488749 = $f87548755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87548755,
"from":L[645]});
}
} catch($e87468747) {
if(R.isCont($e87468747)) {
var $ss87508751 = {"from":L[645],
"go":function(ann_DASH_check_DASH_temp8708756) {
return $Hann_DASH_check_DASH_temp21348757(ann_DASH_check_DASH_temp8708756);
}};
$e87468747.stack[R.EXN_STACKHEIGHT++] = $ss87508751;
}
if(R.isPyretException($e87468747)) {
$e87468747.pyretStack.push(L[645]);
}
throw $e87468747;
}
var $ret87528753 = $Hann_DASH_check_DASH_temp21348757($z87488749);
++R.GAS;
return $ret87528753;
};
var $Hann_DASH_check_DASH_temp21348757 = function(ann_DASH_check_DASH_temp8708756) {
return ann_DASH_check_DASH_temp8708756;
};
var $Hann_DASH_check_DASH_temp21338089 = function(ann_DASH_check_DASH_temp8438088) {
return ann_DASH_check_DASH_temp8438088;
};
var $Hparsed_DASH_val21328107 = function(parsed_DASH_val2698106,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,process2467189,repeated2658073,results2477204,_plus13) {
var cases_DASH_val1288802 = parsed_DASH_val2698106;
var anf_fun8518768 = G(cases_DASH_val1288802,"_match",L[713]);
var anf_obj8558774 = R.makeFunction(function(v2708789) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[715],1,arguments);
}
var $z87928793 = D;
var $f87988799 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2658073,key2537844,v2708789):R.ffi.throwNonFunApp(L[716],handle_DASH_repeated2367037.$var,[results2477204,repeated2658073,key2537844,v2708789]);
};
try {
if(--R.GAS > 0) {
$z87928793 = $f87988799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87988799,
"from":L[716]});
}
} catch($e87908791) {
if(R.isCont($e87908791)) {
var $ss87948795 = {"from":L[716],
"go":function(anf_arg8538800) {
return $Hanf_arg21298801(anf_arg8538800,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
}};
$e87908791.stack[R.EXN_STACKHEIGHT++] = $ss87948795;
}
if(R.isPyretException($e87908791)) {
$e87908791.pyretStack.push(L[716]);
}
throw $e87908791;
}
var $ret87968797 = $Hanf_arg21298801($z87928793,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
++R.GAS;
return $ret87968797;
});
var anf_obj8578775 = R.makeFunction(function(e2718776) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[714],1,arguments);
}
var $z87798780 = D;
var $f87858786 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(e2718776,results2477204):R.ffi.throwNonFunApp(L[714],arg_DASH_error102113.$var,[e2718776,results2477204]);
};
try {
if(--R.GAS > 0) {
$z87798780 = $f87858786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87858786,
"from":L[714]});
}
} catch($e87778778) {
if(R.isCont($e87778778)) {
var $ss87818782 = {"from":L[714],
"go":function(ann_DASH_check_DASH_temp8568787) {
return $Hann_DASH_check_DASH_temp21308788(ann_DASH_check_DASH_temp8568787);
}};
$e87778778.stack[R.EXN_STACKHEIGHT++] = $ss87818782;
}
if(R.isPyretException($e87778778)) {
$e87778778.pyretStack.push(L[714]);
}
throw $e87778778;
}
var $ret87838784 = $Hann_DASH_check_DASH_temp21308788($z87798780);
++R.GAS;
return $ret87838784;
});
var anf_arg8588769 = R.makeObject({"left":anf_obj8558774,
"right":anf_obj8578775});
var anf_arg8608770 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[713],0,arguments);
}
var ann_DASH_check_DASH_temp8598773 = R.throwNoBranchesMatched(L[713],("cases"));
return ann_DASH_check_DASH_temp8598773;
});
var $z87608761 = D;
var $f87668767 = function(_) {
return R.isFunction(anf_fun8518768)?anf_fun8518768.app(anf_arg8588769,anf_arg8608770):R.ffi.throwNonFunApp(L[652],anf_fun8518768,[anf_arg8588769,anf_arg8608770]);
};
try {
if(--R.GAS > 0) {
$z87608761 = $f87668767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87668767,
"from":L[652]});
}
} catch($e87588759) {
if(R.isCont($e87588759)) {
var $ss87628763 = {"from":L[652],
"go":function(ann_DASH_check_DASH_temp8498771) {
return $Hann_DASH_check_DASH_temp21318772(ann_DASH_check_DASH_temp8498771);
}};
$e87588759.stack[R.EXN_STACKHEIGHT++] = $ss87628763;
}
if(R.isPyretException($e87588759)) {
$e87588759.pyretStack.push(L[652]);
}
throw $e87588759;
}
var $ret87648765 = $Hann_DASH_check_DASH_temp21318772($z87608761);
++R.GAS;
return $ret87648765;
};
var $Hann_DASH_check_DASH_temp21318772 = function(ann_DASH_check_DASH_temp8498771) {
return ann_DASH_check_DASH_temp8498771;
};
var $Hann_DASH_check_DASH_temp21308788 = function(ann_DASH_check_DASH_temp8568787) {
return ann_DASH_check_DASH_temp8568787;
};
var $Hanf_arg21298801 = function(anf_arg8538800,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13) {
var $z88058806 = D;
var $f88118812 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[717],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z88058806 = $f88118812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88118812,
"from":L[717]});
}
} catch($e88038804) {
if(R.isCont($e88038804)) {
var $ss88078808 = {"from":L[717],
"go":function(anf_arg8548813) {
return $Hanf_arg21288814(anf_arg8548813,anf_arg8538800,more_DASH_args2517754,process2467189);
}};
$e88038804.stack[R.EXN_STACKHEIGHT++] = $ss88078808;
}
if(R.isPyretException($e88038804)) {
$e88038804.pyretStack.push(L[717]);
}
throw $e88038804;
}
var $ret88098810 = $Hanf_arg21288814($z88058806,anf_arg8538800,more_DASH_args2517754,process2467189);
++R.GAS;
return $ret88098810;
};
var $Hanf_arg21288814 = function(anf_arg8548813,anf_arg8538800,more_DASH_args2517754,process2467189) {
var $z88178818 = D;
var $f88238824 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg8538800,anf_arg8548813,more_DASH_args2517754):R.ffi.throwNonFunApp(L[715],process2467189.$var,[anf_arg8538800,anf_arg8548813,more_DASH_args2517754]);
};
try {
if(--R.GAS > 0) {
$z88178818 = $f88238824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88238824,
"from":L[715]});
}
} catch($e88158816) {
if(R.isCont($e88158816)) {
var $ss88198820 = {"from":L[715],
"go":function(ann_DASH_check_DASH_temp8528825) {
return $Hann_DASH_check_DASH_temp21278826(ann_DASH_check_DASH_temp8528825);
}};
$e88158816.stack[R.EXN_STACKHEIGHT++] = $ss88198820;
}
if(R.isPyretException($e88158816)) {
$e88158816.pyretStack.push(L[715]);
}
throw $e88158816;
}
var $ret88218822 = $Hann_DASH_check_DASH_temp21278826($z88178818);
++R.GAS;
return $ret88218822;
};
var $Hann_DASH_check_DASH_temp21278826 = function(ann_DASH_check_DASH_temp8528825) {
return ann_DASH_check_DASH_temp8528825;
};
var $Hanf_arg21268119 = function(anf_arg8468118,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13) {
var $z88298830 = D;
var $f88358836 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[718],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z88298830 = $f88358836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88358836,
"from":L[718]});
}
} catch($e88278828) {
if(R.isCont($e88278828)) {
var $ss88318832 = {"from":L[718],
"go":function(anf_arg8478837) {
return $Hanf_arg21258838(anf_arg8478837,anf_arg8468118,more_DASH_args2517754,process2467189);
}};
$e88278828.stack[R.EXN_STACKHEIGHT++] = $ss88318832;
}
if(R.isPyretException($e88278828)) {
$e88278828.pyretStack.push(L[718]);
}
throw $e88278828;
}
var $ret88338834 = $Hanf_arg21258838($z88298830,anf_arg8468118,more_DASH_args2517754,process2467189);
++R.GAS;
return $ret88338834;
};
var $Hanf_arg21258838 = function(anf_arg8478837,anf_arg8468118,more_DASH_args2517754,process2467189) {
var $z88418842 = D;
var $f88478848 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg8468118,anf_arg8478837,more_DASH_args2517754):R.ffi.throwNonFunApp(L[655],process2467189.$var,[anf_arg8468118,anf_arg8478837,more_DASH_args2517754]);
};
try {
if(--R.GAS > 0) {
$z88418842 = $f88478848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88478848,
"from":L[655]});
}
} catch($e88398840) {
if(R.isCont($e88398840)) {
var $ss88438844 = {"from":L[655],
"go":function(ann_DASH_check_DASH_temp8458849) {
return $Hann_DASH_check_DASH_temp21248850(ann_DASH_check_DASH_temp8458849);
}};
$e88398840.stack[R.EXN_STACKHEIGHT++] = $ss88438844;
}
if(R.isPyretException($e88398840)) {
$e88398840.pyretStack.push(L[655]);
}
throw $e88398840;
}
var $ret88458846 = $Hann_DASH_check_DASH_temp21248850($z88418842);
++R.GAS;
return $ret88458846;
};
var $Hann_DASH_check_DASH_temp21248850 = function(ann_DASH_check_DASH_temp8458849) {
return ann_DASH_check_DASH_temp8458849;
};
var $Hann_DASH_check_DASH_temp21238138 = function(ann_DASH_check_DASH_temp8178137) {
return ann_DASH_check_DASH_temp8178137;
};
var $Hparsed_DASH_val21228156 = function(parsed_DASH_val2598155,arg_DASH_error102113,cur_DASH_index2487205,handle_DASH_repeated2367037,key2537844,more_DASH_args2517754,process2467189,repeated2558122,results2477204,_plus13) {
var cases_DASH_val1268895 = parsed_DASH_val2598155;
var anf_fun8288861 = G(cases_DASH_val1268895,"_match",L[719]);
var anf_obj8328867 = R.makeFunction(function(v2608882) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[721],1,arguments);
}
var $z88858886 = D;
var $f88918892 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2558122,key2537844,v2608882):R.ffi.throwNonFunApp(L[722],handle_DASH_repeated2367037.$var,[results2477204,repeated2558122,key2537844,v2608882]);
};
try {
if(--R.GAS > 0) {
$z88858886 = $f88918892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88918892,
"from":L[722]});
}
} catch($e88838884) {
if(R.isCont($e88838884)) {
var $ss88878888 = {"from":L[722],
"go":function(anf_arg8308893) {
return $Hanf_arg21198894(anf_arg8308893,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
}};
$e88838884.stack[R.EXN_STACKHEIGHT++] = $ss88878888;
}
if(R.isPyretException($e88838884)) {
$e88838884.pyretStack.push(L[722]);
}
throw $e88838884;
}
var $ret88898890 = $Hanf_arg21198894($z88858886,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
++R.GAS;
return $ret88898890;
});
var anf_obj8348868 = R.makeFunction(function(e2618869) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[720],1,arguments);
}
var $z88728873 = D;
var $f88788879 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(e2618869,results2477204):R.ffi.throwNonFunApp(L[720],arg_DASH_error102113.$var,[e2618869,results2477204]);
};
try {
if(--R.GAS > 0) {
$z88728873 = $f88788879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88788879,
"from":L[720]});
}
} catch($e88708871) {
if(R.isCont($e88708871)) {
var $ss88748875 = {"from":L[720],
"go":function(ann_DASH_check_DASH_temp8338880) {
return $Hann_DASH_check_DASH_temp21208881(ann_DASH_check_DASH_temp8338880);
}};
$e88708871.stack[R.EXN_STACKHEIGHT++] = $ss88748875;
}
if(R.isPyretException($e88708871)) {
$e88708871.pyretStack.push(L[720]);
}
throw $e88708871;
}
var $ret88768877 = $Hann_DASH_check_DASH_temp21208881($z88728873);
++R.GAS;
return $ret88768877;
});
var anf_arg8358862 = R.makeObject({"left":anf_obj8328867,
"right":anf_obj8348868});
var anf_arg8378863 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[719],0,arguments);
}
var ann_DASH_check_DASH_temp8368866 = R.throwNoBranchesMatched(L[719],("cases"));
return ann_DASH_check_DASH_temp8368866;
});
var $z88538854 = D;
var $f88598860 = function(_) {
return R.isFunction(anf_fun8288861)?anf_fun8288861.app(anf_arg8358862,anf_arg8378863):R.ffi.throwNonFunApp(L[660],anf_fun8288861,[anf_arg8358862,anf_arg8378863]);
};
try {
if(--R.GAS > 0) {
$z88538854 = $f88598860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88598860,
"from":L[660]});
}
} catch($e88518852) {
if(R.isCont($e88518852)) {
var $ss88558856 = {"from":L[660],
"go":function(ann_DASH_check_DASH_temp8268864) {
return $Hann_DASH_check_DASH_temp21218865(ann_DASH_check_DASH_temp8268864);
}};
$e88518852.stack[R.EXN_STACKHEIGHT++] = $ss88558856;
}
if(R.isPyretException($e88518852)) {
$e88518852.pyretStack.push(L[660]);
}
throw $e88518852;
}
var $ret88578858 = $Hann_DASH_check_DASH_temp21218865($z88538854);
++R.GAS;
return $ret88578858;
};
var $Hann_DASH_check_DASH_temp21218865 = function(ann_DASH_check_DASH_temp8268864) {
return ann_DASH_check_DASH_temp8268864;
};
var $Hann_DASH_check_DASH_temp21208881 = function(ann_DASH_check_DASH_temp8338880) {
return ann_DASH_check_DASH_temp8338880;
};
var $Hanf_arg21198894 = function(anf_arg8308893,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13) {
var $z88988899 = D;
var $f89048905 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[723],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z88988899 = $f89048905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89048905,
"from":L[723]});
}
} catch($e88968897) {
if(R.isCont($e88968897)) {
var $ss89008901 = {"from":L[723],
"go":function(anf_arg8318906) {
return $Hanf_arg21188907(anf_arg8318906,anf_arg8308893,more_DASH_args2517754,process2467189);
}};
$e88968897.stack[R.EXN_STACKHEIGHT++] = $ss89008901;
}
if(R.isPyretException($e88968897)) {
$e88968897.pyretStack.push(L[723]);
}
throw $e88968897;
}
var $ret89028903 = $Hanf_arg21188907($z88988899,anf_arg8308893,more_DASH_args2517754,process2467189);
++R.GAS;
return $ret89028903;
};
var $Hanf_arg21188907 = function(anf_arg8318906,anf_arg8308893,more_DASH_args2517754,process2467189) {
var $z89108911 = D;
var $f89168917 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg8308893,anf_arg8318906,more_DASH_args2517754):R.ffi.throwNonFunApp(L[721],process2467189.$var,[anf_arg8308893,anf_arg8318906,more_DASH_args2517754]);
};
try {
if(--R.GAS > 0) {
$z89108911 = $f89168917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89168917,
"from":L[721]});
}
} catch($e89088909) {
if(R.isCont($e89088909)) {
var $ss89128913 = {"from":L[721],
"go":function(ann_DASH_check_DASH_temp8298918) {
return $Hann_DASH_check_DASH_temp21178919(ann_DASH_check_DASH_temp8298918);
}};
$e89088909.stack[R.EXN_STACKHEIGHT++] = $ss89128913;
}
if(R.isPyretException($e89088909)) {
$e89088909.pyretStack.push(L[721]);
}
throw $e89088909;
}
var $ret89148915 = $Hann_DASH_check_DASH_temp21178919($z89108911);
++R.GAS;
return $ret89148915;
};
var $Hann_DASH_check_DASH_temp21178919 = function(ann_DASH_check_DASH_temp8298918) {
return ann_DASH_check_DASH_temp8298918;
};
var $Hanf_array_val21168170 = function(anf_array_val8228168,anf_fun8208169,arg_DASH_error102113,format7872,key2537844,results2477204) {
var $z89228923 = D;
var $f89288929 = function(_) {
return R.isFunction(anf_fun8208169)?anf_fun8208169.app([key2537844,key2537844,anf_array_val8228168]):R.ffi.throwNonFunApp(L[666],anf_fun8208169,[[key2537844,key2537844,anf_array_val8228168]]);
};
try {
if(--R.GAS > 0) {
$z89228923 = $f89288929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89288929,
"from":L[666]});
}
} catch($e89208921) {
if(R.isCont($e89208921)) {
var $ss89248925 = {"from":L[666],
"go":function(anf_arg8238930) {
return $Hanf_arg21158931(anf_arg8238930,arg_DASH_error102113,format7872,results2477204);
}};
$e89208921.stack[R.EXN_STACKHEIGHT++] = $ss89248925;
}
if(R.isPyretException($e89208921)) {
$e89208921.pyretStack.push(L[666]);
}
throw $e89208921;
}
var $ret89268927 = $Hanf_arg21158931($z89228923,arg_DASH_error102113,format7872,results2477204);
++R.GAS;
return $ret89268927;
};
var $Hanf_arg21158931 = function(anf_arg8238930,arg_DASH_error102113,format7872,results2477204) {
var $z89348935 = D;
var $f89408941 = function(_) {
return R.isFunction(format7872)?format7872.app(("Option ~a must be of the form --~a=~a"),anf_arg8238930):R.ffi.throwNonFunApp(L[724],format7872,[("Option ~a must be of the form --~a=~a"),anf_arg8238930]);
};
try {
if(--R.GAS > 0) {
$z89348935 = $f89408941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89408941,
"from":L[724]});
}
} catch($e89328933) {
if(R.isCont($e89328933)) {
var $ss89368937 = {"from":L[724],
"go":function(anf_arg8248942) {
return $Hanf_arg21148943(anf_arg8248942,arg_DASH_error102113,results2477204);
}};
$e89328933.stack[R.EXN_STACKHEIGHT++] = $ss89368937;
}
if(R.isPyretException($e89328933)) {
$e89328933.pyretStack.push(L[724]);
}
throw $e89328933;
}
var $ret89388939 = $Hanf_arg21148943($z89348935,arg_DASH_error102113,results2477204);
++R.GAS;
return $ret89388939;
};
var $Hanf_arg21148943 = function(anf_arg8248942,arg_DASH_error102113,results2477204) {
var $z89468947 = D;
var $f89528953 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg8248942,results2477204):R.ffi.throwNonFunApp(L[663],arg_DASH_error102113.$var,[anf_arg8248942,results2477204]);
};
try {
if(--R.GAS > 0) {
$z89468947 = $f89528953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89528953,
"from":L[663]});
}
} catch($e89448945) {
if(R.isCont($e89448945)) {
var $ss89488949 = {"from":L[663],
"go":function(ann_DASH_check_DASH_temp8198954) {
return $Hann_DASH_check_DASH_temp21138955(ann_DASH_check_DASH_temp8198954);
}};
$e89448945.stack[R.EXN_STACKHEIGHT++] = $ss89488949;
}
if(R.isPyretException($e89448945)) {
$e89448945.pyretStack.push(L[663]);
}
throw $e89448945;
}
var $ret89508951 = $Hann_DASH_check_DASH_temp21138955($z89468947);
++R.GAS;
return $ret89508951;
};
var $Hann_DASH_check_DASH_temp21138955 = function(ann_DASH_check_DASH_temp8198954) {
return ann_DASH_check_DASH_temp8198954;
};
var $Hanf_arg21917871 = function(anf_arg8127870,arg_DASH_error102113,if_helper7287788,results2477204) {
var $z89588959 = D;
var $f89648965 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg8127870,results2477204):R.ffi.throwNonFunApp(L[725],arg_DASH_error102113.$var,[anf_arg8127870,results2477204]);
};
try {
if(--R.GAS > 0) {
$z89588959 = $f89648965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89648965,
"from":L[725]});
}
} catch($e89568957) {
if(R.isCont($e89568957)) {
var $ss89608961 = {"from":L[725],
"go":function(cont_tail_arg8138966) {
return $Hcont_tail_arg21908967(cont_tail_arg8138966,if_helper7287788);
}};
$e89568957.stack[R.EXN_STACKHEIGHT++] = $ss89608961;
}
if(R.isPyretException($e89568957)) {
$e89568957.pyretStack.push(L[725]);
}
throw $e89568957;
}
var $ret89628963 = $Hcont_tail_arg21908967($z89588959,if_helper7287788);
++R.GAS;
return $ret89628963;
};
var $Hcont_tail_arg21908967 = function(cont_tail_arg8138966,if_helper7287788) {
if(--R.GAS > 0) {
$z89688969 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg8138966):R.ffi.throwNonFunApp(L[725],if_helper7287788,[cont_tail_arg8138966]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg8138966):R.ffi.throwNonFunApp(L[725],if_helper7287788,[cont_tail_arg8138966]);
},
"from":L[725]});
}
++R.GAS;
return $z89688969;
};
var $Hanf_arg22287801 = function(anf_arg7337800,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,remaining2497206,results2477204,success100109,_plus13,nothing18,string_DASH_length20,string_DASH_substring22) {
var if_DASH_1178996 = R.equiv(anf_arg7337800,("-"));
var anf_if7369000 = R.isBoolean(if_DASH_1178996);
if(R.isPyretTrue(anf_if7369000)) {
if(R.isPyretTrue(if_DASH_1178996)) {
var $z89728973 = D;
var $f89788979 = function(_) {
return R.isFunction(string_DASH_length20)?string_DASH_length20.app(first2507753):R.ffi.throwNonFunApp(L[726],string_DASH_length20,[first2507753]);
};
try {
if(--R.GAS > 0) {
$z89728973 = $f89788979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89788979,
"from":L[726]});
}
} catch($e89708971) {
if(R.isCont($e89708971)) {
var $ss89748975 = {"from":L[726],
"go":function(anf_arg7428980) {
return $Hanf_arg22258981(anf_arg7428980,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18,string_DASH_substring22);
}};
$e89708971.stack[R.EXN_STACKHEIGHT++] = $ss89748975;
}
if(R.isPyretException($e89708971)) {
$e89708971.pyretStack.push(L[726]);
}
throw $e89708971;
}
var $ret89768977 = $Hanf_arg22258981($z89728973,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18,string_DASH_substring22);
++R.GAS;
return $ret89768977;
} else {
var anf_arg7378994 = G(results2477204,"parsed",L[729]);
var anf_arg7388992 = G(results2477204,"unknown",L[728]);
var $z89848985 = D;
var $f89908991 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg7388992,remaining2497206):R.ffi.throwNonFunApp(L[727],_plus13,[anf_arg7388992,remaining2497206]);
};
try {
if(--R.GAS > 0) {
$z89848985 = $f89908991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89908991,
"from":L[727]});
}
} catch($e89828983) {
if(R.isCont($e89828983)) {
var $ss89868987 = {"from":L[727],
"go":function(anf_arg7398993) {
return $Hanf_arg22278995(anf_arg7398993,anf_arg7378994,if_helper7287788,success100109);
}};
$e89828983.stack[R.EXN_STACKHEIGHT++] = $ss89868987;
}
if(R.isPyretException($e89828983)) {
$e89828983.pyretStack.push(L[727]);
}
throw $e89828983;
}
var $ret89888989 = $Hanf_arg22278995($z89848985,anf_arg7378994,if_helper7287788,success100109);
++R.GAS;
return $ret89888989;
}
} else {
var cont_tail_arg7348999 = R.throwNonBooleanCondition(L[730],("if"),if_DASH_1178996);
if(--R.GAS > 0) {
$z89978998 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7348999):R.ffi.throwNonFunApp(L[730],if_helper7287788,[cont_tail_arg7348999]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7348999):R.ffi.throwNonFunApp(L[730],if_helper7287788,[cont_tail_arg7348999]);
},
"from":L[730]});
}
++R.GAS;
return $z89978998;
}
};
var $Hanf_arg22258981 = function(anf_arg7428980,arg_DASH_error102113,cur_DASH_index2487205,first2507753,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18,string_DASH_substring22) {
var $z90039004 = D;
var $f90099010 = function(_) {
return R.isFunction(string_DASH_substring22)?string_DASH_substring22.app(first2507753,(1),anf_arg7428980):R.ffi.throwNonFunApp(L[731],string_DASH_substring22,[first2507753,(1),anf_arg7428980]);
};
try {
if(--R.GAS > 0) {
$z90039004 = $f90099010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90099010,
"from":L[731]});
}
} catch($e90019002) {
if(R.isCont($e90019002)) {
var $ss90059006 = {"from":L[731],
"go":function(key2969011) {
return $Hkey22249012(key2969011,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18);
}};
$e90019002.stack[R.EXN_STACKHEIGHT++] = $ss90059006;
}
if(R.isPyretException($e90019002)) {
$e90019002.pyretStack.push(L[731]);
}
throw $e90019002;
}
var $ret90079008 = $Hkey22249012($z90039004,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18);
++R.GAS;
return $ret90079008;
};
var $Hkey22249012 = function(key2969011,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18) {
var anf_fun7439023 = G(option_DASH_aliases2357054,"has-key",L[733]);
var $z90159016 = D;
var $f90219022 = function(_) {
return R.isFunction(anf_fun7439023)?anf_fun7439023.app(key2969011):R.ffi.throwNonFunApp(L[732],anf_fun7439023,[key2969011]);
};
try {
if(--R.GAS > 0) {
$z90159016 = $f90219022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90219022,
"from":L[732]});
}
} catch($e90139014) {
if(R.isCont($e90139014)) {
var $ss90179018 = {"from":L[732],
"go":function(and_DASH_oper_DASH_1209024) {
return $Hand_DASH_oper_DASH_22239025(and_DASH_oper_DASH_1209024,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,key2969011,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18);
}};
$e90139014.stack[R.EXN_STACKHEIGHT++] = $ss90179018;
}
if(R.isPyretException($e90139014)) {
$e90139014.pyretStack.push(L[732]);
}
throw $e90139014;
}
var $ret90199020 = $Hand_DASH_oper_DASH_22239025($z90159016,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,key2969011,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18);
++R.GAS;
return $ret90199020;
};
var $Hand_DASH_oper_DASH_22239025 = function(and_DASH_oper_DASH_1209024,arg_DASH_error102113,cur_DASH_index2487205,format7872,full_DASH_options2347053,handle_DASH_repeated2367037,if_helper7287788,is_DASH_Param_127163,key2969011,list2776,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13,nothing18) {
var if_helper7449039 = R.makeFunction(function(if_helper_arg7459057) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[732],1,arguments);
}
var if_DASH_1199086 = if_helper_arg7459057;
var if_helper7469071 = R.makeFunction(function(if_helper_arg7479091) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[732],1,arguments);
}
var lookup2979102 = if_helper_arg7479091;
var $z90949095 = D;
var $f91009101 = function(_) {
return R.isFunction(is_DASH_Param_127163.$var)?is_DASH_Param_127163.$var.app(lookup2979102):R.ffi.throwNonFunApp(L[743],is_DASH_Param_127163.$var,[lookup2979102]);
};
try {
if(--R.GAS > 0) {
$z90949095 = $f91009101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91009101,
"from":L[743]});
}
} catch($e90929093) {
if(R.isCont($e90929093)) {
var $ss90969097 = {"from":L[743],
"go":function(if_DASH_1229103) {
return $Hif_DASH_22139104(if_DASH_1229103,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper7287788,key2969011,list2776,lookup2979102,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13);
}};
$e90929093.stack[R.EXN_STACKHEIGHT++] = $ss90969097;
}
if(R.isPyretException($e90929093)) {
$e90929093.pyretStack.push(L[743]);
}
throw $e90929093;
}
var $ret90989099 = $Hif_DASH_22139104($z90949095,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper7287788,key2969011,list2776,lookup2979102,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13);
++R.GAS;
return $ret90989099;
});
var anf_if7819090 = R.isBoolean(if_DASH_1199086);
if(R.isPyretTrue(anf_if7819090)) {
if(R.isPyretTrue(if_DASH_1199086)) {
var anf_fun7909070 = G(full_DASH_options2347053,"get",L[740]);
var anf_fun7919068 = G(option_DASH_aliases2357054,"get",L[739]);
var $z90609061 = D;
var $f90669067 = function(_) {
return R.isFunction(anf_fun7919068)?anf_fun7919068.app(key2969011):R.ffi.throwNonFunApp(L[738],anf_fun7919068,[key2969011]);
};
try {
if(--R.GAS > 0) {
$z90609061 = $f90669067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90669067,
"from":L[738]});
}
} catch($e90589059) {
if(R.isCont($e90589059)) {
var $ss90629063 = {"from":L[738],
"go":function(anf_arg7929069) {
return $Hanf_arg22159072(anf_arg7929069,anf_fun7909070,if_helper7469071);
}};
$e90589059.stack[R.EXN_STACKHEIGHT++] = $ss90629063;
}
if(R.isPyretException($e90589059)) {
$e90589059.pyretStack.push(L[738]);
}
throw $e90589059;
}
var $ret90649065 = $Hanf_arg22159072($z90609061,anf_fun7909070,if_helper7469071);
++R.GAS;
return $ret90649065;
} else {
var anf_fun7829083 = G(full_DASH_options2347053,"has-key",L[742]);
var $z90759076 = D;
var $f90819082 = function(_) {
return R.isFunction(anf_fun7829083)?anf_fun7829083.app(key2969011):R.ffi.throwNonFunApp(L[741],anf_fun7829083,[key2969011]);
};
try {
if(--R.GAS > 0) {
$z90759076 = $f90819082();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90819082,
"from":L[741]});
}
} catch($e90739074) {
if(R.isCont($e90739074)) {
var $ss90779078 = {"from":L[741],
"go":function(if_DASH_1189084) {
return $Hif_DASH_22189085(if_DASH_1189084,full_DASH_options2347053,if_helper7469071,key2969011,nothing18);
}};
$e90739074.stack[R.EXN_STACKHEIGHT++] = $ss90779078;
}
if(R.isPyretException($e90739074)) {
$e90739074.pyretStack.push(L[741]);
}
throw $e90739074;
}
var $ret90799080 = $Hif_DASH_22189085($z90759076,full_DASH_options2347053,if_helper7469071,key2969011,nothing18);
++R.GAS;
return $ret90799080;
}
} else {
var cont_tail_arg7799089 = R.throwNonBooleanCondition(L[732],("if"),if_DASH_1199086);
if(--R.GAS > 0) {
$z90879088 = R.isFunction(if_helper7469071)?if_helper7469071.app(cont_tail_arg7799089):R.ffi.throwNonFunApp(L[732],if_helper7469071,[cont_tail_arg7799089]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7469071)?if_helper7469071.app(cont_tail_arg7799089):R.ffi.throwNonFunApp(L[732],if_helper7469071,[cont_tail_arg7799089]);
},
"from":L[732]});
}
++R.GAS;
return $z90879088;
}
});
var anf_if7979056 = R.isBoolean(and_DASH_oper_DASH_1209024);
if(R.isPyretTrue(anf_if7979056)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1209024)) {
var anf_fun7999038 = G(full_DASH_options2347053,"has-key",L[736]);
var anf_fun8009036 = G(option_DASH_aliases2357054,"get",L[735]);
var $z90289029 = D;
var $f90349035 = function(_) {
return R.isFunction(anf_fun8009036)?anf_fun8009036.app(key2969011):R.ffi.throwNonFunApp(L[734],anf_fun8009036,[key2969011]);
};
try {
if(--R.GAS > 0) {
$z90289029 = $f90349035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90349035,
"from":L[734]});
}
} catch($e90269027) {
if(R.isCont($e90269027)) {
var $ss90309031 = {"from":L[734],
"go":function(anf_arg8019037) {
return $Hanf_arg22219040(anf_arg8019037,anf_fun7999038,if_helper7449039);
}};
$e90269027.stack[R.EXN_STACKHEIGHT++] = $ss90309031;
}
if(R.isPyretException($e90269027)) {
$e90269027.pyretStack.push(L[734]);
}
throw $e90269027;
}
var $ret90329033 = $Hanf_arg22219040($z90289029,anf_fun7999038,if_helper7449039);
++R.GAS;
return $ret90329033;
} else {
var $z90439044 = D;
var $f90499050 = function(_) {
return R.isFunction(if_helper7449039)?if_helper7449039.app((false)):R.ffi.throwNonFunApp(L[732],if_helper7449039,[(false)]);
};
try {
if(--R.GAS > 0) {
$z90439044 = $f90499050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90499050,
"from":L[732]});
}
} catch($e90419042) {
if(R.isCont($e90419042)) {
var $ss90459046 = {"from":L[732],
"go":function(cont_tail_app7989051) {
return $Hcont_tail_app22229052(cont_tail_app7989051);
}};
$e90419042.stack[R.EXN_STACKHEIGHT++] = $ss90459046;
}
if(R.isPyretException($e90419042)) {
$e90419042.pyretStack.push(L[732]);
}
throw $e90419042;
}
var $ret90479048 = $Hcont_tail_app22229052($z90439044);
++R.GAS;
return $ret90479048;
}
} else {
var cont_tail_arg7959055 = R.throwNonBooleanOp(L[737],("first"),("and"),and_DASH_oper_DASH_1209024);
if(--R.GAS > 0) {
$z90539054 = R.isFunction(if_helper7449039)?if_helper7449039.app(cont_tail_arg7959055):R.ffi.throwNonFunApp(L[737],if_helper7449039,[cont_tail_arg7959055]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7449039)?if_helper7449039.app(cont_tail_arg7959055):R.ffi.throwNonFunApp(L[737],if_helper7449039,[cont_tail_arg7959055]);
},
"from":L[737]});
}
++R.GAS;
return $z90539054;
}
};
var $Hanf_arg22219040 = function(anf_arg8019037,anf_fun7999038,if_helper7449039) {
var $z91079108 = D;
var $f91139114 = function(_) {
return R.isFunction(anf_fun7999038)?anf_fun7999038.app(anf_arg8019037):R.ffi.throwNonFunApp(L[732],anf_fun7999038,[anf_arg8019037]);
};
try {
if(--R.GAS > 0) {
$z91079108 = $f91139114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91139114,
"from":L[732]});
}
} catch($e91059106) {
if(R.isCont($e91059106)) {
var $ss91099110 = {"from":L[732],
"go":function(and_DASH_oper_DASH_1219115) {
return $Hand_DASH_oper_DASH_22209116(and_DASH_oper_DASH_1219115,if_helper7449039);
}};
$e91059106.stack[R.EXN_STACKHEIGHT++] = $ss91099110;
}
if(R.isPyretException($e91059106)) {
$e91059106.pyretStack.push(L[732]);
}
throw $e91059106;
}
var $ret91119112 = $Hand_DASH_oper_DASH_22209116($z91079108,if_helper7449039);
++R.GAS;
return $ret91119112;
};
var $Hand_DASH_oper_DASH_22209116 = function(and_DASH_oper_DASH_1219115,if_helper7449039) {
var anf_if8049132 = R.isBoolean(and_DASH_oper_DASH_1219115);
if(R.isPyretTrue(anf_if8049132)) {
var $z91199120 = D;
var $f91259126 = function(_) {
return R.isFunction(if_helper7449039)?if_helper7449039.app(and_DASH_oper_DASH_1219115):R.ffi.throwNonFunApp(L[732],if_helper7449039,[and_DASH_oper_DASH_1219115]);
};
try {
if(--R.GAS > 0) {
$z91199120 = $f91259126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91259126,
"from":L[732]});
}
} catch($e91179118) {
if(R.isCont($e91179118)) {
var $ss91219122 = {"from":L[732],
"go":function(cont_tail_app8059127) {
return $Hcont_tail_app22199128(cont_tail_app8059127);
}};
$e91179118.stack[R.EXN_STACKHEIGHT++] = $ss91219122;
}
if(R.isPyretException($e91179118)) {
$e91179118.pyretStack.push(L[732]);
}
throw $e91179118;
}
var $ret91239124 = $Hcont_tail_app22199128($z91199120);
++R.GAS;
return $ret91239124;
} else {
var cont_tail_arg8029131 = R.throwNonBooleanOp(L[744],("second"),("and"),and_DASH_oper_DASH_1219115);
if(--R.GAS > 0) {
$z91299130 = R.isFunction(if_helper7449039)?if_helper7449039.app(cont_tail_arg8029131):R.ffi.throwNonFunApp(L[744],if_helper7449039,[cont_tail_arg8029131]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7449039)?if_helper7449039.app(cont_tail_arg8029131):R.ffi.throwNonFunApp(L[744],if_helper7449039,[cont_tail_arg8029131]);
},
"from":L[744]});
}
++R.GAS;
return $z91299130;
}
};
var $Hcont_tail_app22199128 = function(cont_tail_app8059127) {
return cont_tail_app8059127;
};
var $Hcont_tail_app22229052 = function(cont_tail_app7989051) {
return cont_tail_app7989051;
};
var $Hanf_arg22159072 = function(anf_arg7929069,anf_fun7909070,if_helper7469071) {
var $z91359136 = D;
var $f91419142 = function(_) {
return R.isFunction(anf_fun7909070)?anf_fun7909070.app(anf_arg7929069):R.ffi.throwNonFunApp(L[745],anf_fun7909070,[anf_arg7929069]);
};
try {
if(--R.GAS > 0) {
$z91359136 = $f91419142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91419142,
"from":L[745]});
}
} catch($e91339134) {
if(R.isCont($e91339134)) {
var $ss91379138 = {"from":L[745],
"go":function(cont_tail_arg7939143) {
return $Hcont_tail_arg22149144(cont_tail_arg7939143,if_helper7469071);
}};
$e91339134.stack[R.EXN_STACKHEIGHT++] = $ss91379138;
}
if(R.isPyretException($e91339134)) {
$e91339134.pyretStack.push(L[745]);
}
throw $e91339134;
}
var $ret91399140 = $Hcont_tail_arg22149144($z91359136,if_helper7469071);
++R.GAS;
return $ret91399140;
};
var $Hcont_tail_arg22149144 = function(cont_tail_arg7939143,if_helper7469071) {
if(--R.GAS > 0) {
$z91459146 = R.isFunction(if_helper7469071)?if_helper7469071.app(cont_tail_arg7939143):R.ffi.throwNonFunApp(L[745],if_helper7469071,[cont_tail_arg7939143]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7469071)?if_helper7469071.app(cont_tail_arg7939143):R.ffi.throwNonFunApp(L[745],if_helper7469071,[cont_tail_arg7939143]);
},
"from":L[745]});
}
++R.GAS;
return $z91459146;
};
var $Hif_DASH_22189085 = function(if_DASH_1189084,full_DASH_options2347053,if_helper7469071,key2969011,nothing18) {
var anf_if7859175 = R.isBoolean(if_DASH_1189084);
if(R.isPyretTrue(anf_if7859175)) {
if(R.isPyretTrue(if_DASH_1189084)) {
var anf_fun7879157 = G(full_DASH_options2347053,"get",L[747]);
var $z91499150 = D;
var $f91559156 = function(_) {
return R.isFunction(anf_fun7879157)?anf_fun7879157.app(key2969011):R.ffi.throwNonFunApp(L[746],anf_fun7879157,[key2969011]);
};
try {
if(--R.GAS > 0) {
$z91499150 = $f91559156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91559156,
"from":L[746]});
}
} catch($e91479148) {
if(R.isCont($e91479148)) {
var $ss91519152 = {"from":L[746],
"go":function(cont_tail_arg7889158) {
return $Hcont_tail_arg22169159(cont_tail_arg7889158,if_helper7469071);
}};
$e91479148.stack[R.EXN_STACKHEIGHT++] = $ss91519152;
}
if(R.isPyretException($e91479148)) {
$e91479148.pyretStack.push(L[746]);
}
throw $e91479148;
}
var $ret91539154 = $Hcont_tail_arg22169159($z91499150,if_helper7469071);
++R.GAS;
return $ret91539154;
} else {
var $z91629163 = D;
var $f91689169 = function(_) {
return R.isFunction(if_helper7469071)?if_helper7469071.app(nothing18):R.ffi.throwNonFunApp(L[748],if_helper7469071,[nothing18]);
};
try {
if(--R.GAS > 0) {
$z91629163 = $f91689169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91689169,
"from":L[748]});
}
} catch($e91609161) {
if(R.isCont($e91609161)) {
var $ss91649165 = {"from":L[748],
"go":function(cont_tail_app7869170) {
return $Hcont_tail_app22179171(cont_tail_app7869170);
}};
$e91609161.stack[R.EXN_STACKHEIGHT++] = $ss91649165;
}
if(R.isPyretException($e91609161)) {
$e91609161.pyretStack.push(L[748]);
}
throw $e91609161;
}
var $ret91669167 = $Hcont_tail_app22179171($z91629163);
++R.GAS;
return $ret91669167;
}
} else {
var cont_tail_arg7839174 = R.throwNonBooleanCondition(L[749],("if"),if_DASH_1189084);
if(--R.GAS > 0) {
$z91729173 = R.isFunction(if_helper7469071)?if_helper7469071.app(cont_tail_arg7839174):R.ffi.throwNonFunApp(L[749],if_helper7469071,[cont_tail_arg7839174]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7469071)?if_helper7469071.app(cont_tail_arg7839174):R.ffi.throwNonFunApp(L[749],if_helper7469071,[cont_tail_arg7839174]);
},
"from":L[749]});
}
++R.GAS;
return $z91729173;
}
};
var $Hcont_tail_arg22169159 = function(cont_tail_arg7889158,if_helper7469071) {
if(--R.GAS > 0) {
$z91769177 = R.isFunction(if_helper7469071)?if_helper7469071.app(cont_tail_arg7889158):R.ffi.throwNonFunApp(L[746],if_helper7469071,[cont_tail_arg7889158]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7469071)?if_helper7469071.app(cont_tail_arg7889158):R.ffi.throwNonFunApp(L[746],if_helper7469071,[cont_tail_arg7889158]);
},
"from":L[746]});
}
++R.GAS;
return $z91769177;
};
var $Hcont_tail_app22179171 = function(cont_tail_app7869170) {
return cont_tail_app7869170;
};
var $Hif_DASH_22139104 = function(if_DASH_1229103,arg_DASH_error102113,cur_DASH_index2487205,format7872,handle_DASH_repeated2367037,if_helper7287788,key2969011,list2776,lookup2979102,more_DASH_args2517754,option_DASH_aliases2357054,process2467189,results2477204,_plus13) {
var anf_if7509275 = R.isBoolean(if_DASH_1229103);
if(R.isPyretTrue(anf_if7509275)) {
if(R.isPyretTrue(if_DASH_1229103)) {
var cases_DASH_val1239259 = lookup2979102;
var anf_fun7549188 = G(cases_DASH_val1239259,"_match",L[750]);
var anf_obj7589206 = R.makeFunction(function(repeated2989245,$underscore2999246) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[758],2,arguments);
}
var $z92499250 = D;
var $f92559256 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated2989245,key2969011,(true)):R.ffi.throwNonFunApp(L[759],handle_DASH_repeated2367037.$var,[results2477204,repeated2989245,key2969011,(true)]);
};
try {
if(--R.GAS > 0) {
$z92499250 = $f92559256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92559256,
"from":L[759]});
}
} catch($e92479248) {
if(R.isCont($e92479248)) {
var $ss92519252 = {"from":L[759],
"go":function(anf_arg7569257) {
return $Hanf_arg21989258(anf_arg7569257,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
}};
$e92479248.stack[R.EXN_STACKHEIGHT++] = $ss92519252;
}
if(R.isPyretException($e92479248)) {
$e92479248.pyretStack.push(L[759]);
}
throw $e92479248;
}
var $ret92539254 = $Hanf_arg21989258($z92499250,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
++R.GAS;
return $ret92539254;
});
var anf_obj7649207 = R.makeFunction(function($underscore3009227,default3019228,$underscore3029229,repeated3039230,$underscore3049231) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[755],5,arguments);
}
var anf_fun7609242 = G(option_DASH_aliases2357054,"get",L[757]);
var $z92349235 = D;
var $f92409241 = function(_) {
return R.isFunction(anf_fun7609242)?anf_fun7609242.app(key2969011):R.ffi.throwNonFunApp(L[756],anf_fun7609242,[key2969011]);
};
try {
if(--R.GAS > 0) {
$z92349235 = $f92409241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92409241,
"from":L[756]});
}
} catch($e92329233) {
if(R.isCont($e92329233)) {
var $ss92369237 = {"from":L[756],
"go":function(anf_arg7619243) {
return $Hanf_arg22029244(anf_arg7619243,cur_DASH_index2487205,default3019228,handle_DASH_repeated2367037,more_DASH_args2517754,process2467189,repeated3039230,results2477204,_plus13);
}};
$e92329233.stack[R.EXN_STACKHEIGHT++] = $ss92369237;
}
if(R.isPyretException($e92329233)) {
$e92329233.pyretStack.push(L[756]);
}
throw $e92329233;
}
var $ret92389239 = $Hanf_arg22029244($z92349235,cur_DASH_index2487205,default3019228,handle_DASH_repeated2367037,more_DASH_args2517754,process2467189,repeated3039230,results2477204,_plus13);
++R.GAS;
return $ret92389239;
});
var anf_obj7709208 = R.makeFunction(function($underscore3059209,default3069210,$underscore3079211,repeated3089212,$underscore3099213) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[752],5,arguments);
}
var anf_fun7669224 = G(option_DASH_aliases2357054,"get",L[754]);
var $z92169217 = D;
var $f92229223 = function(_) {
return R.isFunction(anf_fun7669224)?anf_fun7669224.app(key2969011):R.ffi.throwNonFunApp(L[753],anf_fun7669224,[key2969011]);
};
try {
if(--R.GAS > 0) {
$z92169217 = $f92229223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92229223,
"from":L[753]});
}
} catch($e92149215) {
if(R.isCont($e92149215)) {
var $ss92189219 = {"from":L[753],
"go":function(anf_arg7679225) {
return $Hanf_arg22069226(anf_arg7679225,cur_DASH_index2487205,default3069210,handle_DASH_repeated2367037,more_DASH_args2517754,process2467189,repeated3089212,results2477204,_plus13);
}};
$e92149215.stack[R.EXN_STACKHEIGHT++] = $ss92189219;
}
if(R.isPyretException($e92149215)) {
$e92149215.pyretStack.push(L[753]);
}
throw $e92149215;
}
var $ret92209221 = $Hanf_arg22069226($z92169217,cur_DASH_index2487205,default3069210,handle_DASH_repeated2367037,more_DASH_args2517754,process2467189,repeated3089212,results2477204,_plus13);
++R.GAS;
return $ret92209221;
});
var anf_arg7719189 = R.makeObject({"flag":anf_obj7589206,
"equals-val-default":anf_obj7649207,
"next-val-default":anf_obj7709208});
var anf_arg7769190 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[750],0,arguments);
}
var anf_fun7739203 = G(list2776,"make",L[751]);
var $z91959196 = D;
var $f92019202 = function(_) {
return R.isFunction(anf_fun7739203)?anf_fun7739203.app([key2969011]):R.ffi.throwNonFunApp(L[751],anf_fun7739203,[[key2969011]]);
};
try {
if(--R.GAS > 0) {
$z91959196 = $f92019202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92019202,
"from":L[751]});
}
} catch($e91939194) {
if(R.isCont($e91939194)) {
var $ss91979198 = {"from":L[751],
"go":function(anf_arg7749204) {
return $Hanf_arg22099205(anf_arg7749204,arg_DASH_error102113,format7872,results2477204);
}};
$e91939194.stack[R.EXN_STACKHEIGHT++] = $ss91979198;
}
if(R.isPyretException($e91939194)) {
$e91939194.pyretStack.push(L[751]);
}
throw $e91939194;
}
var $ret91999200 = $Hanf_arg22099205($z91959196,arg_DASH_error102113,format7872,results2477204);
++R.GAS;
return $ret91999200;
});
var $z91809181 = D;
var $f91869187 = function(_) {
return R.isFunction(anf_fun7549188)?anf_fun7549188.app(anf_arg7719189,anf_arg7769190):R.ffi.throwNonFunApp(L[750],anf_fun7549188,[anf_arg7719189,anf_arg7769190]);
};
try {
if(--R.GAS > 0) {
$z91809181 = $f91869187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91869187,
"from":L[750]});
}
} catch($e91789179) {
if(R.isCont($e91789179)) {
var $ss91829183 = {"from":L[750],
"go":function(cont_tail_arg7779191) {
return $Hcont_tail_arg22109192(cont_tail_arg7779191,if_helper7287788);
}};
$e91789179.stack[R.EXN_STACKHEIGHT++] = $ss91829183;
}
if(R.isPyretException($e91789179)) {
$e91789179.pyretStack.push(L[750]);
}
throw $e91789179;
}
var $ret91849185 = $Hcont_tail_arg22109192($z91809181,if_helper7287788);
++R.GAS;
return $ret91849185;
} else {
var $z92629263 = D;
var $f92689269 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Unknown command line option -"),key2969011):R.ffi.throwNonFunApp(L[760],_plus13,[("Unknown command line option -"),key2969011]);
};
try {
if(--R.GAS > 0) {
$z92629263 = $f92689269();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92689269,
"from":L[760]});
}
} catch($e92609261) {
if(R.isCont($e92609261)) {
var $ss92649265 = {"from":L[760],
"go":function(anf_arg7519270) {
return $Hanf_arg22129271(anf_arg7519270,arg_DASH_error102113,if_helper7287788,results2477204);
}};
$e92609261.stack[R.EXN_STACKHEIGHT++] = $ss92649265;
}
if(R.isPyretException($e92609261)) {
$e92609261.pyretStack.push(L[760]);
}
throw $e92609261;
}
var $ret92669267 = $Hanf_arg22129271($z92629263,arg_DASH_error102113,if_helper7287788,results2477204);
++R.GAS;
return $ret92669267;
}
} else {
var cont_tail_arg7489274 = R.throwNonBooleanCondition(L[743],("if"),if_DASH_1229103);
if(--R.GAS > 0) {
$z92729273 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7489274):R.ffi.throwNonFunApp(L[743],if_helper7287788,[cont_tail_arg7489274]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7489274):R.ffi.throwNonFunApp(L[743],if_helper7287788,[cont_tail_arg7489274]);
},
"from":L[743]});
}
++R.GAS;
return $z92729273;
}
};
var $Hcont_tail_arg22109192 = function(cont_tail_arg7779191,if_helper7287788) {
if(--R.GAS > 0) {
$z92769277 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7779191):R.ffi.throwNonFunApp(L[750],if_helper7287788,[cont_tail_arg7779191]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7779191):R.ffi.throwNonFunApp(L[750],if_helper7287788,[cont_tail_arg7779191]);
},
"from":L[750]});
}
++R.GAS;
return $z92769277;
};
var $Hanf_arg22099205 = function(anf_arg7749204,arg_DASH_error102113,format7872,results2477204) {
var $z92809281 = D;
var $f92869287 = function(_) {
return R.isFunction(format7872)?format7872.app(("Command line option --~a must start with two dashes"),anf_arg7749204):R.ffi.throwNonFunApp(L[761],format7872,[("Command line option --~a must start with two dashes"),anf_arg7749204]);
};
try {
if(--R.GAS > 0) {
$z92809281 = $f92869287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92869287,
"from":L[761]});
}
} catch($e92789279) {
if(R.isCont($e92789279)) {
var $ss92829283 = {"from":L[761],
"go":function(anf_arg7759288) {
return $Hanf_arg22089289(anf_arg7759288,arg_DASH_error102113,results2477204);
}};
$e92789279.stack[R.EXN_STACKHEIGHT++] = $ss92829283;
}
if(R.isPyretException($e92789279)) {
$e92789279.pyretStack.push(L[761]);
}
throw $e92789279;
}
var $ret92849285 = $Hanf_arg22089289($z92809281,arg_DASH_error102113,results2477204);
++R.GAS;
return $ret92849285;
};
var $Hanf_arg22089289 = function(anf_arg7759288,arg_DASH_error102113,results2477204) {
var $z92929293 = D;
var $f92989299 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg7759288,results2477204):R.ffi.throwNonFunApp(L[750],arg_DASH_error102113.$var,[anf_arg7759288,results2477204]);
};
try {
if(--R.GAS > 0) {
$z92929293 = $f92989299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92989299,
"from":L[750]});
}
} catch($e92909291) {
if(R.isCont($e92909291)) {
var $ss92949295 = {"from":L[750],
"go":function(ann_DASH_check_DASH_temp7729300) {
return $Hann_DASH_check_DASH_temp22079301(ann_DASH_check_DASH_temp7729300);
}};
$e92909291.stack[R.EXN_STACKHEIGHT++] = $ss92949295;
}
if(R.isPyretException($e92909291)) {
$e92909291.pyretStack.push(L[750]);
}
throw $e92909291;
}
var $ret92969297 = $Hann_DASH_check_DASH_temp22079301($z92929293);
++R.GAS;
return $ret92969297;
};
var $Hann_DASH_check_DASH_temp22079301 = function(ann_DASH_check_DASH_temp7729300) {
return ann_DASH_check_DASH_temp7729300;
};
var $Hanf_arg22069226 = function(anf_arg7679225,cur_DASH_index2487205,default3069210,handle_DASH_repeated2367037,more_DASH_args2517754,process2467189,repeated3089212,results2477204,_plus13) {
var $z93049305 = D;
var $f93109311 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated3089212,anf_arg7679225,default3069210):R.ffi.throwNonFunApp(L[762],handle_DASH_repeated2367037.$var,[results2477204,repeated3089212,anf_arg7679225,default3069210]);
};
try {
if(--R.GAS > 0) {
$z93049305 = $f93109311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93109311,
"from":L[762]});
}
} catch($e93029303) {
if(R.isCont($e93029303)) {
var $ss93069307 = {"from":L[762],
"go":function(anf_arg7689312) {
return $Hanf_arg22059313(anf_arg7689312,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
}};
$e93029303.stack[R.EXN_STACKHEIGHT++] = $ss93069307;
}
if(R.isPyretException($e93029303)) {
$e93029303.pyretStack.push(L[762]);
}
throw $e93029303;
}
var $ret93089309 = $Hanf_arg22059313($z93049305,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
++R.GAS;
return $ret93089309;
};
var $Hanf_arg22059313 = function(anf_arg7689312,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13) {
var $z93169317 = D;
var $f93229323 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[763],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z93169317 = $f93229323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93229323,
"from":L[763]});
}
} catch($e93149315) {
if(R.isCont($e93149315)) {
var $ss93189319 = {"from":L[763],
"go":function(anf_arg7699324) {
return $Hanf_arg22049325(anf_arg7699324,anf_arg7689312,more_DASH_args2517754,process2467189);
}};
$e93149315.stack[R.EXN_STACKHEIGHT++] = $ss93189319;
}
if(R.isPyretException($e93149315)) {
$e93149315.pyretStack.push(L[763]);
}
throw $e93149315;
}
var $ret93209321 = $Hanf_arg22049325($z93169317,anf_arg7689312,more_DASH_args2517754,process2467189);
++R.GAS;
return $ret93209321;
};
var $Hanf_arg22049325 = function(anf_arg7699324,anf_arg7689312,more_DASH_args2517754,process2467189) {
var $z93289329 = D;
var $f93349335 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg7689312,anf_arg7699324,more_DASH_args2517754):R.ffi.throwNonFunApp(L[752],process2467189.$var,[anf_arg7689312,anf_arg7699324,more_DASH_args2517754]);
};
try {
if(--R.GAS > 0) {
$z93289329 = $f93349335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93349335,
"from":L[752]});
}
} catch($e93269327) {
if(R.isCont($e93269327)) {
var $ss93309331 = {"from":L[752],
"go":function(ann_DASH_check_DASH_temp7659336) {
return $Hann_DASH_check_DASH_temp22039337(ann_DASH_check_DASH_temp7659336);
}};
$e93269327.stack[R.EXN_STACKHEIGHT++] = $ss93309331;
}
if(R.isPyretException($e93269327)) {
$e93269327.pyretStack.push(L[752]);
}
throw $e93269327;
}
var $ret93329333 = $Hann_DASH_check_DASH_temp22039337($z93289329);
++R.GAS;
return $ret93329333;
};
var $Hann_DASH_check_DASH_temp22039337 = function(ann_DASH_check_DASH_temp7659336) {
return ann_DASH_check_DASH_temp7659336;
};
var $Hanf_arg22029244 = function(anf_arg7619243,cur_DASH_index2487205,default3019228,handle_DASH_repeated2367037,more_DASH_args2517754,process2467189,repeated3039230,results2477204,_plus13) {
var $z93409341 = D;
var $f93469347 = function(_) {
return R.isFunction(handle_DASH_repeated2367037.$var)?handle_DASH_repeated2367037.$var.app(results2477204,repeated3039230,anf_arg7619243,default3019228):R.ffi.throwNonFunApp(L[764],handle_DASH_repeated2367037.$var,[results2477204,repeated3039230,anf_arg7619243,default3019228]);
};
try {
if(--R.GAS > 0) {
$z93409341 = $f93469347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93469347,
"from":L[764]});
}
} catch($e93389339) {
if(R.isCont($e93389339)) {
var $ss93429343 = {"from":L[764],
"go":function(anf_arg7629348) {
return $Hanf_arg22019349(anf_arg7629348,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
}};
$e93389339.stack[R.EXN_STACKHEIGHT++] = $ss93429343;
}
if(R.isPyretException($e93389339)) {
$e93389339.pyretStack.push(L[764]);
}
throw $e93389339;
}
var $ret93449345 = $Hanf_arg22019349($z93409341,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13);
++R.GAS;
return $ret93449345;
};
var $Hanf_arg22019349 = function(anf_arg7629348,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13) {
var $z93529353 = D;
var $f93589359 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[765],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z93529353 = $f93589359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93589359,
"from":L[765]});
}
} catch($e93509351) {
if(R.isCont($e93509351)) {
var $ss93549355 = {"from":L[765],
"go":function(anf_arg7639360) {
return $Hanf_arg22009361(anf_arg7639360,anf_arg7629348,more_DASH_args2517754,process2467189);
}};
$e93509351.stack[R.EXN_STACKHEIGHT++] = $ss93549355;
}
if(R.isPyretException($e93509351)) {
$e93509351.pyretStack.push(L[765]);
}
throw $e93509351;
}
var $ret93569357 = $Hanf_arg22009361($z93529353,anf_arg7629348,more_DASH_args2517754,process2467189);
++R.GAS;
return $ret93569357;
};
var $Hanf_arg22009361 = function(anf_arg7639360,anf_arg7629348,more_DASH_args2517754,process2467189) {
var $z93649365 = D;
var $f93709371 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg7629348,anf_arg7639360,more_DASH_args2517754):R.ffi.throwNonFunApp(L[755],process2467189.$var,[anf_arg7629348,anf_arg7639360,more_DASH_args2517754]);
};
try {
if(--R.GAS > 0) {
$z93649365 = $f93709371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93709371,
"from":L[755]});
}
} catch($e93629363) {
if(R.isCont($e93629363)) {
var $ss93669367 = {"from":L[755],
"go":function(ann_DASH_check_DASH_temp7599372) {
return $Hann_DASH_check_DASH_temp21999373(ann_DASH_check_DASH_temp7599372);
}};
$e93629363.stack[R.EXN_STACKHEIGHT++] = $ss93669367;
}
if(R.isPyretException($e93629363)) {
$e93629363.pyretStack.push(L[755]);
}
throw $e93629363;
}
var $ret93689369 = $Hann_DASH_check_DASH_temp21999373($z93649365);
++R.GAS;
return $ret93689369;
};
var $Hann_DASH_check_DASH_temp21999373 = function(ann_DASH_check_DASH_temp7599372) {
return ann_DASH_check_DASH_temp7599372;
};
var $Hanf_arg21989258 = function(anf_arg7569257,cur_DASH_index2487205,more_DASH_args2517754,process2467189,_plus13) {
var $z93769377 = D;
var $f93829383 = function(_) {
return R.isFunction(_plus13)?_plus13.app(cur_DASH_index2487205,(1)):R.ffi.throwNonFunApp(L[766],_plus13,[cur_DASH_index2487205,(1)]);
};
try {
if(--R.GAS > 0) {
$z93769377 = $f93829383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93829383,
"from":L[766]});
}
} catch($e93749375) {
if(R.isCont($e93749375)) {
var $ss93789379 = {"from":L[766],
"go":function(anf_arg7579384) {
return $Hanf_arg21979385(anf_arg7579384,anf_arg7569257,more_DASH_args2517754,process2467189);
}};
$e93749375.stack[R.EXN_STACKHEIGHT++] = $ss93789379;
}
if(R.isPyretException($e93749375)) {
$e93749375.pyretStack.push(L[766]);
}
throw $e93749375;
}
var $ret93809381 = $Hanf_arg21979385($z93769377,anf_arg7569257,more_DASH_args2517754,process2467189);
++R.GAS;
return $ret93809381;
};
var $Hanf_arg21979385 = function(anf_arg7579384,anf_arg7569257,more_DASH_args2517754,process2467189) {
var $z93889389 = D;
var $f93949395 = function(_) {
return R.isFunction(process2467189.$var)?process2467189.$var.app(anf_arg7569257,anf_arg7579384,more_DASH_args2517754):R.ffi.throwNonFunApp(L[758],process2467189.$var,[anf_arg7569257,anf_arg7579384,more_DASH_args2517754]);
};
try {
if(--R.GAS > 0) {
$z93889389 = $f93949395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93949395,
"from":L[758]});
}
} catch($e93869387) {
if(R.isCont($e93869387)) {
var $ss93909391 = {"from":L[758],
"go":function(ann_DASH_check_DASH_temp7559396) {
return $Hann_DASH_check_DASH_temp21969397(ann_DASH_check_DASH_temp7559396);
}};
$e93869387.stack[R.EXN_STACKHEIGHT++] = $ss93909391;
}
if(R.isPyretException($e93869387)) {
$e93869387.pyretStack.push(L[758]);
}
throw $e93869387;
}
var $ret93929393 = $Hann_DASH_check_DASH_temp21969397($z93889389);
++R.GAS;
return $ret93929393;
};
var $Hann_DASH_check_DASH_temp21969397 = function(ann_DASH_check_DASH_temp7559396) {
return ann_DASH_check_DASH_temp7559396;
};
var $Hanf_arg22129271 = function(anf_arg7519270,arg_DASH_error102113,if_helper7287788,results2477204) {
var $z94009401 = D;
var $f94069407 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg7519270,results2477204):R.ffi.throwNonFunApp(L[767],arg_DASH_error102113.$var,[anf_arg7519270,results2477204]);
};
try {
if(--R.GAS > 0) {
$z94009401 = $f94069407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94069407,
"from":L[767]});
}
} catch($e93989399) {
if(R.isCont($e93989399)) {
var $ss94029403 = {"from":L[767],
"go":function(cont_tail_arg7529408) {
return $Hcont_tail_arg22119409(cont_tail_arg7529408,if_helper7287788);
}};
$e93989399.stack[R.EXN_STACKHEIGHT++] = $ss94029403;
}
if(R.isPyretException($e93989399)) {
$e93989399.pyretStack.push(L[767]);
}
throw $e93989399;
}
var $ret94049405 = $Hcont_tail_arg22119409($z94009401,if_helper7287788);
++R.GAS;
return $ret94049405;
};
var $Hcont_tail_arg22119409 = function(cont_tail_arg7529408,if_helper7287788) {
if(--R.GAS > 0) {
$z94109411 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7529408):R.ffi.throwNonFunApp(L[767],if_helper7287788,[cont_tail_arg7529408]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7529408):R.ffi.throwNonFunApp(L[767],if_helper7287788,[cont_tail_arg7529408]);
},
"from":L[767]});
}
++R.GAS;
return $z94109411;
};
var $Hanf_arg22278995 = function(anf_arg7398993,anf_arg7378994,if_helper7287788,success100109) {
var $z94149415 = D;
var $f94209421 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg7378994,anf_arg7398993):R.ffi.throwNonFunApp(L[768],success100109.$var,[anf_arg7378994,anf_arg7398993]);
};
try {
if(--R.GAS > 0) {
$z94149415 = $f94209421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94209421,
"from":L[768]});
}
} catch($e94129413) {
if(R.isCont($e94129413)) {
var $ss94169417 = {"from":L[768],
"go":function(cont_tail_arg7409422) {
return $Hcont_tail_arg22269423(cont_tail_arg7409422,if_helper7287788);
}};
$e94129413.stack[R.EXN_STACKHEIGHT++] = $ss94169417;
}
if(R.isPyretException($e94129413)) {
$e94129413.pyretStack.push(L[768]);
}
throw $e94129413;
}
var $ret94189419 = $Hcont_tail_arg22269423($z94149415,if_helper7287788);
++R.GAS;
return $ret94189419;
};
var $Hcont_tail_arg22269423 = function(cont_tail_arg7409422,if_helper7287788) {
if(--R.GAS > 0) {
$z94249425 = R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7409422):R.ffi.throwNonFunApp(L[768],if_helper7287788,[cont_tail_arg7409422]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7287788)?if_helper7287788.app(cont_tail_arg7409422):R.ffi.throwNonFunApp(L[768],if_helper7287788,[cont_tail_arg7409422]);
},
"from":L[768]});
}
++R.GAS;
return $z94249425;
};
var $Hanf_bracket21117069 = function(anf_bracket7037068,required_DASH_many113135,required_DASH_once111131) {
var repeated2459456 = G(anf_bracket7037068,"repeated",L[772]);
var or_DASH_oper_DASH_1159457 = R.equiv(repeated2459456,required_DASH_once111131.$var);
var if_helper7049436 = R.makeFunction(function(if_helper_arg7059462) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[769],1,arguments);
}
var ann_DASH_check_DASH_temp7019463 = if_helper_arg7059462;
return ann_DASH_check_DASH_temp7019463;
});
var anf_if7089461 = R.isBoolean(or_DASH_oper_DASH_1159457);
if(R.isPyretTrue(anf_if7089461)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1159457)) {
var $z94289429 = D;
var $f94349435 = function(_) {
return R.isFunction(if_helper7049436)?if_helper7049436.app((true)):R.ffi.throwNonFunApp(L[769],if_helper7049436,[(true)]);
};
try {
if(--R.GAS > 0) {
$z94289429 = $f94349435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94349435,
"from":L[769]});
}
} catch($e94269427) {
if(R.isCont($e94269427)) {
var $ss94309431 = {"from":L[769],
"go":function(cont_tail_app7139437) {
return $Hcont_tail_app21099438(cont_tail_app7139437);
}};
$e94269427.stack[R.EXN_STACKHEIGHT++] = $ss94309431;
}
if(R.isPyretException($e94269427)) {
$e94269427.pyretStack.push(L[769]);
}
throw $e94269427;
}
var $ret94329433 = $Hcont_tail_app21099438($z94289429);
++R.GAS;
return $ret94329433;
} else {
var or_DASH_oper_DASH_1169449 = R.equiv(repeated2459456,required_DASH_many113135.$var);
var anf_if7119455 = R.isBoolean(or_DASH_oper_DASH_1169449);
if(R.isPyretTrue(anf_if7119455)) {
var $z94419442 = D;
var $f94479448 = function(_) {
return R.isFunction(if_helper7049436)?if_helper7049436.app(or_DASH_oper_DASH_1169449):R.ffi.throwNonFunApp(L[769],if_helper7049436,[or_DASH_oper_DASH_1169449]);
};
try {
if(--R.GAS > 0) {
$z94419442 = $f94479448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94479448,
"from":L[769]});
}
} catch($e94399440) {
if(R.isCont($e94399440)) {
var $ss94439444 = {"from":L[769],
"go":function(cont_tail_app7129450) {
return $Hcont_tail_app21109451(cont_tail_app7129450);
}};
$e94399440.stack[R.EXN_STACKHEIGHT++] = $ss94439444;
}
if(R.isPyretException($e94399440)) {
$e94399440.pyretStack.push(L[769]);
}
throw $e94399440;
}
var $ret94459446 = $Hcont_tail_app21109451($z94419442);
++R.GAS;
return $ret94459446;
} else {
var cont_tail_arg7099454 = R.throwNonBooleanOp(L[770],("second"),("or"),or_DASH_oper_DASH_1169449);
if(--R.GAS > 0) {
$z94529453 = R.isFunction(if_helper7049436)?if_helper7049436.app(cont_tail_arg7099454):R.ffi.throwNonFunApp(L[770],if_helper7049436,[cont_tail_arg7099454]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7049436)?if_helper7049436.app(cont_tail_arg7099454):R.ffi.throwNonFunApp(L[770],if_helper7049436,[cont_tail_arg7099454]);
},
"from":L[770]});
}
++R.GAS;
return $z94529453;
}
}
} else {
var cont_tail_arg7069460 = R.throwNonBooleanOp(L[771],("first"),("or"),or_DASH_oper_DASH_1159457);
if(--R.GAS > 0) {
$z94589459 = R.isFunction(if_helper7049436)?if_helper7049436.app(cont_tail_arg7069460):R.ffi.throwNonFunApp(L[771],if_helper7049436,[cont_tail_arg7069460]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper7049436)?if_helper7049436.app(cont_tail_arg7069460):R.ffi.throwNonFunApp(L[771],if_helper7049436,[cont_tail_arg7069460]);
},
"from":L[771]});
}
++R.GAS;
return $z94589459;
}
};
var $Hcont_tail_app21099438 = function(cont_tail_app7139437) {
return cont_tail_app7139437;
};
var $Hcont_tail_app21109451 = function(cont_tail_app7129450) {
return cont_tail_app7129450;
};
var $Hann_DASH_check_DASH_temp21087088 = function(ann_DASH_check_DASH_temp6027087) {
return ann_DASH_check_DASH_temp6027087;
};
var $Hann_DASH_check_DASH_temp21077107 = function(ann_DASH_check_DASH_temp6047106) {
return ann_DASH_check_DASH_temp6047106;
};
var $Hif_DASH_21067125 = function(if_DASH_1127124,list2776,name2397072,parsed2417091,results2377070,success100109,unknown2427092,val2407073,_plus13) {
var if_helper6709477 = R.makeFunction(function(if_helper_arg6719498) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[539],1,arguments);
}
var ann_DASH_check_DASH_temp6679499 = if_helper_arg6719498;
return ann_DASH_check_DASH_temp6679499;
});
var anf_if6749497 = R.isBoolean(if_DASH_1127124);
if(R.isPyretTrue(anf_if6749497)) {
if(R.isPyretTrue(if_DASH_1127124)) {
var anf_fun6819476 = G(parsed2417091,"set",L[776]);
var anf_bracket6829479 = G(results2377070,"parsed",L[775]);
var anf_fun6839474 = G(anf_bracket6829479,"get",L[774]);
var $z94669467 = D;
var $f94729473 = function(_) {
return R.isFunction(anf_fun6839474)?anf_fun6839474.app(name2397072):R.ffi.throwNonFunApp(L[773],anf_fun6839474,[name2397072]);
};
try {
if(--R.GAS > 0) {
$z94669467 = $f94729473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94729473,
"from":L[773]});
}
} catch($e94649465) {
if(R.isCont($e94649465)) {
var $ss94689469 = {"from":L[773],
"go":function(anf_arg6849475) {
return $Hanf_arg21029478(anf_arg6849475,anf_fun6819476,if_helper6709477,list2776,name2397072,success100109,unknown2427092,val2407073,_plus13);
}};
$e94649465.stack[R.EXN_STACKHEIGHT++] = $ss94689469;
}
if(R.isPyretException($e94649465)) {
$e94649465.pyretStack.push(L[773]);
}
throw $e94649465;
}
var $ret94709471 = $Hanf_arg21029478($z94669467,anf_fun6819476,if_helper6709477,list2776,name2397072,success100109,unknown2427092,val2407073,_plus13);
++R.GAS;
return $ret94709471;
} else {
var anf_fun6759492 = G(parsed2417091,"set",L[778]);
var anf_fun6769490 = G(list2776,"make",L[777]);
var $z94829483 = D;
var $f94889489 = function(_) {
return R.isFunction(anf_fun6769490)?anf_fun6769490.app([val2407073]):R.ffi.throwNonFunApp(L[777],anf_fun6769490,[[val2407073]]);
};
try {
if(--R.GAS > 0) {
$z94829483 = $f94889489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94889489,
"from":L[777]});
}
} catch($e94809481) {
if(R.isCont($e94809481)) {
var $ss94849485 = {"from":L[777],
"go":function(anf_arg6779491) {
return $Hanf_arg21059493(anf_arg6779491,anf_fun6759492,if_helper6709477,name2397072,success100109,unknown2427092);
}};
$e94809481.stack[R.EXN_STACKHEIGHT++] = $ss94849485;
}
if(R.isPyretException($e94809481)) {
$e94809481.pyretStack.push(L[777]);
}
throw $e94809481;
}
var $ret94869487 = $Hanf_arg21059493($z94829483,anf_fun6759492,if_helper6709477,name2397072,success100109,unknown2427092);
++R.GAS;
return $ret94869487;
}
} else {
var cont_tail_arg6729496 = R.throwNonBooleanCondition(L[539],("if"),if_DASH_1127124);
if(--R.GAS > 0) {
$z94949495 = R.isFunction(if_helper6709477)?if_helper6709477.app(cont_tail_arg6729496):R.ffi.throwNonFunApp(L[539],if_helper6709477,[cont_tail_arg6729496]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6709477)?if_helper6709477.app(cont_tail_arg6729496):R.ffi.throwNonFunApp(L[539],if_helper6709477,[cont_tail_arg6729496]);
},
"from":L[539]});
}
++R.GAS;
return $z94949495;
}
};
var $Hanf_arg21029478 = function(anf_arg6849475,anf_fun6819476,if_helper6709477,list2776,name2397072,success100109,unknown2427092,val2407073,_plus13) {
var anf_fun6859510 = G(list2776,"make",L[779]);
var $z95029503 = D;
var $f95089509 = function(_) {
return R.isFunction(anf_fun6859510)?anf_fun6859510.app([val2407073]):R.ffi.throwNonFunApp(L[779],anf_fun6859510,[[val2407073]]);
};
try {
if(--R.GAS > 0) {
$z95029503 = $f95089509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95089509,
"from":L[779]});
}
} catch($e95009501) {
if(R.isCont($e95009501)) {
var $ss95049505 = {"from":L[779],
"go":function(anf_arg6869511) {
return $Hanf_arg21019512(anf_arg6869511,anf_arg6849475,anf_fun6819476,if_helper6709477,name2397072,success100109,unknown2427092,_plus13);
}};
$e95009501.stack[R.EXN_STACKHEIGHT++] = $ss95049505;
}
if(R.isPyretException($e95009501)) {
$e95009501.pyretStack.push(L[779]);
}
throw $e95009501;
}
var $ret95069507 = $Hanf_arg21019512($z95029503,anf_arg6849475,anf_fun6819476,if_helper6709477,name2397072,success100109,unknown2427092,_plus13);
++R.GAS;
return $ret95069507;
};
var $Hanf_arg21019512 = function(anf_arg6869511,anf_arg6849475,anf_fun6819476,if_helper6709477,name2397072,success100109,unknown2427092,_plus13) {
var $z95159516 = D;
var $f95219522 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg6849475,anf_arg6869511):R.ffi.throwNonFunApp(L[780],_plus13,[anf_arg6849475,anf_arg6869511]);
};
try {
if(--R.GAS > 0) {
$z95159516 = $f95219522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95219522,
"from":L[780]});
}
} catch($e95139514) {
if(R.isCont($e95139514)) {
var $ss95179518 = {"from":L[780],
"go":function(anf_arg6879523) {
return $Hanf_arg21009524(anf_arg6879523,anf_fun6819476,if_helper6709477,name2397072,success100109,unknown2427092);
}};
$e95139514.stack[R.EXN_STACKHEIGHT++] = $ss95179518;
}
if(R.isPyretException($e95139514)) {
$e95139514.pyretStack.push(L[780]);
}
throw $e95139514;
}
var $ret95199520 = $Hanf_arg21009524($z95159516,anf_fun6819476,if_helper6709477,name2397072,success100109,unknown2427092);
++R.GAS;
return $ret95199520;
};
var $Hanf_arg21009524 = function(anf_arg6879523,anf_fun6819476,if_helper6709477,name2397072,success100109,unknown2427092) {
var $z95279528 = D;
var $f95339534 = function(_) {
return R.isFunction(anf_fun6819476)?anf_fun6819476.app(name2397072,anf_arg6879523):R.ffi.throwNonFunApp(L[781],anf_fun6819476,[name2397072,anf_arg6879523]);
};
try {
if(--R.GAS > 0) {
$z95279528 = $f95339534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95339534,
"from":L[781]});
}
} catch($e95259526) {
if(R.isCont($e95259526)) {
var $ss95299530 = {"from":L[781],
"go":function(anf_arg6889535) {
return $Hanf_arg20999536(anf_arg6889535,if_helper6709477,success100109,unknown2427092);
}};
$e95259526.stack[R.EXN_STACKHEIGHT++] = $ss95299530;
}
if(R.isPyretException($e95259526)) {
$e95259526.pyretStack.push(L[781]);
}
throw $e95259526;
}
var $ret95319532 = $Hanf_arg20999536($z95279528,if_helper6709477,success100109,unknown2427092);
++R.GAS;
return $ret95319532;
};
var $Hanf_arg20999536 = function(anf_arg6889535,if_helper6709477,success100109,unknown2427092) {
var $z95399540 = D;
var $f95459546 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg6889535,unknown2427092):R.ffi.throwNonFunApp(L[782],success100109.$var,[anf_arg6889535,unknown2427092]);
};
try {
if(--R.GAS > 0) {
$z95399540 = $f95459546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95459546,
"from":L[782]});
}
} catch($e95379538) {
if(R.isCont($e95379538)) {
var $ss95419542 = {"from":L[782],
"go":function(cont_tail_arg6899547) {
return $Hcont_tail_arg20989548(cont_tail_arg6899547,if_helper6709477);
}};
$e95379538.stack[R.EXN_STACKHEIGHT++] = $ss95419542;
}
if(R.isPyretException($e95379538)) {
$e95379538.pyretStack.push(L[782]);
}
throw $e95379538;
}
var $ret95439544 = $Hcont_tail_arg20989548($z95399540,if_helper6709477);
++R.GAS;
return $ret95439544;
};
var $Hcont_tail_arg20989548 = function(cont_tail_arg6899547,if_helper6709477) {
if(--R.GAS > 0) {
$z95499550 = R.isFunction(if_helper6709477)?if_helper6709477.app(cont_tail_arg6899547):R.ffi.throwNonFunApp(L[782],if_helper6709477,[cont_tail_arg6899547]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6709477)?if_helper6709477.app(cont_tail_arg6899547):R.ffi.throwNonFunApp(L[782],if_helper6709477,[cont_tail_arg6899547]);
},
"from":L[782]});
}
++R.GAS;
return $z95499550;
};
var $Hanf_arg21059493 = function(anf_arg6779491,anf_fun6759492,if_helper6709477,name2397072,success100109,unknown2427092) {
var $z95539554 = D;
var $f95599560 = function(_) {
return R.isFunction(anf_fun6759492)?anf_fun6759492.app(name2397072,anf_arg6779491):R.ffi.throwNonFunApp(L[783],anf_fun6759492,[name2397072,anf_arg6779491]);
};
try {
if(--R.GAS > 0) {
$z95539554 = $f95599560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95599560,
"from":L[783]});
}
} catch($e95519552) {
if(R.isCont($e95519552)) {
var $ss95559556 = {"from":L[783],
"go":function(anf_arg6789561) {
return $Hanf_arg21049562(anf_arg6789561,if_helper6709477,success100109,unknown2427092);
}};
$e95519552.stack[R.EXN_STACKHEIGHT++] = $ss95559556;
}
if(R.isPyretException($e95519552)) {
$e95519552.pyretStack.push(L[783]);
}
throw $e95519552;
}
var $ret95579558 = $Hanf_arg21049562($z95539554,if_helper6709477,success100109,unknown2427092);
++R.GAS;
return $ret95579558;
};
var $Hanf_arg21049562 = function(anf_arg6789561,if_helper6709477,success100109,unknown2427092) {
var $z95659566 = D;
var $f95719572 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg6789561,unknown2427092):R.ffi.throwNonFunApp(L[784],success100109.$var,[anf_arg6789561,unknown2427092]);
};
try {
if(--R.GAS > 0) {
$z95659566 = $f95719572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95719572,
"from":L[784]});
}
} catch($e95639564) {
if(R.isCont($e95639564)) {
var $ss95679568 = {"from":L[784],
"go":function(cont_tail_arg6799573) {
return $Hcont_tail_arg21039574(cont_tail_arg6799573,if_helper6709477);
}};
$e95639564.stack[R.EXN_STACKHEIGHT++] = $ss95679568;
}
if(R.isPyretException($e95639564)) {
$e95639564.pyretStack.push(L[784]);
}
throw $e95639564;
}
var $ret95699570 = $Hcont_tail_arg21039574($z95659566,if_helper6709477);
++R.GAS;
return $ret95699570;
};
var $Hcont_tail_arg21039574 = function(cont_tail_arg6799573,if_helper6709477) {
if(--R.GAS > 0) {
$z95759576 = R.isFunction(if_helper6709477)?if_helper6709477.app(cont_tail_arg6799573):R.ffi.throwNonFunApp(L[784],if_helper6709477,[cont_tail_arg6799573]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6709477)?if_helper6709477.app(cont_tail_arg6799573):R.ffi.throwNonFunApp(L[784],if_helper6709477,[cont_tail_arg6799573]);
},
"from":L[784]});
}
++R.GAS;
return $z95759576;
};
var $Hif_DASH_20977139 = function(if_DASH_1117138,arg_DASH_error102113,file_DASH_name83203,format7872,list2776,name2397072,parsed2417091,repeated2387071,results2377070,success100109,unknown2427092,val2407073) {
var if_helper6529589 = R.makeFunction(function(if_helper_arg6539608) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[543],1,arguments);
}
var ann_DASH_check_DASH_temp6499609 = if_helper_arg6539608;
return ann_DASH_check_DASH_temp6499609;
});
var anf_if6569607 = R.isBoolean(if_DASH_1117138);
if(R.isPyretTrue(anf_if6569607)) {
if(R.isPyretTrue(if_DASH_1117138)) {
var anf_fun6619587 = G(list2776,"make",L[785]);
var $z95799580 = D;
var $f95859586 = function(_) {
return R.isFunction(anf_fun6619587)?anf_fun6619587.app([file_DASH_name83203,name2397072,repeated2387071]):R.ffi.throwNonFunApp(L[785],anf_fun6619587,[[file_DASH_name83203,name2397072,repeated2387071]]);
};
try {
if(--R.GAS > 0) {
$z95799580 = $f95859586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95859586,
"from":L[785]});
}
} catch($e95779578) {
if(R.isCont($e95779578)) {
var $ss95819582 = {"from":L[785],
"go":function(anf_arg6629588) {
return $Hanf_arg20949590(anf_arg6629588,arg_DASH_error102113,format7872,if_helper6529589,results2377070);
}};
$e95779578.stack[R.EXN_STACKHEIGHT++] = $ss95819582;
}
if(R.isPyretException($e95779578)) {
$e95779578.pyretStack.push(L[785]);
}
throw $e95779578;
}
var $ret95839584 = $Hanf_arg20949590($z95799580,arg_DASH_error102113,format7872,if_helper6529589,results2377070);
++R.GAS;
return $ret95839584;
} else {
var anf_fun6579601 = G(parsed2417091,"set",L[787]);
var $z95939594 = D;
var $f95999600 = function(_) {
return R.isFunction(anf_fun6579601)?anf_fun6579601.app(name2397072,val2407073):R.ffi.throwNonFunApp(L[786],anf_fun6579601,[name2397072,val2407073]);
};
try {
if(--R.GAS > 0) {
$z95939594 = $f95999600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95999600,
"from":L[786]});
}
} catch($e95919592) {
if(R.isCont($e95919592)) {
var $ss95959596 = {"from":L[786],
"go":function(anf_arg6589602) {
return $Hanf_arg20969603(anf_arg6589602,if_helper6529589,success100109,unknown2427092);
}};
$e95919592.stack[R.EXN_STACKHEIGHT++] = $ss95959596;
}
if(R.isPyretException($e95919592)) {
$e95919592.pyretStack.push(L[786]);
}
throw $e95919592;
}
var $ret95979598 = $Hanf_arg20969603($z95939594,if_helper6529589,success100109,unknown2427092);
++R.GAS;
return $ret95979598;
}
} else {
var cont_tail_arg6549606 = R.throwNonBooleanCondition(L[543],("if"),if_DASH_1117138);
if(--R.GAS > 0) {
$z96049605 = R.isFunction(if_helper6529589)?if_helper6529589.app(cont_tail_arg6549606):R.ffi.throwNonFunApp(L[543],if_helper6529589,[cont_tail_arg6549606]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6529589)?if_helper6529589.app(cont_tail_arg6549606):R.ffi.throwNonFunApp(L[543],if_helper6529589,[cont_tail_arg6549606]);
},
"from":L[543]});
}
++R.GAS;
return $z96049605;
}
};
var $Hanf_arg20949590 = function(anf_arg6629588,arg_DASH_error102113,format7872,if_helper6529589,results2377070) {
var $z96129613 = D;
var $f96189619 = function(_) {
return R.isFunction(format7872)?format7872.app(("Parsing command line options for ~a failed: Option ~a ~a, and it has already been used"),anf_arg6629588):R.ffi.throwNonFunApp(L[788],format7872,[("Parsing command line options for ~a failed: Option ~a ~a, and it has already been used"),anf_arg6629588]);
};
try {
if(--R.GAS > 0) {
$z96129613 = $f96189619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96189619,
"from":L[788]});
}
} catch($e96109611) {
if(R.isCont($e96109611)) {
var $ss96149615 = {"from":L[788],
"go":function(anf_arg6639620) {
return $Hanf_arg20939621(anf_arg6639620,arg_DASH_error102113,if_helper6529589,results2377070);
}};
$e96109611.stack[R.EXN_STACKHEIGHT++] = $ss96149615;
}
if(R.isPyretException($e96109611)) {
$e96109611.pyretStack.push(L[788]);
}
throw $e96109611;
}
var $ret96169617 = $Hanf_arg20939621($z96129613,arg_DASH_error102113,if_helper6529589,results2377070);
++R.GAS;
return $ret96169617;
};
var $Hanf_arg20939621 = function(anf_arg6639620,arg_DASH_error102113,if_helper6529589,results2377070) {
var $z96249625 = D;
var $f96309631 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg6639620,results2377070):R.ffi.throwNonFunApp(L[789],arg_DASH_error102113.$var,[anf_arg6639620,results2377070]);
};
try {
if(--R.GAS > 0) {
$z96249625 = $f96309631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96309631,
"from":L[789]});
}
} catch($e96229623) {
if(R.isCont($e96229623)) {
var $ss96269627 = {"from":L[789],
"go":function(cont_tail_arg6649632) {
return $Hcont_tail_arg20929633(cont_tail_arg6649632,if_helper6529589);
}};
$e96229623.stack[R.EXN_STACKHEIGHT++] = $ss96269627;
}
if(R.isPyretException($e96229623)) {
$e96229623.pyretStack.push(L[789]);
}
throw $e96229623;
}
var $ret96289629 = $Hcont_tail_arg20929633($z96249625,if_helper6529589);
++R.GAS;
return $ret96289629;
};
var $Hcont_tail_arg20929633 = function(cont_tail_arg6649632,if_helper6529589) {
if(--R.GAS > 0) {
$z96349635 = R.isFunction(if_helper6529589)?if_helper6529589.app(cont_tail_arg6649632):R.ffi.throwNonFunApp(L[789],if_helper6529589,[cont_tail_arg6649632]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6529589)?if_helper6529589.app(cont_tail_arg6649632):R.ffi.throwNonFunApp(L[789],if_helper6529589,[cont_tail_arg6649632]);
},
"from":L[789]});
}
++R.GAS;
return $z96349635;
};
var $Hanf_arg20969603 = function(anf_arg6589602,if_helper6529589,success100109,unknown2427092) {
var $z96389639 = D;
var $f96449645 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg6589602,unknown2427092):R.ffi.throwNonFunApp(L[790],success100109.$var,[anf_arg6589602,unknown2427092]);
};
try {
if(--R.GAS > 0) {
$z96389639 = $f96449645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96449645,
"from":L[790]});
}
} catch($e96369637) {
if(R.isCont($e96369637)) {
var $ss96409641 = {"from":L[790],
"go":function(cont_tail_arg6599646) {
return $Hcont_tail_arg20959647(cont_tail_arg6599646,if_helper6529589);
}};
$e96369637.stack[R.EXN_STACKHEIGHT++] = $ss96409641;
}
if(R.isPyretException($e96369637)) {
$e96369637.pyretStack.push(L[790]);
}
throw $e96369637;
}
var $ret96429643 = $Hcont_tail_arg20959647($z96389639,if_helper6529589);
++R.GAS;
return $ret96429643;
};
var $Hcont_tail_arg20959647 = function(cont_tail_arg6599646,if_helper6529589) {
if(--R.GAS > 0) {
$z96489649 = R.isFunction(if_helper6529589)?if_helper6529589.app(cont_tail_arg6599646):R.ffi.throwNonFunApp(L[790],if_helper6529589,[cont_tail_arg6599646]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6529589)?if_helper6529589.app(cont_tail_arg6599646):R.ffi.throwNonFunApp(L[790],if_helper6529589,[cont_tail_arg6599646]);
},
"from":L[790]});
}
++R.GAS;
return $z96489649;
};
var $Hif_DASH_20917153 = function(if_DASH_1107152,list2776,name2397072,parsed2417091,results2377070,success100109,unknown2427092,val2407073,_plus13) {
var if_helper6279663 = R.makeFunction(function(if_helper_arg6289684) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[547],1,arguments);
}
var ann_DASH_check_DASH_temp6249685 = if_helper_arg6289684;
return ann_DASH_check_DASH_temp6249685;
});
var anf_if6319683 = R.isBoolean(if_DASH_1107152);
if(R.isPyretTrue(anf_if6319683)) {
if(R.isPyretTrue(if_DASH_1107152)) {
var anf_fun6389662 = G(parsed2417091,"set",L[794]);
var anf_bracket6399665 = G(results2377070,"parsed",L[793]);
var anf_fun6409660 = G(anf_bracket6399665,"get",L[792]);
var $z96529653 = D;
var $f96589659 = function(_) {
return R.isFunction(anf_fun6409660)?anf_fun6409660.app(name2397072):R.ffi.throwNonFunApp(L[791],anf_fun6409660,[name2397072]);
};
try {
if(--R.GAS > 0) {
$z96529653 = $f96589659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96589659,
"from":L[791]});
}
} catch($e96509651) {
if(R.isCont($e96509651)) {
var $ss96549655 = {"from":L[791],
"go":function(anf_arg6419661) {
return $Hanf_arg20879664(anf_arg6419661,anf_fun6389662,if_helper6279663,list2776,name2397072,success100109,unknown2427092,val2407073,_plus13);
}};
$e96509651.stack[R.EXN_STACKHEIGHT++] = $ss96549655;
}
if(R.isPyretException($e96509651)) {
$e96509651.pyretStack.push(L[791]);
}
throw $e96509651;
}
var $ret96569657 = $Hanf_arg20879664($z96529653,anf_fun6389662,if_helper6279663,list2776,name2397072,success100109,unknown2427092,val2407073,_plus13);
++R.GAS;
return $ret96569657;
} else {
var anf_fun6329678 = G(parsed2417091,"set",L[796]);
var anf_fun6339676 = G(list2776,"make",L[795]);
var $z96689669 = D;
var $f96749675 = function(_) {
return R.isFunction(anf_fun6339676)?anf_fun6339676.app([val2407073]):R.ffi.throwNonFunApp(L[795],anf_fun6339676,[[val2407073]]);
};
try {
if(--R.GAS > 0) {
$z96689669 = $f96749675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96749675,
"from":L[795]});
}
} catch($e96669667) {
if(R.isCont($e96669667)) {
var $ss96709671 = {"from":L[795],
"go":function(anf_arg6349677) {
return $Hanf_arg20909679(anf_arg6349677,anf_fun6329678,if_helper6279663,name2397072,success100109,unknown2427092);
}};
$e96669667.stack[R.EXN_STACKHEIGHT++] = $ss96709671;
}
if(R.isPyretException($e96669667)) {
$e96669667.pyretStack.push(L[795]);
}
throw $e96669667;
}
var $ret96729673 = $Hanf_arg20909679($z96689669,anf_fun6329678,if_helper6279663,name2397072,success100109,unknown2427092);
++R.GAS;
return $ret96729673;
}
} else {
var cont_tail_arg6299682 = R.throwNonBooleanCondition(L[547],("if"),if_DASH_1107152);
if(--R.GAS > 0) {
$z96809681 = R.isFunction(if_helper6279663)?if_helper6279663.app(cont_tail_arg6299682):R.ffi.throwNonFunApp(L[547],if_helper6279663,[cont_tail_arg6299682]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6279663)?if_helper6279663.app(cont_tail_arg6299682):R.ffi.throwNonFunApp(L[547],if_helper6279663,[cont_tail_arg6299682]);
},
"from":L[547]});
}
++R.GAS;
return $z96809681;
}
};
var $Hanf_arg20879664 = function(anf_arg6419661,anf_fun6389662,if_helper6279663,list2776,name2397072,success100109,unknown2427092,val2407073,_plus13) {
var anf_fun6429696 = G(list2776,"make",L[797]);
var $z96889689 = D;
var $f96949695 = function(_) {
return R.isFunction(anf_fun6429696)?anf_fun6429696.app([val2407073]):R.ffi.throwNonFunApp(L[797],anf_fun6429696,[[val2407073]]);
};
try {
if(--R.GAS > 0) {
$z96889689 = $f96949695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96949695,
"from":L[797]});
}
} catch($e96869687) {
if(R.isCont($e96869687)) {
var $ss96909691 = {"from":L[797],
"go":function(anf_arg6439697) {
return $Hanf_arg20869698(anf_arg6439697,anf_arg6419661,anf_fun6389662,if_helper6279663,name2397072,success100109,unknown2427092,_plus13);
}};
$e96869687.stack[R.EXN_STACKHEIGHT++] = $ss96909691;
}
if(R.isPyretException($e96869687)) {
$e96869687.pyretStack.push(L[797]);
}
throw $e96869687;
}
var $ret96929693 = $Hanf_arg20869698($z96889689,anf_arg6419661,anf_fun6389662,if_helper6279663,name2397072,success100109,unknown2427092,_plus13);
++R.GAS;
return $ret96929693;
};
var $Hanf_arg20869698 = function(anf_arg6439697,anf_arg6419661,anf_fun6389662,if_helper6279663,name2397072,success100109,unknown2427092,_plus13) {
var $z97019702 = D;
var $f97079708 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg6419661,anf_arg6439697):R.ffi.throwNonFunApp(L[798],_plus13,[anf_arg6419661,anf_arg6439697]);
};
try {
if(--R.GAS > 0) {
$z97019702 = $f97079708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97079708,
"from":L[798]});
}
} catch($e96999700) {
if(R.isCont($e96999700)) {
var $ss97039704 = {"from":L[798],
"go":function(anf_arg6449709) {
return $Hanf_arg20859710(anf_arg6449709,anf_fun6389662,if_helper6279663,name2397072,success100109,unknown2427092);
}};
$e96999700.stack[R.EXN_STACKHEIGHT++] = $ss97039704;
}
if(R.isPyretException($e96999700)) {
$e96999700.pyretStack.push(L[798]);
}
throw $e96999700;
}
var $ret97059706 = $Hanf_arg20859710($z97019702,anf_fun6389662,if_helper6279663,name2397072,success100109,unknown2427092);
++R.GAS;
return $ret97059706;
};
var $Hanf_arg20859710 = function(anf_arg6449709,anf_fun6389662,if_helper6279663,name2397072,success100109,unknown2427092) {
var $z97139714 = D;
var $f97199720 = function(_) {
return R.isFunction(anf_fun6389662)?anf_fun6389662.app(name2397072,anf_arg6449709):R.ffi.throwNonFunApp(L[799],anf_fun6389662,[name2397072,anf_arg6449709]);
};
try {
if(--R.GAS > 0) {
$z97139714 = $f97199720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97199720,
"from":L[799]});
}
} catch($e97119712) {
if(R.isCont($e97119712)) {
var $ss97159716 = {"from":L[799],
"go":function(anf_arg6459721) {
return $Hanf_arg20849722(anf_arg6459721,if_helper6279663,success100109,unknown2427092);
}};
$e97119712.stack[R.EXN_STACKHEIGHT++] = $ss97159716;
}
if(R.isPyretException($e97119712)) {
$e97119712.pyretStack.push(L[799]);
}
throw $e97119712;
}
var $ret97179718 = $Hanf_arg20849722($z97139714,if_helper6279663,success100109,unknown2427092);
++R.GAS;
return $ret97179718;
};
var $Hanf_arg20849722 = function(anf_arg6459721,if_helper6279663,success100109,unknown2427092) {
var $z97259726 = D;
var $f97319732 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg6459721,unknown2427092):R.ffi.throwNonFunApp(L[800],success100109.$var,[anf_arg6459721,unknown2427092]);
};
try {
if(--R.GAS > 0) {
$z97259726 = $f97319732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97319732,
"from":L[800]});
}
} catch($e97239724) {
if(R.isCont($e97239724)) {
var $ss97279728 = {"from":L[800],
"go":function(cont_tail_arg6469733) {
return $Hcont_tail_arg20839734(cont_tail_arg6469733,if_helper6279663);
}};
$e97239724.stack[R.EXN_STACKHEIGHT++] = $ss97279728;
}
if(R.isPyretException($e97239724)) {
$e97239724.pyretStack.push(L[800]);
}
throw $e97239724;
}
var $ret97299730 = $Hcont_tail_arg20839734($z97259726,if_helper6279663);
++R.GAS;
return $ret97299730;
};
var $Hcont_tail_arg20839734 = function(cont_tail_arg6469733,if_helper6279663) {
if(--R.GAS > 0) {
$z97359736 = R.isFunction(if_helper6279663)?if_helper6279663.app(cont_tail_arg6469733):R.ffi.throwNonFunApp(L[800],if_helper6279663,[cont_tail_arg6469733]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6279663)?if_helper6279663.app(cont_tail_arg6469733):R.ffi.throwNonFunApp(L[800],if_helper6279663,[cont_tail_arg6469733]);
},
"from":L[800]});
}
++R.GAS;
return $z97359736;
};
var $Hanf_arg20909679 = function(anf_arg6349677,anf_fun6329678,if_helper6279663,name2397072,success100109,unknown2427092) {
var $z97399740 = D;
var $f97459746 = function(_) {
return R.isFunction(anf_fun6329678)?anf_fun6329678.app(name2397072,anf_arg6349677):R.ffi.throwNonFunApp(L[801],anf_fun6329678,[name2397072,anf_arg6349677]);
};
try {
if(--R.GAS > 0) {
$z97399740 = $f97459746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97459746,
"from":L[801]});
}
} catch($e97379738) {
if(R.isCont($e97379738)) {
var $ss97419742 = {"from":L[801],
"go":function(anf_arg6359747) {
return $Hanf_arg20899748(anf_arg6359747,if_helper6279663,success100109,unknown2427092);
}};
$e97379738.stack[R.EXN_STACKHEIGHT++] = $ss97419742;
}
if(R.isPyretException($e97379738)) {
$e97379738.pyretStack.push(L[801]);
}
throw $e97379738;
}
var $ret97439744 = $Hanf_arg20899748($z97399740,if_helper6279663,success100109,unknown2427092);
++R.GAS;
return $ret97439744;
};
var $Hanf_arg20899748 = function(anf_arg6359747,if_helper6279663,success100109,unknown2427092) {
var $z97519752 = D;
var $f97579758 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg6359747,unknown2427092):R.ffi.throwNonFunApp(L[802],success100109.$var,[anf_arg6359747,unknown2427092]);
};
try {
if(--R.GAS > 0) {
$z97519752 = $f97579758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97579758,
"from":L[802]});
}
} catch($e97499750) {
if(R.isCont($e97499750)) {
var $ss97539754 = {"from":L[802],
"go":function(cont_tail_arg6369759) {
return $Hcont_tail_arg20889760(cont_tail_arg6369759,if_helper6279663);
}};
$e97499750.stack[R.EXN_STACKHEIGHT++] = $ss97539754;
}
if(R.isPyretException($e97499750)) {
$e97499750.pyretStack.push(L[802]);
}
throw $e97499750;
}
var $ret97559756 = $Hcont_tail_arg20889760($z97519752,if_helper6279663);
++R.GAS;
return $ret97559756;
};
var $Hcont_tail_arg20889760 = function(cont_tail_arg6369759,if_helper6279663) {
if(--R.GAS > 0) {
$z97619762 = R.isFunction(if_helper6279663)?if_helper6279663.app(cont_tail_arg6369759):R.ffi.throwNonFunApp(L[802],if_helper6279663,[cont_tail_arg6369759]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6279663)?if_helper6279663.app(cont_tail_arg6369759):R.ffi.throwNonFunApp(L[802],if_helper6279663,[cont_tail_arg6369759]);
},
"from":L[802]});
}
++R.GAS;
return $z97619762;
};
var $Hif_DASH_20827167 = function(if_DASH_1097166,arg_DASH_error102113,file_DASH_name83203,format7872,list2776,name2397072,parsed2417091,repeated2387071,results2377070,success100109,unknown2427092,val2407073) {
var if_helper6099775 = R.makeFunction(function(if_helper_arg6109794) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[551],1,arguments);
}
var ann_DASH_check_DASH_temp6069795 = if_helper_arg6109794;
return ann_DASH_check_DASH_temp6069795;
});
var anf_if6139793 = R.isBoolean(if_DASH_1097166);
if(R.isPyretTrue(anf_if6139793)) {
if(R.isPyretTrue(if_DASH_1097166)) {
var anf_fun6189773 = G(list2776,"make",L[803]);
var $z97659766 = D;
var $f97719772 = function(_) {
return R.isFunction(anf_fun6189773)?anf_fun6189773.app([file_DASH_name83203,name2397072,repeated2387071]):R.ffi.throwNonFunApp(L[803],anf_fun6189773,[[file_DASH_name83203,name2397072,repeated2387071]]);
};
try {
if(--R.GAS > 0) {
$z97659766 = $f97719772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97719772,
"from":L[803]});
}
} catch($e97639764) {
if(R.isCont($e97639764)) {
var $ss97679768 = {"from":L[803],
"go":function(anf_arg6199774) {
return $Hanf_arg20799776(anf_arg6199774,arg_DASH_error102113,format7872,if_helper6099775,results2377070);
}};
$e97639764.stack[R.EXN_STACKHEIGHT++] = $ss97679768;
}
if(R.isPyretException($e97639764)) {
$e97639764.pyretStack.push(L[803]);
}
throw $e97639764;
}
var $ret97699770 = $Hanf_arg20799776($z97659766,arg_DASH_error102113,format7872,if_helper6099775,results2377070);
++R.GAS;
return $ret97699770;
} else {
var anf_fun6149787 = G(parsed2417091,"set",L[805]);
var $z97799780 = D;
var $f97859786 = function(_) {
return R.isFunction(anf_fun6149787)?anf_fun6149787.app(name2397072,val2407073):R.ffi.throwNonFunApp(L[804],anf_fun6149787,[name2397072,val2407073]);
};
try {
if(--R.GAS > 0) {
$z97799780 = $f97859786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97859786,
"from":L[804]});
}
} catch($e97779778) {
if(R.isCont($e97779778)) {
var $ss97819782 = {"from":L[804],
"go":function(anf_arg6159788) {
return $Hanf_arg20819789(anf_arg6159788,if_helper6099775,success100109,unknown2427092);
}};
$e97779778.stack[R.EXN_STACKHEIGHT++] = $ss97819782;
}
if(R.isPyretException($e97779778)) {
$e97779778.pyretStack.push(L[804]);
}
throw $e97779778;
}
var $ret97839784 = $Hanf_arg20819789($z97799780,if_helper6099775,success100109,unknown2427092);
++R.GAS;
return $ret97839784;
}
} else {
var cont_tail_arg6119792 = R.throwNonBooleanCondition(L[551],("if"),if_DASH_1097166);
if(--R.GAS > 0) {
$z97909791 = R.isFunction(if_helper6099775)?if_helper6099775.app(cont_tail_arg6119792):R.ffi.throwNonFunApp(L[551],if_helper6099775,[cont_tail_arg6119792]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6099775)?if_helper6099775.app(cont_tail_arg6119792):R.ffi.throwNonFunApp(L[551],if_helper6099775,[cont_tail_arg6119792]);
},
"from":L[551]});
}
++R.GAS;
return $z97909791;
}
};
var $Hanf_arg20799776 = function(anf_arg6199774,arg_DASH_error102113,format7872,if_helper6099775,results2377070) {
var $z97989799 = D;
var $f98049805 = function(_) {
return R.isFunction(format7872)?format7872.app(("Parsing command line options for ~a failed: Option ~a ~a, and it has already been used"),anf_arg6199774):R.ffi.throwNonFunApp(L[806],format7872,[("Parsing command line options for ~a failed: Option ~a ~a, and it has already been used"),anf_arg6199774]);
};
try {
if(--R.GAS > 0) {
$z97989799 = $f98049805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98049805,
"from":L[806]});
}
} catch($e97969797) {
if(R.isCont($e97969797)) {
var $ss98009801 = {"from":L[806],
"go":function(anf_arg6209806) {
return $Hanf_arg20789807(anf_arg6209806,arg_DASH_error102113,if_helper6099775,results2377070);
}};
$e97969797.stack[R.EXN_STACKHEIGHT++] = $ss98009801;
}
if(R.isPyretException($e97969797)) {
$e97969797.pyretStack.push(L[806]);
}
throw $e97969797;
}
var $ret98029803 = $Hanf_arg20789807($z97989799,arg_DASH_error102113,if_helper6099775,results2377070);
++R.GAS;
return $ret98029803;
};
var $Hanf_arg20789807 = function(anf_arg6209806,arg_DASH_error102113,if_helper6099775,results2377070) {
var $z98109811 = D;
var $f98169817 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg6209806,results2377070):R.ffi.throwNonFunApp(L[807],arg_DASH_error102113.$var,[anf_arg6209806,results2377070]);
};
try {
if(--R.GAS > 0) {
$z98109811 = $f98169817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98169817,
"from":L[807]});
}
} catch($e98089809) {
if(R.isCont($e98089809)) {
var $ss98129813 = {"from":L[807],
"go":function(cont_tail_arg6219818) {
return $Hcont_tail_arg20779819(cont_tail_arg6219818,if_helper6099775);
}};
$e98089809.stack[R.EXN_STACKHEIGHT++] = $ss98129813;
}
if(R.isPyretException($e98089809)) {
$e98089809.pyretStack.push(L[807]);
}
throw $e98089809;
}
var $ret98149815 = $Hcont_tail_arg20779819($z98109811,if_helper6099775);
++R.GAS;
return $ret98149815;
};
var $Hcont_tail_arg20779819 = function(cont_tail_arg6219818,if_helper6099775) {
if(--R.GAS > 0) {
$z98209821 = R.isFunction(if_helper6099775)?if_helper6099775.app(cont_tail_arg6219818):R.ffi.throwNonFunApp(L[807],if_helper6099775,[cont_tail_arg6219818]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6099775)?if_helper6099775.app(cont_tail_arg6219818):R.ffi.throwNonFunApp(L[807],if_helper6099775,[cont_tail_arg6219818]);
},
"from":L[807]});
}
++R.GAS;
return $z98209821;
};
var $Hanf_arg20819789 = function(anf_arg6159788,if_helper6099775,success100109,unknown2427092) {
var $z98249825 = D;
var $f98309831 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg6159788,unknown2427092):R.ffi.throwNonFunApp(L[808],success100109.$var,[anf_arg6159788,unknown2427092]);
};
try {
if(--R.GAS > 0) {
$z98249825 = $f98309831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98309831,
"from":L[808]});
}
} catch($e98229823) {
if(R.isCont($e98229823)) {
var $ss98269827 = {"from":L[808],
"go":function(cont_tail_arg6169832) {
return $Hcont_tail_arg20809833(cont_tail_arg6169832,if_helper6099775);
}};
$e98229823.stack[R.EXN_STACKHEIGHT++] = $ss98269827;
}
if(R.isPyretException($e98229823)) {
$e98229823.pyretStack.push(L[808]);
}
throw $e98229823;
}
var $ret98289829 = $Hcont_tail_arg20809833($z98249825,if_helper6099775);
++R.GAS;
return $ret98289829;
};
var $Hcont_tail_arg20809833 = function(cont_tail_arg6169832,if_helper6099775) {
if(--R.GAS > 0) {
$z98349835 = R.isFunction(if_helper6099775)?if_helper6099775.app(cont_tail_arg6169832):R.ffi.throwNonFunApp(L[808],if_helper6099775,[cont_tail_arg6169832]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper6099775)?if_helper6099775.app(cont_tail_arg6169832):R.ffi.throwNonFunApp(L[808],if_helper6099775,[cont_tail_arg6169832]);
},
"from":L[808]});
}
++R.GAS;
return $z98349835;
};
var $Hif_DASH_20756985 = function(if_DASH_1086984,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,opts_DASH_dict217400,success100109,_plus13) {
var if_helper5169846 = R.makeFunction(function(if_helper_arg5179866) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[521],1,arguments);
}
var ann_DASH_check_DASH_temp5159867 = if_helper_arg5179866;
return ann_DASH_check_DASH_temp5159867;
});
var anf_if5209865 = R.isBoolean(if_DASH_1086984);
if(R.isPyretTrue(anf_if5209865)) {
if(R.isPyretTrue(if_DASH_1086984)) {
var $z98389839 = D;
var $f98449845 = function(_) {
return R.isFunction(if_helper5169846)?if_helper5169846.app(acc2196972):R.ffi.throwNonFunApp(L[809],if_helper5169846,[acc2196972]);
};
try {
if(--R.GAS > 0) {
$z98389839 = $f98449845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98449845,
"from":L[809]});
}
} catch($e98369837) {
if(R.isCont($e98369837)) {
var $ss98409841 = {"from":L[809],
"go":function(cont_tail_app5909847) {
return $Hcont_tail_app20569848(cont_tail_app5909847);
}};
$e98369837.stack[R.EXN_STACKHEIGHT++] = $ss98409841;
}
if(R.isPyretException($e98369837)) {
$e98369837.pyretStack.push(L[809]);
}
throw $e98369837;
}
var $ret98429843 = $Hcont_tail_app20569848($z98389839);
++R.GAS;
return $ret98429843;
} else {
var anf_fun5219859 = G(opts_DASH_dict217400,"get",L[811]);
var $z98519852 = D;
var $f98579858 = function(_) {
return R.isFunction(anf_fun5219859)?anf_fun5219859.app(key2206973):R.ffi.throwNonFunApp(L[810],anf_fun5219859,[key2206973]);
};
try {
if(--R.GAS > 0) {
$z98519852 = $f98579858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98579858,
"from":L[810]});
}
} catch($e98499850) {
if(R.isCont($e98499850)) {
var $ss98539854 = {"from":L[810],
"go":function(cur_DASH_option2219860) {
return $Hcur_DASH_option20749861(cur_DASH_option2219860,D531,acc2196972,arg_DASH_error102113,if_helper5169846,key2206973,list2776,success100109,_plus13);
}};
$e98499850.stack[R.EXN_STACKHEIGHT++] = $ss98539854;
}
if(R.isPyretException($e98499850)) {
$e98499850.pyretStack.push(L[810]);
}
throw $e98499850;
}
var $ret98559856 = $Hcur_DASH_option20749861($z98519852,D531,acc2196972,arg_DASH_error102113,if_helper5169846,key2206973,list2776,success100109,_plus13);
++R.GAS;
return $ret98559856;
}
} else {
var cont_tail_arg5189864 = R.throwNonBooleanCondition(L[521],("if"),if_DASH_1086984);
if(--R.GAS > 0) {
$z98629863 = R.isFunction(if_helper5169846)?if_helper5169846.app(cont_tail_arg5189864):R.ffi.throwNonFunApp(L[521],if_helper5169846,[cont_tail_arg5189864]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper5169846)?if_helper5169846.app(cont_tail_arg5189864):R.ffi.throwNonFunApp(L[521],if_helper5169846,[cont_tail_arg5189864]);
},
"from":L[521]});
}
++R.GAS;
return $z98629863;
}
};
var $Hcont_tail_app20569848 = function(cont_tail_app5909847) {
return cont_tail_app5909847;
};
var $Hcur_DASH_option20749861 = function(cur_DASH_option2219860,D531,acc2196972,arg_DASH_error102113,if_helper5169846,key2206973,list2776,success100109,_plus13) {
var cases_DASH_val1079966 = cur_DASH_option2219860;
var anf_fun5229878 = G(cases_DASH_val1079966,"_match",L[812]);
var anf_obj5539884 = R.makeFunction(function($underscore2229926,$underscore2239927,short_DASH_name2249928,$underscore2259929,$underscore2269930) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[820],5,arguments);
}
var cases_DASH_val1049965 = short_DASH_name2249928;
var anf_fun5249941 = G(cases_DASH_val1049965,"_match",L[821]);
var anf_obj5269947 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[826],0,arguments);
}
var ann_DASH_check_DASH_temp5259964 = acc2196972;
return ann_DASH_check_DASH_temp5259964;
});
var anf_obj5499948 = R.makeFunction(function(short2279949) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[822],1,arguments);
}
var anf_bracket5289963 = G(acc2196972,"options",L[825]);
var anf_fun5299960 = G(anf_bracket5289963,"has-key",L[824]);
var $z99529953 = D;
var $f99589959 = function(_) {
return R.isFunction(anf_fun5299960)?anf_fun5299960.app(short2279949):R.ffi.throwNonFunApp(L[823],anf_fun5299960,[short2279949]);
};
try {
if(--R.GAS > 0) {
$z99529953 = $f99589959();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99589959,
"from":L[823]});
}
} catch($e99509951) {
if(R.isCont($e99509951)) {
var $ss99549955 = {"from":L[823],
"go":function(if_DASH_1039961) {
return $Hif_DASH_20639962(if_DASH_1039961,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,short2279949,success100109,_plus13);
}};
$e99509951.stack[R.EXN_STACKHEIGHT++] = $ss99549955;
}
if(R.isPyretException($e99509951)) {
$e99509951.pyretStack.push(L[823]);
}
throw $e99509951;
}
var $ret99569957 = $Hif_DASH_20639962($z99529953,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,short2279949,success100109,_plus13);
++R.GAS;
return $ret99569957;
});
var anf_arg5509942 = R.makeObject({"none":anf_obj5269947,
"some":anf_obj5499948});
var anf_arg5529943 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[821],0,arguments);
}
var ann_DASH_check_DASH_temp5519946 = R.throwNoBranchesMatched(L[821],("cases"));
return ann_DASH_check_DASH_temp5519946;
});
var $z99339934 = D;
var $f99399940 = function(_) {
return R.isFunction(anf_fun5249941)?anf_fun5249941.app(anf_arg5509942,anf_arg5529943):R.ffi.throwNonFunApp(L[820],anf_fun5249941,[anf_arg5509942,anf_arg5529943]);
};
try {
if(--R.GAS > 0) {
$z99339934 = $f99399940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99399940,
"from":L[820]});
}
} catch($e99319932) {
if(R.isCont($e99319932)) {
var $ss99359936 = {"from":L[820],
"go":function(ann_DASH_check_DASH_temp5239944) {
return $Hann_DASH_check_DASH_temp20649945(ann_DASH_check_DASH_temp5239944);
}};
$e99319932.stack[R.EXN_STACKHEIGHT++] = $ss99359936;
}
if(R.isPyretException($e99319932)) {
$e99319932.pyretStack.push(L[820]);
}
throw $e99319932;
}
var $ret99379938 = $Hann_DASH_check_DASH_temp20649945($z99339934);
++R.GAS;
return $ret99379938;
});
var anf_obj5849885 = R.makeFunction(function($underscore2289886,$underscore2299887,short_DASH_name2309888,$underscore2319889,$underscore2329890) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[813],5,arguments);
}
var cases_DASH_val1069925 = short_DASH_name2309888;
var anf_fun5559901 = G(cases_DASH_val1069925,"_match",L[814]);
var anf_obj5579907 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[819],0,arguments);
}
var ann_DASH_check_DASH_temp5569924 = acc2196972;
return ann_DASH_check_DASH_temp5569924;
});
var anf_obj5809908 = R.makeFunction(function(short2339909) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[815],1,arguments);
}
var anf_bracket5599923 = G(acc2196972,"options",L[818]);
var anf_fun5609920 = G(anf_bracket5599923,"has-key",L[817]);
var $z99129913 = D;
var $f99189919 = function(_) {
return R.isFunction(anf_fun5609920)?anf_fun5609920.app(short2339909):R.ffi.throwNonFunApp(L[816],anf_fun5609920,[short2339909]);
};
try {
if(--R.GAS > 0) {
$z99129913 = $f99189919();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99189919,
"from":L[816]});
}
} catch($e99109911) {
if(R.isCont($e99109911)) {
var $ss99149915 = {"from":L[816],
"go":function(if_DASH_1059921) {
return $Hif_DASH_20719922(if_DASH_1059921,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,short2339909,success100109,_plus13);
}};
$e99109911.stack[R.EXN_STACKHEIGHT++] = $ss99149915;
}
if(R.isPyretException($e99109911)) {
$e99109911.pyretStack.push(L[816]);
}
throw $e99109911;
}
var $ret99169917 = $Hif_DASH_20719922($z99129913,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,short2339909,success100109,_plus13);
++R.GAS;
return $ret99169917;
});
var anf_arg5819902 = R.makeObject({"none":anf_obj5579907,
"some":anf_obj5809908});
var anf_arg5839903 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[814],0,arguments);
}
var ann_DASH_check_DASH_temp5829906 = R.throwNoBranchesMatched(L[814],("cases"));
return ann_DASH_check_DASH_temp5829906;
});
var $z98939894 = D;
var $f98999900 = function(_) {
return R.isFunction(anf_fun5559901)?anf_fun5559901.app(anf_arg5819902,anf_arg5839903):R.ffi.throwNonFunApp(L[813],anf_fun5559901,[anf_arg5819902,anf_arg5839903]);
};
try {
if(--R.GAS > 0) {
$z98939894 = $f98999900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98999900,
"from":L[813]});
}
} catch($e98919892) {
if(R.isCont($e98919892)) {
var $ss98959896 = {"from":L[813],
"go":function(ann_DASH_check_DASH_temp5549904) {
return $Hann_DASH_check_DASH_temp20729905(ann_DASH_check_DASH_temp5549904);
}};
$e98919892.stack[R.EXN_STACKHEIGHT++] = $ss98959896;
}
if(R.isPyretException($e98919892)) {
$e98919892.pyretStack.push(L[813]);
}
throw $e98919892;
}
var $ret98979898 = $Hann_DASH_check_DASH_temp20729905($z98939894);
++R.GAS;
return $ret98979898;
});
var anf_arg5859879 = R.makeObject({"equals-val-default":anf_obj5539884,
"next-val-default":anf_obj5849885});
var anf_arg5879880 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[812],0,arguments);
}
var ann_DASH_check_DASH_temp5869883 = acc2196972;
return ann_DASH_check_DASH_temp5869883;
});
var $z98709871 = D;
var $f98769877 = function(_) {
return R.isFunction(anf_fun5229878)?anf_fun5229878.app(anf_arg5859879,anf_arg5879880):R.ffi.throwNonFunApp(L[812],anf_fun5229878,[anf_arg5859879,anf_arg5879880]);
};
try {
if(--R.GAS > 0) {
$z98709871 = $f98769877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98769877,
"from":L[812]});
}
} catch($e98689869) {
if(R.isCont($e98689869)) {
var $ss98729873 = {"from":L[812],
"go":function(cont_tail_arg5889881) {
return $Hcont_tail_arg20739882(cont_tail_arg5889881,if_helper5169846);
}};
$e98689869.stack[R.EXN_STACKHEIGHT++] = $ss98729873;
}
if(R.isPyretException($e98689869)) {
$e98689869.pyretStack.push(L[812]);
}
throw $e98689869;
}
var $ret98749875 = $Hcont_tail_arg20739882($z98709871,if_helper5169846);
++R.GAS;
return $ret98749875;
};
var $Hcont_tail_arg20739882 = function(cont_tail_arg5889881,if_helper5169846) {
if(--R.GAS > 0) {
$z99679968 = R.isFunction(if_helper5169846)?if_helper5169846.app(cont_tail_arg5889881):R.ffi.throwNonFunApp(L[812],if_helper5169846,[cont_tail_arg5889881]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper5169846)?if_helper5169846.app(cont_tail_arg5889881):R.ffi.throwNonFunApp(L[812],if_helper5169846,[cont_tail_arg5889881]);
},
"from":L[812]});
}
++R.GAS;
return $z99679968;
};
var $Hann_DASH_check_DASH_temp20729905 = function(ann_DASH_check_DASH_temp5549904) {
return ann_DASH_check_DASH_temp5549904;
};
var $Hif_DASH_20719922 = function(if_DASH_1059921,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,short2339909,success100109,_plus13) {
var if_helper5619980 = R.makeFunction(function(if_helper_arg56210001) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[816],1,arguments);
}
var ann_DASH_check_DASH_temp55810002 = if_helper_arg56210001;
return ann_DASH_check_DASH_temp55810002;
});
var anf_if56510000 = R.isBoolean(if_DASH_1059921);
if(R.isPyretTrue(anf_if56510000)) {
if(R.isPyretTrue(if_DASH_1059921)) {
var $z99719972 = D;
var $f99779978 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Options map already includes entry for short-name "),short2339909):R.ffi.throwNonFunApp(L[827],_plus13,[("Options map already includes entry for short-name "),short2339909]);
};
try {
if(--R.GAS > 0) {
$z99719972 = $f99779978();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99779978,
"from":L[827]});
}
} catch($e99699970) {
if(R.isCont($e99699970)) {
var $ss99739974 = {"from":L[827],
"go":function(anf_arg5729979) {
return $Hanf_arg20699981(anf_arg5729979,D531,arg_DASH_error102113,if_helper5619980,list2776,success100109);
}};
$e99699970.stack[R.EXN_STACKHEIGHT++] = $ss99739974;
}
if(R.isPyretException($e99699970)) {
$e99699970.pyretStack.push(L[827]);
}
throw $e99699970;
}
var $ret99759976 = $Hanf_arg20699981($z99719972,D531,arg_DASH_error102113,if_helper5619980,list2776,success100109);
++R.GAS;
return $ret99759976;
} else {
var anf_extend5669994 = G(acc2196972,"options",L[831]);
var anf_bracket5679996 = G(acc2196972,"aliases",L[830]);
var anf_fun5689992 = G(anf_bracket5679996,"set",L[829]);
var $z99849985 = D;
var $f99909991 = function(_) {
return R.isFunction(anf_fun5689992)?anf_fun5689992.app(short2339909,key2206973):R.ffi.throwNonFunApp(L[828],anf_fun5689992,[short2339909,key2206973]);
};
try {
if(--R.GAS > 0) {
$z99849985 = $f99909991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99909991,
"from":L[828]});
}
} catch($e99829983) {
if(R.isCont($e99829983)) {
var $ss99869987 = {"from":L[828],
"go":function(anf_extend5699993) {
return $Hanf_extend20709995(anf_extend5699993,acc2196972,anf_extend5669994,if_helper5619980);
}};
$e99829983.stack[R.EXN_STACKHEIGHT++] = $ss99869987;
}
if(R.isPyretException($e99829983)) {
$e99829983.pyretStack.push(L[828]);
}
throw $e99829983;
}
var $ret99889989 = $Hanf_extend20709995($z99849985,acc2196972,anf_extend5669994,if_helper5619980);
++R.GAS;
return $ret99889989;
}
} else {
var cont_tail_arg5639999 = R.throwNonBooleanCondition(L[816],("if"),if_DASH_1059921);
if(--R.GAS > 0) {
$z99979998 = R.isFunction(if_helper5619980)?if_helper5619980.app(cont_tail_arg5639999):R.ffi.throwNonFunApp(L[816],if_helper5619980,[cont_tail_arg5639999]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper5619980)?if_helper5619980.app(cont_tail_arg5639999):R.ffi.throwNonFunApp(L[816],if_helper5619980,[cont_tail_arg5639999]);
},
"from":L[816]});
}
++R.GAS;
return $z99979998;
}
};
var $Hanf_arg20699981 = function(anf_arg5729979,D531,arg_DASH_error102113,if_helper5619980,list2776,success100109) {
var anf_fun57310013 = G(D531,"immutable-string-dict",L[833]);
var $z1000510006 = D;
var $f1001110012 = function(_) {
return R.isFunction(anf_fun57310013)?anf_fun57310013.app():R.ffi.throwNonFunApp(L[832],anf_fun57310013,[]);
};
try {
if(--R.GAS > 0) {
$z1000510006 = $f1001110012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1001110012,
"from":L[832]});
}
} catch($e1000310004) {
if(R.isCont($e1000310004)) {
var $ss1000710008 = {"from":L[832],
"go":function(anf_arg57410014) {
return $Hanf_arg206810015(anf_arg57410014,anf_arg5729979,arg_DASH_error102113,if_helper5619980,list2776,success100109);
}};
$e1000310004.stack[R.EXN_STACKHEIGHT++] = $ss1000710008;
}
if(R.isPyretException($e1000310004)) {
$e1000310004.pyretStack.push(L[832]);
}
throw $e1000310004;
}
var $ret1000910010 = $Hanf_arg206810015($z1000510006,anf_arg5729979,arg_DASH_error102113,if_helper5619980,list2776,success100109);
++R.GAS;
return $ret1000910010;
};
var $Hanf_arg206810015 = function(anf_arg57410014,anf_arg5729979,arg_DASH_error102113,if_helper5619980,list2776,success100109) {
var anf_fun57510026 = G(list2776,"make",L[834]);
var $z1001810019 = D;
var $f1002410025 = function(_) {
return R.isFunction(anf_fun57510026)?anf_fun57510026.app([]):R.ffi.throwNonFunApp(L[834],anf_fun57510026,[[]]);
};
try {
if(--R.GAS > 0) {
$z1001810019 = $f1002410025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1002410025,
"from":L[834]});
}
} catch($e1001610017) {
if(R.isCont($e1001610017)) {
var $ss1002010021 = {"from":L[834],
"go":function(anf_arg57610027) {
return $Hanf_arg206710028(anf_arg57610027,anf_arg5729979,anf_arg57410014,arg_DASH_error102113,if_helper5619980,success100109);
}};
$e1001610017.stack[R.EXN_STACKHEIGHT++] = $ss1002010021;
}
if(R.isPyretException($e1001610017)) {
$e1001610017.pyretStack.push(L[834]);
}
throw $e1001610017;
}
var $ret1002210023 = $Hanf_arg206710028($z1001810019,anf_arg5729979,anf_arg57410014,arg_DASH_error102113,if_helper5619980,success100109);
++R.GAS;
return $ret1002210023;
};
var $Hanf_arg206710028 = function(anf_arg57610027,anf_arg5729979,anf_arg57410014,arg_DASH_error102113,if_helper5619980,success100109) {
var $z1003110032 = D;
var $f1003710038 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg57410014,anf_arg57610027):R.ffi.throwNonFunApp(L[835],success100109.$var,[anf_arg57410014,anf_arg57610027]);
};
try {
if(--R.GAS > 0) {
$z1003110032 = $f1003710038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1003710038,
"from":L[835]});
}
} catch($e1002910030) {
if(R.isCont($e1002910030)) {
var $ss1003310034 = {"from":L[835],
"go":function(anf_arg57710039) {
return $Hanf_arg206610040(anf_arg57710039,anf_arg5729979,arg_DASH_error102113,if_helper5619980);
}};
$e1002910030.stack[R.EXN_STACKHEIGHT++] = $ss1003310034;
}
if(R.isPyretException($e1002910030)) {
$e1002910030.pyretStack.push(L[835]);
}
throw $e1002910030;
}
var $ret1003510036 = $Hanf_arg206610040($z1003110032,anf_arg5729979,arg_DASH_error102113,if_helper5619980);
++R.GAS;
return $ret1003510036;
};
var $Hanf_arg206610040 = function(anf_arg57710039,anf_arg5729979,arg_DASH_error102113,if_helper5619980) {
var $z1004310044 = D;
var $f1004910050 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg5729979,anf_arg57710039):R.ffi.throwNonFunApp(L[836],arg_DASH_error102113.$var,[anf_arg5729979,anf_arg57710039]);
};
try {
if(--R.GAS > 0) {
$z1004310044 = $f1004910050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1004910050,
"from":L[836]});
}
} catch($e1004110042) {
if(R.isCont($e1004110042)) {
var $ss1004510046 = {"from":L[836],
"go":function(cont_tail_arg57810051) {
return $Hcont_tail_arg206510052(cont_tail_arg57810051,if_helper5619980);
}};
$e1004110042.stack[R.EXN_STACKHEIGHT++] = $ss1004510046;
}
if(R.isPyretException($e1004110042)) {
$e1004110042.pyretStack.push(L[836]);
}
throw $e1004110042;
}
var $ret1004710048 = $Hcont_tail_arg206510052($z1004310044,if_helper5619980);
++R.GAS;
return $ret1004710048;
};
var $Hcont_tail_arg206510052 = function(cont_tail_arg57810051,if_helper5619980) {
if(--R.GAS > 0) {
$z1005310054 = R.isFunction(if_helper5619980)?if_helper5619980.app(cont_tail_arg57810051):R.ffi.throwNonFunApp(L[836],if_helper5619980,[cont_tail_arg57810051]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper5619980)?if_helper5619980.app(cont_tail_arg57810051):R.ffi.throwNonFunApp(L[836],if_helper5619980,[cont_tail_arg57810051]);
},
"from":L[836]});
}
++R.GAS;
return $z1005310054;
};
var $Hanf_extend20709995 = function(anf_extend5699993,acc2196972,anf_extend5669994,if_helper5619980) {
var cont_tail_arg57010057 = acc2196972.extendWith({"options":anf_extend5669994,
"aliases":anf_extend5699993});
if(--R.GAS > 0) {
$z1005510056 = R.isFunction(if_helper5619980)?if_helper5619980.app(cont_tail_arg57010057):R.ffi.throwNonFunApp(L[837],if_helper5619980,[cont_tail_arg57010057]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper5619980)?if_helper5619980.app(cont_tail_arg57010057):R.ffi.throwNonFunApp(L[837],if_helper5619980,[cont_tail_arg57010057]);
},
"from":L[837]});
}
++R.GAS;
return $z1005510056;
};
var $Hann_DASH_check_DASH_temp20649945 = function(ann_DASH_check_DASH_temp5239944) {
return ann_DASH_check_DASH_temp5239944;
};
var $Hif_DASH_20639962 = function(if_DASH_1039961,D531,acc2196972,arg_DASH_error102113,key2206973,list2776,short2279949,success100109,_plus13) {
var if_helper53010069 = R.makeFunction(function(if_helper_arg53110090) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[823],1,arguments);
}
var ann_DASH_check_DASH_temp52710091 = if_helper_arg53110090;
return ann_DASH_check_DASH_temp52710091;
});
var anf_if53410089 = R.isBoolean(if_DASH_1039961);
if(R.isPyretTrue(anf_if53410089)) {
if(R.isPyretTrue(if_DASH_1039961)) {
var $z1006010061 = D;
var $f1006610067 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Options map already includes entry for short-name "),short2279949):R.ffi.throwNonFunApp(L[838],_plus13,[("Options map already includes entry for short-name "),short2279949]);
};
try {
if(--R.GAS > 0) {
$z1006010061 = $f1006610067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1006610067,
"from":L[838]});
}
} catch($e1005810059) {
if(R.isCont($e1005810059)) {
var $ss1006210063 = {"from":L[838],
"go":function(anf_arg54110068) {
return $Hanf_arg206110070(anf_arg54110068,D531,arg_DASH_error102113,if_helper53010069,list2776,success100109);
}};
$e1005810059.stack[R.EXN_STACKHEIGHT++] = $ss1006210063;
}
if(R.isPyretException($e1005810059)) {
$e1005810059.pyretStack.push(L[838]);
}
throw $e1005810059;
}
var $ret1006410065 = $Hanf_arg206110070($z1006010061,D531,arg_DASH_error102113,if_helper53010069,list2776,success100109);
++R.GAS;
return $ret1006410065;
} else {
var anf_extend53510083 = G(acc2196972,"options",L[842]);
var anf_bracket53610085 = G(acc2196972,"aliases",L[841]);
var anf_fun53710081 = G(anf_bracket53610085,"set",L[840]);
var $z1007310074 = D;
var $f1007910080 = function(_) {
return R.isFunction(anf_fun53710081)?anf_fun53710081.app(short2279949,key2206973):R.ffi.throwNonFunApp(L[839],anf_fun53710081,[short2279949,key2206973]);
};
try {
if(--R.GAS > 0) {
$z1007310074 = $f1007910080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1007910080,
"from":L[839]});
}
} catch($e1007110072) {
if(R.isCont($e1007110072)) {
var $ss1007510076 = {"from":L[839],
"go":function(anf_extend53810082) {
return $Hanf_extend206210084(anf_extend53810082,acc2196972,anf_extend53510083,if_helper53010069);
}};
$e1007110072.stack[R.EXN_STACKHEIGHT++] = $ss1007510076;
}
if(R.isPyretException($e1007110072)) {
$e1007110072.pyretStack.push(L[839]);
}
throw $e1007110072;
}
var $ret1007710078 = $Hanf_extend206210084($z1007310074,acc2196972,anf_extend53510083,if_helper53010069);
++R.GAS;
return $ret1007710078;
}
} else {
var cont_tail_arg53210088 = R.throwNonBooleanCondition(L[823],("if"),if_DASH_1039961);
if(--R.GAS > 0) {
$z1008610087 = R.isFunction(if_helper53010069)?if_helper53010069.app(cont_tail_arg53210088):R.ffi.throwNonFunApp(L[823],if_helper53010069,[cont_tail_arg53210088]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper53010069)?if_helper53010069.app(cont_tail_arg53210088):R.ffi.throwNonFunApp(L[823],if_helper53010069,[cont_tail_arg53210088]);
},
"from":L[823]});
}
++R.GAS;
return $z1008610087;
}
};
var $Hanf_arg206110070 = function(anf_arg54110068,D531,arg_DASH_error102113,if_helper53010069,list2776,success100109) {
var anf_fun54210102 = G(D531,"immutable-string-dict",L[844]);
var $z1009410095 = D;
var $f1010010101 = function(_) {
return R.isFunction(anf_fun54210102)?anf_fun54210102.app():R.ffi.throwNonFunApp(L[843],anf_fun54210102,[]);
};
try {
if(--R.GAS > 0) {
$z1009410095 = $f1010010101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1010010101,
"from":L[843]});
}
} catch($e1009210093) {
if(R.isCont($e1009210093)) {
var $ss1009610097 = {"from":L[843],
"go":function(anf_arg54310103) {
return $Hanf_arg206010104(anf_arg54310103,anf_arg54110068,arg_DASH_error102113,if_helper53010069,list2776,success100109);
}};
$e1009210093.stack[R.EXN_STACKHEIGHT++] = $ss1009610097;
}
if(R.isPyretException($e1009210093)) {
$e1009210093.pyretStack.push(L[843]);
}
throw $e1009210093;
}
var $ret1009810099 = $Hanf_arg206010104($z1009410095,anf_arg54110068,arg_DASH_error102113,if_helper53010069,list2776,success100109);
++R.GAS;
return $ret1009810099;
};
var $Hanf_arg206010104 = function(anf_arg54310103,anf_arg54110068,arg_DASH_error102113,if_helper53010069,list2776,success100109) {
var anf_fun54410115 = G(list2776,"make",L[845]);
var $z1010710108 = D;
var $f1011310114 = function(_) {
return R.isFunction(anf_fun54410115)?anf_fun54410115.app([]):R.ffi.throwNonFunApp(L[845],anf_fun54410115,[[]]);
};
try {
if(--R.GAS > 0) {
$z1010710108 = $f1011310114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1011310114,
"from":L[845]});
}
} catch($e1010510106) {
if(R.isCont($e1010510106)) {
var $ss1010910110 = {"from":L[845],
"go":function(anf_arg54510116) {
return $Hanf_arg205910117(anf_arg54510116,anf_arg54110068,anf_arg54310103,arg_DASH_error102113,if_helper53010069,success100109);
}};
$e1010510106.stack[R.EXN_STACKHEIGHT++] = $ss1010910110;
}
if(R.isPyretException($e1010510106)) {
$e1010510106.pyretStack.push(L[845]);
}
throw $e1010510106;
}
var $ret1011110112 = $Hanf_arg205910117($z1010710108,anf_arg54110068,anf_arg54310103,arg_DASH_error102113,if_helper53010069,success100109);
++R.GAS;
return $ret1011110112;
};
var $Hanf_arg205910117 = function(anf_arg54510116,anf_arg54110068,anf_arg54310103,arg_DASH_error102113,if_helper53010069,success100109) {
var $z1012010121 = D;
var $f1012610127 = function(_) {
return R.isFunction(success100109.$var)?success100109.$var.app(anf_arg54310103,anf_arg54510116):R.ffi.throwNonFunApp(L[846],success100109.$var,[anf_arg54310103,anf_arg54510116]);
};
try {
if(--R.GAS > 0) {
$z1012010121 = $f1012610127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1012610127,
"from":L[846]});
}
} catch($e1011810119) {
if(R.isCont($e1011810119)) {
var $ss1012210123 = {"from":L[846],
"go":function(anf_arg54610128) {
return $Hanf_arg205810129(anf_arg54610128,anf_arg54110068,arg_DASH_error102113,if_helper53010069);
}};
$e1011810119.stack[R.EXN_STACKHEIGHT++] = $ss1012210123;
}
if(R.isPyretException($e1011810119)) {
$e1011810119.pyretStack.push(L[846]);
}
throw $e1011810119;
}
var $ret1012410125 = $Hanf_arg205810129($z1012010121,anf_arg54110068,arg_DASH_error102113,if_helper53010069);
++R.GAS;
return $ret1012410125;
};
var $Hanf_arg205810129 = function(anf_arg54610128,anf_arg54110068,arg_DASH_error102113,if_helper53010069) {
var $z1013210133 = D;
var $f1013810139 = function(_) {
return R.isFunction(arg_DASH_error102113.$var)?arg_DASH_error102113.$var.app(anf_arg54110068,anf_arg54610128):R.ffi.throwNonFunApp(L[847],arg_DASH_error102113.$var,[anf_arg54110068,anf_arg54610128]);
};
try {
if(--R.GAS > 0) {
$z1013210133 = $f1013810139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1013810139,
"from":L[847]});
}
} catch($e1013010131) {
if(R.isCont($e1013010131)) {
var $ss1013410135 = {"from":L[847],
"go":function(cont_tail_arg54710140) {
return $Hcont_tail_arg205710141(cont_tail_arg54710140,if_helper53010069);
}};
$e1013010131.stack[R.EXN_STACKHEIGHT++] = $ss1013410135;
}
if(R.isPyretException($e1013010131)) {
$e1013010131.pyretStack.push(L[847]);
}
throw $e1013010131;
}
var $ret1013610137 = $Hcont_tail_arg205710141($z1013210133,if_helper53010069);
++R.GAS;
return $ret1013610137;
};
var $Hcont_tail_arg205710141 = function(cont_tail_arg54710140,if_helper53010069) {
if(--R.GAS > 0) {
$z1014210143 = R.isFunction(if_helper53010069)?if_helper53010069.app(cont_tail_arg54710140):R.ffi.throwNonFunApp(L[847],if_helper53010069,[cont_tail_arg54710140]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper53010069)?if_helper53010069.app(cont_tail_arg54710140):R.ffi.throwNonFunApp(L[847],if_helper53010069,[cont_tail_arg54710140]);
},
"from":L[847]});
}
++R.GAS;
return $z1014210143;
};
var $Hanf_extend206210084 = function(anf_extend53810082,acc2196972,anf_extend53510083,if_helper53010069) {
var cont_tail_arg53910146 = acc2196972.extendWith({"options":anf_extend53510083,
"aliases":anf_extend53810082});
if(--R.GAS > 0) {
$z1014410145 = R.isFunction(if_helper53010069)?if_helper53010069.app(cont_tail_arg53910146):R.ffi.throwNonFunApp(L[848],if_helper53010069,[cont_tail_arg53910146]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper53010069)?if_helper53010069.app(cont_tail_arg53910146):R.ffi.throwNonFunApp(L[848],if_helper53010069,[cont_tail_arg53910146]);
},
"from":L[848]});
}
++R.GAS;
return $z1014410145;
};
var $Hoptions2055415 = function(options192414,List1959,file_DASH_name83203,format7872,link3175,list2776,lists1134,$type$String28) {
var anf_fun44410160 = G(lists1134,"map",L[854]);
var anf_arg50310159 = R.makeFunction(function(key19410162) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[851],1,arguments);
}
var anf_fun44610173 = G(options192414,"get",L[853]);
var $z1016510166 = D;
var $f1017110172 = function(_) {
return R.isFunction(anf_fun44610173)?anf_fun44610173.app(key19410162):R.ffi.throwNonFunApp(L[852],anf_fun44610173,[key19410162]);
};
try {
if(--R.GAS > 0) {
$z1016510166 = $f1017110172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1017110172,
"from":L[852]});
}
} catch($e1016310164) {
if(R.isCont($e1016310164)) {
var $ss1016710168 = {"from":L[852],
"go":function(cases_DASH_val10110174) {
return $Hcases_DASH_val204810175(cases_DASH_val10110174,format7872,key19410162,list2776);
}};
$e1016310164.stack[R.EXN_STACKHEIGHT++] = $ss1016710168;
}
if(R.isPyretException($e1016310164)) {
$e1016310164.pyretStack.push(L[852]);
}
throw $e1016310164;
}
var $ret1016910170 = $Hcases_DASH_val204810175($z1016510166,format7872,key19410162,list2776);
++R.GAS;
return $ret1016910170;
});
var anf_fun50410157 = G(options192414,"keys",L[850]);
var $z1014910150 = D;
var $f1015510156 = function(_) {
return R.isFunction(anf_fun50410157)?anf_fun50410157.app():R.ffi.throwNonFunApp(L[849],anf_fun50410157,[]);
};
try {
if(--R.GAS > 0) {
$z1014910150 = $f1015510156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1015510156,
"from":L[849]});
}
} catch($e1014710148) {
if(R.isCont($e1014710148)) {
var $ss1015110152 = {"from":L[849],
"go":function(anf_arg50510158) {
return $Hanf_arg205410161(anf_arg50510158,List1959,anf_arg50310159,anf_fun44410160,file_DASH_name83203,format7872,link3175,list2776,$type$String28);
}};
$e1014710148.stack[R.EXN_STACKHEIGHT++] = $ss1015110152;
}
if(R.isPyretException($e1014710148)) {
$e1014710148.pyretStack.push(L[849]);
}
throw $e1014710148;
}
var $ret1015310154 = $Hanf_arg205410161($z1014910150,List1959,anf_arg50310159,anf_fun44410160,file_DASH_name83203,format7872,link3175,list2776,$type$String28);
++R.GAS;
return $ret1015310154;
};
var $Hanf_arg205410161 = function(anf_arg50510158,List1959,anf_arg50310159,anf_fun44410160,file_DASH_name83203,format7872,link3175,list2776,$type$String28) {
var $z1017810179 = D;
var $f1018410185 = function(_) {
return R.isFunction(anf_fun44410160)?anf_fun44410160.app(anf_arg50310159,anf_arg50510158):R.ffi.throwNonFunApp(L[855],anf_fun44410160,[anf_arg50310159,anf_arg50510158]);
};
try {
if(--R.GAS > 0) {
$z1017810179 = $f1018410185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1018410185,
"from":L[855]});
}
} catch($e1017610177) {
if(R.isCont($e1017610177)) {
var $ss1018010181 = {"from":L[855],
"go":function(option_DASH_info19310186) {
return $Hoption_DASH_info205310187(option_DASH_info19310186,List1959,file_DASH_name83203,format7872,link3175,list2776,$type$String28);
}};
$e1017610177.stack[R.EXN_STACKHEIGHT++] = $ss1018010181;
}
if(R.isPyretException($e1017610177)) {
$e1017610177.pyretStack.push(L[855]);
}
throw $e1017610177;
}
var $ret1018210183 = $Hoption_DASH_info205310187($z1017810179,List1959,file_DASH_name83203,format7872,link3175,list2776,$type$String28);
++R.GAS;
return $ret1018210183;
};
var $Hoption_DASH_info205310187 = function(option_DASH_info19310186,List1959,file_DASH_name83203,format7872,link3175,list2776,$type$String28) {
var anf_fun50710200 = R.makeFunction(function(arg_DASH_10210202) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[857],1,arguments);
}
var $z1020510206 = D;
var $f1021110212 = function(_) {
return R.isFunction(link3175)?link3175.app(arg_DASH_10210202,option_DASH_info19310186):R.ffi.throwNonFunApp(L[857],link3175,[arg_DASH_10210202,option_DASH_info19310186]);
};
try {
if(--R.GAS > 0) {
$z1020510206 = $f1021110212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1021110212,
"from":L[857]});
}
} catch($e1020310204) {
if(R.isCont($e1020310204)) {
var $ss1020710208 = {"from":L[857],
"go":function(ann_DASH_check_DASH_temp50610213) {
return $Hann_DASH_check_DASH_temp204910214(ann_DASH_check_DASH_temp50610213);
}};
$e1020310204.stack[R.EXN_STACKHEIGHT++] = $ss1020710208;
}
if(R.isPyretException($e1020310204)) {
$e1020310204.pyretStack.push(L[857]);
}
throw $e1020310204;
}
var $ret1020910210 = $Hann_DASH_check_DASH_temp204910214($z1020510206);
++R.GAS;
return $ret1020910210;
});
var anf_fun50810198 = G(list2776,"make",L[856]);
var $z1019010191 = D;
var $f1019610197 = function(_) {
return R.isFunction(anf_fun50810198)?anf_fun50810198.app([file_DASH_name83203]):R.ffi.throwNonFunApp(L[856],anf_fun50810198,[[file_DASH_name83203]]);
};
try {
if(--R.GAS > 0) {
$z1019010191 = $f1019610197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1019610197,
"from":L[856]});
}
} catch($e1018810189) {
if(R.isCont($e1018810189)) {
var $ss1019210193 = {"from":L[856],
"go":function(anf_arg50910199) {
return $Hanf_arg205210201(anf_arg50910199,List1959,anf_fun50710200,format7872,$type$String28);
}};
$e1018810189.stack[R.EXN_STACKHEIGHT++] = $ss1019210193;
}
if(R.isPyretException($e1018810189)) {
$e1018810189.pyretStack.push(L[856]);
}
throw $e1018810189;
}
var $ret1019410195 = $Hanf_arg205210201($z1019010191,List1959,anf_fun50710200,format7872,$type$String28);
++R.GAS;
return $ret1019410195;
};
var $Hanf_arg205210201 = function(anf_arg50910199,List1959,anf_fun50710200,format7872,$type$String28) {
var $z1021710218 = D;
var $f1022310224 = function(_) {
return R.isFunction(format7872)?format7872.app(("Usage: ~a [list: options] where:"),anf_arg50910199):R.ffi.throwNonFunApp(L[858],format7872,[("Usage: ~a [list: options] where:"),anf_arg50910199]);
};
try {
if(--R.GAS > 0) {
$z1021710218 = $f1022310224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1022310224,
"from":L[858]});
}
} catch($e1021510216) {
if(R.isCont($e1021510216)) {
var $ss1021910220 = {"from":L[858],
"go":function(anf_arg51010225) {
return $Hanf_arg205110226(anf_arg51010225,List1959,anf_fun50710200,$type$String28);
}};
$e1021510216.stack[R.EXN_STACKHEIGHT++] = $ss1021910220;
}
if(R.isPyretException($e1021510216)) {
$e1021510216.pyretStack.push(L[858]);
}
throw $e1021510216;
}
var $ret1022110222 = $Hanf_arg205110226($z1021710218,List1959,anf_fun50710200,$type$String28);
++R.GAS;
return $ret1022110222;
};
var $Hanf_arg205110226 = function(anf_arg51010225,List1959,anf_fun50710200,$type$String28) {
var $z1022910230 = D;
var $f1023510236 = function(_) {
return R.isFunction(anf_fun50710200)?anf_fun50710200.app(anf_arg51010225):R.ffi.throwNonFunApp(L[17],anf_fun50710200,[anf_arg51010225]);
};
try {
if(--R.GAS > 0) {
$z1022910230 = $f1023510236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1023510236,
"from":L[17]});
}
} catch($e1022710228) {
if(R.isCont($e1022710228)) {
var $ss1023110232 = {"from":L[17],
"go":function(ann_DASH_check_DASH_temp44210237) {
return $Hann_DASH_check_DASH_temp205010238(ann_DASH_check_DASH_temp44210237,List1959,$type$String28);
}};
$e1022710228.stack[R.EXN_STACKHEIGHT++] = $ss1023110232;
}
if(R.isPyretException($e1022710228)) {
$e1022710228.pyretStack.push(L[17]);
}
throw $e1022710228;
}
var $ret1023310234 = $Hann_DASH_check_DASH_temp205010238($z1022910230,List1959,$type$String28);
++R.GAS;
return $ret1023310234;
};
var $Hann_DASH_check_DASH_temp205010238 = function(ann_DASH_check_DASH_temp44210237,List1959,$type$String28) {
return ann_DASH_check_DASH_temp44210237;
};
var $Hann_DASH_check_DASH_temp204910214 = function(ann_DASH_check_DASH_temp50610213) {
return ann_DASH_check_DASH_temp50610213;
};
var $Hcases_DASH_val204810175 = function(cases_DASH_val10110174,format7872,key19410162,list2776) {
var anf_fun44710249 = G(cases_DASH_val10110174,"_match",L[852]);
var anf_obj45110255 = R.makeFunction(function(repeated19510400,desc19610401) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[887],2,arguments);
}
var anf_fun44910412 = G(list2776,"make",L[888]);
var $z1040410405 = D;
var $f1041010411 = function(_) {
return R.isFunction(anf_fun44910412)?anf_fun44910412.app([key19410162,desc19610401,repeated19510400]):R.ffi.throwNonFunApp(L[888],anf_fun44910412,[[key19410162,desc19610401,repeated19510400]]);
};
try {
if(--R.GAS > 0) {
$z1040410405 = $f1041010411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1041010411,
"from":L[888]});
}
} catch($e1040210403) {
if(R.isCont($e1040210403)) {
var $ss1040610407 = {"from":L[888],
"go":function(anf_arg45010413) {
return $Hanf_arg202610414(anf_arg45010413,format7872);
}};
$e1040210403.stack[R.EXN_STACKHEIGHT++] = $ss1040610407;
}
if(R.isPyretException($e1040210403)) {
$e1040210403.pyretStack.push(L[888]);
}
throw $e1040210403;
}
var $ret1040810409 = $Hanf_arg202610414($z1040410405,format7872);
++R.GAS;
return $ret1040810409;
});
var anf_obj45710256 = R.makeFunction(function(parser19710383,repeated19810384,desc19910385) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[883],3,arguments);
}
var anf_fun45310398 = G(list2776,"make",L[886]);
var anf_fun45410396 = G(parser19710383,"parse-string",L[885]);
var $z1038810389 = D;
var $f1039410395 = function(_) {
return R.isFunction(anf_fun45410396)?anf_fun45410396.app():R.ffi.throwNonFunApp(L[884],anf_fun45410396,[]);
};
try {
if(--R.GAS > 0) {
$z1038810389 = $f1039410395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1039410395,
"from":L[884]});
}
} catch($e1038610387) {
if(R.isCont($e1038610387)) {
var $ss1039010391 = {"from":L[884],
"go":function(anf_array_val45510397) {
return $Hanf_array_val202910399(anf_array_val45510397,anf_fun45310398,desc19910385,format7872,key19410162,repeated19810384);
}};
$e1038610387.stack[R.EXN_STACKHEIGHT++] = $ss1039010391;
}
if(R.isPyretException($e1038610387)) {
$e1038610387.pyretStack.push(L[884]);
}
throw $e1038610387;
}
var $ret1039210393 = $Hanf_array_val202910399($z1038810389,anf_fun45310398,desc19910385,format7872,key19410162,repeated19810384);
++R.GAS;
return $ret1039210393;
});
var anf_obj47510257 = R.makeFunction(function(parser20010330,default20110331,short_DASH_name20210332,repeated20310333,desc20410334) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[873],5,arguments);
}
var cases_DASH_val9910382 = short_DASH_name20210332;
var anf_fun45910345 = G(cases_DASH_val9910382,"_match",L[874]);
var anf_obj46510351 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[879],0,arguments);
}
var anf_fun46110380 = G(list2776,"make",L[882]);
var anf_fun46210378 = G(parser20010330,"parse-string",L[881]);
var $z1037010371 = D;
var $f1037610377 = function(_) {
return R.isFunction(anf_fun46210378)?anf_fun46210378.app():R.ffi.throwNonFunApp(L[880],anf_fun46210378,[]);
};
try {
if(--R.GAS > 0) {
$z1037010371 = $f1037610377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1037610377,
"from":L[880]});
}
} catch($e1036810369) {
if(R.isCont($e1036810369)) {
var $ss1037210373 = {"from":L[880],
"go":function(anf_array_val46310379) {
return $Hanf_array_val203210381(anf_array_val46310379,anf_fun46110380,default20110331,desc20410334,format7872,key19410162,repeated20310333);
}};
$e1036810369.stack[R.EXN_STACKHEIGHT++] = $ss1037210373;
}
if(R.isPyretException($e1036810369)) {
$e1036810369.pyretStack.push(L[880]);
}
throw $e1036810369;
}
var $ret1037410375 = $Hanf_array_val203210381($z1037010371,anf_fun46110380,default20110331,desc20410334,format7872,key19410162,repeated20310333);
++R.GAS;
return $ret1037410375;
});
var anf_obj47110352 = R.makeFunction(function(short20510353) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[875],1,arguments);
}
var anf_fun46710366 = G(list2776,"make",L[878]);
var anf_fun46810364 = G(parser20010330,"parse-string",L[877]);
var $z1035610357 = D;
var $f1036210363 = function(_) {
return R.isFunction(anf_fun46810364)?anf_fun46810364.app():R.ffi.throwNonFunApp(L[876],anf_fun46810364,[]);
};
try {
if(--R.GAS > 0) {
$z1035610357 = $f1036210363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1036210363,
"from":L[876]});
}
} catch($e1035410355) {
if(R.isCont($e1035410355)) {
var $ss1035810359 = {"from":L[876],
"go":function(anf_array_val46910365) {
return $Hanf_array_val203510367(anf_array_val46910365,anf_fun46710366,default20110331,desc20410334,format7872,key19410162,repeated20310333,short20510353);
}};
$e1035410355.stack[R.EXN_STACKHEIGHT++] = $ss1035810359;
}
if(R.isPyretException($e1035410355)) {
$e1035410355.pyretStack.push(L[876]);
}
throw $e1035410355;
}
var $ret1036010361 = $Hanf_array_val203510367($z1035610357,anf_fun46710366,default20110331,desc20410334,format7872,key19410162,repeated20310333,short20510353);
++R.GAS;
return $ret1036010361;
});
var anf_arg47210346 = R.makeObject({"none":anf_obj46510351,
"some":anf_obj47110352});
var anf_arg47410347 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[874],0,arguments);
}
var ann_DASH_check_DASH_temp47310350 = R.throwNoBranchesMatched(L[874],("cases"));
return ann_DASH_check_DASH_temp47310350;
});
var $z1033710338 = D;
var $f1034310344 = function(_) {
return R.isFunction(anf_fun45910345)?anf_fun45910345.app(anf_arg47210346,anf_arg47410347):R.ffi.throwNonFunApp(L[873],anf_fun45910345,[anf_arg47210346,anf_arg47410347]);
};
try {
if(--R.GAS > 0) {
$z1033710338 = $f1034310344();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1034310344,
"from":L[873]});
}
} catch($e1033510336) {
if(R.isCont($e1033510336)) {
var $ss1033910340 = {"from":L[873],
"go":function(ann_DASH_check_DASH_temp45810348) {
return $Hann_DASH_check_DASH_temp203610349(ann_DASH_check_DASH_temp45810348);
}};
$e1033510336.stack[R.EXN_STACKHEIGHT++] = $ss1033910340;
}
if(R.isPyretException($e1033510336)) {
$e1033510336.pyretStack.push(L[873]);
}
throw $e1033510336;
}
var $ret1034110342 = $Hann_DASH_check_DASH_temp203610349($z1033710338);
++R.GAS;
return $ret1034110342;
});
var anf_obj48110258 = R.makeFunction(function(parser20610313,repeated20710314,desc20810315) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[869],3,arguments);
}
var anf_fun47710328 = G(list2776,"make",L[872]);
var anf_fun47810326 = G(parser20610313,"parse-string",L[871]);
var $z1031810319 = D;
var $f1032410325 = function(_) {
return R.isFunction(anf_fun47810326)?anf_fun47810326.app():R.ffi.throwNonFunApp(L[870],anf_fun47810326,[]);
};
try {
if(--R.GAS > 0) {
$z1031810319 = $f1032410325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1032410325,
"from":L[870]});
}
} catch($e1031610317) {
if(R.isCont($e1031610317)) {
var $ss1032010321 = {"from":L[870],
"go":function(anf_array_val47910327) {
return $Hanf_array_val203910329(anf_array_val47910327,anf_fun47710328,desc20810315,format7872,key19410162,repeated20710314);
}};
$e1031610317.stack[R.EXN_STACKHEIGHT++] = $ss1032010321;
}
if(R.isPyretException($e1031610317)) {
$e1031610317.pyretStack.push(L[870]);
}
throw $e1031610317;
}
var $ret1032210323 = $Hanf_array_val203910329($z1031810319,anf_fun47710328,desc20810315,format7872,key19410162,repeated20710314);
++R.GAS;
return $ret1032210323;
});
var anf_obj49910259 = R.makeFunction(function(parser20910260,default21010261,short_DASH_name21110262,repeated21210263,desc21310264) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[859],5,arguments);
}
var cases_DASH_val10010312 = short_DASH_name21110262;
var anf_fun48310275 = G(cases_DASH_val10010312,"_match",L[860]);
var anf_obj48910281 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[865],0,arguments);
}
var anf_fun48510310 = G(list2776,"make",L[868]);
var anf_fun48610308 = G(parser20910260,"parse-string",L[867]);
var $z1030010301 = D;
var $f1030610307 = function(_) {
return R.isFunction(anf_fun48610308)?anf_fun48610308.app():R.ffi.throwNonFunApp(L[866],anf_fun48610308,[]);
};
try {
if(--R.GAS > 0) {
$z1030010301 = $f1030610307();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1030610307,
"from":L[866]});
}
} catch($e1029810299) {
if(R.isCont($e1029810299)) {
var $ss1030210303 = {"from":L[866],
"go":function(anf_array_val48710309) {
return $Hanf_array_val204210311(anf_array_val48710309,anf_fun48510310,default21010261,desc21310264,format7872,key19410162,repeated21210263);
}};
$e1029810299.stack[R.EXN_STACKHEIGHT++] = $ss1030210303;
}
if(R.isPyretException($e1029810299)) {
$e1029810299.pyretStack.push(L[866]);
}
throw $e1029810299;
}
var $ret1030410305 = $Hanf_array_val204210311($z1030010301,anf_fun48510310,default21010261,desc21310264,format7872,key19410162,repeated21210263);
++R.GAS;
return $ret1030410305;
});
var anf_obj49510282 = R.makeFunction(function(short21410283) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[861],1,arguments);
}
var anf_fun49110296 = G(list2776,"make",L[864]);
var anf_fun49210294 = G(parser20910260,"parse-string",L[863]);
var $z1028610287 = D;
var $f1029210293 = function(_) {
return R.isFunction(anf_fun49210294)?anf_fun49210294.app():R.ffi.throwNonFunApp(L[862],anf_fun49210294,[]);
};
try {
if(--R.GAS > 0) {
$z1028610287 = $f1029210293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1029210293,
"from":L[862]});
}
} catch($e1028410285) {
if(R.isCont($e1028410285)) {
var $ss1028810289 = {"from":L[862],
"go":function(anf_array_val49310295) {
return $Hanf_array_val204510297(anf_array_val49310295,anf_fun49110296,default21010261,desc21310264,format7872,key19410162,repeated21210263,short21410283);
}};
$e1028410285.stack[R.EXN_STACKHEIGHT++] = $ss1028810289;
}
if(R.isPyretException($e1028410285)) {
$e1028410285.pyretStack.push(L[862]);
}
throw $e1028410285;
}
var $ret1029010291 = $Hanf_array_val204510297($z1028610287,anf_fun49110296,default21010261,desc21310264,format7872,key19410162,repeated21210263,short21410283);
++R.GAS;
return $ret1029010291;
});
var anf_arg49610276 = R.makeObject({"none":anf_obj48910281,
"some":anf_obj49510282});
var anf_arg49810277 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[860],0,arguments);
}
var ann_DASH_check_DASH_temp49710280 = R.throwNoBranchesMatched(L[860],("cases"));
return ann_DASH_check_DASH_temp49710280;
});
var $z1026710268 = D;
var $f1027310274 = function(_) {
return R.isFunction(anf_fun48310275)?anf_fun48310275.app(anf_arg49610276,anf_arg49810277):R.ffi.throwNonFunApp(L[859],anf_fun48310275,[anf_arg49610276,anf_arg49810277]);
};
try {
if(--R.GAS > 0) {
$z1026710268 = $f1027310274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1027310274,
"from":L[859]});
}
} catch($e1026510266) {
if(R.isCont($e1026510266)) {
var $ss1026910270 = {"from":L[859],
"go":function(ann_DASH_check_DASH_temp48210278) {
return $Hann_DASH_check_DASH_temp204610279(ann_DASH_check_DASH_temp48210278);
}};
$e1026510266.stack[R.EXN_STACKHEIGHT++] = $ss1026910270;
}
if(R.isPyretException($e1026510266)) {
$e1026510266.pyretStack.push(L[859]);
}
throw $e1026510266;
}
var $ret1027110272 = $Hann_DASH_check_DASH_temp204610279($z1026710268);
++R.GAS;
return $ret1027110272;
});
var anf_arg50010250 = R.makeObject({"flag":anf_obj45110255,
"equals-val":anf_obj45710256,
"equals-val-default":anf_obj47510257,
"next-val":anf_obj48110258,
"next-val-default":anf_obj49910259});
var anf_arg50210251 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[852],0,arguments);
}
var ann_DASH_check_DASH_temp50110254 = R.throwNoBranchesMatched(L[852],("cases"));
return ann_DASH_check_DASH_temp50110254;
});
var $z1024110242 = D;
var $f1024710248 = function(_) {
return R.isFunction(anf_fun44710249)?anf_fun44710249.app(anf_arg50010250,anf_arg50210251):R.ffi.throwNonFunApp(L[851],anf_fun44710249,[anf_arg50010250,anf_arg50210251]);
};
try {
if(--R.GAS > 0) {
$z1024110242 = $f1024710248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1024710248,
"from":L[851]});
}
} catch($e1023910240) {
if(R.isCont($e1023910240)) {
var $ss1024310244 = {"from":L[851],
"go":function(ann_DASH_check_DASH_temp44510252) {
return $Hann_DASH_check_DASH_temp204710253(ann_DASH_check_DASH_temp44510252);
}};
$e1023910240.stack[R.EXN_STACKHEIGHT++] = $ss1024310244;
}
if(R.isPyretException($e1023910240)) {
$e1023910240.pyretStack.push(L[851]);
}
throw $e1023910240;
}
var $ret1024510246 = $Hann_DASH_check_DASH_temp204710253($z1024110242);
++R.GAS;
return $ret1024510246;
};
var $Hann_DASH_check_DASH_temp204710253 = function(ann_DASH_check_DASH_temp44510252) {
return ann_DASH_check_DASH_temp44510252;
};
var $Hann_DASH_check_DASH_temp204610279 = function(ann_DASH_check_DASH_temp48210278) {
return ann_DASH_check_DASH_temp48210278;
};
var $Hanf_array_val204510297 = function(anf_array_val49310295,anf_fun49110296,default21010261,desc21310264,format7872,key19410162,repeated21210263,short21410283) {
var $z1041710418 = D;
var $f1042310424 = function(_) {
return R.isFunction(anf_fun49110296)?anf_fun49110296.app([key19410162,anf_array_val49310295,desc21310264,repeated21210263,default21010261,short21410283,desc21310264,repeated21210263]):R.ffi.throwNonFunApp(L[864],anf_fun49110296,[[key19410162,anf_array_val49310295,desc21310264,repeated21210263,default21010261,short21410283,desc21310264,repeated21210263]]);
};
try {
if(--R.GAS > 0) {
$z1041710418 = $f1042310424();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1042310424,
"from":L[864]});
}
} catch($e1041510416) {
if(R.isCont($e1041510416)) {
var $ss1041910420 = {"from":L[864],
"go":function(anf_arg49410425) {
return $Hanf_arg204410426(anf_arg49410425,format7872);
}};
$e1041510416.stack[R.EXN_STACKHEIGHT++] = $ss1041910420;
}
if(R.isPyretException($e1041510416)) {
$e1041510416.pyretStack.push(L[864]);
}
throw $e1041510416;
}
var $ret1042110422 = $Hanf_arg204410426($z1041710418,format7872);
++R.GAS;
return $ret1042110422;
};
var $Hanf_arg204410426 = function(anf_arg49410425,format7872) {
var $z1042910430 = D;
var $f1043510436 = function(_) {
return R.isFunction(format7872)?format7872.app(("  --~a [list: ~a]: ~a (~a, default: ~a)\n  -~a: Defaults for ~a (~a)"),anf_arg49410425):R.ffi.throwNonFunApp(L[861],format7872,[("  --~a [list: ~a]: ~a (~a, default: ~a)\n  -~a: Defaults for ~a (~a)"),anf_arg49410425]);
};
try {
if(--R.GAS > 0) {
$z1042910430 = $f1043510436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1043510436,
"from":L[861]});
}
} catch($e1042710428) {
if(R.isCont($e1042710428)) {
var $ss1043110432 = {"from":L[861],
"go":function(ann_DASH_check_DASH_temp49010437) {
return $Hann_DASH_check_DASH_temp204310438(ann_DASH_check_DASH_temp49010437);
}};
$e1042710428.stack[R.EXN_STACKHEIGHT++] = $ss1043110432;
}
if(R.isPyretException($e1042710428)) {
$e1042710428.pyretStack.push(L[861]);
}
throw $e1042710428;
}
var $ret1043310434 = $Hann_DASH_check_DASH_temp204310438($z1042910430);
++R.GAS;
return $ret1043310434;
};
var $Hann_DASH_check_DASH_temp204310438 = function(ann_DASH_check_DASH_temp49010437) {
return ann_DASH_check_DASH_temp49010437;
};
var $Hanf_array_val204210311 = function(anf_array_val48710309,anf_fun48510310,default21010261,desc21310264,format7872,key19410162,repeated21210263) {
var $z1044110442 = D;
var $f1044710448 = function(_) {
return R.isFunction(anf_fun48510310)?anf_fun48510310.app([key19410162,anf_array_val48710309,desc21310264,repeated21210263,default21010261]):R.ffi.throwNonFunApp(L[868],anf_fun48510310,[[key19410162,anf_array_val48710309,desc21310264,repeated21210263,default21010261]]);
};
try {
if(--R.GAS > 0) {
$z1044110442 = $f1044710448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1044710448,
"from":L[868]});
}
} catch($e1043910440) {
if(R.isCont($e1043910440)) {
var $ss1044310444 = {"from":L[868],
"go":function(anf_arg48810449) {
return $Hanf_arg204110450(anf_arg48810449,format7872);
}};
$e1043910440.stack[R.EXN_STACKHEIGHT++] = $ss1044310444;
}
if(R.isPyretException($e1043910440)) {
$e1043910440.pyretStack.push(L[868]);
}
throw $e1043910440;
}
var $ret1044510446 = $Hanf_arg204110450($z1044110442,format7872);
++R.GAS;
return $ret1044510446;
};
var $Hanf_arg204110450 = function(anf_arg48810449,format7872) {
var $z1045310454 = D;
var $f1045910460 = function(_) {
return R.isFunction(format7872)?format7872.app(("  --~a [list: ~a]: ~a (~a, default: ~a)"),anf_arg48810449):R.ffi.throwNonFunApp(L[865],format7872,[("  --~a [list: ~a]: ~a (~a, default: ~a)"),anf_arg48810449]);
};
try {
if(--R.GAS > 0) {
$z1045310454 = $f1045910460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1045910460,
"from":L[865]});
}
} catch($e1045110452) {
if(R.isCont($e1045110452)) {
var $ss1045510456 = {"from":L[865],
"go":function(ann_DASH_check_DASH_temp48410461) {
return $Hann_DASH_check_DASH_temp204010462(ann_DASH_check_DASH_temp48410461);
}};
$e1045110452.stack[R.EXN_STACKHEIGHT++] = $ss1045510456;
}
if(R.isPyretException($e1045110452)) {
$e1045110452.pyretStack.push(L[865]);
}
throw $e1045110452;
}
var $ret1045710458 = $Hann_DASH_check_DASH_temp204010462($z1045310454);
++R.GAS;
return $ret1045710458;
};
var $Hann_DASH_check_DASH_temp204010462 = function(ann_DASH_check_DASH_temp48410461) {
return ann_DASH_check_DASH_temp48410461;
};
var $Hanf_array_val203910329 = function(anf_array_val47910327,anf_fun47710328,desc20810315,format7872,key19410162,repeated20710314) {
var $z1046510466 = D;
var $f1047110472 = function(_) {
return R.isFunction(anf_fun47710328)?anf_fun47710328.app([key19410162,anf_array_val47910327,desc20810315,repeated20710314]):R.ffi.throwNonFunApp(L[872],anf_fun47710328,[[key19410162,anf_array_val47910327,desc20810315,repeated20710314]]);
};
try {
if(--R.GAS > 0) {
$z1046510466 = $f1047110472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1047110472,
"from":L[872]});
}
} catch($e1046310464) {
if(R.isCont($e1046310464)) {
var $ss1046710468 = {"from":L[872],
"go":function(anf_arg48010473) {
return $Hanf_arg203810474(anf_arg48010473,format7872);
}};
$e1046310464.stack[R.EXN_STACKHEIGHT++] = $ss1046710468;
}
if(R.isPyretException($e1046310464)) {
$e1046310464.pyretStack.push(L[872]);
}
throw $e1046310464;
}
var $ret1046910470 = $Hanf_arg203810474($z1046510466,format7872);
++R.GAS;
return $ret1046910470;
};
var $Hanf_arg203810474 = function(anf_arg48010473,format7872) {
var $z1047710478 = D;
var $f1048310484 = function(_) {
return R.isFunction(format7872)?format7872.app(("  --~a ~a: ~a (~a)"),anf_arg48010473):R.ffi.throwNonFunApp(L[869],format7872,[("  --~a ~a: ~a (~a)"),anf_arg48010473]);
};
try {
if(--R.GAS > 0) {
$z1047710478 = $f1048310484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1048310484,
"from":L[869]});
}
} catch($e1047510476) {
if(R.isCont($e1047510476)) {
var $ss1047910480 = {"from":L[869],
"go":function(ann_DASH_check_DASH_temp47610485) {
return $Hann_DASH_check_DASH_temp203710486(ann_DASH_check_DASH_temp47610485);
}};
$e1047510476.stack[R.EXN_STACKHEIGHT++] = $ss1047910480;
}
if(R.isPyretException($e1047510476)) {
$e1047510476.pyretStack.push(L[869]);
}
throw $e1047510476;
}
var $ret1048110482 = $Hann_DASH_check_DASH_temp203710486($z1047710478);
++R.GAS;
return $ret1048110482;
};
var $Hann_DASH_check_DASH_temp203710486 = function(ann_DASH_check_DASH_temp47610485) {
return ann_DASH_check_DASH_temp47610485;
};
var $Hann_DASH_check_DASH_temp203610349 = function(ann_DASH_check_DASH_temp45810348) {
return ann_DASH_check_DASH_temp45810348;
};
var $Hanf_array_val203510367 = function(anf_array_val46910365,anf_fun46710366,default20110331,desc20410334,format7872,key19410162,repeated20310333,short20510353) {
var $z1048910490 = D;
var $f1049510496 = function(_) {
return R.isFunction(anf_fun46710366)?anf_fun46710366.app([key19410162,anf_array_val46910365,desc20410334,repeated20310333,default20110331,short20510353,desc20410334,repeated20310333]):R.ffi.throwNonFunApp(L[878],anf_fun46710366,[[key19410162,anf_array_val46910365,desc20410334,repeated20310333,default20110331,short20510353,desc20410334,repeated20310333]]);
};
try {
if(--R.GAS > 0) {
$z1048910490 = $f1049510496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1049510496,
"from":L[878]});
}
} catch($e1048710488) {
if(R.isCont($e1048710488)) {
var $ss1049110492 = {"from":L[878],
"go":function(anf_arg47010497) {
return $Hanf_arg203410498(anf_arg47010497,format7872);
}};
$e1048710488.stack[R.EXN_STACKHEIGHT++] = $ss1049110492;
}
if(R.isPyretException($e1048710488)) {
$e1048710488.pyretStack.push(L[878]);
}
throw $e1048710488;
}
var $ret1049310494 = $Hanf_arg203410498($z1048910490,format7872);
++R.GAS;
return $ret1049310494;
};
var $Hanf_arg203410498 = function(anf_arg47010497,format7872) {
var $z1050110502 = D;
var $f1050710508 = function(_) {
return R.isFunction(format7872)?format7872.app(("  --~a[list: =~a]: ~a (~a, default: ~a)\n  -~a: Defaults for ~a (~a)"),anf_arg47010497):R.ffi.throwNonFunApp(L[875],format7872,[("  --~a[list: =~a]: ~a (~a, default: ~a)\n  -~a: Defaults for ~a (~a)"),anf_arg47010497]);
};
try {
if(--R.GAS > 0) {
$z1050110502 = $f1050710508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1050710508,
"from":L[875]});
}
} catch($e1049910500) {
if(R.isCont($e1049910500)) {
var $ss1050310504 = {"from":L[875],
"go":function(ann_DASH_check_DASH_temp46610509) {
return $Hann_DASH_check_DASH_temp203310510(ann_DASH_check_DASH_temp46610509);
}};
$e1049910500.stack[R.EXN_STACKHEIGHT++] = $ss1050310504;
}
if(R.isPyretException($e1049910500)) {
$e1049910500.pyretStack.push(L[875]);
}
throw $e1049910500;
}
var $ret1050510506 = $Hann_DASH_check_DASH_temp203310510($z1050110502);
++R.GAS;
return $ret1050510506;
};
var $Hann_DASH_check_DASH_temp203310510 = function(ann_DASH_check_DASH_temp46610509) {
return ann_DASH_check_DASH_temp46610509;
};
var $Hanf_array_val203210381 = function(anf_array_val46310379,anf_fun46110380,default20110331,desc20410334,format7872,key19410162,repeated20310333) {
var $z1051310514 = D;
var $f1051910520 = function(_) {
return R.isFunction(anf_fun46110380)?anf_fun46110380.app([key19410162,anf_array_val46310379,desc20410334,repeated20310333,default20110331]):R.ffi.throwNonFunApp(L[882],anf_fun46110380,[[key19410162,anf_array_val46310379,desc20410334,repeated20310333,default20110331]]);
};
try {
if(--R.GAS > 0) {
$z1051310514 = $f1051910520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1051910520,
"from":L[882]});
}
} catch($e1051110512) {
if(R.isCont($e1051110512)) {
var $ss1051510516 = {"from":L[882],
"go":function(anf_arg46410521) {
return $Hanf_arg203110522(anf_arg46410521,format7872);
}};
$e1051110512.stack[R.EXN_STACKHEIGHT++] = $ss1051510516;
}
if(R.isPyretException($e1051110512)) {
$e1051110512.pyretStack.push(L[882]);
}
throw $e1051110512;
}
var $ret1051710518 = $Hanf_arg203110522($z1051310514,format7872);
++R.GAS;
return $ret1051710518;
};
var $Hanf_arg203110522 = function(anf_arg46410521,format7872) {
var $z1052510526 = D;
var $f1053110532 = function(_) {
return R.isFunction(format7872)?format7872.app(("  --~a[list: =~a]: ~a (~a, default: ~a)"),anf_arg46410521):R.ffi.throwNonFunApp(L[879],format7872,[("  --~a[list: =~a]: ~a (~a, default: ~a)"),anf_arg46410521]);
};
try {
if(--R.GAS > 0) {
$z1052510526 = $f1053110532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1053110532,
"from":L[879]});
}
} catch($e1052310524) {
if(R.isCont($e1052310524)) {
var $ss1052710528 = {"from":L[879],
"go":function(ann_DASH_check_DASH_temp46010533) {
return $Hann_DASH_check_DASH_temp203010534(ann_DASH_check_DASH_temp46010533);
}};
$e1052310524.stack[R.EXN_STACKHEIGHT++] = $ss1052710528;
}
if(R.isPyretException($e1052310524)) {
$e1052310524.pyretStack.push(L[879]);
}
throw $e1052310524;
}
var $ret1052910530 = $Hann_DASH_check_DASH_temp203010534($z1052510526);
++R.GAS;
return $ret1052910530;
};
var $Hann_DASH_check_DASH_temp203010534 = function(ann_DASH_check_DASH_temp46010533) {
return ann_DASH_check_DASH_temp46010533;
};
var $Hanf_array_val202910399 = function(anf_array_val45510397,anf_fun45310398,desc19910385,format7872,key19410162,repeated19810384) {
var $z1053710538 = D;
var $f1054310544 = function(_) {
return R.isFunction(anf_fun45310398)?anf_fun45310398.app([key19410162,anf_array_val45510397,desc19910385,repeated19810384]):R.ffi.throwNonFunApp(L[886],anf_fun45310398,[[key19410162,anf_array_val45510397,desc19910385,repeated19810384]]);
};
try {
if(--R.GAS > 0) {
$z1053710538 = $f1054310544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1054310544,
"from":L[886]});
}
} catch($e1053510536) {
if(R.isCont($e1053510536)) {
var $ss1053910540 = {"from":L[886],
"go":function(anf_arg45610545) {
return $Hanf_arg202810546(anf_arg45610545,format7872);
}};
$e1053510536.stack[R.EXN_STACKHEIGHT++] = $ss1053910540;
}
if(R.isPyretException($e1053510536)) {
$e1053510536.pyretStack.push(L[886]);
}
throw $e1053510536;
}
var $ret1054110542 = $Hanf_arg202810546($z1053710538,format7872);
++R.GAS;
return $ret1054110542;
};
var $Hanf_arg202810546 = function(anf_arg45610545,format7872) {
var $z1054910550 = D;
var $f1055510556 = function(_) {
return R.isFunction(format7872)?format7872.app(("  --~a=~a: ~a (~a)"),anf_arg45610545):R.ffi.throwNonFunApp(L[883],format7872,[("  --~a=~a: ~a (~a)"),anf_arg45610545]);
};
try {
if(--R.GAS > 0) {
$z1054910550 = $f1055510556();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1055510556,
"from":L[883]});
}
} catch($e1054710548) {
if(R.isCont($e1054710548)) {
var $ss1055110552 = {"from":L[883],
"go":function(ann_DASH_check_DASH_temp45210557) {
return $Hann_DASH_check_DASH_temp202710558(ann_DASH_check_DASH_temp45210557);
}};
$e1054710548.stack[R.EXN_STACKHEIGHT++] = $ss1055110552;
}
if(R.isPyretException($e1054710548)) {
$e1054710548.pyretStack.push(L[883]);
}
throw $e1054710548;
}
var $ret1055310554 = $Hann_DASH_check_DASH_temp202710558($z1054910550);
++R.GAS;
return $ret1055310554;
};
var $Hann_DASH_check_DASH_temp202710558 = function(ann_DASH_check_DASH_temp45210557) {
return ann_DASH_check_DASH_temp45210557;
};
var $Hanf_arg202610414 = function(anf_arg45010413,format7872) {
var $z1056110562 = D;
var $f1056710568 = function(_) {
return R.isFunction(format7872)?format7872.app(("  -~a: ~a (~a)"),anf_arg45010413):R.ffi.throwNonFunApp(L[887],format7872,[("  -~a: ~a (~a)"),anf_arg45010413]);
};
try {
if(--R.GAS > 0) {
$z1056110562 = $f1056710568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1056710568,
"from":L[887]});
}
} catch($e1055910560) {
if(R.isCont($e1055910560)) {
var $ss1056310564 = {"from":L[887],
"go":function(ann_DASH_check_DASH_temp44810569) {
return $Hann_DASH_check_DASH_temp202510570(ann_DASH_check_DASH_temp44810569);
}};
$e1055910560.stack[R.EXN_STACKHEIGHT++] = $ss1056310564;
}
if(R.isPyretException($e1055910560)) {
$e1055910560.pyretStack.push(L[887]);
}
throw $e1055910560;
}
var $ret1056510566 = $Hann_DASH_check_DASH_temp202510570($z1056110562);
++R.GAS;
return $ret1056510566;
};
var $Hann_DASH_check_DASH_temp202510570 = function(ann_DASH_check_DASH_temp44810569) {
return ann_DASH_check_DASH_temp44810569;
};
var $Hor_DASH_oper_DASH_2024428 = function(or_DASH_oper_DASH_94427,is_DASH_equals_DASH_val_DASH_default121151,is_DASH_equals_DASH_val119147,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416) {
var if_helper41910581 = R.makeFunction(function(if_helper_arg42010600) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[21],1,arguments);
}
var ann_DASH_check_DASH_temp41810601 = if_helper_arg42010600;
return ann_DASH_check_DASH_temp41810601;
});
var anf_if42310599 = R.isBoolean(or_DASH_oper_DASH_94427);
if(R.isPyretTrue(anf_if42310599)) {
if(R.isPyretTrue(or_DASH_oper_DASH_94427)) {
var $z1057310574 = D;
var $f1057910580 = function(_) {
return R.isFunction(if_helper41910581)?if_helper41910581.app((true)):R.ffi.throwNonFunApp(L[21],if_helper41910581,[(true)]);
};
try {
if(--R.GAS > 0) {
$z1057310574 = $f1057910580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1057910580,
"from":L[21]});
}
} catch($e1057110572) {
if(R.isCont($e1057110572)) {
var $ss1057510576 = {"from":L[21],
"go":function(cont_tail_app44010582) {
return $Hcont_tail_app201510583(cont_tail_app44010582);
}};
$e1057110572.stack[R.EXN_STACKHEIGHT++] = $ss1057510576;
}
if(R.isPyretException($e1057110572)) {
$e1057110572.pyretStack.push(L[21]);
}
throw $e1057110572;
}
var $ret1057710578 = $Hcont_tail_app201510583($z1057310574);
++R.GAS;
return $ret1057710578;
} else {
var $z1058610587 = D;
var $f1059210593 = function(_) {
return R.isFunction(is_DASH_equals_DASH_val119147.$var)?is_DASH_equals_DASH_val119147.$var.app(l190416):R.ffi.throwNonFunApp(L[21],is_DASH_equals_DASH_val119147.$var,[l190416]);
};
try {
if(--R.GAS > 0) {
$z1058610587 = $f1059210593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1059210593,
"from":L[21]});
}
} catch($e1058410585) {
if(R.isCont($e1058410585)) {
var $ss1058810589 = {"from":L[21],
"go":function(or_DASH_oper_DASH_9510594) {
return $Hor_DASH_oper_DASH_202310595(or_DASH_oper_DASH_9510594,if_helper41910581,is_DASH_equals_DASH_val_DASH_default121151,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416);
}};
$e1058410585.stack[R.EXN_STACKHEIGHT++] = $ss1058810589;
}
if(R.isPyretException($e1058410585)) {
$e1058410585.pyretStack.push(L[21]);
}
throw $e1058410585;
}
var $ret1059010591 = $Hor_DASH_oper_DASH_202310595($z1058610587,if_helper41910581,is_DASH_equals_DASH_val_DASH_default121151,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416);
++R.GAS;
return $ret1059010591;
}
} else {
var cont_tail_arg42110598 = R.throwNonBooleanOp(L[889],("first"),("or"),or_DASH_oper_DASH_94427);
if(--R.GAS > 0) {
$z1059610597 = R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg42110598):R.ffi.throwNonFunApp(L[889],if_helper41910581,[cont_tail_arg42110598]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg42110598):R.ffi.throwNonFunApp(L[889],if_helper41910581,[cont_tail_arg42110598]);
},
"from":L[889]});
}
++R.GAS;
return $z1059610597;
}
};
var $Hcont_tail_app201510583 = function(cont_tail_app44010582) {
return cont_tail_app44010582;
};
var $Hor_DASH_oper_DASH_202310595 = function(or_DASH_oper_DASH_9510594,if_helper41910581,is_DASH_equals_DASH_val_DASH_default121151,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416) {
var anf_if42610629 = R.isBoolean(or_DASH_oper_DASH_9510594);
if(R.isPyretTrue(anf_if42610629)) {
if(R.isPyretTrue(or_DASH_oper_DASH_9510594)) {
var $z1060410605 = D;
var $f1061010611 = function(_) {
return R.isFunction(if_helper41910581)?if_helper41910581.app((true)):R.ffi.throwNonFunApp(L[21],if_helper41910581,[(true)]);
};
try {
if(--R.GAS > 0) {
$z1060410605 = $f1061010611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1061010611,
"from":L[21]});
}
} catch($e1060210603) {
if(R.isCont($e1060210603)) {
var $ss1060610607 = {"from":L[21],
"go":function(cont_tail_app43910612) {
return $Hcont_tail_app201610613(cont_tail_app43910612);
}};
$e1060210603.stack[R.EXN_STACKHEIGHT++] = $ss1060610607;
}
if(R.isPyretException($e1060210603)) {
$e1060210603.pyretStack.push(L[21]);
}
throw $e1060210603;
}
var $ret1060810609 = $Hcont_tail_app201610613($z1060410605);
++R.GAS;
return $ret1060810609;
} else {
var $z1061610617 = D;
var $f1062210623 = function(_) {
return R.isFunction(is_DASH_equals_DASH_val_DASH_default121151.$var)?is_DASH_equals_DASH_val_DASH_default121151.$var.app(l190416):R.ffi.throwNonFunApp(L[21],is_DASH_equals_DASH_val_DASH_default121151.$var,[l190416]);
};
try {
if(--R.GAS > 0) {
$z1061610617 = $f1062210623();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1062210623,
"from":L[21]});
}
} catch($e1061410615) {
if(R.isCont($e1061410615)) {
var $ss1061810619 = {"from":L[21],
"go":function(or_DASH_oper_DASH_9610624) {
return $Hor_DASH_oper_DASH_202210625(or_DASH_oper_DASH_9610624,if_helper41910581,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416);
}};
$e1061410615.stack[R.EXN_STACKHEIGHT++] = $ss1061810619;
}
if(R.isPyretException($e1061410615)) {
$e1061410615.pyretStack.push(L[21]);
}
throw $e1061410615;
}
var $ret1062010621 = $Hor_DASH_oper_DASH_202210625($z1061610617,if_helper41910581,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416);
++R.GAS;
return $ret1062010621;
}
} else {
var cont_tail_arg42410628 = R.throwNonBooleanOp(L[890],("first"),("or"),or_DASH_oper_DASH_9510594);
if(--R.GAS > 0) {
$z1062610627 = R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg42410628):R.ffi.throwNonFunApp(L[890],if_helper41910581,[cont_tail_arg42410628]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg42410628):R.ffi.throwNonFunApp(L[890],if_helper41910581,[cont_tail_arg42410628]);
},
"from":L[890]});
}
++R.GAS;
return $z1062610627;
}
};
var $Hcont_tail_app201610613 = function(cont_tail_app43910612) {
return cont_tail_app43910612;
};
var $Hor_DASH_oper_DASH_202210625 = function(or_DASH_oper_DASH_9610624,if_helper41910581,is_DASH_next_DASH_val_DASH_default125159,is_DASH_next_DASH_val123155,l190416) {
var anf_if42910657 = R.isBoolean(or_DASH_oper_DASH_9610624);
if(R.isPyretTrue(anf_if42910657)) {
if(R.isPyretTrue(or_DASH_oper_DASH_9610624)) {
var $z1063210633 = D;
var $f1063810639 = function(_) {
return R.isFunction(if_helper41910581)?if_helper41910581.app((true)):R.ffi.throwNonFunApp(L[21],if_helper41910581,[(true)]);
};
try {
if(--R.GAS > 0) {
$z1063210633 = $f1063810639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1063810639,
"from":L[21]});
}
} catch($e1063010631) {
if(R.isCont($e1063010631)) {
var $ss1063410635 = {"from":L[21],
"go":function(cont_tail_app43810640) {
return $Hcont_tail_app201710641(cont_tail_app43810640);
}};
$e1063010631.stack[R.EXN_STACKHEIGHT++] = $ss1063410635;
}
if(R.isPyretException($e1063010631)) {
$e1063010631.pyretStack.push(L[21]);
}
throw $e1063010631;
}
var $ret1063610637 = $Hcont_tail_app201710641($z1063210633);
++R.GAS;
return $ret1063610637;
} else {
var $z1064410645 = D;
var $f1065010651 = function(_) {
return R.isFunction(is_DASH_next_DASH_val123155.$var)?is_DASH_next_DASH_val123155.$var.app(l190416):R.ffi.throwNonFunApp(L[21],is_DASH_next_DASH_val123155.$var,[l190416]);
};
try {
if(--R.GAS > 0) {
$z1064410645 = $f1065010651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1065010651,
"from":L[21]});
}
} catch($e1064210643) {
if(R.isCont($e1064210643)) {
var $ss1064610647 = {"from":L[21],
"go":function(or_DASH_oper_DASH_9710652) {
return $Hor_DASH_oper_DASH_202110653(or_DASH_oper_DASH_9710652,if_helper41910581,is_DASH_next_DASH_val_DASH_default125159,l190416);
}};
$e1064210643.stack[R.EXN_STACKHEIGHT++] = $ss1064610647;
}
if(R.isPyretException($e1064210643)) {
$e1064210643.pyretStack.push(L[21]);
}
throw $e1064210643;
}
var $ret1064810649 = $Hor_DASH_oper_DASH_202110653($z1064410645,if_helper41910581,is_DASH_next_DASH_val_DASH_default125159,l190416);
++R.GAS;
return $ret1064810649;
}
} else {
var cont_tail_arg42710656 = R.throwNonBooleanOp(L[891],("first"),("or"),or_DASH_oper_DASH_9610624);
if(--R.GAS > 0) {
$z1065410655 = R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg42710656):R.ffi.throwNonFunApp(L[891],if_helper41910581,[cont_tail_arg42710656]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg42710656):R.ffi.throwNonFunApp(L[891],if_helper41910581,[cont_tail_arg42710656]);
},
"from":L[891]});
}
++R.GAS;
return $z1065410655;
}
};
var $Hcont_tail_app201710641 = function(cont_tail_app43810640) {
return cont_tail_app43810640;
};
var $Hor_DASH_oper_DASH_202110653 = function(or_DASH_oper_DASH_9710652,if_helper41910581,is_DASH_next_DASH_val_DASH_default125159,l190416) {
var anf_if43210685 = R.isBoolean(or_DASH_oper_DASH_9710652);
if(R.isPyretTrue(anf_if43210685)) {
if(R.isPyretTrue(or_DASH_oper_DASH_9710652)) {
var $z1066010661 = D;
var $f1066610667 = function(_) {
return R.isFunction(if_helper41910581)?if_helper41910581.app((true)):R.ffi.throwNonFunApp(L[21],if_helper41910581,[(true)]);
};
try {
if(--R.GAS > 0) {
$z1066010661 = $f1066610667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1066610667,
"from":L[21]});
}
} catch($e1065810659) {
if(R.isCont($e1065810659)) {
var $ss1066210663 = {"from":L[21],
"go":function(cont_tail_app43710668) {
return $Hcont_tail_app201810669(cont_tail_app43710668);
}};
$e1065810659.stack[R.EXN_STACKHEIGHT++] = $ss1066210663;
}
if(R.isPyretException($e1065810659)) {
$e1065810659.pyretStack.push(L[21]);
}
throw $e1065810659;
}
var $ret1066410665 = $Hcont_tail_app201810669($z1066010661);
++R.GAS;
return $ret1066410665;
} else {
var $z1067210673 = D;
var $f1067810679 = function(_) {
return R.isFunction(is_DASH_next_DASH_val_DASH_default125159.$var)?is_DASH_next_DASH_val_DASH_default125159.$var.app(l190416):R.ffi.throwNonFunApp(L[21],is_DASH_next_DASH_val_DASH_default125159.$var,[l190416]);
};
try {
if(--R.GAS > 0) {
$z1067210673 = $f1067810679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1067810679,
"from":L[21]});
}
} catch($e1067010671) {
if(R.isCont($e1067010671)) {
var $ss1067410675 = {"from":L[21],
"go":function(or_DASH_oper_DASH_9810680) {
return $Hor_DASH_oper_DASH_202010681(or_DASH_oper_DASH_9810680,if_helper41910581);
}};
$e1067010671.stack[R.EXN_STACKHEIGHT++] = $ss1067410675;
}
if(R.isPyretException($e1067010671)) {
$e1067010671.pyretStack.push(L[21]);
}
throw $e1067010671;
}
var $ret1067610677 = $Hor_DASH_oper_DASH_202010681($z1067210673,if_helper41910581);
++R.GAS;
return $ret1067610677;
}
} else {
var cont_tail_arg43010684 = R.throwNonBooleanOp(L[892],("first"),("or"),or_DASH_oper_DASH_9710652);
if(--R.GAS > 0) {
$z1068210683 = R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg43010684):R.ffi.throwNonFunApp(L[892],if_helper41910581,[cont_tail_arg43010684]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg43010684):R.ffi.throwNonFunApp(L[892],if_helper41910581,[cont_tail_arg43010684]);
},
"from":L[892]});
}
++R.GAS;
return $z1068210683;
}
};
var $Hcont_tail_app201810669 = function(cont_tail_app43710668) {
return cont_tail_app43710668;
};
var $Hor_DASH_oper_DASH_202010681 = function(or_DASH_oper_DASH_9810680,if_helper41910581) {
var anf_if43510701 = R.isBoolean(or_DASH_oper_DASH_9810680);
if(R.isPyretTrue(anf_if43510701)) {
var $z1068810689 = D;
var $f1069410695 = function(_) {
return R.isFunction(if_helper41910581)?if_helper41910581.app(or_DASH_oper_DASH_9810680):R.ffi.throwNonFunApp(L[21],if_helper41910581,[or_DASH_oper_DASH_9810680]);
};
try {
if(--R.GAS > 0) {
$z1068810689 = $f1069410695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1069410695,
"from":L[21]});
}
} catch($e1068610687) {
if(R.isCont($e1068610687)) {
var $ss1069010691 = {"from":L[21],
"go":function(cont_tail_app43610696) {
return $Hcont_tail_app201910697(cont_tail_app43610696);
}};
$e1068610687.stack[R.EXN_STACKHEIGHT++] = $ss1069010691;
}
if(R.isPyretException($e1068610687)) {
$e1068610687.pyretStack.push(L[21]);
}
throw $e1068610687;
}
var $ret1069210693 = $Hcont_tail_app201910697($z1068810689);
++R.GAS;
return $ret1069210693;
} else {
var cont_tail_arg43310700 = R.throwNonBooleanOp(L[893],("second"),("or"),or_DASH_oper_DASH_9810680);
if(--R.GAS > 0) {
$z1069810699 = R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg43310700):R.ffi.throwNonFunApp(L[893],if_helper41910581,[cont_tail_arg43310700]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper41910581)?if_helper41910581.app(cont_tail_arg43310700):R.ffi.throwNonFunApp(L[893],if_helper41910581,[cont_tail_arg43310700]);
},
"from":L[893]});
}
++R.GAS;
return $z1069810699;
}
};
var $Hcont_tail_app201910697 = function(cont_tail_app43610696) {
return cont_tail_app43610696;
};
var $Hanf_arg2014495 = function(anf_arg385493,self92494,_plus13,torepr24) {
var anf_arg38610712 = G(self92494,"default",L[22]);
var $z1070410705 = D;
var $f1071010711 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg38610712):R.ffi.throwNonFunApp(L[22],torepr24,[anf_arg38610712]);
};
try {
if(--R.GAS > 0) {
$z1070410705 = $f1071010711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1071010711,
"from":L[22]});
}
} catch($e1070210703) {
if(R.isCont($e1070210703)) {
var $ss1070610707 = {"from":L[22],
"go":function(anf_arg38710713) {
return $Hanf_arg201310714(anf_arg38710713,anf_arg385493,self92494,_plus13,torepr24);
}};
$e1070210703.stack[R.EXN_STACKHEIGHT++] = $ss1070610707;
}
if(R.isPyretException($e1070210703)) {
$e1070210703.pyretStack.push(L[22]);
}
throw $e1070210703;
}
var $ret1070810709 = $Hanf_arg201310714($z1070410705,anf_arg385493,self92494,_plus13,torepr24);
++R.GAS;
return $ret1070810709;
};
var $Hanf_arg201310714 = function(anf_arg38710713,anf_arg385493,self92494,_plus13,torepr24) {
var $z1071710718 = D;
var $f1072310724 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg38710713):R.ffi.throwNonFunApp(L[22],_plus13,[(", "),anf_arg38710713]);
};
try {
if(--R.GAS > 0) {
$z1071710718 = $f1072310724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1072310724,
"from":L[22]});
}
} catch($e1071510716) {
if(R.isCont($e1071510716)) {
var $ss1071910720 = {"from":L[22],
"go":function(anf_arg38810725) {
return $Hanf_arg201210726(anf_arg38810725,anf_arg385493,self92494,_plus13,torepr24);
}};
$e1071510716.stack[R.EXN_STACKHEIGHT++] = $ss1071910720;
}
if(R.isPyretException($e1071510716)) {
$e1071510716.pyretStack.push(L[22]);
}
throw $e1071510716;
}
var $ret1072110722 = $Hanf_arg201210726($z1071710718,anf_arg385493,self92494,_plus13,torepr24);
++R.GAS;
return $ret1072110722;
};
var $Hanf_arg201210726 = function(anf_arg38810725,anf_arg385493,self92494,_plus13,torepr24) {
var $z1072910730 = D;
var $f1073510736 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg385493,anf_arg38810725):R.ffi.throwNonFunApp(L[22],_plus13,[anf_arg385493,anf_arg38810725]);
};
try {
if(--R.GAS > 0) {
$z1072910730 = $f1073510736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1073510736,
"from":L[22]});
}
} catch($e1072710728) {
if(R.isCont($e1072710728)) {
var $ss1073110732 = {"from":L[22],
"go":function(anf_arg38910737) {
return $Hanf_arg201110738(anf_arg38910737,self92494,_plus13,torepr24);
}};
$e1072710728.stack[R.EXN_STACKHEIGHT++] = $ss1073110732;
}
if(R.isPyretException($e1072710728)) {
$e1072710728.pyretStack.push(L[22]);
}
throw $e1072710728;
}
var $ret1073310734 = $Hanf_arg201110738($z1072910730,self92494,_plus13,torepr24);
++R.GAS;
return $ret1073310734;
};
var $Hanf_arg201110738 = function(anf_arg38910737,self92494,_plus13,torepr24) {
var anf_arg39010749 = G(self92494,"short-name",L[22]);
var $z1074110742 = D;
var $f1074710748 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg39010749):R.ffi.throwNonFunApp(L[22],torepr24,[anf_arg39010749]);
};
try {
if(--R.GAS > 0) {
$z1074110742 = $f1074710748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1074710748,
"from":L[22]});
}
} catch($e1073910740) {
if(R.isCont($e1073910740)) {
var $ss1074310744 = {"from":L[22],
"go":function(anf_arg39110750) {
return $Hanf_arg201010751(anf_arg39110750,anf_arg38910737,self92494,_plus13,torepr24);
}};
$e1073910740.stack[R.EXN_STACKHEIGHT++] = $ss1074310744;
}
if(R.isPyretException($e1073910740)) {
$e1073910740.pyretStack.push(L[22]);
}
throw $e1073910740;
}
var $ret1074510746 = $Hanf_arg201010751($z1074110742,anf_arg38910737,self92494,_plus13,torepr24);
++R.GAS;
return $ret1074510746;
};
var $Hanf_arg201010751 = function(anf_arg39110750,anf_arg38910737,self92494,_plus13,torepr24) {
var $z1075410755 = D;
var $f1076010761 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg39110750):R.ffi.throwNonFunApp(L[22],_plus13,[(", "),anf_arg39110750]);
};
try {
if(--R.GAS > 0) {
$z1075410755 = $f1076010761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1076010761,
"from":L[22]});
}
} catch($e1075210753) {
if(R.isCont($e1075210753)) {
var $ss1075610757 = {"from":L[22],
"go":function(anf_arg39210762) {
return $Hanf_arg200910763(anf_arg39210762,anf_arg38910737,self92494,_plus13,torepr24);
}};
$e1075210753.stack[R.EXN_STACKHEIGHT++] = $ss1075610757;
}
if(R.isPyretException($e1075210753)) {
$e1075210753.pyretStack.push(L[22]);
}
throw $e1075210753;
}
var $ret1075810759 = $Hanf_arg200910763($z1075410755,anf_arg38910737,self92494,_plus13,torepr24);
++R.GAS;
return $ret1075810759;
};
var $Hanf_arg200910763 = function(anf_arg39210762,anf_arg38910737,self92494,_plus13,torepr24) {
var $z1076610767 = D;
var $f1077210773 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg38910737,anf_arg39210762):R.ffi.throwNonFunApp(L[22],_plus13,[anf_arg38910737,anf_arg39210762]);
};
try {
if(--R.GAS > 0) {
$z1076610767 = $f1077210773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1077210773,
"from":L[22]});
}
} catch($e1076410765) {
if(R.isCont($e1076410765)) {
var $ss1076810769 = {"from":L[22],
"go":function(anf_arg39310774) {
return $Hanf_arg200810775(anf_arg39310774,self92494,_plus13,torepr24);
}};
$e1076410765.stack[R.EXN_STACKHEIGHT++] = $ss1076810769;
}
if(R.isPyretException($e1076410765)) {
$e1076410765.pyretStack.push(L[22]);
}
throw $e1076410765;
}
var $ret1077010771 = $Hanf_arg200810775($z1076610767,self92494,_plus13,torepr24);
++R.GAS;
return $ret1077010771;
};
var $Hanf_arg200810775 = function(anf_arg39310774,self92494,_plus13,torepr24) {
var anf_arg39410786 = G(self92494,"repeated",L[22]);
var $z1077810779 = D;
var $f1078410785 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg39410786):R.ffi.throwNonFunApp(L[22],torepr24,[anf_arg39410786]);
};
try {
if(--R.GAS > 0) {
$z1077810779 = $f1078410785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1078410785,
"from":L[22]});
}
} catch($e1077610777) {
if(R.isCont($e1077610777)) {
var $ss1078010781 = {"from":L[22],
"go":function(anf_arg39510787) {
return $Hanf_arg200710788(anf_arg39510787,anf_arg39310774,self92494,_plus13,torepr24);
}};
$e1077610777.stack[R.EXN_STACKHEIGHT++] = $ss1078010781;
}
if(R.isPyretException($e1077610777)) {
$e1077610777.pyretStack.push(L[22]);
}
throw $e1077610777;
}
var $ret1078210783 = $Hanf_arg200710788($z1077810779,anf_arg39310774,self92494,_plus13,torepr24);
++R.GAS;
return $ret1078210783;
};
var $Hanf_arg200710788 = function(anf_arg39510787,anf_arg39310774,self92494,_plus13,torepr24) {
var $z1079110792 = D;
var $f1079710798 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg39510787):R.ffi.throwNonFunApp(L[22],_plus13,[(", "),anf_arg39510787]);
};
try {
if(--R.GAS > 0) {
$z1079110792 = $f1079710798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1079710798,
"from":L[22]});
}
} catch($e1078910790) {
if(R.isCont($e1078910790)) {
var $ss1079310794 = {"from":L[22],
"go":function(anf_arg39610799) {
return $Hanf_arg200610800(anf_arg39610799,anf_arg39310774,self92494,_plus13,torepr24);
}};
$e1078910790.stack[R.EXN_STACKHEIGHT++] = $ss1079310794;
}
if(R.isPyretException($e1078910790)) {
$e1078910790.pyretStack.push(L[22]);
}
throw $e1078910790;
}
var $ret1079510796 = $Hanf_arg200610800($z1079110792,anf_arg39310774,self92494,_plus13,torepr24);
++R.GAS;
return $ret1079510796;
};
var $Hanf_arg200610800 = function(anf_arg39610799,anf_arg39310774,self92494,_plus13,torepr24) {
var $z1080310804 = D;
var $f1080910810 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg39310774,anf_arg39610799):R.ffi.throwNonFunApp(L[22],_plus13,[anf_arg39310774,anf_arg39610799]);
};
try {
if(--R.GAS > 0) {
$z1080310804 = $f1080910810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1080910810,
"from":L[22]});
}
} catch($e1080110802) {
if(R.isCont($e1080110802)) {
var $ss1080510806 = {"from":L[22],
"go":function(anf_arg39710811) {
return $Hanf_arg200510812(anf_arg39710811,self92494,_plus13,torepr24);
}};
$e1080110802.stack[R.EXN_STACKHEIGHT++] = $ss1080510806;
}
if(R.isPyretException($e1080110802)) {
$e1080110802.pyretStack.push(L[22]);
}
throw $e1080110802;
}
var $ret1080710808 = $Hanf_arg200510812($z1080310804,self92494,_plus13,torepr24);
++R.GAS;
return $ret1080710808;
};
var $Hanf_arg200510812 = function(anf_arg39710811,self92494,_plus13,torepr24) {
var anf_arg39810823 = G(self92494,"desc",L[22]);
var $z1081510816 = D;
var $f1082110822 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg39810823):R.ffi.throwNonFunApp(L[22],torepr24,[anf_arg39810823]);
};
try {
if(--R.GAS > 0) {
$z1081510816 = $f1082110822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1082110822,
"from":L[22]});
}
} catch($e1081310814) {
if(R.isCont($e1081310814)) {
var $ss1081710818 = {"from":L[22],
"go":function(anf_arg39910824) {
return $Hanf_arg200410825(anf_arg39910824,anf_arg39710811,_plus13);
}};
$e1081310814.stack[R.EXN_STACKHEIGHT++] = $ss1081710818;
}
if(R.isPyretException($e1081310814)) {
$e1081310814.pyretStack.push(L[22]);
}
throw $e1081310814;
}
var $ret1081910820 = $Hanf_arg200410825($z1081510816,anf_arg39710811,_plus13);
++R.GAS;
return $ret1081910820;
};
var $Hanf_arg200410825 = function(anf_arg39910824,anf_arg39710811,_plus13) {
var $z1082810829 = D;
var $f1083410835 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg39910824):R.ffi.throwNonFunApp(L[22],_plus13,[(", "),anf_arg39910824]);
};
try {
if(--R.GAS > 0) {
$z1082810829 = $f1083410835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1083410835,
"from":L[22]});
}
} catch($e1082610827) {
if(R.isCont($e1082610827)) {
var $ss1083010831 = {"from":L[22],
"go":function(anf_arg40010836) {
return $Hanf_arg200310837(anf_arg40010836,anf_arg39710811,_plus13);
}};
$e1082610827.stack[R.EXN_STACKHEIGHT++] = $ss1083010831;
}
if(R.isPyretException($e1082610827)) {
$e1082610827.pyretStack.push(L[22]);
}
throw $e1082610827;
}
var $ret1083210833 = $Hanf_arg200310837($z1082810829,anf_arg39710811,_plus13);
++R.GAS;
return $ret1083210833;
};
var $Hanf_arg200310837 = function(anf_arg40010836,anf_arg39710811,_plus13) {
var $z1084010841 = D;
var $f1084610847 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg39710811,anf_arg40010836):R.ffi.throwNonFunApp(L[22],_plus13,[anf_arg39710811,anf_arg40010836]);
};
try {
if(--R.GAS > 0) {
$z1084010841 = $f1084610847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1084610847,
"from":L[22]});
}
} catch($e1083810839) {
if(R.isCont($e1083810839)) {
var $ss1084210843 = {"from":L[22],
"go":function(anf_arg40110848) {
return $Hanf_arg200210849(anf_arg40110848,_plus13);
}};
$e1083810839.stack[R.EXN_STACKHEIGHT++] = $ss1084210843;
}
if(R.isPyretException($e1083810839)) {
$e1083810839.pyretStack.push(L[22]);
}
throw $e1083810839;
}
var $ret1084410845 = $Hanf_arg200210849($z1084010841,_plus13);
++R.GAS;
return $ret1084410845;
};
var $Hanf_arg200210849 = function(anf_arg40110848,_plus13) {
var $z1085210853 = D;
var $f1085810859 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg40110848,(")")):R.ffi.throwNonFunApp(L[22],_plus13,[anf_arg40110848,(")")]);
};
try {
if(--R.GAS > 0) {
$z1085210853 = $f1085810859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1085810859,
"from":L[22]});
}
} catch($e1085010851) {
if(R.isCont($e1085010851)) {
var $ss1085410855 = {"from":L[22],
"go":function(anf_arg40210860) {
return $Hanf_arg200110861(anf_arg40210860,_plus13);
}};
$e1085010851.stack[R.EXN_STACKHEIGHT++] = $ss1085410855;
}
if(R.isPyretException($e1085010851)) {
$e1085010851.pyretStack.push(L[22]);
}
throw $e1085010851;
}
var $ret1085610857 = $Hanf_arg200110861($z1085210853,_plus13);
++R.GAS;
return $ret1085610857;
};
var $Hanf_arg200110861 = function(anf_arg40210860,_plus13) {
var $z1086410865 = D;
var $f1087010871 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg40210860):R.ffi.throwNonFunApp(L[22],_plus13,[("("),anf_arg40210860]);
};
try {
if(--R.GAS > 0) {
$z1086410865 = $f1087010871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1087010871,
"from":L[22]});
}
} catch($e1086210863) {
if(R.isCont($e1086210863)) {
var $ss1086610867 = {"from":L[22],
"go":function(anf_arg40310872) {
return $Hanf_arg200010873(anf_arg40310872,_plus13);
}};
$e1086210863.stack[R.EXN_STACKHEIGHT++] = $ss1086610867;
}
if(R.isPyretException($e1086210863)) {
$e1086210863.pyretStack.push(L[22]);
}
throw $e1086210863;
}
var $ret1086810869 = $Hanf_arg200010873($z1086410865,_plus13);
++R.GAS;
return $ret1086810869;
};
var $Hanf_arg200010873 = function(anf_arg40310872,_plus13) {
var $z1087610877 = D;
var $f1088210883 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("next-val-default"),anf_arg40310872):R.ffi.throwNonFunApp(L[22],_plus13,[("next-val-default"),anf_arg40310872]);
};
try {
if(--R.GAS > 0) {
$z1087610877 = $f1088210883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1088210883,
"from":L[22]});
}
} catch($e1087410875) {
if(R.isCont($e1087410875)) {
var $ss1087810879 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp38310884) {
return $Hann_DASH_check_DASH_temp199910885(ann_DASH_check_DASH_temp38310884);
}};
$e1087410875.stack[R.EXN_STACKHEIGHT++] = $ss1087810879;
}
if(R.isPyretException($e1087410875)) {
$e1087410875.pyretStack.push(L[22]);
}
throw $e1087410875;
}
var $ret1088010881 = $Hann_DASH_check_DASH_temp199910885($z1087610877);
++R.GAS;
return $ret1088010881;
};
var $Hann_DASH_check_DASH_temp199910885 = function(ann_DASH_check_DASH_temp38310884) {
return ann_DASH_check_DASH_temp38310884;
};
var $Hcont_tail_arg1997514 = function(cont_tail_arg380512,if_helper368513) {
if(--R.GAS > 0) {
$z1088610887 = R.isFunction(if_helper368513)?if_helper368513.app(cont_tail_arg380512):R.ffi.throwNonFunApp(L[22],if_helper368513,[cont_tail_arg380512]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper368513)?if_helper368513.app(cont_tail_arg380512):R.ffi.throwNonFunApp(L[22],if_helper368513,[cont_tail_arg380512]);
},
"from":L[22]});
}
++R.GAS;
return $z1088610887;
};
var $Hcont_tail_arg1998529 = function(cont_tail_arg373528,if_helper368513) {
if(--R.GAS > 0) {
$z1088810889 = R.isFunction(if_helper368513)?if_helper368513.app(cont_tail_arg373528):R.ffi.throwNonFunApp(L[22],if_helper368513,[cont_tail_arg373528]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper368513)?if_helper368513.app(cont_tail_arg373528):R.ffi.throwNonFunApp(L[22],if_helper368513,[cont_tail_arg373528]);
},
"from":L[22]});
}
++R.GAS;
return $z1088810889;
};
var $Hanf_arg1996550 = function(anf_arg355548,self86549,_plus13,torepr24) {
var anf_arg35610900 = G(self86549,"repeated",L[23]);
var $z1089210893 = D;
var $f1089810899 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg35610900):R.ffi.throwNonFunApp(L[23],torepr24,[anf_arg35610900]);
};
try {
if(--R.GAS > 0) {
$z1089210893 = $f1089810899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1089810899,
"from":L[23]});
}
} catch($e1089010891) {
if(R.isCont($e1089010891)) {
var $ss1089410895 = {"from":L[23],
"go":function(anf_arg35710901) {
return $Hanf_arg199510902(anf_arg35710901,anf_arg355548,self86549,_plus13,torepr24);
}};
$e1089010891.stack[R.EXN_STACKHEIGHT++] = $ss1089410895;
}
if(R.isPyretException($e1089010891)) {
$e1089010891.pyretStack.push(L[23]);
}
throw $e1089010891;
}
var $ret1089610897 = $Hanf_arg199510902($z1089210893,anf_arg355548,self86549,_plus13,torepr24);
++R.GAS;
return $ret1089610897;
};
var $Hanf_arg199510902 = function(anf_arg35710901,anf_arg355548,self86549,_plus13,torepr24) {
var $z1090510906 = D;
var $f1091110912 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg35710901):R.ffi.throwNonFunApp(L[23],_plus13,[(", "),anf_arg35710901]);
};
try {
if(--R.GAS > 0) {
$z1090510906 = $f1091110912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1091110912,
"from":L[23]});
}
} catch($e1090310904) {
if(R.isCont($e1090310904)) {
var $ss1090710908 = {"from":L[23],
"go":function(anf_arg35810913) {
return $Hanf_arg199410914(anf_arg35810913,anf_arg355548,self86549,_plus13,torepr24);
}};
$e1090310904.stack[R.EXN_STACKHEIGHT++] = $ss1090710908;
}
if(R.isPyretException($e1090310904)) {
$e1090310904.pyretStack.push(L[23]);
}
throw $e1090310904;
}
var $ret1090910910 = $Hanf_arg199410914($z1090510906,anf_arg355548,self86549,_plus13,torepr24);
++R.GAS;
return $ret1090910910;
};
var $Hanf_arg199410914 = function(anf_arg35810913,anf_arg355548,self86549,_plus13,torepr24) {
var $z1091710918 = D;
var $f1092310924 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg355548,anf_arg35810913):R.ffi.throwNonFunApp(L[23],_plus13,[anf_arg355548,anf_arg35810913]);
};
try {
if(--R.GAS > 0) {
$z1091710918 = $f1092310924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1092310924,
"from":L[23]});
}
} catch($e1091510916) {
if(R.isCont($e1091510916)) {
var $ss1091910920 = {"from":L[23],
"go":function(anf_arg35910925) {
return $Hanf_arg199310926(anf_arg35910925,self86549,_plus13,torepr24);
}};
$e1091510916.stack[R.EXN_STACKHEIGHT++] = $ss1091910920;
}
if(R.isPyretException($e1091510916)) {
$e1091510916.pyretStack.push(L[23]);
}
throw $e1091510916;
}
var $ret1092110922 = $Hanf_arg199310926($z1091710918,self86549,_plus13,torepr24);
++R.GAS;
return $ret1092110922;
};
var $Hanf_arg199310926 = function(anf_arg35910925,self86549,_plus13,torepr24) {
var anf_arg36010937 = G(self86549,"desc",L[23]);
var $z1092910930 = D;
var $f1093510936 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg36010937):R.ffi.throwNonFunApp(L[23],torepr24,[anf_arg36010937]);
};
try {
if(--R.GAS > 0) {
$z1092910930 = $f1093510936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1093510936,
"from":L[23]});
}
} catch($e1092710928) {
if(R.isCont($e1092710928)) {
var $ss1093110932 = {"from":L[23],
"go":function(anf_arg36110938) {
return $Hanf_arg199210939(anf_arg36110938,anf_arg35910925,_plus13);
}};
$e1092710928.stack[R.EXN_STACKHEIGHT++] = $ss1093110932;
}
if(R.isPyretException($e1092710928)) {
$e1092710928.pyretStack.push(L[23]);
}
throw $e1092710928;
}
var $ret1093310934 = $Hanf_arg199210939($z1092910930,anf_arg35910925,_plus13);
++R.GAS;
return $ret1093310934;
};
var $Hanf_arg199210939 = function(anf_arg36110938,anf_arg35910925,_plus13) {
var $z1094210943 = D;
var $f1094810949 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg36110938):R.ffi.throwNonFunApp(L[23],_plus13,[(", "),anf_arg36110938]);
};
try {
if(--R.GAS > 0) {
$z1094210943 = $f1094810949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1094810949,
"from":L[23]});
}
} catch($e1094010941) {
if(R.isCont($e1094010941)) {
var $ss1094410945 = {"from":L[23],
"go":function(anf_arg36210950) {
return $Hanf_arg199110951(anf_arg36210950,anf_arg35910925,_plus13);
}};
$e1094010941.stack[R.EXN_STACKHEIGHT++] = $ss1094410945;
}
if(R.isPyretException($e1094010941)) {
$e1094010941.pyretStack.push(L[23]);
}
throw $e1094010941;
}
var $ret1094610947 = $Hanf_arg199110951($z1094210943,anf_arg35910925,_plus13);
++R.GAS;
return $ret1094610947;
};
var $Hanf_arg199110951 = function(anf_arg36210950,anf_arg35910925,_plus13) {
var $z1095410955 = D;
var $f1096010961 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg35910925,anf_arg36210950):R.ffi.throwNonFunApp(L[23],_plus13,[anf_arg35910925,anf_arg36210950]);
};
try {
if(--R.GAS > 0) {
$z1095410955 = $f1096010961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1096010961,
"from":L[23]});
}
} catch($e1095210953) {
if(R.isCont($e1095210953)) {
var $ss1095610957 = {"from":L[23],
"go":function(anf_arg36310962) {
return $Hanf_arg199010963(anf_arg36310962,_plus13);
}};
$e1095210953.stack[R.EXN_STACKHEIGHT++] = $ss1095610957;
}
if(R.isPyretException($e1095210953)) {
$e1095210953.pyretStack.push(L[23]);
}
throw $e1095210953;
}
var $ret1095810959 = $Hanf_arg199010963($z1095410955,_plus13);
++R.GAS;
return $ret1095810959;
};
var $Hanf_arg199010963 = function(anf_arg36310962,_plus13) {
var $z1096610967 = D;
var $f1097210973 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg36310962,(")")):R.ffi.throwNonFunApp(L[23],_plus13,[anf_arg36310962,(")")]);
};
try {
if(--R.GAS > 0) {
$z1096610967 = $f1097210973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1097210973,
"from":L[23]});
}
} catch($e1096410965) {
if(R.isCont($e1096410965)) {
var $ss1096810969 = {"from":L[23],
"go":function(anf_arg36410974) {
return $Hanf_arg198910975(anf_arg36410974,_plus13);
}};
$e1096410965.stack[R.EXN_STACKHEIGHT++] = $ss1096810969;
}
if(R.isPyretException($e1096410965)) {
$e1096410965.pyretStack.push(L[23]);
}
throw $e1096410965;
}
var $ret1097010971 = $Hanf_arg198910975($z1096610967,_plus13);
++R.GAS;
return $ret1097010971;
};
var $Hanf_arg198910975 = function(anf_arg36410974,_plus13) {
var $z1097810979 = D;
var $f1098410985 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg36410974):R.ffi.throwNonFunApp(L[23],_plus13,[("("),anf_arg36410974]);
};
try {
if(--R.GAS > 0) {
$z1097810979 = $f1098410985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1098410985,
"from":L[23]});
}
} catch($e1097610977) {
if(R.isCont($e1097610977)) {
var $ss1098010981 = {"from":L[23],
"go":function(anf_arg36510986) {
return $Hanf_arg198810987(anf_arg36510986,_plus13);
}};
$e1097610977.stack[R.EXN_STACKHEIGHT++] = $ss1098010981;
}
if(R.isPyretException($e1097610977)) {
$e1097610977.pyretStack.push(L[23]);
}
throw $e1097610977;
}
var $ret1098210983 = $Hanf_arg198810987($z1097810979,_plus13);
++R.GAS;
return $ret1098210983;
};
var $Hanf_arg198810987 = function(anf_arg36510986,_plus13) {
var $z1099010991 = D;
var $f1099610997 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("next-val"),anf_arg36510986):R.ffi.throwNonFunApp(L[23],_plus13,[("next-val"),anf_arg36510986]);
};
try {
if(--R.GAS > 0) {
$z1099010991 = $f1099610997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1099610997,
"from":L[23]});
}
} catch($e1098810989) {
if(R.isCont($e1098810989)) {
var $ss1099210993 = {"from":L[23],
"go":function(ann_DASH_check_DASH_temp35310998) {
return $Hann_DASH_check_DASH_temp198710999(ann_DASH_check_DASH_temp35310998);
}};
$e1098810989.stack[R.EXN_STACKHEIGHT++] = $ss1099210993;
}
if(R.isPyretException($e1098810989)) {
$e1098810989.pyretStack.push(L[23]);
}
throw $e1098810989;
}
var $ret1099410995 = $Hann_DASH_check_DASH_temp198710999($z1099010991);
++R.GAS;
return $ret1099410995;
};
var $Hann_DASH_check_DASH_temp198710999 = function(ann_DASH_check_DASH_temp35310998) {
return ann_DASH_check_DASH_temp35310998;
};
var $Hcont_tail_arg1985567 = function(cont_tail_arg350565,if_helper340566) {
if(--R.GAS > 0) {
$z1100011001 = R.isFunction(if_helper340566)?if_helper340566.app(cont_tail_arg350565):R.ffi.throwNonFunApp(L[23],if_helper340566,[cont_tail_arg350565]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper340566)?if_helper340566.app(cont_tail_arg350565):R.ffi.throwNonFunApp(L[23],if_helper340566,[cont_tail_arg350565]);
},
"from":L[23]});
}
++R.GAS;
return $z1100011001;
};
var $Hcont_tail_arg1986582 = function(cont_tail_arg345581,if_helper340566) {
if(--R.GAS > 0) {
$z1100211003 = R.isFunction(if_helper340566)?if_helper340566.app(cont_tail_arg345581):R.ffi.throwNonFunApp(L[23],if_helper340566,[cont_tail_arg345581]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper340566)?if_helper340566.app(cont_tail_arg345581):R.ffi.throwNonFunApp(L[23],if_helper340566,[cont_tail_arg345581]);
},
"from":L[23]});
}
++R.GAS;
return $z1100211003;
};
var $Hanf_arg1984603 = function(anf_arg319601,self80602,_plus13,torepr24) {
var anf_arg32011014 = G(self80602,"default",L[24]);
var $z1100611007 = D;
var $f1101211013 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg32011014):R.ffi.throwNonFunApp(L[24],torepr24,[anf_arg32011014]);
};
try {
if(--R.GAS > 0) {
$z1100611007 = $f1101211013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1101211013,
"from":L[24]});
}
} catch($e1100411005) {
if(R.isCont($e1100411005)) {
var $ss1100811009 = {"from":L[24],
"go":function(anf_arg32111015) {
return $Hanf_arg198311016(anf_arg32111015,anf_arg319601,self80602,_plus13,torepr24);
}};
$e1100411005.stack[R.EXN_STACKHEIGHT++] = $ss1100811009;
}
if(R.isPyretException($e1100411005)) {
$e1100411005.pyretStack.push(L[24]);
}
throw $e1100411005;
}
var $ret1101011011 = $Hanf_arg198311016($z1100611007,anf_arg319601,self80602,_plus13,torepr24);
++R.GAS;
return $ret1101011011;
};
var $Hanf_arg198311016 = function(anf_arg32111015,anf_arg319601,self80602,_plus13,torepr24) {
var $z1101911020 = D;
var $f1102511026 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg32111015):R.ffi.throwNonFunApp(L[24],_plus13,[(", "),anf_arg32111015]);
};
try {
if(--R.GAS > 0) {
$z1101911020 = $f1102511026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1102511026,
"from":L[24]});
}
} catch($e1101711018) {
if(R.isCont($e1101711018)) {
var $ss1102111022 = {"from":L[24],
"go":function(anf_arg32211027) {
return $Hanf_arg198211028(anf_arg32211027,anf_arg319601,self80602,_plus13,torepr24);
}};
$e1101711018.stack[R.EXN_STACKHEIGHT++] = $ss1102111022;
}
if(R.isPyretException($e1101711018)) {
$e1101711018.pyretStack.push(L[24]);
}
throw $e1101711018;
}
var $ret1102311024 = $Hanf_arg198211028($z1101911020,anf_arg319601,self80602,_plus13,torepr24);
++R.GAS;
return $ret1102311024;
};
var $Hanf_arg198211028 = function(anf_arg32211027,anf_arg319601,self80602,_plus13,torepr24) {
var $z1103111032 = D;
var $f1103711038 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg319601,anf_arg32211027):R.ffi.throwNonFunApp(L[24],_plus13,[anf_arg319601,anf_arg32211027]);
};
try {
if(--R.GAS > 0) {
$z1103111032 = $f1103711038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1103711038,
"from":L[24]});
}
} catch($e1102911030) {
if(R.isCont($e1102911030)) {
var $ss1103311034 = {"from":L[24],
"go":function(anf_arg32311039) {
return $Hanf_arg198111040(anf_arg32311039,self80602,_plus13,torepr24);
}};
$e1102911030.stack[R.EXN_STACKHEIGHT++] = $ss1103311034;
}
if(R.isPyretException($e1102911030)) {
$e1102911030.pyretStack.push(L[24]);
}
throw $e1102911030;
}
var $ret1103511036 = $Hanf_arg198111040($z1103111032,self80602,_plus13,torepr24);
++R.GAS;
return $ret1103511036;
};
var $Hanf_arg198111040 = function(anf_arg32311039,self80602,_plus13,torepr24) {
var anf_arg32411051 = G(self80602,"short-name",L[24]);
var $z1104311044 = D;
var $f1104911050 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg32411051):R.ffi.throwNonFunApp(L[24],torepr24,[anf_arg32411051]);
};
try {
if(--R.GAS > 0) {
$z1104311044 = $f1104911050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1104911050,
"from":L[24]});
}
} catch($e1104111042) {
if(R.isCont($e1104111042)) {
var $ss1104511046 = {"from":L[24],
"go":function(anf_arg32511052) {
return $Hanf_arg198011053(anf_arg32511052,anf_arg32311039,self80602,_plus13,torepr24);
}};
$e1104111042.stack[R.EXN_STACKHEIGHT++] = $ss1104511046;
}
if(R.isPyretException($e1104111042)) {
$e1104111042.pyretStack.push(L[24]);
}
throw $e1104111042;
}
var $ret1104711048 = $Hanf_arg198011053($z1104311044,anf_arg32311039,self80602,_plus13,torepr24);
++R.GAS;
return $ret1104711048;
};
var $Hanf_arg198011053 = function(anf_arg32511052,anf_arg32311039,self80602,_plus13,torepr24) {
var $z1105611057 = D;
var $f1106211063 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg32511052):R.ffi.throwNonFunApp(L[24],_plus13,[(", "),anf_arg32511052]);
};
try {
if(--R.GAS > 0) {
$z1105611057 = $f1106211063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1106211063,
"from":L[24]});
}
} catch($e1105411055) {
if(R.isCont($e1105411055)) {
var $ss1105811059 = {"from":L[24],
"go":function(anf_arg32611064) {
return $Hanf_arg197911065(anf_arg32611064,anf_arg32311039,self80602,_plus13,torepr24);
}};
$e1105411055.stack[R.EXN_STACKHEIGHT++] = $ss1105811059;
}
if(R.isPyretException($e1105411055)) {
$e1105411055.pyretStack.push(L[24]);
}
throw $e1105411055;
}
var $ret1106011061 = $Hanf_arg197911065($z1105611057,anf_arg32311039,self80602,_plus13,torepr24);
++R.GAS;
return $ret1106011061;
};
var $Hanf_arg197911065 = function(anf_arg32611064,anf_arg32311039,self80602,_plus13,torepr24) {
var $z1106811069 = D;
var $f1107411075 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg32311039,anf_arg32611064):R.ffi.throwNonFunApp(L[24],_plus13,[anf_arg32311039,anf_arg32611064]);
};
try {
if(--R.GAS > 0) {
$z1106811069 = $f1107411075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1107411075,
"from":L[24]});
}
} catch($e1106611067) {
if(R.isCont($e1106611067)) {
var $ss1107011071 = {"from":L[24],
"go":function(anf_arg32711076) {
return $Hanf_arg197811077(anf_arg32711076,self80602,_plus13,torepr24);
}};
$e1106611067.stack[R.EXN_STACKHEIGHT++] = $ss1107011071;
}
if(R.isPyretException($e1106611067)) {
$e1106611067.pyretStack.push(L[24]);
}
throw $e1106611067;
}
var $ret1107211073 = $Hanf_arg197811077($z1106811069,self80602,_plus13,torepr24);
++R.GAS;
return $ret1107211073;
};
var $Hanf_arg197811077 = function(anf_arg32711076,self80602,_plus13,torepr24) {
var anf_arg32811088 = G(self80602,"repeated",L[24]);
var $z1108011081 = D;
var $f1108611087 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg32811088):R.ffi.throwNonFunApp(L[24],torepr24,[anf_arg32811088]);
};
try {
if(--R.GAS > 0) {
$z1108011081 = $f1108611087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1108611087,
"from":L[24]});
}
} catch($e1107811079) {
if(R.isCont($e1107811079)) {
var $ss1108211083 = {"from":L[24],
"go":function(anf_arg32911089) {
return $Hanf_arg197711090(anf_arg32911089,anf_arg32711076,self80602,_plus13,torepr24);
}};
$e1107811079.stack[R.EXN_STACKHEIGHT++] = $ss1108211083;
}
if(R.isPyretException($e1107811079)) {
$e1107811079.pyretStack.push(L[24]);
}
throw $e1107811079;
}
var $ret1108411085 = $Hanf_arg197711090($z1108011081,anf_arg32711076,self80602,_plus13,torepr24);
++R.GAS;
return $ret1108411085;
};
var $Hanf_arg197711090 = function(anf_arg32911089,anf_arg32711076,self80602,_plus13,torepr24) {
var $z1109311094 = D;
var $f1109911100 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg32911089):R.ffi.throwNonFunApp(L[24],_plus13,[(", "),anf_arg32911089]);
};
try {
if(--R.GAS > 0) {
$z1109311094 = $f1109911100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1109911100,
"from":L[24]});
}
} catch($e1109111092) {
if(R.isCont($e1109111092)) {
var $ss1109511096 = {"from":L[24],
"go":function(anf_arg33011101) {
return $Hanf_arg197611102(anf_arg33011101,anf_arg32711076,self80602,_plus13,torepr24);
}};
$e1109111092.stack[R.EXN_STACKHEIGHT++] = $ss1109511096;
}
if(R.isPyretException($e1109111092)) {
$e1109111092.pyretStack.push(L[24]);
}
throw $e1109111092;
}
var $ret1109711098 = $Hanf_arg197611102($z1109311094,anf_arg32711076,self80602,_plus13,torepr24);
++R.GAS;
return $ret1109711098;
};
var $Hanf_arg197611102 = function(anf_arg33011101,anf_arg32711076,self80602,_plus13,torepr24) {
var $z1110511106 = D;
var $f1111111112 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg32711076,anf_arg33011101):R.ffi.throwNonFunApp(L[24],_plus13,[anf_arg32711076,anf_arg33011101]);
};
try {
if(--R.GAS > 0) {
$z1110511106 = $f1111111112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1111111112,
"from":L[24]});
}
} catch($e1110311104) {
if(R.isCont($e1110311104)) {
var $ss1110711108 = {"from":L[24],
"go":function(anf_arg33111113) {
return $Hanf_arg197511114(anf_arg33111113,self80602,_plus13,torepr24);
}};
$e1110311104.stack[R.EXN_STACKHEIGHT++] = $ss1110711108;
}
if(R.isPyretException($e1110311104)) {
$e1110311104.pyretStack.push(L[24]);
}
throw $e1110311104;
}
var $ret1110911110 = $Hanf_arg197511114($z1110511106,self80602,_plus13,torepr24);
++R.GAS;
return $ret1110911110;
};
var $Hanf_arg197511114 = function(anf_arg33111113,self80602,_plus13,torepr24) {
var anf_arg33211125 = G(self80602,"desc",L[24]);
var $z1111711118 = D;
var $f1112311124 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg33211125):R.ffi.throwNonFunApp(L[24],torepr24,[anf_arg33211125]);
};
try {
if(--R.GAS > 0) {
$z1111711118 = $f1112311124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1112311124,
"from":L[24]});
}
} catch($e1111511116) {
if(R.isCont($e1111511116)) {
var $ss1111911120 = {"from":L[24],
"go":function(anf_arg33311126) {
return $Hanf_arg197411127(anf_arg33311126,anf_arg33111113,_plus13);
}};
$e1111511116.stack[R.EXN_STACKHEIGHT++] = $ss1111911120;
}
if(R.isPyretException($e1111511116)) {
$e1111511116.pyretStack.push(L[24]);
}
throw $e1111511116;
}
var $ret1112111122 = $Hanf_arg197411127($z1111711118,anf_arg33111113,_plus13);
++R.GAS;
return $ret1112111122;
};
var $Hanf_arg197411127 = function(anf_arg33311126,anf_arg33111113,_plus13) {
var $z1113011131 = D;
var $f1113611137 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg33311126):R.ffi.throwNonFunApp(L[24],_plus13,[(", "),anf_arg33311126]);
};
try {
if(--R.GAS > 0) {
$z1113011131 = $f1113611137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1113611137,
"from":L[24]});
}
} catch($e1112811129) {
if(R.isCont($e1112811129)) {
var $ss1113211133 = {"from":L[24],
"go":function(anf_arg33411138) {
return $Hanf_arg197311139(anf_arg33411138,anf_arg33111113,_plus13);
}};
$e1112811129.stack[R.EXN_STACKHEIGHT++] = $ss1113211133;
}
if(R.isPyretException($e1112811129)) {
$e1112811129.pyretStack.push(L[24]);
}
throw $e1112811129;
}
var $ret1113411135 = $Hanf_arg197311139($z1113011131,anf_arg33111113,_plus13);
++R.GAS;
return $ret1113411135;
};
var $Hanf_arg197311139 = function(anf_arg33411138,anf_arg33111113,_plus13) {
var $z1114211143 = D;
var $f1114811149 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg33111113,anf_arg33411138):R.ffi.throwNonFunApp(L[24],_plus13,[anf_arg33111113,anf_arg33411138]);
};
try {
if(--R.GAS > 0) {
$z1114211143 = $f1114811149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1114811149,
"from":L[24]});
}
} catch($e1114011141) {
if(R.isCont($e1114011141)) {
var $ss1114411145 = {"from":L[24],
"go":function(anf_arg33511150) {
return $Hanf_arg197211151(anf_arg33511150,_plus13);
}};
$e1114011141.stack[R.EXN_STACKHEIGHT++] = $ss1114411145;
}
if(R.isPyretException($e1114011141)) {
$e1114011141.pyretStack.push(L[24]);
}
throw $e1114011141;
}
var $ret1114611147 = $Hanf_arg197211151($z1114211143,_plus13);
++R.GAS;
return $ret1114611147;
};
var $Hanf_arg197211151 = function(anf_arg33511150,_plus13) {
var $z1115411155 = D;
var $f1116011161 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg33511150,(")")):R.ffi.throwNonFunApp(L[24],_plus13,[anf_arg33511150,(")")]);
};
try {
if(--R.GAS > 0) {
$z1115411155 = $f1116011161();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1116011161,
"from":L[24]});
}
} catch($e1115211153) {
if(R.isCont($e1115211153)) {
var $ss1115611157 = {"from":L[24],
"go":function(anf_arg33611162) {
return $Hanf_arg197111163(anf_arg33611162,_plus13);
}};
$e1115211153.stack[R.EXN_STACKHEIGHT++] = $ss1115611157;
}
if(R.isPyretException($e1115211153)) {
$e1115211153.pyretStack.push(L[24]);
}
throw $e1115211153;
}
var $ret1115811159 = $Hanf_arg197111163($z1115411155,_plus13);
++R.GAS;
return $ret1115811159;
};
var $Hanf_arg197111163 = function(anf_arg33611162,_plus13) {
var $z1116611167 = D;
var $f1117211173 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg33611162):R.ffi.throwNonFunApp(L[24],_plus13,[("("),anf_arg33611162]);
};
try {
if(--R.GAS > 0) {
$z1116611167 = $f1117211173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1117211173,
"from":L[24]});
}
} catch($e1116411165) {
if(R.isCont($e1116411165)) {
var $ss1116811169 = {"from":L[24],
"go":function(anf_arg33711174) {
return $Hanf_arg197011175(anf_arg33711174,_plus13);
}};
$e1116411165.stack[R.EXN_STACKHEIGHT++] = $ss1116811169;
}
if(R.isPyretException($e1116411165)) {
$e1116411165.pyretStack.push(L[24]);
}
throw $e1116411165;
}
var $ret1117011171 = $Hanf_arg197011175($z1116611167,_plus13);
++R.GAS;
return $ret1117011171;
};
var $Hanf_arg197011175 = function(anf_arg33711174,_plus13) {
var $z1117811179 = D;
var $f1118411185 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("equals-val-default"),anf_arg33711174):R.ffi.throwNonFunApp(L[24],_plus13,[("equals-val-default"),anf_arg33711174]);
};
try {
if(--R.GAS > 0) {
$z1117811179 = $f1118411185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1118411185,
"from":L[24]});
}
} catch($e1117611177) {
if(R.isCont($e1117611177)) {
var $ss1118011181 = {"from":L[24],
"go":function(ann_DASH_check_DASH_temp31711186) {
return $Hann_DASH_check_DASH_temp196911187(ann_DASH_check_DASH_temp31711186);
}};
$e1117611177.stack[R.EXN_STACKHEIGHT++] = $ss1118011181;
}
if(R.isPyretException($e1117611177)) {
$e1117611177.pyretStack.push(L[24]);
}
throw $e1117611177;
}
var $ret1118211183 = $Hann_DASH_check_DASH_temp196911187($z1117811179);
++R.GAS;
return $ret1118211183;
};
var $Hann_DASH_check_DASH_temp196911187 = function(ann_DASH_check_DASH_temp31711186) {
return ann_DASH_check_DASH_temp31711186;
};
var $Hcont_tail_arg1967622 = function(cont_tail_arg314620,if_helper302621) {
if(--R.GAS > 0) {
$z1118811189 = R.isFunction(if_helper302621)?if_helper302621.app(cont_tail_arg314620):R.ffi.throwNonFunApp(L[24],if_helper302621,[cont_tail_arg314620]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper302621)?if_helper302621.app(cont_tail_arg314620):R.ffi.throwNonFunApp(L[24],if_helper302621,[cont_tail_arg314620]);
},
"from":L[24]});
}
++R.GAS;
return $z1118811189;
};
var $Hcont_tail_arg1968637 = function(cont_tail_arg307636,if_helper302621) {
if(--R.GAS > 0) {
$z1119011191 = R.isFunction(if_helper302621)?if_helper302621.app(cont_tail_arg307636):R.ffi.throwNonFunApp(L[24],if_helper302621,[cont_tail_arg307636]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper302621)?if_helper302621.app(cont_tail_arg307636):R.ffi.throwNonFunApp(L[24],if_helper302621,[cont_tail_arg307636]);
},
"from":L[24]});
}
++R.GAS;
return $z1119011191;
};
var $Hanf_arg1966658 = function(anf_arg289656,self74657,_plus13,torepr24) {
var anf_arg29011202 = G(self74657,"repeated",L[25]);
var $z1119411195 = D;
var $f1120011201 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg29011202):R.ffi.throwNonFunApp(L[25],torepr24,[anf_arg29011202]);
};
try {
if(--R.GAS > 0) {
$z1119411195 = $f1120011201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1120011201,
"from":L[25]});
}
} catch($e1119211193) {
if(R.isCont($e1119211193)) {
var $ss1119611197 = {"from":L[25],
"go":function(anf_arg29111203) {
return $Hanf_arg196511204(anf_arg29111203,anf_arg289656,self74657,_plus13,torepr24);
}};
$e1119211193.stack[R.EXN_STACKHEIGHT++] = $ss1119611197;
}
if(R.isPyretException($e1119211193)) {
$e1119211193.pyretStack.push(L[25]);
}
throw $e1119211193;
}
var $ret1119811199 = $Hanf_arg196511204($z1119411195,anf_arg289656,self74657,_plus13,torepr24);
++R.GAS;
return $ret1119811199;
};
var $Hanf_arg196511204 = function(anf_arg29111203,anf_arg289656,self74657,_plus13,torepr24) {
var $z1120711208 = D;
var $f1121311214 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg29111203):R.ffi.throwNonFunApp(L[25],_plus13,[(", "),anf_arg29111203]);
};
try {
if(--R.GAS > 0) {
$z1120711208 = $f1121311214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1121311214,
"from":L[25]});
}
} catch($e1120511206) {
if(R.isCont($e1120511206)) {
var $ss1120911210 = {"from":L[25],
"go":function(anf_arg29211215) {
return $Hanf_arg196411216(anf_arg29211215,anf_arg289656,self74657,_plus13,torepr24);
}};
$e1120511206.stack[R.EXN_STACKHEIGHT++] = $ss1120911210;
}
if(R.isPyretException($e1120511206)) {
$e1120511206.pyretStack.push(L[25]);
}
throw $e1120511206;
}
var $ret1121111212 = $Hanf_arg196411216($z1120711208,anf_arg289656,self74657,_plus13,torepr24);
++R.GAS;
return $ret1121111212;
};
var $Hanf_arg196411216 = function(anf_arg29211215,anf_arg289656,self74657,_plus13,torepr24) {
var $z1121911220 = D;
var $f1122511226 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg289656,anf_arg29211215):R.ffi.throwNonFunApp(L[25],_plus13,[anf_arg289656,anf_arg29211215]);
};
try {
if(--R.GAS > 0) {
$z1121911220 = $f1122511226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1122511226,
"from":L[25]});
}
} catch($e1121711218) {
if(R.isCont($e1121711218)) {
var $ss1122111222 = {"from":L[25],
"go":function(anf_arg29311227) {
return $Hanf_arg196311228(anf_arg29311227,self74657,_plus13,torepr24);
}};
$e1121711218.stack[R.EXN_STACKHEIGHT++] = $ss1122111222;
}
if(R.isPyretException($e1121711218)) {
$e1121711218.pyretStack.push(L[25]);
}
throw $e1121711218;
}
var $ret1122311224 = $Hanf_arg196311228($z1121911220,self74657,_plus13,torepr24);
++R.GAS;
return $ret1122311224;
};
var $Hanf_arg196311228 = function(anf_arg29311227,self74657,_plus13,torepr24) {
var anf_arg29411239 = G(self74657,"desc",L[25]);
var $z1123111232 = D;
var $f1123711238 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg29411239):R.ffi.throwNonFunApp(L[25],torepr24,[anf_arg29411239]);
};
try {
if(--R.GAS > 0) {
$z1123111232 = $f1123711238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1123711238,
"from":L[25]});
}
} catch($e1122911230) {
if(R.isCont($e1122911230)) {
var $ss1123311234 = {"from":L[25],
"go":function(anf_arg29511240) {
return $Hanf_arg196211241(anf_arg29511240,anf_arg29311227,_plus13);
}};
$e1122911230.stack[R.EXN_STACKHEIGHT++] = $ss1123311234;
}
if(R.isPyretException($e1122911230)) {
$e1122911230.pyretStack.push(L[25]);
}
throw $e1122911230;
}
var $ret1123511236 = $Hanf_arg196211241($z1123111232,anf_arg29311227,_plus13);
++R.GAS;
return $ret1123511236;
};
var $Hanf_arg196211241 = function(anf_arg29511240,anf_arg29311227,_plus13) {
var $z1124411245 = D;
var $f1125011251 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg29511240):R.ffi.throwNonFunApp(L[25],_plus13,[(", "),anf_arg29511240]);
};
try {
if(--R.GAS > 0) {
$z1124411245 = $f1125011251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1125011251,
"from":L[25]});
}
} catch($e1124211243) {
if(R.isCont($e1124211243)) {
var $ss1124611247 = {"from":L[25],
"go":function(anf_arg29611252) {
return $Hanf_arg196111253(anf_arg29611252,anf_arg29311227,_plus13);
}};
$e1124211243.stack[R.EXN_STACKHEIGHT++] = $ss1124611247;
}
if(R.isPyretException($e1124211243)) {
$e1124211243.pyretStack.push(L[25]);
}
throw $e1124211243;
}
var $ret1124811249 = $Hanf_arg196111253($z1124411245,anf_arg29311227,_plus13);
++R.GAS;
return $ret1124811249;
};
var $Hanf_arg196111253 = function(anf_arg29611252,anf_arg29311227,_plus13) {
var $z1125611257 = D;
var $f1126211263 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg29311227,anf_arg29611252):R.ffi.throwNonFunApp(L[25],_plus13,[anf_arg29311227,anf_arg29611252]);
};
try {
if(--R.GAS > 0) {
$z1125611257 = $f1126211263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1126211263,
"from":L[25]});
}
} catch($e1125411255) {
if(R.isCont($e1125411255)) {
var $ss1125811259 = {"from":L[25],
"go":function(anf_arg29711264) {
return $Hanf_arg196011265(anf_arg29711264,_plus13);
}};
$e1125411255.stack[R.EXN_STACKHEIGHT++] = $ss1125811259;
}
if(R.isPyretException($e1125411255)) {
$e1125411255.pyretStack.push(L[25]);
}
throw $e1125411255;
}
var $ret1126011261 = $Hanf_arg196011265($z1125611257,_plus13);
++R.GAS;
return $ret1126011261;
};
var $Hanf_arg196011265 = function(anf_arg29711264,_plus13) {
var $z1126811269 = D;
var $f1127411275 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg29711264,(")")):R.ffi.throwNonFunApp(L[25],_plus13,[anf_arg29711264,(")")]);
};
try {
if(--R.GAS > 0) {
$z1126811269 = $f1127411275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1127411275,
"from":L[25]});
}
} catch($e1126611267) {
if(R.isCont($e1126611267)) {
var $ss1127011271 = {"from":L[25],
"go":function(anf_arg29811276) {
return $Hanf_arg195911277(anf_arg29811276,_plus13);
}};
$e1126611267.stack[R.EXN_STACKHEIGHT++] = $ss1127011271;
}
if(R.isPyretException($e1126611267)) {
$e1126611267.pyretStack.push(L[25]);
}
throw $e1126611267;
}
var $ret1127211273 = $Hanf_arg195911277($z1126811269,_plus13);
++R.GAS;
return $ret1127211273;
};
var $Hanf_arg195911277 = function(anf_arg29811276,_plus13) {
var $z1128011281 = D;
var $f1128611287 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg29811276):R.ffi.throwNonFunApp(L[25],_plus13,[("("),anf_arg29811276]);
};
try {
if(--R.GAS > 0) {
$z1128011281 = $f1128611287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1128611287,
"from":L[25]});
}
} catch($e1127811279) {
if(R.isCont($e1127811279)) {
var $ss1128211283 = {"from":L[25],
"go":function(anf_arg29911288) {
return $Hanf_arg195811289(anf_arg29911288,_plus13);
}};
$e1127811279.stack[R.EXN_STACKHEIGHT++] = $ss1128211283;
}
if(R.isPyretException($e1127811279)) {
$e1127811279.pyretStack.push(L[25]);
}
throw $e1127811279;
}
var $ret1128411285 = $Hanf_arg195811289($z1128011281,_plus13);
++R.GAS;
return $ret1128411285;
};
var $Hanf_arg195811289 = function(anf_arg29911288,_plus13) {
var $z1129211293 = D;
var $f1129811299 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("equals-val"),anf_arg29911288):R.ffi.throwNonFunApp(L[25],_plus13,[("equals-val"),anf_arg29911288]);
};
try {
if(--R.GAS > 0) {
$z1129211293 = $f1129811299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1129811299,
"from":L[25]});
}
} catch($e1129011291) {
if(R.isCont($e1129011291)) {
var $ss1129411295 = {"from":L[25],
"go":function(ann_DASH_check_DASH_temp28711300) {
return $Hann_DASH_check_DASH_temp195711301(ann_DASH_check_DASH_temp28711300);
}};
$e1129011291.stack[R.EXN_STACKHEIGHT++] = $ss1129411295;
}
if(R.isPyretException($e1129011291)) {
$e1129011291.pyretStack.push(L[25]);
}
throw $e1129011291;
}
var $ret1129611297 = $Hann_DASH_check_DASH_temp195711301($z1129211293);
++R.GAS;
return $ret1129611297;
};
var $Hann_DASH_check_DASH_temp195711301 = function(ann_DASH_check_DASH_temp28711300) {
return ann_DASH_check_DASH_temp28711300;
};
var $Hcont_tail_arg1955675 = function(cont_tail_arg284673,if_helper274674) {
if(--R.GAS > 0) {
$z1130211303 = R.isFunction(if_helper274674)?if_helper274674.app(cont_tail_arg284673):R.ffi.throwNonFunApp(L[25],if_helper274674,[cont_tail_arg284673]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper274674)?if_helper274674.app(cont_tail_arg284673):R.ffi.throwNonFunApp(L[25],if_helper274674,[cont_tail_arg284673]);
},
"from":L[25]});
}
++R.GAS;
return $z1130211303;
};
var $Hcont_tail_arg1956690 = function(cont_tail_arg279689,if_helper274674) {
if(--R.GAS > 0) {
$z1130411305 = R.isFunction(if_helper274674)?if_helper274674.app(cont_tail_arg279689):R.ffi.throwNonFunApp(L[25],if_helper274674,[cont_tail_arg279689]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper274674)?if_helper274674.app(cont_tail_arg279689):R.ffi.throwNonFunApp(L[25],if_helper274674,[cont_tail_arg279689]);
},
"from":L[25]});
}
++R.GAS;
return $z1130411305;
};
var $Hanf_arg1954711 = function(anf_arg265709,self68710,_plus13,torepr24) {
var anf_arg26611316 = G(self68710,"desc",L[26]);
var $z1130811309 = D;
var $f1131411315 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg26611316):R.ffi.throwNonFunApp(L[26],torepr24,[anf_arg26611316]);
};
try {
if(--R.GAS > 0) {
$z1130811309 = $f1131411315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1131411315,
"from":L[26]});
}
} catch($e1130611307) {
if(R.isCont($e1130611307)) {
var $ss1131011311 = {"from":L[26],
"go":function(anf_arg26711317) {
return $Hanf_arg195311318(anf_arg26711317,anf_arg265709,_plus13);
}};
$e1130611307.stack[R.EXN_STACKHEIGHT++] = $ss1131011311;
}
if(R.isPyretException($e1130611307)) {
$e1130611307.pyretStack.push(L[26]);
}
throw $e1130611307;
}
var $ret1131211313 = $Hanf_arg195311318($z1130811309,anf_arg265709,_plus13);
++R.GAS;
return $ret1131211313;
};
var $Hanf_arg195311318 = function(anf_arg26711317,anf_arg265709,_plus13) {
var $z1132111322 = D;
var $f1132711328 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg26711317):R.ffi.throwNonFunApp(L[26],_plus13,[(", "),anf_arg26711317]);
};
try {
if(--R.GAS > 0) {
$z1132111322 = $f1132711328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1132711328,
"from":L[26]});
}
} catch($e1131911320) {
if(R.isCont($e1131911320)) {
var $ss1132311324 = {"from":L[26],
"go":function(anf_arg26811329) {
return $Hanf_arg195211330(anf_arg26811329,anf_arg265709,_plus13);
}};
$e1131911320.stack[R.EXN_STACKHEIGHT++] = $ss1132311324;
}
if(R.isPyretException($e1131911320)) {
$e1131911320.pyretStack.push(L[26]);
}
throw $e1131911320;
}
var $ret1132511326 = $Hanf_arg195211330($z1132111322,anf_arg265709,_plus13);
++R.GAS;
return $ret1132511326;
};
var $Hanf_arg195211330 = function(anf_arg26811329,anf_arg265709,_plus13) {
var $z1133311334 = D;
var $f1133911340 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg265709,anf_arg26811329):R.ffi.throwNonFunApp(L[26],_plus13,[anf_arg265709,anf_arg26811329]);
};
try {
if(--R.GAS > 0) {
$z1133311334 = $f1133911340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1133911340,
"from":L[26]});
}
} catch($e1133111332) {
if(R.isCont($e1133111332)) {
var $ss1133511336 = {"from":L[26],
"go":function(anf_arg26911341) {
return $Hanf_arg195111342(anf_arg26911341,_plus13);
}};
$e1133111332.stack[R.EXN_STACKHEIGHT++] = $ss1133511336;
}
if(R.isPyretException($e1133111332)) {
$e1133111332.pyretStack.push(L[26]);
}
throw $e1133111332;
}
var $ret1133711338 = $Hanf_arg195111342($z1133311334,_plus13);
++R.GAS;
return $ret1133711338;
};
var $Hanf_arg195111342 = function(anf_arg26911341,_plus13) {
var $z1134511346 = D;
var $f1135111352 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg26911341,(")")):R.ffi.throwNonFunApp(L[26],_plus13,[anf_arg26911341,(")")]);
};
try {
if(--R.GAS > 0) {
$z1134511346 = $f1135111352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1135111352,
"from":L[26]});
}
} catch($e1134311344) {
if(R.isCont($e1134311344)) {
var $ss1134711348 = {"from":L[26],
"go":function(anf_arg27011353) {
return $Hanf_arg195011354(anf_arg27011353,_plus13);
}};
$e1134311344.stack[R.EXN_STACKHEIGHT++] = $ss1134711348;
}
if(R.isPyretException($e1134311344)) {
$e1134311344.pyretStack.push(L[26]);
}
throw $e1134311344;
}
var $ret1134911350 = $Hanf_arg195011354($z1134511346,_plus13);
++R.GAS;
return $ret1134911350;
};
var $Hanf_arg195011354 = function(anf_arg27011353,_plus13) {
var $z1135711358 = D;
var $f1136311364 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg27011353):R.ffi.throwNonFunApp(L[26],_plus13,[("("),anf_arg27011353]);
};
try {
if(--R.GAS > 0) {
$z1135711358 = $f1136311364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1136311364,
"from":L[26]});
}
} catch($e1135511356) {
if(R.isCont($e1135511356)) {
var $ss1135911360 = {"from":L[26],
"go":function(anf_arg27111365) {
return $Hanf_arg194911366(anf_arg27111365,_plus13);
}};
$e1135511356.stack[R.EXN_STACKHEIGHT++] = $ss1135911360;
}
if(R.isPyretException($e1135511356)) {
$e1135511356.pyretStack.push(L[26]);
}
throw $e1135511356;
}
var $ret1136111362 = $Hanf_arg194911366($z1135711358,_plus13);
++R.GAS;
return $ret1136111362;
};
var $Hanf_arg194911366 = function(anf_arg27111365,_plus13) {
var $z1136911370 = D;
var $f1137511376 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("flag"),anf_arg27111365):R.ffi.throwNonFunApp(L[26],_plus13,[("flag"),anf_arg27111365]);
};
try {
if(--R.GAS > 0) {
$z1136911370 = $f1137511376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1137511376,
"from":L[26]});
}
} catch($e1136711368) {
if(R.isCont($e1136711368)) {
var $ss1137111372 = {"from":L[26],
"go":function(ann_DASH_check_DASH_temp26311377) {
return $Hann_DASH_check_DASH_temp194811378(ann_DASH_check_DASH_temp26311377);
}};
$e1136711368.stack[R.EXN_STACKHEIGHT++] = $ss1137111372;
}
if(R.isPyretException($e1136711368)) {
$e1136711368.pyretStack.push(L[26]);
}
throw $e1136711368;
}
var $ret1137311374 = $Hann_DASH_check_DASH_temp194811378($z1136911370);
++R.GAS;
return $ret1137311374;
};
var $Hann_DASH_check_DASH_temp194811378 = function(ann_DASH_check_DASH_temp26311377) {
return ann_DASH_check_DASH_temp26311377;
};
var $Hcont_tail_arg1946727 = function(cont_tail_arg260725,if_helper251726) {
if(--R.GAS > 0) {
$z1137911380 = R.isFunction(if_helper251726)?if_helper251726.app(cont_tail_arg260725):R.ffi.throwNonFunApp(L[26],if_helper251726,[cont_tail_arg260725]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper251726)?if_helper251726.app(cont_tail_arg260725):R.ffi.throwNonFunApp(L[26],if_helper251726,[cont_tail_arg260725]);
},
"from":L[26]});
}
++R.GAS;
return $z1137911380;
};
var $Hcont_tail_arg1947742 = function(cont_tail_arg256741,if_helper251726) {
if(--R.GAS > 0) {
$z1138111382 = R.isFunction(if_helper251726)?if_helper251726.app(cont_tail_arg256741):R.ffi.throwNonFunApp(L[26],if_helper251726,[cont_tail_arg256741]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper251726)?if_helper251726.app(cont_tail_arg256741):R.ffi.throwNonFunApp(L[26],if_helper251726,[cont_tail_arg256741]);
},
"from":L[26]});
}
++R.GAS;
return $z1138111382;
};
var $Hcont_tail_arg1944799 = function(cont_tail_arg232797,if_helper225798) {
if(--R.GAS > 0) {
$z1138311384 = R.isFunction(if_helper225798)?if_helper225798.app(cont_tail_arg232797):R.ffi.throwNonFunApp(L[67],if_helper225798,[cont_tail_arg232797]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper225798)?if_helper225798.app(cont_tail_arg232797):R.ffi.throwNonFunApp(L[67],if_helper225798,[cont_tail_arg232797]);
},
"from":L[67]});
}
++R.GAS;
return $z1138311384;
};
var $Hcont_tail_arg1945813 = function(cont_tail_arg230812,if_helper225798) {
if(--R.GAS > 0) {
$z1138511386 = R.isFunction(if_helper225798)?if_helper225798.app(cont_tail_arg230812):R.ffi.throwNonFunApp(L[67],if_helper225798,[cont_tail_arg230812]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper225798)?if_helper225798.app(cont_tail_arg230812):R.ffi.throwNonFunApp(L[67],if_helper225798,[cont_tail_arg230812]);
},
"from":L[67]});
}
++R.GAS;
return $z1138511386;
};
var $Hcont_tail_arg1942839 = function(cont_tail_arg217837,if_helper210838) {
if(--R.GAS > 0) {
$z1138711388 = R.isFunction(if_helper210838)?if_helper210838.app(cont_tail_arg217837):R.ffi.throwNonFunApp(L[68],if_helper210838,[cont_tail_arg217837]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper210838)?if_helper210838.app(cont_tail_arg217837):R.ffi.throwNonFunApp(L[68],if_helper210838,[cont_tail_arg217837]);
},
"from":L[68]});
}
++R.GAS;
return $z1138711388;
};
var $Hcont_tail_arg1943853 = function(cont_tail_arg215852,if_helper210838) {
if(--R.GAS > 0) {
$z1138911390 = R.isFunction(if_helper210838)?if_helper210838.app(cont_tail_arg215852):R.ffi.throwNonFunApp(L[68],if_helper210838,[cont_tail_arg215852]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper210838)?if_helper210838.app(cont_tail_arg215852):R.ffi.throwNonFunApp(L[68],if_helper210838,[cont_tail_arg215852]);
},
"from":L[68]});
}
++R.GAS;
return $z1138911390;
};
var $Hcont_tail_arg1940879 = function(cont_tail_arg202877,if_helper195878) {
if(--R.GAS > 0) {
$z1139111392 = R.isFunction(if_helper195878)?if_helper195878.app(cont_tail_arg202877):R.ffi.throwNonFunApp(L[69],if_helper195878,[cont_tail_arg202877]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper195878)?if_helper195878.app(cont_tail_arg202877):R.ffi.throwNonFunApp(L[69],if_helper195878,[cont_tail_arg202877]);
},
"from":L[69]});
}
++R.GAS;
return $z1139111392;
};
var $Hcont_tail_arg1941893 = function(cont_tail_arg200892,if_helper195878) {
if(--R.GAS > 0) {
$z1139311394 = R.isFunction(if_helper195878)?if_helper195878.app(cont_tail_arg200892):R.ffi.throwNonFunApp(L[69],if_helper195878,[cont_tail_arg200892]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper195878)?if_helper195878.app(cont_tail_arg200892):R.ffi.throwNonFunApp(L[69],if_helper195878,[cont_tail_arg200892]);
},
"from":L[69]});
}
++R.GAS;
return $z1139311394;
};
var $Hcont_tail_arg1938919 = function(cont_tail_arg187917,if_helper180918) {
if(--R.GAS > 0) {
$z1139511396 = R.isFunction(if_helper180918)?if_helper180918.app(cont_tail_arg187917):R.ffi.throwNonFunApp(L[70],if_helper180918,[cont_tail_arg187917]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper180918)?if_helper180918.app(cont_tail_arg187917):R.ffi.throwNonFunApp(L[70],if_helper180918,[cont_tail_arg187917]);
},
"from":L[70]});
}
++R.GAS;
return $z1139511396;
};
var $Hcont_tail_arg1939933 = function(cont_tail_arg185932,if_helper180918) {
if(--R.GAS > 0) {
$z1139711398 = R.isFunction(if_helper180918)?if_helper180918.app(cont_tail_arg185932):R.ffi.throwNonFunApp(L[70],if_helper180918,[cont_tail_arg185932]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper180918)?if_helper180918.app(cont_tail_arg185932):R.ffi.throwNonFunApp(L[70],if_helper180918,[cont_tail_arg185932]);
},
"from":L[70]});
}
++R.GAS;
return $z1139711398;
};
var $Hanf_arg1937973 = function(anf_arg164971,self38972,_plus13,torepr24) {
var anf_arg16511409 = G(self38972,"partial-results",L[76]);
var $z1140111402 = D;
var $f1140711408 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg16511409):R.ffi.throwNonFunApp(L[76],torepr24,[anf_arg16511409]);
};
try {
if(--R.GAS > 0) {
$z1140111402 = $f1140711408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1140711408,
"from":L[76]});
}
} catch($e1139911400) {
if(R.isCont($e1139911400)) {
var $ss1140311404 = {"from":L[76],
"go":function(anf_arg16611410) {
return $Hanf_arg193611411(anf_arg16611410,anf_arg164971,_plus13);
}};
$e1139911400.stack[R.EXN_STACKHEIGHT++] = $ss1140311404;
}
if(R.isPyretException($e1139911400)) {
$e1139911400.pyretStack.push(L[76]);
}
throw $e1139911400;
}
var $ret1140511406 = $Hanf_arg193611411($z1140111402,anf_arg164971,_plus13);
++R.GAS;
return $ret1140511406;
};
var $Hanf_arg193611411 = function(anf_arg16611410,anf_arg164971,_plus13) {
var $z1141411415 = D;
var $f1142011421 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg16611410):R.ffi.throwNonFunApp(L[76],_plus13,[(", "),anf_arg16611410]);
};
try {
if(--R.GAS > 0) {
$z1141411415 = $f1142011421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1142011421,
"from":L[76]});
}
} catch($e1141211413) {
if(R.isCont($e1141211413)) {
var $ss1141611417 = {"from":L[76],
"go":function(anf_arg16711422) {
return $Hanf_arg193511423(anf_arg16711422,anf_arg164971,_plus13);
}};
$e1141211413.stack[R.EXN_STACKHEIGHT++] = $ss1141611417;
}
if(R.isPyretException($e1141211413)) {
$e1141211413.pyretStack.push(L[76]);
}
throw $e1141211413;
}
var $ret1141811419 = $Hanf_arg193511423($z1141411415,anf_arg164971,_plus13);
++R.GAS;
return $ret1141811419;
};
var $Hanf_arg193511423 = function(anf_arg16711422,anf_arg164971,_plus13) {
var $z1142611427 = D;
var $f1143211433 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg164971,anf_arg16711422):R.ffi.throwNonFunApp(L[76],_plus13,[anf_arg164971,anf_arg16711422]);
};
try {
if(--R.GAS > 0) {
$z1142611427 = $f1143211433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1143211433,
"from":L[76]});
}
} catch($e1142411425) {
if(R.isCont($e1142411425)) {
var $ss1142811429 = {"from":L[76],
"go":function(anf_arg16811434) {
return $Hanf_arg193411435(anf_arg16811434,_plus13);
}};
$e1142411425.stack[R.EXN_STACKHEIGHT++] = $ss1142811429;
}
if(R.isPyretException($e1142411425)) {
$e1142411425.pyretStack.push(L[76]);
}
throw $e1142411425;
}
var $ret1143011431 = $Hanf_arg193411435($z1142611427,_plus13);
++R.GAS;
return $ret1143011431;
};
var $Hanf_arg193411435 = function(anf_arg16811434,_plus13) {
var $z1143811439 = D;
var $f1144411445 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg16811434,(")")):R.ffi.throwNonFunApp(L[76],_plus13,[anf_arg16811434,(")")]);
};
try {
if(--R.GAS > 0) {
$z1143811439 = $f1144411445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1144411445,
"from":L[76]});
}
} catch($e1143611437) {
if(R.isCont($e1143611437)) {
var $ss1144011441 = {"from":L[76],
"go":function(anf_arg16911446) {
return $Hanf_arg193311447(anf_arg16911446,_plus13);
}};
$e1143611437.stack[R.EXN_STACKHEIGHT++] = $ss1144011441;
}
if(R.isPyretException($e1143611437)) {
$e1143611437.pyretStack.push(L[76]);
}
throw $e1143611437;
}
var $ret1144211443 = $Hanf_arg193311447($z1143811439,_plus13);
++R.GAS;
return $ret1144211443;
};
var $Hanf_arg193311447 = function(anf_arg16911446,_plus13) {
var $z1145011451 = D;
var $f1145611457 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg16911446):R.ffi.throwNonFunApp(L[76],_plus13,[("("),anf_arg16911446]);
};
try {
if(--R.GAS > 0) {
$z1145011451 = $f1145611457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1145611457,
"from":L[76]});
}
} catch($e1144811449) {
if(R.isCont($e1144811449)) {
var $ss1145211453 = {"from":L[76],
"go":function(anf_arg17011458) {
return $Hanf_arg193211459(anf_arg17011458,_plus13);
}};
$e1144811449.stack[R.EXN_STACKHEIGHT++] = $ss1145211453;
}
if(R.isPyretException($e1144811449)) {
$e1144811449.pyretStack.push(L[76]);
}
throw $e1144811449;
}
var $ret1145411455 = $Hanf_arg193211459($z1145011451,_plus13);
++R.GAS;
return $ret1145411455;
};
var $Hanf_arg193211459 = function(anf_arg17011458,_plus13) {
var $z1146211463 = D;
var $f1146811469 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("arg-error"),anf_arg17011458):R.ffi.throwNonFunApp(L[76],_plus13,[("arg-error"),anf_arg17011458]);
};
try {
if(--R.GAS > 0) {
$z1146211463 = $f1146811469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1146811469,
"from":L[76]});
}
} catch($e1146011461) {
if(R.isCont($e1146011461)) {
var $ss1146411465 = {"from":L[76],
"go":function(ann_DASH_check_DASH_temp16211470) {
return $Hann_DASH_check_DASH_temp193111471(ann_DASH_check_DASH_temp16211470);
}};
$e1146011461.stack[R.EXN_STACKHEIGHT++] = $ss1146411465;
}
if(R.isPyretException($e1146011461)) {
$e1146011461.pyretStack.push(L[76]);
}
throw $e1146011461;
}
var $ret1146611467 = $Hann_DASH_check_DASH_temp193111471($z1146211463);
++R.GAS;
return $ret1146611467;
};
var $Hann_DASH_check_DASH_temp193111471 = function(ann_DASH_check_DASH_temp16211470) {
return ann_DASH_check_DASH_temp16211470;
};
var $Hcont_tail_arg1929989 = function(cont_tail_arg159987,if_helper150988) {
if(--R.GAS > 0) {
$z1147211473 = R.isFunction(if_helper150988)?if_helper150988.app(cont_tail_arg159987):R.ffi.throwNonFunApp(L[76],if_helper150988,[cont_tail_arg159987]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper150988)?if_helper150988.app(cont_tail_arg159987):R.ffi.throwNonFunApp(L[76],if_helper150988,[cont_tail_arg159987]);
},
"from":L[76]});
}
++R.GAS;
return $z1147211473;
};
var $Hcont_tail_arg19301004 = function(cont_tail_arg1551003,if_helper150988) {
if(--R.GAS > 0) {
$z1147411475 = R.isFunction(if_helper150988)?if_helper150988.app(cont_tail_arg1551003):R.ffi.throwNonFunApp(L[76],if_helper150988,[cont_tail_arg1551003]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper150988)?if_helper150988.app(cont_tail_arg1551003):R.ffi.throwNonFunApp(L[76],if_helper150988,[cont_tail_arg1551003]);
},
"from":L[76]});
}
++R.GAS;
return $z1147411475;
};
var $Hanf_arg19281025 = function(anf_arg1411023,self321024,_plus13,torepr24) {
var anf_arg14211486 = G(self321024,"unknown",L[77]);
var $z1147811479 = D;
var $f1148411485 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg14211486):R.ffi.throwNonFunApp(L[77],torepr24,[anf_arg14211486]);
};
try {
if(--R.GAS > 0) {
$z1147811479 = $f1148411485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1148411485,
"from":L[77]});
}
} catch($e1147611477) {
if(R.isCont($e1147611477)) {
var $ss1148011481 = {"from":L[77],
"go":function(anf_arg14311487) {
return $Hanf_arg192711488(anf_arg14311487,anf_arg1411023,_plus13);
}};
$e1147611477.stack[R.EXN_STACKHEIGHT++] = $ss1148011481;
}
if(R.isPyretException($e1147611477)) {
$e1147611477.pyretStack.push(L[77]);
}
throw $e1147611477;
}
var $ret1148211483 = $Hanf_arg192711488($z1147811479,anf_arg1411023,_plus13);
++R.GAS;
return $ret1148211483;
};
var $Hanf_arg192711488 = function(anf_arg14311487,anf_arg1411023,_plus13) {
var $z1149111492 = D;
var $f1149711498 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg14311487):R.ffi.throwNonFunApp(L[77],_plus13,[(", "),anf_arg14311487]);
};
try {
if(--R.GAS > 0) {
$z1149111492 = $f1149711498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1149711498,
"from":L[77]});
}
} catch($e1148911490) {
if(R.isCont($e1148911490)) {
var $ss1149311494 = {"from":L[77],
"go":function(anf_arg14411499) {
return $Hanf_arg192611500(anf_arg14411499,anf_arg1411023,_plus13);
}};
$e1148911490.stack[R.EXN_STACKHEIGHT++] = $ss1149311494;
}
if(R.isPyretException($e1148911490)) {
$e1148911490.pyretStack.push(L[77]);
}
throw $e1148911490;
}
var $ret1149511496 = $Hanf_arg192611500($z1149111492,anf_arg1411023,_plus13);
++R.GAS;
return $ret1149511496;
};
var $Hanf_arg192611500 = function(anf_arg14411499,anf_arg1411023,_plus13) {
var $z1150311504 = D;
var $f1150911510 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1411023,anf_arg14411499):R.ffi.throwNonFunApp(L[77],_plus13,[anf_arg1411023,anf_arg14411499]);
};
try {
if(--R.GAS > 0) {
$z1150311504 = $f1150911510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1150911510,
"from":L[77]});
}
} catch($e1150111502) {
if(R.isCont($e1150111502)) {
var $ss1150511506 = {"from":L[77],
"go":function(anf_arg14511511) {
return $Hanf_arg192511512(anf_arg14511511,_plus13);
}};
$e1150111502.stack[R.EXN_STACKHEIGHT++] = $ss1150511506;
}
if(R.isPyretException($e1150111502)) {
$e1150111502.pyretStack.push(L[77]);
}
throw $e1150111502;
}
var $ret1150711508 = $Hanf_arg192511512($z1150311504,_plus13);
++R.GAS;
return $ret1150711508;
};
var $Hanf_arg192511512 = function(anf_arg14511511,_plus13) {
var $z1151511516 = D;
var $f1152111522 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg14511511,(")")):R.ffi.throwNonFunApp(L[77],_plus13,[anf_arg14511511,(")")]);
};
try {
if(--R.GAS > 0) {
$z1151511516 = $f1152111522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1152111522,
"from":L[77]});
}
} catch($e1151311514) {
if(R.isCont($e1151311514)) {
var $ss1151711518 = {"from":L[77],
"go":function(anf_arg14611523) {
return $Hanf_arg192411524(anf_arg14611523,_plus13);
}};
$e1151311514.stack[R.EXN_STACKHEIGHT++] = $ss1151711518;
}
if(R.isPyretException($e1151311514)) {
$e1151311514.pyretStack.push(L[77]);
}
throw $e1151311514;
}
var $ret1151911520 = $Hanf_arg192411524($z1151511516,_plus13);
++R.GAS;
return $ret1151911520;
};
var $Hanf_arg192411524 = function(anf_arg14611523,_plus13) {
var $z1152711528 = D;
var $f1153311534 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg14611523):R.ffi.throwNonFunApp(L[77],_plus13,[("("),anf_arg14611523]);
};
try {
if(--R.GAS > 0) {
$z1152711528 = $f1153311534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1153311534,
"from":L[77]});
}
} catch($e1152511526) {
if(R.isCont($e1152511526)) {
var $ss1152911530 = {"from":L[77],
"go":function(anf_arg14711535) {
return $Hanf_arg192311536(anf_arg14711535,_plus13);
}};
$e1152511526.stack[R.EXN_STACKHEIGHT++] = $ss1152911530;
}
if(R.isPyretException($e1152511526)) {
$e1152511526.pyretStack.push(L[77]);
}
throw $e1152511526;
}
var $ret1153111532 = $Hanf_arg192311536($z1152711528,_plus13);
++R.GAS;
return $ret1153111532;
};
var $Hanf_arg192311536 = function(anf_arg14711535,_plus13) {
var $z1153911540 = D;
var $f1154511546 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("success"),anf_arg14711535):R.ffi.throwNonFunApp(L[77],_plus13,[("success"),anf_arg14711535]);
};
try {
if(--R.GAS > 0) {
$z1153911540 = $f1154511546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1154511546,
"from":L[77]});
}
} catch($e1153711538) {
if(R.isCont($e1153711538)) {
var $ss1154111542 = {"from":L[77],
"go":function(ann_DASH_check_DASH_temp13911547) {
return $Hann_DASH_check_DASH_temp192211548(ann_DASH_check_DASH_temp13911547);
}};
$e1153711538.stack[R.EXN_STACKHEIGHT++] = $ss1154111542;
}
if(R.isPyretException($e1153711538)) {
$e1153711538.pyretStack.push(L[77]);
}
throw $e1153711538;
}
var $ret1154311544 = $Hann_DASH_check_DASH_temp192211548($z1153911540);
++R.GAS;
return $ret1154311544;
};
var $Hann_DASH_check_DASH_temp192211548 = function(ann_DASH_check_DASH_temp13911547) {
return ann_DASH_check_DASH_temp13911547;
};
var $Hcont_tail_arg19201041 = function(cont_tail_arg1361039,if_helper1271040) {
if(--R.GAS > 0) {
$z1154911550 = R.isFunction(if_helper1271040)?if_helper1271040.app(cont_tail_arg1361039):R.ffi.throwNonFunApp(L[77],if_helper1271040,[cont_tail_arg1361039]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1271040)?if_helper1271040.app(cont_tail_arg1361039):R.ffi.throwNonFunApp(L[77],if_helper1271040,[cont_tail_arg1361039]);
},
"from":L[77]});
}
++R.GAS;
return $z1154911550;
};
var $Hcont_tail_arg19211056 = function(cont_tail_arg1321055,if_helper1271040) {
if(--R.GAS > 0) {
$z1155111552 = R.isFunction(if_helper1271040)?if_helper1271040.app(cont_tail_arg1321055):R.ffi.throwNonFunApp(L[77],if_helper1271040,[cont_tail_arg1321055]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1271040)?if_helper1271040.app(cont_tail_arg1321055):R.ffi.throwNonFunApp(L[77],if_helper1271040,[cont_tail_arg1321055]);
},
"from":L[77]});
}
++R.GAS;
return $z1155111552;
};
var $Hanf_arg19191115 = function(anf_arg1131114,format7872) {
var $z1155511556 = D;
var $f1156111562 = function(_) {
return R.isFunction(format7872)?format7872.app(("<~a>"),anf_arg1131114):R.ffi.throwNonFunApp(L[99],format7872,[("<~a>"),anf_arg1131114]);
};
try {
if(--R.GAS > 0) {
$z1155511556 = $f1156111562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1156111562,
"from":L[99]});
}
} catch($e1155311554) {
if(R.isCont($e1155311554)) {
var $ss1155711558 = {"from":L[99],
"go":function(ann_DASH_check_DASH_temp11011563) {
return $Hann_DASH_check_DASH_temp191811564(ann_DASH_check_DASH_temp11011563);
}};
$e1155311554.stack[R.EXN_STACKHEIGHT++] = $ss1155711558;
}
if(R.isPyretException($e1155311554)) {
$e1155311554.pyretStack.push(L[99]);
}
throw $e1155311554;
}
var $ret1155911560 = $Hann_DASH_check_DASH_temp191811564($z1155511556);
++R.GAS;
return $ret1155911560;
};
var $Hann_DASH_check_DASH_temp191811564 = function(ann_DASH_check_DASH_temp11011563) {
return ann_DASH_check_DASH_temp11011563;
};
var $Hann_DASH_check_DASH_temp19171132 = function(ann_DASH_check_DASH_temp1071131) {
return ann_DASH_check_DASH_temp1071131;
};
var $Hanf_arg19161147 = function(anf_arg991145,self261146,_plus13,torepr24) {
var anf_arg10011575 = G(self261146,"parser",L[89]);
var $z1156711568 = D;
var $f1157311574 = function(_) {
return R.isFunction(torepr24)?torepr24.app(anf_arg10011575):R.ffi.throwNonFunApp(L[89],torepr24,[anf_arg10011575]);
};
try {
if(--R.GAS > 0) {
$z1156711568 = $f1157311574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1157311574,
"from":L[89]});
}
} catch($e1156511566) {
if(R.isCont($e1156511566)) {
var $ss1156911570 = {"from":L[89],
"go":function(anf_arg10111576) {
return $Hanf_arg191511577(anf_arg10111576,anf_arg991145,_plus13);
}};
$e1156511566.stack[R.EXN_STACKHEIGHT++] = $ss1156911570;
}
if(R.isPyretException($e1156511566)) {
$e1156511566.pyretStack.push(L[89]);
}
throw $e1156511566;
}
var $ret1157111572 = $Hanf_arg191511577($z1156711568,anf_arg991145,_plus13);
++R.GAS;
return $ret1157111572;
};
var $Hanf_arg191511577 = function(anf_arg10111576,anf_arg991145,_plus13) {
var $z1158011581 = D;
var $f1158611587 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg10111576):R.ffi.throwNonFunApp(L[89],_plus13,[(", "),anf_arg10111576]);
};
try {
if(--R.GAS > 0) {
$z1158011581 = $f1158611587();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1158611587,
"from":L[89]});
}
} catch($e1157811579) {
if(R.isCont($e1157811579)) {
var $ss1158211583 = {"from":L[89],
"go":function(anf_arg10211588) {
return $Hanf_arg191411589(anf_arg10211588,anf_arg991145,_plus13);
}};
$e1157811579.stack[R.EXN_STACKHEIGHT++] = $ss1158211583;
}
if(R.isPyretException($e1157811579)) {
$e1157811579.pyretStack.push(L[89]);
}
throw $e1157811579;
}
var $ret1158411585 = $Hanf_arg191411589($z1158011581,anf_arg991145,_plus13);
++R.GAS;
return $ret1158411585;
};
var $Hanf_arg191411589 = function(anf_arg10211588,anf_arg991145,_plus13) {
var $z1159211593 = D;
var $f1159811599 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg991145,anf_arg10211588):R.ffi.throwNonFunApp(L[89],_plus13,[anf_arg991145,anf_arg10211588]);
};
try {
if(--R.GAS > 0) {
$z1159211593 = $f1159811599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1159811599,
"from":L[89]});
}
} catch($e1159011591) {
if(R.isCont($e1159011591)) {
var $ss1159411595 = {"from":L[89],
"go":function(anf_arg10311600) {
return $Hanf_arg191311601(anf_arg10311600,_plus13);
}};
$e1159011591.stack[R.EXN_STACKHEIGHT++] = $ss1159411595;
}
if(R.isPyretException($e1159011591)) {
$e1159011591.pyretStack.push(L[89]);
}
throw $e1159011591;
}
var $ret1159611597 = $Hanf_arg191311601($z1159211593,_plus13);
++R.GAS;
return $ret1159611597;
};
var $Hanf_arg191311601 = function(anf_arg10311600,_plus13) {
var $z1160411605 = D;
var $f1161011611 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg10311600,(")")):R.ffi.throwNonFunApp(L[89],_plus13,[anf_arg10311600,(")")]);
};
try {
if(--R.GAS > 0) {
$z1160411605 = $f1161011611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1161011611,
"from":L[89]});
}
} catch($e1160211603) {
if(R.isCont($e1160211603)) {
var $ss1160611607 = {"from":L[89],
"go":function(anf_arg10411612) {
return $Hanf_arg191211613(anf_arg10411612,_plus13);
}};
$e1160211603.stack[R.EXN_STACKHEIGHT++] = $ss1160611607;
}
if(R.isPyretException($e1160211603)) {
$e1160211603.pyretStack.push(L[89]);
}
throw $e1160211603;
}
var $ret1160811609 = $Hanf_arg191211613($z1160411605,_plus13);
++R.GAS;
return $ret1160811609;
};
var $Hanf_arg191211613 = function(anf_arg10411612,_plus13) {
var $z1161611617 = D;
var $f1162211623 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg10411612):R.ffi.throwNonFunApp(L[89],_plus13,[("("),anf_arg10411612]);
};
try {
if(--R.GAS > 0) {
$z1161611617 = $f1162211623();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1162211623,
"from":L[89]});
}
} catch($e1161411615) {
if(R.isCont($e1161411615)) {
var $ss1161811619 = {"from":L[89],
"go":function(anf_arg10511624) {
return $Hanf_arg191111625(anf_arg10511624,_plus13);
}};
$e1161411615.stack[R.EXN_STACKHEIGHT++] = $ss1161811619;
}
if(R.isPyretException($e1161411615)) {
$e1161411615.pyretStack.push(L[89]);
}
throw $e1161411615;
}
var $ret1162011621 = $Hanf_arg191111625($z1161611617,_plus13);
++R.GAS;
return $ret1162011621;
};
var $Hanf_arg191111625 = function(anf_arg10511624,_plus13) {
var $z1162811629 = D;
var $f1163411635 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("read-custom"),anf_arg10511624):R.ffi.throwNonFunApp(L[89],_plus13,[("read-custom"),anf_arg10511624]);
};
try {
if(--R.GAS > 0) {
$z1162811629 = $f1163411635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1163411635,
"from":L[89]});
}
} catch($e1162611627) {
if(R.isCont($e1162611627)) {
var $ss1163011631 = {"from":L[89],
"go":function(ann_DASH_check_DASH_temp9711636) {
return $Hann_DASH_check_DASH_temp191011637(ann_DASH_check_DASH_temp9711636);
}};
$e1162611627.stack[R.EXN_STACKHEIGHT++] = $ss1163011631;
}
if(R.isPyretException($e1162611627)) {
$e1162611627.pyretStack.push(L[89]);
}
throw $e1162611627;
}
var $ret1163211633 = $Hann_DASH_check_DASH_temp191011637($z1162811629);
++R.GAS;
return $ret1163211633;
};
var $Hann_DASH_check_DASH_temp191011637 = function(ann_DASH_check_DASH_temp9711636) {
return ann_DASH_check_DASH_temp9711636;
};
var $Hcont_tail_arg19081163 = function(cont_tail_arg941161,if_helper851162) {
if(--R.GAS > 0) {
$z1163811639 = R.isFunction(if_helper851162)?if_helper851162.app(cont_tail_arg941161):R.ffi.throwNonFunApp(L[89],if_helper851162,[cont_tail_arg941161]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper851162)?if_helper851162.app(cont_tail_arg941161):R.ffi.throwNonFunApp(L[89],if_helper851162,[cont_tail_arg941161]);
},
"from":L[89]});
}
++R.GAS;
return $z1163811639;
};
var $Hcont_tail_arg19091178 = function(cont_tail_arg901177,if_helper851162) {
if(--R.GAS > 0) {
$z1164011641 = R.isFunction(if_helper851162)?if_helper851162.app(cont_tail_arg901177):R.ffi.throwNonFunApp(L[89],if_helper851162,[cont_tail_arg901177]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper851162)?if_helper851162.app(cont_tail_arg901177):R.ffi.throwNonFunApp(L[89],if_helper851162,[cont_tail_arg901177]);
},
"from":L[89]});
}
++R.GAS;
return $z1164011641;
};
var $Hann_DASH_check_DASH_temp19071200 = function(ann_DASH_check_DASH_temp801199,$type$String28) {
return ann_DASH_check_DASH_temp801199;
};
var $Hcont_tail_arg19051219 = function(cont_tail_arg751217,if_helper681218) {
if(--R.GAS > 0) {
$z1164211643 = R.isFunction(if_helper681218)?if_helper681218.app(cont_tail_arg751217):R.ffi.throwNonFunApp(L[90],if_helper681218,[cont_tail_arg751217]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper681218)?if_helper681218.app(cont_tail_arg751217):R.ffi.throwNonFunApp(L[90],if_helper681218,[cont_tail_arg751217]);
},
"from":L[90]});
}
++R.GAS;
return $z1164211643;
};
var $Hcont_tail_arg19061233 = function(cont_tail_arg731232,if_helper681218) {
if(--R.GAS > 0) {
$z1164411645 = R.isFunction(if_helper681218)?if_helper681218.app(cont_tail_arg731232):R.ffi.throwNonFunApp(L[90],if_helper681218,[cont_tail_arg731232]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper681218)?if_helper681218.app(cont_tail_arg731232):R.ffi.throwNonFunApp(L[90],if_helper681218,[cont_tail_arg731232]);
},
"from":L[90]});
}
++R.GAS;
return $z1164411645;
};
var $Hcont_tail_arg18991256 = function(cont_tail_arg621254,if_helper461255) {
if(--R.GAS > 0) {
$z1164611647 = R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg621254):R.ffi.throwNonFunApp(L[113],if_helper461255,[cont_tail_arg621254]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg621254):R.ffi.throwNonFunApp(L[113],if_helper461255,[cont_tail_arg621254]);
},
"from":L[113]});
}
++R.GAS;
return $z1164611647;
};
var $Hcont_tail_arg19001268 = function(cont_tail_arg601267,if_helper461255) {
if(--R.GAS > 0) {
$z1164811649 = R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg601267):R.ffi.throwNonFunApp(L[114],if_helper461255,[cont_tail_arg601267]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg601267):R.ffi.throwNonFunApp(L[114],if_helper461255,[cont_tail_arg601267]);
},
"from":L[114]});
}
++R.GAS;
return $z1164811649;
};
var $Hanf_array_val19041283 = function(anf_array_val551280,anf_fun541281,format7872,if_helper461255,param_DASH_name1491282,right8177) {
var $z1165211653 = D;
var $f1165811659 = function(_) {
return R.isFunction(anf_fun541281)?anf_fun541281.app([param_DASH_name1491282,anf_array_val551280]):R.ffi.throwNonFunApp(L[116],anf_fun541281,[[param_DASH_name1491282,anf_array_val551280]]);
};
try {
if(--R.GAS > 0) {
$z1165211653 = $f1165811659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1165811659,
"from":L[116]});
}
} catch($e1165011651) {
if(R.isCont($e1165011651)) {
var $ss1165411655 = {"from":L[116],
"go":function(anf_arg5611660) {
return $Hanf_arg190311661(anf_arg5611660,format7872,if_helper461255,right8177);
}};
$e1165011651.stack[R.EXN_STACKHEIGHT++] = $ss1165411655;
}
if(R.isPyretException($e1165011651)) {
$e1165011651.pyretStack.push(L[116]);
}
throw $e1165011651;
}
var $ret1165611657 = $Hanf_arg190311661($z1165211653,format7872,if_helper461255,right8177);
++R.GAS;
return $ret1165611657;
};
var $Hanf_arg190311661 = function(anf_arg5611660,format7872,if_helper461255,right8177) {
var $z1166411665 = D;
var $f1167011671 = function(_) {
return R.isFunction(format7872)?format7872.app(("~a expected a boolean argument, got ~a"),anf_arg5611660):R.ffi.throwNonFunApp(L[894],format7872,[("~a expected a boolean argument, got ~a"),anf_arg5611660]);
};
try {
if(--R.GAS > 0) {
$z1166411665 = $f1167011671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1167011671,
"from":L[894]});
}
} catch($e1166211663) {
if(R.isCont($e1166211663)) {
var $ss1166611667 = {"from":L[894],
"go":function(anf_arg5711672) {
return $Hanf_arg190211673(anf_arg5711672,if_helper461255,right8177);
}};
$e1166211663.stack[R.EXN_STACKHEIGHT++] = $ss1166611667;
}
if(R.isPyretException($e1166211663)) {
$e1166211663.pyretStack.push(L[894]);
}
throw $e1166211663;
}
var $ret1166811669 = $Hanf_arg190211673($z1166411665,if_helper461255,right8177);
++R.GAS;
return $ret1166811669;
};
var $Hanf_arg190211673 = function(anf_arg5711672,if_helper461255,right8177) {
var $z1167611677 = D;
var $f1168211683 = function(_) {
return R.isFunction(right8177)?right8177.app(anf_arg5711672):R.ffi.throwNonFunApp(L[895],right8177,[anf_arg5711672]);
};
try {
if(--R.GAS > 0) {
$z1167611677 = $f1168211683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1168211683,
"from":L[895]});
}
} catch($e1167411675) {
if(R.isCont($e1167411675)) {
var $ss1167811679 = {"from":L[895],
"go":function(cont_tail_arg5811684) {
return $Hcont_tail_arg190111685(cont_tail_arg5811684,if_helper461255);
}};
$e1167411675.stack[R.EXN_STACKHEIGHT++] = $ss1167811679;
}
if(R.isPyretException($e1167411675)) {
$e1167411675.pyretStack.push(L[895]);
}
throw $e1167411675;
}
var $ret1168011681 = $Hcont_tail_arg190111685($z1167611677,if_helper461255);
++R.GAS;
return $ret1168011681;
};
var $Hcont_tail_arg190111685 = function(cont_tail_arg5811684,if_helper461255) {
if(--R.GAS > 0) {
$z1168611687 = R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg5811684):R.ffi.throwNonFunApp(L[895],if_helper461255,[cont_tail_arg5811684]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper461255)?if_helper461255.app(cont_tail_arg5811684):R.ffi.throwNonFunApp(L[895],if_helper461255,[cont_tail_arg5811684]);
},
"from":L[895]});
}
++R.GAS;
return $z1168611687;
};
var $Hcont_tail_arg18971313 = function(cont_tail_arg401311,if_helper331312) {
if(--R.GAS > 0) {
$z1168811689 = R.isFunction(if_helper331312)?if_helper331312.app(cont_tail_arg401311):R.ffi.throwNonFunApp(L[91],if_helper331312,[cont_tail_arg401311]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper331312)?if_helper331312.app(cont_tail_arg401311):R.ffi.throwNonFunApp(L[91],if_helper331312,[cont_tail_arg401311]);
},
"from":L[91]});
}
++R.GAS;
return $z1168811689;
};
var $Hcont_tail_arg18981327 = function(cont_tail_arg381326,if_helper331312) {
if(--R.GAS > 0) {
$z1169011691 = R.isFunction(if_helper331312)?if_helper331312.app(cont_tail_arg381326):R.ffi.throwNonFunApp(L[91],if_helper331312,[cont_tail_arg381326]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper331312)?if_helper331312.app(cont_tail_arg381326):R.ffi.throwNonFunApp(L[91],if_helper331312,[cont_tail_arg381326]);
},
"from":L[91]});
}
++R.GAS;
return $z1169011691;
};
var $Hn18961351 = function(n1451349,format7872,left8074,list2776,param_DASH_name1431350,right8177,s1441348,is_DASH_nothing16,torepr24,$type$Number27) {
var $z1169411695 = D;
var $f1170011701 = function(_) {
return R.isFunction(is_DASH_nothing16)?is_DASH_nothing16.app(n1451349):R.ffi.throwNonFunApp(L[896],is_DASH_nothing16,[n1451349]);
};
try {
if(--R.GAS > 0) {
$z1169411695 = $f1170011701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1170011701,
"from":L[896]});
}
} catch($e1169211693) {
if(R.isCont($e1169211693)) {
var $ss1169611697 = {"from":L[896],
"go":function(if_DASH_711702) {
return $Hif_DASH_189511703(if_DASH_711702,format7872,left8074,list2776,n1451349,param_DASH_name1431350,right8177,s1441348,torepr24,$type$Number27);
}};
$e1169211693.stack[R.EXN_STACKHEIGHT++] = $ss1169611697;
}
if(R.isPyretException($e1169211693)) {
$e1169211693.pyretStack.push(L[896]);
}
throw $e1169211693;
}
var $ret1169811699 = $Hif_DASH_189511703($z1169411695,format7872,left8074,list2776,n1451349,param_DASH_name1431350,right8177,s1441348,torepr24,$type$Number27);
++R.GAS;
return $ret1169811699;
};
var $Hif_DASH_189511703 = function(if_DASH_711702,format7872,left8074,list2776,n1451349,param_DASH_name1431350,right8177,s1441348,torepr24,$type$Number27) {
var if_helper1611716 = R.makeFunction(function(if_helper_arg1711734) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[896],1,arguments);
}
var ann_DASH_check_DASH_temp1511735 = if_helper_arg1711734;
return R.checkAnn(L[900],$type$Number27,ann_DASH_check_DASH_temp1511735,function() {
return ann_DASH_check_DASH_temp1511735;
});
});
var anf_if2011733 = R.isBoolean(if_DASH_711702);
if(R.isPyretTrue(anf_if2011733)) {
if(R.isPyretTrue(if_DASH_711702)) {
var anf_fun2311715 = G(list2776,"make",L[898]);
var $z1170611707 = D;
var $f1171211713 = function(_) {
return R.isFunction(torepr24)?torepr24.app(s1441348):R.ffi.throwNonFunApp(L[897],torepr24,[s1441348]);
};
try {
if(--R.GAS > 0) {
$z1170611707 = $f1171211713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1171211713,
"from":L[897]});
}
} catch($e1170411705) {
if(R.isCont($e1170411705)) {
var $ss1170811709 = {"from":L[897],
"go":function(anf_array_val2411714) {
return $Hanf_array_val189311717(anf_array_val2411714,anf_fun2311715,format7872,if_helper1611716,param_DASH_name1431350,right8177);
}};
$e1170411705.stack[R.EXN_STACKHEIGHT++] = $ss1170811709;
}
if(R.isPyretException($e1170411705)) {
$e1170411705.pyretStack.push(L[897]);
}
throw $e1170411705;
}
var $ret1171011711 = $Hanf_array_val189311717($z1170611707,anf_fun2311715,format7872,if_helper1611716,param_DASH_name1431350,right8177);
++R.GAS;
return $ret1171011711;
} else {
var $z1172011721 = D;
var $f1172611727 = function(_) {
return R.isFunction(left8074)?left8074.app(n1451349):R.ffi.throwNonFunApp(L[899],left8074,[n1451349]);
};
try {
if(--R.GAS > 0) {
$z1172011721 = $f1172611727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1172611727,
"from":L[899]});
}
} catch($e1171811719) {
if(R.isCont($e1171811719)) {
var $ss1172211723 = {"from":L[899],
"go":function(cont_tail_arg2111728) {
return $Hcont_tail_arg189411729(cont_tail_arg2111728,if_helper1611716);
}};
$e1171811719.stack[R.EXN_STACKHEIGHT++] = $ss1172211723;
}
if(R.isPyretException($e1171811719)) {
$e1171811719.pyretStack.push(L[899]);
}
throw $e1171811719;
}
var $ret1172411725 = $Hcont_tail_arg189411729($z1172011721,if_helper1611716);
++R.GAS;
return $ret1172411725;
}
} else {
var cont_tail_arg1811732 = R.throwNonBooleanCondition(L[896],("if"),if_DASH_711702);
if(--R.GAS > 0) {
$z1173011731 = R.isFunction(if_helper1611716)?if_helper1611716.app(cont_tail_arg1811732):R.ffi.throwNonFunApp(L[896],if_helper1611716,[cont_tail_arg1811732]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1611716)?if_helper1611716.app(cont_tail_arg1811732):R.ffi.throwNonFunApp(L[896],if_helper1611716,[cont_tail_arg1811732]);
},
"from":L[896]});
}
++R.GAS;
return $z1173011731;
}
};
var $Hanf_array_val189311717 = function(anf_array_val2411714,anf_fun2311715,format7872,if_helper1611716,param_DASH_name1431350,right8177) {
var $z1173811739 = D;
var $f1174411745 = function(_) {
return R.isFunction(anf_fun2311715)?anf_fun2311715.app([param_DASH_name1431350,anf_array_val2411714]):R.ffi.throwNonFunApp(L[898],anf_fun2311715,[[param_DASH_name1431350,anf_array_val2411714]]);
};
try {
if(--R.GAS > 0) {
$z1173811739 = $f1174411745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1174411745,
"from":L[898]});
}
} catch($e1173611737) {
if(R.isCont($e1173611737)) {
var $ss1174011741 = {"from":L[898],
"go":function(anf_arg2511746) {
return $Hanf_arg189211747(anf_arg2511746,format7872,if_helper1611716,right8177);
}};
$e1173611737.stack[R.EXN_STACKHEIGHT++] = $ss1174011741;
}
if(R.isPyretException($e1173611737)) {
$e1173611737.pyretStack.push(L[898]);
}
throw $e1173611737;
}
var $ret1174211743 = $Hanf_arg189211747($z1173811739,format7872,if_helper1611716,right8177);
++R.GAS;
return $ret1174211743;
};
var $Hanf_arg189211747 = function(anf_arg2511746,format7872,if_helper1611716,right8177) {
var $z1175011751 = D;
var $f1175611757 = function(_) {
return R.isFunction(format7872)?format7872.app(("~a expected a numeric argument, got ~a"),anf_arg2511746):R.ffi.throwNonFunApp(L[901],format7872,[("~a expected a numeric argument, got ~a"),anf_arg2511746]);
};
try {
if(--R.GAS > 0) {
$z1175011751 = $f1175611757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1175611757,
"from":L[901]});
}
} catch($e1174811749) {
if(R.isCont($e1174811749)) {
var $ss1175211753 = {"from":L[901],
"go":function(anf_arg2611758) {
return $Hanf_arg189111759(anf_arg2611758,if_helper1611716,right8177);
}};
$e1174811749.stack[R.EXN_STACKHEIGHT++] = $ss1175211753;
}
if(R.isPyretException($e1174811749)) {
$e1174811749.pyretStack.push(L[901]);
}
throw $e1174811749;
}
var $ret1175411755 = $Hanf_arg189111759($z1175011751,if_helper1611716,right8177);
++R.GAS;
return $ret1175411755;
};
var $Hanf_arg189111759 = function(anf_arg2611758,if_helper1611716,right8177) {
var $z1176211763 = D;
var $f1176811769 = function(_) {
return R.isFunction(right8177)?right8177.app(anf_arg2611758):R.ffi.throwNonFunApp(L[902],right8177,[anf_arg2611758]);
};
try {
if(--R.GAS > 0) {
$z1176211763 = $f1176811769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1176811769,
"from":L[902]});
}
} catch($e1176011761) {
if(R.isCont($e1176011761)) {
var $ss1176411765 = {"from":L[902],
"go":function(cont_tail_arg2711770) {
return $Hcont_tail_arg189011771(cont_tail_arg2711770,if_helper1611716);
}};
$e1176011761.stack[R.EXN_STACKHEIGHT++] = $ss1176411765;
}
if(R.isPyretException($e1176011761)) {
$e1176011761.pyretStack.push(L[902]);
}
throw $e1176011761;
}
var $ret1176611767 = $Hcont_tail_arg189011771($z1176211763,if_helper1611716);
++R.GAS;
return $ret1176611767;
};
var $Hcont_tail_arg189011771 = function(cont_tail_arg2711770,if_helper1611716) {
if(--R.GAS > 0) {
$z1177211773 = R.isFunction(if_helper1611716)?if_helper1611716.app(cont_tail_arg2711770):R.ffi.throwNonFunApp(L[902],if_helper1611716,[cont_tail_arg2711770]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1611716)?if_helper1611716.app(cont_tail_arg2711770):R.ffi.throwNonFunApp(L[902],if_helper1611716,[cont_tail_arg2711770]);
},
"from":L[902]});
}
++R.GAS;
return $z1177211773;
};
var $Hcont_tail_arg189411729 = function(cont_tail_arg2111728,if_helper1611716) {
if(--R.GAS > 0) {
$z1177411775 = R.isFunction(if_helper1611716)?if_helper1611716.app(cont_tail_arg2111728):R.ffi.throwNonFunApp(L[899],if_helper1611716,[cont_tail_arg2111728]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper1611716)?if_helper1611716.app(cont_tail_arg2111728):R.ffi.throwNonFunApp(L[899],if_helper1611716,[cont_tail_arg2111728]);
},
"from":L[899]});
}
++R.GAS;
return $z1177411775;
};
var $Hcont_tail_arg18881369 = function(cont_tail_arg101367,if_helper31368) {
if(--R.GAS > 0) {
$z1177611777 = R.isFunction(if_helper31368)?if_helper31368.app(cont_tail_arg101367):R.ffi.throwNonFunApp(L[92],if_helper31368,[cont_tail_arg101367]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper31368)?if_helper31368.app(cont_tail_arg101367):R.ffi.throwNonFunApp(L[92],if_helper31368,[cont_tail_arg101367]);
},
"from":L[92]});
}
++R.GAS;
return $z1177611777;
};
var $Hcont_tail_arg18891383 = function(cont_tail_arg81382,if_helper31368) {
if(--R.GAS > 0) {
$z1177811779 = R.isFunction(if_helper31368)?if_helper31368.app(cont_tail_arg81382):R.ffi.throwNonFunApp(L[92],if_helper31368,[cont_tail_arg81382]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored262) {
return R.isFunction(if_helper31368)?if_helper31368.app(cont_tail_arg81382):R.ffi.throwNonFunApp(L[92],if_helper31368,[cont_tail_arg81382]);
},
"from":L[92]});
}
++R.GAS;
return $z1177811779;
};
return R.loadModulesNew(NAMESPACE,[$CL12948,$F33049,$D53150,$E73251,$arrays93352,$lists113453,$option133554,$error153655,$sets173756],function($CL12948,$F33049,$D53150,$E73251,$arrays93352,$lists113453,$option133554,$error153655,$sets173756) {
var CL129 = R.getField($CL12948,"values");
var F330 = R.getField($F33049,"values");
var D531 = R.getField($D53150,"values");
var E732 = R.getField($E73251,"values");
var arrays933 = R.getField($arrays93352,"values");
var lists1134 = R.getField($lists113453,"values");
var option1335 = R.getField($option133554,"values");
var error1536 = R.getField($error153655,"values");
var sets1737 = R.getField($sets173756,"values");
var CL238 = R.getField($CL12948,"types");
var F439 = R.getField($F33049,"types");
var D640 = R.getField($D53150,"types");
var E841 = R.getField($E73251,"types");
var arrays1042 = R.getField($arrays93352,"types");
var lists1243 = R.getField($lists113453,"types");
var option1444 = R.getField($option133554,"types");
var error1645 = R.getField($error153655,"types");
var sets1846 = R.getField($sets173756,"types");
return R.safeCall(function() {
var List1959 = R.getDotAnn(L[903],"lists",lists1243,"List");
var Option2060 = R.getDotAnn(L[903],"option",option1444,"Option");
var Array2111780 = R.getDotAnn(L[903],"arrays",arrays1042,"Array");
var Set2211781 = R.getDotAnn(L[903],"sets",sets1846,"Set");
var array2311833 = G(arrays933,"array",L[903]);
var build_DASH_array2411832 = G(arrays933,"build-array",L[903]);
var array_DASH_from_DASH_list2511831 = G(arrays933,"array-from-list",L[903]);
var is_DASH_array2611830 = G(arrays933,"is-array",L[903]);
var list2776 = G(lists1134,"list",L[903]);
var is_DASH_empty2873 = G(lists1134,"is-empty",L[903]);
var is_DASH_link2911829 = G(lists1134,"is-link",L[903]);
var empty3011828 = G(lists1134,"empty",L[903]);
var link3175 = G(lists1134,"link",L[903]);
var range3211827 = G(lists1134,"range",L[903]);
var repeat3311826 = G(lists1134,"repeat",L[903]);
var filter3411825 = G(lists1134,"filter",L[903]);
var partition3511824 = G(lists1134,"partition",L[903]);
var split_DASH_at3611823 = G(lists1134,"split-at",L[903]);
var any3711822 = G(lists1134,"any",L[903]);
var find3811821 = G(lists1134,"find",L[903]);
var map3911820 = G(lists1134,"map",L[903]);
var map24011819 = G(lists1134,"map2",L[903]);
var map34111818 = G(lists1134,"map3",L[903]);
var map44211817 = G(lists1134,"map4",L[903]);
var map_n4311816 = G(lists1134,"map_n",L[903]);
var map2_n4411815 = G(lists1134,"map2_n",L[903]);
var map3_n4511814 = G(lists1134,"map3_n",L[903]);
var map4_n4611813 = G(lists1134,"map4_n",L[903]);
var each4711812 = G(lists1134,"each",L[903]);
var each24811811 = G(lists1134,"each2",L[903]);
var each34911810 = G(lists1134,"each3",L[903]);
var each45011809 = G(lists1134,"each4",L[903]);
var each_n5111808 = G(lists1134,"each_n",L[903]);
var each2_n5211807 = G(lists1134,"each2_n",L[903]);
var each3_n5311806 = G(lists1134,"each3_n",L[903]);
var each4_n5411805 = G(lists1134,"each4_n",L[903]);
var fold5571 = G(lists1134,"fold",L[903]);
var fold25611804 = G(lists1134,"fold2",L[903]);
var fold35711803 = G(lists1134,"fold3",L[903]);
var fold45811802 = G(lists1134,"fold4",L[903]);
var index5911801 = G(lists1134,"index",L[903]);
var Option6011800 = G(option1335,"Option",L[903]);
var is_DASH_none6111799 = G(option1335,"is-none",L[903]);
var is_DASH_some6211798 = G(option1335,"is-some",L[903]);
var none6311797 = G(option1335,"none",L[903]);
var some6478 = G(option1335,"some",L[903]);
var set6511796 = G(sets1737,"set",L[903]);
var tree_DASH_set6611795 = G(sets1737,"tree-set",L[903]);
var list_DASH_set6711794 = G(sets1737,"list-set",L[903]);
var ParseParamT26966 = R.namedBrander("ParseParam");
var ParseParam6865 = R.makeBranderAnn(ParseParamT26966,"ParseParam");
var ParsedArgumentsT37168 = R.namedBrander("ParsedArguments");
var ParsedArguments7067 = R.makeBranderAnn(ParsedArgumentsT37168,"ParsedArguments");
var ParamRepeatT47363 = R.namedBrander("ParamRepeat");
var ParamRepeat7262 = R.makeBranderAnn(ParamRepeatT47363,"ParamRepeat");
var ParamT57564 = R.namedBrander("Param");
var Param7461 = R.makeBranderAnn(ParamT57564,"Param");
var RGBT67770 = R.namedBrander("RGB");
var RGB7669 = R.makeBranderAnn(RGBT67770,"RGB");
var format7872 = G(F330,"format",L[909]);
var Either7911793 = G(E732,"Either",L[908]);
var left8074 = G(E732,"left",L[907]);
var right8177 = G(E732,"right",L[906]);
var anf_fun111792 = G(CL129,"command-line-arguments",L[905]);
var $z1178411785 = D;
var $f1179011791 = function(_) {
return R.isFunction(anf_fun111792)?anf_fun111792.app():R.ffi.throwNonFunApp(L[904],anf_fun111792,[]);
};
try {
if(--R.GAS > 0) {
$z1178411785 = $f1179011791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1179011791,
"from":L[904]});
}
} catch($e1178211783) {
if(R.isCont($e1178211783)) {
var $ss1178611787 = {"from":L[904],
"go":function(all_DASH_cmdline_DASH_params8258) {
return $Hall_DASH_cmdline_DASH_params276757(all_DASH_cmdline_DASH_params8258,D531,D640,List1959,Option2060,Param7461,ParamRepeat7262,ParamRepeatT47363,ParamT57564,ParseParam6865,ParseParamT26966,ParsedArguments7067,ParsedArgumentsT37168,RGB7669,RGBT67770,fold5571,format7872,is_DASH_empty2873,left8074,link3175,list2776,lists1134,right8177,some6478,_divide12,_plus13,_times14,builtins15,is_DASH_nothing16,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22,string_DASH_tonumber23,torepr24,$type$Boolean25,$type$Function26,$type$Number27,$type$String28);
}};
$e1178211783.stack[R.EXN_STACKHEIGHT++] = $ss1178611787;
}
if(R.isPyretException($e1178211783)) {
$e1178211783.pyretStack.push(L[904]);
}
throw $e1178211783;
}
var $ret1178811789 = $Hall_DASH_cmdline_DASH_params276757($z1178411785,D531,D640,List1959,Option2060,Param7461,ParamRepeat7262,ParamRepeatT47363,ParamT57564,ParseParam6865,ParseParamT26966,ParsedArguments7067,ParsedArgumentsT37168,RGB7669,RGBT67770,fold5571,format7872,is_DASH_empty2873,left8074,link3175,list2776,lists1134,right8177,some6478,_divide12,_plus13,_times14,builtins15,is_DASH_nothing16,not17,nothing18,string_DASH_char_DASH_at19,string_DASH_length20,string_DASH_split21,string_DASH_substring22,string_DASH_tonumber23,torepr24,$type$Boolean25,$type$Function26,$type$Number27,$type$String28);
++R.GAS;
return $ret1178811789;
},function(moduleVal) {
R.modules["$src/arr/trove/cmdline.arr47"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/filelib',["js/runtime-util", "fs", "js/ffi-helpers"], function(util, fs, ffiLib) {

  return util.memoModule("filelib", function(RUNTIME, NAMESPACE) {
    return RUNTIME.loadJSModules(NAMESPACE, [ffiLib], function(ffi) {
      
      function InputFile(name) {
        this.name = name;
      }

      function OutputFile(name, append) {
        this.name = name;
        this.append = append;
      }

      return RUNTIME.makeObject({
          provide: RUNTIME.makeObject({
              "open-input-file": RUNTIME.makeFunction(function(filename) {
                  ffi.checkArity(1, arguments, "open-input-file");
                  RUNTIME.checkString(filename);
                  var s = RUNTIME.unwrap(filename);
                  return RUNTIME.makeOpaque(new InputFile(s));
                }),
              "open-output-file": RUNTIME.makeFunction(function(filename, append) {
                  ffi.checkArity(2, arguments, "open-output-file");
                  RUNTIME.checkString(filename);
                  RUNTIME.checkBoolean(append);
                  var s = RUNTIME.unwrap(filename);
                  var b = RUNTIME.unwrap(append);
                  return RUNTIME.makeOpaque(new OutputFile(s, b));
                }),
              "read-file": RUNTIME.makeFunction(function(file) {
                  ffi.checkArity(1, arguments, "read-file");
                  RUNTIME.checkOpaque(file);
                  var v = file.val;
                  if(v instanceof InputFile) {
                    return RUNTIME.makeString(fs.readFileSync(v.name, {encoding: 'utf8'}));
                  }
                  else {
                    throw Error("Expected file in read-file, but got something else");
                  }
                }),
              "display": RUNTIME.makeFunction(function(file, val) {
                  ffi.checkArity(2, arguments, "display");
                  RUNTIME.checkOpaque(file);
                  RUNTIME.checkString(val);
                  var v = file.val;
                  var s = RUNTIME.unwrap(val);
                  if(v instanceof OutputFile) {
                    fs.writeFileSync(v.name, s, {encoding: 'utf8'});
                    return NAMESPACE.get('nothing');
                  }
                  else {
                    throw Error("Expected file in read-file, but got something else");
                  }
                }),
              "close-output-file": RUNTIME.makeFunction(function(file) { 
                  ffi.checkArity(1, arguments, "close-output-file");
                }),
              "close-input-file": RUNTIME.makeFunction(function(file) { 
                  ffi.checkArity(1, arguments, "close-input-file");
                })
            }),
          answer: NAMESPACE.get("nothing")
        });
    });
  });    
});


define('trove/file',["trove/filelib",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($F1922,$arrays31023,$lists51124,$option71225,$error91326,$sets111427) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/trove/file.arr21"]) {
return R.modules["$src/arr/trove/file.arr21"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/trove/file.arr";
var D = R.undefined;
var L = [[M,13,0,184,22,3,624],
[M,40,0,854,42,3,952],
[M,34,2,807,34,19,824],
[M,34,6,811,34,17,822],
[M,35,2,827,35,16,841],
[M,35,2,827,35,14,839],
[M,24,0,626,26,3,694],
[M,18,2,404,21,57,620],
[M,14,2,197,17,61,401],
[M,3,0,13,42,3,952],
[M,41,9,915,41,41,947],
[M,41,9,915,41,27,933],
[M,40,24,878,40,30,884],
[M,40,42,896,40,49,903],
[M,32,0,756,37,3,849],
[M,33,2,784,33,22,804],
[M,28,0,696,30,3,754],
[M,29,2,731,29,15,744],
[M,28,24,720,28,30,726],
[M,25,8,666,25,31,689],
[M,25,8,666,25,25,683],
[M,24,23,649,24,29,655],
[M,14,4,199,14,28,223],
[M,18,4,406,18,29,431],
[M,21,4,567,21,57,620],
[M,21,37,600,21,52,615],
[M,21,17,580,21,36,599],
[M,20,4,503,20,62,561],
[M,20,42,541,20,57,556],
[M,20,22,521,20,41,540],
[M,19,4,442,19,59,497],
[M,19,34,472,19,49,487],
[M,19,24,462,19,33,471],
[M,18,11,413,18,28,430],
[M,17,4,344,17,61,401],
[M,17,41,381,17,56,396],
[M,17,22,362,17,40,380],
[M,16,4,289,16,53,338],
[M,16,33,318,16,48,333],
[M,16,21,306,16,32,317],
[M,15,4,234,15,53,283],
[M,15,33,263,15,48,278],
[M,15,21,251,15,32,262],
[M,14,10,205,14,27,222]];
var _plus3 = NAMESPACE.get("_plus");
var builtins4 = NAMESPACE.get("builtins");
var nothing5 = NAMESPACE.get("nothing");
var torepr6 = NAMESPACE.get("torepr");
var $type$Boolean7 = NAMESPACE.get("$type$Boolean");
var $type$String8 = NAMESPACE.get("$type$String");
var $Hanf_bracket11628 = function(anf_bracket8529,File6230,provides8331,nothing5) {
var anf_fun8642 = G(anf_bracket8529,"results",L[0]);
var $z3435 = D;
var $f4041 = function(_) {
return R.isFunction(anf_fun8642)?anf_fun8642.app():R.ffi.throwNonFunApp(L[0],anf_fun8642,[]);
};
try {
if(--R.GAS > 0) {
$z3435 = $f4041();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4041,
"from":L[0]});
}
} catch($e3233) {
if(R.isCont($e3233)) {
var $ss3637 = {"from":L[0],
"go":function(checks8743) {
return $Hchecks11544(checks8743,File6230,provides8331,nothing5);
}};
$e3233.stack[R.EXN_STACKHEIGHT++] = $ss3637;
}
if(R.isPyretException($e3233)) {
$e3233.pyretStack.push(L[0]);
}
throw $e3233;
}
var $ret3839 = $Hchecks11544($z3435,File6230,provides8331,nothing5);
++R.GAS;
return $ret3839;
};
var $Hchecks11544 = function(checks8743,File6230,provides8331,nothing5) {
return R.makeObject({"answer":nothing5,
"provide-plus-types":R.makeObject({"values":provides8331,
"types":{"File":File6230}}),
"checks":checks8743});
};
var $Hanf_arg11445 = function(anf_arg8146,out_DASH_fd7047) {
var $z5051 = D;
var $f5657 = function(_) {
return R.isFunction(out_DASH_fd7047.$var)?out_DASH_fd7047.$var.app(anf_arg8146):R.ffi.throwNonFunApp(L[1],out_DASH_fd7047.$var,[anf_arg8146]);
};
try {
if(--R.GAS > 0) {
$z5051 = $f5657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5657,
"from":L[1]});
}
} catch($e4849) {
if(R.isCont($e4849)) {
var $ss5253 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp7958) {
return $Hann_DASH_check_DASH_temp11359(ann_DASH_check_DASH_temp7958);
}};
$e4849.stack[R.EXN_STACKHEIGHT++] = $ss5253;
}
if(R.isPyretException($e4849)) {
$e4849.pyretStack.push(L[1]);
}
throw $e4849;
}
var $ret5455 = $Hann_DASH_check_DASH_temp11359($z5051);
++R.GAS;
return $ret5455;
};
var $Hann_DASH_check_DASH_temp11359 = function(ann_DASH_check_DASH_temp7958) {
return ann_DASH_check_DASH_temp7958;
};
var $Hf11260 = function(f8761) {
var anf_fun7672 = G(f8761,"read-file",L[3]);
var $z6465 = D;
var $f7071 = function(_) {
return R.isFunction(anf_fun7672)?anf_fun7672.app():R.ffi.throwNonFunApp(L[2],anf_fun7672,[]);
};
try {
if(--R.GAS > 0) {
$z6465 = $f7071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7071,
"from":L[2]});
}
} catch($e6263) {
if(R.isCont($e6263)) {
var $ss6667 = {"from":L[2],
"go":function(s8873) {
return $Hs11174(s8873,f8761);
}};
$e6263.stack[R.EXN_STACKHEIGHT++] = $ss6667;
}
if(R.isPyretException($e6263)) {
$e6263.pyretStack.push(L[2]);
}
throw $e6263;
}
var $ret6869 = $Hs11174($z6465,f8761);
++R.GAS;
return $ret6869;
};
var $Hs11174 = function(s8873,f8761) {
var anf_fun7785 = G(f8761,"close-file",L[5]);
var $z7778 = D;
var $f8384 = function(_) {
return R.isFunction(anf_fun7785)?anf_fun7785.app():R.ffi.throwNonFunApp(L[4],anf_fun7785,[]);
};
try {
if(--R.GAS > 0) {
$z7778 = $f8384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8384,
"from":L[4]});
}
} catch($e7576) {
if(R.isCont($e7576)) {
var $ss7980 = {"from":L[4],
"go":function(anf_begin_app_dropped10986) {
return $Hanf_begin_app_dropped11087(anf_begin_app_dropped10986,s8873);
}};
$e7576.stack[R.EXN_STACKHEIGHT++] = $ss7980;
}
if(R.isPyretException($e7576)) {
$e7576.pyretStack.push(L[4]);
}
throw $e7576;
}
var $ret8182 = $Hanf_begin_app_dropped11087($z7778,s8873);
++R.GAS;
return $ret8182;
};
var $Hanf_begin_app_dropped11087 = function(anf_begin_app_dropped10986,s8873) {
var ann_DASH_check_DASH_temp7588 = s8873;
return ann_DASH_check_DASH_temp7588;
};
var $Hann_DASH_check_DASH_temp10889 = function(ann_DASH_check_DASH_temp7290) {
return ann_DASH_check_DASH_temp7290;
};
var $Hanf_arg10791 = function(anf_arg7092,in_DASH_fd6893) {
var $z9697 = D;
var $f102103 = function(_) {
return R.isFunction(in_DASH_fd6893.$var)?in_DASH_fd6893.$var.app(anf_arg7092):R.ffi.throwNonFunApp(L[6],in_DASH_fd6893.$var,[anf_arg7092]);
};
try {
if(--R.GAS > 0) {
$z9697 = $f102103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f102103,
"from":L[6]});
}
} catch($e9495) {
if(R.isCont($e9495)) {
var $ss9899 = {"from":L[6],
"go":function(ann_DASH_check_DASH_temp68104) {
return $Hann_DASH_check_DASH_temp106105(ann_DASH_check_DASH_temp68104);
}};
$e9495.stack[R.EXN_STACKHEIGHT++] = $ss9899;
}
if(R.isPyretException($e9495)) {
$e9495.pyretStack.push(L[6]);
}
throw $e9495;
}
var $ret100101 = $Hann_DASH_check_DASH_temp106105($z9697);
++R.GAS;
return $ret100101;
};
var $Hann_DASH_check_DASH_temp106105 = function(ann_DASH_check_DASH_temp68104) {
return ann_DASH_check_DASH_temp68104;
};
var $Hann_DASH_check_DASH_temp105106 = function(ann_DASH_check_DASH_temp57107) {
return ann_DASH_check_DASH_temp57107;
};
var $Hann_DASH_check_DASH_temp104108 = function(ann_DASH_check_DASH_temp53109) {
return ann_DASH_check_DASH_temp53109;
};
var $Hann_DASH_check_DASH_temp103110 = function(ann_DASH_check_DASH_temp49111) {
return ann_DASH_check_DASH_temp49111;
};
var $Hanf_arg102112 = function(anf_arg45113,_plus3) {
var $z116117 = D;
var $f122123 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg45113,(")")):R.ffi.throwNonFunApp(L[7],_plus3,[anf_arg45113,(")")]);
};
try {
if(--R.GAS > 0) {
$z116117 = $f122123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f122123,
"from":L[7]});
}
} catch($e114115) {
if(R.isCont($e114115)) {
var $ss118119 = {"from":L[7],
"go":function(anf_arg46124) {
return $Hanf_arg101125(anf_arg46124,_plus3);
}};
$e114115.stack[R.EXN_STACKHEIGHT++] = $ss118119;
}
if(R.isPyretException($e114115)) {
$e114115.pyretStack.push(L[7]);
}
throw $e114115;
}
var $ret120121 = $Hanf_arg101125($z116117,_plus3);
++R.GAS;
return $ret120121;
};
var $Hanf_arg101125 = function(anf_arg46124,_plus3) {
var $z128129 = D;
var $f134135 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("("),anf_arg46124):R.ffi.throwNonFunApp(L[7],_plus3,[("("),anf_arg46124]);
};
try {
if(--R.GAS > 0) {
$z128129 = $f134135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f134135,
"from":L[7]});
}
} catch($e126127) {
if(R.isCont($e126127)) {
var $ss130131 = {"from":L[7],
"go":function(anf_arg47136) {
return $Hanf_arg100137(anf_arg47136,_plus3);
}};
$e126127.stack[R.EXN_STACKHEIGHT++] = $ss130131;
}
if(R.isPyretException($e126127)) {
$e126127.pyretStack.push(L[7]);
}
throw $e126127;
}
var $ret132133 = $Hanf_arg100137($z128129,_plus3);
++R.GAS;
return $ret132133;
};
var $Hanf_arg100137 = function(anf_arg47136,_plus3) {
var $z140141 = D;
var $f146147 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("out-fd"),anf_arg47136):R.ffi.throwNonFunApp(L[7],_plus3,[("out-fd"),anf_arg47136]);
};
try {
if(--R.GAS > 0) {
$z140141 = $f146147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f146147,
"from":L[7]});
}
} catch($e138139) {
if(R.isCont($e138139)) {
var $ss142143 = {"from":L[7],
"go":function(ann_DASH_check_DASH_temp43148) {
return $Hann_DASH_check_DASH_temp99149(ann_DASH_check_DASH_temp43148);
}};
$e138139.stack[R.EXN_STACKHEIGHT++] = $ss142143;
}
if(R.isPyretException($e138139)) {
$e138139.pyretStack.push(L[7]);
}
throw $e138139;
}
var $ret144145 = $Hann_DASH_check_DASH_temp99149($z140141);
++R.GAS;
return $ret144145;
};
var $Hann_DASH_check_DASH_temp99149 = function(ann_DASH_check_DASH_temp43148) {
return ann_DASH_check_DASH_temp43148;
};
var $Hcont_tail_arg97150 = function(cont_tail_arg40151,if_helper32152) {
if(--R.GAS > 0) {
$z153154 = R.isFunction(if_helper32152)?if_helper32152.app(cont_tail_arg40151):R.ffi.throwNonFunApp(L[7],if_helper32152,[cont_tail_arg40151]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored155) {
return R.isFunction(if_helper32152)?if_helper32152.app(cont_tail_arg40151):R.ffi.throwNonFunApp(L[7],if_helper32152,[cont_tail_arg40151]);
},
"from":L[7]});
}
++R.GAS;
return $z153154;
};
var $Hcont_tail_arg98156 = function(cont_tail_arg37157,if_helper32152) {
if(--R.GAS > 0) {
$z158159 = R.isFunction(if_helper32152)?if_helper32152.app(cont_tail_arg37157):R.ffi.throwNonFunApp(L[7],if_helper32152,[cont_tail_arg37157]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored155) {
return R.isFunction(if_helper32152)?if_helper32152.app(cont_tail_arg37157):R.ffi.throwNonFunApp(L[7],if_helper32152,[cont_tail_arg37157]);
},
"from":L[7]});
}
++R.GAS;
return $z158159;
};
var $Hann_DASH_check_DASH_temp96160 = function(ann_DASH_check_DASH_temp27161) {
return ann_DASH_check_DASH_temp27161;
};
var $Hann_DASH_check_DASH_temp95162 = function(ann_DASH_check_DASH_temp23163) {
return ann_DASH_check_DASH_temp23163;
};
var $Hann_DASH_check_DASH_temp94164 = function(ann_DASH_check_DASH_temp19165) {
return ann_DASH_check_DASH_temp19165;
};
var $Hanf_arg93166 = function(anf_arg15167,_plus3) {
var $z170171 = D;
var $f176177 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg15167,(")")):R.ffi.throwNonFunApp(L[8],_plus3,[anf_arg15167,(")")]);
};
try {
if(--R.GAS > 0) {
$z170171 = $f176177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f176177,
"from":L[8]});
}
} catch($e168169) {
if(R.isCont($e168169)) {
var $ss172173 = {"from":L[8],
"go":function(anf_arg16178) {
return $Hanf_arg92179(anf_arg16178,_plus3);
}};
$e168169.stack[R.EXN_STACKHEIGHT++] = $ss172173;
}
if(R.isPyretException($e168169)) {
$e168169.pyretStack.push(L[8]);
}
throw $e168169;
}
var $ret174175 = $Hanf_arg92179($z170171,_plus3);
++R.GAS;
return $ret174175;
};
var $Hanf_arg92179 = function(anf_arg16178,_plus3) {
var $z182183 = D;
var $f188189 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("("),anf_arg16178):R.ffi.throwNonFunApp(L[8],_plus3,[("("),anf_arg16178]);
};
try {
if(--R.GAS > 0) {
$z182183 = $f188189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f188189,
"from":L[8]});
}
} catch($e180181) {
if(R.isCont($e180181)) {
var $ss184185 = {"from":L[8],
"go":function(anf_arg17190) {
return $Hanf_arg91191(anf_arg17190,_plus3);
}};
$e180181.stack[R.EXN_STACKHEIGHT++] = $ss184185;
}
if(R.isPyretException($e180181)) {
$e180181.pyretStack.push(L[8]);
}
throw $e180181;
}
var $ret186187 = $Hanf_arg91191($z182183,_plus3);
++R.GAS;
return $ret186187;
};
var $Hanf_arg91191 = function(anf_arg17190,_plus3) {
var $z194195 = D;
var $f200201 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("in-fd"),anf_arg17190):R.ffi.throwNonFunApp(L[8],_plus3,[("in-fd"),anf_arg17190]);
};
try {
if(--R.GAS > 0) {
$z194195 = $f200201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f200201,
"from":L[8]});
}
} catch($e192193) {
if(R.isCont($e192193)) {
var $ss196197 = {"from":L[8],
"go":function(ann_DASH_check_DASH_temp13202) {
return $Hann_DASH_check_DASH_temp90203(ann_DASH_check_DASH_temp13202);
}};
$e192193.stack[R.EXN_STACKHEIGHT++] = $ss196197;
}
if(R.isPyretException($e192193)) {
$e192193.pyretStack.push(L[8]);
}
throw $e192193;
}
var $ret198199 = $Hann_DASH_check_DASH_temp90203($z194195);
++R.GAS;
return $ret198199;
};
var $Hann_DASH_check_DASH_temp90203 = function(ann_DASH_check_DASH_temp13202) {
return ann_DASH_check_DASH_temp13202;
};
var $Hcont_tail_arg88204 = function(cont_tail_arg10205,if_helper2206) {
if(--R.GAS > 0) {
$z207208 = R.isFunction(if_helper2206)?if_helper2206.app(cont_tail_arg10205):R.ffi.throwNonFunApp(L[8],if_helper2206,[cont_tail_arg10205]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored155) {
return R.isFunction(if_helper2206)?if_helper2206.app(cont_tail_arg10205):R.ffi.throwNonFunApp(L[8],if_helper2206,[cont_tail_arg10205]);
},
"from":L[8]});
}
++R.GAS;
return $z207208;
};
var $Hcont_tail_arg89209 = function(cont_tail_arg7210,if_helper2206) {
if(--R.GAS > 0) {
$z211212 = R.isFunction(if_helper2206)?if_helper2206.app(cont_tail_arg7210):R.ffi.throwNonFunApp(L[8],if_helper2206,[cont_tail_arg7210]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored155) {
return R.isFunction(if_helper2206)?if_helper2206.app(cont_tail_arg7210):R.ffi.throwNonFunApp(L[8],if_helper2206,[cont_tail_arg7210]);
},
"from":L[8]});
}
++R.GAS;
return $z211212;
};
return R.loadModulesNew(NAMESPACE,[$F1922,$arrays31023,$lists51124,$option71225,$error91326,$sets111427],function($F1922,$arrays31023,$lists51124,$option71225,$error91326,$sets111427) {
var F19 = R.getField($F1922,"values");
var arrays310 = R.getField($arrays31023,"values");
var lists511 = R.getField($lists51124,"values");
var option712 = R.getField($option71225,"values");
var error913 = R.getField($error91326,"values");
var sets1114 = R.getField($sets111427,"values");
var F215 = R.getField($F1922,"types");
var arrays416 = R.getField($arrays31023,"types");
var lists617 = R.getField($lists51124,"types");
var option818 = R.getField($option71225,"types");
var error1019 = R.getField($error91326,"types");
var sets1220 = R.getField($sets111427,"types");
return R.safeCall(function() {
var List13213 = R.getDotAnn(L[9],"lists",lists617,"List");
var Option14214 = R.getDotAnn(L[9],"option",option818,"Option");
var Array15215 = R.getDotAnn(L[9],"arrays",arrays416,"Array");
var Set16216 = R.getDotAnn(L[9],"sets",sets1220,"Set");
var array17530 = G(arrays310,"array",L[9]);
var build_DASH_array18529 = G(arrays310,"build-array",L[9]);
var array_DASH_from_DASH_list19528 = G(arrays310,"array-from-list",L[9]);
var is_DASH_array20527 = G(arrays310,"is-array",L[9]);
var list21526 = G(lists511,"list",L[9]);
var is_DASH_empty22525 = G(lists511,"is-empty",L[9]);
var is_DASH_link23524 = G(lists511,"is-link",L[9]);
var empty24523 = G(lists511,"empty",L[9]);
var link25522 = G(lists511,"link",L[9]);
var range26521 = G(lists511,"range",L[9]);
var repeat27520 = G(lists511,"repeat",L[9]);
var filter28519 = G(lists511,"filter",L[9]);
var partition29518 = G(lists511,"partition",L[9]);
var split_DASH_at30517 = G(lists511,"split-at",L[9]);
var any31516 = G(lists511,"any",L[9]);
var find32515 = G(lists511,"find",L[9]);
var map33514 = G(lists511,"map",L[9]);
var map234513 = G(lists511,"map2",L[9]);
var map335512 = G(lists511,"map3",L[9]);
var map436511 = G(lists511,"map4",L[9]);
var map_n37510 = G(lists511,"map_n",L[9]);
var map2_n38509 = G(lists511,"map2_n",L[9]);
var map3_n39508 = G(lists511,"map3_n",L[9]);
var map4_n40507 = G(lists511,"map4_n",L[9]);
var each41506 = G(lists511,"each",L[9]);
var each242505 = G(lists511,"each2",L[9]);
var each343504 = G(lists511,"each3",L[9]);
var each444503 = G(lists511,"each4",L[9]);
var each_n45502 = G(lists511,"each_n",L[9]);
var each2_n46501 = G(lists511,"each2_n",L[9]);
var each3_n47500 = G(lists511,"each3_n",L[9]);
var each4_n48499 = G(lists511,"each4_n",L[9]);
var fold49498 = G(lists511,"fold",L[9]);
var fold250497 = G(lists511,"fold2",L[9]);
var fold351496 = G(lists511,"fold3",L[9]);
var fold452495 = G(lists511,"fold4",L[9]);
var index53494 = G(lists511,"index",L[9]);
var Option54493 = G(option712,"Option",L[9]);
var is_DASH_none55492 = G(option712,"is-none",L[9]);
var is_DASH_some56491 = G(option712,"is-some",L[9]);
var none57490 = G(option712,"none",L[9]);
var some58489 = G(option712,"some",L[9]);
var set59488 = G(sets1114,"set",L[9]);
var tree_DASH_set60487 = G(sets1114,"tree-set",L[9]);
var list_DASH_set61486 = G(sets1114,"list-set",L[9]);
var FileT163217 = R.namedBrander("File");
var File6230 = R.makeBranderAnn(FileT163217,"File");
var File264218 = {"$var":D,
"$name":"File2"};
var File65220 = {"$var":D,
"$name":"File"};
var is_DASH_File66222 = {"$var":D,
"$name":"is-File"};
var is_DASH_in_DASH_fd67224 = {"$var":D,
"$name":"is-in-fd"};
var in_DASH_fd6893 = {"$var":D,
"$name":"in-fd"};
var is_DASH_out_DASH_fd69227 = {"$var":D,
"$name":"is-out-fd"};
var out_DASH_fd7047 = {"$var":D,
"$name":"out-fd"};
var input_DASH_file71230 = {"$var":D,
"$name":"input-file"};
var file_DASH_exists72232 = {"$var":D,
"$name":"file-exists"};
var file_DASH_to_DASH_string73234 = {"$var":D,
"$name":"file-to-string"};
var output_DASH_file74236 = {"$var":D,
"$name":"output-file"};
var anf_variant_member12302 = R.makeMethod(function(self2466) {
return function(cases_DASH_funs3467,else_DASH_clause4478) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[8],2,arguments);
}
var if_DASH_6479 = R.hasField(cases_DASH_funs3467,("in-fd"));
var if_helper2206 = R.makeFunction(function(if_helper_arg3484) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
var ann_DASH_check_DASH_temp1485 = if_helper_arg3484;
return ann_DASH_check_DASH_temp1485;
});
var anf_if6483 = R.isBoolean(if_DASH_6479);
if(R.isPyretTrue(anf_if6483)) {
if(R.isPyretTrue(if_DASH_6479)) {
var call_DASH_in_DASH_fd1464 = G(cases_DASH_funs3467,"in-fd",L[8]);
var anf_arg9465 = G(self2466,"inner-file",L[43]);
var $z456457 = D;
var $f462463 = function(_) {
return R.isFunction(call_DASH_in_DASH_fd1464)?call_DASH_in_DASH_fd1464.app(anf_arg9465):R.ffi.throwNonFunApp(L[8],call_DASH_in_DASH_fd1464,[anf_arg9465]);
};
try {
if(--R.GAS > 0) {
$z456457 = $f462463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f462463,
"from":L[8]});
}
} catch($e454455) {
if(R.isCont($e454455)) {
var $ss458459 = {"from":L[8],
"go":function(cont_tail_arg10205) {
return $Hcont_tail_arg88204(cont_tail_arg10205,if_helper2206);
}};
$e454455.stack[R.EXN_STACKHEIGHT++] = $ss458459;
}
if(R.isPyretException($e454455)) {
$e454455.pyretStack.push(L[8]);
}
throw $e454455;
}
var $ret460461 = $Hcont_tail_arg88204($z456457,if_helper2206);
++R.GAS;
return $ret460461;
} else {
var $z470471 = D;
var $f476477 = function(_) {
return R.isFunction(else_DASH_clause4478)?else_DASH_clause4478.app():R.ffi.throwNonFunApp(L[8],else_DASH_clause4478,[]);
};
try {
if(--R.GAS > 0) {
$z470471 = $f476477();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f476477,
"from":L[8]});
}
} catch($e468469) {
if(R.isCont($e468469)) {
var $ss472473 = {"from":L[8],
"go":function(cont_tail_arg7210) {
return $Hcont_tail_arg89209(cont_tail_arg7210,if_helper2206);
}};
$e468469.stack[R.EXN_STACKHEIGHT++] = $ss472473;
}
if(R.isPyretException($e468469)) {
$e468469.pyretStack.push(L[8]);
}
throw $e468469;
}
var $ret474475 = $Hcont_tail_arg89209($z470471,if_helper2206);
++R.GAS;
return $ret474475;
}
} else {
var cont_tail_arg4482 = R.throwNonBooleanCondition(L[8],("if"),if_DASH_6479);
if(--R.GAS > 0) {
$z480481 = R.isFunction(if_helper2206)?if_helper2206.app(cont_tail_arg4482):R.ffi.throwNonFunApp(L[8],if_helper2206,[cont_tail_arg4482]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored155) {
return R.isFunction(if_helper2206)?if_helper2206.app(cont_tail_arg4482):R.ffi.throwNonFunApp(L[8],if_helper2206,[cont_tail_arg4482]);
},
"from":L[8]});
}
++R.GAS;
return $z480481;
}
};
},{"length":3});
var anf_variant_member18303 = R.makeMethod(function(self5453) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[8],0,arguments);
}
var anf_arg14452 = G(self5453,"inner-file",L[8]);
var $z444445 = D;
var $f450451 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg14452):R.ffi.throwNonFunApp(L[8],torepr6,[anf_arg14452]);
};
try {
if(--R.GAS > 0) {
$z444445 = $f450451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f450451,
"from":L[8]});
}
} catch($e442443) {
if(R.isCont($e442443)) {
var $ss446447 = {"from":L[8],
"go":function(anf_arg15167) {
return $Hanf_arg93166(anf_arg15167,_plus3);
}};
$e442443.stack[R.EXN_STACKHEIGHT++] = $ss446447;
}
if(R.isPyretException($e442443)) {
$e442443.pyretStack.push(L[8]);
}
throw $e442443;
}
var $ret448449 = $Hanf_arg93166($z444445,_plus3);
++R.GAS;
return $ret448449;
};
},{"length":1});
var anf_variant_member22304 = R.makeMethod(function(self76441) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[40],0,arguments);
}
var anf_fun20439 = G(F19,"read-line",L[42]);
var anf_arg21440 = G(self76441,"inner-file",L[41]);
var $z431432 = D;
var $f437438 = function(_) {
return R.isFunction(anf_fun20439)?anf_fun20439.app(anf_arg21440):R.ffi.throwNonFunApp(L[40],anf_fun20439,[anf_arg21440]);
};
try {
if(--R.GAS > 0) {
$z431432 = $f437438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f437438,
"from":L[40]});
}
} catch($e429430) {
if(R.isCont($e429430)) {
var $ss433434 = {"from":L[40],
"go":function(ann_DASH_check_DASH_temp19165) {
return $Hann_DASH_check_DASH_temp94164(ann_DASH_check_DASH_temp19165);
}};
$e429430.stack[R.EXN_STACKHEIGHT++] = $ss433434;
}
if(R.isPyretException($e429430)) {
$e429430.pyretStack.push(L[40]);
}
throw $e429430;
}
var $ret435436 = $Hann_DASH_check_DASH_temp94164($z431432);
++R.GAS;
return $ret435436;
};
},{"length":1});
var anf_variant_member26305 = R.makeMethod(function(self77428) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[37],0,arguments);
}
var anf_fun24426 = G(F19,"read-file",L[39]);
var anf_arg25427 = G(self77428,"inner-file",L[38]);
var $z418419 = D;
var $f424425 = function(_) {
return R.isFunction(anf_fun24426)?anf_fun24426.app(anf_arg25427):R.ffi.throwNonFunApp(L[37],anf_fun24426,[anf_arg25427]);
};
try {
if(--R.GAS > 0) {
$z418419 = $f424425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f424425,
"from":L[37]});
}
} catch($e416417) {
if(R.isCont($e416417)) {
var $ss420421 = {"from":L[37],
"go":function(ann_DASH_check_DASH_temp23163) {
return $Hann_DASH_check_DASH_temp95162(ann_DASH_check_DASH_temp23163);
}};
$e416417.stack[R.EXN_STACKHEIGHT++] = $ss420421;
}
if(R.isPyretException($e416417)) {
$e416417.pyretStack.push(L[37]);
}
throw $e416417;
}
var $ret422423 = $Hann_DASH_check_DASH_temp95162($z418419);
++R.GAS;
return $ret422423;
};
},{"length":1});
var anf_variant_member30306 = R.makeMethod(function(self78415) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[34],0,arguments);
}
var anf_fun28413 = G(F19,"close-input-file",L[36]);
var anf_arg29414 = G(self78415,"inner-file",L[35]);
var $z405406 = D;
var $f411412 = function(_) {
return R.isFunction(anf_fun28413)?anf_fun28413.app(anf_arg29414):R.ffi.throwNonFunApp(L[34],anf_fun28413,[anf_arg29414]);
};
try {
if(--R.GAS > 0) {
$z405406 = $f411412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f411412,
"from":L[34]});
}
} catch($e403404) {
if(R.isCont($e403404)) {
var $ss407408 = {"from":L[34],
"go":function(ann_DASH_check_DASH_temp27161) {
return $Hann_DASH_check_DASH_temp96160(ann_DASH_check_DASH_temp27161);
}};
$e403404.stack[R.EXN_STACKHEIGHT++] = $ss407408;
}
if(R.isPyretException($e403404)) {
$e403404.pyretStack.push(L[34]);
}
throw $e403404;
}
var $ret409410 = $Hann_DASH_check_DASH_temp96160($z405406);
++R.GAS;
return $ret409410;
};
},{"length":1});
var anf_variant_member42313 = R.makeMethod(function(self8383) {
return function(cases_DASH_funs9384,else_DASH_clause10395) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[7],2,arguments);
}
var if_DASH_12396 = R.hasField(cases_DASH_funs9384,("out-fd"));
var if_helper32152 = R.makeFunction(function(if_helper_arg33401) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
var ann_DASH_check_DASH_temp31402 = if_helper_arg33401;
return ann_DASH_check_DASH_temp31402;
});
var anf_if36400 = R.isBoolean(if_DASH_12396);
if(R.isPyretTrue(anf_if36400)) {
if(R.isPyretTrue(if_DASH_12396)) {
var call_DASH_out_DASH_fd7381 = G(cases_DASH_funs9384,"out-fd",L[7]);
var anf_arg39382 = G(self8383,"inner-file",L[33]);
var $z373374 = D;
var $f379380 = function(_) {
return R.isFunction(call_DASH_out_DASH_fd7381)?call_DASH_out_DASH_fd7381.app(anf_arg39382):R.ffi.throwNonFunApp(L[7],call_DASH_out_DASH_fd7381,[anf_arg39382]);
};
try {
if(--R.GAS > 0) {
$z373374 = $f379380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f379380,
"from":L[7]});
}
} catch($e371372) {
if(R.isCont($e371372)) {
var $ss375376 = {"from":L[7],
"go":function(cont_tail_arg40151) {
return $Hcont_tail_arg97150(cont_tail_arg40151,if_helper32152);
}};
$e371372.stack[R.EXN_STACKHEIGHT++] = $ss375376;
}
if(R.isPyretException($e371372)) {
$e371372.pyretStack.push(L[7]);
}
throw $e371372;
}
var $ret377378 = $Hcont_tail_arg97150($z373374,if_helper32152);
++R.GAS;
return $ret377378;
} else {
var $z387388 = D;
var $f393394 = function(_) {
return R.isFunction(else_DASH_clause10395)?else_DASH_clause10395.app():R.ffi.throwNonFunApp(L[7],else_DASH_clause10395,[]);
};
try {
if(--R.GAS > 0) {
$z387388 = $f393394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f393394,
"from":L[7]});
}
} catch($e385386) {
if(R.isCont($e385386)) {
var $ss389390 = {"from":L[7],
"go":function(cont_tail_arg37157) {
return $Hcont_tail_arg98156(cont_tail_arg37157,if_helper32152);
}};
$e385386.stack[R.EXN_STACKHEIGHT++] = $ss389390;
}
if(R.isPyretException($e385386)) {
$e385386.pyretStack.push(L[7]);
}
throw $e385386;
}
var $ret391392 = $Hcont_tail_arg98156($z387388,if_helper32152);
++R.GAS;
return $ret391392;
}
} else {
var cont_tail_arg34399 = R.throwNonBooleanCondition(L[7],("if"),if_DASH_12396);
if(--R.GAS > 0) {
$z397398 = R.isFunction(if_helper32152)?if_helper32152.app(cont_tail_arg34399):R.ffi.throwNonFunApp(L[7],if_helper32152,[cont_tail_arg34399]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored155) {
return R.isFunction(if_helper32152)?if_helper32152.app(cont_tail_arg34399):R.ffi.throwNonFunApp(L[7],if_helper32152,[cont_tail_arg34399]);
},
"from":L[7]});
}
++R.GAS;
return $z397398;
}
};
},{"length":3});
var anf_variant_member48314 = R.makeMethod(function(self11370) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[7],0,arguments);
}
var anf_arg44369 = G(self11370,"inner-file",L[7]);
var $z361362 = D;
var $f367368 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg44369):R.ffi.throwNonFunApp(L[7],torepr6,[anf_arg44369]);
};
try {
if(--R.GAS > 0) {
$z361362 = $f367368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f367368,
"from":L[7]});
}
} catch($e359360) {
if(R.isCont($e359360)) {
var $ss363364 = {"from":L[7],
"go":function(anf_arg45113) {
return $Hanf_arg102112(anf_arg45113,_plus3);
}};
$e359360.stack[R.EXN_STACKHEIGHT++] = $ss363364;
}
if(R.isPyretException($e359360)) {
$e359360.pyretStack.push(L[7]);
}
throw $e359360;
}
var $ret365366 = $Hanf_arg102112($z361362,_plus3);
++R.GAS;
return $ret365366;
};
},{"length":1});
var anf_variant_member52315 = R.makeMethod(function(self80358) {
return function(val81357) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
var anf_fun50355 = G(F19,"display",L[32]);
var anf_arg51356 = G(self80358,"inner-file",L[31]);
var $z347348 = D;
var $f353354 = function(_) {
return R.isFunction(anf_fun50355)?anf_fun50355.app(anf_arg51356,val81357):R.ffi.throwNonFunApp(L[30],anf_fun50355,[anf_arg51356,val81357]);
};
try {
if(--R.GAS > 0) {
$z347348 = $f353354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f353354,
"from":L[30]});
}
} catch($e345346) {
if(R.isCont($e345346)) {
var $ss349350 = {"from":L[30],
"go":function(ann_DASH_check_DASH_temp49111) {
return $Hann_DASH_check_DASH_temp103110(ann_DASH_check_DASH_temp49111);
}};
$e345346.stack[R.EXN_STACKHEIGHT++] = $ss349350;
}
if(R.isPyretException($e345346)) {
$e345346.pyretStack.push(L[30]);
}
throw $e345346;
}
var $ret351352 = $Hann_DASH_check_DASH_temp103110($z347348);
++R.GAS;
return $ret351352;
};
},{"length":2});
var anf_variant_member56316 = R.makeMethod(function(self82344) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[27],0,arguments);
}
var anf_fun54342 = G(F19,"close-output-file",L[29]);
var anf_arg55343 = G(self82344,"inner-file",L[28]);
var $z334335 = D;
var $f340341 = function(_) {
return R.isFunction(anf_fun54342)?anf_fun54342.app(anf_arg55343):R.ffi.throwNonFunApp(L[27],anf_fun54342,[anf_arg55343]);
};
try {
if(--R.GAS > 0) {
$z334335 = $f340341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f340341,
"from":L[27]});
}
} catch($e332333) {
if(R.isCont($e332333)) {
var $ss336337 = {"from":L[27],
"go":function(ann_DASH_check_DASH_temp53109) {
return $Hann_DASH_check_DASH_temp104108(ann_DASH_check_DASH_temp53109);
}};
$e332333.stack[R.EXN_STACKHEIGHT++] = $ss336337;
}
if(R.isPyretException($e332333)) {
$e332333.pyretStack.push(L[27]);
}
throw $e332333;
}
var $ret338339 = $Hann_DASH_check_DASH_temp104108($z334335);
++R.GAS;
return $ret338339;
};
},{"length":1});
var anf_variant_member60317 = R.makeMethod(function(self83331) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[24],0,arguments);
}
var anf_fun58329 = G(F19,"flush-output-file",L[26]);
var anf_arg59330 = G(self83331,"inner-file",L[25]);
var $z321322 = D;
var $f327328 = function(_) {
return R.isFunction(anf_fun58329)?anf_fun58329.app(anf_arg59330):R.ffi.throwNonFunApp(L[24],anf_fun58329,[anf_arg59330]);
};
try {
if(--R.GAS > 0) {
$z321322 = $f327328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f327328,
"from":L[24]});
}
} catch($e319320) {
if(R.isCont($e319320)) {
var $ss323324 = {"from":L[24],
"go":function(ann_DASH_check_DASH_temp57107) {
return $Hann_DASH_check_DASH_temp105106(ann_DASH_check_DASH_temp57107);
}};
$e319320.stack[R.EXN_STACKHEIGHT++] = $ss323324;
}
if(R.isPyretException($e319320)) {
$e319320.pyretStack.push(L[24]);
}
throw $e319320;
}
var $ret325326 = $Hann_DASH_check_DASH_temp105106($z321322);
++R.GAS;
return $ret325326;
};
},{"length":1});
var anf_assign61219 = (function() {
var $in_DASH_fd_DASH_base297298 = {"_match":anf_variant_member12302,
"_torepr":anf_variant_member18303,
"read-line":anf_variant_member22304,
"read-file":anf_variant_member26305,
"close-file":anf_variant_member30306};
var $in_DASH_fd_DASH_brands300301 = {"$brand-in-fd299":true};
$in_DASH_fd_DASH_brands300301[FileT163217._brand] = true
var $out_DASH_fd_DASH_base308309 = {"_match":anf_variant_member42313,
"_torepr":anf_variant_member48314,
"display":anf_variant_member52315,
"close-file":anf_variant_member56316,
"flush":anf_variant_member60317};
var $out_DASH_fd_DASH_brands311312 = {"$brand-out-fd310":true};
$out_DASH_fd_DASH_brands311312[FileT163217._brand] = true
return R.makeObject({"File":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,FileT163217._brand));
}),
"is-in-fd":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-in-fd299"));
}),
"in-fd":R.makeFunction(function(inner_DASH_file75307) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
var dict = R.create($in_DASH_fd_DASH_base297298);
dict["inner-file"] = inner_DASH_file75307
return R.makeBrandedObject(dict,$in_DASH_fd_DASH_brands300301);
}),
"is-out-fd":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-out-fd310"));
}),
"out-fd":R.makeFunction(function(inner_DASH_file79318) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
var dict = R.create($out_DASH_fd_DASH_base308309);
dict["inner-file"] = inner_DASH_file79318
return R.makeBrandedObject(dict,$out_DASH_fd_DASH_brands311312);
})});
})();
File264218.$var = anf_assign61219;
var anf_assign62221 = G(File264218.$var,"File",L[0]);
File65220.$var = anf_assign62221;
var anf_assign63223 = G(File264218.$var,"File",L[0]);
is_DASH_File66222.$var = anf_assign63223;
var anf_assign64225 = G(File264218.$var,"is-in-fd",L[8]);
is_DASH_in_DASH_fd67224.$var = anf_assign64225;
var anf_assign65226 = G(File264218.$var,"in-fd",L[8]);
in_DASH_fd6893.$var = anf_assign65226;
var anf_assign66228 = G(File264218.$var,"is-out-fd",L[7]);
is_DASH_out_DASH_fd69227.$var = anf_assign66228;
var anf_assign67229 = G(File264218.$var,"out-fd",L[7]);
out_DASH_fd7047.$var = anf_assign67229;
var anf_assign71231 = R.makeFunction(function(path84285) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
return R.checkAnnArgs([$type$String8],[path84285],[L[21]],function() {
var anf_fun69296 = G(F19,"open-input-file",L[20]);
var $z288289 = D;
var $f294295 = function(_) {
return R.isFunction(anf_fun69296)?anf_fun69296.app(path84285):R.ffi.throwNonFunApp(L[19],anf_fun69296,[path84285]);
};
try {
if(--R.GAS > 0) {
$z288289 = $f294295();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f294295,
"from":L[19]});
}
} catch($e286287) {
if(R.isCont($e286287)) {
var $ss290291 = {"from":L[19],
"go":function(anf_arg7092) {
return $Hanf_arg10791(anf_arg7092,in_DASH_fd6893);
}};
$e286287.stack[R.EXN_STACKHEIGHT++] = $ss290291;
}
if(R.isPyretException($e286287)) {
$e286287.pyretStack.push(L[19]);
}
throw $e286287;
}
var $ret292293 = $Hanf_arg10791($z288289,in_DASH_fd6893);
++R.GAS;
return $ret292293;
});
});
input_DASH_file71230.$var = anf_assign71231;
var anf_assign74233 = R.makeFunction(function(path85273) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[16],1,arguments);
}
return R.checkAnnArgs([$type$String8],[path85273],[L[18]],function() {
var anf_fun73284 = G(F19,"file-exists",L[17]);
var $z276277 = D;
var $f282283 = function(_) {
return R.isFunction(anf_fun73284)?anf_fun73284.app(path85273):R.ffi.throwNonFunApp(L[16],anf_fun73284,[path85273]);
};
try {
if(--R.GAS > 0) {
$z276277 = $f282283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f282283,
"from":L[16]});
}
} catch($e274275) {
if(R.isCont($e274275)) {
var $ss278279 = {"from":L[16],
"go":function(ann_DASH_check_DASH_temp7290) {
return $Hann_DASH_check_DASH_temp10889(ann_DASH_check_DASH_temp7290);
}};
$e274275.stack[R.EXN_STACKHEIGHT++] = $ss278279;
}
if(R.isPyretException($e274275)) {
$e274275.pyretStack.push(L[16]);
}
throw $e274275;
}
var $ret280281 = $Hann_DASH_check_DASH_temp10889($z276277);
++R.GAS;
return $ret280281;
});
});
file_DASH_exists72232.$var = anf_assign74233;
var anf_assign78235 = R.makeFunction(function(path86262) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[14],1,arguments);
}
var $z265266 = D;
var $f271272 = function(_) {
return R.isFunction(input_DASH_file71230.$var)?input_DASH_file71230.$var.app(path86262):R.ffi.throwNonFunApp(L[15],input_DASH_file71230.$var,[path86262]);
};
try {
if(--R.GAS > 0) {
$z265266 = $f271272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f271272,
"from":L[15]});
}
} catch($e263264) {
if(R.isCont($e263264)) {
var $ss267268 = {"from":L[15],
"go":function(f8761) {
return $Hf11260(f8761);
}};
$e263264.stack[R.EXN_STACKHEIGHT++] = $ss267268;
}
if(R.isPyretException($e263264)) {
$e263264.pyretStack.push(L[15]);
}
throw $e263264;
}
var $ret269270 = $Hf11260($z265266);
++R.GAS;
return $ret269270;
});
file_DASH_to_DASH_string73234.$var = anf_assign78235;
var anf_assign82237 = R.makeFunction(function(path89249,append90250) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
return R.checkAnnArgs([$type$String8,$type$Boolean7],[path89249,append90250],[L[12],L[13]],function() {
var anf_fun80261 = G(F19,"open-output-file",L[11]);
var $z253254 = D;
var $f259260 = function(_) {
return R.isFunction(anf_fun80261)?anf_fun80261.app(path89249,append90250):R.ffi.throwNonFunApp(L[10],anf_fun80261,[path89249,append90250]);
};
try {
if(--R.GAS > 0) {
$z253254 = $f259260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f259260,
"from":L[10]});
}
} catch($e251252) {
if(R.isCont($e251252)) {
var $ss255256 = {"from":L[10],
"go":function(anf_arg8146) {
return $Hanf_arg11445(anf_arg8146,out_DASH_fd7047);
}};
$e251252.stack[R.EXN_STACKHEIGHT++] = $ss255256;
}
if(R.isPyretException($e251252)) {
$e251252.pyretStack.push(L[10]);
}
throw $e251252;
}
var $ret257258 = $Hanf_arg11445($z253254,out_DASH_fd7047);
++R.GAS;
return $ret257258;
});
});
output_DASH_file74236.$var = anf_assign82237;
var provides8331 = R.makeObject({"input-file":input_DASH_file71230.$var,
"output-file":output_DASH_file74236.$var,
"file-exists":file_DASH_exists72232.$var,
"file-to-string":file_DASH_to_DASH_string73234.$var});
var anf_fun84248 = G(builtins4,"current-checker",L[0]);
var $z240241 = D;
var $f246247 = function(_) {
return R.isFunction(anf_fun84248)?anf_fun84248.app():R.ffi.throwNonFunApp(L[0],anf_fun84248,[]);
};
try {
if(--R.GAS > 0) {
$z240241 = $f246247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f246247,
"from":L[0]});
}
} catch($e238239) {
if(R.isCont($e238239)) {
var $ss242243 = {"from":L[0],
"go":function(anf_bracket8529) {
return $Hanf_bracket11628(anf_bracket8529,File6230,provides8331,nothing5);
}};
$e238239.stack[R.EXN_STACKHEIGHT++] = $ss242243;
}
if(R.isPyretException($e238239)) {
$e238239.pyretStack.push(L[0]);
}
throw $e238239;
}
var $ret244245 = $Hanf_bracket11628($z240241,File6230,provides8331,nothing5);
++R.GAS;
return $ret244245;
},function(moduleVal) {
R.modules["$src/arr/trove/file.arr21"] = moduleVal
return moduleVal;
});
});
}
};
});
define('js/secure-loader',["require", "q"], function(rjs, Q) {
  var ourCajaVM;
  function unsafeCaja() {
    var compileExpr = function(src) {
      return function(env) {
        var define = env.define;
        Function("define", src)(define);
      }
    };
    ourCajaVM = { compileExpr: compileExpr };
  }
  if(requirejs.isBrowser) {
    // caja.js had better be on the page already
    if(typeof caja === "undefined") {
      console.warn("Page was loaded without SES, so evals will be unguarded. Does this page load https://caja.appspot.com/caja.js?");
      unsafeCaja();
    }
    else {
      caja.initialize({
        debug: true,
        forceES5Mode: true
      });
      caja.load(undefined, undefined, function(frame) {
        ourCajaVM = {
          compileExpr: function(s) {
            return function(env) { frame.code("https://", "application/javascript", s).api(env).run(); }
          }
        };
      });
    }
  }
  else {
    var FS = require("fs");
    var VM = require("vm");

    var RUN_SES = false; // NOTE(joe): skipping on servers for now; SES isn't really there yet
    if(RUN_SES) {
      var source = FS.readFileSync(require.nodeRequire.resolve("ses/initSES.js"));
      var oldLog = console.log;
      console.log = function() { /* intentional no-op to suppress SES logging */ }
      var script = new VM.Script(source);
      script.runInThisContext();
      ourCajaVM = cajaVM;
      console.log = oldLog;
    } else {
      unsafeCaja();
    }
  }

  function safeEval(string, env) {
    var f = ourCajaVM.compileExpr(string);
    f(env);
  }

  function goodIdea(runtime, name, src) {
    var deferred = Q.defer();
    safeEval(src, { define: function(deps, body) {
        define(name, deps, body);
        function success(val) {
          deferred.resolve(val);
        }
        // Since requirejs seems to not call our errback, use its global
        // error handler.
        var oldOnError = require.onError;
        require.onError = function(err) {
          require.onError = oldOnError;
          var names = [];
          for(var i = 0; i < err.requireModules.length; i++) {
            require.undef(err.requireModules[i]);
            names.push(err.requireModules[i]);
          }
          deferred.reject(runtime.makePyretFailException(runtime.ffi.makeModuleLoadFailureL(names)));
        };
        require([name], success);
      }
    });
    return deferred.promise;
  }

  return {
    safeEval: safeEval,
    goodIdea: goodIdea
  }
});

define('trove/checker',["trove/srcloc",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($SL11427,$arrays31528,$lists51629,$option71730,$error91831,$sets111932) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/trove/checker.arr26"]) {
return R.modules["$src/arr/trove/checker.arr26"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/trove/checker.arr";
var D = R.undefined;
var L = [[M,9,0,82,11,3,193],
[M,147,2,4726,147,40,4764],
[M,101,2,2956,129,5,4060],
[M,130,34,4095,130,100,4161],
[M,133,8,4259,133,50,4301],
[M,135,34,4348,135,67,4381],
[M,135,43,4357,135,66,4380],
[M,132,19,4221,132,48,4250],
[M,137,4,4421,137,41,4458],
[M,132,19,4221,132,42,4244],
[M,141,15,4515,141,139,4639],
[M,141,15,4515,141,24,4524],
[M,131,10,4172,131,39,4201],
[M,131,10,4172,131,33,4195],
[M,130,5,4066,130,33,4094],
[M,130,5,4066,130,27,4088],
[M,135,8,4322,135,92,4406],
[M,141,44,4544,141,62,4562],
[M,141,53,4553,141,61,4561],
[M,141,80,4580,141,98,4598],
[M,141,89,4589,141,97,4597],
[M,141,115,4615,141,132,4632],
[M,141,124,4624,141,131,4631],
[M,140,4,4496,142,5,4645],
[M,102,4,3041,117,7,3575],
[M,118,14,3590,118,164,3740],
[M,118,14,3590,118,29,3605],
[M,118,41,3617,118,60,3636],
[M,118,41,3617,118,54,3630],
[M,118,41,3617,118,47,3623],
[M,118,70,3646,118,77,3653],
[M,118,87,3663,118,117,3693],
[M,118,96,3672,118,116,3692],
[M,118,126,3702,118,155,3731],
[M,118,135,3711,118,154,3730],
[M,118,4,3580,118,164,3740],
[M,120,36,3799,120,38,3801],
[M,121,12,3814,121,33,3835],
[M,120,9,3772,120,35,3798],
[M,124,15,3867,124,41,3893],
[M,120,9,3772,120,29,3792],
[M,125,14,3908,125,52,3946],
[M,125,31,3925,125,51,3945],
[M,125,14,3908,125,28,3922],
[M,126,14,3961,126,52,3999],
[M,126,31,3978,126,51,3998],
[M,126,14,3961,126,28,3975],
[M,127,13,4013,127,48,4048],
[M,127,29,4029,127,48,4048],
[M,127,13,4013,127,26,4026],
[M,110,35,3379,110,55,3399],
[M,110,35,3379,110,48,3392],
[M,110,35,3379,110,41,3385],
[M,110,14,3358,110,98,3442],
[M,110,87,3431,110,98,3442],
[M,110,87,3431,110,96,3440],
[M,110,10,3354,110,98,3442],
[M,113,20,3501,113,33,3514],
[M,113,20,3501,113,28,3509],
[M,114,19,3534,114,30,3545],
[M,114,19,3534,114,26,3541],
[M,105,42,3221,105,59,3238],
[M,105,42,3221,105,52,3231],
[M,105,21,3200,105,69,3248],
[M,106,20,3269,106,33,3282],
[M,106,20,3269,106,28,3277],
[M,107,19,3302,107,30,3313],
[M,107,19,3302,107,26,3309],
[M,38,2,1170,38,32,1200],
[M,38,24,1192,38,32,1200],
[M,35,2,1066,37,5,1167],
[M,36,21,1134,36,32,1145],
[M,35,30,1094,35,46,1110],
[M,89,6,2754,89,26,2774],
[M,88,4,2734,90,7,2797],
[M,85,4,2686,87,7,2728],
[M,83,6,2642,83,21,2657],
[M,82,4,2621,84,7,2680],
[M,79,4,2464,81,7,2615],
[M,80,42,2553,80,90,2601],
[M,80,71,2582,80,82,2593],
[M,80,6,2517,80,23,2534],
[M,68,6,2120,68,30,2144],
[M,67,4,2054,78,7,2458],
[M,61,9,1903,61,19,1913],
[M,60,4,1848,66,7,2048],
[M,55,19,1731,55,37,1749],
[M,57,19,1782,57,60,1823],
[M,54,9,1697,54,23,1711],
[M,53,4,1648,59,7,1842],
[M,45,11,1404,45,58,1451],
[M,45,23,1416,45,57,1450],
[M,45,11,1404,45,20,1413],
[M,46,8,1460,50,11,1624],
[M,47,10,1495,47,25,1510],
[M,45,6,1399,51,9,1634],
[M,44,4,1354,52,7,1642],
[M,42,2,1296,42,51,1345],
[M,42,42,1336,42,50,1344],
[M,39,2,1204,41,5,1293],
[M,40,23,1260,40,32,1269],
[M,39,22,1224,39,32,1234],
[M,69,6,2151,77,9,2450],
[M,71,8,2250,76,13,2440],
[M,72,13,2277,72,36,2300],
[M,70,8,2181,70,68,2241],
[M,70,32,2205,70,67,2240],
[M,73,23,2325,73,41,2343],
[M,75,23,2384,75,64,2425],
[M,73,12,2314,73,42,2344],
[M,75,12,2373,75,65,2426],
[M,62,19,1934,62,37,1952],
[M,64,19,1985,64,63,2029],
[M,62,8,1923,62,38,1953],
[M,64,8,1974,64,64,2030],
[M,55,8,1720,55,38,1750],
[M,57,8,1771,57,61,1824],
[M,48,10,1521,48,17,1528],
[M,48,10,1521,48,15,1526],
[M,49,27,1556,49,82,1611],
[M,49,54,1583,49,64,1593],
[M,49,46,1575,49,52,1581],
[M,40,23,1260,40,50,1287],
[M,36,21,1134,36,48,1161],
[M,28,4,865,30,7,953],
[M,27,2,796,30,7,953],
[M,25,6,682,25,109,785],
[M,25,84,760,25,109,785],
[M,25,91,767,25,108,784],
[M,24,4,662,26,7,793],
[M,23,2,578,26,7,793],
[M,20,4,498,22,7,575],
[M,19,2,425,22,7,575],
[M,17,6,345,17,75,414],
[M,17,57,396,17,75,414],
[M,17,64,403,17,74,413],
[M,16,4,325,18,7,422],
[M,15,2,254,18,7,422],
[M,14,2,214,14,39,251],
[M,10,2,107,10,84,189],
[M,3,0,13,148,3,4768],
[M,7,11,71,7,20,80],
[M,146,0,4657,148,3,4768],
[M,147,2,4726,147,32,4756],
[M,146,42,4699,146,64,4721],
[M,94,0,2807,144,3,4655],
[M,101,57,3011,101,80,3034],
[M,101,57,3011,101,78,3032],
[M,101,21,2975,129,5,4060],
[M,102,50,3087,102,75,3112],
[M,102,50,3087,102,73,3110],
[M,102,50,3087,102,65,3102],
[M,102,20,3057,117,7,3575],
[M,103,6,3121,116,9,3567],
[M,110,14,3358,110,23,3367],
[M,104,8,3151,108,11,3325],
[M,105,21,3200,105,30,3209],
[M,94,37,2844,94,59,2866],
[M,33,0,959,92,3,2805],
[M,34,2,1035,34,30,1063],
[M,34,22,1055,34,30,1063],
[M,33,43,1002,33,49,1008],
[M,33,64,1023,33,71,1030],
[M,13,0,195,31,3,957],
[M,14,4,216,14,39,251],
[M,14,19,231,14,22,234],
[M,14,32,244,14,38,250],
[M,15,4,256,15,62,314],
[M,15,29,281,15,32,284],
[M,15,42,294,15,48,300],
[M,19,4,427,19,64,487],
[M,19,33,456,19,36,459],
[M,19,46,469,19,52,475],
[M,23,4,580,23,75,651],
[M,23,29,605,23,32,608],
[M,23,42,618,23,48,624],
[M,27,4,798,27,60,854],
[M,27,26,820,27,29,823],
[M,27,39,833,27,45,839],
[M,29,41,920,29,66,945],
[M,29,48,927,29,65,944],
[M,27,47,841,27,59,853],
[M,27,31,825,27,45,839],
[M,27,19,813,27,29,823],
[M,25,36,712,25,59,735],
[M,25,43,719,25,58,734],
[M,23,64,640,23,74,650],
[M,23,50,626,23,62,638],
[M,23,34,610,23,48,624],
[M,23,22,598,23,32,608],
[M,21,39,551,21,55,567],
[M,21,46,558,21,54,566],
[M,19,59,482,19,63,486],
[M,19,54,477,19,57,480],
[M,19,38,461,19,52,475],
[M,19,26,449,19,36,459],
[M,17,30,369,17,47,386],
[M,17,37,376,17,46,385],
[M,15,56,308,15,61,313],
[M,15,50,302,15,54,306],
[M,15,34,286,15,48,300],
[M,15,22,274,15,32,284],
[M,14,24,236,14,38,250],
[M,14,12,224,14,22,234],
[M,10,4,109,10,84,189],
[M,10,31,136,10,37,142],
[M,10,46,151,10,49,154],
[M,10,67,172,10,83,188],
[M,10,51,156,10,83,188],
[M,10,39,144,10,49,154],
[M,10,23,128,10,37,142]];
var _plus5 = NAMESPACE.get("_plus");
var builtins6 = NAMESPACE.get("builtins");
var nothing7 = NAMESPACE.get("nothing");
var run_DASH_task8 = NAMESPACE.get("run-task");
var string_DASH_contains9 = NAMESPACE.get("string-contains");
var torepr10 = NAMESPACE.get("torepr");
var tostring11 = NAMESPACE.get("tostring");
var $type$Boolean12 = NAMESPACE.get("$type$Boolean");
var $type$String13 = NAMESPACE.get("$type$String");
var $Hanf_bracket63833 = function(anf_bracket44734,CheckBlockResult6235,Loc6636,TestResult6437,provides44538,nothing7) {
var anf_fun44849 = G(anf_bracket44734,"results",L[0]);
var $z4142 = D;
var $f4748 = function(_) {
return R.isFunction(anf_fun44849)?anf_fun44849.app():R.ffi.throwNonFunApp(L[0],anf_fun44849,[]);
};
try {
if(--R.GAS > 0) {
$z4142 = $f4748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4748,
"from":L[0]});
}
} catch($e3940) {
if(R.isCont($e3940)) {
var $ss4344 = {"from":L[0],
"go":function(checks44950) {
return $Hchecks63751(checks44950,CheckBlockResult6235,Loc6636,TestResult6437,provides44538,nothing7);
}};
$e3940.stack[R.EXN_STACKHEIGHT++] = $ss4344;
}
if(R.isPyretException($e3940)) {
$e3940.pyretStack.push(L[0]);
}
throw $e3940;
}
var $ret4546 = $Hchecks63751($z4142,CheckBlockResult6235,Loc6636,TestResult6437,provides44538,nothing7);
++R.GAS;
return $ret4546;
};
var $Hchecks63751 = function(checks44950,CheckBlockResult6235,Loc6636,TestResult6437,provides44538,nothing7) {
return R.makeObject({"answer":nothing7,
"provide-plus-types":R.makeObject({"values":provides44538,
"types":{"Loc":Loc6636,
"CheckBlockResult":CheckBlockResult6235,
"TestResult":TestResult6437}}),
"checks":checks44950});
};
var $Hanf_bracket63652 = function(anf_bracket44353) {
var ann_DASH_check_DASH_temp44254 = G(anf_bracket44353,"message",L[1]);
return ann_DASH_check_DASH_temp44254;
};
var $Hanf_arg63555 = function(anf_arg39856,anf_arg39657,fold4958,init15559,_plus5,tostring11) {
var $z6263 = D;
var $f6869 = function(_) {
return R.isFunction(fold4958)?fold4958.app(anf_arg39657,init15559,anf_arg39856):R.ffi.throwNonFunApp(L[2],fold4958,[anf_arg39657,init15559,anf_arg39856]);
};
try {
if(--R.GAS > 0) {
$z6263 = $f6869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6869,
"from":L[2]});
}
} catch($e6061) {
if(R.isCont($e6061)) {
var $ss6465 = {"from":L[2],
"go":function(complete_DASH_summary15670) {
return $Hcomplete_DASH_summary63471(complete_DASH_summary15670,_plus5,tostring11);
}};
$e6061.stack[R.EXN_STACKHEIGHT++] = $ss6465;
}
if(R.isPyretException($e6061)) {
$e6061.pyretStack.push(L[2]);
}
throw $e6061;
}
var $ret6667 = $Hcomplete_DASH_summary63471($z6263,_plus5,tostring11);
++R.GAS;
return $ret6667;
};
var $Hcomplete_DASH_summary63471 = function(complete_DASH_summary15670,_plus5,tostring11) {
var anf_arg399141 = G(complete_DASH_summary15670,"total",L[15]);
var if_DASH_48134 = R.equiv(anf_arg399141,(0));
var if_helper40074 = R.makeFunction(function(if_helper_arg401139) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[14],1,arguments);
}
var ann_DASH_check_DASH_temp324140 = if_helper_arg401139;
return ann_DASH_check_DASH_temp324140;
});
var anf_if404138 = R.isBoolean(if_DASH_48134);
if(R.isPyretTrue(anf_if404138)) {
if(R.isPyretTrue(if_DASH_48134)) {
var cont_tail_arg43975 = complete_DASH_summary15670.extendWith({"message":("The program didn't define any tests.")});
if(--R.GAS > 0) {
$z7273 = R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg43975):R.ffi.throwNonFunApp(L[3],if_helper40074,[cont_tail_arg43975]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg43975):R.ffi.throwNonFunApp(L[3],if_helper40074,[cont_tail_arg43975]);
},
"from":L[3]});
}
++R.GAS;
return $z7273;
} else {
var anf_arg405133 = G(complete_DASH_summary15670,"failed",L[13]);
var if_DASH_46128 = R.equiv(anf_arg405133,(0));
var anf_if408132 = R.isBoolean(if_DASH_46128);
if(R.isPyretTrue(anf_if408132)) {
if(R.isPyretTrue(if_DASH_46128)) {
var anf_arg425113 = G(complete_DASH_summary15670,"passed",L[9]);
var if_DASH_47103 = R.equiv(anf_arg425113,(1));
var if_helper42687 = R.makeFunction(function(if_helper_arg427108) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
var happy_DASH_msg167112 = if_helper_arg427108;
var cont_tail_arg428111 = complete_DASH_summary15670.extendWith({"message":happy_DASH_msg167112});
if(--R.GAS > 0) {
$z109110 = R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg428111):R.ffi.throwNonFunApp(L[8],if_helper40074,[cont_tail_arg428111]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg428111):R.ffi.throwNonFunApp(L[8],if_helper40074,[cont_tail_arg428111]);
},
"from":L[8]});
}
++R.GAS;
return $z109110;
});
var anf_if432107 = R.isBoolean(if_DASH_47103);
if(R.isPyretTrue(anf_if432107)) {
if(R.isPyretTrue(if_DASH_47103)) {
var $z7980 = D;
var $f8586 = function(_) {
return R.isFunction(if_helper42687)?if_helper42687.app(("Looks shipshape, your test passed, mate!")):R.ffi.throwNonFunApp(L[4],if_helper42687,[("Looks shipshape, your test passed, mate!")]);
};
try {
if(--R.GAS > 0) {
$z7980 = $f8586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8586,
"from":L[4]});
}
} catch($e7778) {
if(R.isCont($e7778)) {
var $ss8182 = {"from":L[4],
"go":function(cont_tail_app43888) {
return $Hcont_tail_app62089(cont_tail_app43888);
}};
$e7778.stack[R.EXN_STACKHEIGHT++] = $ss8182;
}
if(R.isPyretException($e7778)) {
$e7778.pyretStack.push(L[4]);
}
throw $e7778;
}
var $ret8384 = $Hcont_tail_app62089($z7980);
++R.GAS;
return $ret8384;
} else {
var anf_arg433100 = G(complete_DASH_summary15670,"passed",L[6]);
var $z9293 = D;
var $f9899 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg433100):R.ffi.throwNonFunApp(L[5],tostring11,[anf_arg433100]);
};
try {
if(--R.GAS > 0) {
$z9293 = $f9899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9899,
"from":L[5]});
}
} catch($e9091) {
if(R.isCont($e9091)) {
var $ss9495 = {"from":L[5],
"go":function(anf_arg434101) {
return $Hanf_arg623102(anf_arg434101,if_helper42687,_plus5);
}};
$e9091.stack[R.EXN_STACKHEIGHT++] = $ss9495;
}
if(R.isPyretException($e9091)) {
$e9091.pyretStack.push(L[5]);
}
throw $e9091;
}
var $ret9697 = $Hanf_arg623102($z9293,if_helper42687,_plus5);
++R.GAS;
return $ret9697;
}
} else {
var cont_tail_arg430106 = R.throwNonBooleanCondition(L[7],("if"),if_DASH_47103);
if(--R.GAS > 0) {
$z104105 = R.isFunction(if_helper42687)?if_helper42687.app(cont_tail_arg430106):R.ffi.throwNonFunApp(L[7],if_helper42687,[cont_tail_arg430106]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper42687)?if_helper42687.app(cont_tail_arg430106):R.ffi.throwNonFunApp(L[7],if_helper42687,[cont_tail_arg430106]);
},
"from":L[7]});
}
++R.GAS;
return $z104105;
}
} else {
var c168126 = complete_DASH_summary15670;
var anf_arg409124 = G(c168126,"message",L[11]);
var $z116117 = D;
var $f122123 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg409124,("\n\nPassed: ")):R.ffi.throwNonFunApp(L[10],_plus5,[anf_arg409124,("\n\nPassed: ")]);
};
try {
if(--R.GAS > 0) {
$z116117 = $f122123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f122123,
"from":L[10]});
}
} catch($e114115) {
if(R.isCont($e114115)) {
var $ss118119 = {"from":L[10],
"go":function(anf_arg410125) {
return $Hanf_arg633127(anf_arg410125,c168126,if_helper40074,_plus5,tostring11);
}};
$e114115.stack[R.EXN_STACKHEIGHT++] = $ss118119;
}
if(R.isPyretException($e114115)) {
$e114115.pyretStack.push(L[10]);
}
throw $e114115;
}
var $ret120121 = $Hanf_arg633127($z116117,c168126,if_helper40074,_plus5,tostring11);
++R.GAS;
return $ret120121;
}
} else {
var cont_tail_arg406131 = R.throwNonBooleanCondition(L[12],("if"),if_DASH_46128);
if(--R.GAS > 0) {
$z129130 = R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg406131):R.ffi.throwNonFunApp(L[12],if_helper40074,[cont_tail_arg406131]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg406131):R.ffi.throwNonFunApp(L[12],if_helper40074,[cont_tail_arg406131]);
},
"from":L[12]});
}
++R.GAS;
return $z129130;
}
}
} else {
var cont_tail_arg402137 = R.throwNonBooleanCondition(L[14],("if"),if_DASH_48134);
if(--R.GAS > 0) {
$z135136 = R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg402137):R.ffi.throwNonFunApp(L[14],if_helper40074,[cont_tail_arg402137]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg402137):R.ffi.throwNonFunApp(L[14],if_helper40074,[cont_tail_arg402137]);
},
"from":L[14]});
}
++R.GAS;
return $z135136;
}
};
var $Hcont_tail_app62089 = function(cont_tail_app43888) {
return cont_tail_app43888;
};
var $Hanf_arg623102 = function(anf_arg434101,if_helper42687,_plus5) {
var $z144145 = D;
var $f150151 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Looks shipshape, all "),anf_arg434101):R.ffi.throwNonFunApp(L[16],_plus5,[("Looks shipshape, all "),anf_arg434101]);
};
try {
if(--R.GAS > 0) {
$z144145 = $f150151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f150151,
"from":L[16]});
}
} catch($e142143) {
if(R.isCont($e142143)) {
var $ss146147 = {"from":L[16],
"go":function(anf_arg435152) {
return $Hanf_arg622153(anf_arg435152,if_helper42687,_plus5);
}};
$e142143.stack[R.EXN_STACKHEIGHT++] = $ss146147;
}
if(R.isPyretException($e142143)) {
$e142143.pyretStack.push(L[16]);
}
throw $e142143;
}
var $ret148149 = $Hanf_arg622153($z144145,if_helper42687,_plus5);
++R.GAS;
return $ret148149;
};
var $Hanf_arg622153 = function(anf_arg435152,if_helper42687,_plus5) {
var $z156157 = D;
var $f162163 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg435152,(" tests passed, mate!")):R.ffi.throwNonFunApp(L[16],_plus5,[anf_arg435152,(" tests passed, mate!")]);
};
try {
if(--R.GAS > 0) {
$z156157 = $f162163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f162163,
"from":L[16]});
}
} catch($e154155) {
if(R.isCont($e154155)) {
var $ss158159 = {"from":L[16],
"go":function(cont_tail_arg436164) {
return $Hcont_tail_arg621165(cont_tail_arg436164,if_helper42687);
}};
$e154155.stack[R.EXN_STACKHEIGHT++] = $ss158159;
}
if(R.isPyretException($e154155)) {
$e154155.pyretStack.push(L[16]);
}
throw $e154155;
}
var $ret160161 = $Hcont_tail_arg621165($z156157,if_helper42687);
++R.GAS;
return $ret160161;
};
var $Hcont_tail_arg621165 = function(cont_tail_arg436164,if_helper42687) {
if(--R.GAS > 0) {
$z166167 = R.isFunction(if_helper42687)?if_helper42687.app(cont_tail_arg436164):R.ffi.throwNonFunApp(L[16],if_helper42687,[cont_tail_arg436164]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper42687)?if_helper42687.app(cont_tail_arg436164):R.ffi.throwNonFunApp(L[16],if_helper42687,[cont_tail_arg436164]);
},
"from":L[16]});
}
++R.GAS;
return $z166167;
};
var $Hanf_arg633127 = function(anf_arg410125,c168126,if_helper40074,_plus5,tostring11) {
var anf_arg411178 = G(c168126,"passed",L[18]);
var $z170171 = D;
var $f176177 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg411178):R.ffi.throwNonFunApp(L[17],tostring11,[anf_arg411178]);
};
try {
if(--R.GAS > 0) {
$z170171 = $f176177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f176177,
"from":L[17]});
}
} catch($e168169) {
if(R.isCont($e168169)) {
var $ss172173 = {"from":L[17],
"go":function(anf_arg412179) {
return $Hanf_arg632180(anf_arg412179,anf_arg410125,c168126,if_helper40074,_plus5,tostring11);
}};
$e168169.stack[R.EXN_STACKHEIGHT++] = $ss172173;
}
if(R.isPyretException($e168169)) {
$e168169.pyretStack.push(L[17]);
}
throw $e168169;
}
var $ret174175 = $Hanf_arg632180($z170171,anf_arg410125,c168126,if_helper40074,_plus5,tostring11);
++R.GAS;
return $ret174175;
};
var $Hanf_arg632180 = function(anf_arg412179,anf_arg410125,c168126,if_helper40074,_plus5,tostring11) {
var $z183184 = D;
var $f189190 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg410125,anf_arg412179):R.ffi.throwNonFunApp(L[10],_plus5,[anf_arg410125,anf_arg412179]);
};
try {
if(--R.GAS > 0) {
$z183184 = $f189190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f189190,
"from":L[10]});
}
} catch($e181182) {
if(R.isCont($e181182)) {
var $ss185186 = {"from":L[10],
"go":function(anf_arg413191) {
return $Hanf_arg631192(anf_arg413191,c168126,if_helper40074,_plus5,tostring11);
}};
$e181182.stack[R.EXN_STACKHEIGHT++] = $ss185186;
}
if(R.isPyretException($e181182)) {
$e181182.pyretStack.push(L[10]);
}
throw $e181182;
}
var $ret187188 = $Hanf_arg631192($z183184,c168126,if_helper40074,_plus5,tostring11);
++R.GAS;
return $ret187188;
};
var $Hanf_arg631192 = function(anf_arg413191,c168126,if_helper40074,_plus5,tostring11) {
var $z195196 = D;
var $f201202 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg413191,("; Failed: ")):R.ffi.throwNonFunApp(L[10],_plus5,[anf_arg413191,("; Failed: ")]);
};
try {
if(--R.GAS > 0) {
$z195196 = $f201202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f201202,
"from":L[10]});
}
} catch($e193194) {
if(R.isCont($e193194)) {
var $ss197198 = {"from":L[10],
"go":function(anf_arg414203) {
return $Hanf_arg630204(anf_arg414203,c168126,if_helper40074,_plus5,tostring11);
}};
$e193194.stack[R.EXN_STACKHEIGHT++] = $ss197198;
}
if(R.isPyretException($e193194)) {
$e193194.pyretStack.push(L[10]);
}
throw $e193194;
}
var $ret199200 = $Hanf_arg630204($z195196,c168126,if_helper40074,_plus5,tostring11);
++R.GAS;
return $ret199200;
};
var $Hanf_arg630204 = function(anf_arg414203,c168126,if_helper40074,_plus5,tostring11) {
var anf_arg415215 = G(c168126,"failed",L[20]);
var $z207208 = D;
var $f213214 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg415215):R.ffi.throwNonFunApp(L[19],tostring11,[anf_arg415215]);
};
try {
if(--R.GAS > 0) {
$z207208 = $f213214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f213214,
"from":L[19]});
}
} catch($e205206) {
if(R.isCont($e205206)) {
var $ss209210 = {"from":L[19],
"go":function(anf_arg416216) {
return $Hanf_arg629217(anf_arg416216,anf_arg414203,c168126,if_helper40074,_plus5,tostring11);
}};
$e205206.stack[R.EXN_STACKHEIGHT++] = $ss209210;
}
if(R.isPyretException($e205206)) {
$e205206.pyretStack.push(L[19]);
}
throw $e205206;
}
var $ret211212 = $Hanf_arg629217($z207208,anf_arg414203,c168126,if_helper40074,_plus5,tostring11);
++R.GAS;
return $ret211212;
};
var $Hanf_arg629217 = function(anf_arg416216,anf_arg414203,c168126,if_helper40074,_plus5,tostring11) {
var $z220221 = D;
var $f226227 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg414203,anf_arg416216):R.ffi.throwNonFunApp(L[10],_plus5,[anf_arg414203,anf_arg416216]);
};
try {
if(--R.GAS > 0) {
$z220221 = $f226227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f226227,
"from":L[10]});
}
} catch($e218219) {
if(R.isCont($e218219)) {
var $ss222223 = {"from":L[10],
"go":function(anf_arg417228) {
return $Hanf_arg628229(anf_arg417228,c168126,if_helper40074,_plus5,tostring11);
}};
$e218219.stack[R.EXN_STACKHEIGHT++] = $ss222223;
}
if(R.isPyretException($e218219)) {
$e218219.pyretStack.push(L[10]);
}
throw $e218219;
}
var $ret224225 = $Hanf_arg628229($z220221,c168126,if_helper40074,_plus5,tostring11);
++R.GAS;
return $ret224225;
};
var $Hanf_arg628229 = function(anf_arg417228,c168126,if_helper40074,_plus5,tostring11) {
var $z232233 = D;
var $f238239 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg417228,("; Total: ")):R.ffi.throwNonFunApp(L[10],_plus5,[anf_arg417228,("; Total: ")]);
};
try {
if(--R.GAS > 0) {
$z232233 = $f238239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f238239,
"from":L[10]});
}
} catch($e230231) {
if(R.isCont($e230231)) {
var $ss234235 = {"from":L[10],
"go":function(anf_arg418240) {
return $Hanf_arg627241(anf_arg418240,c168126,if_helper40074,_plus5,tostring11);
}};
$e230231.stack[R.EXN_STACKHEIGHT++] = $ss234235;
}
if(R.isPyretException($e230231)) {
$e230231.pyretStack.push(L[10]);
}
throw $e230231;
}
var $ret236237 = $Hanf_arg627241($z232233,c168126,if_helper40074,_plus5,tostring11);
++R.GAS;
return $ret236237;
};
var $Hanf_arg627241 = function(anf_arg418240,c168126,if_helper40074,_plus5,tostring11) {
var anf_arg419252 = G(c168126,"total",L[22]);
var $z244245 = D;
var $f250251 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg419252):R.ffi.throwNonFunApp(L[21],tostring11,[anf_arg419252]);
};
try {
if(--R.GAS > 0) {
$z244245 = $f250251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f250251,
"from":L[21]});
}
} catch($e242243) {
if(R.isCont($e242243)) {
var $ss246247 = {"from":L[21],
"go":function(anf_arg420253) {
return $Hanf_arg626254(anf_arg420253,anf_arg418240,c168126,if_helper40074,_plus5);
}};
$e242243.stack[R.EXN_STACKHEIGHT++] = $ss246247;
}
if(R.isPyretException($e242243)) {
$e242243.pyretStack.push(L[21]);
}
throw $e242243;
}
var $ret248249 = $Hanf_arg626254($z244245,anf_arg418240,c168126,if_helper40074,_plus5);
++R.GAS;
return $ret248249;
};
var $Hanf_arg626254 = function(anf_arg420253,anf_arg418240,c168126,if_helper40074,_plus5) {
var $z257258 = D;
var $f263264 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg418240,anf_arg420253):R.ffi.throwNonFunApp(L[10],_plus5,[anf_arg418240,anf_arg420253]);
};
try {
if(--R.GAS > 0) {
$z257258 = $f263264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f263264,
"from":L[10]});
}
} catch($e255256) {
if(R.isCont($e255256)) {
var $ss259260 = {"from":L[10],
"go":function(anf_arg421265) {
return $Hanf_arg625266(anf_arg421265,c168126,if_helper40074,_plus5);
}};
$e255256.stack[R.EXN_STACKHEIGHT++] = $ss259260;
}
if(R.isPyretException($e255256)) {
$e255256.pyretStack.push(L[10]);
}
throw $e255256;
}
var $ret261262 = $Hanf_arg625266($z257258,c168126,if_helper40074,_plus5);
++R.GAS;
return $ret261262;
};
var $Hanf_arg625266 = function(anf_arg421265,c168126,if_helper40074,_plus5) {
var $z269270 = D;
var $f275276 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg421265,("\n")):R.ffi.throwNonFunApp(L[10],_plus5,[anf_arg421265,("\n")]);
};
try {
if(--R.GAS > 0) {
$z269270 = $f275276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f275276,
"from":L[10]});
}
} catch($e267268) {
if(R.isCont($e267268)) {
var $ss271272 = {"from":L[10],
"go":function(anf_extend422277) {
return $Hanf_extend624278(anf_extend422277,c168126,if_helper40074);
}};
$e267268.stack[R.EXN_STACKHEIGHT++] = $ss271272;
}
if(R.isPyretException($e267268)) {
$e267268.pyretStack.push(L[10]);
}
throw $e267268;
}
var $ret273274 = $Hanf_extend624278($z269270,c168126,if_helper40074);
++R.GAS;
return $ret273274;
};
var $Hanf_extend624278 = function(anf_extend422277,c168126,if_helper40074) {
var cont_tail_arg423281 = c168126.extendWith({"message":anf_extend422277});
if(--R.GAS > 0) {
$z279280 = R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg423281):R.ffi.throwNonFunApp(L[23],if_helper40074,[cont_tail_arg423281]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper40074)?if_helper40074.app(cont_tail_arg423281):R.ffi.throwNonFunApp(L[23],if_helper40074,[cont_tail_arg423281]);
},
"from":L[23]});
}
++R.GAS;
return $z279280;
};
var $Hanf_arg619282 = function(anf_arg359283,anf_arg356284,br158285,fold4958,init15559,summary157286,_plus5,tostring11) {
var $z289290 = D;
var $f295296 = function(_) {
return R.isFunction(fold4958)?fold4958.app(anf_arg356284,init15559,anf_arg359283):R.ffi.throwNonFunApp(L[24],fold4958,[anf_arg356284,init15559,anf_arg359283]);
};
try {
if(--R.GAS > 0) {
$z289290 = $f295296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f295296,
"from":L[24]});
}
} catch($e287288) {
if(R.isCont($e287288)) {
var $ss291292 = {"from":L[24],
"go":function(block_DASH_summary159297) {
return $Hblock_DASH_summary618298(block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
}};
$e287288.stack[R.EXN_STACKHEIGHT++] = $ss291292;
}
if(R.isPyretException($e287288)) {
$e287288.pyretStack.push(L[24]);
}
throw $e287288;
}
var $ret293294 = $Hblock_DASH_summary618298($z289290,br158285,summary157286,_plus5,tostring11);
++R.GAS;
return $ret293294;
};
var $Hblock_DASH_summary618298 = function(block_DASH_summary159297,br158285,summary157286,_plus5,tostring11) {
var anf_arg360309 = G(summary157286,"message",L[26]);
var $z301302 = D;
var $f307308 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg360309,("\n\n")):R.ffi.throwNonFunApp(L[25],_plus5,[anf_arg360309,("\n\n")]);
};
try {
if(--R.GAS > 0) {
$z301302 = $f307308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f307308,
"from":L[25]});
}
} catch($e299300) {
if(R.isCont($e299300)) {
var $ss303304 = {"from":L[25],
"go":function(anf_arg361310) {
return $Hanf_arg617311(anf_arg361310,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
}};
$e299300.stack[R.EXN_STACKHEIGHT++] = $ss303304;
}
if(R.isPyretException($e299300)) {
$e299300.pyretStack.push(L[25]);
}
throw $e299300;
}
var $ret305306 = $Hanf_arg617311($z301302,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
++R.GAS;
return $ret305306;
};
var $Hanf_arg617311 = function(anf_arg361310,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11) {
var anf_bracket362325 = G(br158285,"loc",L[29]);
var anf_fun363322 = G(anf_bracket362325,"format",L[28]);
var $z314315 = D;
var $f320321 = function(_) {
return R.isFunction(anf_fun363322)?anf_fun363322.app((true)):R.ffi.throwNonFunApp(L[27],anf_fun363322,[(true)]);
};
try {
if(--R.GAS > 0) {
$z314315 = $f320321();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f320321,
"from":L[27]});
}
} catch($e312313) {
if(R.isCont($e312313)) {
var $ss316317 = {"from":L[27],
"go":function(anf_arg364323) {
return $Hanf_arg616324(anf_arg364323,anf_arg361310,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
}};
$e312313.stack[R.EXN_STACKHEIGHT++] = $ss316317;
}
if(R.isPyretException($e312313)) {
$e312313.pyretStack.push(L[27]);
}
throw $e312313;
}
var $ret318319 = $Hanf_arg616324($z314315,anf_arg361310,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
++R.GAS;
return $ret318319;
};
var $Hanf_arg616324 = function(anf_arg364323,anf_arg361310,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11) {
var $z328329 = D;
var $f334335 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg361310,anf_arg364323):R.ffi.throwNonFunApp(L[25],_plus5,[anf_arg361310,anf_arg364323]);
};
try {
if(--R.GAS > 0) {
$z328329 = $f334335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f334335,
"from":L[25]});
}
} catch($e326327) {
if(R.isCont($e326327)) {
var $ss330331 = {"from":L[25],
"go":function(anf_arg365336) {
return $Hanf_arg615337(anf_arg365336,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
}};
$e326327.stack[R.EXN_STACKHEIGHT++] = $ss330331;
}
if(R.isPyretException($e326327)) {
$e326327.pyretStack.push(L[25]);
}
throw $e326327;
}
var $ret332333 = $Hanf_arg615337($z328329,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
++R.GAS;
return $ret332333;
};
var $Hanf_arg615337 = function(anf_arg365336,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11) {
var $z340341 = D;
var $f346347 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg365336,(": ")):R.ffi.throwNonFunApp(L[25],_plus5,[anf_arg365336,(": ")]);
};
try {
if(--R.GAS > 0) {
$z340341 = $f346347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f346347,
"from":L[25]});
}
} catch($e338339) {
if(R.isCont($e338339)) {
var $ss342343 = {"from":L[25],
"go":function(anf_arg366348) {
return $Hanf_arg614349(anf_arg366348,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
}};
$e338339.stack[R.EXN_STACKHEIGHT++] = $ss342343;
}
if(R.isPyretException($e338339)) {
$e338339.pyretStack.push(L[25]);
}
throw $e338339;
}
var $ret344345 = $Hanf_arg614349($z340341,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11);
++R.GAS;
return $ret344345;
};
var $Hanf_arg614349 = function(anf_arg366348,block_DASH_summary159297,br158285,summary157286,_plus5,tostring11) {
var anf_arg367360 = G(br158285,"name",L[30]);
var $z352353 = D;
var $f358359 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg366348,anf_arg367360):R.ffi.throwNonFunApp(L[25],_plus5,[anf_arg366348,anf_arg367360]);
};
try {
if(--R.GAS > 0) {
$z352353 = $f358359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f358359,
"from":L[25]});
}
} catch($e350351) {
if(R.isCont($e350351)) {
var $ss354355 = {"from":L[25],
"go":function(anf_arg368361) {
return $Hanf_arg613362(anf_arg368361,block_DASH_summary159297,summary157286,_plus5,tostring11);
}};
$e350351.stack[R.EXN_STACKHEIGHT++] = $ss354355;
}
if(R.isPyretException($e350351)) {
$e350351.pyretStack.push(L[25]);
}
throw $e350351;
}
var $ret356357 = $Hanf_arg613362($z352353,block_DASH_summary159297,summary157286,_plus5,tostring11);
++R.GAS;
return $ret356357;
};
var $Hanf_arg613362 = function(anf_arg368361,block_DASH_summary159297,summary157286,_plus5,tostring11) {
var $z365366 = D;
var $f371372 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg368361,(" (")):R.ffi.throwNonFunApp(L[25],_plus5,[anf_arg368361,(" (")]);
};
try {
if(--R.GAS > 0) {
$z365366 = $f371372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f371372,
"from":L[25]});
}
} catch($e363364) {
if(R.isCont($e363364)) {
var $ss367368 = {"from":L[25],
"go":function(anf_arg369373) {
return $Hanf_arg612374(anf_arg369373,block_DASH_summary159297,summary157286,_plus5,tostring11);
}};
$e363364.stack[R.EXN_STACKHEIGHT++] = $ss367368;
}
if(R.isPyretException($e363364)) {
$e363364.pyretStack.push(L[25]);
}
throw $e363364;
}
var $ret369370 = $Hanf_arg612374($z365366,block_DASH_summary159297,summary157286,_plus5,tostring11);
++R.GAS;
return $ret369370;
};
var $Hanf_arg612374 = function(anf_arg369373,block_DASH_summary159297,summary157286,_plus5,tostring11) {
var anf_arg370385 = G(block_DASH_summary159297,"passed",L[32]);
var $z377378 = D;
var $f383384 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg370385):R.ffi.throwNonFunApp(L[31],tostring11,[anf_arg370385]);
};
try {
if(--R.GAS > 0) {
$z377378 = $f383384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f383384,
"from":L[31]});
}
} catch($e375376) {
if(R.isCont($e375376)) {
var $ss379380 = {"from":L[31],
"go":function(anf_arg371386) {
return $Hanf_arg611387(anf_arg371386,anf_arg369373,block_DASH_summary159297,summary157286,_plus5,tostring11);
}};
$e375376.stack[R.EXN_STACKHEIGHT++] = $ss379380;
}
if(R.isPyretException($e375376)) {
$e375376.pyretStack.push(L[31]);
}
throw $e375376;
}
var $ret381382 = $Hanf_arg611387($z377378,anf_arg369373,block_DASH_summary159297,summary157286,_plus5,tostring11);
++R.GAS;
return $ret381382;
};
var $Hanf_arg611387 = function(anf_arg371386,anf_arg369373,block_DASH_summary159297,summary157286,_plus5,tostring11) {
var $z390391 = D;
var $f396397 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg369373,anf_arg371386):R.ffi.throwNonFunApp(L[25],_plus5,[anf_arg369373,anf_arg371386]);
};
try {
if(--R.GAS > 0) {
$z390391 = $f396397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f396397,
"from":L[25]});
}
} catch($e388389) {
if(R.isCont($e388389)) {
var $ss392393 = {"from":L[25],
"go":function(anf_arg372398) {
return $Hanf_arg610399(anf_arg372398,block_DASH_summary159297,summary157286,_plus5,tostring11);
}};
$e388389.stack[R.EXN_STACKHEIGHT++] = $ss392393;
}
if(R.isPyretException($e388389)) {
$e388389.pyretStack.push(L[25]);
}
throw $e388389;
}
var $ret394395 = $Hanf_arg610399($z390391,block_DASH_summary159297,summary157286,_plus5,tostring11);
++R.GAS;
return $ret394395;
};
var $Hanf_arg610399 = function(anf_arg372398,block_DASH_summary159297,summary157286,_plus5,tostring11) {
var $z402403 = D;
var $f408409 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg372398,("/")):R.ffi.throwNonFunApp(L[25],_plus5,[anf_arg372398,("/")]);
};
try {
if(--R.GAS > 0) {
$z402403 = $f408409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f408409,
"from":L[25]});
}
} catch($e400401) {
if(R.isCont($e400401)) {
var $ss404405 = {"from":L[25],
"go":function(anf_arg373410) {
return $Hanf_arg609411(anf_arg373410,block_DASH_summary159297,summary157286,_plus5,tostring11);
}};
$e400401.stack[R.EXN_STACKHEIGHT++] = $ss404405;
}
if(R.isPyretException($e400401)) {
$e400401.pyretStack.push(L[25]);
}
throw $e400401;
}
var $ret406407 = $Hanf_arg609411($z402403,block_DASH_summary159297,summary157286,_plus5,tostring11);
++R.GAS;
return $ret406407;
};
var $Hanf_arg609411 = function(anf_arg373410,block_DASH_summary159297,summary157286,_plus5,tostring11) {
var anf_arg374422 = G(block_DASH_summary159297,"total",L[34]);
var $z414415 = D;
var $f420421 = function(_) {
return R.isFunction(tostring11)?tostring11.app(anf_arg374422):R.ffi.throwNonFunApp(L[33],tostring11,[anf_arg374422]);
};
try {
if(--R.GAS > 0) {
$z414415 = $f420421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f420421,
"from":L[33]});
}
} catch($e412413) {
if(R.isCont($e412413)) {
var $ss416417 = {"from":L[33],
"go":function(anf_arg375423) {
return $Hanf_arg608424(anf_arg375423,anf_arg373410,block_DASH_summary159297,summary157286,_plus5);
}};
$e412413.stack[R.EXN_STACKHEIGHT++] = $ss416417;
}
if(R.isPyretException($e412413)) {
$e412413.pyretStack.push(L[33]);
}
throw $e412413;
}
var $ret418419 = $Hanf_arg608424($z414415,anf_arg373410,block_DASH_summary159297,summary157286,_plus5);
++R.GAS;
return $ret418419;
};
var $Hanf_arg608424 = function(anf_arg375423,anf_arg373410,block_DASH_summary159297,summary157286,_plus5) {
var $z427428 = D;
var $f433434 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg373410,anf_arg375423):R.ffi.throwNonFunApp(L[25],_plus5,[anf_arg373410,anf_arg375423]);
};
try {
if(--R.GAS > 0) {
$z427428 = $f433434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f433434,
"from":L[25]});
}
} catch($e425426) {
if(R.isCont($e425426)) {
var $ss429430 = {"from":L[25],
"go":function(anf_arg376435) {
return $Hanf_arg607436(anf_arg376435,block_DASH_summary159297,summary157286,_plus5);
}};
$e425426.stack[R.EXN_STACKHEIGHT++] = $ss429430;
}
if(R.isPyretException($e425426)) {
$e425426.pyretStack.push(L[25]);
}
throw $e425426;
}
var $ret431432 = $Hanf_arg607436($z427428,block_DASH_summary159297,summary157286,_plus5);
++R.GAS;
return $ret431432;
};
var $Hanf_arg607436 = function(anf_arg376435,block_DASH_summary159297,summary157286,_plus5) {
var $z439440 = D;
var $f445446 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg376435,(") \n")):R.ffi.throwNonFunApp(L[35],_plus5,[anf_arg376435,(") \n")]);
};
try {
if(--R.GAS > 0) {
$z439440 = $f445446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f445446,
"from":L[35]});
}
} catch($e437438) {
if(R.isCont($e437438)) {
var $ss441442 = {"from":L[35],
"go":function(message165447) {
return $Hmessage606448(message165447,block_DASH_summary159297,summary157286,_plus5);
}};
$e437438.stack[R.EXN_STACKHEIGHT++] = $ss441442;
}
if(R.isPyretException($e437438)) {
$e437438.pyretStack.push(L[35]);
}
throw $e437438;
}
var $ret443444 = $Hmessage606448($z439440,block_DASH_summary159297,summary157286,_plus5);
++R.GAS;
return $ret443444;
};
var $Hmessage606448 = function(message165447,block_DASH_summary159297,summary157286,_plus5) {
var anf_arg377484 = G(block_DASH_summary159297,"failed",L[40]);
var if_DASH_45465 = R.equiv(anf_arg377484,(0));
var if_helper378459 = R.makeFunction(function(if_helper_arg379470) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[38],1,arguments);
}
var rest_DASH_of_DASH_message166481 = if_helper_arg379470;
var $z473474 = D;
var $f479480 = function(_) {
return R.isFunction(_plus5)?_plus5.app(message165447,rest_DASH_of_DASH_message166481):R.ffi.throwNonFunApp(L[39],_plus5,[message165447,rest_DASH_of_DASH_message166481]);
};
try {
if(--R.GAS > 0) {
$z473474 = $f479480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f479480,
"from":L[39]});
}
} catch($e471472) {
if(R.isCont($e471472)) {
var $ss475476 = {"from":L[39],
"go":function(anf_obj380482) {
return $Hanf_obj604483(anf_obj380482,block_DASH_summary159297,summary157286,_plus5);
}};
$e471472.stack[R.EXN_STACKHEIGHT++] = $ss475476;
}
if(R.isPyretException($e471472)) {
$e471472.pyretStack.push(L[39]);
}
throw $e471472;
}
var $ret477478 = $Hanf_obj604483($z473474,block_DASH_summary159297,summary157286,_plus5);
++R.GAS;
return $ret477478;
});
var anf_if392469 = R.isBoolean(if_DASH_45465);
if(R.isPyretTrue(anf_if392469)) {
if(R.isPyretTrue(if_DASH_45465)) {
var $z451452 = D;
var $f457458 = function(_) {
return R.isFunction(if_helper378459)?if_helper378459.app(("")):R.ffi.throwNonFunApp(L[36],if_helper378459,[("")]);
};
try {
if(--R.GAS > 0) {
$z451452 = $f457458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f457458,
"from":L[36]});
}
} catch($e449450) {
if(R.isCont($e449450)) {
var $ss453454 = {"from":L[36],
"go":function(cont_tail_app395460) {
return $Hcont_tail_app605461(cont_tail_app395460);
}};
$e449450.stack[R.EXN_STACKHEIGHT++] = $ss453454;
}
if(R.isPyretException($e449450)) {
$e449450.pyretStack.push(L[36]);
}
throw $e449450;
}
var $ret455456 = $Hcont_tail_app605461($z451452);
++R.GAS;
return $ret455456;
} else {
var cont_tail_arg393464 = G(block_DASH_summary159297,"message",L[37]);
if(--R.GAS > 0) {
$z462463 = R.isFunction(if_helper378459)?if_helper378459.app(cont_tail_arg393464):R.ffi.throwNonFunApp(L[37],if_helper378459,[cont_tail_arg393464]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper378459)?if_helper378459.app(cont_tail_arg393464):R.ffi.throwNonFunApp(L[37],if_helper378459,[cont_tail_arg393464]);
},
"from":L[37]});
}
++R.GAS;
return $z462463;
}
} else {
var cont_tail_arg390468 = R.throwNonBooleanCondition(L[38],("if"),if_DASH_45465);
if(--R.GAS > 0) {
$z466467 = R.isFunction(if_helper378459)?if_helper378459.app(cont_tail_arg390468):R.ffi.throwNonFunApp(L[38],if_helper378459,[cont_tail_arg390468]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper378459)?if_helper378459.app(cont_tail_arg390468):R.ffi.throwNonFunApp(L[38],if_helper378459,[cont_tail_arg390468]);
},
"from":L[38]});
}
++R.GAS;
return $z466467;
}
};
var $Hcont_tail_app605461 = function(cont_tail_app395460) {
return cont_tail_app395460;
};
var $Hanf_obj604483 = function(anf_obj380482,block_DASH_summary159297,summary157286,_plus5) {
var anf_arg381495 = G(summary157286,"passed",L[43]);
var anf_arg382496 = G(block_DASH_summary159297,"passed",L[42]);
var $z487488 = D;
var $f493494 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg381495,anf_arg382496):R.ffi.throwNonFunApp(L[41],_plus5,[anf_arg381495,anf_arg382496]);
};
try {
if(--R.GAS > 0) {
$z487488 = $f493494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f493494,
"from":L[41]});
}
} catch($e485486) {
if(R.isCont($e485486)) {
var $ss489490 = {"from":L[41],
"go":function(anf_obj383497) {
return $Hanf_obj603498(anf_obj383497,anf_obj380482,block_DASH_summary159297,summary157286,_plus5);
}};
$e485486.stack[R.EXN_STACKHEIGHT++] = $ss489490;
}
if(R.isPyretException($e485486)) {
$e485486.pyretStack.push(L[41]);
}
throw $e485486;
}
var $ret491492 = $Hanf_obj603498($z487488,anf_obj380482,block_DASH_summary159297,summary157286,_plus5);
++R.GAS;
return $ret491492;
};
var $Hanf_obj603498 = function(anf_obj383497,anf_obj380482,block_DASH_summary159297,summary157286,_plus5) {
var anf_arg384509 = G(summary157286,"failed",L[46]);
var anf_arg385510 = G(block_DASH_summary159297,"failed",L[45]);
var $z501502 = D;
var $f507508 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg384509,anf_arg385510):R.ffi.throwNonFunApp(L[44],_plus5,[anf_arg384509,anf_arg385510]);
};
try {
if(--R.GAS > 0) {
$z501502 = $f507508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f507508,
"from":L[44]});
}
} catch($e499500) {
if(R.isCont($e499500)) {
var $ss503504 = {"from":L[44],
"go":function(anf_obj386511) {
return $Hanf_obj602512(anf_obj386511,anf_obj380482,anf_obj383497,block_DASH_summary159297,summary157286,_plus5);
}};
$e499500.stack[R.EXN_STACKHEIGHT++] = $ss503504;
}
if(R.isPyretException($e499500)) {
$e499500.pyretStack.push(L[44]);
}
throw $e499500;
}
var $ret505506 = $Hanf_obj602512($z501502,anf_obj380482,anf_obj383497,block_DASH_summary159297,summary157286,_plus5);
++R.GAS;
return $ret505506;
};
var $Hanf_obj602512 = function(anf_obj386511,anf_obj380482,anf_obj383497,block_DASH_summary159297,summary157286,_plus5) {
var anf_arg387523 = G(summary157286,"total",L[49]);
var anf_arg388524 = G(block_DASH_summary159297,"total",L[48]);
var $z515516 = D;
var $f521522 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg387523,anf_arg388524):R.ffi.throwNonFunApp(L[47],_plus5,[anf_arg387523,anf_arg388524]);
};
try {
if(--R.GAS > 0) {
$z515516 = $f521522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f521522,
"from":L[47]});
}
} catch($e513514) {
if(R.isCont($e513514)) {
var $ss517518 = {"from":L[47],
"go":function(anf_obj389525) {
return $Hanf_obj601526(anf_obj389525,anf_obj380482,anf_obj383497,anf_obj386511);
}};
$e513514.stack[R.EXN_STACKHEIGHT++] = $ss517518;
}
if(R.isPyretException($e513514)) {
$e513514.pyretStack.push(L[47]);
}
throw $e513514;
}
var $ret519520 = $Hanf_obj601526($z515516,anf_obj380482,anf_obj383497,anf_obj386511);
++R.GAS;
return $ret519520;
};
var $Hanf_obj601526 = function(anf_obj389525,anf_obj380482,anf_obj383497,anf_obj386511) {
var ann_DASH_check_DASH_temp325527 = R.makeObject({"message":anf_obj380482,
"passed":anf_obj383497,
"failed":anf_obj386511,
"total":anf_obj389525});
return ann_DASH_check_DASH_temp325527;
};
var $Hann_DASH_check_DASH_temp600528 = function(ann_DASH_check_DASH_temp326529) {
return ann_DASH_check_DASH_temp326529;
};
var $Hanf_arg599530 = function(anf_arg343531,s160532,tr161533,_plus5) {
var anf_bracket344547 = G(tr161533,"loc",L[52]);
var anf_fun345544 = G(anf_bracket344547,"format",L[51]);
var $z536537 = D;
var $f542543 = function(_) {
return R.isFunction(anf_fun345544)?anf_fun345544.app((false)):R.ffi.throwNonFunApp(L[50],anf_fun345544,[(false)]);
};
try {
if(--R.GAS > 0) {
$z536537 = $f542543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f542543,
"from":L[50]});
}
} catch($e534535) {
if(R.isCont($e534535)) {
var $ss538539 = {"from":L[50],
"go":function(anf_arg346545) {
return $Hanf_arg598546(anf_arg346545,anf_arg343531,s160532,tr161533,_plus5);
}};
$e534535.stack[R.EXN_STACKHEIGHT++] = $ss538539;
}
if(R.isPyretException($e534535)) {
$e534535.pyretStack.push(L[50]);
}
throw $e534535;
}
var $ret540541 = $Hanf_arg598546($z536537,anf_arg343531,s160532,tr161533,_plus5);
++R.GAS;
return $ret540541;
};
var $Hanf_arg598546 = function(anf_arg346545,anf_arg343531,s160532,tr161533,_plus5) {
var $z550551 = D;
var $f556557 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg343531,anf_arg346545):R.ffi.throwNonFunApp(L[53],_plus5,[anf_arg343531,anf_arg346545]);
};
try {
if(--R.GAS > 0) {
$z550551 = $f556557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f556557,
"from":L[53]});
}
} catch($e548549) {
if(R.isCont($e548549)) {
var $ss552553 = {"from":L[53],
"go":function(anf_arg347558) {
return $Hanf_arg597559(anf_arg347558,s160532,tr161533,_plus5);
}};
$e548549.stack[R.EXN_STACKHEIGHT++] = $ss552553;
}
if(R.isPyretException($e548549)) {
$e548549.pyretStack.push(L[53]);
}
throw $e548549;
}
var $ret554555 = $Hanf_arg597559($z550551,s160532,tr161533,_plus5);
++R.GAS;
return $ret554555;
};
var $Hanf_arg597559 = function(anf_arg347558,s160532,tr161533,_plus5) {
var $z562563 = D;
var $f568569 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg347558,(": failed because: \n    ")):R.ffi.throwNonFunApp(L[53],_plus5,[anf_arg347558,(": failed because: \n    ")]);
};
try {
if(--R.GAS > 0) {
$z562563 = $f568569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f568569,
"from":L[53]});
}
} catch($e560561) {
if(R.isCont($e560561)) {
var $ss564565 = {"from":L[53],
"go":function(anf_arg348570) {
return $Hanf_arg596571(anf_arg348570,s160532,tr161533,_plus5);
}};
$e560561.stack[R.EXN_STACKHEIGHT++] = $ss564565;
}
if(R.isPyretException($e560561)) {
$e560561.pyretStack.push(L[53]);
}
throw $e560561;
}
var $ret566567 = $Hanf_arg596571($z562563,s160532,tr161533,_plus5);
++R.GAS;
return $ret566567;
};
var $Hanf_arg596571 = function(anf_arg348570,s160532,tr161533,_plus5) {
var anf_fun349582 = G(tr161533,"reason",L[55]);
var $z574575 = D;
var $f580581 = function(_) {
return R.isFunction(anf_fun349582)?anf_fun349582.app():R.ffi.throwNonFunApp(L[54],anf_fun349582,[]);
};
try {
if(--R.GAS > 0) {
$z574575 = $f580581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f580581,
"from":L[54]});
}
} catch($e572573) {
if(R.isCont($e572573)) {
var $ss576577 = {"from":L[54],
"go":function(anf_arg350583) {
return $Hanf_arg595584(anf_arg350583,anf_arg348570,s160532,_plus5);
}};
$e572573.stack[R.EXN_STACKHEIGHT++] = $ss576577;
}
if(R.isPyretException($e572573)) {
$e572573.pyretStack.push(L[54]);
}
throw $e572573;
}
var $ret578579 = $Hanf_arg595584($z574575,anf_arg348570,s160532,_plus5);
++R.GAS;
return $ret578579;
};
var $Hanf_arg595584 = function(anf_arg350583,anf_arg348570,s160532,_plus5) {
var $z587588 = D;
var $f593594 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg348570,anf_arg350583):R.ffi.throwNonFunApp(L[56],_plus5,[anf_arg348570,anf_arg350583]);
};
try {
if(--R.GAS > 0) {
$z587588 = $f593594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f593594,
"from":L[56]});
}
} catch($e585586) {
if(R.isCont($e585586)) {
var $ss589590 = {"from":L[56],
"go":function(m164595) {
return $Hm594596(m164595,s160532,_plus5);
}};
$e585586.stack[R.EXN_STACKHEIGHT++] = $ss589590;
}
if(R.isPyretException($e585586)) {
$e585586.pyretStack.push(L[56]);
}
throw $e585586;
}
var $ret591592 = $Hm594596($z587588,s160532,_plus5);
++R.GAS;
return $ret591592;
};
var $Hm594596 = function(m164595,s160532,_plus5) {
var anf_arg351607 = G(s160532,"failed",L[58]);
var $z599600 = D;
var $f605606 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg351607,(1)):R.ffi.throwNonFunApp(L[57],_plus5,[anf_arg351607,(1)]);
};
try {
if(--R.GAS > 0) {
$z599600 = $f605606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f605606,
"from":L[57]});
}
} catch($e597598) {
if(R.isCont($e597598)) {
var $ss601602 = {"from":L[57],
"go":function(anf_extend352608) {
return $Hanf_extend593609(anf_extend352608,m164595,s160532,_plus5);
}};
$e597598.stack[R.EXN_STACKHEIGHT++] = $ss601602;
}
if(R.isPyretException($e597598)) {
$e597598.pyretStack.push(L[57]);
}
throw $e597598;
}
var $ret603604 = $Hanf_extend593609($z599600,m164595,s160532,_plus5);
++R.GAS;
return $ret603604;
};
var $Hanf_extend593609 = function(anf_extend352608,m164595,s160532,_plus5) {
var anf_arg353620 = G(s160532,"total",L[60]);
var $z612613 = D;
var $f618619 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg353620,(1)):R.ffi.throwNonFunApp(L[59],_plus5,[anf_arg353620,(1)]);
};
try {
if(--R.GAS > 0) {
$z612613 = $f618619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f618619,
"from":L[59]});
}
} catch($e610611) {
if(R.isCont($e610611)) {
var $ss614615 = {"from":L[59],
"go":function(anf_extend354621) {
return $Hanf_extend592622(anf_extend354621,anf_extend352608,m164595,s160532);
}};
$e610611.stack[R.EXN_STACKHEIGHT++] = $ss614615;
}
if(R.isPyretException($e610611)) {
$e610611.pyretStack.push(L[59]);
}
throw $e610611;
}
var $ret616617 = $Hanf_extend592622($z612613,anf_extend352608,m164595,s160532);
++R.GAS;
return $ret616617;
};
var $Hanf_extend592622 = function(anf_extend354621,anf_extend352608,m164595,s160532) {
var ann_DASH_check_DASH_temp341623 = s160532.extendWith({"message":m164595,
"failed":anf_extend352608,
"total":anf_extend354621});
return ann_DASH_check_DASH_temp341623;
};
var $Hanf_arg591624 = function(anf_arg330625,loc162626,s160532,_plus5) {
var anf_fun331637 = G(loc162626,"format",L[62]);
var $z629630 = D;
var $f635636 = function(_) {
return R.isFunction(anf_fun331637)?anf_fun331637.app((false)):R.ffi.throwNonFunApp(L[61],anf_fun331637,[(false)]);
};
try {
if(--R.GAS > 0) {
$z629630 = $f635636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f635636,
"from":L[61]});
}
} catch($e627628) {
if(R.isCont($e627628)) {
var $ss631632 = {"from":L[61],
"go":function(anf_arg332638) {
return $Hanf_arg590639(anf_arg332638,anf_arg330625,s160532,_plus5);
}};
$e627628.stack[R.EXN_STACKHEIGHT++] = $ss631632;
}
if(R.isPyretException($e627628)) {
$e627628.pyretStack.push(L[61]);
}
throw $e627628;
}
var $ret633634 = $Hanf_arg590639($z629630,anf_arg330625,s160532,_plus5);
++R.GAS;
return $ret633634;
};
var $Hanf_arg590639 = function(anf_arg332638,anf_arg330625,s160532,_plus5) {
var $z642643 = D;
var $f648649 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg330625,anf_arg332638):R.ffi.throwNonFunApp(L[63],_plus5,[anf_arg330625,anf_arg332638]);
};
try {
if(--R.GAS > 0) {
$z642643 = $f648649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f648649,
"from":L[63]});
}
} catch($e640641) {
if(R.isCont($e640641)) {
var $ss644645 = {"from":L[63],
"go":function(anf_arg333650) {
return $Hanf_arg589651(anf_arg333650,s160532,_plus5);
}};
$e640641.stack[R.EXN_STACKHEIGHT++] = $ss644645;
}
if(R.isPyretException($e640641)) {
$e640641.pyretStack.push(L[63]);
}
throw $e640641;
}
var $ret646647 = $Hanf_arg589651($z642643,s160532,_plus5);
++R.GAS;
return $ret646647;
};
var $Hanf_arg589651 = function(anf_arg333650,s160532,_plus5) {
var $z654655 = D;
var $f660661 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg333650,(": ok")):R.ffi.throwNonFunApp(L[63],_plus5,[anf_arg333650,(": ok")]);
};
try {
if(--R.GAS > 0) {
$z654655 = $f660661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f660661,
"from":L[63]});
}
} catch($e652653) {
if(R.isCont($e652653)) {
var $ss656657 = {"from":L[63],
"go":function(anf_extend334662) {
return $Hanf_extend588663(anf_extend334662,s160532,_plus5);
}};
$e652653.stack[R.EXN_STACKHEIGHT++] = $ss656657;
}
if(R.isPyretException($e652653)) {
$e652653.pyretStack.push(L[63]);
}
throw $e652653;
}
var $ret658659 = $Hanf_extend588663($z654655,s160532,_plus5);
++R.GAS;
return $ret658659;
};
var $Hanf_extend588663 = function(anf_extend334662,s160532,_plus5) {
var anf_arg335674 = G(s160532,"passed",L[65]);
var $z666667 = D;
var $f672673 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg335674,(1)):R.ffi.throwNonFunApp(L[64],_plus5,[anf_arg335674,(1)]);
};
try {
if(--R.GAS > 0) {
$z666667 = $f672673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f672673,
"from":L[64]});
}
} catch($e664665) {
if(R.isCont($e664665)) {
var $ss668669 = {"from":L[64],
"go":function(anf_extend336675) {
return $Hanf_extend587676(anf_extend336675,anf_extend334662,s160532,_plus5);
}};
$e664665.stack[R.EXN_STACKHEIGHT++] = $ss668669;
}
if(R.isPyretException($e664665)) {
$e664665.pyretStack.push(L[64]);
}
throw $e664665;
}
var $ret670671 = $Hanf_extend587676($z666667,anf_extend334662,s160532,_plus5);
++R.GAS;
return $ret670671;
};
var $Hanf_extend587676 = function(anf_extend336675,anf_extend334662,s160532,_plus5) {
var anf_arg337687 = G(s160532,"total",L[67]);
var $z679680 = D;
var $f685686 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg337687,(1)):R.ffi.throwNonFunApp(L[66],_plus5,[anf_arg337687,(1)]);
};
try {
if(--R.GAS > 0) {
$z679680 = $f685686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f685686,
"from":L[66]});
}
} catch($e677678) {
if(R.isCont($e677678)) {
var $ss681682 = {"from":L[66],
"go":function(anf_extend338688) {
return $Hanf_extend586689(anf_extend338688,anf_extend334662,anf_extend336675,s160532);
}};
$e677678.stack[R.EXN_STACKHEIGHT++] = $ss681682;
}
if(R.isPyretException($e677678)) {
$e677678.pyretStack.push(L[66]);
}
throw $e677678;
}
var $ret683684 = $Hanf_extend586689($z679680,anf_extend334662,anf_extend336675,s160532);
++R.GAS;
return $ret683684;
};
var $Hanf_extend586689 = function(anf_extend338688,anf_extend334662,anf_extend336675,s160532) {
var ann_DASH_check_DASH_temp328690 = s160532.extendWith({"message":anf_extend334662,
"passed":anf_extend336675,
"total":anf_extend338688});
return ann_DASH_check_DASH_temp328690;
};
var $Hvar_DASH_bind585691 = function(var_DASH_bind542692,CheckBlockResult6235,TestResult6437,check_DASH_all113693,check_DASH_block_DASH_result71694,each41695,failure_DASH_no_DASH_exn84696,failure_DASH_not_DASH_equal78697,failure_DASH_not_DASH_satisfied80698,failure_DASH_wrong_DASH_exn82699,list21700,main_DASH_module_DASH_name112701,render_DASH_check_DASH_results87702,results_DASH_summary86703,success76704,_plus5,nothing7,run_DASH_task8,string_DASH_contains9,torepr10) {
var block_DASH_results114719 = {"$var":var_DASH_bind542692,
"$name":"block-results"};
var add_DASH_block_DASH_result115705 = {"$var":D,
"$name":"add-block-result"};
var anf_assign227706 = R.makeFunction(function(cbr116721) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[70],1,arguments);
}
return R.checkAnnArgs([CheckBlockResult6235],[cbr116721],[L[72]],function() {
var anf_fun224732 = G(list21700,"make",L[71]);
var $z724725 = D;
var $f730731 = function(_) {
return R.isFunction(anf_fun224732)?anf_fun224732.app([cbr116721]):R.ffi.throwNonFunApp(L[71],anf_fun224732,[[cbr116721]]);
};
try {
if(--R.GAS > 0) {
$z724725 = $f730731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f730731,
"from":L[71]});
}
} catch($e722723) {
if(R.isCont($e722723)) {
var $ss726727 = {"from":L[71],
"go":function(anf_arg225733) {
return $Hanf_arg544734(anf_arg225733,block_DASH_results114719,_plus5);
}};
$e722723.stack[R.EXN_STACKHEIGHT++] = $ss726727;
}
if(R.isPyretException($e722723)) {
$e722723.pyretStack.push(L[71]);
}
throw $e722723;
}
var $ret728729 = $Hanf_arg544734($z724725,block_DASH_results114719,_plus5);
++R.GAS;
return $ret728729;
});
});
add_DASH_block_DASH_result115705.$var = anf_assign227706;
var anf_fun228717 = G(list21700,"make",L[69]);
var $z709710 = D;
var $f715716 = function(_) {
return R.isFunction(anf_fun228717)?anf_fun228717.app([]):R.ffi.throwNonFunApp(L[68],anf_fun228717,[[]]);
};
try {
if(--R.GAS > 0) {
$z709710 = $f715716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f715716,
"from":L[68]});
}
} catch($e707708) {
if(R.isCont($e707708)) {
var $ss711712 = {"from":L[68],
"go":function(var_DASH_bind545718) {
return $Hvar_DASH_bind584720(var_DASH_bind545718,TestResult6437,add_DASH_block_DASH_result115705,block_DASH_results114719,check_DASH_all113693,check_DASH_block_DASH_result71694,each41695,failure_DASH_no_DASH_exn84696,failure_DASH_not_DASH_equal78697,failure_DASH_not_DASH_satisfied80698,failure_DASH_wrong_DASH_exn82699,list21700,main_DASH_module_DASH_name112701,render_DASH_check_DASH_results87702,results_DASH_summary86703,success76704,_plus5,nothing7,run_DASH_task8,string_DASH_contains9,torepr10);
}};
$e707708.stack[R.EXN_STACKHEIGHT++] = $ss711712;
}
if(R.isPyretException($e707708)) {
$e707708.pyretStack.push(L[68]);
}
throw $e707708;
}
var $ret713714 = $Hvar_DASH_bind584720($z709710,TestResult6437,add_DASH_block_DASH_result115705,block_DASH_results114719,check_DASH_all113693,check_DASH_block_DASH_result71694,each41695,failure_DASH_no_DASH_exn84696,failure_DASH_not_DASH_equal78697,failure_DASH_not_DASH_satisfied80698,failure_DASH_wrong_DASH_exn82699,list21700,main_DASH_module_DASH_name112701,render_DASH_check_DASH_results87702,results_DASH_summary86703,success76704,_plus5,nothing7,run_DASH_task8,string_DASH_contains9,torepr10);
++R.GAS;
return $ret713714;
};
var $Hvar_DASH_bind584720 = function(var_DASH_bind545718,TestResult6437,add_DASH_block_DASH_result115705,block_DASH_results114719,check_DASH_all113693,check_DASH_block_DASH_result71694,each41695,failure_DASH_no_DASH_exn84696,failure_DASH_not_DASH_equal78697,failure_DASH_not_DASH_satisfied80698,failure_DASH_wrong_DASH_exn82699,list21700,main_DASH_module_DASH_name112701,render_DASH_check_DASH_results87702,results_DASH_summary86703,success76704,_plus5,nothing7,run_DASH_task8,string_DASH_contains9,torepr10) {
var current_DASH_results117945 = {"$var":var_DASH_bind545718,
"$name":"current-results"};
var add_DASH_result118735 = {"$var":D,
"$name":"add-result"};
var reset_DASH_results119737 = {"$var":D,
"$name":"reset-results"};
var anf_assign233736 = R.makeFunction(function(t120980) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[99],1,arguments);
}
return R.checkAnnArgs([TestResult6437],[t120980],[L[101]],function() {
var anf_fun230991 = G(list21700,"make",L[100]);
var $z983984 = D;
var $f989990 = function(_) {
return R.isFunction(anf_fun230991)?anf_fun230991.app([t120980]):R.ffi.throwNonFunApp(L[100],anf_fun230991,[[t120980]]);
};
try {
if(--R.GAS > 0) {
$z983984 = $f989990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f989990,
"from":L[100]});
}
} catch($e981982) {
if(R.isCont($e981982)) {
var $ss985986 = {"from":L[100],
"go":function(anf_arg231992) {
return $Hanf_arg547993(anf_arg231992,current_DASH_results117945,_plus5);
}};
$e981982.stack[R.EXN_STACKHEIGHT++] = $ss985986;
}
if(R.isPyretException($e981982)) {
$e981982.pyretStack.push(L[100]);
}
throw $e981982;
}
var $ret987988 = $Hanf_arg547993($z983984,current_DASH_results117945,_plus5);
++R.GAS;
return $ret987988;
});
});
add_DASH_result118735.$var = anf_assign233736;
var anf_assign237738 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[97],0,arguments);
}
var anf_fun235977 = G(list21700,"make",L[98]);
var $z969970 = D;
var $f975976 = function(_) {
return R.isFunction(anf_fun235977)?anf_fun235977.app([]):R.ffi.throwNonFunApp(L[98],anf_fun235977,[[]]);
};
try {
if(--R.GAS > 0) {
$z969970 = $f975976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f975976,
"from":L[98]});
}
} catch($e967968) {
if(R.isCont($e967968)) {
var $ss971972 = {"from":L[98],
"go":function(anf_assign236978) {
return $Hanf_assign548979(anf_assign236978,current_DASH_results117945);
}};
$e967968.stack[R.EXN_STACKHEIGHT++] = $ss971972;
}
if(R.isPyretException($e967968)) {
$e967968.pyretStack.push(L[98]);
}
throw $e967968;
}
var $ret973974 = $Hanf_assign548979($z969970,current_DASH_results117945);
++R.GAS;
return $ret973974;
});
reset_DASH_results119737.$var = anf_assign237738;
var anf_obj262740 = R.makeMethod(function(self121966) {
return function(module_DASH_name122911,checks123929) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[96],2,arguments);
}
var or_DASH_oper_DASH_38912 = check_DASH_all113693;
var if_helper239891 = R.makeFunction(function(if_helper_arg240917) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[90],1,arguments);
}
var when_DASH_37959 = if_helper_arg240917;
var if_helper241931 = R.makeFunction(function(if_helper_arg242964) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[95],1,arguments);
}
var ann_DASH_check_DASH_temp238965 = if_helper_arg242964;
return ann_DASH_check_DASH_temp238965;
});
var anf_if245963 = R.isBoolean(when_DASH_37959);
if(R.isPyretTrue(anf_if245963)) {
if(R.isPyretTrue(when_DASH_37959)) {
var anf_arg252928 = R.makeFunction(function(c124933) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[93],1,arguments);
}
var $z936937 = D;
var $f942943 = function(_) {
return R.isFunction(reset_DASH_results119737.$var)?reset_DASH_results119737.$var.app():R.ffi.throwNonFunApp(L[94],reset_DASH_results119737.$var,[]);
};
try {
if(--R.GAS > 0) {
$z936937 = $f942943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f942943,
"from":L[94]});
}
} catch($e934935) {
if(R.isCont($e934935)) {
var $ss938939 = {"from":L[94],
"go":function(anf_begin_app_dropped549944) {
return $Hanf_begin_app_dropped554946(anf_begin_app_dropped549944,add_DASH_block_DASH_result115705,c124933,check_DASH_block_DASH_result71694,current_DASH_results117945);
}};
$e934935.stack[R.EXN_STACKHEIGHT++] = $ss938939;
}
if(R.isPyretException($e934935)) {
$e934935.pyretStack.push(L[94]);
}
throw $e934935;
}
var $ret940941 = $Hanf_begin_app_dropped554946($z936937,add_DASH_block_DASH_result115705,c124933,check_DASH_block_DASH_result71694,current_DASH_results117945);
++R.GAS;
return $ret940941;
});
var $z920921 = D;
var $f926927 = function(_) {
return R.isFunction(each41695)?each41695.app(anf_arg252928,checks123929):R.ffi.throwNonFunApp(L[93],each41695,[anf_arg252928,checks123929]);
};
try {
if(--R.GAS > 0) {
$z920921 = $f926927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f926927,
"from":L[93]});
}
} catch($e918919) {
if(R.isCont($e918919)) {
var $ss922923 = {"from":L[93],
"go":function(anf_begin_app_dropped555930) {
return $Hanf_begin_app_dropped557932(anf_begin_app_dropped555930,if_helper241931,nothing7);
}};
$e918919.stack[R.EXN_STACKHEIGHT++] = $ss922923;
}
if(R.isPyretException($e918919)) {
$e918919.pyretStack.push(L[93]);
}
throw $e918919;
}
var $ret924925 = $Hanf_begin_app_dropped557932($z920921,if_helper241931,nothing7);
++R.GAS;
return $ret924925;
} else {
var $z949950 = D;
var $f955956 = function(_) {
return R.isFunction(if_helper241931)?if_helper241931.app(nothing7):R.ffi.throwNonFunApp(L[95],if_helper241931,[nothing7]);
};
try {
if(--R.GAS > 0) {
$z949950 = $f955956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f955956,
"from":L[95]});
}
} catch($e947948) {
if(R.isCont($e947948)) {
var $ss951952 = {"from":L[95],
"go":function(cont_tail_app246957) {
return $Hcont_tail_app558958(cont_tail_app246957);
}};
$e947948.stack[R.EXN_STACKHEIGHT++] = $ss951952;
}
if(R.isPyretException($e947948)) {
$e947948.pyretStack.push(L[95]);
}
throw $e947948;
}
var $ret953954 = $Hcont_tail_app558958($z949950);
++R.GAS;
return $ret953954;
}
} else {
var cont_tail_arg243962 = R.throwNonBooleanCondition(L[90],("when"),when_DASH_37959);
if(--R.GAS > 0) {
$z960961 = R.isFunction(if_helper241931)?if_helper241931.app(cont_tail_arg243962):R.ffi.throwNonFunApp(L[90],if_helper241931,[cont_tail_arg243962]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper241931)?if_helper241931.app(cont_tail_arg243962):R.ffi.throwNonFunApp(L[90],if_helper241931,[cont_tail_arg243962]);
},
"from":L[90]});
}
++R.GAS;
return $z960961;
}
});
var anf_if256916 = R.isBoolean(or_DASH_oper_DASH_38912);
if(R.isPyretTrue(anf_if256916)) {
if(R.isPyretTrue(or_DASH_oper_DASH_38912)) {
var $z883884 = D;
var $f889890 = function(_) {
return R.isFunction(if_helper239891)?if_helper239891.app((true)):R.ffi.throwNonFunApp(L[90],if_helper239891,[(true)]);
};
try {
if(--R.GAS > 0) {
$z883884 = $f889890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f889890,
"from":L[90]});
}
} catch($e881882) {
if(R.isCont($e881882)) {
var $ss885886 = {"from":L[90],
"go":function(cont_tail_app261892) {
return $Hcont_tail_app559893(cont_tail_app261892);
}};
$e881882.stack[R.EXN_STACKHEIGHT++] = $ss885886;
}
if(R.isPyretException($e881882)) {
$e881882.pyretStack.push(L[90]);
}
throw $e881882;
}
var $ret887888 = $Hcont_tail_app559893($z883884);
++R.GAS;
return $ret887888;
} else {
var or_DASH_oper_DASH_39904 = R.equiv(module_DASH_name122911,main_DASH_module_DASH_name112701);
var anf_if259910 = R.isBoolean(or_DASH_oper_DASH_39904);
if(R.isPyretTrue(anf_if259910)) {
var $z896897 = D;
var $f902903 = function(_) {
return R.isFunction(if_helper239891)?if_helper239891.app(or_DASH_oper_DASH_39904):R.ffi.throwNonFunApp(L[90],if_helper239891,[or_DASH_oper_DASH_39904]);
};
try {
if(--R.GAS > 0) {
$z896897 = $f902903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f902903,
"from":L[90]});
}
} catch($e894895) {
if(R.isCont($e894895)) {
var $ss898899 = {"from":L[90],
"go":function(cont_tail_app260905) {
return $Hcont_tail_app560906(cont_tail_app260905);
}};
$e894895.stack[R.EXN_STACKHEIGHT++] = $ss898899;
}
if(R.isPyretException($e894895)) {
$e894895.pyretStack.push(L[90]);
}
throw $e894895;
}
var $ret900901 = $Hcont_tail_app560906($z896897);
++R.GAS;
return $ret900901;
} else {
var cont_tail_arg257909 = R.throwNonBooleanOp(L[91],("second"),("or"),or_DASH_oper_DASH_39904);
if(--R.GAS > 0) {
$z907908 = R.isFunction(if_helper239891)?if_helper239891.app(cont_tail_arg257909):R.ffi.throwNonFunApp(L[91],if_helper239891,[cont_tail_arg257909]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper239891)?if_helper239891.app(cont_tail_arg257909):R.ffi.throwNonFunApp(L[91],if_helper239891,[cont_tail_arg257909]);
},
"from":L[91]});
}
++R.GAS;
return $z907908;
}
}
} else {
var cont_tail_arg254915 = R.throwNonBooleanOp(L[92],("first"),("or"),or_DASH_oper_DASH_38912);
if(--R.GAS > 0) {
$z913914 = R.isFunction(if_helper239891)?if_helper239891.app(cont_tail_arg254915):R.ffi.throwNonFunApp(L[92],if_helper239891,[cont_tail_arg254915]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper239891)?if_helper239891.app(cont_tail_arg254915):R.ffi.throwNonFunApp(L[92],if_helper239891,[cont_tail_arg254915]);
},
"from":L[92]});
}
++R.GAS;
return $z913914;
}
};
},{"length":3});
var anf_obj275741 = R.makeMethod(function(self125880) {
return function(code126855,left127869,right128870,loc129854) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[89],4,arguments);
}
var if_DASH_40873 = R.equiv(left127869,right128870);
var if_helper264857 = R.makeFunction(function(if_helper_arg265878) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[88],1,arguments);
}
var ann_DASH_check_DASH_temp263879 = if_helper_arg265878;
return ann_DASH_check_DASH_temp263879;
});
var anf_if268877 = R.isBoolean(if_DASH_40873);
if(R.isPyretTrue(anf_if268877)) {
if(R.isPyretTrue(if_DASH_40873)) {
var $z846847 = D;
var $f852853 = function(_) {
return R.isFunction(success76704.$var)?success76704.$var.app(loc129854,code126855):R.ffi.throwNonFunApp(L[86],success76704.$var,[loc129854,code126855]);
};
try {
if(--R.GAS > 0) {
$z846847 = $f852853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f852853,
"from":L[86]});
}
} catch($e844845) {
if(R.isCont($e844845)) {
var $ss848849 = {"from":L[86],
"go":function(anf_arg272856) {
return $Hanf_arg562858(anf_arg272856,add_DASH_result118735,if_helper264857);
}};
$e844845.stack[R.EXN_STACKHEIGHT++] = $ss848849;
}
if(R.isPyretException($e844845)) {
$e844845.pyretStack.push(L[86]);
}
throw $e844845;
}
var $ret850851 = $Hanf_arg562858($z846847,add_DASH_result118735,if_helper264857);
++R.GAS;
return $ret850851;
} else {
var $z861862 = D;
var $f867868 = function(_) {
return R.isFunction(failure_DASH_not_DASH_equal78697.$var)?failure_DASH_not_DASH_equal78697.$var.app(loc129854,code126855,left127869,right128870):R.ffi.throwNonFunApp(L[87],failure_DASH_not_DASH_equal78697.$var,[loc129854,code126855,left127869,right128870]);
};
try {
if(--R.GAS > 0) {
$z861862 = $f867868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f867868,
"from":L[87]});
}
} catch($e859860) {
if(R.isCont($e859860)) {
var $ss863864 = {"from":L[87],
"go":function(anf_arg269871) {
return $Hanf_arg564872(anf_arg269871,add_DASH_result118735,if_helper264857);
}};
$e859860.stack[R.EXN_STACKHEIGHT++] = $ss863864;
}
if(R.isPyretException($e859860)) {
$e859860.pyretStack.push(L[87]);
}
throw $e859860;
}
var $ret865866 = $Hanf_arg564872($z861862,add_DASH_result118735,if_helper264857);
++R.GAS;
return $ret865866;
}
} else {
var cont_tail_arg266876 = R.throwNonBooleanCondition(L[88],("if"),if_DASH_40873);
if(--R.GAS > 0) {
$z874875 = R.isFunction(if_helper264857)?if_helper264857.app(cont_tail_arg266876):R.ffi.throwNonFunApp(L[88],if_helper264857,[cont_tail_arg266876]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper264857)?if_helper264857.app(cont_tail_arg266876):R.ffi.throwNonFunApp(L[88],if_helper264857,[cont_tail_arg266876]);
},
"from":L[88]});
}
++R.GAS;
return $z874875;
}
};
},{"length":5});
var anf_obj288742 = R.makeMethod(function(self130843) {
return function(code131840,left132838,pred133837,loc134841) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[85],4,arguments);
}
var $z829830 = D;
var $f835836 = function(_) {
return R.isFunction(pred133837)?pred133837.app(left132838):R.ffi.throwNonFunApp(L[84],pred133837,[left132838]);
};
try {
if(--R.GAS > 0) {
$z829830 = $f835836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f835836,
"from":L[84]});
}
} catch($e827828) {
if(R.isCont($e827828)) {
var $ss831832 = {"from":L[84],
"go":function(if_DASH_41839) {
return $Hif_DASH_569842(if_DASH_41839,add_DASH_result118735,code131840,failure_DASH_not_DASH_satisfied80698,left132838,loc134841,pred133837,success76704);
}};
$e827828.stack[R.EXN_STACKHEIGHT++] = $ss831832;
}
if(R.isPyretException($e827828)) {
$e827828.pyretStack.push(L[84]);
}
throw $e827828;
}
var $ret833834 = $Hif_DASH_569842($z829830,add_DASH_result118735,code131840,failure_DASH_not_DASH_satisfied80698,left132838,loc134841,pred133837,success76704);
++R.GAS;
return $ret833834;
};
},{"length":5});
var anf_obj310743 = R.makeMethod(function(self135826) {
return function(code136821,thunk137819,expected138823,comparator139822,loc140824) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[83],5,arguments);
}
var $z811812 = D;
var $f817818 = function(_) {
return R.isFunction(run_DASH_task8)?run_DASH_task8.app(thunk137819):R.ffi.throwNonFunApp(L[82],run_DASH_task8,[thunk137819]);
};
try {
if(--R.GAS > 0) {
$z811812 = $f817818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f817818,
"from":L[82]});
}
} catch($e809810) {
if(R.isCont($e809810)) {
var $ss813814 = {"from":L[82],
"go":function(result141820) {
return $Hresult578825(result141820,add_DASH_result118735,code136821,comparator139822,expected138823,failure_DASH_no_DASH_exn84696,failure_DASH_wrong_DASH_exn82699,loc140824,success76704);
}};
$e809810.stack[R.EXN_STACKHEIGHT++] = $ss813814;
}
if(R.isPyretException($e809810)) {
$e809810.pyretStack.push(L[82]);
}
throw $e809810;
}
var $ret815816 = $Hresult578825($z811812,add_DASH_result118735,code136821,comparator139822,expected138823,failure_DASH_no_DASH_exn84696,failure_DASH_wrong_DASH_exn82699,loc140824,success76704);
++R.GAS;
return $ret815816;
};
},{"length":6});
var anf_obj316744 = R.makeMethod(function(self144808) {
return function(code145787,thunk146788,str147789,loc148791) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[78],4,arguments);
}
var anf_fun312786 = G(self144808,"check-raises",L[81]);
var anf_arg315790 = R.makeFunction(function(exn149794,s150795) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[79],2,arguments);
}
var $z798799 = D;
var $f804805 = function(_) {
return R.isFunction(torepr10)?torepr10.app(exn149794):R.ffi.throwNonFunApp(L[80],torepr10,[exn149794]);
};
try {
if(--R.GAS > 0) {
$z798799 = $f804805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f804805,
"from":L[80]});
}
} catch($e796797) {
if(R.isCont($e796797)) {
var $ss800801 = {"from":L[80],
"go":function(anf_arg314806) {
return $Hanf_arg580807(anf_arg314806,s150795,string_DASH_contains9);
}};
$e796797.stack[R.EXN_STACKHEIGHT++] = $ss800801;
}
if(R.isPyretException($e796797)) {
$e796797.pyretStack.push(L[80]);
}
throw $e796797;
}
var $ret802803 = $Hanf_arg580807($z798799,s150795,string_DASH_contains9);
++R.GAS;
return $ret802803;
});
var $z778779 = D;
var $f784785 = function(_) {
return R.isFunction(anf_fun312786)?anf_fun312786.app(code145787,thunk146788,str147789,anf_arg315790,loc148791):R.ffi.throwNonFunApp(L[78],anf_fun312786,[code145787,thunk146788,str147789,anf_arg315790,loc148791]);
};
try {
if(--R.GAS > 0) {
$z778779 = $f784785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f784785,
"from":L[78]});
}
} catch($e776777) {
if(R.isCont($e776777)) {
var $ss780781 = {"from":L[78],
"go":function(ann_DASH_check_DASH_temp311792) {
return $Hann_DASH_check_DASH_temp581793(ann_DASH_check_DASH_temp311792);
}};
$e776777.stack[R.EXN_STACKHEIGHT++] = $ss780781;
}
if(R.isPyretException($e776777)) {
$e776777.pyretStack.push(L[78]);
}
throw $e776777;
}
var $ret782783 = $Hann_DASH_check_DASH_temp581793($z778779);
++R.GAS;
return $ret782783;
};
},{"length":5});
var anf_obj318745 = R.makeMethod(function(self151775) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[77],0,arguments);
}
var $z765766 = D;
var $f771772 = function(_) {
return R.isFunction(results_DASH_summary86703.$var === D?U(L[76],"results-summary"):results_DASH_summary86703.$var)?results_DASH_summary86703.$var === D?U(L[76],"results-summary"):results_DASH_summary86703.$var.app(block_DASH_results114719.$var):R.ffi.throwNonFunApp(L[77],results_DASH_summary86703.$var === D?U(L[76],"results-summary"):results_DASH_summary86703.$var,[block_DASH_results114719.$var]);
};
try {
if(--R.GAS > 0) {
$z765766 = $f771772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f771772,
"from":L[77]});
}
} catch($e763764) {
if(R.isCont($e763764)) {
var $ss767768 = {"from":L[77],
"go":function(ann_DASH_check_DASH_temp317773) {
return $Hann_DASH_check_DASH_temp582774(ann_DASH_check_DASH_temp317773);
}};
$e763764.stack[R.EXN_STACKHEIGHT++] = $ss767768;
}
if(R.isPyretException($e763764)) {
$e763764.pyretStack.push(L[77]);
}
throw $e763764;
}
var $ret769770 = $Hann_DASH_check_DASH_temp582774($z765766);
++R.GAS;
return $ret769770;
};
},{"length":1});
var anf_obj320746 = R.makeMethod(function(self152762) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[75],0,arguments);
}
var ann_DASH_check_DASH_temp319761 = block_DASH_results114719.$var;
return ann_DASH_check_DASH_temp319761;
};
},{"length":1});
var anf_obj322747 = R.makeMethod(function(self153760) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[74],0,arguments);
}
var $z750751 = D;
var $f756757 = function(_) {
return R.isFunction(render_DASH_check_DASH_results87702.$var === D?U(L[73],"render-check-results"):render_DASH_check_DASH_results87702.$var)?render_DASH_check_DASH_results87702.$var === D?U(L[73],"render-check-results"):render_DASH_check_DASH_results87702.$var.app(block_DASH_results114719.$var):R.ffi.throwNonFunApp(L[74],render_DASH_check_DASH_results87702.$var === D?U(L[73],"render-check-results"):render_DASH_check_DASH_results87702.$var,[block_DASH_results114719.$var]);
};
try {
if(--R.GAS > 0) {
$z750751 = $f756757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f756757,
"from":L[74]});
}
} catch($e748749) {
if(R.isCont($e748749)) {
var $ss752753 = {"from":L[74],
"go":function(ann_DASH_check_DASH_temp321758) {
return $Hann_DASH_check_DASH_temp583759(ann_DASH_check_DASH_temp321758);
}};
$e748749.stack[R.EXN_STACKHEIGHT++] = $ss752753;
}
if(R.isPyretException($e748749)) {
$e748749.pyretStack.push(L[74]);
}
throw $e748749;
}
var $ret754755 = $Hann_DASH_check_DASH_temp583759($z750751);
++R.GAS;
return $ret754755;
};
},{"length":1});
var ann_DASH_check_DASH_temp221739 = R.makeObject({"run-checks":anf_obj262740,
"check-is":anf_obj275741,
"check-satisfies":anf_obj288742,
"check-raises":anf_obj310743,
"check-raises-str":anf_obj316744,
"summary":anf_obj318745,
"results":anf_obj320746,
"render":anf_obj322747});
return ann_DASH_check_DASH_temp221739;
};
var $Hann_DASH_check_DASH_temp583759 = function(ann_DASH_check_DASH_temp321758) {
return ann_DASH_check_DASH_temp321758;
};
var $Hann_DASH_check_DASH_temp582774 = function(ann_DASH_check_DASH_temp317773) {
return ann_DASH_check_DASH_temp317773;
};
var $Hann_DASH_check_DASH_temp581793 = function(ann_DASH_check_DASH_temp311792) {
return ann_DASH_check_DASH_temp311792;
};
var $Hanf_arg580807 = function(anf_arg314806,s150795,string_DASH_contains9) {
var $z996997 = D;
var $f10021003 = function(_) {
return R.isFunction(string_DASH_contains9)?string_DASH_contains9.app(anf_arg314806,s150795):R.ffi.throwNonFunApp(L[79],string_DASH_contains9,[anf_arg314806,s150795]);
};
try {
if(--R.GAS > 0) {
$z996997 = $f10021003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10021003,
"from":L[79]});
}
} catch($e994995) {
if(R.isCont($e994995)) {
var $ss998999 = {"from":L[79],
"go":function(ann_DASH_check_DASH_temp3131004) {
return $Hann_DASH_check_DASH_temp5791005(ann_DASH_check_DASH_temp3131004);
}};
$e994995.stack[R.EXN_STACKHEIGHT++] = $ss998999;
}
if(R.isPyretException($e994995)) {
$e994995.pyretStack.push(L[79]);
}
throw $e994995;
}
var $ret10001001 = $Hann_DASH_check_DASH_temp5791005($z996997);
++R.GAS;
return $ret10001001;
};
var $Hann_DASH_check_DASH_temp5791005 = function(ann_DASH_check_DASH_temp3131004) {
return ann_DASH_check_DASH_temp3131004;
};
var $Hresult578825 = function(result141820,add_DASH_result118735,code136821,comparator139822,expected138823,failure_DASH_no_DASH_exn84696,failure_DASH_wrong_DASH_exn82699,loc140824,success76704) {
var cases_DASH_val431050 = result141820;
var anf_fun2901016 = G(cases_DASH_val431050,"_match",L[102]);
var anf_obj2931022 = R.makeFunction(function(v1421037) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[105],1,arguments);
}
var $z10401041 = D;
var $f10461047 = function(_) {
return R.isFunction(failure_DASH_no_DASH_exn84696.$var)?failure_DASH_no_DASH_exn84696.$var.app(loc140824,code136821,expected138823):R.ffi.throwNonFunApp(L[106],failure_DASH_no_DASH_exn84696.$var,[loc140824,code136821,expected138823]);
};
try {
if(--R.GAS > 0) {
$z10401041 = $f10461047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10461047,
"from":L[106]});
}
} catch($e10381039) {
if(R.isCont($e10381039)) {
var $ss10421043 = {"from":L[106],
"go":function(anf_arg2921048) {
return $Hanf_arg5711049(anf_arg2921048,add_DASH_result118735);
}};
$e10381039.stack[R.EXN_STACKHEIGHT++] = $ss10421043;
}
if(R.isPyretException($e10381039)) {
$e10381039.pyretStack.push(L[106]);
}
throw $e10381039;
}
var $ret10441045 = $Hanf_arg5711049($z10401041,add_DASH_result118735);
++R.GAS;
return $ret10441045;
});
var anf_obj3061023 = R.makeFunction(function(v1431024) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[103],1,arguments);
}
var $z10271028 = D;
var $f10331034 = function(_) {
return R.isFunction(comparator139822)?comparator139822.app(v1431024,expected138823):R.ffi.throwNonFunApp(L[104],comparator139822,[v1431024,expected138823]);
};
try {
if(--R.GAS > 0) {
$z10271028 = $f10331034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10331034,
"from":L[104]});
}
} catch($e10251026) {
if(R.isCont($e10251026)) {
var $ss10291030 = {"from":L[104],
"go":function(if_DASH_421035) {
return $Hif_DASH_5761036(if_DASH_421035,add_DASH_result118735,code136821,expected138823,failure_DASH_wrong_DASH_exn82699,loc140824,success76704,v1431024);
}};
$e10251026.stack[R.EXN_STACKHEIGHT++] = $ss10291030;
}
if(R.isPyretException($e10251026)) {
$e10251026.pyretStack.push(L[104]);
}
throw $e10251026;
}
var $ret10311032 = $Hif_DASH_5761036($z10271028,add_DASH_result118735,code136821,expected138823,failure_DASH_wrong_DASH_exn82699,loc140824,success76704,v1431024);
++R.GAS;
return $ret10311032;
});
var anf_arg3071017 = R.makeObject({"left":anf_obj2931022,
"right":anf_obj3061023});
var anf_arg3091018 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[102],0,arguments);
}
var ann_DASH_check_DASH_temp3081021 = R.throwNoBranchesMatched(L[102],("cases"));
return ann_DASH_check_DASH_temp3081021;
});
var $z10081009 = D;
var $f10141015 = function(_) {
return R.isFunction(anf_fun2901016)?anf_fun2901016.app(anf_arg3071017,anf_arg3091018):R.ffi.throwNonFunApp(L[83],anf_fun2901016,[anf_arg3071017,anf_arg3091018]);
};
try {
if(--R.GAS > 0) {
$z10081009 = $f10141015();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10141015,
"from":L[83]});
}
} catch($e10061007) {
if(R.isCont($e10061007)) {
var $ss10101011 = {"from":L[83],
"go":function(ann_DASH_check_DASH_temp2891019) {
return $Hann_DASH_check_DASH_temp5771020(ann_DASH_check_DASH_temp2891019);
}};
$e10061007.stack[R.EXN_STACKHEIGHT++] = $ss10101011;
}
if(R.isPyretException($e10061007)) {
$e10061007.pyretStack.push(L[83]);
}
throw $e10061007;
}
var $ret10121013 = $Hann_DASH_check_DASH_temp5771020($z10081009);
++R.GAS;
return $ret10121013;
};
var $Hann_DASH_check_DASH_temp5771020 = function(ann_DASH_check_DASH_temp2891019) {
return ann_DASH_check_DASH_temp2891019;
};
var $Hif_DASH_5761036 = function(if_DASH_421035,add_DASH_result118735,code136821,expected138823,failure_DASH_wrong_DASH_exn82699,loc140824,success76704,v1431024) {
var if_helper2951062 = R.makeFunction(function(if_helper_arg2961080) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[104],1,arguments);
}
var ann_DASH_check_DASH_temp2941081 = if_helper_arg2961080;
return ann_DASH_check_DASH_temp2941081;
});
var anf_if2991079 = R.isBoolean(if_DASH_421035);
if(R.isPyretTrue(anf_if2991079)) {
if(R.isPyretTrue(if_DASH_421035)) {
var $z10531054 = D;
var $f10591060 = function(_) {
return R.isFunction(success76704.$var)?success76704.$var.app(loc140824,code136821):R.ffi.throwNonFunApp(L[107],success76704.$var,[loc140824,code136821]);
};
try {
if(--R.GAS > 0) {
$z10531054 = $f10591060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10591060,
"from":L[107]});
}
} catch($e10511052) {
if(R.isCont($e10511052)) {
var $ss10551056 = {"from":L[107],
"go":function(anf_arg3031061) {
return $Hanf_arg5731063(anf_arg3031061,add_DASH_result118735,if_helper2951062);
}};
$e10511052.stack[R.EXN_STACKHEIGHT++] = $ss10551056;
}
if(R.isPyretException($e10511052)) {
$e10511052.pyretStack.push(L[107]);
}
throw $e10511052;
}
var $ret10571058 = $Hanf_arg5731063($z10531054,add_DASH_result118735,if_helper2951062);
++R.GAS;
return $ret10571058;
} else {
var $z10661067 = D;
var $f10721073 = function(_) {
return R.isFunction(failure_DASH_wrong_DASH_exn82699.$var)?failure_DASH_wrong_DASH_exn82699.$var.app(loc140824,code136821,expected138823,v1431024):R.ffi.throwNonFunApp(L[108],failure_DASH_wrong_DASH_exn82699.$var,[loc140824,code136821,expected138823,v1431024]);
};
try {
if(--R.GAS > 0) {
$z10661067 = $f10721073();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10721073,
"from":L[108]});
}
} catch($e10641065) {
if(R.isCont($e10641065)) {
var $ss10681069 = {"from":L[108],
"go":function(anf_arg3001074) {
return $Hanf_arg5751075(anf_arg3001074,add_DASH_result118735,if_helper2951062);
}};
$e10641065.stack[R.EXN_STACKHEIGHT++] = $ss10681069;
}
if(R.isPyretException($e10641065)) {
$e10641065.pyretStack.push(L[108]);
}
throw $e10641065;
}
var $ret10701071 = $Hanf_arg5751075($z10661067,add_DASH_result118735,if_helper2951062);
++R.GAS;
return $ret10701071;
}
} else {
var cont_tail_arg2971078 = R.throwNonBooleanCondition(L[104],("if"),if_DASH_421035);
if(--R.GAS > 0) {
$z10761077 = R.isFunction(if_helper2951062)?if_helper2951062.app(cont_tail_arg2971078):R.ffi.throwNonFunApp(L[104],if_helper2951062,[cont_tail_arg2971078]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper2951062)?if_helper2951062.app(cont_tail_arg2971078):R.ffi.throwNonFunApp(L[104],if_helper2951062,[cont_tail_arg2971078]);
},
"from":L[104]});
}
++R.GAS;
return $z10761077;
}
};
var $Hanf_arg5731063 = function(anf_arg3031061,add_DASH_result118735,if_helper2951062) {
var $z10841085 = D;
var $f10901091 = function(_) {
return R.isFunction(add_DASH_result118735.$var)?add_DASH_result118735.$var.app(anf_arg3031061):R.ffi.throwNonFunApp(L[109],add_DASH_result118735.$var,[anf_arg3031061]);
};
try {
if(--R.GAS > 0) {
$z10841085 = $f10901091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10901091,
"from":L[109]});
}
} catch($e10821083) {
if(R.isCont($e10821083)) {
var $ss10861087 = {"from":L[109],
"go":function(cont_tail_arg3041092) {
return $Hcont_tail_arg5721093(cont_tail_arg3041092,if_helper2951062);
}};
$e10821083.stack[R.EXN_STACKHEIGHT++] = $ss10861087;
}
if(R.isPyretException($e10821083)) {
$e10821083.pyretStack.push(L[109]);
}
throw $e10821083;
}
var $ret10881089 = $Hcont_tail_arg5721093($z10841085,if_helper2951062);
++R.GAS;
return $ret10881089;
};
var $Hcont_tail_arg5721093 = function(cont_tail_arg3041092,if_helper2951062) {
if(--R.GAS > 0) {
$z10941095 = R.isFunction(if_helper2951062)?if_helper2951062.app(cont_tail_arg3041092):R.ffi.throwNonFunApp(L[109],if_helper2951062,[cont_tail_arg3041092]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper2951062)?if_helper2951062.app(cont_tail_arg3041092):R.ffi.throwNonFunApp(L[109],if_helper2951062,[cont_tail_arg3041092]);
},
"from":L[109]});
}
++R.GAS;
return $z10941095;
};
var $Hanf_arg5751075 = function(anf_arg3001074,add_DASH_result118735,if_helper2951062) {
var $z10981099 = D;
var $f11041105 = function(_) {
return R.isFunction(add_DASH_result118735.$var)?add_DASH_result118735.$var.app(anf_arg3001074):R.ffi.throwNonFunApp(L[110],add_DASH_result118735.$var,[anf_arg3001074]);
};
try {
if(--R.GAS > 0) {
$z10981099 = $f11041105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11041105,
"from":L[110]});
}
} catch($e10961097) {
if(R.isCont($e10961097)) {
var $ss11001101 = {"from":L[110],
"go":function(cont_tail_arg3011106) {
return $Hcont_tail_arg5741107(cont_tail_arg3011106,if_helper2951062);
}};
$e10961097.stack[R.EXN_STACKHEIGHT++] = $ss11001101;
}
if(R.isPyretException($e10961097)) {
$e10961097.pyretStack.push(L[110]);
}
throw $e10961097;
}
var $ret11021103 = $Hcont_tail_arg5741107($z10981099,if_helper2951062);
++R.GAS;
return $ret11021103;
};
var $Hcont_tail_arg5741107 = function(cont_tail_arg3011106,if_helper2951062) {
if(--R.GAS > 0) {
$z11081109 = R.isFunction(if_helper2951062)?if_helper2951062.app(cont_tail_arg3011106):R.ffi.throwNonFunApp(L[110],if_helper2951062,[cont_tail_arg3011106]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper2951062)?if_helper2951062.app(cont_tail_arg3011106):R.ffi.throwNonFunApp(L[110],if_helper2951062,[cont_tail_arg3011106]);
},
"from":L[110]});
}
++R.GAS;
return $z11081109;
};
var $Hanf_arg5711049 = function(anf_arg2921048,add_DASH_result118735) {
var $z11121113 = D;
var $f11181119 = function(_) {
return R.isFunction(add_DASH_result118735.$var)?add_DASH_result118735.$var.app(anf_arg2921048):R.ffi.throwNonFunApp(L[105],add_DASH_result118735.$var,[anf_arg2921048]);
};
try {
if(--R.GAS > 0) {
$z11121113 = $f11181119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11181119,
"from":L[105]});
}
} catch($e11101111) {
if(R.isCont($e11101111)) {
var $ss11141115 = {"from":L[105],
"go":function(ann_DASH_check_DASH_temp2911120) {
return $Hann_DASH_check_DASH_temp5701121(ann_DASH_check_DASH_temp2911120);
}};
$e11101111.stack[R.EXN_STACKHEIGHT++] = $ss11141115;
}
if(R.isPyretException($e11101111)) {
$e11101111.pyretStack.push(L[105]);
}
throw $e11101111;
}
var $ret11161117 = $Hann_DASH_check_DASH_temp5701121($z11121113);
++R.GAS;
return $ret11161117;
};
var $Hann_DASH_check_DASH_temp5701121 = function(ann_DASH_check_DASH_temp2911120) {
return ann_DASH_check_DASH_temp2911120;
};
var $Hif_DASH_569842 = function(if_DASH_41839,add_DASH_result118735,code131840,failure_DASH_not_DASH_satisfied80698,left132838,loc134841,pred133837,success76704) {
var if_helper2771133 = R.makeFunction(function(if_helper_arg2781151) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[84],1,arguments);
}
var ann_DASH_check_DASH_temp2761152 = if_helper_arg2781151;
return ann_DASH_check_DASH_temp2761152;
});
var anf_if2811150 = R.isBoolean(if_DASH_41839);
if(R.isPyretTrue(anf_if2811150)) {
if(R.isPyretTrue(if_DASH_41839)) {
var $z11241125 = D;
var $f11301131 = function(_) {
return R.isFunction(success76704.$var)?success76704.$var.app(loc134841,code131840):R.ffi.throwNonFunApp(L[111],success76704.$var,[loc134841,code131840]);
};
try {
if(--R.GAS > 0) {
$z11241125 = $f11301131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11301131,
"from":L[111]});
}
} catch($e11221123) {
if(R.isCont($e11221123)) {
var $ss11261127 = {"from":L[111],
"go":function(anf_arg2851132) {
return $Hanf_arg5661134(anf_arg2851132,add_DASH_result118735,if_helper2771133);
}};
$e11221123.stack[R.EXN_STACKHEIGHT++] = $ss11261127;
}
if(R.isPyretException($e11221123)) {
$e11221123.pyretStack.push(L[111]);
}
throw $e11221123;
}
var $ret11281129 = $Hanf_arg5661134($z11241125,add_DASH_result118735,if_helper2771133);
++R.GAS;
return $ret11281129;
} else {
var $z11371138 = D;
var $f11431144 = function(_) {
return R.isFunction(failure_DASH_not_DASH_satisfied80698.$var)?failure_DASH_not_DASH_satisfied80698.$var.app(loc134841,code131840,left132838,pred133837):R.ffi.throwNonFunApp(L[112],failure_DASH_not_DASH_satisfied80698.$var,[loc134841,code131840,left132838,pred133837]);
};
try {
if(--R.GAS > 0) {
$z11371138 = $f11431144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11431144,
"from":L[112]});
}
} catch($e11351136) {
if(R.isCont($e11351136)) {
var $ss11391140 = {"from":L[112],
"go":function(anf_arg2821145) {
return $Hanf_arg5681146(anf_arg2821145,add_DASH_result118735,if_helper2771133);
}};
$e11351136.stack[R.EXN_STACKHEIGHT++] = $ss11391140;
}
if(R.isPyretException($e11351136)) {
$e11351136.pyretStack.push(L[112]);
}
throw $e11351136;
}
var $ret11411142 = $Hanf_arg5681146($z11371138,add_DASH_result118735,if_helper2771133);
++R.GAS;
return $ret11411142;
}
} else {
var cont_tail_arg2791149 = R.throwNonBooleanCondition(L[84],("if"),if_DASH_41839);
if(--R.GAS > 0) {
$z11471148 = R.isFunction(if_helper2771133)?if_helper2771133.app(cont_tail_arg2791149):R.ffi.throwNonFunApp(L[84],if_helper2771133,[cont_tail_arg2791149]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper2771133)?if_helper2771133.app(cont_tail_arg2791149):R.ffi.throwNonFunApp(L[84],if_helper2771133,[cont_tail_arg2791149]);
},
"from":L[84]});
}
++R.GAS;
return $z11471148;
}
};
var $Hanf_arg5661134 = function(anf_arg2851132,add_DASH_result118735,if_helper2771133) {
var $z11551156 = D;
var $f11611162 = function(_) {
return R.isFunction(add_DASH_result118735.$var)?add_DASH_result118735.$var.app(anf_arg2851132):R.ffi.throwNonFunApp(L[113],add_DASH_result118735.$var,[anf_arg2851132]);
};
try {
if(--R.GAS > 0) {
$z11551156 = $f11611162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11611162,
"from":L[113]});
}
} catch($e11531154) {
if(R.isCont($e11531154)) {
var $ss11571158 = {"from":L[113],
"go":function(cont_tail_arg2861163) {
return $Hcont_tail_arg5651164(cont_tail_arg2861163,if_helper2771133);
}};
$e11531154.stack[R.EXN_STACKHEIGHT++] = $ss11571158;
}
if(R.isPyretException($e11531154)) {
$e11531154.pyretStack.push(L[113]);
}
throw $e11531154;
}
var $ret11591160 = $Hcont_tail_arg5651164($z11551156,if_helper2771133);
++R.GAS;
return $ret11591160;
};
var $Hcont_tail_arg5651164 = function(cont_tail_arg2861163,if_helper2771133) {
if(--R.GAS > 0) {
$z11651166 = R.isFunction(if_helper2771133)?if_helper2771133.app(cont_tail_arg2861163):R.ffi.throwNonFunApp(L[113],if_helper2771133,[cont_tail_arg2861163]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper2771133)?if_helper2771133.app(cont_tail_arg2861163):R.ffi.throwNonFunApp(L[113],if_helper2771133,[cont_tail_arg2861163]);
},
"from":L[113]});
}
++R.GAS;
return $z11651166;
};
var $Hanf_arg5681146 = function(anf_arg2821145,add_DASH_result118735,if_helper2771133) {
var $z11691170 = D;
var $f11751176 = function(_) {
return R.isFunction(add_DASH_result118735.$var)?add_DASH_result118735.$var.app(anf_arg2821145):R.ffi.throwNonFunApp(L[114],add_DASH_result118735.$var,[anf_arg2821145]);
};
try {
if(--R.GAS > 0) {
$z11691170 = $f11751176();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11751176,
"from":L[114]});
}
} catch($e11671168) {
if(R.isCont($e11671168)) {
var $ss11711172 = {"from":L[114],
"go":function(cont_tail_arg2831177) {
return $Hcont_tail_arg5671178(cont_tail_arg2831177,if_helper2771133);
}};
$e11671168.stack[R.EXN_STACKHEIGHT++] = $ss11711172;
}
if(R.isPyretException($e11671168)) {
$e11671168.pyretStack.push(L[114]);
}
throw $e11671168;
}
var $ret11731174 = $Hcont_tail_arg5671178($z11691170,if_helper2771133);
++R.GAS;
return $ret11731174;
};
var $Hcont_tail_arg5671178 = function(cont_tail_arg2831177,if_helper2771133) {
if(--R.GAS > 0) {
$z11791180 = R.isFunction(if_helper2771133)?if_helper2771133.app(cont_tail_arg2831177):R.ffi.throwNonFunApp(L[114],if_helper2771133,[cont_tail_arg2831177]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper2771133)?if_helper2771133.app(cont_tail_arg2831177):R.ffi.throwNonFunApp(L[114],if_helper2771133,[cont_tail_arg2831177]);
},
"from":L[114]});
}
++R.GAS;
return $z11791180;
};
var $Hanf_arg562858 = function(anf_arg272856,add_DASH_result118735,if_helper264857) {
var $z11831184 = D;
var $f11891190 = function(_) {
return R.isFunction(add_DASH_result118735.$var)?add_DASH_result118735.$var.app(anf_arg272856):R.ffi.throwNonFunApp(L[115],add_DASH_result118735.$var,[anf_arg272856]);
};
try {
if(--R.GAS > 0) {
$z11831184 = $f11891190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11891190,
"from":L[115]});
}
} catch($e11811182) {
if(R.isCont($e11811182)) {
var $ss11851186 = {"from":L[115],
"go":function(cont_tail_arg2731191) {
return $Hcont_tail_arg5611192(cont_tail_arg2731191,if_helper264857);
}};
$e11811182.stack[R.EXN_STACKHEIGHT++] = $ss11851186;
}
if(R.isPyretException($e11811182)) {
$e11811182.pyretStack.push(L[115]);
}
throw $e11811182;
}
var $ret11871188 = $Hcont_tail_arg5611192($z11831184,if_helper264857);
++R.GAS;
return $ret11871188;
};
var $Hcont_tail_arg5611192 = function(cont_tail_arg2731191,if_helper264857) {
if(--R.GAS > 0) {
$z11931194 = R.isFunction(if_helper264857)?if_helper264857.app(cont_tail_arg2731191):R.ffi.throwNonFunApp(L[115],if_helper264857,[cont_tail_arg2731191]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper264857)?if_helper264857.app(cont_tail_arg2731191):R.ffi.throwNonFunApp(L[115],if_helper264857,[cont_tail_arg2731191]);
},
"from":L[115]});
}
++R.GAS;
return $z11931194;
};
var $Hanf_arg564872 = function(anf_arg269871,add_DASH_result118735,if_helper264857) {
var $z11971198 = D;
var $f12031204 = function(_) {
return R.isFunction(add_DASH_result118735.$var)?add_DASH_result118735.$var.app(anf_arg269871):R.ffi.throwNonFunApp(L[116],add_DASH_result118735.$var,[anf_arg269871]);
};
try {
if(--R.GAS > 0) {
$z11971198 = $f12031204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12031204,
"from":L[116]});
}
} catch($e11951196) {
if(R.isCont($e11951196)) {
var $ss11991200 = {"from":L[116],
"go":function(cont_tail_arg2701205) {
return $Hcont_tail_arg5631206(cont_tail_arg2701205,if_helper264857);
}};
$e11951196.stack[R.EXN_STACKHEIGHT++] = $ss11991200;
}
if(R.isPyretException($e11951196)) {
$e11951196.pyretStack.push(L[116]);
}
throw $e11951196;
}
var $ret12011202 = $Hcont_tail_arg5631206($z11971198,if_helper264857);
++R.GAS;
return $ret12011202;
};
var $Hcont_tail_arg5631206 = function(cont_tail_arg2701205,if_helper264857) {
if(--R.GAS > 0) {
$z12071208 = R.isFunction(if_helper264857)?if_helper264857.app(cont_tail_arg2701205):R.ffi.throwNonFunApp(L[116],if_helper264857,[cont_tail_arg2701205]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper264857)?if_helper264857.app(cont_tail_arg2701205):R.ffi.throwNonFunApp(L[116],if_helper264857,[cont_tail_arg2701205]);
},
"from":L[116]});
}
++R.GAS;
return $z12071208;
};
var $Hcont_tail_app559893 = function(cont_tail_app261892) {
return cont_tail_app261892;
};
var $Hcont_tail_app560906 = function(cont_tail_app260905) {
return cont_tail_app260905;
};
var $Hanf_begin_app_dropped557932 = function(anf_begin_app_dropped555930,if_helper241931,nothing7) {
var $z12111212 = D;
var $f12171218 = function(_) {
return R.isFunction(if_helper241931)?if_helper241931.app(nothing7):R.ffi.throwNonFunApp(L[95],if_helper241931,[nothing7]);
};
try {
if(--R.GAS > 0) {
$z12111212 = $f12171218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12171218,
"from":L[95]});
}
} catch($e12091210) {
if(R.isCont($e12091210)) {
var $ss12131214 = {"from":L[95],
"go":function(cont_tail_app2531219) {
return $Hcont_tail_app5561220(cont_tail_app2531219);
}};
$e12091210.stack[R.EXN_STACKHEIGHT++] = $ss12131214;
}
if(R.isPyretException($e12091210)) {
$e12091210.pyretStack.push(L[95]);
}
throw $e12091210;
}
var $ret12151216 = $Hcont_tail_app5561220($z12111212);
++R.GAS;
return $ret12151216;
};
var $Hcont_tail_app5561220 = function(cont_tail_app2531219) {
return cont_tail_app2531219;
};
var $Hanf_begin_app_dropped554946 = function(anf_begin_app_dropped549944,add_DASH_block_DASH_result115705,c124933,check_DASH_block_DASH_result71694,current_DASH_results117945) {
var anf_fun2481231 = G(c124933,"run",L[118]);
var $z12231224 = D;
var $f12291230 = function(_) {
return R.isFunction(anf_fun2481231)?anf_fun2481231.app():R.ffi.throwNonFunApp(L[117],anf_fun2481231,[]);
};
try {
if(--R.GAS > 0) {
$z12231224 = $f12291230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12291230,
"from":L[117]});
}
} catch($e12211222) {
if(R.isCont($e12211222)) {
var $ss12251226 = {"from":L[117],
"go":function(anf_begin_app_dropped5501232) {
return $Hanf_begin_app_dropped5531233(anf_begin_app_dropped5501232,add_DASH_block_DASH_result115705,c124933,check_DASH_block_DASH_result71694,current_DASH_results117945);
}};
$e12211222.stack[R.EXN_STACKHEIGHT++] = $ss12251226;
}
if(R.isPyretException($e12211222)) {
$e12211222.pyretStack.push(L[117]);
}
throw $e12211222;
}
var $ret12271228 = $Hanf_begin_app_dropped5531233($z12231224,add_DASH_block_DASH_result115705,c124933,check_DASH_block_DASH_result71694,current_DASH_results117945);
++R.GAS;
return $ret12271228;
};
var $Hanf_begin_app_dropped5531233 = function(anf_begin_app_dropped5501232,add_DASH_block_DASH_result115705,c124933,check_DASH_block_DASH_result71694,current_DASH_results117945) {
var anf_arg2491244 = G(c124933,"name",L[121]);
var anf_arg2501245 = G(c124933,"location",L[120]);
var $z12361237 = D;
var $f12421243 = function(_) {
return R.isFunction(check_DASH_block_DASH_result71694.$var)?check_DASH_block_DASH_result71694.$var.app(anf_arg2491244,anf_arg2501245,current_DASH_results117945.$var):R.ffi.throwNonFunApp(L[119],check_DASH_block_DASH_result71694.$var,[anf_arg2491244,anf_arg2501245,current_DASH_results117945.$var]);
};
try {
if(--R.GAS > 0) {
$z12361237 = $f12421243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12421243,
"from":L[119]});
}
} catch($e12341235) {
if(R.isCont($e12341235)) {
var $ss12381239 = {"from":L[119],
"go":function(anf_arg2511246) {
return $Hanf_arg5521247(anf_arg2511246,add_DASH_block_DASH_result115705);
}};
$e12341235.stack[R.EXN_STACKHEIGHT++] = $ss12381239;
}
if(R.isPyretException($e12341235)) {
$e12341235.pyretStack.push(L[119]);
}
throw $e12341235;
}
var $ret12401241 = $Hanf_arg5521247($z12361237,add_DASH_block_DASH_result115705);
++R.GAS;
return $ret12401241;
};
var $Hanf_arg5521247 = function(anf_arg2511246,add_DASH_block_DASH_result115705) {
var $z12501251 = D;
var $f12561257 = function(_) {
return R.isFunction(add_DASH_block_DASH_result115705.$var)?add_DASH_block_DASH_result115705.$var.app(anf_arg2511246):R.ffi.throwNonFunApp(L[93],add_DASH_block_DASH_result115705.$var,[anf_arg2511246]);
};
try {
if(--R.GAS > 0) {
$z12501251 = $f12561257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12561257,
"from":L[93]});
}
} catch($e12481249) {
if(R.isCont($e12481249)) {
var $ss12521253 = {"from":L[93],
"go":function(ann_DASH_check_DASH_temp2471258) {
return $Hann_DASH_check_DASH_temp5511259(ann_DASH_check_DASH_temp2471258);
}};
$e12481249.stack[R.EXN_STACKHEIGHT++] = $ss12521253;
}
if(R.isPyretException($e12481249)) {
$e12481249.pyretStack.push(L[93]);
}
throw $e12481249;
}
var $ret12541255 = $Hann_DASH_check_DASH_temp5511259($z12501251);
++R.GAS;
return $ret12541255;
};
var $Hann_DASH_check_DASH_temp5511259 = function(ann_DASH_check_DASH_temp2471258) {
return ann_DASH_check_DASH_temp2471258;
};
var $Hcont_tail_app558958 = function(cont_tail_app246957) {
return cont_tail_app246957;
};
var $Hanf_assign548979 = function(anf_assign236978,current_DASH_results117945) {
var ann_DASH_check_DASH_temp2341260 = current_DASH_results117945.$var = anf_assign236978;
return ann_DASH_check_DASH_temp2341260;
};
var $Hanf_arg547993 = function(anf_arg231992,current_DASH_results117945,_plus5) {
var $z12631264 = D;
var $f12691270 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg231992,current_DASH_results117945.$var):R.ffi.throwNonFunApp(L[122],_plus5,[anf_arg231992,current_DASH_results117945.$var]);
};
try {
if(--R.GAS > 0) {
$z12631264 = $f12691270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12691270,
"from":L[122]});
}
} catch($e12611262) {
if(R.isCont($e12611262)) {
var $ss12651266 = {"from":L[122],
"go":function(anf_assign2321271) {
return $Hanf_assign5461272(anf_assign2321271,current_DASH_results117945);
}};
$e12611262.stack[R.EXN_STACKHEIGHT++] = $ss12651266;
}
if(R.isPyretException($e12611262)) {
$e12611262.pyretStack.push(L[122]);
}
throw $e12611262;
}
var $ret12671268 = $Hanf_assign5461272($z12631264,current_DASH_results117945);
++R.GAS;
return $ret12671268;
};
var $Hanf_assign5461272 = function(anf_assign2321271,current_DASH_results117945) {
var ann_DASH_check_DASH_temp2291273 = current_DASH_results117945.$var = anf_assign2321271;
return ann_DASH_check_DASH_temp2291273;
};
var $Hanf_arg544734 = function(anf_arg225733,block_DASH_results114719,_plus5) {
var $z12761277 = D;
var $f12821283 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg225733,block_DASH_results114719.$var):R.ffi.throwNonFunApp(L[123],_plus5,[anf_arg225733,block_DASH_results114719.$var]);
};
try {
if(--R.GAS > 0) {
$z12761277 = $f12821283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12821283,
"from":L[123]});
}
} catch($e12741275) {
if(R.isCont($e12741275)) {
var $ss12781279 = {"from":L[123],
"go":function(anf_assign2261284) {
return $Hanf_assign5431285(anf_assign2261284,block_DASH_results114719);
}};
$e12741275.stack[R.EXN_STACKHEIGHT++] = $ss12781279;
}
if(R.isPyretException($e12741275)) {
$e12741275.pyretStack.push(L[123]);
}
throw $e12741275;
}
var $ret12801281 = $Hanf_assign5431285($z12761277,block_DASH_results114719);
++R.GAS;
return $ret12801281;
};
var $Hanf_assign5431285 = function(anf_assign2261284,block_DASH_results114719) {
var ann_DASH_check_DASH_temp2231286 = block_DASH_results114719.$var = anf_assign2261284;
return ann_DASH_check_DASH_temp2231286;
};
var $Hanf_arg5411287 = function(anf_arg2061288,_plus5) {
var $z12911292 = D;
var $f12971298 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("No exception raised, expected "),anf_arg2061288):R.ffi.throwNonFunApp(L[124],_plus5,[("No exception raised, expected "),anf_arg2061288]);
};
try {
if(--R.GAS > 0) {
$z12911292 = $f12971298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12971298,
"from":L[124]});
}
} catch($e12891290) {
if(R.isCont($e12891290)) {
var $ss12931294 = {"from":L[124],
"go":function(ann_DASH_check_DASH_temp2041299) {
return $Hann_DASH_check_DASH_temp5401300(ann_DASH_check_DASH_temp2041299);
}};
$e12891290.stack[R.EXN_STACKHEIGHT++] = $ss12931294;
}
if(R.isPyretException($e12891290)) {
$e12891290.pyretStack.push(L[124]);
}
throw $e12891290;
}
var $ret12951296 = $Hann_DASH_check_DASH_temp5401300($z12911292);
++R.GAS;
return $ret12951296;
};
var $Hann_DASH_check_DASH_temp5401300 = function(ann_DASH_check_DASH_temp2041299) {
return ann_DASH_check_DASH_temp2041299;
};
var $Hanf_arg5391301 = function(anf_arg1921302,self351303,_plus5,torepr10) {
var anf_arg1931314 = G(self351303,"code",L[125]);
var $z13061307 = D;
var $f13121313 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1931314):R.ffi.throwNonFunApp(L[125],torepr10,[anf_arg1931314]);
};
try {
if(--R.GAS > 0) {
$z13061307 = $f13121313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13121313,
"from":L[125]});
}
} catch($e13041305) {
if(R.isCont($e13041305)) {
var $ss13081309 = {"from":L[125],
"go":function(anf_arg1941315) {
return $Hanf_arg5381316(anf_arg1941315,anf_arg1921302,self351303,_plus5,torepr10);
}};
$e13041305.stack[R.EXN_STACKHEIGHT++] = $ss13081309;
}
if(R.isPyretException($e13041305)) {
$e13041305.pyretStack.push(L[125]);
}
throw $e13041305;
}
var $ret13101311 = $Hanf_arg5381316($z13061307,anf_arg1921302,self351303,_plus5,torepr10);
++R.GAS;
return $ret13101311;
};
var $Hanf_arg5381316 = function(anf_arg1941315,anf_arg1921302,self351303,_plus5,torepr10) {
var $z13191320 = D;
var $f13251326 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1941315):R.ffi.throwNonFunApp(L[125],_plus5,[(", "),anf_arg1941315]);
};
try {
if(--R.GAS > 0) {
$z13191320 = $f13251326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13251326,
"from":L[125]});
}
} catch($e13171318) {
if(R.isCont($e13171318)) {
var $ss13211322 = {"from":L[125],
"go":function(anf_arg1951327) {
return $Hanf_arg5371328(anf_arg1951327,anf_arg1921302,self351303,_plus5,torepr10);
}};
$e13171318.stack[R.EXN_STACKHEIGHT++] = $ss13211322;
}
if(R.isPyretException($e13171318)) {
$e13171318.pyretStack.push(L[125]);
}
throw $e13171318;
}
var $ret13231324 = $Hanf_arg5371328($z13191320,anf_arg1921302,self351303,_plus5,torepr10);
++R.GAS;
return $ret13231324;
};
var $Hanf_arg5371328 = function(anf_arg1951327,anf_arg1921302,self351303,_plus5,torepr10) {
var $z13311332 = D;
var $f13371338 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1921302,anf_arg1951327):R.ffi.throwNonFunApp(L[125],_plus5,[anf_arg1921302,anf_arg1951327]);
};
try {
if(--R.GAS > 0) {
$z13311332 = $f13371338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13371338,
"from":L[125]});
}
} catch($e13291330) {
if(R.isCont($e13291330)) {
var $ss13331334 = {"from":L[125],
"go":function(anf_arg1961339) {
return $Hanf_arg5361340(anf_arg1961339,self351303,_plus5,torepr10);
}};
$e13291330.stack[R.EXN_STACKHEIGHT++] = $ss13331334;
}
if(R.isPyretException($e13291330)) {
$e13291330.pyretStack.push(L[125]);
}
throw $e13291330;
}
var $ret13351336 = $Hanf_arg5361340($z13311332,self351303,_plus5,torepr10);
++R.GAS;
return $ret13351336;
};
var $Hanf_arg5361340 = function(anf_arg1961339,self351303,_plus5,torepr10) {
var anf_arg1971351 = G(self351303,"exn-expected",L[125]);
var $z13431344 = D;
var $f13491350 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1971351):R.ffi.throwNonFunApp(L[125],torepr10,[anf_arg1971351]);
};
try {
if(--R.GAS > 0) {
$z13431344 = $f13491350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13491350,
"from":L[125]});
}
} catch($e13411342) {
if(R.isCont($e13411342)) {
var $ss13451346 = {"from":L[125],
"go":function(anf_arg1981352) {
return $Hanf_arg5351353(anf_arg1981352,anf_arg1961339,_plus5);
}};
$e13411342.stack[R.EXN_STACKHEIGHT++] = $ss13451346;
}
if(R.isPyretException($e13411342)) {
$e13411342.pyretStack.push(L[125]);
}
throw $e13411342;
}
var $ret13471348 = $Hanf_arg5351353($z13431344,anf_arg1961339,_plus5);
++R.GAS;
return $ret13471348;
};
var $Hanf_arg5351353 = function(anf_arg1981352,anf_arg1961339,_plus5) {
var $z13561357 = D;
var $f13621363 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1981352):R.ffi.throwNonFunApp(L[125],_plus5,[(", "),anf_arg1981352]);
};
try {
if(--R.GAS > 0) {
$z13561357 = $f13621363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13621363,
"from":L[125]});
}
} catch($e13541355) {
if(R.isCont($e13541355)) {
var $ss13581359 = {"from":L[125],
"go":function(anf_arg1991364) {
return $Hanf_arg5341365(anf_arg1991364,anf_arg1961339,_plus5);
}};
$e13541355.stack[R.EXN_STACKHEIGHT++] = $ss13581359;
}
if(R.isPyretException($e13541355)) {
$e13541355.pyretStack.push(L[125]);
}
throw $e13541355;
}
var $ret13601361 = $Hanf_arg5341365($z13561357,anf_arg1961339,_plus5);
++R.GAS;
return $ret13601361;
};
var $Hanf_arg5341365 = function(anf_arg1991364,anf_arg1961339,_plus5) {
var $z13681369 = D;
var $f13741375 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1961339,anf_arg1991364):R.ffi.throwNonFunApp(L[125],_plus5,[anf_arg1961339,anf_arg1991364]);
};
try {
if(--R.GAS > 0) {
$z13681369 = $f13741375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13741375,
"from":L[125]});
}
} catch($e13661367) {
if(R.isCont($e13661367)) {
var $ss13701371 = {"from":L[125],
"go":function(anf_arg2001376) {
return $Hanf_arg5331377(anf_arg2001376,_plus5);
}};
$e13661367.stack[R.EXN_STACKHEIGHT++] = $ss13701371;
}
if(R.isPyretException($e13661367)) {
$e13661367.pyretStack.push(L[125]);
}
throw $e13661367;
}
var $ret13721373 = $Hanf_arg5331377($z13681369,_plus5);
++R.GAS;
return $ret13721373;
};
var $Hanf_arg5331377 = function(anf_arg2001376,_plus5) {
var $z13801381 = D;
var $f13861387 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg2001376,(")")):R.ffi.throwNonFunApp(L[125],_plus5,[anf_arg2001376,(")")]);
};
try {
if(--R.GAS > 0) {
$z13801381 = $f13861387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13861387,
"from":L[125]});
}
} catch($e13781379) {
if(R.isCont($e13781379)) {
var $ss13821383 = {"from":L[125],
"go":function(anf_arg2011388) {
return $Hanf_arg5321389(anf_arg2011388,_plus5);
}};
$e13781379.stack[R.EXN_STACKHEIGHT++] = $ss13821383;
}
if(R.isPyretException($e13781379)) {
$e13781379.pyretStack.push(L[125]);
}
throw $e13781379;
}
var $ret13841385 = $Hanf_arg5321389($z13801381,_plus5);
++R.GAS;
return $ret13841385;
};
var $Hanf_arg5321389 = function(anf_arg2011388,_plus5) {
var $z13921393 = D;
var $f13981399 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg2011388):R.ffi.throwNonFunApp(L[125],_plus5,[("("),anf_arg2011388]);
};
try {
if(--R.GAS > 0) {
$z13921393 = $f13981399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13981399,
"from":L[125]});
}
} catch($e13901391) {
if(R.isCont($e13901391)) {
var $ss13941395 = {"from":L[125],
"go":function(anf_arg2021400) {
return $Hanf_arg5311401(anf_arg2021400,_plus5);
}};
$e13901391.stack[R.EXN_STACKHEIGHT++] = $ss13941395;
}
if(R.isPyretException($e13901391)) {
$e13901391.pyretStack.push(L[125]);
}
throw $e13901391;
}
var $ret13961397 = $Hanf_arg5311401($z13921393,_plus5);
++R.GAS;
return $ret13961397;
};
var $Hanf_arg5311401 = function(anf_arg2021400,_plus5) {
var $z14041405 = D;
var $f14101411 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("failure-no-exn"),anf_arg2021400):R.ffi.throwNonFunApp(L[125],_plus5,[("failure-no-exn"),anf_arg2021400]);
};
try {
if(--R.GAS > 0) {
$z14041405 = $f14101411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14101411,
"from":L[125]});
}
} catch($e14021403) {
if(R.isCont($e14021403)) {
var $ss14061407 = {"from":L[125],
"go":function(ann_DASH_check_DASH_temp1901412) {
return $Hann_DASH_check_DASH_temp5301413(ann_DASH_check_DASH_temp1901412);
}};
$e14021403.stack[R.EXN_STACKHEIGHT++] = $ss14061407;
}
if(R.isPyretException($e14021403)) {
$e14021403.pyretStack.push(L[125]);
}
throw $e14021403;
}
var $ret14081409 = $Hann_DASH_check_DASH_temp5301413($z14041405);
++R.GAS;
return $ret14081409;
};
var $Hann_DASH_check_DASH_temp5301413 = function(ann_DASH_check_DASH_temp1901412) {
return ann_DASH_check_DASH_temp1901412;
};
var $Hcont_tail_arg5281414 = function(cont_tail_arg1871415,if_helper1771416) {
if(--R.GAS > 0) {
$z14171418 = R.isFunction(if_helper1771416)?if_helper1771416.app(cont_tail_arg1871415):R.ffi.throwNonFunApp(L[125],if_helper1771416,[cont_tail_arg1871415]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper1771416)?if_helper1771416.app(cont_tail_arg1871415):R.ffi.throwNonFunApp(L[125],if_helper1771416,[cont_tail_arg1871415]);
},
"from":L[125]});
}
++R.GAS;
return $z14171418;
};
var $Hcont_tail_arg5291419 = function(cont_tail_arg1821420,if_helper1771416) {
if(--R.GAS > 0) {
$z14211422 = R.isFunction(if_helper1771416)?if_helper1771416.app(cont_tail_arg1821420):R.ffi.throwNonFunApp(L[125],if_helper1771416,[cont_tail_arg1821420]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper1771416)?if_helper1771416.app(cont_tail_arg1821420):R.ffi.throwNonFunApp(L[125],if_helper1771416,[cont_tail_arg1821420]);
},
"from":L[125]});
}
++R.GAS;
return $z14211422;
};
var $Hanf_arg5271423 = function(anf_arg1701424,self1071425,_plus5,torepr10) {
var $z14281429 = D;
var $f14341435 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Got unexpected exception "),anf_arg1701424):R.ffi.throwNonFunApp(L[126],_plus5,[("Got unexpected exception "),anf_arg1701424]);
};
try {
if(--R.GAS > 0) {
$z14281429 = $f14341435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14341435,
"from":L[126]});
}
} catch($e14261427) {
if(R.isCont($e14261427)) {
var $ss14301431 = {"from":L[126],
"go":function(anf_arg1711436) {
return $Hanf_arg5261437(anf_arg1711436,self1071425,_plus5,torepr10);
}};
$e14261427.stack[R.EXN_STACKHEIGHT++] = $ss14301431;
}
if(R.isPyretException($e14261427)) {
$e14261427.pyretStack.push(L[126]);
}
throw $e14261427;
}
var $ret14321433 = $Hanf_arg5261437($z14281429,self1071425,_plus5,torepr10);
++R.GAS;
return $ret14321433;
};
var $Hanf_arg5261437 = function(anf_arg1711436,self1071425,_plus5,torepr10) {
var $z14401441 = D;
var $f14461447 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1711436,(", when expecting ")):R.ffi.throwNonFunApp(L[126],_plus5,[anf_arg1711436,(", when expecting ")]);
};
try {
if(--R.GAS > 0) {
$z14401441 = $f14461447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14461447,
"from":L[126]});
}
} catch($e14381439) {
if(R.isCont($e14381439)) {
var $ss14421443 = {"from":L[126],
"go":function(anf_arg1721448) {
return $Hanf_arg5251449(anf_arg1721448,self1071425,_plus5,torepr10);
}};
$e14381439.stack[R.EXN_STACKHEIGHT++] = $ss14421443;
}
if(R.isPyretException($e14381439)) {
$e14381439.pyretStack.push(L[126]);
}
throw $e14381439;
}
var $ret14441445 = $Hanf_arg5251449($z14401441,self1071425,_plus5,torepr10);
++R.GAS;
return $ret14441445;
};
var $Hanf_arg5251449 = function(anf_arg1721448,self1071425,_plus5,torepr10) {
var anf_arg1731460 = G(self1071425,"exn-expected",L[128]);
var $z14521453 = D;
var $f14581459 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1731460):R.ffi.throwNonFunApp(L[127],torepr10,[anf_arg1731460]);
};
try {
if(--R.GAS > 0) {
$z14521453 = $f14581459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14581459,
"from":L[127]});
}
} catch($e14501451) {
if(R.isCont($e14501451)) {
var $ss14541455 = {"from":L[127],
"go":function(anf_arg1741461) {
return $Hanf_arg5241462(anf_arg1741461,anf_arg1721448,_plus5);
}};
$e14501451.stack[R.EXN_STACKHEIGHT++] = $ss14541455;
}
if(R.isPyretException($e14501451)) {
$e14501451.pyretStack.push(L[127]);
}
throw $e14501451;
}
var $ret14561457 = $Hanf_arg5241462($z14521453,anf_arg1721448,_plus5);
++R.GAS;
return $ret14561457;
};
var $Hanf_arg5241462 = function(anf_arg1741461,anf_arg1721448,_plus5) {
var $z14651466 = D;
var $f14711472 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1721448,anf_arg1741461):R.ffi.throwNonFunApp(L[129],_plus5,[anf_arg1721448,anf_arg1741461]);
};
try {
if(--R.GAS > 0) {
$z14651466 = $f14711472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14711472,
"from":L[129]});
}
} catch($e14631464) {
if(R.isCont($e14631464)) {
var $ss14671468 = {"from":L[129],
"go":function(ann_DASH_check_DASH_temp1681473) {
return $Hann_DASH_check_DASH_temp5231474(ann_DASH_check_DASH_temp1681473);
}};
$e14631464.stack[R.EXN_STACKHEIGHT++] = $ss14671468;
}
if(R.isPyretException($e14631464)) {
$e14631464.pyretStack.push(L[129]);
}
throw $e14631464;
}
var $ret14691470 = $Hann_DASH_check_DASH_temp5231474($z14651466);
++R.GAS;
return $ret14691470;
};
var $Hann_DASH_check_DASH_temp5231474 = function(ann_DASH_check_DASH_temp1681473) {
return ann_DASH_check_DASH_temp1681473;
};
var $Hanf_arg5221475 = function(anf_arg1521476,self291477,_plus5,torepr10) {
var anf_arg1531488 = G(self291477,"code",L[130]);
var $z14801481 = D;
var $f14861487 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1531488):R.ffi.throwNonFunApp(L[130],torepr10,[anf_arg1531488]);
};
try {
if(--R.GAS > 0) {
$z14801481 = $f14861487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14861487,
"from":L[130]});
}
} catch($e14781479) {
if(R.isCont($e14781479)) {
var $ss14821483 = {"from":L[130],
"go":function(anf_arg1541489) {
return $Hanf_arg5211490(anf_arg1541489,anf_arg1521476,self291477,_plus5,torepr10);
}};
$e14781479.stack[R.EXN_STACKHEIGHT++] = $ss14821483;
}
if(R.isPyretException($e14781479)) {
$e14781479.pyretStack.push(L[130]);
}
throw $e14781479;
}
var $ret14841485 = $Hanf_arg5211490($z14801481,anf_arg1521476,self291477,_plus5,torepr10);
++R.GAS;
return $ret14841485;
};
var $Hanf_arg5211490 = function(anf_arg1541489,anf_arg1521476,self291477,_plus5,torepr10) {
var $z14931494 = D;
var $f14991500 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1541489):R.ffi.throwNonFunApp(L[130],_plus5,[(", "),anf_arg1541489]);
};
try {
if(--R.GAS > 0) {
$z14931494 = $f14991500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14991500,
"from":L[130]});
}
} catch($e14911492) {
if(R.isCont($e14911492)) {
var $ss14951496 = {"from":L[130],
"go":function(anf_arg1551501) {
return $Hanf_arg5201502(anf_arg1551501,anf_arg1521476,self291477,_plus5,torepr10);
}};
$e14911492.stack[R.EXN_STACKHEIGHT++] = $ss14951496;
}
if(R.isPyretException($e14911492)) {
$e14911492.pyretStack.push(L[130]);
}
throw $e14911492;
}
var $ret14971498 = $Hanf_arg5201502($z14931494,anf_arg1521476,self291477,_plus5,torepr10);
++R.GAS;
return $ret14971498;
};
var $Hanf_arg5201502 = function(anf_arg1551501,anf_arg1521476,self291477,_plus5,torepr10) {
var $z15051506 = D;
var $f15111512 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1521476,anf_arg1551501):R.ffi.throwNonFunApp(L[130],_plus5,[anf_arg1521476,anf_arg1551501]);
};
try {
if(--R.GAS > 0) {
$z15051506 = $f15111512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15111512,
"from":L[130]});
}
} catch($e15031504) {
if(R.isCont($e15031504)) {
var $ss15071508 = {"from":L[130],
"go":function(anf_arg1561513) {
return $Hanf_arg5191514(anf_arg1561513,self291477,_plus5,torepr10);
}};
$e15031504.stack[R.EXN_STACKHEIGHT++] = $ss15071508;
}
if(R.isPyretException($e15031504)) {
$e15031504.pyretStack.push(L[130]);
}
throw $e15031504;
}
var $ret15091510 = $Hanf_arg5191514($z15051506,self291477,_plus5,torepr10);
++R.GAS;
return $ret15091510;
};
var $Hanf_arg5191514 = function(anf_arg1561513,self291477,_plus5,torepr10) {
var anf_arg1571525 = G(self291477,"exn-expected",L[130]);
var $z15171518 = D;
var $f15231524 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1571525):R.ffi.throwNonFunApp(L[130],torepr10,[anf_arg1571525]);
};
try {
if(--R.GAS > 0) {
$z15171518 = $f15231524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15231524,
"from":L[130]});
}
} catch($e15151516) {
if(R.isCont($e15151516)) {
var $ss15191520 = {"from":L[130],
"go":function(anf_arg1581526) {
return $Hanf_arg5181527(anf_arg1581526,anf_arg1561513,self291477,_plus5,torepr10);
}};
$e15151516.stack[R.EXN_STACKHEIGHT++] = $ss15191520;
}
if(R.isPyretException($e15151516)) {
$e15151516.pyretStack.push(L[130]);
}
throw $e15151516;
}
var $ret15211522 = $Hanf_arg5181527($z15171518,anf_arg1561513,self291477,_plus5,torepr10);
++R.GAS;
return $ret15211522;
};
var $Hanf_arg5181527 = function(anf_arg1581526,anf_arg1561513,self291477,_plus5,torepr10) {
var $z15301531 = D;
var $f15361537 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1581526):R.ffi.throwNonFunApp(L[130],_plus5,[(", "),anf_arg1581526]);
};
try {
if(--R.GAS > 0) {
$z15301531 = $f15361537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15361537,
"from":L[130]});
}
} catch($e15281529) {
if(R.isCont($e15281529)) {
var $ss15321533 = {"from":L[130],
"go":function(anf_arg1591538) {
return $Hanf_arg5171539(anf_arg1591538,anf_arg1561513,self291477,_plus5,torepr10);
}};
$e15281529.stack[R.EXN_STACKHEIGHT++] = $ss15321533;
}
if(R.isPyretException($e15281529)) {
$e15281529.pyretStack.push(L[130]);
}
throw $e15281529;
}
var $ret15341535 = $Hanf_arg5171539($z15301531,anf_arg1561513,self291477,_plus5,torepr10);
++R.GAS;
return $ret15341535;
};
var $Hanf_arg5171539 = function(anf_arg1591538,anf_arg1561513,self291477,_plus5,torepr10) {
var $z15421543 = D;
var $f15481549 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1561513,anf_arg1591538):R.ffi.throwNonFunApp(L[130],_plus5,[anf_arg1561513,anf_arg1591538]);
};
try {
if(--R.GAS > 0) {
$z15421543 = $f15481549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15481549,
"from":L[130]});
}
} catch($e15401541) {
if(R.isCont($e15401541)) {
var $ss15441545 = {"from":L[130],
"go":function(anf_arg1601550) {
return $Hanf_arg5161551(anf_arg1601550,self291477,_plus5,torepr10);
}};
$e15401541.stack[R.EXN_STACKHEIGHT++] = $ss15441545;
}
if(R.isPyretException($e15401541)) {
$e15401541.pyretStack.push(L[130]);
}
throw $e15401541;
}
var $ret15461547 = $Hanf_arg5161551($z15421543,self291477,_plus5,torepr10);
++R.GAS;
return $ret15461547;
};
var $Hanf_arg5161551 = function(anf_arg1601550,self291477,_plus5,torepr10) {
var anf_arg1611562 = G(self291477,"actual-exn",L[130]);
var $z15541555 = D;
var $f15601561 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1611562):R.ffi.throwNonFunApp(L[130],torepr10,[anf_arg1611562]);
};
try {
if(--R.GAS > 0) {
$z15541555 = $f15601561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15601561,
"from":L[130]});
}
} catch($e15521553) {
if(R.isCont($e15521553)) {
var $ss15561557 = {"from":L[130],
"go":function(anf_arg1621563) {
return $Hanf_arg5151564(anf_arg1621563,anf_arg1601550,_plus5);
}};
$e15521553.stack[R.EXN_STACKHEIGHT++] = $ss15561557;
}
if(R.isPyretException($e15521553)) {
$e15521553.pyretStack.push(L[130]);
}
throw $e15521553;
}
var $ret15581559 = $Hanf_arg5151564($z15541555,anf_arg1601550,_plus5);
++R.GAS;
return $ret15581559;
};
var $Hanf_arg5151564 = function(anf_arg1621563,anf_arg1601550,_plus5) {
var $z15671568 = D;
var $f15731574 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1621563):R.ffi.throwNonFunApp(L[130],_plus5,[(", "),anf_arg1621563]);
};
try {
if(--R.GAS > 0) {
$z15671568 = $f15731574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15731574,
"from":L[130]});
}
} catch($e15651566) {
if(R.isCont($e15651566)) {
var $ss15691570 = {"from":L[130],
"go":function(anf_arg1631575) {
return $Hanf_arg5141576(anf_arg1631575,anf_arg1601550,_plus5);
}};
$e15651566.stack[R.EXN_STACKHEIGHT++] = $ss15691570;
}
if(R.isPyretException($e15651566)) {
$e15651566.pyretStack.push(L[130]);
}
throw $e15651566;
}
var $ret15711572 = $Hanf_arg5141576($z15671568,anf_arg1601550,_plus5);
++R.GAS;
return $ret15711572;
};
var $Hanf_arg5141576 = function(anf_arg1631575,anf_arg1601550,_plus5) {
var $z15791580 = D;
var $f15851586 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1601550,anf_arg1631575):R.ffi.throwNonFunApp(L[130],_plus5,[anf_arg1601550,anf_arg1631575]);
};
try {
if(--R.GAS > 0) {
$z15791580 = $f15851586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15851586,
"from":L[130]});
}
} catch($e15771578) {
if(R.isCont($e15771578)) {
var $ss15811582 = {"from":L[130],
"go":function(anf_arg1641587) {
return $Hanf_arg5131588(anf_arg1641587,_plus5);
}};
$e15771578.stack[R.EXN_STACKHEIGHT++] = $ss15811582;
}
if(R.isPyretException($e15771578)) {
$e15771578.pyretStack.push(L[130]);
}
throw $e15771578;
}
var $ret15831584 = $Hanf_arg5131588($z15791580,_plus5);
++R.GAS;
return $ret15831584;
};
var $Hanf_arg5131588 = function(anf_arg1641587,_plus5) {
var $z15911592 = D;
var $f15971598 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1641587,(")")):R.ffi.throwNonFunApp(L[130],_plus5,[anf_arg1641587,(")")]);
};
try {
if(--R.GAS > 0) {
$z15911592 = $f15971598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15971598,
"from":L[130]});
}
} catch($e15891590) {
if(R.isCont($e15891590)) {
var $ss15931594 = {"from":L[130],
"go":function(anf_arg1651599) {
return $Hanf_arg5121600(anf_arg1651599,_plus5);
}};
$e15891590.stack[R.EXN_STACKHEIGHT++] = $ss15931594;
}
if(R.isPyretException($e15891590)) {
$e15891590.pyretStack.push(L[130]);
}
throw $e15891590;
}
var $ret15951596 = $Hanf_arg5121600($z15911592,_plus5);
++R.GAS;
return $ret15951596;
};
var $Hanf_arg5121600 = function(anf_arg1651599,_plus5) {
var $z16031604 = D;
var $f16091610 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg1651599):R.ffi.throwNonFunApp(L[130],_plus5,[("("),anf_arg1651599]);
};
try {
if(--R.GAS > 0) {
$z16031604 = $f16091610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16091610,
"from":L[130]});
}
} catch($e16011602) {
if(R.isCont($e16011602)) {
var $ss16051606 = {"from":L[130],
"go":function(anf_arg1661611) {
return $Hanf_arg5111612(anf_arg1661611,_plus5);
}};
$e16011602.stack[R.EXN_STACKHEIGHT++] = $ss16051606;
}
if(R.isPyretException($e16011602)) {
$e16011602.pyretStack.push(L[130]);
}
throw $e16011602;
}
var $ret16071608 = $Hanf_arg5111612($z16031604,_plus5);
++R.GAS;
return $ret16071608;
};
var $Hanf_arg5111612 = function(anf_arg1661611,_plus5) {
var $z16151616 = D;
var $f16211622 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("failure-wrong-exn"),anf_arg1661611):R.ffi.throwNonFunApp(L[130],_plus5,[("failure-wrong-exn"),anf_arg1661611]);
};
try {
if(--R.GAS > 0) {
$z16151616 = $f16211622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16211622,
"from":L[130]});
}
} catch($e16131614) {
if(R.isCont($e16131614)) {
var $ss16171618 = {"from":L[130],
"go":function(ann_DASH_check_DASH_temp1501623) {
return $Hann_DASH_check_DASH_temp5101624(ann_DASH_check_DASH_temp1501623);
}};
$e16131614.stack[R.EXN_STACKHEIGHT++] = $ss16171618;
}
if(R.isPyretException($e16131614)) {
$e16131614.pyretStack.push(L[130]);
}
throw $e16131614;
}
var $ret16191620 = $Hann_DASH_check_DASH_temp5101624($z16151616);
++R.GAS;
return $ret16191620;
};
var $Hann_DASH_check_DASH_temp5101624 = function(ann_DASH_check_DASH_temp1501623) {
return ann_DASH_check_DASH_temp1501623;
};
var $Hcont_tail_arg5081625 = function(cont_tail_arg1471626,if_helper1361627) {
if(--R.GAS > 0) {
$z16281629 = R.isFunction(if_helper1361627)?if_helper1361627.app(cont_tail_arg1471626):R.ffi.throwNonFunApp(L[130],if_helper1361627,[cont_tail_arg1471626]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper1361627)?if_helper1361627.app(cont_tail_arg1471626):R.ffi.throwNonFunApp(L[130],if_helper1361627,[cont_tail_arg1471626]);
},
"from":L[130]});
}
++R.GAS;
return $z16281629;
};
var $Hcont_tail_arg5091630 = function(cont_tail_arg1411631,if_helper1361627) {
if(--R.GAS > 0) {
$z16321633 = R.isFunction(if_helper1361627)?if_helper1361627.app(cont_tail_arg1411631):R.ffi.throwNonFunApp(L[130],if_helper1361627,[cont_tail_arg1411631]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper1361627)?if_helper1361627.app(cont_tail_arg1411631):R.ffi.throwNonFunApp(L[130],if_helper1361627,[cont_tail_arg1411631]);
},
"from":L[130]});
}
++R.GAS;
return $z16321633;
};
var $Hanf_arg5071634 = function(anf_arg1331635,_plus5) {
var $z16381639 = D;
var $f16441645 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Predicate failed for value: "),anf_arg1331635):R.ffi.throwNonFunApp(L[131],_plus5,[("Predicate failed for value: "),anf_arg1331635]);
};
try {
if(--R.GAS > 0) {
$z16381639 = $f16441645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16441645,
"from":L[131]});
}
} catch($e16361637) {
if(R.isCont($e16361637)) {
var $ss16401641 = {"from":L[131],
"go":function(ann_DASH_check_DASH_temp1311646) {
return $Hann_DASH_check_DASH_temp5061647(ann_DASH_check_DASH_temp1311646);
}};
$e16361637.stack[R.EXN_STACKHEIGHT++] = $ss16401641;
}
if(R.isPyretException($e16361637)) {
$e16361637.pyretStack.push(L[131]);
}
throw $e16361637;
}
var $ret16421643 = $Hann_DASH_check_DASH_temp5061647($z16381639);
++R.GAS;
return $ret16421643;
};
var $Hann_DASH_check_DASH_temp5061647 = function(ann_DASH_check_DASH_temp1311646) {
return ann_DASH_check_DASH_temp1311646;
};
var $Hanf_arg5051648 = function(anf_arg1151649,self231650,_plus5,torepr10) {
var anf_arg1161661 = G(self231650,"code",L[132]);
var $z16531654 = D;
var $f16591660 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1161661):R.ffi.throwNonFunApp(L[132],torepr10,[anf_arg1161661]);
};
try {
if(--R.GAS > 0) {
$z16531654 = $f16591660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16591660,
"from":L[132]});
}
} catch($e16511652) {
if(R.isCont($e16511652)) {
var $ss16551656 = {"from":L[132],
"go":function(anf_arg1171662) {
return $Hanf_arg5041663(anf_arg1171662,anf_arg1151649,self231650,_plus5,torepr10);
}};
$e16511652.stack[R.EXN_STACKHEIGHT++] = $ss16551656;
}
if(R.isPyretException($e16511652)) {
$e16511652.pyretStack.push(L[132]);
}
throw $e16511652;
}
var $ret16571658 = $Hanf_arg5041663($z16531654,anf_arg1151649,self231650,_plus5,torepr10);
++R.GAS;
return $ret16571658;
};
var $Hanf_arg5041663 = function(anf_arg1171662,anf_arg1151649,self231650,_plus5,torepr10) {
var $z16661667 = D;
var $f16721673 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1171662):R.ffi.throwNonFunApp(L[132],_plus5,[(", "),anf_arg1171662]);
};
try {
if(--R.GAS > 0) {
$z16661667 = $f16721673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16721673,
"from":L[132]});
}
} catch($e16641665) {
if(R.isCont($e16641665)) {
var $ss16681669 = {"from":L[132],
"go":function(anf_arg1181674) {
return $Hanf_arg5031675(anf_arg1181674,anf_arg1151649,self231650,_plus5,torepr10);
}};
$e16641665.stack[R.EXN_STACKHEIGHT++] = $ss16681669;
}
if(R.isPyretException($e16641665)) {
$e16641665.pyretStack.push(L[132]);
}
throw $e16641665;
}
var $ret16701671 = $Hanf_arg5031675($z16661667,anf_arg1151649,self231650,_plus5,torepr10);
++R.GAS;
return $ret16701671;
};
var $Hanf_arg5031675 = function(anf_arg1181674,anf_arg1151649,self231650,_plus5,torepr10) {
var $z16781679 = D;
var $f16841685 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1151649,anf_arg1181674):R.ffi.throwNonFunApp(L[132],_plus5,[anf_arg1151649,anf_arg1181674]);
};
try {
if(--R.GAS > 0) {
$z16781679 = $f16841685();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16841685,
"from":L[132]});
}
} catch($e16761677) {
if(R.isCont($e16761677)) {
var $ss16801681 = {"from":L[132],
"go":function(anf_arg1191686) {
return $Hanf_arg5021687(anf_arg1191686,self231650,_plus5,torepr10);
}};
$e16761677.stack[R.EXN_STACKHEIGHT++] = $ss16801681;
}
if(R.isPyretException($e16761677)) {
$e16761677.pyretStack.push(L[132]);
}
throw $e16761677;
}
var $ret16821683 = $Hanf_arg5021687($z16781679,self231650,_plus5,torepr10);
++R.GAS;
return $ret16821683;
};
var $Hanf_arg5021687 = function(anf_arg1191686,self231650,_plus5,torepr10) {
var anf_arg1201698 = G(self231650,"val",L[132]);
var $z16901691 = D;
var $f16961697 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1201698):R.ffi.throwNonFunApp(L[132],torepr10,[anf_arg1201698]);
};
try {
if(--R.GAS > 0) {
$z16901691 = $f16961697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16961697,
"from":L[132]});
}
} catch($e16881689) {
if(R.isCont($e16881689)) {
var $ss16921693 = {"from":L[132],
"go":function(anf_arg1211699) {
return $Hanf_arg5011700(anf_arg1211699,anf_arg1191686,self231650,_plus5,torepr10);
}};
$e16881689.stack[R.EXN_STACKHEIGHT++] = $ss16921693;
}
if(R.isPyretException($e16881689)) {
$e16881689.pyretStack.push(L[132]);
}
throw $e16881689;
}
var $ret16941695 = $Hanf_arg5011700($z16901691,anf_arg1191686,self231650,_plus5,torepr10);
++R.GAS;
return $ret16941695;
};
var $Hanf_arg5011700 = function(anf_arg1211699,anf_arg1191686,self231650,_plus5,torepr10) {
var $z17031704 = D;
var $f17091710 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1211699):R.ffi.throwNonFunApp(L[132],_plus5,[(", "),anf_arg1211699]);
};
try {
if(--R.GAS > 0) {
$z17031704 = $f17091710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17091710,
"from":L[132]});
}
} catch($e17011702) {
if(R.isCont($e17011702)) {
var $ss17051706 = {"from":L[132],
"go":function(anf_arg1221711) {
return $Hanf_arg5001712(anf_arg1221711,anf_arg1191686,self231650,_plus5,torepr10);
}};
$e17011702.stack[R.EXN_STACKHEIGHT++] = $ss17051706;
}
if(R.isPyretException($e17011702)) {
$e17011702.pyretStack.push(L[132]);
}
throw $e17011702;
}
var $ret17071708 = $Hanf_arg5001712($z17031704,anf_arg1191686,self231650,_plus5,torepr10);
++R.GAS;
return $ret17071708;
};
var $Hanf_arg5001712 = function(anf_arg1221711,anf_arg1191686,self231650,_plus5,torepr10) {
var $z17151716 = D;
var $f17211722 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1191686,anf_arg1221711):R.ffi.throwNonFunApp(L[132],_plus5,[anf_arg1191686,anf_arg1221711]);
};
try {
if(--R.GAS > 0) {
$z17151716 = $f17211722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17211722,
"from":L[132]});
}
} catch($e17131714) {
if(R.isCont($e17131714)) {
var $ss17171718 = {"from":L[132],
"go":function(anf_arg1231723) {
return $Hanf_arg4991724(anf_arg1231723,self231650,_plus5,torepr10);
}};
$e17131714.stack[R.EXN_STACKHEIGHT++] = $ss17171718;
}
if(R.isPyretException($e17131714)) {
$e17131714.pyretStack.push(L[132]);
}
throw $e17131714;
}
var $ret17191720 = $Hanf_arg4991724($z17151716,self231650,_plus5,torepr10);
++R.GAS;
return $ret17191720;
};
var $Hanf_arg4991724 = function(anf_arg1231723,self231650,_plus5,torepr10) {
var anf_arg1241735 = G(self231650,"pred",L[132]);
var $z17271728 = D;
var $f17331734 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1241735):R.ffi.throwNonFunApp(L[132],torepr10,[anf_arg1241735]);
};
try {
if(--R.GAS > 0) {
$z17271728 = $f17331734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17331734,
"from":L[132]});
}
} catch($e17251726) {
if(R.isCont($e17251726)) {
var $ss17291730 = {"from":L[132],
"go":function(anf_arg1251736) {
return $Hanf_arg4981737(anf_arg1251736,anf_arg1231723,_plus5);
}};
$e17251726.stack[R.EXN_STACKHEIGHT++] = $ss17291730;
}
if(R.isPyretException($e17251726)) {
$e17251726.pyretStack.push(L[132]);
}
throw $e17251726;
}
var $ret17311732 = $Hanf_arg4981737($z17271728,anf_arg1231723,_plus5);
++R.GAS;
return $ret17311732;
};
var $Hanf_arg4981737 = function(anf_arg1251736,anf_arg1231723,_plus5) {
var $z17401741 = D;
var $f17461747 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg1251736):R.ffi.throwNonFunApp(L[132],_plus5,[(", "),anf_arg1251736]);
};
try {
if(--R.GAS > 0) {
$z17401741 = $f17461747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17461747,
"from":L[132]});
}
} catch($e17381739) {
if(R.isCont($e17381739)) {
var $ss17421743 = {"from":L[132],
"go":function(anf_arg1261748) {
return $Hanf_arg4971749(anf_arg1261748,anf_arg1231723,_plus5);
}};
$e17381739.stack[R.EXN_STACKHEIGHT++] = $ss17421743;
}
if(R.isPyretException($e17381739)) {
$e17381739.pyretStack.push(L[132]);
}
throw $e17381739;
}
var $ret17441745 = $Hanf_arg4971749($z17401741,anf_arg1231723,_plus5);
++R.GAS;
return $ret17441745;
};
var $Hanf_arg4971749 = function(anf_arg1261748,anf_arg1231723,_plus5) {
var $z17521753 = D;
var $f17581759 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1231723,anf_arg1261748):R.ffi.throwNonFunApp(L[132],_plus5,[anf_arg1231723,anf_arg1261748]);
};
try {
if(--R.GAS > 0) {
$z17521753 = $f17581759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17581759,
"from":L[132]});
}
} catch($e17501751) {
if(R.isCont($e17501751)) {
var $ss17541755 = {"from":L[132],
"go":function(anf_arg1271760) {
return $Hanf_arg4961761(anf_arg1271760,_plus5);
}};
$e17501751.stack[R.EXN_STACKHEIGHT++] = $ss17541755;
}
if(R.isPyretException($e17501751)) {
$e17501751.pyretStack.push(L[132]);
}
throw $e17501751;
}
var $ret17561757 = $Hanf_arg4961761($z17521753,_plus5);
++R.GAS;
return $ret17561757;
};
var $Hanf_arg4961761 = function(anf_arg1271760,_plus5) {
var $z17641765 = D;
var $f17701771 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg1271760,(")")):R.ffi.throwNonFunApp(L[132],_plus5,[anf_arg1271760,(")")]);
};
try {
if(--R.GAS > 0) {
$z17641765 = $f17701771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17701771,
"from":L[132]});
}
} catch($e17621763) {
if(R.isCont($e17621763)) {
var $ss17661767 = {"from":L[132],
"go":function(anf_arg1281772) {
return $Hanf_arg4951773(anf_arg1281772,_plus5);
}};
$e17621763.stack[R.EXN_STACKHEIGHT++] = $ss17661767;
}
if(R.isPyretException($e17621763)) {
$e17621763.pyretStack.push(L[132]);
}
throw $e17621763;
}
var $ret17681769 = $Hanf_arg4951773($z17641765,_plus5);
++R.GAS;
return $ret17681769;
};
var $Hanf_arg4951773 = function(anf_arg1281772,_plus5) {
var $z17761777 = D;
var $f17821783 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg1281772):R.ffi.throwNonFunApp(L[132],_plus5,[("("),anf_arg1281772]);
};
try {
if(--R.GAS > 0) {
$z17761777 = $f17821783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17821783,
"from":L[132]});
}
} catch($e17741775) {
if(R.isCont($e17741775)) {
var $ss17781779 = {"from":L[132],
"go":function(anf_arg1291784) {
return $Hanf_arg4941785(anf_arg1291784,_plus5);
}};
$e17741775.stack[R.EXN_STACKHEIGHT++] = $ss17781779;
}
if(R.isPyretException($e17741775)) {
$e17741775.pyretStack.push(L[132]);
}
throw $e17741775;
}
var $ret17801781 = $Hanf_arg4941785($z17761777,_plus5);
++R.GAS;
return $ret17801781;
};
var $Hanf_arg4941785 = function(anf_arg1291784,_plus5) {
var $z17881789 = D;
var $f17941795 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("failure-not-satisfied"),anf_arg1291784):R.ffi.throwNonFunApp(L[132],_plus5,[("failure-not-satisfied"),anf_arg1291784]);
};
try {
if(--R.GAS > 0) {
$z17881789 = $f17941795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17941795,
"from":L[132]});
}
} catch($e17861787) {
if(R.isCont($e17861787)) {
var $ss17901791 = {"from":L[132],
"go":function(ann_DASH_check_DASH_temp1131796) {
return $Hann_DASH_check_DASH_temp4931797(ann_DASH_check_DASH_temp1131796);
}};
$e17861787.stack[R.EXN_STACKHEIGHT++] = $ss17901791;
}
if(R.isPyretException($e17861787)) {
$e17861787.pyretStack.push(L[132]);
}
throw $e17861787;
}
var $ret17921793 = $Hann_DASH_check_DASH_temp4931797($z17881789);
++R.GAS;
return $ret17921793;
};
var $Hann_DASH_check_DASH_temp4931797 = function(ann_DASH_check_DASH_temp1131796) {
return ann_DASH_check_DASH_temp1131796;
};
var $Hcont_tail_arg4911798 = function(cont_tail_arg1101799,if_helper991800) {
if(--R.GAS > 0) {
$z18011802 = R.isFunction(if_helper991800)?if_helper991800.app(cont_tail_arg1101799):R.ffi.throwNonFunApp(L[132],if_helper991800,[cont_tail_arg1101799]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper991800)?if_helper991800.app(cont_tail_arg1101799):R.ffi.throwNonFunApp(L[132],if_helper991800,[cont_tail_arg1101799]);
},
"from":L[132]});
}
++R.GAS;
return $z18011802;
};
var $Hcont_tail_arg4921803 = function(cont_tail_arg1041804,if_helper991800) {
if(--R.GAS > 0) {
$z18051806 = R.isFunction(if_helper991800)?if_helper991800.app(cont_tail_arg1041804):R.ffi.throwNonFunApp(L[132],if_helper991800,[cont_tail_arg1041804]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper991800)?if_helper991800.app(cont_tail_arg1041804):R.ffi.throwNonFunApp(L[132],if_helper991800,[cont_tail_arg1041804]);
},
"from":L[132]});
}
++R.GAS;
return $z18051806;
};
var $Hanf_arg4901807 = function(anf_arg921808,self971809,_plus5,torepr10) {
var $z18121813 = D;
var $f18181819 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("Values not equal:\n"),anf_arg921808):R.ffi.throwNonFunApp(L[133],_plus5,[("Values not equal:\n"),anf_arg921808]);
};
try {
if(--R.GAS > 0) {
$z18121813 = $f18181819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18181819,
"from":L[133]});
}
} catch($e18101811) {
if(R.isCont($e18101811)) {
var $ss18141815 = {"from":L[133],
"go":function(anf_arg931820) {
return $Hanf_arg4891821(anf_arg931820,self971809,_plus5,torepr10);
}};
$e18101811.stack[R.EXN_STACKHEIGHT++] = $ss18141815;
}
if(R.isPyretException($e18101811)) {
$e18101811.pyretStack.push(L[133]);
}
throw $e18101811;
}
var $ret18161817 = $Hanf_arg4891821($z18121813,self971809,_plus5,torepr10);
++R.GAS;
return $ret18161817;
};
var $Hanf_arg4891821 = function(anf_arg931820,self971809,_plus5,torepr10) {
var $z18241825 = D;
var $f18301831 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg931820,("\n")):R.ffi.throwNonFunApp(L[133],_plus5,[anf_arg931820,("\n")]);
};
try {
if(--R.GAS > 0) {
$z18241825 = $f18301831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18301831,
"from":L[133]});
}
} catch($e18221823) {
if(R.isCont($e18221823)) {
var $ss18261827 = {"from":L[133],
"go":function(anf_arg941832) {
return $Hanf_arg4881833(anf_arg941832,self971809,_plus5,torepr10);
}};
$e18221823.stack[R.EXN_STACKHEIGHT++] = $ss18261827;
}
if(R.isPyretException($e18221823)) {
$e18221823.pyretStack.push(L[133]);
}
throw $e18221823;
}
var $ret18281829 = $Hanf_arg4881833($z18241825,self971809,_plus5,torepr10);
++R.GAS;
return $ret18281829;
};
var $Hanf_arg4881833 = function(anf_arg941832,self971809,_plus5,torepr10) {
var anf_arg951844 = G(self971809,"right",L[135]);
var $z18361837 = D;
var $f18421843 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg951844):R.ffi.throwNonFunApp(L[134],torepr10,[anf_arg951844]);
};
try {
if(--R.GAS > 0) {
$z18361837 = $f18421843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18421843,
"from":L[134]});
}
} catch($e18341835) {
if(R.isCont($e18341835)) {
var $ss18381839 = {"from":L[134],
"go":function(anf_arg961845) {
return $Hanf_arg4871846(anf_arg961845,anf_arg941832,_plus5);
}};
$e18341835.stack[R.EXN_STACKHEIGHT++] = $ss18381839;
}
if(R.isPyretException($e18341835)) {
$e18341835.pyretStack.push(L[134]);
}
throw $e18341835;
}
var $ret18401841 = $Hanf_arg4871846($z18361837,anf_arg941832,_plus5);
++R.GAS;
return $ret18401841;
};
var $Hanf_arg4871846 = function(anf_arg961845,anf_arg941832,_plus5) {
var $z18491850 = D;
var $f18551856 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg941832,anf_arg961845):R.ffi.throwNonFunApp(L[136],_plus5,[anf_arg941832,anf_arg961845]);
};
try {
if(--R.GAS > 0) {
$z18491850 = $f18551856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18551856,
"from":L[136]});
}
} catch($e18471848) {
if(R.isCont($e18471848)) {
var $ss18511852 = {"from":L[136],
"go":function(ann_DASH_check_DASH_temp901857) {
return $Hann_DASH_check_DASH_temp4861858(ann_DASH_check_DASH_temp901857);
}};
$e18471848.stack[R.EXN_STACKHEIGHT++] = $ss18511852;
}
if(R.isPyretException($e18471848)) {
$e18471848.pyretStack.push(L[136]);
}
throw $e18471848;
}
var $ret18531854 = $Hann_DASH_check_DASH_temp4861858($z18491850);
++R.GAS;
return $ret18531854;
};
var $Hann_DASH_check_DASH_temp4861858 = function(ann_DASH_check_DASH_temp901857) {
return ann_DASH_check_DASH_temp901857;
};
var $Hanf_arg4851859 = function(anf_arg741860,self171861,_plus5,torepr10) {
var anf_arg751872 = G(self171861,"code",L[137]);
var $z18641865 = D;
var $f18701871 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg751872):R.ffi.throwNonFunApp(L[137],torepr10,[anf_arg751872]);
};
try {
if(--R.GAS > 0) {
$z18641865 = $f18701871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18701871,
"from":L[137]});
}
} catch($e18621863) {
if(R.isCont($e18621863)) {
var $ss18661867 = {"from":L[137],
"go":function(anf_arg761873) {
return $Hanf_arg4841874(anf_arg761873,anf_arg741860,self171861,_plus5,torepr10);
}};
$e18621863.stack[R.EXN_STACKHEIGHT++] = $ss18661867;
}
if(R.isPyretException($e18621863)) {
$e18621863.pyretStack.push(L[137]);
}
throw $e18621863;
}
var $ret18681869 = $Hanf_arg4841874($z18641865,anf_arg741860,self171861,_plus5,torepr10);
++R.GAS;
return $ret18681869;
};
var $Hanf_arg4841874 = function(anf_arg761873,anf_arg741860,self171861,_plus5,torepr10) {
var $z18771878 = D;
var $f18831884 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg761873):R.ffi.throwNonFunApp(L[137],_plus5,[(", "),anf_arg761873]);
};
try {
if(--R.GAS > 0) {
$z18771878 = $f18831884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18831884,
"from":L[137]});
}
} catch($e18751876) {
if(R.isCont($e18751876)) {
var $ss18791880 = {"from":L[137],
"go":function(anf_arg771885) {
return $Hanf_arg4831886(anf_arg771885,anf_arg741860,self171861,_plus5,torepr10);
}};
$e18751876.stack[R.EXN_STACKHEIGHT++] = $ss18791880;
}
if(R.isPyretException($e18751876)) {
$e18751876.pyretStack.push(L[137]);
}
throw $e18751876;
}
var $ret18811882 = $Hanf_arg4831886($z18771878,anf_arg741860,self171861,_plus5,torepr10);
++R.GAS;
return $ret18811882;
};
var $Hanf_arg4831886 = function(anf_arg771885,anf_arg741860,self171861,_plus5,torepr10) {
var $z18891890 = D;
var $f18951896 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg741860,anf_arg771885):R.ffi.throwNonFunApp(L[137],_plus5,[anf_arg741860,anf_arg771885]);
};
try {
if(--R.GAS > 0) {
$z18891890 = $f18951896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18951896,
"from":L[137]});
}
} catch($e18871888) {
if(R.isCont($e18871888)) {
var $ss18911892 = {"from":L[137],
"go":function(anf_arg781897) {
return $Hanf_arg4821898(anf_arg781897,self171861,_plus5,torepr10);
}};
$e18871888.stack[R.EXN_STACKHEIGHT++] = $ss18911892;
}
if(R.isPyretException($e18871888)) {
$e18871888.pyretStack.push(L[137]);
}
throw $e18871888;
}
var $ret18931894 = $Hanf_arg4821898($z18891890,self171861,_plus5,torepr10);
++R.GAS;
return $ret18931894;
};
var $Hanf_arg4821898 = function(anf_arg781897,self171861,_plus5,torepr10) {
var anf_arg791909 = G(self171861,"left",L[137]);
var $z19011902 = D;
var $f19071908 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg791909):R.ffi.throwNonFunApp(L[137],torepr10,[anf_arg791909]);
};
try {
if(--R.GAS > 0) {
$z19011902 = $f19071908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19071908,
"from":L[137]});
}
} catch($e18991900) {
if(R.isCont($e18991900)) {
var $ss19031904 = {"from":L[137],
"go":function(anf_arg801910) {
return $Hanf_arg4811911(anf_arg801910,anf_arg781897,self171861,_plus5,torepr10);
}};
$e18991900.stack[R.EXN_STACKHEIGHT++] = $ss19031904;
}
if(R.isPyretException($e18991900)) {
$e18991900.pyretStack.push(L[137]);
}
throw $e18991900;
}
var $ret19051906 = $Hanf_arg4811911($z19011902,anf_arg781897,self171861,_plus5,torepr10);
++R.GAS;
return $ret19051906;
};
var $Hanf_arg4811911 = function(anf_arg801910,anf_arg781897,self171861,_plus5,torepr10) {
var $z19141915 = D;
var $f19201921 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg801910):R.ffi.throwNonFunApp(L[137],_plus5,[(", "),anf_arg801910]);
};
try {
if(--R.GAS > 0) {
$z19141915 = $f19201921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19201921,
"from":L[137]});
}
} catch($e19121913) {
if(R.isCont($e19121913)) {
var $ss19161917 = {"from":L[137],
"go":function(anf_arg811922) {
return $Hanf_arg4801923(anf_arg811922,anf_arg781897,self171861,_plus5,torepr10);
}};
$e19121913.stack[R.EXN_STACKHEIGHT++] = $ss19161917;
}
if(R.isPyretException($e19121913)) {
$e19121913.pyretStack.push(L[137]);
}
throw $e19121913;
}
var $ret19181919 = $Hanf_arg4801923($z19141915,anf_arg781897,self171861,_plus5,torepr10);
++R.GAS;
return $ret19181919;
};
var $Hanf_arg4801923 = function(anf_arg811922,anf_arg781897,self171861,_plus5,torepr10) {
var $z19261927 = D;
var $f19321933 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg781897,anf_arg811922):R.ffi.throwNonFunApp(L[137],_plus5,[anf_arg781897,anf_arg811922]);
};
try {
if(--R.GAS > 0) {
$z19261927 = $f19321933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19321933,
"from":L[137]});
}
} catch($e19241925) {
if(R.isCont($e19241925)) {
var $ss19281929 = {"from":L[137],
"go":function(anf_arg821934) {
return $Hanf_arg4791935(anf_arg821934,self171861,_plus5,torepr10);
}};
$e19241925.stack[R.EXN_STACKHEIGHT++] = $ss19281929;
}
if(R.isPyretException($e19241925)) {
$e19241925.pyretStack.push(L[137]);
}
throw $e19241925;
}
var $ret19301931 = $Hanf_arg4791935($z19261927,self171861,_plus5,torepr10);
++R.GAS;
return $ret19301931;
};
var $Hanf_arg4791935 = function(anf_arg821934,self171861,_plus5,torepr10) {
var anf_arg831946 = G(self171861,"right",L[137]);
var $z19381939 = D;
var $f19441945 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg831946):R.ffi.throwNonFunApp(L[137],torepr10,[anf_arg831946]);
};
try {
if(--R.GAS > 0) {
$z19381939 = $f19441945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19441945,
"from":L[137]});
}
} catch($e19361937) {
if(R.isCont($e19361937)) {
var $ss19401941 = {"from":L[137],
"go":function(anf_arg841947) {
return $Hanf_arg4781948(anf_arg841947,anf_arg821934,_plus5);
}};
$e19361937.stack[R.EXN_STACKHEIGHT++] = $ss19401941;
}
if(R.isPyretException($e19361937)) {
$e19361937.pyretStack.push(L[137]);
}
throw $e19361937;
}
var $ret19421943 = $Hanf_arg4781948($z19381939,anf_arg821934,_plus5);
++R.GAS;
return $ret19421943;
};
var $Hanf_arg4781948 = function(anf_arg841947,anf_arg821934,_plus5) {
var $z19511952 = D;
var $f19571958 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg841947):R.ffi.throwNonFunApp(L[137],_plus5,[(", "),anf_arg841947]);
};
try {
if(--R.GAS > 0) {
$z19511952 = $f19571958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19571958,
"from":L[137]});
}
} catch($e19491950) {
if(R.isCont($e19491950)) {
var $ss19531954 = {"from":L[137],
"go":function(anf_arg851959) {
return $Hanf_arg4771960(anf_arg851959,anf_arg821934,_plus5);
}};
$e19491950.stack[R.EXN_STACKHEIGHT++] = $ss19531954;
}
if(R.isPyretException($e19491950)) {
$e19491950.pyretStack.push(L[137]);
}
throw $e19491950;
}
var $ret19551956 = $Hanf_arg4771960($z19511952,anf_arg821934,_plus5);
++R.GAS;
return $ret19551956;
};
var $Hanf_arg4771960 = function(anf_arg851959,anf_arg821934,_plus5) {
var $z19631964 = D;
var $f19691970 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg821934,anf_arg851959):R.ffi.throwNonFunApp(L[137],_plus5,[anf_arg821934,anf_arg851959]);
};
try {
if(--R.GAS > 0) {
$z19631964 = $f19691970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19691970,
"from":L[137]});
}
} catch($e19611962) {
if(R.isCont($e19611962)) {
var $ss19651966 = {"from":L[137],
"go":function(anf_arg861971) {
return $Hanf_arg4761972(anf_arg861971,_plus5);
}};
$e19611962.stack[R.EXN_STACKHEIGHT++] = $ss19651966;
}
if(R.isPyretException($e19611962)) {
$e19611962.pyretStack.push(L[137]);
}
throw $e19611962;
}
var $ret19671968 = $Hanf_arg4761972($z19631964,_plus5);
++R.GAS;
return $ret19671968;
};
var $Hanf_arg4761972 = function(anf_arg861971,_plus5) {
var $z19751976 = D;
var $f19811982 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg861971,(")")):R.ffi.throwNonFunApp(L[137],_plus5,[anf_arg861971,(")")]);
};
try {
if(--R.GAS > 0) {
$z19751976 = $f19811982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19811982,
"from":L[137]});
}
} catch($e19731974) {
if(R.isCont($e19731974)) {
var $ss19771978 = {"from":L[137],
"go":function(anf_arg871983) {
return $Hanf_arg4751984(anf_arg871983,_plus5);
}};
$e19731974.stack[R.EXN_STACKHEIGHT++] = $ss19771978;
}
if(R.isPyretException($e19731974)) {
$e19731974.pyretStack.push(L[137]);
}
throw $e19731974;
}
var $ret19791980 = $Hanf_arg4751984($z19751976,_plus5);
++R.GAS;
return $ret19791980;
};
var $Hanf_arg4751984 = function(anf_arg871983,_plus5) {
var $z19871988 = D;
var $f19931994 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg871983):R.ffi.throwNonFunApp(L[137],_plus5,[("("),anf_arg871983]);
};
try {
if(--R.GAS > 0) {
$z19871988 = $f19931994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19931994,
"from":L[137]});
}
} catch($e19851986) {
if(R.isCont($e19851986)) {
var $ss19891990 = {"from":L[137],
"go":function(anf_arg881995) {
return $Hanf_arg4741996(anf_arg881995,_plus5);
}};
$e19851986.stack[R.EXN_STACKHEIGHT++] = $ss19891990;
}
if(R.isPyretException($e19851986)) {
$e19851986.pyretStack.push(L[137]);
}
throw $e19851986;
}
var $ret19911992 = $Hanf_arg4741996($z19871988,_plus5);
++R.GAS;
return $ret19911992;
};
var $Hanf_arg4741996 = function(anf_arg881995,_plus5) {
var $z19992000 = D;
var $f20052006 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("failure-not-equal"),anf_arg881995):R.ffi.throwNonFunApp(L[137],_plus5,[("failure-not-equal"),anf_arg881995]);
};
try {
if(--R.GAS > 0) {
$z19992000 = $f20052006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20052006,
"from":L[137]});
}
} catch($e19971998) {
if(R.isCont($e19971998)) {
var $ss20012002 = {"from":L[137],
"go":function(ann_DASH_check_DASH_temp722007) {
return $Hann_DASH_check_DASH_temp4732008(ann_DASH_check_DASH_temp722007);
}};
$e19971998.stack[R.EXN_STACKHEIGHT++] = $ss20012002;
}
if(R.isPyretException($e19971998)) {
$e19971998.pyretStack.push(L[137]);
}
throw $e19971998;
}
var $ret20032004 = $Hann_DASH_check_DASH_temp4732008($z19992000);
++R.GAS;
return $ret20032004;
};
var $Hann_DASH_check_DASH_temp4732008 = function(ann_DASH_check_DASH_temp722007) {
return ann_DASH_check_DASH_temp722007;
};
var $Hcont_tail_arg4712009 = function(cont_tail_arg692010,if_helper582011) {
if(--R.GAS > 0) {
$z20122013 = R.isFunction(if_helper582011)?if_helper582011.app(cont_tail_arg692010):R.ffi.throwNonFunApp(L[137],if_helper582011,[cont_tail_arg692010]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper582011)?if_helper582011.app(cont_tail_arg692010):R.ffi.throwNonFunApp(L[137],if_helper582011,[cont_tail_arg692010]);
},
"from":L[137]});
}
++R.GAS;
return $z20122013;
};
var $Hcont_tail_arg4722014 = function(cont_tail_arg632015,if_helper582011) {
if(--R.GAS > 0) {
$z20162017 = R.isFunction(if_helper582011)?if_helper582011.app(cont_tail_arg632015):R.ffi.throwNonFunApp(L[137],if_helper582011,[cont_tail_arg632015]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper582011)?if_helper582011.app(cont_tail_arg632015):R.ffi.throwNonFunApp(L[137],if_helper582011,[cont_tail_arg632015]);
},
"from":L[137]});
}
++R.GAS;
return $z20162017;
};
var $Hanf_arg4702018 = function(anf_arg492019,self112020,_plus5,torepr10) {
var anf_arg502031 = G(self112020,"code",L[138]);
var $z20232024 = D;
var $f20292030 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg502031):R.ffi.throwNonFunApp(L[138],torepr10,[anf_arg502031]);
};
try {
if(--R.GAS > 0) {
$z20232024 = $f20292030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20292030,
"from":L[138]});
}
} catch($e20212022) {
if(R.isCont($e20212022)) {
var $ss20252026 = {"from":L[138],
"go":function(anf_arg512032) {
return $Hanf_arg4692033(anf_arg512032,anf_arg492019,_plus5);
}};
$e20212022.stack[R.EXN_STACKHEIGHT++] = $ss20252026;
}
if(R.isPyretException($e20212022)) {
$e20212022.pyretStack.push(L[138]);
}
throw $e20212022;
}
var $ret20272028 = $Hanf_arg4692033($z20232024,anf_arg492019,_plus5);
++R.GAS;
return $ret20272028;
};
var $Hanf_arg4692033 = function(anf_arg512032,anf_arg492019,_plus5) {
var $z20362037 = D;
var $f20422043 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg512032):R.ffi.throwNonFunApp(L[138],_plus5,[(", "),anf_arg512032]);
};
try {
if(--R.GAS > 0) {
$z20362037 = $f20422043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20422043,
"from":L[138]});
}
} catch($e20342035) {
if(R.isCont($e20342035)) {
var $ss20382039 = {"from":L[138],
"go":function(anf_arg522044) {
return $Hanf_arg4682045(anf_arg522044,anf_arg492019,_plus5);
}};
$e20342035.stack[R.EXN_STACKHEIGHT++] = $ss20382039;
}
if(R.isPyretException($e20342035)) {
$e20342035.pyretStack.push(L[138]);
}
throw $e20342035;
}
var $ret20402041 = $Hanf_arg4682045($z20362037,anf_arg492019,_plus5);
++R.GAS;
return $ret20402041;
};
var $Hanf_arg4682045 = function(anf_arg522044,anf_arg492019,_plus5) {
var $z20482049 = D;
var $f20542055 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg492019,anf_arg522044):R.ffi.throwNonFunApp(L[138],_plus5,[anf_arg492019,anf_arg522044]);
};
try {
if(--R.GAS > 0) {
$z20482049 = $f20542055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20542055,
"from":L[138]});
}
} catch($e20462047) {
if(R.isCont($e20462047)) {
var $ss20502051 = {"from":L[138],
"go":function(anf_arg532056) {
return $Hanf_arg4672057(anf_arg532056,_plus5);
}};
$e20462047.stack[R.EXN_STACKHEIGHT++] = $ss20502051;
}
if(R.isPyretException($e20462047)) {
$e20462047.pyretStack.push(L[138]);
}
throw $e20462047;
}
var $ret20522053 = $Hanf_arg4672057($z20482049,_plus5);
++R.GAS;
return $ret20522053;
};
var $Hanf_arg4672057 = function(anf_arg532056,_plus5) {
var $z20602061 = D;
var $f20662067 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg532056,(")")):R.ffi.throwNonFunApp(L[138],_plus5,[anf_arg532056,(")")]);
};
try {
if(--R.GAS > 0) {
$z20602061 = $f20662067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20662067,
"from":L[138]});
}
} catch($e20582059) {
if(R.isCont($e20582059)) {
var $ss20622063 = {"from":L[138],
"go":function(anf_arg542068) {
return $Hanf_arg4662069(anf_arg542068,_plus5);
}};
$e20582059.stack[R.EXN_STACKHEIGHT++] = $ss20622063;
}
if(R.isPyretException($e20582059)) {
$e20582059.pyretStack.push(L[138]);
}
throw $e20582059;
}
var $ret20642065 = $Hanf_arg4662069($z20602061,_plus5);
++R.GAS;
return $ret20642065;
};
var $Hanf_arg4662069 = function(anf_arg542068,_plus5) {
var $z20722073 = D;
var $f20782079 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg542068):R.ffi.throwNonFunApp(L[138],_plus5,[("("),anf_arg542068]);
};
try {
if(--R.GAS > 0) {
$z20722073 = $f20782079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20782079,
"from":L[138]});
}
} catch($e20702071) {
if(R.isCont($e20702071)) {
var $ss20742075 = {"from":L[138],
"go":function(anf_arg552080) {
return $Hanf_arg4652081(anf_arg552080,_plus5);
}};
$e20702071.stack[R.EXN_STACKHEIGHT++] = $ss20742075;
}
if(R.isPyretException($e20702071)) {
$e20702071.pyretStack.push(L[138]);
}
throw $e20702071;
}
var $ret20762077 = $Hanf_arg4652081($z20722073,_plus5);
++R.GAS;
return $ret20762077;
};
var $Hanf_arg4652081 = function(anf_arg552080,_plus5) {
var $z20842085 = D;
var $f20902091 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("success"),anf_arg552080):R.ffi.throwNonFunApp(L[138],_plus5,[("success"),anf_arg552080]);
};
try {
if(--R.GAS > 0) {
$z20842085 = $f20902091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20902091,
"from":L[138]});
}
} catch($e20822083) {
if(R.isCont($e20822083)) {
var $ss20862087 = {"from":L[138],
"go":function(ann_DASH_check_DASH_temp472092) {
return $Hann_DASH_check_DASH_temp4642093(ann_DASH_check_DASH_temp472092);
}};
$e20822083.stack[R.EXN_STACKHEIGHT++] = $ss20862087;
}
if(R.isPyretException($e20822083)) {
$e20822083.pyretStack.push(L[138]);
}
throw $e20822083;
}
var $ret20882089 = $Hann_DASH_check_DASH_temp4642093($z20842085);
++R.GAS;
return $ret20882089;
};
var $Hann_DASH_check_DASH_temp4642093 = function(ann_DASH_check_DASH_temp472092) {
return ann_DASH_check_DASH_temp472092;
};
var $Hcont_tail_arg4622094 = function(cont_tail_arg442095,if_helper352096) {
if(--R.GAS > 0) {
$z20972098 = R.isFunction(if_helper352096)?if_helper352096.app(cont_tail_arg442095):R.ffi.throwNonFunApp(L[138],if_helper352096,[cont_tail_arg442095]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper352096)?if_helper352096.app(cont_tail_arg442095):R.ffi.throwNonFunApp(L[138],if_helper352096,[cont_tail_arg442095]);
},
"from":L[138]});
}
++R.GAS;
return $z20972098;
};
var $Hcont_tail_arg4632099 = function(cont_tail_arg402100,if_helper352096) {
if(--R.GAS > 0) {
$z21012102 = R.isFunction(if_helper352096)?if_helper352096.app(cont_tail_arg402100):R.ffi.throwNonFunApp(L[138],if_helper352096,[cont_tail_arg402100]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper352096)?if_helper352096.app(cont_tail_arg402100):R.ffi.throwNonFunApp(L[138],if_helper352096,[cont_tail_arg402100]);
},
"from":L[138]});
}
++R.GAS;
return $z21012102;
};
var $Hanf_arg4612103 = function(anf_arg172104,self52105,_plus5,torepr10) {
var anf_arg182116 = G(self52105,"loc",L[139]);
var $z21082109 = D;
var $f21142115 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg182116):R.ffi.throwNonFunApp(L[139],torepr10,[anf_arg182116]);
};
try {
if(--R.GAS > 0) {
$z21082109 = $f21142115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21142115,
"from":L[139]});
}
} catch($e21062107) {
if(R.isCont($e21062107)) {
var $ss21102111 = {"from":L[139],
"go":function(anf_arg192117) {
return $Hanf_arg4602118(anf_arg192117,anf_arg172104,self52105,_plus5,torepr10);
}};
$e21062107.stack[R.EXN_STACKHEIGHT++] = $ss21102111;
}
if(R.isPyretException($e21062107)) {
$e21062107.pyretStack.push(L[139]);
}
throw $e21062107;
}
var $ret21122113 = $Hanf_arg4602118($z21082109,anf_arg172104,self52105,_plus5,torepr10);
++R.GAS;
return $ret21122113;
};
var $Hanf_arg4602118 = function(anf_arg192117,anf_arg172104,self52105,_plus5,torepr10) {
var $z21212122 = D;
var $f21272128 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg192117):R.ffi.throwNonFunApp(L[139],_plus5,[(", "),anf_arg192117]);
};
try {
if(--R.GAS > 0) {
$z21212122 = $f21272128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21272128,
"from":L[139]});
}
} catch($e21192120) {
if(R.isCont($e21192120)) {
var $ss21232124 = {"from":L[139],
"go":function(anf_arg202129) {
return $Hanf_arg4592130(anf_arg202129,anf_arg172104,self52105,_plus5,torepr10);
}};
$e21192120.stack[R.EXN_STACKHEIGHT++] = $ss21232124;
}
if(R.isPyretException($e21192120)) {
$e21192120.pyretStack.push(L[139]);
}
throw $e21192120;
}
var $ret21252126 = $Hanf_arg4592130($z21212122,anf_arg172104,self52105,_plus5,torepr10);
++R.GAS;
return $ret21252126;
};
var $Hanf_arg4592130 = function(anf_arg202129,anf_arg172104,self52105,_plus5,torepr10) {
var $z21332134 = D;
var $f21392140 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg172104,anf_arg202129):R.ffi.throwNonFunApp(L[139],_plus5,[anf_arg172104,anf_arg202129]);
};
try {
if(--R.GAS > 0) {
$z21332134 = $f21392140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21392140,
"from":L[139]});
}
} catch($e21312132) {
if(R.isCont($e21312132)) {
var $ss21352136 = {"from":L[139],
"go":function(anf_arg212141) {
return $Hanf_arg4582142(anf_arg212141,self52105,_plus5,torepr10);
}};
$e21312132.stack[R.EXN_STACKHEIGHT++] = $ss21352136;
}
if(R.isPyretException($e21312132)) {
$e21312132.pyretStack.push(L[139]);
}
throw $e21312132;
}
var $ret21372138 = $Hanf_arg4582142($z21332134,self52105,_plus5,torepr10);
++R.GAS;
return $ret21372138;
};
var $Hanf_arg4582142 = function(anf_arg212141,self52105,_plus5,torepr10) {
var anf_arg222153 = G(self52105,"test-results",L[139]);
var $z21452146 = D;
var $f21512152 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg222153):R.ffi.throwNonFunApp(L[139],torepr10,[anf_arg222153]);
};
try {
if(--R.GAS > 0) {
$z21452146 = $f21512152();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21512152,
"from":L[139]});
}
} catch($e21432144) {
if(R.isCont($e21432144)) {
var $ss21472148 = {"from":L[139],
"go":function(anf_arg232154) {
return $Hanf_arg4572155(anf_arg232154,anf_arg212141,_plus5);
}};
$e21432144.stack[R.EXN_STACKHEIGHT++] = $ss21472148;
}
if(R.isPyretException($e21432144)) {
$e21432144.pyretStack.push(L[139]);
}
throw $e21432144;
}
var $ret21492150 = $Hanf_arg4572155($z21452146,anf_arg212141,_plus5);
++R.GAS;
return $ret21492150;
};
var $Hanf_arg4572155 = function(anf_arg232154,anf_arg212141,_plus5) {
var $z21582159 = D;
var $f21642165 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg232154):R.ffi.throwNonFunApp(L[139],_plus5,[(", "),anf_arg232154]);
};
try {
if(--R.GAS > 0) {
$z21582159 = $f21642165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21642165,
"from":L[139]});
}
} catch($e21562157) {
if(R.isCont($e21562157)) {
var $ss21602161 = {"from":L[139],
"go":function(anf_arg242166) {
return $Hanf_arg4562167(anf_arg242166,anf_arg212141,_plus5);
}};
$e21562157.stack[R.EXN_STACKHEIGHT++] = $ss21602161;
}
if(R.isPyretException($e21562157)) {
$e21562157.pyretStack.push(L[139]);
}
throw $e21562157;
}
var $ret21622163 = $Hanf_arg4562167($z21582159,anf_arg212141,_plus5);
++R.GAS;
return $ret21622163;
};
var $Hanf_arg4562167 = function(anf_arg242166,anf_arg212141,_plus5) {
var $z21702171 = D;
var $f21762177 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg212141,anf_arg242166):R.ffi.throwNonFunApp(L[139],_plus5,[anf_arg212141,anf_arg242166]);
};
try {
if(--R.GAS > 0) {
$z21702171 = $f21762177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21762177,
"from":L[139]});
}
} catch($e21682169) {
if(R.isCont($e21682169)) {
var $ss21722173 = {"from":L[139],
"go":function(anf_arg252178) {
return $Hanf_arg4552179(anf_arg252178,_plus5);
}};
$e21682169.stack[R.EXN_STACKHEIGHT++] = $ss21722173;
}
if(R.isPyretException($e21682169)) {
$e21682169.pyretStack.push(L[139]);
}
throw $e21682169;
}
var $ret21742175 = $Hanf_arg4552179($z21702171,_plus5);
++R.GAS;
return $ret21742175;
};
var $Hanf_arg4552179 = function(anf_arg252178,_plus5) {
var $z21822183 = D;
var $f21882189 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg252178,(")")):R.ffi.throwNonFunApp(L[139],_plus5,[anf_arg252178,(")")]);
};
try {
if(--R.GAS > 0) {
$z21822183 = $f21882189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21882189,
"from":L[139]});
}
} catch($e21802181) {
if(R.isCont($e21802181)) {
var $ss21842185 = {"from":L[139],
"go":function(anf_arg262190) {
return $Hanf_arg4542191(anf_arg262190,_plus5);
}};
$e21802181.stack[R.EXN_STACKHEIGHT++] = $ss21842185;
}
if(R.isPyretException($e21802181)) {
$e21802181.pyretStack.push(L[139]);
}
throw $e21802181;
}
var $ret21862187 = $Hanf_arg4542191($z21822183,_plus5);
++R.GAS;
return $ret21862187;
};
var $Hanf_arg4542191 = function(anf_arg262190,_plus5) {
var $z21942195 = D;
var $f22002201 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg262190):R.ffi.throwNonFunApp(L[139],_plus5,[("("),anf_arg262190]);
};
try {
if(--R.GAS > 0) {
$z21942195 = $f22002201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22002201,
"from":L[139]});
}
} catch($e21922193) {
if(R.isCont($e21922193)) {
var $ss21962197 = {"from":L[139],
"go":function(anf_arg272202) {
return $Hanf_arg4532203(anf_arg272202,_plus5);
}};
$e21922193.stack[R.EXN_STACKHEIGHT++] = $ss21962197;
}
if(R.isPyretException($e21922193)) {
$e21922193.pyretStack.push(L[139]);
}
throw $e21922193;
}
var $ret21982199 = $Hanf_arg4532203($z21942195,_plus5);
++R.GAS;
return $ret21982199;
};
var $Hanf_arg4532203 = function(anf_arg272202,_plus5) {
var $z22062207 = D;
var $f22122213 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("check-block-result"),anf_arg272202):R.ffi.throwNonFunApp(L[139],_plus5,[("check-block-result"),anf_arg272202]);
};
try {
if(--R.GAS > 0) {
$z22062207 = $f22122213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22122213,
"from":L[139]});
}
} catch($e22042205) {
if(R.isCont($e22042205)) {
var $ss22082209 = {"from":L[139],
"go":function(ann_DASH_check_DASH_temp152214) {
return $Hann_DASH_check_DASH_temp4522215(ann_DASH_check_DASH_temp152214);
}};
$e22042205.stack[R.EXN_STACKHEIGHT++] = $ss22082209;
}
if(R.isPyretException($e22042205)) {
$e22042205.pyretStack.push(L[139]);
}
throw $e22042205;
}
var $ret22102211 = $Hann_DASH_check_DASH_temp4522215($z22062207);
++R.GAS;
return $ret22102211;
};
var $Hann_DASH_check_DASH_temp4522215 = function(ann_DASH_check_DASH_temp152214) {
return ann_DASH_check_DASH_temp152214;
};
var $Hcont_tail_arg4502216 = function(cont_tail_arg122217,if_helper22218) {
if(--R.GAS > 0) {
$z22192220 = R.isFunction(if_helper22218)?if_helper22218.app(cont_tail_arg122217):R.ffi.throwNonFunApp(L[139],if_helper22218,[cont_tail_arg122217]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper22218)?if_helper22218.app(cont_tail_arg122217):R.ffi.throwNonFunApp(L[139],if_helper22218,[cont_tail_arg122217]);
},
"from":L[139]});
}
++R.GAS;
return $z22192220;
};
var $Hcont_tail_arg4512221 = function(cont_tail_arg72222,if_helper22218) {
if(--R.GAS > 0) {
$z22232224 = R.isFunction(if_helper22218)?if_helper22218.app(cont_tail_arg72222):R.ffi.throwNonFunApp(L[139],if_helper22218,[cont_tail_arg72222]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper22218)?if_helper22218.app(cont_tail_arg72222):R.ffi.throwNonFunApp(L[139],if_helper22218,[cont_tail_arg72222]);
},
"from":L[139]});
}
++R.GAS;
return $z22232224;
};
return R.loadModulesNew(NAMESPACE,[$SL11427,$arrays31528,$lists51629,$option71730,$error91831,$sets111932],function($SL11427,$arrays31528,$lists51629,$option71730,$error91831,$sets111932) {
var SL114 = R.getField($SL11427,"values");
var arrays315 = R.getField($arrays31528,"values");
var lists516 = R.getField($lists51629,"values");
var option717 = R.getField($option71730,"values");
var error918 = R.getField($error91831,"values");
var sets1119 = R.getField($sets111932,"values");
var SL220 = R.getField($SL11427,"types");
var arrays421 = R.getField($arrays31528,"types");
var lists622 = R.getField($lists51629,"types");
var option823 = R.getField($option71730,"types");
var error1024 = R.getField($error91831,"types");
var sets1225 = R.getField($sets111932,"types");
return R.safeCall(function() {
var List132225 = R.getDotAnn(L[140],"lists",lists622,"List");
var Option142226 = R.getDotAnn(L[140],"option",option823,"Option");
var Array152227 = R.getDotAnn(L[140],"arrays",arrays421,"Array");
var Set162228 = R.getDotAnn(L[140],"sets",sets1225,"Set");
var array172785 = G(arrays315,"array",L[140]);
var build_DASH_array182784 = G(arrays315,"build-array",L[140]);
var array_DASH_from_DASH_list192783 = G(arrays315,"array-from-list",L[140]);
var is_DASH_array202782 = G(arrays315,"is-array",L[140]);
var list21700 = G(lists516,"list",L[140]);
var is_DASH_empty222781 = G(lists516,"is-empty",L[140]);
var is_DASH_link232780 = G(lists516,"is-link",L[140]);
var empty242779 = G(lists516,"empty",L[140]);
var link252778 = G(lists516,"link",L[140]);
var range262777 = G(lists516,"range",L[140]);
var repeat272776 = G(lists516,"repeat",L[140]);
var filter282775 = G(lists516,"filter",L[140]);
var partition292774 = G(lists516,"partition",L[140]);
var split_DASH_at302773 = G(lists516,"split-at",L[140]);
var any312772 = G(lists516,"any",L[140]);
var find322771 = G(lists516,"find",L[140]);
var map332770 = G(lists516,"map",L[140]);
var map2342769 = G(lists516,"map2",L[140]);
var map3352768 = G(lists516,"map3",L[140]);
var map4362767 = G(lists516,"map4",L[140]);
var map_n372766 = G(lists516,"map_n",L[140]);
var map2_n382765 = G(lists516,"map2_n",L[140]);
var map3_n392764 = G(lists516,"map3_n",L[140]);
var map4_n402763 = G(lists516,"map4_n",L[140]);
var each41695 = G(lists516,"each",L[140]);
var each2422762 = G(lists516,"each2",L[140]);
var each3432761 = G(lists516,"each3",L[140]);
var each4442760 = G(lists516,"each4",L[140]);
var each_n452759 = G(lists516,"each_n",L[140]);
var each2_n462758 = G(lists516,"each2_n",L[140]);
var each3_n472757 = G(lists516,"each3_n",L[140]);
var each4_n482756 = G(lists516,"each4_n",L[140]);
var fold4958 = G(lists516,"fold",L[140]);
var fold2502755 = G(lists516,"fold2",L[140]);
var fold3512754 = G(lists516,"fold3",L[140]);
var fold4522753 = G(lists516,"fold4",L[140]);
var index532752 = G(lists516,"index",L[140]);
var Option542751 = G(option717,"Option",L[140]);
var is_DASH_none552750 = G(option717,"is-none",L[140]);
var is_DASH_some562749 = G(option717,"is-some",L[140]);
var none572748 = G(option717,"none",L[140]);
var some582747 = G(option717,"some",L[140]);
var set592746 = G(sets1119,"set",L[140]);
var tree_DASH_set602745 = G(sets1119,"tree-set",L[140]);
var list_DASH_set612744 = G(sets1119,"list-set",L[140]);
var CheckBlockResultT1632229 = R.namedBrander("CheckBlockResult");
var CheckBlockResult6235 = R.makeBranderAnn(CheckBlockResultT1632229,"CheckBlockResult");
var TestResultT2652230 = R.namedBrander("TestResult");
var TestResult6437 = R.makeBranderAnn(TestResultT2652230,"TestResult");
var Loc6636 = R.getDotAnn(L[141],"SL",SL220,"Srcloc");
var CheckBlockResult3672231 = {"$var":D,
"$name":"CheckBlockResult3"};
var CheckBlockResult682233 = {"$var":D,
"$name":"CheckBlockResult"};
var is_DASH_CheckBlockResult692235 = {"$var":D,
"$name":"is-CheckBlockResult"};
var is_DASH_check_DASH_block_DASH_result702237 = {"$var":D,
"$name":"is-check-block-result"};
var check_DASH_block_DASH_result71694 = {"$var":D,
"$name":"check-block-result"};
var TestResult4722240 = {"$var":D,
"$name":"TestResult4"};
var TestResult732242 = {"$var":D,
"$name":"TestResult"};
var is_DASH_TestResult742244 = {"$var":D,
"$name":"is-TestResult"};
var is_DASH_success752246 = {"$var":D,
"$name":"is-success"};
var success76704 = {"$var":D,
"$name":"success"};
var is_DASH_failure_DASH_not_DASH_equal772249 = {"$var":D,
"$name":"is-failure-not-equal"};
var failure_DASH_not_DASH_equal78697 = {"$var":D,
"$name":"failure-not-equal"};
var is_DASH_failure_DASH_not_DASH_satisfied792252 = {"$var":D,
"$name":"is-failure-not-satisfied"};
var failure_DASH_not_DASH_satisfied80698 = {"$var":D,
"$name":"failure-not-satisfied"};
var is_DASH_failure_DASH_wrong_DASH_exn812255 = {"$var":D,
"$name":"is-failure-wrong-exn"};
var failure_DASH_wrong_DASH_exn82699 = {"$var":D,
"$name":"failure-wrong-exn"};
var is_DASH_failure_DASH_no_DASH_exn832258 = {"$var":D,
"$name":"is-failure-no-exn"};
var failure_DASH_no_DASH_exn84696 = {"$var":D,
"$name":"failure-no-exn"};
var make_DASH_check_DASH_context852261 = {"$var":D,
"$name":"make-check-context"};
var results_DASH_summary86703 = {"$var":D,
"$name":"results-summary"};
var render_DASH_check_DASH_results87702 = {"$var":D,
"$name":"render-check-results"};
var anf_variant_member142694 = R.makeMethod(function(self22724) {
return function(cases_DASH_funs32725,else_DASH_clause42736) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[139],2,arguments);
}
var if_DASH_62737 = R.hasField(cases_DASH_funs32725,("check-block-result"));
var if_helper22218 = R.makeFunction(function(if_helper_arg32742) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[139],1,arguments);
}
var ann_DASH_check_DASH_temp12743 = if_helper_arg32742;
return ann_DASH_check_DASH_temp12743;
});
var anf_if62741 = R.isBoolean(if_DASH_62737);
if(R.isPyretTrue(anf_if62741)) {
if(R.isPyretTrue(if_DASH_62737)) {
var call_DASH_check_DASH_block_DASH_result12720 = G(cases_DASH_funs32725,"check-block-result",L[139]);
var anf_arg92721 = G(self22724,"name",L[210]);
var anf_arg102722 = G(self22724,"loc",L[209]);
var anf_arg112723 = G(self22724,"test-results",L[208]);
var $z27122713 = D;
var $f27182719 = function(_) {
return R.isFunction(call_DASH_check_DASH_block_DASH_result12720)?call_DASH_check_DASH_block_DASH_result12720.app(anf_arg92721,anf_arg102722,anf_arg112723):R.ffi.throwNonFunApp(L[139],call_DASH_check_DASH_block_DASH_result12720,[anf_arg92721,anf_arg102722,anf_arg112723]);
};
try {
if(--R.GAS > 0) {
$z27122713 = $f27182719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27182719,
"from":L[139]});
}
} catch($e27102711) {
if(R.isCont($e27102711)) {
var $ss27142715 = {"from":L[139],
"go":function(cont_tail_arg122217) {
return $Hcont_tail_arg4502216(cont_tail_arg122217,if_helper22218);
}};
$e27102711.stack[R.EXN_STACKHEIGHT++] = $ss27142715;
}
if(R.isPyretException($e27102711)) {
$e27102711.pyretStack.push(L[139]);
}
throw $e27102711;
}
var $ret27162717 = $Hcont_tail_arg4502216($z27122713,if_helper22218);
++R.GAS;
return $ret27162717;
} else {
var $z27282729 = D;
var $f27342735 = function(_) {
return R.isFunction(else_DASH_clause42736)?else_DASH_clause42736.app():R.ffi.throwNonFunApp(L[139],else_DASH_clause42736,[]);
};
try {
if(--R.GAS > 0) {
$z27282729 = $f27342735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27342735,
"from":L[139]});
}
} catch($e27262727) {
if(R.isCont($e27262727)) {
var $ss27302731 = {"from":L[139],
"go":function(cont_tail_arg72222) {
return $Hcont_tail_arg4512221(cont_tail_arg72222,if_helper22218);
}};
$e27262727.stack[R.EXN_STACKHEIGHT++] = $ss27302731;
}
if(R.isPyretException($e27262727)) {
$e27262727.pyretStack.push(L[139]);
}
throw $e27262727;
}
var $ret27322733 = $Hcont_tail_arg4512221($z27282729,if_helper22218);
++R.GAS;
return $ret27322733;
}
} else {
var cont_tail_arg42740 = R.throwNonBooleanCondition(L[139],("if"),if_DASH_62737);
if(--R.GAS > 0) {
$z27382739 = R.isFunction(if_helper22218)?if_helper22218.app(cont_tail_arg42740):R.ffi.throwNonFunApp(L[139],if_helper22218,[cont_tail_arg42740]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper22218)?if_helper22218.app(cont_tail_arg42740):R.ffi.throwNonFunApp(L[139],if_helper22218,[cont_tail_arg42740]);
},
"from":L[139]});
}
++R.GAS;
return $z27382739;
}
};
},{"length":3});
var anf_variant_member282695 = R.makeMethod(function(self52105) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[139],0,arguments);
}
var anf_arg162709 = G(self52105,"name",L[139]);
var $z27012702 = D;
var $f27072708 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg162709):R.ffi.throwNonFunApp(L[139],torepr10,[anf_arg162709]);
};
try {
if(--R.GAS > 0) {
$z27012702 = $f27072708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27072708,
"from":L[139]});
}
} catch($e26992700) {
if(R.isCont($e26992700)) {
var $ss27032704 = {"from":L[139],
"go":function(anf_arg172104) {
return $Hanf_arg4612103(anf_arg172104,self52105,_plus5,torepr10);
}};
$e26992700.stack[R.EXN_STACKHEIGHT++] = $ss27032704;
}
if(R.isPyretException($e26992700)) {
$e26992700.pyretStack.push(L[139]);
}
throw $e26992700;
}
var $ret27052706 = $Hanf_arg4612103($z27012702,self52105,_plus5,torepr10);
++R.GAS;
return $ret27052706;
};
},{"length":1});
var anf_assign292232 = (function() {
var $check_DASH_block_DASH_result_DASH_base26892690 = {"_match":anf_variant_member142694,
"_torepr":anf_variant_member282695};
var $check_DASH_block_DASH_result_DASH_brands26922693 = {"$brand-check-block-result2691":true};
$check_DASH_block_DASH_result_DASH_brands26922693[CheckBlockResultT1632229._brand] = true
return R.makeObject({"CheckBlockResult":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CheckBlockResultT1632229._brand));
}),
"is-check-block-result":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[139],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-check-block-result2691"));
}),
"check-block-result":R.makeFunction(function(name882696,loc892697,test_DASH_results902698) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[204],3,arguments);
}
return R.checkAnnArgs([$type$String13,Loc6636,List132225],[name882696,loc892697,test_DASH_results902698],[L[205],L[206],L[207]],function() {
var dict = R.create($check_DASH_block_DASH_result_DASH_base26892690);
dict["name"] = name882696
dict["loc"] = loc892697
dict["test-results"] = test_DASH_results902698
return R.makeBrandedObject(dict,$check_DASH_block_DASH_result_DASH_brands26922693);
});
})});
})();
CheckBlockResult3672231.$var = anf_assign292232;
var anf_assign302234 = G(CheckBlockResult3672231.$var,"CheckBlockResult",L[0]);
CheckBlockResult682233.$var = anf_assign302234;
var anf_assign312236 = G(CheckBlockResult3672231.$var,"CheckBlockResult",L[0]);
is_DASH_CheckBlockResult692235.$var = anf_assign312236;
var anf_assign322238 = G(CheckBlockResult3672231.$var,"is-check-block-result",L[139]);
is_DASH_check_DASH_block_DASH_result702237.$var = anf_assign322238;
var anf_assign332239 = G(CheckBlockResult3672231.$var,"check-block-result",L[139]);
check_DASH_block_DASH_result71694.$var = anf_assign332239;
var anf_variant_member462365 = R.makeMethod(function(self82669) {
return function(cases_DASH_funs92670,else_DASH_clause102681) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[138],2,arguments);
}
var if_DASH_122682 = R.hasField(cases_DASH_funs92670,("success"));
var if_helper352096 = R.makeFunction(function(if_helper_arg362687) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[138],1,arguments);
}
var ann_DASH_check_DASH_temp342688 = if_helper_arg362687;
return ann_DASH_check_DASH_temp342688;
});
var anf_if392686 = R.isBoolean(if_DASH_122682);
if(R.isPyretTrue(anf_if392686)) {
if(R.isPyretTrue(if_DASH_122682)) {
var call_DASH_success72666 = G(cases_DASH_funs92670,"success",L[138]);
var anf_arg422667 = G(self82669,"loc",L[203]);
var anf_arg432668 = G(self82669,"code",L[202]);
var $z26582659 = D;
var $f26642665 = function(_) {
return R.isFunction(call_DASH_success72666)?call_DASH_success72666.app(anf_arg422667,anf_arg432668):R.ffi.throwNonFunApp(L[138],call_DASH_success72666,[anf_arg422667,anf_arg432668]);
};
try {
if(--R.GAS > 0) {
$z26582659 = $f26642665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26642665,
"from":L[138]});
}
} catch($e26562657) {
if(R.isCont($e26562657)) {
var $ss26602661 = {"from":L[138],
"go":function(cont_tail_arg442095) {
return $Hcont_tail_arg4622094(cont_tail_arg442095,if_helper352096);
}};
$e26562657.stack[R.EXN_STACKHEIGHT++] = $ss26602661;
}
if(R.isPyretException($e26562657)) {
$e26562657.pyretStack.push(L[138]);
}
throw $e26562657;
}
var $ret26622663 = $Hcont_tail_arg4622094($z26582659,if_helper352096);
++R.GAS;
return $ret26622663;
} else {
var $z26732674 = D;
var $f26792680 = function(_) {
return R.isFunction(else_DASH_clause102681)?else_DASH_clause102681.app():R.ffi.throwNonFunApp(L[138],else_DASH_clause102681,[]);
};
try {
if(--R.GAS > 0) {
$z26732674 = $f26792680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26792680,
"from":L[138]});
}
} catch($e26712672) {
if(R.isCont($e26712672)) {
var $ss26752676 = {"from":L[138],
"go":function(cont_tail_arg402100) {
return $Hcont_tail_arg4632099(cont_tail_arg402100,if_helper352096);
}};
$e26712672.stack[R.EXN_STACKHEIGHT++] = $ss26752676;
}
if(R.isPyretException($e26712672)) {
$e26712672.pyretStack.push(L[138]);
}
throw $e26712672;
}
var $ret26772678 = $Hcont_tail_arg4632099($z26732674,if_helper352096);
++R.GAS;
return $ret26772678;
}
} else {
var cont_tail_arg372685 = R.throwNonBooleanCondition(L[138],("if"),if_DASH_122682);
if(--R.GAS > 0) {
$z26832684 = R.isFunction(if_helper352096)?if_helper352096.app(cont_tail_arg372685):R.ffi.throwNonFunApp(L[138],if_helper352096,[cont_tail_arg372685]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper352096)?if_helper352096.app(cont_tail_arg372685):R.ffi.throwNonFunApp(L[138],if_helper352096,[cont_tail_arg372685]);
},
"from":L[138]});
}
++R.GAS;
return $z26832684;
}
};
},{"length":3});
var anf_variant_member562366 = R.makeMethod(function(self112020) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[138],0,arguments);
}
var anf_arg482655 = G(self112020,"loc",L[138]);
var $z26472648 = D;
var $f26532654 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg482655):R.ffi.throwNonFunApp(L[138],torepr10,[anf_arg482655]);
};
try {
if(--R.GAS > 0) {
$z26472648 = $f26532654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26532654,
"from":L[138]});
}
} catch($e26452646) {
if(R.isCont($e26452646)) {
var $ss26492650 = {"from":L[138],
"go":function(anf_arg492019) {
return $Hanf_arg4702018(anf_arg492019,self112020,_plus5,torepr10);
}};
$e26452646.stack[R.EXN_STACKHEIGHT++] = $ss26492650;
}
if(R.isPyretException($e26452646)) {
$e26452646.pyretStack.push(L[138]);
}
throw $e26452646;
}
var $ret26512652 = $Hanf_arg4702018($z26472648,self112020,_plus5,torepr10);
++R.GAS;
return $ret26512652;
};
},{"length":1});
var anf_variant_member712374 = R.makeMethod(function(self142625) {
return function(cases_DASH_funs152626,else_DASH_clause162637) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[137],2,arguments);
}
var if_DASH_182638 = R.hasField(cases_DASH_funs152626,("failure-not-equal"));
var if_helper582011 = R.makeFunction(function(if_helper_arg592643) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[137],1,arguments);
}
var ann_DASH_check_DASH_temp572644 = if_helper_arg592643;
return ann_DASH_check_DASH_temp572644;
});
var anf_if622642 = R.isBoolean(if_DASH_182638);
if(R.isPyretTrue(anf_if622642)) {
if(R.isPyretTrue(if_DASH_182638)) {
var call_DASH_failure_DASH_not_DASH_equal132620 = G(cases_DASH_funs152626,"failure-not-equal",L[137]);
var anf_arg652621 = G(self142625,"loc",L[201]);
var anf_arg662622 = G(self142625,"code",L[200]);
var anf_arg672623 = G(self142625,"left",L[199]);
var anf_arg682624 = G(self142625,"right",L[198]);
var $z26122613 = D;
var $f26182619 = function(_) {
return R.isFunction(call_DASH_failure_DASH_not_DASH_equal132620)?call_DASH_failure_DASH_not_DASH_equal132620.app(anf_arg652621,anf_arg662622,anf_arg672623,anf_arg682624):R.ffi.throwNonFunApp(L[137],call_DASH_failure_DASH_not_DASH_equal132620,[anf_arg652621,anf_arg662622,anf_arg672623,anf_arg682624]);
};
try {
if(--R.GAS > 0) {
$z26122613 = $f26182619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26182619,
"from":L[137]});
}
} catch($e26102611) {
if(R.isCont($e26102611)) {
var $ss26142615 = {"from":L[137],
"go":function(cont_tail_arg692010) {
return $Hcont_tail_arg4712009(cont_tail_arg692010,if_helper582011);
}};
$e26102611.stack[R.EXN_STACKHEIGHT++] = $ss26142615;
}
if(R.isPyretException($e26102611)) {
$e26102611.pyretStack.push(L[137]);
}
throw $e26102611;
}
var $ret26162617 = $Hcont_tail_arg4712009($z26122613,if_helper582011);
++R.GAS;
return $ret26162617;
} else {
var $z26292630 = D;
var $f26352636 = function(_) {
return R.isFunction(else_DASH_clause162637)?else_DASH_clause162637.app():R.ffi.throwNonFunApp(L[137],else_DASH_clause162637,[]);
};
try {
if(--R.GAS > 0) {
$z26292630 = $f26352636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26352636,
"from":L[137]});
}
} catch($e26272628) {
if(R.isCont($e26272628)) {
var $ss26312632 = {"from":L[137],
"go":function(cont_tail_arg632015) {
return $Hcont_tail_arg4722014(cont_tail_arg632015,if_helper582011);
}};
$e26272628.stack[R.EXN_STACKHEIGHT++] = $ss26312632;
}
if(R.isPyretException($e26272628)) {
$e26272628.pyretStack.push(L[137]);
}
throw $e26272628;
}
var $ret26332634 = $Hcont_tail_arg4722014($z26292630,if_helper582011);
++R.GAS;
return $ret26332634;
}
} else {
var cont_tail_arg602641 = R.throwNonBooleanCondition(L[137],("if"),if_DASH_182638);
if(--R.GAS > 0) {
$z26392640 = R.isFunction(if_helper582011)?if_helper582011.app(cont_tail_arg602641):R.ffi.throwNonFunApp(L[137],if_helper582011,[cont_tail_arg602641]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper582011)?if_helper582011.app(cont_tail_arg602641):R.ffi.throwNonFunApp(L[137],if_helper582011,[cont_tail_arg602641]);
},
"from":L[137]});
}
++R.GAS;
return $z26392640;
}
};
},{"length":3});
var anf_variant_member892375 = R.makeMethod(function(self171861) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[137],0,arguments);
}
var anf_arg732609 = G(self171861,"loc",L[137]);
var $z26012602 = D;
var $f26072608 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg732609):R.ffi.throwNonFunApp(L[137],torepr10,[anf_arg732609]);
};
try {
if(--R.GAS > 0) {
$z26012602 = $f26072608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26072608,
"from":L[137]});
}
} catch($e25992600) {
if(R.isCont($e25992600)) {
var $ss26032604 = {"from":L[137],
"go":function(anf_arg741860) {
return $Hanf_arg4851859(anf_arg741860,self171861,_plus5,torepr10);
}};
$e25992600.stack[R.EXN_STACKHEIGHT++] = $ss26032604;
}
if(R.isPyretException($e25992600)) {
$e25992600.pyretStack.push(L[137]);
}
throw $e25992600;
}
var $ret26052606 = $Hanf_arg4851859($z26012602,self171861,_plus5,torepr10);
++R.GAS;
return $ret26052606;
};
},{"length":1});
var anf_variant_member972376 = R.makeMethod(function(self971809) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[136],0,arguments);
}
var anf_arg912598 = G(self971809,"left",L[197]);
var $z25902591 = D;
var $f25962597 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg912598):R.ffi.throwNonFunApp(L[196],torepr10,[anf_arg912598]);
};
try {
if(--R.GAS > 0) {
$z25902591 = $f25962597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25962597,
"from":L[196]});
}
} catch($e25882589) {
if(R.isCont($e25882589)) {
var $ss25922593 = {"from":L[196],
"go":function(anf_arg921808) {
return $Hanf_arg4901807(anf_arg921808,self971809,_plus5,torepr10);
}};
$e25882589.stack[R.EXN_STACKHEIGHT++] = $ss25922593;
}
if(R.isPyretException($e25882589)) {
$e25882589.pyretStack.push(L[196]);
}
throw $e25882589;
}
var $ret25942595 = $Hanf_arg4901807($z25902591,self971809,_plus5,torepr10);
++R.GAS;
return $ret25942595;
};
},{"length":1});
var anf_variant_member1122386 = R.makeMethod(function(self202568) {
return function(cases_DASH_funs212569,else_DASH_clause222580) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[132],2,arguments);
}
var if_DASH_242581 = R.hasField(cases_DASH_funs212569,("failure-not-satisfied"));
var if_helper991800 = R.makeFunction(function(if_helper_arg1002586) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[132],1,arguments);
}
var ann_DASH_check_DASH_temp982587 = if_helper_arg1002586;
return ann_DASH_check_DASH_temp982587;
});
var anf_if1032585 = R.isBoolean(if_DASH_242581);
if(R.isPyretTrue(anf_if1032585)) {
if(R.isPyretTrue(if_DASH_242581)) {
var call_DASH_failure_DASH_not_DASH_satisfied192563 = G(cases_DASH_funs212569,"failure-not-satisfied",L[132]);
var anf_arg1062564 = G(self202568,"loc",L[195]);
var anf_arg1072565 = G(self202568,"code",L[194]);
var anf_arg1082566 = G(self202568,"val",L[193]);
var anf_arg1092567 = G(self202568,"pred",L[192]);
var $z25552556 = D;
var $f25612562 = function(_) {
return R.isFunction(call_DASH_failure_DASH_not_DASH_satisfied192563)?call_DASH_failure_DASH_not_DASH_satisfied192563.app(anf_arg1062564,anf_arg1072565,anf_arg1082566,anf_arg1092567):R.ffi.throwNonFunApp(L[132],call_DASH_failure_DASH_not_DASH_satisfied192563,[anf_arg1062564,anf_arg1072565,anf_arg1082566,anf_arg1092567]);
};
try {
if(--R.GAS > 0) {
$z25552556 = $f25612562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25612562,
"from":L[132]});
}
} catch($e25532554) {
if(R.isCont($e25532554)) {
var $ss25572558 = {"from":L[132],
"go":function(cont_tail_arg1101799) {
return $Hcont_tail_arg4911798(cont_tail_arg1101799,if_helper991800);
}};
$e25532554.stack[R.EXN_STACKHEIGHT++] = $ss25572558;
}
if(R.isPyretException($e25532554)) {
$e25532554.pyretStack.push(L[132]);
}
throw $e25532554;
}
var $ret25592560 = $Hcont_tail_arg4911798($z25552556,if_helper991800);
++R.GAS;
return $ret25592560;
} else {
var $z25722573 = D;
var $f25782579 = function(_) {
return R.isFunction(else_DASH_clause222580)?else_DASH_clause222580.app():R.ffi.throwNonFunApp(L[132],else_DASH_clause222580,[]);
};
try {
if(--R.GAS > 0) {
$z25722573 = $f25782579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25782579,
"from":L[132]});
}
} catch($e25702571) {
if(R.isCont($e25702571)) {
var $ss25742575 = {"from":L[132],
"go":function(cont_tail_arg1041804) {
return $Hcont_tail_arg4921803(cont_tail_arg1041804,if_helper991800);
}};
$e25702571.stack[R.EXN_STACKHEIGHT++] = $ss25742575;
}
if(R.isPyretException($e25702571)) {
$e25702571.pyretStack.push(L[132]);
}
throw $e25702571;
}
var $ret25762577 = $Hcont_tail_arg4921803($z25722573,if_helper991800);
++R.GAS;
return $ret25762577;
}
} else {
var cont_tail_arg1012584 = R.throwNonBooleanCondition(L[132],("if"),if_DASH_242581);
if(--R.GAS > 0) {
$z25822583 = R.isFunction(if_helper991800)?if_helper991800.app(cont_tail_arg1012584):R.ffi.throwNonFunApp(L[132],if_helper991800,[cont_tail_arg1012584]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper991800)?if_helper991800.app(cont_tail_arg1012584):R.ffi.throwNonFunApp(L[132],if_helper991800,[cont_tail_arg1012584]);
},
"from":L[132]});
}
++R.GAS;
return $z25822583;
}
};
},{"length":3});
var anf_variant_member1302387 = R.makeMethod(function(self231650) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[132],0,arguments);
}
var anf_arg1142552 = G(self231650,"loc",L[132]);
var $z25442545 = D;
var $f25502551 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1142552):R.ffi.throwNonFunApp(L[132],torepr10,[anf_arg1142552]);
};
try {
if(--R.GAS > 0) {
$z25442545 = $f25502551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25502551,
"from":L[132]});
}
} catch($e25422543) {
if(R.isCont($e25422543)) {
var $ss25462547 = {"from":L[132],
"go":function(anf_arg1151649) {
return $Hanf_arg5051648(anf_arg1151649,self231650,_plus5,torepr10);
}};
$e25422543.stack[R.EXN_STACKHEIGHT++] = $ss25462547;
}
if(R.isPyretException($e25422543)) {
$e25422543.pyretStack.push(L[132]);
}
throw $e25422543;
}
var $ret25482549 = $Hanf_arg5051648($z25442545,self231650,_plus5,torepr10);
++R.GAS;
return $ret25482549;
};
},{"length":1});
var anf_variant_member1342388 = R.makeMethod(function(self1022541) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[131],0,arguments);
}
var anf_arg1322540 = G(self1022541,"val",L[191]);
var $z25322533 = D;
var $f25382539 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1322540):R.ffi.throwNonFunApp(L[190],torepr10,[anf_arg1322540]);
};
try {
if(--R.GAS > 0) {
$z25322533 = $f25382539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25382539,
"from":L[190]});
}
} catch($e25302531) {
if(R.isCont($e25302531)) {
var $ss25342535 = {"from":L[190],
"go":function(anf_arg1331635) {
return $Hanf_arg5071634(anf_arg1331635,_plus5);
}};
$e25302531.stack[R.EXN_STACKHEIGHT++] = $ss25342535;
}
if(R.isPyretException($e25302531)) {
$e25302531.pyretStack.push(L[190]);
}
throw $e25302531;
}
var $ret25362537 = $Hanf_arg5071634($z25322533,_plus5);
++R.GAS;
return $ret25362537;
};
},{"length":1});
var anf_variant_member1492398 = R.makeMethod(function(self262510) {
return function(cases_DASH_funs272511,else_DASH_clause282522) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[130],2,arguments);
}
var if_DASH_302523 = R.hasField(cases_DASH_funs272511,("failure-wrong-exn"));
var if_helper1361627 = R.makeFunction(function(if_helper_arg1372528) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[130],1,arguments);
}
var ann_DASH_check_DASH_temp1352529 = if_helper_arg1372528;
return ann_DASH_check_DASH_temp1352529;
});
var anf_if1402527 = R.isBoolean(if_DASH_302523);
if(R.isPyretTrue(anf_if1402527)) {
if(R.isPyretTrue(if_DASH_302523)) {
var call_DASH_failure_DASH_wrong_DASH_exn252505 = G(cases_DASH_funs272511,"failure-wrong-exn",L[130]);
var anf_arg1432506 = G(self262510,"loc",L[189]);
var anf_arg1442507 = G(self262510,"code",L[188]);
var anf_arg1452508 = G(self262510,"exn-expected",L[187]);
var anf_arg1462509 = G(self262510,"actual-exn",L[186]);
var $z24972498 = D;
var $f25032504 = function(_) {
return R.isFunction(call_DASH_failure_DASH_wrong_DASH_exn252505)?call_DASH_failure_DASH_wrong_DASH_exn252505.app(anf_arg1432506,anf_arg1442507,anf_arg1452508,anf_arg1462509):R.ffi.throwNonFunApp(L[130],call_DASH_failure_DASH_wrong_DASH_exn252505,[anf_arg1432506,anf_arg1442507,anf_arg1452508,anf_arg1462509]);
};
try {
if(--R.GAS > 0) {
$z24972498 = $f25032504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25032504,
"from":L[130]});
}
} catch($e24952496) {
if(R.isCont($e24952496)) {
var $ss24992500 = {"from":L[130],
"go":function(cont_tail_arg1471626) {
return $Hcont_tail_arg5081625(cont_tail_arg1471626,if_helper1361627);
}};
$e24952496.stack[R.EXN_STACKHEIGHT++] = $ss24992500;
}
if(R.isPyretException($e24952496)) {
$e24952496.pyretStack.push(L[130]);
}
throw $e24952496;
}
var $ret25012502 = $Hcont_tail_arg5081625($z24972498,if_helper1361627);
++R.GAS;
return $ret25012502;
} else {
var $z25142515 = D;
var $f25202521 = function(_) {
return R.isFunction(else_DASH_clause282522)?else_DASH_clause282522.app():R.ffi.throwNonFunApp(L[130],else_DASH_clause282522,[]);
};
try {
if(--R.GAS > 0) {
$z25142515 = $f25202521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25202521,
"from":L[130]});
}
} catch($e25122513) {
if(R.isCont($e25122513)) {
var $ss25162517 = {"from":L[130],
"go":function(cont_tail_arg1411631) {
return $Hcont_tail_arg5091630(cont_tail_arg1411631,if_helper1361627);
}};
$e25122513.stack[R.EXN_STACKHEIGHT++] = $ss25162517;
}
if(R.isPyretException($e25122513)) {
$e25122513.pyretStack.push(L[130]);
}
throw $e25122513;
}
var $ret25182519 = $Hcont_tail_arg5091630($z25142515,if_helper1361627);
++R.GAS;
return $ret25182519;
}
} else {
var cont_tail_arg1382526 = R.throwNonBooleanCondition(L[130],("if"),if_DASH_302523);
if(--R.GAS > 0) {
$z25242525 = R.isFunction(if_helper1361627)?if_helper1361627.app(cont_tail_arg1382526):R.ffi.throwNonFunApp(L[130],if_helper1361627,[cont_tail_arg1382526]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper1361627)?if_helper1361627.app(cont_tail_arg1382526):R.ffi.throwNonFunApp(L[130],if_helper1361627,[cont_tail_arg1382526]);
},
"from":L[130]});
}
++R.GAS;
return $z25242525;
}
};
},{"length":3});
var anf_variant_member1672399 = R.makeMethod(function(self291477) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[130],0,arguments);
}
var anf_arg1512494 = G(self291477,"loc",L[130]);
var $z24862487 = D;
var $f24922493 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1512494):R.ffi.throwNonFunApp(L[130],torepr10,[anf_arg1512494]);
};
try {
if(--R.GAS > 0) {
$z24862487 = $f24922493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24922493,
"from":L[130]});
}
} catch($e24842485) {
if(R.isCont($e24842485)) {
var $ss24882489 = {"from":L[130],
"go":function(anf_arg1521476) {
return $Hanf_arg5221475(anf_arg1521476,self291477,_plus5,torepr10);
}};
$e24842485.stack[R.EXN_STACKHEIGHT++] = $ss24882489;
}
if(R.isPyretException($e24842485)) {
$e24842485.pyretStack.push(L[130]);
}
throw $e24842485;
}
var $ret24902491 = $Hanf_arg5221475($z24862487,self291477,_plus5,torepr10);
++R.GAS;
return $ret24902491;
};
},{"length":1});
var anf_variant_member1752400 = R.makeMethod(function(self1071425) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[129],0,arguments);
}
var anf_arg1692483 = G(self1071425,"actual-exn",L[185]);
var $z24752476 = D;
var $f24812482 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1692483):R.ffi.throwNonFunApp(L[184],torepr10,[anf_arg1692483]);
};
try {
if(--R.GAS > 0) {
$z24752476 = $f24812482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24812482,
"from":L[184]});
}
} catch($e24732474) {
if(R.isCont($e24732474)) {
var $ss24772478 = {"from":L[184],
"go":function(anf_arg1701424) {
return $Hanf_arg5271423(anf_arg1701424,self1071425,_plus5,torepr10);
}};
$e24732474.stack[R.EXN_STACKHEIGHT++] = $ss24772478;
}
if(R.isPyretException($e24732474)) {
$e24732474.pyretStack.push(L[184]);
}
throw $e24732474;
}
var $ret24792480 = $Hanf_arg5271423($z24752476,self1071425,_plus5,torepr10);
++R.GAS;
return $ret24792480;
};
},{"length":1});
var anf_variant_member1892410 = R.makeMethod(function(self322453) {
return function(cases_DASH_funs332454,else_DASH_clause342465) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[125],2,arguments);
}
var if_DASH_362466 = R.hasField(cases_DASH_funs332454,("failure-no-exn"));
var if_helper1771416 = R.makeFunction(function(if_helper_arg1782471) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[125],1,arguments);
}
var ann_DASH_check_DASH_temp1762472 = if_helper_arg1782471;
return ann_DASH_check_DASH_temp1762472;
});
var anf_if1812470 = R.isBoolean(if_DASH_362466);
if(R.isPyretTrue(anf_if1812470)) {
if(R.isPyretTrue(if_DASH_362466)) {
var call_DASH_failure_DASH_no_DASH_exn312449 = G(cases_DASH_funs332454,"failure-no-exn",L[125]);
var anf_arg1842450 = G(self322453,"loc",L[183]);
var anf_arg1852451 = G(self322453,"code",L[182]);
var anf_arg1862452 = G(self322453,"exn-expected",L[181]);
var $z24412442 = D;
var $f24472448 = function(_) {
return R.isFunction(call_DASH_failure_DASH_no_DASH_exn312449)?call_DASH_failure_DASH_no_DASH_exn312449.app(anf_arg1842450,anf_arg1852451,anf_arg1862452):R.ffi.throwNonFunApp(L[125],call_DASH_failure_DASH_no_DASH_exn312449,[anf_arg1842450,anf_arg1852451,anf_arg1862452]);
};
try {
if(--R.GAS > 0) {
$z24412442 = $f24472448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24472448,
"from":L[125]});
}
} catch($e24392440) {
if(R.isCont($e24392440)) {
var $ss24432444 = {"from":L[125],
"go":function(cont_tail_arg1871415) {
return $Hcont_tail_arg5281414(cont_tail_arg1871415,if_helper1771416);
}};
$e24392440.stack[R.EXN_STACKHEIGHT++] = $ss24432444;
}
if(R.isPyretException($e24392440)) {
$e24392440.pyretStack.push(L[125]);
}
throw $e24392440;
}
var $ret24452446 = $Hcont_tail_arg5281414($z24412442,if_helper1771416);
++R.GAS;
return $ret24452446;
} else {
var $z24572458 = D;
var $f24632464 = function(_) {
return R.isFunction(else_DASH_clause342465)?else_DASH_clause342465.app():R.ffi.throwNonFunApp(L[125],else_DASH_clause342465,[]);
};
try {
if(--R.GAS > 0) {
$z24572458 = $f24632464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24632464,
"from":L[125]});
}
} catch($e24552456) {
if(R.isCont($e24552456)) {
var $ss24592460 = {"from":L[125],
"go":function(cont_tail_arg1821420) {
return $Hcont_tail_arg5291419(cont_tail_arg1821420,if_helper1771416);
}};
$e24552456.stack[R.EXN_STACKHEIGHT++] = $ss24592460;
}
if(R.isPyretException($e24552456)) {
$e24552456.pyretStack.push(L[125]);
}
throw $e24552456;
}
var $ret24612462 = $Hcont_tail_arg5291419($z24572458,if_helper1771416);
++R.GAS;
return $ret24612462;
}
} else {
var cont_tail_arg1792469 = R.throwNonBooleanCondition(L[125],("if"),if_DASH_362466);
if(--R.GAS > 0) {
$z24672468 = R.isFunction(if_helper1771416)?if_helper1771416.app(cont_tail_arg1792469):R.ffi.throwNonFunApp(L[125],if_helper1771416,[cont_tail_arg1792469]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored76) {
return R.isFunction(if_helper1771416)?if_helper1771416.app(cont_tail_arg1792469):R.ffi.throwNonFunApp(L[125],if_helper1771416,[cont_tail_arg1792469]);
},
"from":L[125]});
}
++R.GAS;
return $z24672468;
}
};
},{"length":3});
var anf_variant_member2032411 = R.makeMethod(function(self351303) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[125],0,arguments);
}
var anf_arg1912438 = G(self351303,"loc",L[125]);
var $z24302431 = D;
var $f24362437 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg1912438):R.ffi.throwNonFunApp(L[125],torepr10,[anf_arg1912438]);
};
try {
if(--R.GAS > 0) {
$z24302431 = $f24362437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24362437,
"from":L[125]});
}
} catch($e24282429) {
if(R.isCont($e24282429)) {
var $ss24322433 = {"from":L[125],
"go":function(anf_arg1921302) {
return $Hanf_arg5391301(anf_arg1921302,self351303,_plus5,torepr10);
}};
$e24282429.stack[R.EXN_STACKHEIGHT++] = $ss24322433;
}
if(R.isPyretException($e24282429)) {
$e24282429.pyretStack.push(L[125]);
}
throw $e24282429;
}
var $ret24342435 = $Hanf_arg5391301($z24302431,self351303,_plus5,torepr10);
++R.GAS;
return $ret24342435;
};
},{"length":1});
var anf_variant_member2072412 = R.makeMethod(function(self1112427) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[124],0,arguments);
}
var anf_arg2052426 = G(self1112427,"exn-expected",L[180]);
var $z24182419 = D;
var $f24242425 = function(_) {
return R.isFunction(torepr10)?torepr10.app(anf_arg2052426):R.ffi.throwNonFunApp(L[179],torepr10,[anf_arg2052426]);
};
try {
if(--R.GAS > 0) {
$z24182419 = $f24242425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24242425,
"from":L[179]});
}
} catch($e24162417) {
if(R.isCont($e24162417)) {
var $ss24202421 = {"from":L[179],
"go":function(anf_arg2061288) {
return $Hanf_arg5411287(anf_arg2061288,_plus5);
}};
$e24162417.stack[R.EXN_STACKHEIGHT++] = $ss24202421;
}
if(R.isPyretException($e24162417)) {
$e24162417.pyretStack.push(L[179]);
}
throw $e24162417;
}
var $ret24222423 = $Hanf_arg5411287($z24182419,_plus5);
++R.GAS;
return $ret24222423;
};
},{"length":1});
var anf_assign2082241 = (function() {
var $success_DASH_base23602361 = {"_match":anf_variant_member462365,
"_torepr":anf_variant_member562366};
var $success_DASH_brands23632364 = {"$brand-success2362":true};
$success_DASH_brands23632364[TestResultT2652230._brand] = true
var $failure_DASH_not_DASH_equal_DASH_base23692370 = {"_match":anf_variant_member712374,
"_torepr":anf_variant_member892375,
"reason":anf_variant_member972376};
var $failure_DASH_not_DASH_equal_DASH_brands23722373 = {"$brand-failure-not-equal2371":true};
$failure_DASH_not_DASH_equal_DASH_brands23722373[TestResultT2652230._brand] = true
var $failure_DASH_not_DASH_satisfied_DASH_base23812382 = {"_match":anf_variant_member1122386,
"_torepr":anf_variant_member1302387,
"reason":anf_variant_member1342388};
var $failure_DASH_not_DASH_satisfied_DASH_brands23842385 = {"$brand-failure-not-satisfied2383":true};
$failure_DASH_not_DASH_satisfied_DASH_brands23842385[TestResultT2652230._brand] = true
var $failure_DASH_wrong_DASH_exn_DASH_base23932394 = {"_match":anf_variant_member1492398,
"_torepr":anf_variant_member1672399,
"reason":anf_variant_member1752400};
var $failure_DASH_wrong_DASH_exn_DASH_brands23962397 = {"$brand-failure-wrong-exn2395":true};
$failure_DASH_wrong_DASH_exn_DASH_brands23962397[TestResultT2652230._brand] = true
var $failure_DASH_no_DASH_exn_DASH_base24052406 = {"_match":anf_variant_member1892410,
"_torepr":anf_variant_member2032411,
"reason":anf_variant_member2072412};
var $failure_DASH_no_DASH_exn_DASH_brands24082409 = {"$brand-failure-no-exn2407":true};
$failure_DASH_no_DASH_exn_DASH_brands24082409[TestResultT2652230._brand] = true
return R.makeObject({"TestResult":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[163],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,TestResultT2652230._brand));
}),
"is-success":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[138],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-success2362"));
}),
"success":R.makeFunction(function(loc912367,code922368) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[164],2,arguments);
}
return R.checkAnnArgs([Loc6636,$type$String13],[loc912367,code922368],[L[165],L[166]],function() {
var dict = R.create($success_DASH_base23602361);
dict["loc"] = loc912367
dict["code"] = code922368
return R.makeBrandedObject(dict,$success_DASH_brands23632364);
});
}),
"is-failure-not-equal":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[137],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-failure-not-equal2371"));
}),
"failure-not-equal":R.makeFunction(function(loc932377,code942378,left952379,right962380) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[167],4,arguments);
}
return R.checkAnnArgs([Loc6636,$type$String13],[loc932377,code942378],[L[168],L[169]],function() {
var dict = R.create($failure_DASH_not_DASH_equal_DASH_base23692370);
dict["loc"] = loc932377
dict["code"] = code942378
dict["left"] = left952379
dict["right"] = right962380
return R.makeBrandedObject(dict,$failure_DASH_not_DASH_equal_DASH_brands23722373);
});
}),
"is-failure-not-satisfied":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[132],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-failure-not-satisfied2383"));
}),
"failure-not-satisfied":R.makeFunction(function(loc982389,code992390,val1002391,pred1012392) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[170],4,arguments);
}
return R.checkAnnArgs([Loc6636,$type$String13],[loc982389,code992390],[L[171],L[172]],function() {
var dict = R.create($failure_DASH_not_DASH_satisfied_DASH_base23812382);
dict["loc"] = loc982389
dict["code"] = code992390
dict["val"] = val1002391
dict["pred"] = pred1012392
return R.makeBrandedObject(dict,$failure_DASH_not_DASH_satisfied_DASH_brands23842385);
});
}),
"is-failure-wrong-exn":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[130],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-failure-wrong-exn2395"));
}),
"failure-wrong-exn":R.makeFunction(function(loc1032401,code1042402,exn_DASH_expected1052403,actual_DASH_exn1062404) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[173],4,arguments);
}
return R.checkAnnArgs([Loc6636,$type$String13],[loc1032401,code1042402],[L[174],L[175]],function() {
var dict = R.create($failure_DASH_wrong_DASH_exn_DASH_base23932394);
dict["loc"] = loc1032401
dict["code"] = code1042402
dict["exn-expected"] = exn_DASH_expected1052403
dict["actual-exn"] = actual_DASH_exn1062404
return R.makeBrandedObject(dict,$failure_DASH_wrong_DASH_exn_DASH_brands23962397);
});
}),
"is-failure-no-exn":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[125],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-failure-no-exn2407"));
}),
"failure-no-exn":R.makeFunction(function(loc1082413,code1092414,exn_DASH_expected1102415) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[176],3,arguments);
}
return R.checkAnnArgs([Loc6636,$type$String13],[loc1082413,code1092414],[L[177],L[178]],function() {
var dict = R.create($failure_DASH_no_DASH_exn_DASH_base24052406);
dict["loc"] = loc1082413
dict["code"] = code1092414
dict["exn-expected"] = exn_DASH_expected1102415
return R.makeBrandedObject(dict,$failure_DASH_no_DASH_exn_DASH_brands24082409);
});
})});
})();
TestResult4722240.$var = anf_assign2082241;
var anf_assign2092243 = G(TestResult4722240.$var,"TestResult",L[163]);
TestResult732242.$var = anf_assign2092243;
var anf_assign2102245 = G(TestResult4722240.$var,"TestResult",L[163]);
is_DASH_TestResult742244.$var = anf_assign2102245;
var anf_assign2112247 = G(TestResult4722240.$var,"is-success",L[138]);
is_DASH_success752246.$var = anf_assign2112247;
var anf_assign2122248 = G(TestResult4722240.$var,"success",L[138]);
success76704.$var = anf_assign2122248;
var anf_assign2132250 = G(TestResult4722240.$var,"is-failure-not-equal",L[137]);
is_DASH_failure_DASH_not_DASH_equal772249.$var = anf_assign2132250;
var anf_assign2142251 = G(TestResult4722240.$var,"failure-not-equal",L[137]);
failure_DASH_not_DASH_equal78697.$var = anf_assign2142251;
var anf_assign2152253 = G(TestResult4722240.$var,"is-failure-not-satisfied",L[132]);
is_DASH_failure_DASH_not_DASH_satisfied792252.$var = anf_assign2152253;
var anf_assign2162254 = G(TestResult4722240.$var,"failure-not-satisfied",L[132]);
failure_DASH_not_DASH_satisfied80698.$var = anf_assign2162254;
var anf_assign2172256 = G(TestResult4722240.$var,"is-failure-wrong-exn",L[130]);
is_DASH_failure_DASH_wrong_DASH_exn812255.$var = anf_assign2172256;
var anf_assign2182257 = G(TestResult4722240.$var,"failure-wrong-exn",L[130]);
failure_DASH_wrong_DASH_exn82699.$var = anf_assign2182257;
var anf_assign2192259 = G(TestResult4722240.$var,"is-failure-no-exn",L[125]);
is_DASH_failure_DASH_no_DASH_exn832258.$var = anf_assign2192259;
var anf_assign2202260 = G(TestResult4722240.$var,"failure-no-exn",L[125]);
failure_DASH_no_DASH_exn84696.$var = anf_assign2202260;
var anf_assign3232262 = R.makeFunction(function(main_DASH_module_DASH_name112701,check_DASH_all113693) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[158],2,arguments);
}
return R.checkAnnArgs([$type$String13,$type$Boolean12],[main_DASH_module_DASH_name112701,check_DASH_all113693],[L[161],L[162]],function() {
var anf_fun2222359 = G(list21700,"make",L[160]);
var $z23512352 = D;
var $f23572358 = function(_) {
return R.isFunction(anf_fun2222359)?anf_fun2222359.app([]):R.ffi.throwNonFunApp(L[159],anf_fun2222359,[[]]);
};
try {
if(--R.GAS > 0) {
$z23512352 = $f23572358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23572358,
"from":L[159]});
}
} catch($e23492350) {
if(R.isCont($e23492350)) {
var $ss23532354 = {"from":L[159],
"go":function(var_DASH_bind542692) {
return $Hvar_DASH_bind585691(var_DASH_bind542692,CheckBlockResult6235,TestResult6437,check_DASH_all113693,check_DASH_block_DASH_result71694,each41695,failure_DASH_no_DASH_exn84696,failure_DASH_not_DASH_equal78697,failure_DASH_not_DASH_satisfied80698,failure_DASH_wrong_DASH_exn82699,list21700,main_DASH_module_DASH_name112701,render_DASH_check_DASH_results87702,results_DASH_summary86703,success76704,_plus5,nothing7,run_DASH_task8,string_DASH_contains9,torepr10);
}};
$e23492350.stack[R.EXN_STACKHEIGHT++] = $ss23532354;
}
if(R.isPyretException($e23492350)) {
$e23492350.pyretStack.push(L[159]);
}
throw $e23492350;
}
var $ret23552356 = $Hvar_DASH_bind585691($z23512352,CheckBlockResult6235,TestResult6437,check_DASH_all113693,check_DASH_block_DASH_result71694,each41695,failure_DASH_no_DASH_exn84696,failure_DASH_not_DASH_equal78697,failure_DASH_not_DASH_satisfied80698,failure_DASH_wrong_DASH_exn82699,list21700,main_DASH_module_DASH_name112701,render_DASH_check_DASH_results87702,results_DASH_summary86703,success76704,_plus5,nothing7,run_DASH_task8,string_DASH_contains9,torepr10);
++R.GAS;
return $ret23552356;
});
});
make_DASH_check_DASH_context852261.$var = anf_assign3232262;
var anf_assign4412263 = R.makeFunction(function(block_DASH_results1542287) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[145],1,arguments);
}
return R.checkAnnArgs([List132225],[block_DASH_results1542287],[L[157]],function() {
var init15559 = R.makeObject({"message":(""),
"passed":(0),
"failed":(0),
"total":(0)});
var anf_arg39657 = R.makeFunction(function(summary157286,br158285) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[148],2,arguments);
}
var anf_arg356284 = R.makeFunction(function(s160532,tr161533) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[152],2,arguments);
}
var cases_DASH_val442348 = tr161533;
var anf_fun3272321 = G(cases_DASH_val442348,"_match",L[153]);
var anf_obj3392335 = R.makeFunction(function(loc162626,code1632336) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[155],2,arguments);
}
var anf_arg3292347 = G(s160532,"message",L[156]);
var $z23392340 = D;
var $f23452346 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3292347,("\n  ")):R.ffi.throwNonFunApp(L[63],_plus5,[anf_arg3292347,("\n  ")]);
};
try {
if(--R.GAS > 0) {
$z23392340 = $f23452346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23452346,
"from":L[63]});
}
} catch($e23372338) {
if(R.isCont($e23372338)) {
var $ss23412342 = {"from":L[63],
"go":function(anf_arg330625) {
return $Hanf_arg591624(anf_arg330625,loc162626,s160532,_plus5);
}};
$e23372338.stack[R.EXN_STACKHEIGHT++] = $ss23412342;
}
if(R.isPyretException($e23372338)) {
$e23372338.pyretStack.push(L[63]);
}
throw $e23372338;
}
var $ret23432344 = $Hanf_arg591624($z23392340,loc162626,s160532,_plus5);
++R.GAS;
return $ret23432344;
});
var anf_arg3402322 = R.makeObject({"success":anf_obj3392335});
var anf_arg3552323 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[153],0,arguments);
}
var anf_arg3422334 = G(s160532,"message",L[154]);
var $z23262327 = D;
var $f23322333 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg3422334,("\n  ")):R.ffi.throwNonFunApp(L[53],_plus5,[anf_arg3422334,("\n  ")]);
};
try {
if(--R.GAS > 0) {
$z23262327 = $f23322333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23322333,
"from":L[53]});
}
} catch($e23242325) {
if(R.isCont($e23242325)) {
var $ss23282329 = {"from":L[53],
"go":function(anf_arg343531) {
return $Hanf_arg599530(anf_arg343531,s160532,tr161533,_plus5);
}};
$e23242325.stack[R.EXN_STACKHEIGHT++] = $ss23282329;
}
if(R.isPyretException($e23242325)) {
$e23242325.pyretStack.push(L[53]);
}
throw $e23242325;
}
var $ret23302331 = $Hanf_arg599530($z23262327,s160532,tr161533,_plus5);
++R.GAS;
return $ret23302331;
});
var $z23132314 = D;
var $f23192320 = function(_) {
return R.isFunction(anf_fun3272321)?anf_fun3272321.app(anf_arg3402322,anf_arg3552323):R.ffi.throwNonFunApp(L[152],anf_fun3272321,[anf_arg3402322,anf_arg3552323]);
};
try {
if(--R.GAS > 0) {
$z23132314 = $f23192320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23192320,
"from":L[152]});
}
} catch($e23112312) {
if(R.isCont($e23112312)) {
var $ss23152316 = {"from":L[152],
"go":function(ann_DASH_check_DASH_temp326529) {
return $Hann_DASH_check_DASH_temp600528(ann_DASH_check_DASH_temp326529);
}};
$e23112312.stack[R.EXN_STACKHEIGHT++] = $ss23152316;
}
if(R.isPyretException($e23112312)) {
$e23112312.pyretStack.push(L[152]);
}
throw $e23112312;
}
var $ret23172318 = $Hann_DASH_check_DASH_temp600528($z23132314);
++R.GAS;
return $ret23172318;
});
var anf_bracket3572310 = G(br158285,"test-results",L[151]);
var anf_fun3582309 = G(anf_bracket3572310,"reverse",L[150]);
var $z23012302 = D;
var $f23072308 = function(_) {
return R.isFunction(anf_fun3582309)?anf_fun3582309.app():R.ffi.throwNonFunApp(L[149],anf_fun3582309,[]);
};
try {
if(--R.GAS > 0) {
$z23012302 = $f23072308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23072308,
"from":L[149]});
}
} catch($e22992300) {
if(R.isCont($e22992300)) {
var $ss23032304 = {"from":L[149],
"go":function(anf_arg359283) {
return $Hanf_arg619282(anf_arg359283,anf_arg356284,br158285,fold4958,init15559,summary157286,_plus5,tostring11);
}};
$e22992300.stack[R.EXN_STACKHEIGHT++] = $ss23032304;
}
if(R.isPyretException($e22992300)) {
$e22992300.pyretStack.push(L[149]);
}
throw $e22992300;
}
var $ret23052306 = $Hanf_arg619282($z23012302,anf_arg356284,br158285,fold4958,init15559,summary157286,_plus5,tostring11);
++R.GAS;
return $ret23052306;
});
var anf_fun3972298 = G(block_DASH_results1542287,"reverse",L[147]);
var $z22902291 = D;
var $f22962297 = function(_) {
return R.isFunction(anf_fun3972298)?anf_fun3972298.app():R.ffi.throwNonFunApp(L[146],anf_fun3972298,[]);
};
try {
if(--R.GAS > 0) {
$z22902291 = $f22962297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22962297,
"from":L[146]});
}
} catch($e22882289) {
if(R.isCont($e22882289)) {
var $ss22922293 = {"from":L[146],
"go":function(anf_arg39856) {
return $Hanf_arg63555(anf_arg39856,anf_arg39657,fold4958,init15559,_plus5,tostring11);
}};
$e22882289.stack[R.EXN_STACKHEIGHT++] = $ss22922293;
}
if(R.isPyretException($e22882289)) {
$e22882289.pyretStack.push(L[146]);
}
throw $e22882289;
}
var $ret22942295 = $Hanf_arg63555($z22902291,anf_arg39657,fold4958,init15559,_plus5,tostring11);
++R.GAS;
return $ret22942295;
});
});
results_DASH_summary86703.$var = anf_assign4412263;
var anf_assign4442264 = R.makeFunction(function(block_DASH_results1692276) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[142],1,arguments);
}
return R.checkAnnArgs([List132225],[block_DASH_results1692276],[L[144]],function() {
var $z22792280 = D;
var $f22852286 = function(_) {
return R.isFunction(results_DASH_summary86703.$var)?results_DASH_summary86703.$var.app(block_DASH_results1692276):R.ffi.throwNonFunApp(L[143],results_DASH_summary86703.$var,[block_DASH_results1692276]);
};
try {
if(--R.GAS > 0) {
$z22792280 = $f22852286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22852286,
"from":L[143]});
}
} catch($e22772278) {
if(R.isCont($e22772278)) {
var $ss22812282 = {"from":L[143],
"go":function(anf_bracket44353) {
return $Hanf_bracket63652(anf_bracket44353);
}};
$e22772278.stack[R.EXN_STACKHEIGHT++] = $ss22812282;
}
if(R.isPyretException($e22772278)) {
$e22772278.pyretStack.push(L[143]);
}
throw $e22772278;
}
var $ret22832284 = $Hanf_bracket63652($z22792280);
++R.GAS;
return $ret22832284;
});
});
render_DASH_check_DASH_results87702.$var = anf_assign4442264;
var provides44538 = R.makeObject({"CheckBlockResult":CheckBlockResult682233.$var,
"is-CheckBlockResult":is_DASH_CheckBlockResult692235.$var,
"check-block-result":check_DASH_block_DASH_result71694.$var,
"is-check-block-result":is_DASH_check_DASH_block_DASH_result702237.$var,
"TestResult":TestResult732242.$var,
"is-TestResult":is_DASH_TestResult742244.$var,
"success":success76704.$var,
"is-success":is_DASH_success752246.$var,
"failure-not-equal":failure_DASH_not_DASH_equal78697.$var,
"is-failure-not-equal":is_DASH_failure_DASH_not_DASH_equal772249.$var,
"failure-not-satisfied":failure_DASH_not_DASH_satisfied80698.$var,
"is-failure-not-satisfied":is_DASH_failure_DASH_not_DASH_satisfied792252.$var,
"failure-wrong-exn":failure_DASH_wrong_DASH_exn82699.$var,
"is-failure-wrong-exn":is_DASH_failure_DASH_wrong_DASH_exn812255.$var,
"failure-no-exn":failure_DASH_no_DASH_exn84696.$var,
"is-failure-no-exn":is_DASH_failure_DASH_no_DASH_exn832258.$var,
"make-check-context":make_DASH_check_DASH_context852261.$var,
"results-summary":results_DASH_summary86703.$var,
"render-check-results":render_DASH_check_DASH_results87702.$var});
var anf_fun4462275 = G(builtins6,"current-checker",L[0]);
var $z22672268 = D;
var $f22732274 = function(_) {
return R.isFunction(anf_fun4462275)?anf_fun4462275.app():R.ffi.throwNonFunApp(L[0],anf_fun4462275,[]);
};
try {
if(--R.GAS > 0) {
$z22672268 = $f22732274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22732274,
"from":L[0]});
}
} catch($e22652266) {
if(R.isCont($e22652266)) {
var $ss22692270 = {"from":L[0],
"go":function(anf_bracket44734) {
return $Hanf_bracket63833(anf_bracket44734,CheckBlockResult6235,Loc6636,TestResult6437,provides44538,nothing7);
}};
$e22652266.stack[R.EXN_STACKHEIGHT++] = $ss22692270;
}
if(R.isPyretException($e22652266)) {
$e22652266.pyretStack.push(L[0]);
}
throw $e22652266;
}
var $ret22712272 = $Hanf_bracket63833($z22672268,CheckBlockResult6235,Loc6636,TestResult6437,provides44538,nothing7);
++R.GAS;
return $ret22712272;
},function(moduleVal) {
R.modules["$src/arr/trove/checker.arr26"] = moduleVal
return moduleVal;
});
});
}
};
});
define('js/../../../lib/jglr/cyclicJSON',[], function() {
/*
  cycle.js
  2013-02-19

  Public Domain.

  NO WARRANTY EXPRESSED OR IMPLIED. USE AT YOUR OWN RISK.

  This code should be minified before deployment.
  See http://javascript.crockford.com/jsmin.html

  USE YOUR OWN COPY. IT IS EXTREMELY UNWISE TO LOAD CODE FROM SERVERS YOU DO
  NOT CONTROL.
*/

/*jslint evil: true, regexp: true */

/*members $ref, apply, call, decycle, hasOwnProperty, length, prototype, push,
  retrocycle, stringify, test, toString
*/
//////////////////////////////////
if (typeof JSON.decycle !== 'function') {
  JSON.decycle = function decycle(object) {
    

    // Make a deep copy of an object or array, assuring that there is at most
    // one instance of each object or array in the resulting structure. The
    // duplicate references (which might be forming cycles) are replaced with
    // an object of the form
    //      {$ref: PATH}
    // where the PATH is a JSONPath string that locates the first occurance.
    // So,
    //      var a = [];
    //      a[0] = a;
    //      return JSON.stringify(JSON.decycle(a));
    // produces the string '[{"$ref":"$"}]'.

    // JSONPath is used to locate the unique object. $ indicates the top level of
    // the object or array. [NUMBER] or [STRING] indicates a child member or
    // property.
    
    var objects = [],   // Keep a reference to each unique object or array
    paths = [];     // Keep the path to each unique object or array
    
    return (function derez(value, path) {
      
      // The derez recurses through the object, producing the deep copy.
      
      var i,          // The loop counter
      name,       // Property name
      nu;         // The new object or array
      
      // typeof null === 'object', so go on if this value is really an object but not
      // one of the weird builtin objects.

      if (typeof value === 'object' && value !== null &&
          !(value instanceof Boolean) &&
          !(value instanceof Date)    &&
          !(value instanceof Number)  &&
          !(value instanceof RegExp)  &&
          !(value instanceof String)) {

        // If the value is an object or array, look to see if we have already
        // encountered it. If so, return a $ref/path object. This is a hard way,
        // linear search that will get slower as the number of unique objects grows.

        for (i = 0; i < objects.length; i += 1) {
          if (objects[i] === value) {
            return {$ref: paths[i]};
          }
        }

        // Otherwise, accumulate the unique value and its path.

        objects.push(value);
        paths.push(path);

        // If it is an array, replicate the array.

        if (Object.prototype.toString.apply(value) === '[object Array]') {
          nu = [];
          for (i = 0; i < value.length; i += 1) {
            nu[i] = derez(value[i], path + '[' + i + ']');
          }
        } else {

          // If it is an object, replicate the object.

          nu = {};
          for (name in value) {
            if (Object.prototype.hasOwnProperty.call(value, name)) {
              nu[name] = derez(value[name],
                               path + '[' + JSON.stringify(name) + ']');
            }
          }
        }
        return nu;
      }
      return value;
    }(object, '$'));
  };
}


if (typeof JSON.retrocycle !== 'function') {
  JSON.retrocycle = function retrocycle($) {
    

    // Restore an object that was reduced by decycle. Members whose values are
    // objects of the form
    //      {$ref: PATH}
    // are replaced with references to the value found by the PATH. This will
    // restore cycles. The object will be mutated.

    // The eval function is used to locate the values described by a PATH. The
    // root object is kept in a $ variable. A regular expression is used to
    // assure that the PATH is extremely well formed. The regexp contains nested
    // * quantifiers. That has been known to have extremely bad performance
    // problems on some browsers for very long strings. A PATH is expected to be
    // reasonably short. A PATH is allowed to belong to a very restricted subset of
    // Goessner's JSONPath.

    // So,
    //      var s = '[{"$ref":"$"}]';
    //      return JSON.retrocycle(JSON.parse(s));
    // produces an array containing a single element which is the array itself.

    var px =
      /^\$(?:\[(?:\d+|\"(?:[^\\\"\u0000-\u001f]|\\([\\\"\/bfnrt]|u[0-9a-zA-Z]{4}))*\")\])*$/;

    (function rez(value) {

      // The rez function walks recursively through the object looking for $ref
      // properties. When it finds one that has a value that is a path, then it
      // replaces the $ref object with a reference to the value that is found by
      // the path.

      var i, item, name, path;

      if (value && typeof value === 'object') {
        if (Object.prototype.toString.apply(value) === '[object Array]') {
          for (i = 0; i < value.length; i += 1) {
            item = value[i];
            if (item && typeof item === 'object') {
              path = item.$ref;
              if (typeof path === 'string' && px.test(path)) {
                value[i] = eval(path);
              } else {
                rez(item);
              }
            }
          }
        } else {
          for (name in value) {
            if (typeof value[name] === 'object') {
              item = value[name];
              if (item) {
                path = item.$ref;
                if (typeof path === 'string' && px.test(path)) {
                  value[name] = eval(path);
                } else {
                  rez(item);
                }
              }
            }
          }
        }
      }
    }($));
    return $;
  };
}
});

define('js/../../../lib/jglr/rnglr',["./cyclicJSON"], function(cycle) {
  function SrcLoc(startRow, startCol, startChar, endRow, endCol, endChar) {
    this.startRow = startRow;
    this.startCol = startCol;
    this.startChar = startChar;
    this.endRow = endRow;
    this.endCol = endCol;
    this.endChar = endChar;
  }
  SrcLoc.cache = {};
  SrcLoc.reset = function() { SrcLoc.cache = {}; }
  SrcLoc.make = function(startRow, startCol, startChar, endRow, endCol, endChar) {
    var byStartChar = SrcLoc.cache[startChar];
    if (byStartChar === undefined)
      byStartChar = SrcLoc.cache[startChar] = {};
    var byEndChar = byStartChar[endChar];
    if (byEndChar === undefined)
      byEndChar = byStartChar[endChar] = new SrcLoc(startRow, startCol, startChar, endRow, endCol, endChar);
    return byEndChar;
  }
  SrcLoc.prototype.toString = function(show_span) {
    var ret = this.startRow + ":" + this.startCol;
    if (show_span)
      ret += "-" + this.endRow + ":" + this.endCol;
    return ret;
  }
  SrcLoc.prototype.combine = function(that, inPlace) {
    //assert.notEqual(that, undefined, "Can't combine " + this + " with undefined");
    if (inPlace) {
      if (this.startChar > that.startChar) {
        this.startChar = that.startChar;
        this.startRow = that.startRow;
        this.startCol = that.startCol;
      }
      if (this.endChar < that.endChar) {
        this.endChar = that.endChar;
        this.endRow = that.endRow;
        this.endCol = that.endCol;
      }
      return this;
    } else {
      if (this.startChar < that.startChar) {
        if (this.endChar < that.endChar) {
          return SrcLoc.make(this.startRow, this.startCol, this.startChar, that.endRow, that.endCol, that.endChar);
        } else {
          return SrcLoc.make(this.startRow, this.startCol, this.startChar, this.endRow, this.endCol, this.endChar);
        }
      } else {
        if (this.endChar < that.endChar) {
          return SrcLoc.make(that.startRow, that.startCol, that.startChar, that.endRow, that.endCol, that.endChar);
        } else {
          return SrcLoc.make(that.startRow, that.startCol, that.startChar, this.endRow, this.endCol, this.endChar);
        }
      }
    }
  }
  SrcLoc.prototype.posAtStart = function() { 
    return SrcLoc.make(this.startRow, this.startCol, this.startChar, this.startRow, this.startCol, this.startChar);
  }
  SrcLoc.prototype.posAtEnd = function() { 
    return SrcLoc.make(this.endRow, this.endCol, this.endChar, this.endRow, this.endCol, this.endChar);
  }

  //////////////////////////////////
  ////////// Various Sets //////////
  //////////////////////////////////
  function IntSet(items) {
    this.elements = {};
    this.ordered = [];
    if (items instanceof IntSet) {
      for (var i = 0; i < items.ordered.length; i++)
        this.add(items.ordered[i]);
    } else if (items) {
      for (var i = 0; i < items.length; i++)
        this.add(items[i]);
    }
  }
  IntSet.prototype.add = function(item) {
    if (this.elements[item] === undefined) {
      this.elements[item] = item;
      this.ordered.push(item);
      return true;
    }
    return false;
  }
  IntSet.prototype.contains = function(item) { return this.elements[item] !== undefined; }
  IntSet.prototype.size = function() { return this.ordered.length; }
  IntSet.prototype.get = function(index) { return this.ordered[index]; }
  IntSet.prototype.toString = function() {
    var items = this.ordered.slice(0);
    items.sort();
    return "{" + JSON.stringify(items) + "}";
  }
  IntSet.prototype.equals = function(that) {
    if (this.size() !== that.size()) return false;
    if (!(that instanceof IntSet)) return false;
    for (var i = 0; i < this.ordered.length; i++)
      if (that.elements[this.ordered[i]] === undefined)
        return false;
    return true;
  }


  function KeyedSet(key, items) {
    this.elements = {};
    this.ordered = [];
    this.uniqueId = "KS" + (++KeyedSet.nextSetId);
    this.byKey = key;
    if (key instanceof KeyedSet) {
      items = key;
      this.byKey = items.byKey;
      for (var i = 0; i < items.ordered.length; i++)
        this.add(items.ordered[i]);
    } else if (items) {
      for (var i = 0; i < items.length; i++)
        this.add(items[i]);
    }
  }
  KeyedSet.nextSetId = 0;
  KeyedSet.equals = function(thiz, that) { return thiz.equals(that); }
  KeyedSet.prototype.add = function(item) {
    var key = item[this.byKey];
    if (this.elements[key] === undefined) {
      this.elements[key] = item;
      this.ordered.push(item);
      return true;
    }
    return false;
  }
  KeyedSet.prototype.size = function() { return this.ordered.length; }
  KeyedSet.prototype.contains = function(item) { return this.elements[item[this.byKey]] !== undefined; }
  KeyedSet.prototype.equals = function(that) {
    if (this.size() !== that.size()) return false;
    if (this.byKey !== that.byKey) return false;
    for (var i = 0; i < this.ordered.length; i++)
      if (that.elements[this.ordered[i][this.byKey]] === undefined)
        return false;
    return true;
  }
  KeyedSet.prototype.get = function(index) { return this.ordered[index]; }
  KeyedSet.prototype.itemForKey = function(key) { return this.elements[key]; }
  KeyedSet.prototype.merge = function(that) {
    var ret = false;
    for (var i = 0; i < that.ordered.length; i++)
      ret = this.add(that.ordered[i]) || ret;
    return ret;
  }
  KeyedSet.prototype.toString = function() {
    var keys = [];
    for (var i = 0; i < this.ordered.length; i++)
      keys.push(this.ordered[i][this.byKey]);
    keys.sort();
    var s = "";
    for (var i = 0; i < keys.length; i++) {
      if (s !== "") s += ", ";
      s += this.elements[keys[i]];
    }
    return "{" + s + "}";
  }

  function LR1Set(rules) {
    this.uniqueId = "LR" + ++LR1Set.nextId;
    this.ruleIdx = {}; // maps rules-as-strings to indices in coreRules
    this.coreRules = []; // array of core rules
    this.core = []; // maps indices to sets of lookahead tokens
    this.noLook = []; // true iff we have an LR0 item in this set
    if (rules instanceof KeyedSet) {
      for (var i = 0; i < rules.size(); i++)
        this.addRule(rules.get(i));
    } else if (rules instanceof Array) {
      for (var i = 0; i < rules.length; i++)
        this.addRule(rules[i]);
    } else if (rules instanceof LR1Set) {
      this.coreRules = rules.coreRules.slice(0);
      this.noLook = rules.noLook.slice(0);
      for (var r in rules.ruleIdx)
        this.ruleIdx[r] = rules.ruleIdx[r];
      for (var i = 0; i < rules.core.length; i++)
        this.core[i] = new KeyedSet(rules.core[i]);
    }
  }
  LR1Set.nextId = 0;
  LR1Set.prototype.exhaustive = function() {
    var ret = [];
    for (var i = 0; i < this.coreRules.length; i++) {
      if (this.noLook[i])
        ret.push(this.coreRules[i]);
      for (var j = 0; j < this.core[i].size(); j++) {
        ret.push(this.coreRules[i].withLookahead(this.core[i].get(j)));
      }
    }
    return ret;
  }
  LR1Set.prototype.coreSize = function() { return this.coreRules.length; }
  LR1Set.prototype.getCore = function(i) { return this.coreRules[i]; }
  LR1Set.prototype.getLookaheads = function(i) { return this.core[i]; }
  LR1Set.prototype.addRule = function(rule) {
    var ret = false;
    var noLookahead = rule.withLookahead(undefined);
    ruleKey = noLookahead.toString();
    var idx = this.ruleIdx[ruleKey];
    if (idx === undefined) {
      ret = true;
      idx = this.ruleIdx[ruleKey] = this.coreRules.push(noLookahead) - 1;
    }
    if (rule.lookahead === undefined) {
      ret = ret || !this.noLook[idx];
      this.noLook[idx] = true;
    } else {
      if (this.core[idx] === undefined)
        this.core[idx] = new KeyedSet("key");
      ret = this.core[idx].add(rule.lookahead) || ret;
    }
    return ret; // Return true if something's been added
  }
  LR1Set.prototype.addRuleWithLookaheads = function(rule, lookaheads) {
    var noLookahead = rule.withLookahead(undefined);
    ruleKey = noLookahead.toString();
    var idx = this.ruleIdx[ruleKey];
    if (idx === undefined) {
      idx = this.ruleIdx[ruleKey] = this.coreRules.push(noLookahead) - 1;
    }
    if (lookaheads.size() === 0) {
      this.noLook[idx] = true;
    } else {
      if (this.core[idx] === undefined)
        this.core[idx] = new KeyedSet("key");
      this.core[idx].merge(lookaheads);
    }
  }
  LR1Set.prototype.toString = function(multiLine) {
    var s = "";
    var sep = (multiLine ? "\n" : ", ");
    var leader = (multiLine ? "  " : "");
    for (var i = 0; i < this.coreRules.length; i++) {
      if (this.noLook[i]) {
        if (s !== "") s += sep;
        s += leader + this.coreRules[i].toString();
      }
      if (this.core[i] !== undefined) {
        if (s !== "") s += sep;
        s += leader + "[" + this.coreRules[i].toString() + ", " + this.core[i].toString() + "]";
      }
    }
    return "{" + (multiLine ? "\n" : "") + s + "}";
  }
  LR1Set.equals = function(thiz, that) { return thiz.equalsCore(that); }
  LR1Set.prototype.equalsCore = function(that) {
    ret = true
    if (this.core.length !== that.core.length) ret = false;
    for (var r in this.ruleIdx)
      if (that.ruleIdx[r] === undefined) ret = false;
    return ret;
  }


  function SetOfSets(items, comparison) {
    this.ordered = [];
    this.comparison = comparison
    if (items instanceof SetOfSets) {
      if (!this.comparison)
        this.comparison = items.comparison;
      for (var i = 0; i < items.ordered.length; i++)
        this.add(items.ordered[i]);
    } else if (items) {
      for (var i = 0; i < items.length; i++)
        this.add(items[i]);
    }
  }
  SetOfSets.prototype.toString = function(sep_lines, sorted) {
    var s = "";
    var items_strs = []
    for (var i = 0; i < this.ordered.length; i++)
      items_strs[i] = this.ordered[i].toString();
    if (sorted)
      items_strs.sort();
    for (var i = 0; i < items_strs.length; i++) {
      if (s == "")
        s += "{" + items_strs[i]
      else
        s += (sep_lines ? ",\n " : ", ") + items_strs[i];
    }
    if (s == "")
      return "{}";
    return s + "}";
  }
  SetOfSets.prototype.add = function(item) {
    var key = item.toString();
    if (this.indexOf(item) === -1) {
      this.ordered.push(item);
      return true;
    }
    return false;
  }
  SetOfSets.prototype.indexOf = function(item) {
    return this.indexOfHelp(this.ordered, item);
  }
  SetOfSets.prototype.indexOfHelp = function(items, item) {
    for (var i = 0; i < items.length; i++) {
      if ((this.comparison && this.comparison(items[i], item)) ||
          ((!this.comparison) && (items[i] == item))) {
        return i;
      }
    }
    return -1;
  }  
  SetOfSets.prototype.size = function() { return this.ordered.length; }
  SetOfSets.prototype.get = function(index) { return this.ordered[index]; }

  //////////////////////////////////
  ///////////// Queues /////////////
  //////////////////////////////////

  function Queue(items) {
    this.items = items.slice(0);
    this.start = 0;
    this.end = items.length;
    this.length = items.length;
  }
  Queue.prototype.push = function(item) {
    this.items[this.end] = item;
    this.end++;
    this.length++;
  }
  Queue.prototype.shift = function() {
    if (this.length === 0) return undefined;
    var ret = this.items[this.start];
    this.start++;
    this.length--;
    return ret;
  }
  Queue.prototype.get = function(idx) {
    if (this.start + idx < this.end) return this.items[this.start + idx];
    return undefined;
  }
  Queue.prototype.insertAt = function(idx, item) {
    if (this.start + idx < this.end) {
      this.items.splice(this.start + idx, 0, item);
      this.end++;
      this.length++;
    } else
      this.push(item);
  }
  Queue.prototype.debugPrint = function() { 
    console.log("********** Debug print of queue: start = " + this.start + ", end = " + this.end + ", length = " + this.length);
    for (var i = this.start; i < this.end; i++) {
      if (this.end === i) console.log("<<-- END");
      if (this.start === i) console.log("-->> START");
      if (this.items[i].hasOwnProperty("debugPrint"))
        console.log(i + ": " + this.items[i].debugPrint());
      else
        console.log(i + ": " + this.items[i].toString(true));
    }
    if (this.items.length === this.start) console.log("-->> START");
    if (this.items.length === this.end) console.log("<<-- END");
  }


  //////////////////////////////////
  ///////////// Atoms //////////////
  //////////////////////////////////

  function Atom() {}
  Atom.equals = function(thiz, that) {
    if (thiz === that) return true;
    if ((thiz instanceof Nonterm) && (that instanceof Nonterm) && (thiz.name == that.name)) return true;
    if ((thiz instanceof Token) && (that instanceof Token) && (thiz.name == that.name)) return true;
    return false;
  }
  Atom.equals.toString = function() { return "Atom.equals" };
  Atom.fromSerializable = function(obj) {
    if (obj === undefined) return undefined;
    if (obj.type === "Nonterm") return new Nonterm(obj.name);
    if (obj.type === "Token") return new Token(obj.name, obj.value);
    if (obj.type === "EOF") return EOF;
    if (obj.type === "EPSILON") return EPSILON;
    if (obj.type === "HASH") return HASH;
    return null;
  }
  function Nonterm(name) {
    this.name = name;
    this.key = "@" + this.name;
  }
  Nonterm.prototype = Object.create(Atom.prototype);
  Nonterm.prototype.toString = function() { return this.name; }
  function Token(name, value) {
    this.name = name;
    if (value !== undefined)
      this.value = value;
    else
      this.value = name;
    this.key = "'" + this.name + ":" + this.value;
  }
  Nonterm.prototype.toSerializable = function() { return {type: "Nonterm", name: this.name}; }
  Token.prototype = Object.create(Atom.prototype);
  Token.prototype.toString = function(showVal) { 
    if (showVal && this.name !== this.value)
      return "('" + this.name + " " + JSON.stringify(this.value) + ")";
    else
      return "'" + this.name; 
  }
  Token.prototype.toSerializable = function() { 
    if (this.name !== this.value)
      return {type: "Token", name: this.name, value: this.value};
    else
      return {type: "Token", name: this.name};
  }

  const EOF = Object.create(Token.prototype, 
                            {name: {enumerable: true, value: "EOF"}, 
                             toString: {value: function(showVal) { 
                               if (showVal) return "<end of file>";
                               return "$"; 
                             }},
                             key: {enumerable: true, value: "$"},
                             toSerializable: {value: function() { return {type:"EOF"}; } }});
  const EPSILON = Object.create(Atom.prototype, 
                                {name: {enumerable: true, value: "EPSILON"}, 
                                 toString: {value: function() { return "ε"; }},
                                 key: {enumerable: true, value: "ε"},
                                 toSerializable: {value: function() { return {type:"EPSILON"}; } }});
  const HASH = Object.create(Atom.prototype, 
                             {name: {enumerable: true, value: "HASH"}, 
                              toString: {value: function() { return "#"; }},
                              key: {enumerable: true, value: "#"},
                              toSerializable: {value: function() { return {type:"HASH"}; } }});

  //////////////////////////////////
  //////////// Actions /////////////
  //////////////////////////////////

  function Action() { }
  Action.equals = function actionEquals(thiz, that) {
    return (thiz.type === that.type && Rule.equals(thiz.rule, that.rule) && thiz.dest == that.dest);
  }
  Action.equals.toString = function() { return "Action.equals"; }
  function ReduceAction(rule, f) {
    this.type = "Reduce";
    this.rule = rule;
    this.f = f;
    //assert.notEqual(f, undefined, "Bad f value for rule " + rule);
    this.key = rule.id + "#" + f
  }
  ReduceAction.prototype = Object.create(Action.prototype);
  ReduceAction.prototype.toString = function(hideRule) { 
    if (hideRule)
      return "Reduce " + this.rule.id;
    else
      return "Reduce(" + this.rule.id + ":" + this.rule.asString + ", m" + this.rule.position + ", f" + this.f + ")";
  }
  ReduceAction.prototype.equals = function(that) { return (that instanceof ReduceAction) && (this.rule == that.rule); }

  //////////////////////////////////
  ///////////// Rules //////////////
  //////////////////////////////////

  // name :: string
  // symbols :: array of Atoms
  // lookahead :: Atom or undefined
  // position :: Number or undefined
  function Rule(name, symbols, lookahead, position) {
    this.id = Rule.NextRuleId++;
    this.name = name;
    this.symbols = symbols;
    this.lookahead = lookahead
    this.position = position || 0;
    var s = this.name.toString() + " =>";
    var c = s
    for (var i = 0; i < this.symbols.length; i++) {
      if (i === this.position)
        s += " .";
      s += " " + this.symbols[i].toString();
      c += " " + this.symbols[i].toString();
    }
    this.coreString = c;
    if (this.position === this.symbols.length)
      s += " .";
    if (this.lookahead)
      s = "[" + s + ", " + this.lookahead.toString() + "]";
    this.asString = s;
  }
  Rule.defaultASTToString = function(show_pos) {
    var toStr = "(" + this.name; 
    if (show_pos)
      toStr += "@" + this.pos.toString(true);
    for (var i = 0; i < this.kids.length; i++) {
      toStr += " " + this.kids[i].toString(true);
    }
    toStr += ")";
    return toStr; 
  }
  Rule.defaultAction = function(kids, curPos, semActions) {
    var useful_kids = [];
    for (var i = 0; i < kids.length; i++) {
      if (kids[i].shouldInline === true) useful_kids = useful_kids.concat(kids[i].kids);
      else useful_kids.push(kids[i]);
    }
    var pos = (kids.length > 0 ? kids[0].pos.combine(kids[kids.length  - 1].pos) : curPos);
    if (semActions !== undefined && semActions[this.name] !== undefined)
      return semActions[this.name](useful_kids, pos);
    else
      return { name: this.name, kids: useful_kids, toString: Rule.defaultASTToString, pos: pos };
  }
  Rule.defaultAction.toString = function() { return "Rule.defaultAction"; }

  Rule.ListCons = function(hd, tl, shouldInline) {
    var ret = function(kids, curPos, ignoredSemActions) {
      var useful_kids = [];
      for (var i = 0; i < kids.length; i++) {
        if (kids[i].name === hd) {
          if (kids[i].shouldInline === true)
            useful_kids = useful_kids.concat(kids[i].kids);
          else
            useful_kids.push(kids[i]);
        } else if (kids[i].name === tl) useful_kids = useful_kids.concat(kids[i].kids); 
      }
      var pos = (kids.length > 0 ? kids[0].pos.combine(curPos) : curPos);
      return { name: tl, kids: useful_kids, toString: Rule.defaultASTToString, pos: pos,
               shouldInline: shouldInline };
    }
    if (shouldInline) {
      ret.toString = function() { return "Rule.ListCons(" + JSON.stringify(hd) + ", " + JSON.stringify(tl) + ", true)"; }
    }
    else {
      ret.toString = function() { return "Rule.ListCons(" + JSON.stringify(hd) + ", " + JSON.stringify(tl) + ")"; }
    }
    return ret;
  }

  Rule.Inline = function(kids, curPos, semActions) {
    var ret = Rule.defaultAction.call(this, kids, curPos, semActions);
    ret.shouldInline = true;
    return ret;
  }
  Rule.Inline.toString = function() { return "Rule.Inline"; }

  Rule.KeepOnly = function(names, shouldInline) {
    var name_dict = {};
    for (var i = 0; i < names.length; i++)
      name_dict[names[i]] = true;
    var ret = function(kids, curPos, ignoredSemActions) {
      var useful_kids = [];
      for (var i = 0; i < kids.length; i++) {
        if (name_dict[kids[i].name] === true) {
          if (kids[i].shouldInline === true)
            useful_kids = useful_kids.concat(kids[i].kids);
          else
            useful_kids.push(kids[i]);
        }
      }
      var pos = (kids.length > 0 ? kids[0].pos.combine(curPos) : curPos);
      return { name: this.name, kids: useful_kids, toString: Rule.defaultASTToString, pos: pos, 
               shouldInline: shouldInline };
    }
    if (shouldInline)
      ret.toString = function() { return "Rule.KeepOnly(" + JSON.stringify(names) + ", true)"; };
    else
      ret.toString = function() { return "Rule.KeepOnly(" + JSON.stringify(names) + ")"; };
    return ret;
  }

  var RuleFactory = {};
  RuleFactory.cache = {};
  RuleFactory.byId = {};
  RuleFactory.make = function(name, symbols, lookahead, pos) {
    pos = pos || 0;
    var findByName = RuleFactory.cache[name];
    if (findByName) {
      var findBySymbols = findByName[symbols];
      if (findBySymbols) {
        var findByLookahead = findBySymbols[lookahead];
        if (findByLookahead) {
          var findByPos = findByLookahead[pos];
          if (findByPos) return findByPos;
          else {
            var rule = new Rule(name, symbols, lookahead, pos);
            RuleFactory.byId[rule.id] = rule;
            findByLookahead[pos] = rule;
            return rule;
          }
        } else {
          var rule = new Rule(name, symbols, lookahead, pos);
          RuleFactory.byId[rule.id] = rule;
          var byPos = {}; byPos[pos] = rule;
          findBySymbols[lookahead] = byPos;
          return rule;
        }
      } else {
        var rule = new Rule(name, symbols, lookahead, pos);
        RuleFactory.byId[rule.id] = rule;
        var byPos = {}; byPos[pos] = rule;
        var byLookahead = {}; byLookahead[lookahead] = byPos;
        findByName[symbols] = byLookahead;
        return rule;
      }
    } else {
      var rule = new Rule(name, symbols, lookahead, pos);
      RuleFactory.byId[rule.id] = rule;
      var byPos = {}; byPos[pos] = rule;
      var byLookahead = {}; byLookahead[lookahead] = byPos;
      var bySymbols = {}; bySymbols[symbols] = byLookahead;
      RuleFactory.cache[name] = {}; RuleFactory.cache[name] = bySymbols;
      return rule;
    }
  }
  Rule.fromSerializable = function(rulesByOldId, id) {
    var obj = rulesByOldId[id];
    if (obj.hasOwnProperty("like")) {
      var base = Rule.fromSerializable(rulesByOldId, obj.like);
      var lookahead = obj.lookahead;
      var pos = obj.position;
      return RuleFactory.make(base.name, base.symbols, Atom.fromSerializable(lookahead), pos);
    } else {
      var sym = [];
      for (var i = 0; i < obj.symbols.length; i++) {
        sym[i] = Atom.fromSerializable(obj.symbols[i]);
      }
      return RuleFactory.make(obj.name, sym, Atom.fromSerializable(obj.lookahead), obj.position);
    }
  }

  Rule.NextRuleId = 0;
  Rule.equals = function(thiz, that) {
    if (thiz === that) return true;
    if (thiz === undefined || that === undefined) return false;
    if (thiz.id === that.id) return true;
    if (!(thiz.name == that.name && 
          thiz.symbols == that.symbols && 
          thiz.lookahead == that.lookahead && 
          thiz.position == that.position)) return false;
    return true;
  }
  Rule.equalsCore = function(thiz, that) {
    if (thiz === that) return true;
    if (thiz === undefined || that === undefined) return false;
    if (!(thiz.name == that.name && 
          thiz.symbols == that.symbols && 
          thiz.position == that.position)) return false;
    return true;
  }
  Rule.prototype = {
    toString: function() { return this.asString; },
    withPosition: function(pos) {
      return RuleFactory.make(this.name, this.symbols, this.lookahead, pos);
    },
    withLookahead: function(lookahead) { 
      return RuleFactory.make(this.name, this.symbols, lookahead, this.position); 
    },
    withLookaheadPosition: function(lookahead, pos) {
      return RuleFactory.make(this.name, this.symbols, lookahead, pos);
    },
    toSerializable: function() {
      var ret = {};
      if (this.lookahead) {
        ret.lookahead = this.lookahead.toSerializable();
        ret.position = this.position;
        ret.like = this.withLookaheadPosition(undefined, 0).id;
        return ret;
      }
      ret.name = this.name;
      ret.position = this.position;
      ret.symbols = [];
      for (var i = 0; i < this.symbols.length; i++)
        ret.symbols[i] = this.symbols[i].toSerializable();
      return ret;
    }
  }



  function Link(prev, val) {
    this.prev = prev;
    this.val = val;
    this.linkId = Link.NextLinkId++;
  }
  Link.NextLinkId = 0;
  Link.prototype.toString = function() {
    return this.prev.state + "<-(" + this.linkId + (this.reduced ? "r" : "") + ")-" + this.val;
  }



  function ShiftPair(gssNode, state) {
    this.gssNode = gssNode;
    this.state = state;
  }
  ShiftPair.prototype.toString = function() { return "Shift(" + this.gssNode.toString() + ", " + this.state + ")"; }
  function ReductionItem(gssNode, rule, m, f, label) {
    this.gssNode = gssNode;
    this.rule = rule;
    this.m = m;
    this.f = f;
    this.label = label;
  }
  ReductionItem.prototype.toString = function() {
    return "RedItem(" + this.gssNode + ", " + this.rule + ", " + this.m + ", " + this.f + ", " + this.label + ")";
  }
  function GSSNode(label) {
    this.gssId = GSSNode.NextNodeId++;
    this.label = label;
    this.links = [];
    GSSNode.allNodes.push(this);
  }
  GSSNode.NextNodeId = 0;
  GSSNode.allNodes = [];
  GSSNode.prototype.toString = function() { 
    return "GSSNode(#" + this.gssId + ",s" + this.parentSetId + ":st" + this.label + ")"; 
  }
  GSSNode.prototype.forPathsOfLength = function(len, callback) {
    if (len === 0) {
      callback({labels: [], leftSib: this}); 
    } else {
      //assert(this.links.length > 0, "Can't find any paths of length " + len + " from " + this)
      for (var i = 0; i < this.links.length; i++)
        pathLengthHelp(this.links[i], len, [], [this.toString()], callback);
    }
  }
  function pathLengthHelp(link, len, labels, stack, callback) {
    labels[len - 1] = link.val;
    stack.push(link.prev.toString());
    if (len == 1) { 
      // console.log("Constructed path via [" + stack + "]");
      // console.log("Calling callback with [" + labels + "] and leftSib.state " + link.prev.label);
      callback({labels: labels, leftSib: link.prev}); 
    } else {
      var prev_links = link.prev.links;
      //assert(prev_links.length > 0, "Can't find any paths of length " + len + " from " + this)
      for (var i = 0; i < prev_links.length; i++)
        pathLengthHelp(prev_links[i], len - 1, labels, stack, callback);
    }
    stack.pop();
  }
  


  var allowNull = false;
  function SPPFNode(label, pos) {
    //if (!allowNull)
      //assert(pos !== undefined && pos !== null);
    this.sppfId = SPPFNode.NextId++;
    this.label = label;
    this.pos = pos;
    this.rule = undefined;
    this.kids = undefined;
    this.ambig = undefined;
    SPPFNode.allNodes.push(this);
  }
  SPPFNode.allNodes = [];
  SPPFNode.NextId = 0;
  SPPFNode.prototype.toString = function() {
    var posString = "null";
    if (this.pos)
      posString = this.pos.toString();
    var ruleAmbig = "";
    if (this.rule)
      ruleAmbig = this.rule.toString();
    else if (this.ambig)
      ruleAmbig = "ambig";
    else if (this.label instanceof Token)
      ruleAmbig = "<Token " + this.label.toString(true) + ">";
    else
      ruleAmbig = "<unknown>";
    return "SPPFNode(" + this.sppfId + ", " + this.label.toString(true) + "@" + posString + " " + ruleAmbig + ")";
  }
  SPPFNode.prototype.addChildren = function(rule, kids, grammar) {
    if (this.kids === undefined && this.ambig === undefined) {
      this.kids = kids;
      this.rule = rule;
    } else if (this.ambig === undefined) {
      this.ambig = [];
      this.ambig.push({kids: this.kids, rule: this.rule}); 
      this.ambig.push({kids: kids, rule: rule});
      delete this.kids; delete this.rule;
    } else {
      var ruleFlags = grammar.getFlags(rule);
      var sortingFlag = grammar.ambiguitySortingFlag;
      if (sortingFlag === undefined || ruleFlags === undefined || ruleFlags[sortingFlag] === undefined) {
        this.ambig.push({kids: kids, rule: rule});
      } else {
        var newFlag = ruleFlags[sortingFlag];
        for (var i = 0; i < this.ambig.length; i++) {
          var flags = grammar.getFlags(this.ambig[i].rule);
          var relevantFlag = flags ? flags[sortingFlag] : undefined;
          if (relevantFlag > newFlag) {
            this.ambig.splice(i, 0, {kids: kids, rule: rule});
            return;
          }
        }
        this.ambig.push({kids: kids, rule: rule});
      }
    }
  }

  //////////////////////////////////
  //////////// Grammars ////////////
  //////////////////////////////////

  function Grammar(name, start) {
    this.name = name;
    this.rules = {};
    this.actions = {};
    this.flags = {};
    this.start = start;
    this.rnTable = [];
    this.acceptStates = [];
    this.atoms = new KeyedSet("key", [EOF, EPSILON]);
    this.tokens = new KeyedSet("key", [EOF, EPSILON]);
    this.nonterms = new KeyedSet("key");
  }

  Grammar.fromSerializable = function(obj) {
    var g = new Grammar(obj.name, obj.start);
    var rulesByOldId = {};
    var actionsByOldId = {};
    var flagsByOldId = {};
    GSSNode.NextNodeId = 0;
    Link.NextLinkId = 0;
    SPPFNode.NextId = 0
    for (var id in obj.rulesByOldId) {
      rulesByOldId[id] = Rule.fromSerializable(obj.rulesByOldId, id);
      actionsByOldId[id] = obj.actionsByOldId[id] ? eval(obj.actionsByOldId[id]) : undefined;
      flagsByOldId[id] = obj.flagsByOldId[id];
    }
    for (var i = 0; i < obj.rules.length; i++) {
      g.addRule(rulesByOldId[obj.rules[i]], actionsByOldId[obj.rules[i]], flagsByOldId[obj.rules[i]]);
    }
    g.rnTable = [];
    for (var i = 0; i < obj.rnTable.length; i++) {
      var tableRow = obj.rnTable[i];
      var newRow = g.rnTable[i] = {};
      for (var j = 0; j < g.atoms.size(); j++) {
        var atom = g.atoms.get(j);
        newRow[atom] = {push: undefined, reductions: new KeyedSet("key")};
        if (atom in tableRow) {
          if (tableRow[atom].accept)
            newRow[atom].accept = true;
          if (tableRow[atom].push) {
            //assert.equal(newRow[atom].push, undefined, "Already have a push action for atom " + atom);
            newRow[atom].push = tableRow[atom].push;
          }
          if (tableRow[atom].reductions) {
            for (var k = 0; k < tableRow[atom].reductions.length; k++) {
              var red = tableRow[atom].reductions[k];
              newRow[atom].reductions.add(new ReduceAction(rulesByOldId[red[0]], red[1]));
            }
          }
        }
      }
    }
    g.acceptStates = [];
    for (var i = 0; i < obj.acceptStates.length; i++)
      g.acceptStates[obj.acceptStates[i]] = true;
    g.derivable = {};
    for (var name in obj.derivable) {
      g.derivable[name] = {};
      for (var i = 0; i < obj.derivable[name].length; i++)
        g.derivable[name][obj.derivable[name][i]] = true;
    }
    g.ambiguitySortingFlag = obj.ambiguitySortingFlag;
    g.mode = obj.mode;
    g.eSPPFs = [];
    g.I = obj.I;
    var Iinv = {};
    for (var name in obj.I)
      Iinv[obj.I[name]] = name;
    allowNull = true;
    for (var i = 0; i < obj.eSPPFs.length; i++) {
      var label = obj.eSPPFs[i].label;
      if (label === "EPSILON")
        label = EPSILON;
      g.eSPPFs[i] = {null: new SPPFNode(label, null)};
    }
    allowNull = false;
    for (var i = 0; i < obj.eSPPFs.length; i++) {
      var src = obj.eSPPFs[i];
      var dest = g.eSPPFs[i].null;
      if (src.kids) {
        var kids = [];
        for (var j = 0; j < src.kids.length; j++)
          kids.push(g.eSPPFs[src.kids[j]].null);
        dest.addChildren(rulesByOldId[src.rule], kids, this);
      }
    }
    return g;
  }



  Grammar.prototype = {
    resetParser: function() {
      this.rnTable = [];
      this.acceptStates = [];
      delete this.first;
      delete this.nontermFirst;
      delete this.states;
      this.firstStringCache = {};
      this.closureCache = {};
    },
    initializeParser: function() {
      console.log("Initializing " + this.name);
      var new_start;
      if (!this.initialized) {
        new_start = "START";
        while (this.rules.hasOwnProperty(new_start))
          new_start += "_";
        this.addRule(new_start, [new Nonterm(this.start)]);
        this.start = new_start;
        this.initialized = true;
      }
      var orig_start = this.rules[this.start][0].symbols[0];
      console.log("Grammar productions:");
      for (var name in this.rules)
        for (var i = 0; i < this.rules[name].length; i++)
          console.log("  " + this.rules[name][i].toString(true));
      console.log("Computing first sets");
      this.resetParser();
      this.computeFirstSets();
      console.log("Computing derivability");
      this.computeDerivability();
      console.log("Computing states");
      this.computeStateKernels();
      console.log("Computing required nullable parts");
      this.computeRequiredNullableParts();
      console.log("Computing RN Table");
      this.computeRNTable();
      // console.log(this.printTables());
      this.mode = "RNGLR";
      console.log("Done initializing " + this.name);
    },
    parse: function(token_stream) {
      if (this.mode === "RNGLR")
        return this.parseRNGLR(token_stream);
      return "Unknown parsing mode -- can't actually parse!"
    },
    toString: function() {
      var s = "Grammar " + this.name + ": (initial rule " + this.start + ")\n";
      for (var name in this.rules) {
        var rules = this.rules[name];
        for (var i = 0; i < rules.length; i++)
          s += rules[i].toString() + "\n";
      }
      return s;
    },
    sortAmbiguitiesBy: function(s) { 
      this.ambiguitySortingFlag = s; 
    },
    toSerializable: function() {
      var ret = {};
      ret.start = this.start;
      ret.name = this.name;
      ret.acceptStates = [];
      for (var i = 0; i < this.acceptStates.length; i++)
        if (this.acceptStates[i])
          ret.acceptStates.push(i);
      if (this.ambiguitySortingFlag)
        ret.ambiguitySortingFlag = this.ambiguitySortingFlag;
      ret.mode = this.mode;
      ret.derivable = {};
      for (var name in this.derivable) {
        ret.derivable[name] = [];
        for (var der in this.derivable[name])
          ret.derivable[name].push(der);
      }
      ret.rulesByOldId = {};
      ret.actionsByOldId = {};
      ret.flagsByOldId = {};
      ret.rules = [];
      for (var name in this.rules) {
        for (var i = 0; i < this.rules[name].length; i++) {
          var rule = this.rules[name][i];
          var id = rule.id;
          ret.rulesByOldId[id] = rule.toSerializable();
          ret.rules.push(id);
          var rule_noLookahead = rule.withLookahead(undefined);
          ret.rulesByOldId[rule_noLookahead.id] = rule_noLookahead.toSerializable();
          ret.actionsByOldId[rule_noLookahead.id] = this.getAction(rule_noLookahead);
          if (ret.actionsByOldId[rule_noLookahead.id] !== undefined) {
            ret.actionsByOldId[rule_noLookahead.id] = ret.actionsByOldId[rule_noLookahead.id].toString();
          }
          ret.flagsByOldId[rule_noLookahead.id] = this.getFlags(rule_noLookahead);
        }
      }
      ret.rnTable = []; // TODO: Fix this
      for (var i = 0; i < this.rnTable.length; i++) {
        var tableRow = this.rnTable[i];
        ret.rnTable[i] = {};
        for (var name in tableRow) {
          if (tableRow[name].push === undefined && !tableRow[name].accept && tableRow[name].reductions.size() === 0) {
            //ret.rnTable[i][name] = "empty";
          } else {
            var entry = tableRow[name];
            var dest = ret.rnTable[i][name] = {};
            if (entry.accept) dest.accept = true;
            if (entry.push !== undefined) {
              dest.push = entry.push;
            }
            if (entry.reductions.size() > 0) {
              dest.reductions = [];
              for (var j = 0; j < entry.reductions.size(); j++) {
                var red = entry.reductions.get(j)
                dest.reductions.push([red.rule.id, red.f]);
                ret.rulesByOldId[red.rule.id] = red.rule.toSerializable();
                var rule_noLookahead = red.rule.withLookahead(undefined);
                ret.rulesByOldId[rule_noLookahead.id] = rule_noLookahead.toSerializable();
              }
            }
          }
        }
      }
      ret.I = this.I;
      ret.eSPPFs = [];
      for (var i = 0; i < this.eSPPFs.length; i++) {
        var null_eSPPF = this.eSPPFs[i].null;
        var label = null_eSPPF.label;
        if (label === EPSILON) {
          label = "EPSILON";
        }
        if (null_eSPPF.kids) {
          var kids = [];
          for (var j = 0; j < null_eSPPF.kids.length; j++)
            kids.push(null_eSPPF.kids[j].sppfId);
          if (null_eSPPF.rule)
            ret.eSPPFs[i] = {label: label, kids: kids, rule: null_eSPPF.rule.id};
          else
            ret.eSPPFs[i] = {label: label, kids: kids};
        } else {
          if (null_eSPPF.rule)
            ret.eSPPFs[i] = {label: label, rule: null_eSPPF.rule.id};
          else
            ret.eSPPFs[i] = {label: label};
        }
      }
      return ret;
    },

    addRule: function(name, symbols, action, flags) {
      var new_rule;
      if (name instanceof Rule) {
        new_rule = name;
        name = new_rule.name;
        flags = action; // slide arguments over by one
        action = symbols;
        symbols = new_rule.symbols;
      } else {
        new_rule = RuleFactory.make(name, symbols, undefined, undefined);
      }
      if (action === undefined)
        action = Rule.defaultAction;
      this.actions[new_rule.id] = action;
      this.flags[new_rule.id] = flags;
      if (!(this.rules.hasOwnProperty(name)))
        this.rules[name] = [];
      this.rules[name].push(new_rule);
      this.atoms.add(new Nonterm(name));
      this.nonterms.add(new Nonterm(name));
      for (var i = 0; i < symbols.length; i++) {
        this.atoms.add(symbols[i]);
        if (symbols[i] instanceof Nonterm)
          this.nonterms.add(symbols[i])
        else
          this.tokens.add(symbols[i])
      }
      return new_rule;
    },

    getAction: function(rule) {
      var baseRule = rule.withLookaheadPosition(undefined, 0);
      var action = this.actions[baseRule.id];
      return action;
    },
    applyAction: function(rule, kids, pos, semActions) {
      var action = this.getAction(rule);
      return action.call(rule, kids, pos, semActions);
    },
    getFlags: function(rule) {
      return this.flags[rule.withLookaheadPosition(undefined, 0).id];
    },

    //////////////////////////////////
    // Computes what nonterminals can derive other nonterminals in one or more steps,
    // i.e. A ->+ B for two nonterminals A and B (possibly the same)
    //////////////////////////////////
    computeDerivability: function() {
      this.derivable = {}
      for (var i = 0; i < this.nonterms.size(); i++)
        this.derivable[this.nonterms.get(i)] = {};
      var changed = true;
      while(changed) {
        changed = false;
        // console.log("\nNew loop...");
        for (var name in this.rules) {
          var rules = this.rules[name]
          for (var i = 0; i < rules.length; i++) {
            var rule = rules[i];
            // console.log("Processing rule [" + rule + "]");
            if (rule.symbols.length === 0) {
              // if (!this.derivable[name][EPSILON])
              //   console.log("  " + name + " can derive EPSILON via rule " + rule);
              changed = changed || (!this.derivable[name][EPSILON]);
              this.derivable[name][EPSILON] = true; // Rule <name> is nullable
            }
            for (var j = 0; j < rule.symbols.length; j++) {
              var sym = rule.symbols[j]
              if ((sym instanceof Token) && (sym !== EOF)) {
                // console.log("  Rule [" + rule + "] isn't nullable due to " + sym + " so skipping rest");
                break; // A token in the RHS of a rule means it can't derive a nonterminal on its own
              }
              var restNullable = true;
              for (var k = j + 1; k < rule.symbols.length; k++) {
                if (rule.symbols[k] === EOF) continue;
                if ((rule.symbols[k] instanceof Token) || 
                    (this.derivable[rule.symbols[k]][EPSILON] !== true)) {
                  restNullable = false;
                  break;
                }
              }
              if (restNullable) {
                // if (!this.derivable[name][sym])
                //   console.log("  " + name + " can derive " + sym + " via [" + rule + "]");
                changed = changed || (!this.derivable[name][sym]);
                this.derivable[name][sym] = true;
              }
              if ((!this.derivable[sym]) || this.derivable[sym][EPSILON] !== true) {
                // console.log("Rule [" + rule + "] isn't nullable after " + sym + " so skipping rest");
                break; // This nonterminal isn't nullable, so skip the rest of the rule
              }
            }
          }
        }

        for (var i = 0; i < this.nonterms.size(); i++) {
          var term_i = this.nonterms.get(i);
          for (var j = 0; j < this.nonterms.size(); j++) {
            var term_j = this.nonterms.get(j);
            if (i == j || !this.derivable[term_i][term_j]) continue;
            if (this.derivable[term_j][EPSILON] && !this.derivable[term_i][EPSILON]) {
              // console.log(term_i + " can derive EPSILON via " + term_j);
              this.derivable[term_i][EPSILON] = true;
            }
            for (var k = 0; k < this.nonterms.size(); k++) {
              var term_k = this.nonterms.get(k);
              if (j == k || !this.derivable[term_j][term_k]) continue;
              // if (!this.derivable[term_i][term_k])
              //   console.log(term_i + " can derive " + term_k + " via " + term_j);
              changed = changed || (!this.derivable[term_i][term_k])
              this.derivable[term_i][term_k] = true;
            }
          }
        }
      }
      // console.log("Done");
    },

    //////////////////////////////////
    // Computes the set of first tokens in a rule
    // If a rule is nullable, then EPSILON is one possible token
    //////////////////////////////////
    computeFirstSets: function() {
      var thiz = this;
      var changed = true;
      function addFirst(name, token) {
        var ret = !(token.toString() in thiz.first[name])
        thiz.first[name][token.toString()] = token;
        return ret;
      }
      function merge(dest, source) {
        var ret = false;
        for (var tok in thiz.first[source])
          if (thiz.first[source][tok] !== EPSILON)
            ret = addFirst(dest, thiz.first[source][tok]) || ret;
        return ret;
      }
      this.first = {};
      this.nontermFirst = {};
      for (var name in this.rules) {
        if (this.rules.hasOwnProperty(name)) {
          this.first[name] = {};
          this.nontermFirst[name] = new KeyedSet("key", [new Nonterm(name)]);
          for (var i = 0; i < this.rules[name].length; i++)
            if (this.rules[name][i].symbols.length === 0)
              addFirst(name, EPSILON);
        }
      }
      while (changed) {
        changed = false;
        for (var name in this.rules) {
          var name_rules = this.rules[name];
          for (var i = 0; i < name_rules.length; i++) {
            var name_rule = name_rules[i];
            var allNullable = true;
            for (var j = 0; j < name_rule.symbols.length; j++) {
              if (name_rule.symbols[j] instanceof Nonterm) {
                changed = merge(name, name_rule.symbols[j]) || changed;
                //if (this.nontermFirst[name_rule.symbols[j]] === undefined)
                  //assert(false, "Couldn't find a nontermFirst for " + name_rule.symbols[j]);
                this.nontermFirst[name].merge(this.nontermFirst[name_rule.symbols[j]]);
                if (this.first[name_rule.symbols[j]][EPSILON] !== EPSILON) {
                  allNullable = false;
                  break;
                }
              } else {
                changed = addFirst(name, name_rule.symbols[j]) || changed;
                allNullable = false;
                break;
              }
            }
            if (allNullable) {
              addFirst(name, EPSILON);
            }
          }
        }
      }
    },


    //////////////////////////////////
    // Computes the tokens that can immediately follow the specified position
    // in the current rule.  This is a subset of the Follow set for the given
    // nonterminal, and is therefore more precise and less prone to producing
    // parsing conflicts.
    //////////////////////////////////
    computeFollowAtPosition: function(rule, pos) {
      if (rule.lookahead)
        return this.computeFirstOfStrings(rule.symbols.slice(pos).concat(rule.lookahead));
      else
        return this.computeFirstOfStrings(rule.symbols.slice(pos));
    },

    //////////////////////////////////
    // Lifts the first relation from non-terminals to strings of grammar symbols
    computeFirstOfStrings: function(string) {
      var ret = this.firstStringCache[string];
      if (ret !== undefined) return ret;
      ret = this.firstStringCache[string] = new KeyedSet("key");
      var nullable = true;
      // console.log("syms[" + i + "] = [" + string + "], length = " + string.length);
      for (var j = 0; j < string.length; j++) {
        if (string[j] instanceof Token || string[j] === HASH) { // Tokens aren't nullable, so we're done
          ret.add(string[j]);
          nullable = false;
          break;
        } else {
          var first = this.first[string[j]];
          if (first === undefined) {
            console.log("WTF? string[j] = " + string[j] + " but first is undefined");
          }
          for (var name in first) {
            if (first[name] !== EPSILON)
              ret.add(first[name]);
          }
          if (first[EPSILON] === undefined) { // This nonterminal isn't nullable, so we're done
            nullable = false;
            break;
          }
        }
      }
      if (nullable)
        ret.add(EPSILON);
      return ret;
    },

    //////////////////////////////////
    // Computes the LR(1) closure of a rule set: 
    // For a given rule [A -> a.Bb, x] in the set, it adds [B -> .g, y]
    // for all [B -> g] in the grammar, and all y in FIRST(bx).
    // 
    // If inline = true, then it mutates the provided argument
    // otherwise it constructs a new set and returns that.
    // Dragon book 2ed, p261
    completeClosure: function(lrSet, inline) {
      var ret = inline ? lrSet : new LR1Set(lrSet);
      var worklist = new Queue(ret.exhaustive());
      while (worklist.length > 0) {
        var rule = worklist.shift();
        if (rule.position < rule.symbols.length) {
          var next_symbol = rule.symbols[rule.position];
          if (next_symbol instanceof Nonterm) {
            var next = this.computeFollowAtPosition(rule, rule.position + 1);
            // console.log("    next(" + rule + ") = " + next);
            var rules_to_add = this.rules[next_symbol]
            if (rules_to_add === undefined) {
              throw("No rules known for symbol " + next_symbol);
            }
            for (var j = 0; j < rules_to_add.length; j++) {
              var rule_to_add = rules_to_add[j];
              for (var k = 0; k < next.size(); k++) {
                var new_rule = RuleFactory.make(rule_to_add.name, rule_to_add.symbols, next.get(k), 0)
                if (ret.addRule(new_rule)) {
                  worklist.push(new_rule);
                }
              }
            }
          }
        }
      }
      return ret;
    },
    
    //////////////////////////////////
    // Computes the kernel of the LR(1) Goto set for a given kernel and symbol
    // Dragon book 2ed, p261
    computeGotoKernel: function(setNum, lrSet, symbol) {
      // console.log("--> Rule_set #" + setNum + " = " + lrSet + ", symbol = " + symbol);
      var ret = new LR1Set();
      for (var i = 0; i < lrSet.coreSize(); i++) {
        var rule = lrSet.getCore(i);
        // console.log("    Processing rule " + rule);
        if (rule.position < rule.symbols.length && rule.symbols[rule.position].toString() == symbol) {
          // console.log("      Pushing " + symbol + " over in rule " + rule);
          var new_rule = rule.withPosition(rule.position + 1);
          // console.log("      new_rule = " + new_rule + " and lookaheads = " + lrSet.getLookaheads(i));
          ret.addRuleWithLookaheads(new_rule, lrSet.getLookaheads(i));
        }
      }
      this.completeClosure(ret, true);
      // console.log("<-- Result = " + ret);
      return ret;
    },

    reducer: function(U, R, Q, N, i, cur_tok, skipped_WS_loc) {
      // cur_tok = token #i+1: i starts at index 0, and tokens start at index 1
      // U is an array of sets of GSS nodes
      // R is the worklist of pending reductions
      // Q is the set of (GSS node, token) pairs of pending shifts
      // N is the set of SPPF nodes created in this step
      // cur_tok is the current token
      var item = R.shift();
      // console.log("In reducer, i = " + i + ", cur_tok = " + cur_tok.toString(true) + ", and item = " + item);
      var v = item.gssNode; // GSS node from which the reduction is to be applied
      var X = item.rule.name; // the name of the reduction rule
      var m = item.m; // the length of the RHS of the reduction rule (maybe just item.rule.position?)
      var f = item.f; // the index of the required nullable part at the righthand end of the reduction
      // or 0 if the reduction isn't right-nullable
      var y = item.label; // the SPPF node labels the first edge of the path down which the reduction is applied
      // (if m = 0 then y = epsilon) [sic]
      var y_m = (m !== 0 ? y : undefined)
      var U_i = U[i]
      const thiz = this;
      v.forPathsOfLength(m > 0 ? (m - 1) : 0, function(p) {
        // console.log("Found path " + JSON.stringify(p, null, "  "));
        // p.labels contain the edge labels of the path
        var u = p.leftSib;
        var k = u.label;
        var l = thiz.rnTable[k][X].push;
        if (l !== undefined) {
          // console.log("k = " + k + ", X = " + X + ", l = " + l);
          var z = undefined;
          if (m === 0)
            z = thiz.getEpsilonSPPF(f, cur_tok.pos.posAtStart());
          else {
            var c = u.parentSetId;
            var nodes_X = N[X];
            if (nodes_X === undefined)
              nodes_X = N[X] = {};
            z = nodes_X[c];
            if (z === undefined) {
              var pos;
              if (skipped_WS_loc !== undefined) {
                pos = skipped_WS_loc.posAtStart();
              } else {
                pos = cur_tok.pos;
              }
              if (p.labels.length > 0) {
                pos = pos.combine(p.labels[0].pos);
              }
              z = nodes_X[c] = new SPPFNode(X, pos);
            }
          }
          // console.log("z = " + z); // XXX Serializing of eSPPFs isn't working
          var w = U_i.itemForKey(l);
          if (w !== undefined) {
            // console.log("1. Adding link from " + w + " to " + u + " labelled " + z);
            if (thiz.addLink(/*from*/w, /*to*/u, /*labelled*/z)) {
              if (m !== 0) {
                var reductions = thiz.getActions(l, cur_tok).reductions;
                for (var r = 0; r < reductions.size(); r++) {
                  var red = reductions.get(r);
                  if (red.rule.position !== 0)
                    R.push(new ReductionItem(u, red.rule, red.rule.position, red.f, z));
                }
              }
            }
          } else {
            w = new GSSNode(/*labelled*/l);
            w.parentSetId = U_i.id;
            U_i.add(w);
            // console.log("Added " + w + " to U[" + i + "] ==> " + U_i);
            // console.log("2. Adding link from " + w + " to " + u + " labelled " + z);
            thiz.addLink(/*from*/w,/*to*/u,/*labelled*/z);
            var actions = thiz.getActions(l, cur_tok);
            var ph = actions.push;
            if (ph !== undefined)
              Q.push(new ShiftPair(w, ph));
            var reductions = actions.reductions;
            // console.log("reductions(" + l + ", " + cur_tok.toString(true) + ") = " + reductions);
            for (var r = 0; r < reductions.size(); r++) {
              var red = reductions.get(r);
              if (red.rule.position === 0)
                // the label here is irrelevant, because m == 0 means the rest of the rule derives EPSILON
                R.push(new ReductionItem(w, red.rule, 0, red.f, EPSILON)); 
            }
            if (m !== 0) {
              for (var r = 0; r < reductions.size(); r++) {
                var red = reductions.get(r);
                if (red.rule.position !== 0)
                  R.push(new ReductionItem(u, red.rule, red.rule.position, red.f, z));
              }
            }
          }
          // console.log("R.length = " + R.length);
          // R.debugPrint();
          if (m !== 0) {
            var labels = p.labels.slice(0);
            labels.push(y_m);
            thiz.addChildren(item.rule, z, labels, f, skipped_WS_loc !== undefined ? skipped_WS_loc.posAtStart() : cur_tok.pos.posAtStart());
          }
        }
      });
    },

    addLink: function(rightSib, leftSib, val) {
      var link = undefined;
      for (var i = 0; i < rightSib.links.length; i++) {
        if (rightSib.links[i].prev === leftSib) {
          link = rightSib.links[i];
          break;
        }
      }
      if (link === undefined) {
        link = new Link(leftSib, val);
        rightSib.links.push(link);
        // console.log("Linking " + leftSib.toString() + " <-- " + rightSib.toString() + " with val " + val + "@" + val.pos);
        return link;
      } else {
        // console.log("Link already exists between " + leftSib.toString() + " <-- " + rightSib.toString());
        return undefined;
      }
    },

    shifter: function(U, R, Q, N, i, cur_tok, next_tok) {
      // cur_tok = token #i+1: i starts at index 0, and tokens start at index 1
      // next_tok = token #i+2
      // U is an array of sets of GSS nodes
      // R is the worklist of pending reductions
      // Q is the set of (GSS node, token) pairs of pending shifts
      // N is the set of SPPF nodes created in this step
      var success = false;
      if (cur_tok !== EOF) { // if i != d, in the paper, where d is the last token number
        // Q.debugPrint();
        var Qprime = new Queue([]);
        var z = new SPPFNode(cur_tok, cur_tok.pos);
        var U_i1 = U[i+1] = new KeyedSet("label");
        U_i1.id = i + 1;
        while (Q.length > 0) {
          var item = Q.shift();
          var v = item.gssNode;
          var k = item.state;
          var w = U_i1.itemForKey(k);
          // console.log("item = " + item + ", k = " + k + " and therefore w = " + w);
          if (w !== undefined) {
            success = true;
            this.addLink(/*from*/w, /*to*/v, /*labelled*/z);
            var reductions = this.getActions(k, next_tok).reductions;
            for (var r = 0; r < reductions.size(); r++) {
              var red = reductions.get(r);
              if (red.rule.position !== 0)
                R.push(new ReductionItem(v, red.rule, red.rule.position, red.f, z));
            }
          } else {
            w = new GSSNode(/*labelled*/k);
            w.parentSetId = U_i1.id;
            U_i1.add(w);
            // console.log("Added " + w + " to U[" + (i + 1) + "] ==> " + U_i1);
            this.addLink(/*from*/w, /*to*/v, /*labelled*/z);

            var actions = this.getActions(k, next_tok);
            // console.log("next_tok = " + next_tok.toString(true) + ", k = " + k + ", actions = " + JSON.stringify(actions));
            if (actions !== undefined) {
              success = true;
              var ph = actions.push;
              if (ph !== undefined) {
                var sp = new ShiftPair(w, ph);
                // console.log("Pushing " + sp + " onto Q'");
                Qprime.push(sp);
              }
              var reductions = actions.reductions;
              // console.log("Reductions for k = " + k + " next_tok = " + next_tok + " are " + reductions);
              for (var r = 0; r < reductions.size(); r++) {
                var red = reductions.get(r);
                // console.log("red.f = " + red.f + ", red.rule.position = " + red.rule.position);
                if (red.rule.position !== 0) {
                  R.push(new ReductionItem(v, red.rule, red.rule.position, red.f, z));
                }
              }
              for (var r = 0; r < reductions.size(); r++) {
                var red = reductions.get(r);
                if (red.rule.position === 0) {
                  // the label here is irrelevant, because m == 0 means the rest of the rule derives EPSILON
                  R.push(new ReductionItem(w, red.rule, 0, red.f, EPSILON)); 
                }
              }
              // console.log("R = ");
              // R.debugPrint();
            } else {
              // Possibly shouldn't throw?
              // throw("No actions found in state " + k + " for token " + next_tok.toString(true) + " at " +
              //      next_tok.pos.toString(true));
            }
          }
        }
        while (Qprime.length > 0)
          Q.push(Qprime.shift());
        // console.log("At the end of shifter(" + i + "), Q = ");
        // Q.debugPrint();
      }
      return success;
    },

    addChildren: function(rule, y, kids, f, pos) {
      var lambda = kids.slice(0);
      if (f !== 0)
        lambda.push(this.getEpsilonSPPF(f, pos));
      // Find lambda in the kids of y
      function examine(y_rule, y_kids) {
        if (y_rule !== rule) return false;
        if (y_kids.length !== lambda.length) return false;
        for (var i = 0; i < y_kids.length; i++)
          if (y_kids[i] !== lambda[i]) return false;
        return true;
      }
      var found = false;
      if (y.kids) {
        found = examine(y.rule, y.kids);
      } else if (y.ambig) {
        for (var i = 0; i < y.ambig.length; i++)
          if (examine(y.ambig[i].rule, y.ambig[i].kids)) {
            found = true;
            break;
          }
      }
      if (!found)
        y.addChildren(rule, lambda, this);
    },

    getActions: function(state, tok) {
      var tableRow = this.rnTable[state];
      var actions1 = tableRow[tok];
      return actions1;
    },
    
    printSPPFasDot: function() {
      var ret = [];
      ret.push("digraph " + this.name + "_SPPF {");
      ret.push("  rankdir=RL; clusterrank=local;");
      ret.push("  // Nodes");
      for (var i = 0; i < SPPFNode.allNodes.length; i++) {
        var node = SPPFNode.allNodes[i];
        var style = "";
        if (node.inline)
          style = ", style=dashed";
        var label = "SPPFNode #" + node.sppfId;
        if (node.inline)
          label += "\nInlined e-SPPF for " + node.label;
        else
          label += "\nLabel: " + node.label.toString(true);
        if (node.rule)
          label += "\nRule: " + node.rule.toString();
        else if (node.ambig)
          label += "\nMultiple derivations";

        ret.push("  " + node.sppfId + " [label=" + JSON.stringify(label) + style + "];");
        if (node.ambig !== undefined) {
          for (var j = 0; j < node.ambig.length; j++) {
            ret.push("  \"" + node.sppfId + "_" + j 
                     + "\" [label=" + JSON.stringify(node.ambig[j].rule.toString()) +", shape=box];");
          }
        }
      }
      ret.push("  // Edges");
      for (var i = 0; i < SPPFNode.allNodes.length; i++) {
        var node = SPPFNode.allNodes[i];
        if (node.kids !== undefined)
          for (var j = 0; j < node.kids.length; j++)
            ret.push("  " + node.sppfId + " -> " + node.kids[j].sppfId
                     + " [label=\"" + j + "\"];");
        else if (node.ambig !== undefined) {
          for (var j = 0; j < node.ambig.length; j++) {
            ret.push("  " + node.sppfId + " -> \"" + node.sppfId + "_" + j + "\";");
            for (var k = 0; k < node.ambig[j].kids.length; k++)
              ret.push("  \"" + node.sppfId + "_" + j + "\" -> " + node.ambig[j].kids[k].sppfId 
                       + " [label=\"" + k + "\"];");
          }
        }
      }
      ret.push("}");
      return ret.join("\n");
    },

    printGSSasDot: function() {
      var ret = [];
      ret.push("digraph " + this.name + "_GSS {");
      ret.push("  rankdir=RL; clusterrank=local;");
      ret.push("  // Nodes");
      for (var i = 0; i < GSSNode.allNodes.length; i++) {
        var node = GSSNode.allNodes[i];
        ret.push("  " + node.gssId + "[label=" + JSON.stringify(node.toString()) + "];");
      }
      ret.push("  // Ranks");
      for (var i = 0; i < this.U.length; i++) {
        var s = "";
        for (var j = 0; j < this.U[i].size(); j++)
          s += " " + this.U[i].get(j).gssId + ";";
        ret.push("  subgraph cluster" + i + " {");
        ret.push("    rank = same; color=black;");
        if (i > 0)
          ret.push("    label=\"Token " + i + "\"");
        ret.push("    " + s);
        ret.push("  }");
      }
      ret.push("  // Edges");
      for (var i = 0; i < GSSNode.allNodes.length; i++) {
        var node = GSSNode.allNodes[i];
        for (var j = 0; j < node.links.length; j++)
          ret.push("  " + node.gssId + " -> " + node.links[j].prev.gssId 
                   + "[label=" + JSON.stringify(node.links[j].val.toString()) + "]"
                   //+ "[label=" + JSON.stringify(JSON.decycle(node.links[j].val), null, "  ") + "]"
                   + ";");
      }
      ret.push("}");
      return ret.join("\n");
    },

    //////////////////////////////////
    // The RNGLR algorithm
    // Following Scott & Johnstone '06, TOPLAS 28:4
    //////////////////////////////////
    parseRNGLR: function(token_source) {
      if (token_source.isEmpty()) {
        if (this.acceptStates[0])
          return this.getEpsilonSPPF(this.I[this.start], SrcLoc.make(0,0,0,0,0,0));
        else {
          console.log("There are zero tokens available, but the grammar does not accept the empty string");
          return undefined;
        }
      } else {
        var v0 = new GSSNode(0);
        var U0 = new KeyedSet("label", [v0]);
        U0.id = 0;
        v0.parentSetId = U0.id;
        this.U = [];
        this.U[0] = U0;
        var R = new Queue([]);
        var Q = new Queue([]);
        var hasNext = true;
        var cur_tok = token_source.next(); // need to peek at first token
        var actions = this.getActions(0, cur_tok);
        // console.log("Actions[0][" + cur_tok.toString(true) + "] = " + JSON.stringify(actions));
        if (actions !== undefined) {
          var pk = actions.push;
          if (pk !== undefined)
            Q.push(new ShiftPair(v0, pk));
          // console.log("Q = ");
          // Q.debugPrint();
          var reductions = actions.reductions;
          for (var r = 0; r < reductions.size(); r++) {
            var red = reductions.get(r);
            if (red.rule.position === 0)
              // Again, label shouldn't matter because length is 0
              R.push(new ReductionItem(v0, red.rule, 0, red.f, EPSILON));
          }
        }
        // console.log("R = ");
        // R.debugPrint();
        var i = 0;
        // try {
          while (hasNext && this.U[i].size() > 0) {
            var N = new Queue([]);
            // console.log("Phase 1: reducing due to token #" + i + ": " + cur_tok.toString(true));
            while (R.length > 0) {
              this.reducer(this.U, R, Q, N, i, cur_tok, token_source.skippedWhitespace);
            }
            hasNext = token_source.hasNext();
            var next_tok = token_source.next();
            // console.log("Phase 2: shifting token #" + i + ": " + cur_tok.toString(true));
            hasNext = this.shifter(this.U, R, Q, N, i, cur_tok, next_tok) && hasNext;
            if (hasNext) {
              cur_tok = next_tok;
            } else {
              token_source.unshiftToken(cur_tok);
            }
            i++;
          }
          // console.log("DONE WITH LOOP, i = " + i 
          //             + ", last token = " + cur_tok.toString(true) + "@" + cur_tok.pos.toString(true)
          //             + ", hasNext = " + hasNext + ", final set emptied out: " + (this.U[i].size() == 0));
          if (!hasNext) i--;
          //        console.log("Finalizing: i = " + i + " and U[i] = " + this.U[i]);
          for (var acc = 0; acc < this.acceptStates.length; acc++) {
            if (this.acceptStates[acc]) {
              //console.log("Searching for " + acc);
              var t = this.U[i].itemForKey(acc);
              if (t !== undefined) {
                //console.log("Parse success!");
                var link = undefined;
                for (var j = 0; j < t.links.length; j++) {
                  if (t.links[j].prev === v0) {
                    link = t.links[j];
                    break;
                  }
                }
                if (link !== undefined) {
                  return link.val;
                } else
                  console.log("Couldn't find correct link in " + JSON.stringify(JSON.decycle(t), null, "  "));
              } else {
                //console.log("Parse failure");
              }
            }
          }
          // // Collect error information
          // if (i > 0) {
          //   var acc = undefined;
          //   for (var j = 0; j < this.U[i - 1].size(); j++) {
          //     var head = this.U[i - 1].get(j);
          //     console.log("For token " + i + ", " + cur_tok + ", head is in state " + head.label);
          //     acc = this.plausibleTokensForState(head.label, acc);
          //   }
          //   throw(acc);
          // }
        // } catch(e) {
        //   console.log(e);
        //   return undefined;
        // }
      }
    },

    plausibleTokensForState: function(state, ret) {
      if (ret === undefined)
        ret = {};
      for (var j = 0; j < this.tokens.size(); j++) {
        var tok = this.tokens.get(j);
        var actions = this.getActions(state, tok);
        if (tok !== EPSILON && actions !== undefined && 
            (actions.push !== undefined || (actions.reductions !== undefined && actions.reductions.size() > 0))) {
          console.log("In state " + state + " for token " + tok + ", actions = " + JSON.stringify(actions.reductions.elements));
          ret[tok] = true;
        }
      }
      return ret;
    },

    constructAllParses: function(sppfNode, semActions) {
      if (sppfNode === undefined) return undefined;
      if (sppfNode.label instanceof Token) {
        return [sppfNode.label];
      }
      var options = undefined;
      if (sppfNode.ambig)
        options = sppfNode.ambig;
      else
        options = [{kids: sppfNode.kids, rule: sppfNode.rule}];
      var ret = [];
      for (var i = 0; i < options.length; i++) {
        var kids = options[i].kids;
        var rule = options[i].rule;
        var kidsParses = [];
        for (var j = 0; j < kids.length; j++) {
          if (kids[j].rule === undefined && kids[j].ambig === undefined && kids[j].inline === true) {
            for (var k = 0; k < kids[j].kids.length; k++) {
              kidsParses.push([this.applyAction(kids[j].kids[k].rule, kids[j].kids[k].kids, kids[j].kids[k].pos, semActions)]);
            }
          } else if (kids[j].rule === undefined && kids[j].kids !== undefined && kids[j].label.indexOf(',') > -1) {
            for (var k = 0; k < kids[j].kids.length; k++) {
              kidsParses.push(this.constructAllParses(kids[j].kids[k], semActions));
            }
          } else {
            kidsParses.push(this.constructAllParses(kids[j], semActions));
          }
        }
        const thiz = this;
        ret = ret.concat(this.cartesian(kidsParses, 0, [], 
                                        function(kids) { return thiz.applyAction(rule, kids, sppfNode.pos, semActions); }));
      }
      return ret;
    },
    cartesian: function(arrays, idx, arr, callback) {
      if (arrays.length == idx) return callback(arr);
      var ret = [];
      for (var i = 0; i < arrays[idx].length; i++) {
        ret = ret.concat(this.cartesian(arrays, idx+1, arr.concat(arrays[idx][i]), callback));
      }
      return ret;
    },

    countAllParses: function(sppfNode) {
      if (sppfNode === undefined) return 0;
      var todo = [[[sppfNode]]]; // stack of alternate lists of children
      var count = [[[]], [[]]]; // stack of sums of factors
      while (todo.length > 0) {
        var top = todo[todo.length - 1];
        var topCount = count[count.length - 1];
        if (top.length === 0) { // done with all parses of a given node
          todo.pop();
          count.pop();
          var tot = 0;
          for (var i = 0; i < topCount.length; i++) {
            var prod = 1;
            for (var j = 0; j < topCount[i].length; j++)
              prod *= topCount[i][j];
            tot += prod;
          }
          var newTopCount = count[count.length - 1];
          newTopCount[newTopCount.length - 1].push(tot);
        } else if (top[top.length - 1].length === 0) { // done with one alternative
          top.pop();
          if (top.length > 0) {
            topCount.push([]);
          }
        } else { 
          var node = top[top.length - 1].pop();
          if (node.label instanceof Token) {
            topCount[topCount.length - 1].push(1);
          } else if (node.ambig && node.ambig.length > 0) {
            count.push([[]]);
            todo.push(node.ambig.map(function(d) { return d.kids.slice(0); }));
          } else if (node.kids && node.kids.length > 0) {
            count.push([[]]);
            todo.push([node.kids.slice(0)]);
          }
        }
      }
      if (count.length > 0 && count[0].length > 0 && count[0][0].length > 0)
        return count[0][0][0];
      else
        throw count;
    },

    constructUniqueParse: function(sppfNode, semActions) {
      if (sppfNode === undefined) return undefined;
      // Each stack item is a pair {todo, done}, where todo is a list of children
      // in reverse order (so that pop goes from left-to-right in actual tree order)
      // and done is a list of children in tree order
      // If there are nodes todo:
      //   We examine the pop()ed node from stack[TOP].todo:
      //     if it has kids, we push a new stack item
      //     otherwise, we move it over
      //   Otherwise we reduce
      var stack = [{todo: [sppfNode], done: []}];
      while (stack.length > 0 && stack[0].todo.length > 0) {
        var curr = stack[stack.length - 1];
        if (curr.todo.length > 0) { 
          var next = curr.todo[curr.todo.length - 1];
          if (next.label instanceof Token) {
            curr.todo.pop();
            curr.done.push(next.label);
          } else if (next.ambig) {
            throw("Not a unique parse");
          } else if (next.rule === undefined && next.label.indexOf(',') > -1) {
            curr.todo.pop();
            for (var k = next.kids.length - 1; k >= 0; k--)
              curr.todo.unshift(next.kids[k]);
          } else if (next.kids.length == 0) {
            // Optimization for nullary nonterminals
            curr.todo.pop();
            curr.done.push(this.applyAction(next.rule, [], next.pos, semActions))
          } else {
            stack.push({todo: next.kids.slice(0).reverse(), done: []});
          }
        } else {
          if (stack.length > 1) {
            stack.pop();
            var prev = stack[stack.length - 1];
            var toReduce = prev.todo.pop();
            if (toReduce.rule === undefined) {
              function jsonPos(key, value) {
                if (key === "pos") { return "SrcLoc(" + value.toString(true) + ")"; }
                else { return value; }
              }
              throw("Cannot find a reduction rule on " + JSON.stringify(toReduce, jsonPos, "  "));
            } else {
              prev.done.push(this.applyAction(toReduce.rule, curr.done, toReduce.pos, semActions));
            }
          }
        }
      }
      return stack[0].done[0];
    },

    constructNextParse: function(sppfNode, semActions, directions) {
      if (sppfNode === undefined) return undefined;
      // Directions contains an array of pairs {choice, of}
      // saying which index choice (out of how many choices) at an ambig node
      // was taken by the previous parse.
      // To compute the next parse, remove all trailing pairs for which choice == of,
      // then increment the last remaining choice
      var newDirs = [];
      if (directions) {
        var lastIndex = directions.length - 1;
        while (lastIndex >= directions[lastIndex].choice == directions[lastIndex].of)
          lastIndex--;
        if (lastIndex < 0) return undefined;
        for (var i = 0; i < lastIndex; i++)
          newDirs[i] = directions[i];
        newDirs[lastIndex] = {choice: directions[i].choice + 1, of: directions[i].of};
      }
      var stack = [{todo: [sppfNode], done: []}];
      var curDir = 0;
      while (stack.length > 0 && stack[0].todo.length > 0) {
        var curr = stack[stack.length - 1];
        if (curr.todo.length > 0) {
          var next = curr.todo[curr.todo.length - 1];
          if (next.label instanceof Token) {
            curr.todo.pop();
            curr.done.push(next.label);
          } else if (next.rule === undefined && next.label.indexOf(',') > -1) {
            curr.todo.pop();
            for (var k = next.kids.length - 1; k >= 0; k--)
              curr.todo.unshift(next.kids[k]);
          } else if (next.ambig) {
            if (curDir < newDirs.length) {
              next = next.ambig[newDirs[curDir++].choice];
            } else {
              newDirs.push({choice: 0, of: next.ambig.length})
              next = next.ambig[0];
            }
            if (next.kids.length == 0) {
              // Optimization for nullary nonterminals
              curr.todo.pop();
              curr.done.push(this.applyAction(next.rule, [], next.pos, semActions))
            } else {
              stack.push({todo: next.kids.slice(0).reverse(), done: []});
            }
          } else if (next.kids.length == 0) {
            // Optimization for nullary nonterminals
            curr.todo.pop();
            curr.done.push(this.applyAction(next.rule, [], next.pos, semActions))
          } else {
            stack.push({todo: next.kids.slice(0).reverse(), done: []});
          }
        } else {
          if (stack.length > 1) {
            stack.pop();
            var prev = stack[stack.length - 1];
            var toReduce = prev.todo.pop();
            if (toReduce.rule === undefined) {
              function jsonPos(key, value) {
                if (key === "pos") { return "SrcLoc(" + value.toString(true) + ")"; }
                else { return value; }
              }
              throw("Cannot find a reduction rule on " + JSON.stringify(toReduce, jsonPos, "  "));
            } else {
              prev.done.push(this.applyAction(toReduce.rule, curr.done, toReduce.pos, semActions));
            }
          }
        }
      }
      return {parse: stack[0].done[0], directions: newDirs};
    },
    checkPositionContainment: function(sppfNode) {
      if (sppfNode === undefined) return undefined;
      var violations = [];
      //var worklist = [sppfNode];
      function helper(node) {
        var pos = node.pos;
        if (node.kids) {
          for (var i = 0; i < node.kids.length; i++) {
            var kidPos = node.kids[i].pos;
            if (kidPos.startChar < pos.startChar || kidPos.endChar > pos.endChar) {
              violations.push(node);
              break;
            }
          }
        } else if (node.ambig) {
          for (var i = 0; i < node.ambig.length; i++) {
            var kids = node.ambig[i].kids;
            var shouldBreak = false
            for (var j = 0; j < kids.length; j++) {
              var kidPos = kids[j].pos;
              if (kidPos.startChar < pos.startChar || kidPos.endChar > pos.endChar) {
                violations.push(node);
                shouldBreak = true;
                break;
              }
            }
            if (shouldBreak) break;
          }
        }
      }
      helper(sppfNode);
      if (violations.length > 0) return violations;
      return false;
    },

    computeRequiredNullableParts: function() {
      // The I dictionary is an index of all nullable nonterminals and (nonempty) strings of 
      // nonterminals that appear as right-hand tails in rules in the grammar.
      // The eSPPFs table is a dictionary indexed first by I value and second by position.
      // We already ensure that position objects are singletons, and this second-level
      // dictionary ensures that e-SPPFs are singletons too, for each position in the 
      // parse tree for which they are needed.  This helps ensure that finding existing links
      // doesn't create duplicates and therefore does't cause duplicate parses, later.
      allowNull = true;
      this.I = {};
      this.I[EPSILON] = 0;
      this.eSPPFs = [];
      this.eSPPFs[0] = {null: new SPPFNode(EPSILON, null)};
      // Initialize all eSPPFs to empty nodes
      for (var name in this.rules) {
        if (this.derivable[name][EPSILON] !== true) continue;
        var name_eSPPF = new SPPFNode(name, null);
        this.I[name] = this.eSPPFs.length;
        this.eSPPFs.push({null: name_eSPPF});
      }
      // Compute the e-closure of the rules
      for (var name in this.rules) {
        if (this.derivable[name][EPSILON] !== true) continue;
        var rules_name = this.rules[name];
        var name_eSPPF = this.eSPPFs[this.I[name]].null;
        for (var i = 0; i < rules_name.length; i++) {
          var rule = rules_name[i];
          if (this.computeFirstOfStrings(rule.symbols).contains(EPSILON)) {
            var kids = [];
            for (var j = 0; j < rule.symbols.length; j++) {
              kids.push(this.eSPPFs[this.I[rule.symbols[j]]].null);
            }
            name_eSPPF.addChildren(rule, kids, this);
          }
        }
      }
      // Compute required nullable parts
      for (var name in this.rules) {
        var rules_name = this.rules[name];
        for (var i = 0; i < rules_name.length; i++) {
          var rule = rules_name[i];
          for (var j = 1/*note: not 0*/; j < rule.symbols.length; j++) {
            var slice = rule.symbols.slice(j)
            if (this.computeFirstOfStrings(slice).contains(EPSILON) && this.I[slice] === undefined) {
              var eSPPF_slice = new SPPFNode("" + slice, null);
              eSPPF_slice.inline = true;
              var kids = [];
              for (var k = 0; k < slice.length; k++)
                kids[k] = this.eSPPFs[this.I[slice[k]]].null;
              eSPPF_slice.kids = kids;
              this.I[slice] = this.eSPPFs.length;
              this.eSPPFs.push({null: eSPPF_slice});
            }
          }
        }
      }
      allowNull = false;
    },
    getI: function(rule) {
      var ret = undefined;
      if (rule.position === 0) ret = this.I[rule.name];
      else if (rule.position === rule.symbols.length) ret = this.I[EPSILON];
      else ret = this.I[rule.symbols.slice(rule.position)];
      return ret;
    },
    getEpsilonSPPF: function(i, pos) {
      function find(node, cache) {
        for (var i = 0; i < cache.length; i++) {
          if (cache[i].key === node) {
            return cache[i].value;
          }
        }
        return undefined;
      }
      function clone(node, cache) {
        var ret = find(node, cache);
        if (ret !== undefined) return ret;
        ret = {};
        cache.push({key: node, value: ret});
        ret.sppfId = node.sppfId;
        ret.name = node.name;
        ret.label = node.label;
        ret.pos = pos;
        ret.toString = node.toString;
        ret.rule = node.rule;
        ret.inline = node.inline;
        if (node.kids !== undefined) {
          ret.kids = [];
          for (var i = 0; i < node.kids.length; i++) {
            ret.kids[i] = clone(node.kids[i], cache);
          }
        } else if (node.ambig !== undefined) {
          ret.ambig = [];
          for (var i = 0; i < node.ambig.length; i++) {
            var kids = [];
            ret.ambig.push({kids: kids, rule: node.ambig[i].rule});
            for (var j = 0; j < node.ambig[i].kids.length; j++) {
              kids[j] = clone(node.ambig[i].kids[j], cache);
            }
          }
        }
        return ret;
      }
      var byI = this.eSPPFs[i];
      var ret = byI[pos];
      if (ret === undefined)
        ret = byI[pos] = clone(byI[null], []);
      return ret;
    },

    computeRNTable: function() {
      const thiz = this;
      function initTables(index) {
        var tableRow = thiz.rnTable[index];
        if (tableRow === undefined)
          tableRow = thiz.rnTable[index] = {};
        for (var k = 0; k < thiz.atoms.size(); k++) {
          if (tableRow[thiz.atoms.get(k)] === undefined)
            tableRow[thiz.atoms.get(k)] = {push: undefined, reductions: new KeyedSet("key")};
        }
      }
      

      initTables(0);
      // This doesn't seem to be needed, because we always explicitly shift the EOF token
      // if (this.derivable[this.start][EPSILON] === true) {
      //   this.acceptStates[0] = true;
      //   this.rnTable[0][EOF].accept = true;
      // }
      for (var i = 0; i < this.states.size(); i++) {
        var state_i = this.states.get(i);
        initTables(i);
        // console.log("State " + i + " = " + state_i.toString());
        var full_state = this.completeClosure(state_i);
        // console.log("FullState " + i + " = " + full_state.toString());
        for (var j = 0; j < full_state.coreSize(); j++) {
          var rule_j = full_state.getCore(j);
          if (rule_j.name === this.start) {
            if (rule_j.position === rule_j.symbols.length && full_state.getLookaheads(j).contains(EOF)) {
              this.acceptStates[i] = true;
              this.rnTable[i][EOF].accept = true;
            }
          } else {
            if (this.computeFollowAtPosition(rule_j, rule_j.position).contains(EPSILON)) {
              var lookaheads = full_state.getLookaheads(j);
              for (var k = 0; k < lookaheads.size(); k++) {
                if (this.rnTable[i][lookaheads.get(k)] === undefined) {
                  throw("Can't get rnTable actions for i = " + i + " and symbol = " + lookaheads.get(k) + " in rule " + rule_j.toString(true));
                }
                this.rnTable[i][lookaheads.get(k)].reductions.add(new ReduceAction(rule_j, this.getI(rule_j)));
              }
            }
          }
        }
      }
    },

    //////////////////////////////////
    // 


    //////////////////////////////////
    // Algorithm 4.13 (p242-243) in Dragon book
    computeStateKernels: function() {
      var init_rule = this.rules[this.start][0].withLookahead(EOF);
      this.init_set = new LR1Set([init_rule]);
      this.completeClosure(this.init_set, true);
      var kernelStates = new SetOfSets([this.init_set], LR1Set.equals);
      this.rnTable = [];
      // Step 1
      var worklist = new Queue([this.init_set]);
      var state_num = -1;
      while (worklist.length > 0) {
        var set = worklist.shift();
        state_num++;
        this.rnTable[state_num] = undefined;
        for (var j = 0; j < this.atoms.size(); j++) {
          var atom_j = this.atoms.get(j);
          var new_set = this.computeGotoKernel(state_num, set, atom_j);
          if (new_set.coreSize() > 0) {
            var gotoStateNum = undefined;
            if (kernelStates.add(new_set)) {
              gotoStateNum = kernelStates.size() - 1;
              // console.log("\nAdded new_set at index " + gotoStateNum + ": " + new_set.toString() + "\n");
              // console.log("Added new_set at index " + gotoStateNum);
              worklist.push(new_set);
            } else {
              gotoStateNum = kernelStates.indexOf(new_set);
              // console.log("Set already exists at index " + gotoStateNum + ": " + new_set.toString());
            }
            // console.log(state_num + ":" + set + " goes to " + gotoStateNum + ":" + new_set + " via symbol " + atom_j);
            var tableRow = this.rnTable[state_num];
            if (tableRow === undefined)
              tableRow = this.rnTable[state_num] = {};
            var tableCell = tableRow[atom_j];
            if (tableCell === undefined)
              tableCell = tableRow[atom_j] = {push: undefined, reductions: new KeyedSet("key")};
            if (tableCell.push !== undefined && tableCell.push !== gotoStateNum)
              throw ("Already have a push action for atom " + atom_j + " in state " + state_num + ": supposed to goto state " + tableCell.push + " and now need to go to " + gotoStateNum);
            tableCell.push = gotoStateNum;
          }
        }
      }
      console.log("Done with step 1");
      // console.log("There are " + kernelStates.size() + " kernel states");
      // console.log(kernelStates.toString(true));
      // Step 2
      this.states = [];
      var spontLookaheads = {}; // Map from goto state number -> rule id -> setOf(lookaheads)
      var propLookaheads = {}; // Map from state number -> goto state num -> rule id -> setOf(rule ids)
      for (var i = 0; i < kernelStates.size(); i++) {
        this.states.push(new LR1Set());
        spontLookaheads[i] = {};
        propLookaheads[i] = {};
      }
      init_rule = this.rules[this.start][0];
      spontLookaheads[0][init_rule.id] = new KeyedSet("key", [EOF]);
      for (var i = 0; i < kernelStates.size(); i++) {
        // if (i > 0 && i % 100 == 0) { console.log("Processing state " + i); }
        this.applyLookaheads(spontLookaheads, propLookaheads, kernelStates.get(i), i, this.atoms.get(j));
      }
      console.log("Done with step 2");
      // Step 3
      var allLookaheads = {}; // Map from goto state num -> rule id -> setOf(lookaheads)
      for (var i = 0; i < kernelStates.size(); i++) {
        allLookaheads[i] = {};
        for (var j in spontLookaheads[i]) {
          // console.log("i = " + i + ", j = " + j + ", spontLookaheads[i][j] = " + spontLookaheads[i][j]);
          allLookaheads[i][j] = new KeyedSet(spontLookaheads[i][j]);
        }
      }
      console.log("Done with step 3");
      // Step 4
      // console.log("\n\n\n");
      function printSets(k, v) {
        if (v instanceof KeyedSet || v instanceof IntSet || v instanceof LR1Set)
          return v.toString();
        else
          return v;
      }
      // console.log("spontLookaheads = " + JSON.stringify(spontLookaheads, printSets, "  "));
      // console.log("propLookaheads = " + JSON.stringify(propLookaheads, printSets, "  "));
      var changed = true;
      var pass = 0;
      while (changed) {
        changed = false;
        pass++;
        for (var i = 0; i < kernelStates.size(); i++) {
          var state_i = kernelStates.get(i);
          var rnTable_i = this.rnTable[i];
          for (var x in rnTable_i) {
            var gotoState = rnTable_i[x].push;
            if (gotoState !== undefined) {
              for (var j = 0; j < state_i.coreSize(); j++) {
                var rule_j = state_i.getCore(j);
                var prop = propLookaheads[i][gotoState] ? propLookaheads[i][gotoState][rule_j.id] : undefined;
                var look = allLookaheads[i][rule_j.id];
                if (prop !== undefined && look !== undefined) {
                  // console.log("Propagating " + look.toString() + " from state " + i + " to all rules " + prop.toString() + " in state " + gotoState);
                  for (var k = 0; k < prop.size(); k++) {
                    var id_k = prop.get(k);
                    if (allLookaheads[gotoState][id_k] === undefined)
                      allLookaheads[gotoState][id_k] = new KeyedSet("key");
                    changed = allLookaheads[gotoState][id_k].merge(look) || changed;
                  }
                }
              }
            }
          }
        }
      }
      console.log("Done with step 4");
      // console.log("allLookaheads = " + JSON.stringify(allLookaheads, printSets, "  "));
      // console.log("All rules:")
      // for (var r in RuleFactory.byId)
      //   console.log(r + ": " + RuleFactory.byId[r]);
      // Step 5 -- expand
      for (var i = 0; i < kernelStates.size(); i++) {
        var kernelState_i = kernelStates.get(i);
        var state_i = this.states[i];
        for (var j = 0; j < kernelState_i.coreSize(); j++) {
          var rule_j = kernelState_i.getCore(j);
          var lookahead = allLookaheads[i][rule_j.id];
          // console.log("Lookaheads in state " + i + " for rule #" + rule_j.id + " " + rule_j.toString(true) + ": " + lookahead);
          if (lookahead) {
            state_i.addRuleWithLookaheads(rule_j, lookahead);
            // for (var k = 0; k < lookahead.size(); k++)
            //   state_i.addRule(RuleFactory.make(rule_j.name, rule_j.symbols, lookahead.get(k), rule_j.position));
          }
        }
      }
      this.states = new SetOfSets(this.states, LR1Set.equals);
    },

    //////////////////////////////////
    // Algorithm 4.12 (p242) in Dragon book
    applyLookaheads: function(spont, prop, rule_set, set_num) {
      // console.log("-----------------------------\nRuleSet #" + set_num + " = " + rule_set);
      for (var i = 0; i < rule_set.coreSize(); i++) {
        var rule = rule_set.getCore(i);
        var jPrime_rule = RuleFactory.make(rule.name, rule.symbols, HASH, rule.position);
        var jPrime = this.closureCache[jPrime_rule];
        if (jPrime === undefined)
          jPrime = this.closureCache[jPrime_rule] = this.completeClosure(new LR1Set([jPrime_rule]), true);
        // console.log("\nClosure(" + jPrime_rule.toString(true) + ") = " + jPrime.toString());
        for (var a = 0; a < this.atoms.size(); a++) {
          var symbol = this.atoms.get(a);
          if (this.rnTable[set_num] === undefined || this.rnTable[set_num][symbol] === undefined) {
            continue;
          }
          var goto_set_num = this.rnTable[set_num][symbol].push;
          // console.log("GOTO(" + set_num + ", " + symbol + ") = " + goto_set_num);
          
          for (var j = 0; j < jPrime.coreSize(); j++) {
            var rule_j = jPrime.getCore(j);
            if (rule_j.position < rule_j.symbols.length && rule_j.symbols[rule_j.position].toString() == symbol) {
              var lookaheads = jPrime.getLookaheads(j);
              if (lookaheads !== undefined) {
                for (var k = 0; k < lookaheads.size(); k++) {
                  if (lookaheads.get(k) !== HASH) {
                    var new_rule = RuleFactory.make(rule_j.name, rule_j.symbols, undefined, rule_j.position + 1);
                    if (spont[goto_set_num][new_rule.id] === undefined)
                      spont[goto_set_num][new_rule.id] = new KeyedSet("key");
                    if (spont[goto_set_num][new_rule.id].add(lookaheads.get(k))) {
                      // console.log("Added " + lookaheads.get(k) + " to rule " + new_rule + " in set " + goto_set_num);
                    }
                  } else {
                    var new_rule = RuleFactory.make(rule_j.name, rule_j.symbols, undefined, rule_j.position + 1);
                    if (prop[set_num][goto_set_num] === undefined)
                      prop[set_num][goto_set_num] = {};
                    if (prop[set_num][goto_set_num][rule.id] === undefined)
                      prop[set_num][goto_set_num][rule.id] = new IntSet();
                    if (prop[set_num][goto_set_num][rule.id].add(new_rule.id)) {
                      // console.log("Propagating from " + rule + " in state " + set_num + " to " + new_rule + " in state " + goto_set_num);
                    }
                  }
                }
              }
            }
          }
        }
      }
    },




    printTables: function() {
      var ret = "";
      for (var i = 0; i < this.rnTable.length; i++) {
        var str_action = ""
        rnTable_i = this.rnTable[i];
        if (rnTable_i === undefined) {
          var state = this.states.get(i);
          ret += "No actions in state #" + i + ":" + (state ? state.toString() : "undefined!") + "\n";
          continue;
        }
        for (var j = 0; j < this.atoms.size(); j++) {
          actions = this.rnTable[i][this.atoms.get(j)]
          if (actions.accept)
            str_action += "\n    On " + this.atoms.get(j) + ", accept";
          if (actions.push !== undefined)
            str_action += "\n    On " + this.atoms.get(j) + ", " + actions.push;
          if (actions.reductions && actions.reductions.size() > 0)
            str_action += "\n    On " + this.atoms.get(j) + ", " + actions.reductions;
        }
        var s = "In state #" + i + ":" + this.states.get(i).toString();
        if (this.acceptStates[i])
          s += " (ACCEPT STATE)";
        if (str_action)
          s += "\n  Actions:" + str_action;
        if (s !== "") s += "\n";
        ret += s;
      }
      return ret;
    },

    checkForCycles: function() {
      var cyclic = []
      for (var name in this.rules)
        if (this.derivable[name][name])
          cyclic.push(name);
      if (cyclic.length === 0) return false;
      return cyclic;
    }

    // //////////////////////////////////
    // // A LALR(1) ambiguity is a state/token pair that has multiple enabled actions
    // // Returns a list of warning messages
    // //////////////////////////////////
    // checkForLALRAmbiguity: function() {
    //   var ambiguities = []
    //   for (var i = 0; i < this.rnTable.length; i++) {
    //     var tableRow = this.rnTable[i];
    //     for (var name in tableRow) {
    //       if (tableRow.hasOwnProperty(name)) {
    //         var actions = tableRow[name];
    //         if (actions.size() > 1) {
    //           ambiguities.push("In state #" + i + ", conflicting actions on token " + name + ": " + actions);
    //         }
    //       }
    //     }
    //   }
    //   return ambiguities;
    // },

  }


  return {
    Atom: Atom,
    Nonterm: Nonterm,
    Token: Token,
    Rule: Rule,
    Grammar: Grammar,
    SetOfSets: SetOfSets,
    EOF: EOF,
    EPSILON: EPSILON,
    SrcLoc: SrcLoc
  };
});

define('js/../../../lib/jglr/jglr',["./rnglr"], function(E) {
  const SrcLoc = E.SrcLoc

  function Tokenizer(ignore_ws, Tokens) {
    this.ignore_ws = ignore_ws;
    this.Tokens = Tokens;
  }
  Tokenizer.prototype.isEOF = function(tok) { return tok === E.EOF; }
  Tokenizer.prototype.tokenizeFrom = function(str) {
    this.str = str;
    this.curLine = 1;
    this.curCol = 0;
    this.pos = 0;
    this.len = str.length;
    delete this.curTok;
    delete E.EOF.pos;
    SrcLoc.reset();
  }
  const STICKY_REGEXP = ''; //(function() { try { new RegExp("", 'y'); return 'y' } catch(e) { return ''; }})();

  Tokenizer.prototype.hasNext = function() { return this.pos <= this.len; }
  Tokenizer.prototype.isEmpty = function() { return this.length == 0; }
  if (STICKY_REGEXP === 'y') {
    Tokenizer.prototype.positionTokenRegexp = function(tok) { tok.val.lastIndex = this.pos; };
    Tokenizer.prototype.updateString = function(match) { };
    Tokenizer.prototype.updatePosition = function(tok, match) { this.pos = tok.val.lastIndex; };
  } else {
    Tokenizer.prototype.positionTokenRegexp = function(tok) { };
    Tokenizer.prototype.updateString = function(match) { this.str = this.str.slice(match[0].length); };
    Tokenizer.prototype.updatePosition = function(tok, match) { this.pos += match[0].length; };
  }
  Tokenizer.prototype.makeToken = function (tok_type, s, pos) { 
    var t = new E.Token(tok_type, s);
    t.pos = pos;
    return t;
  }
  Tokenizer.prototype.postProcessMatch = function(tok, match) { return tok.name; }
  Tokenizer.prototype.unshiftToken = function(prev_tok) { this.curTok = prev_tok; }
  Tokenizer.prototype.next = function() {
    delete this.skippedWhitespace;
    while (this.hasNext()) { // Surround the tokenizer loop...
      if (this.pos == this.len) { 
        this.pos++; 
        E.EOF.pos = SrcLoc.make(this.curLine, this.curCol, this.pos, this.curLine, this.curCol, this.pos);
        this.curTok = E.EOF;
        return E.EOF; 
      }
      for (var i = 0; i < this.Tokens.length; i++) {
        var tok = this.Tokens[i];
        this.positionTokenRegexp(tok);
        var match = tok.val.exec(this.str);
        if (match !== null) {
          var tok_type = this.postProcessMatch(tok, match);
          this.updateString(match);
          var p = this.pos;
          var l = this.curLine;
          var c = this.curCol;
          var s = match[0];
          var lines = s.split("\n").length - 1; // From jsPerf, this is UNBELIEVABLY much faster than the prior implementation
          this.updatePosition(tok, match);
          this.curLine += lines;
          if (lines === 0)
            this.curCol += s.length;
          else
            this.curCol = s.length - s.lastIndexOf("\n") - 1;
          if (this.ignore_ws && (tok_type === "WS" || tok_type === "COMMENT")) {
            // ... in case we're ignoring whitespace
            this.skippedWhitespace = SrcLoc.make(l, c, p, this.curLine, this.curCol, this.pos);
            break;
          }
          var t = this.makeToken(tok_type, s, SrcLoc.make(l, c, p, this.curLine, this.curCol, this.pos));
          this.curTok = t;
          return t;
        }
      }
    }
  }

  return {
    'Tokenizer': Tokenizer,
    'STICKY_REGEXP': STICKY_REGEXP,
    'Atom': E.Atom,
    'Nonterm': E.Nonterm,
    'Token': E.Token,
    'Rule': E.Rule,
    'Grammar': E.Grammar,
    'SetOfSets': E.SetOfSets,
    'EOF': E.EOF,
    'EPSILON': E.EPSILON,
    'SrcLoc': E.SrcLoc
  };
});

define('js/pyret-tokenizer',["../../../lib/jglr/jglr"], function(E) {
  const Grammar = E.Grammar
  const Nonterm = E.Nonterm
  const Token = E.Token
  const SrcLoc = E.SrcLoc
  const GenTokenizer = E.Tokenizer;
  const STICKY_REGEXP = E.STICKY_REGEXP;

  const escapes = new RegExp("^(.*?)\\\\([\\\\\"\'nrt]|u[0-9A-Fa-f]{1,4}|x[0-9A-Fa-f]{1,2}|[0-7]{1,3}|[\r\n]{1,2})");
  function fixEscapes(s) {
    var ret = "";
    var match = escapes.exec(s);
    while (match !== null) {
      var esc = match[2];
      ret += match[1];
      s = s.slice(match[0].length);
      if (esc === "\n") {}
      else if (esc === "\r") {}
      else if (esc === "\n\r") {}
      else if (esc === "\r\n") {}
      else if (esc === "n") { ret += "\n"; }
      else if (esc === "r") { ret += "\r"; }
      else if (esc === "t") { ret += "\t"; }
      else if (esc === "\"") { ret += "\""; }
      else if (esc === "'") { ret += "'"; }
      else if (esc === "\\") { ret += "\\"; }
      else if (esc[0] === 'u') { ret += String.fromCharCode(parseInt(esc.slice(1), 16)); }
      else if (esc[0] === 'x') { ret += String.fromCharCode(parseInt(esc.slice(1), 16)); }
      else { ret += String.fromCharCode(parseInt(esc.slice(2), 8)); }
      match = escapes.exec(s);
    }
    ret += s;
    return ret;
  }

  function Tokenizer(ignore_ws, Tokens) {
    GenTokenizer.call(this, ignore_ws, Tokens);
    this.parenIsForExp = true; // initialize this at the beginning of file to true
  }
  Tokenizer.prototype = Object.create(GenTokenizer.prototype);
  Tokenizer.prototype.tokenizeFrom = function(str) {
    GenTokenizer.prototype.tokenizeFrom.call(this, str);
    this.parenIsForExp = true;
  }
  Tokenizer.prototype.makeToken = function (tok_type, s, pos) { 
    if (tok_type === "STRING") s = fixEscapes(s);
    else if (tok_type === "LONG_STRING") tok_type = "STRING";
    return GenTokenizer.prototype.makeToken(tok_type, s, pos);
  }
  Tokenizer.prototype.postProcessMatch = function(tok, match) {
    var tok_type = tok.name;
    if (tok_type === "PAREN?") {
      for (var j = 0; j < this.Tokens.length; j++) {
        if (STICKY_REGEXP !== '') {
          var oldIndex = this.Tokens[j].val.lastIndex;
          this.Tokens[j].val.lastIndex = 0;
        }
        var op = this.Tokens[j].val.exec(match[0]);
        if (STICKY_REGEXP !== '') {
          this.Tokens[j].val.lastIndex = oldIndex;
        }
        if (op !== null) {
          tok_type = this.Tokens[j].name;
          if (tok_type == "LPAREN?")
            tok_type = this.parenIsForExp ? "PARENSPACE" : "PARENNOSPACE";
          break;
        }
      }
    } else if (tok_type == "LPAREN?") {
      tok_type = this.parenIsForExp ? "PARENSPACE" : "PARENNOSPACE";
    }
    this.parenIsForExp = !!tok.parenIsForExp;
    return tok_type;
  }



  function kw(str) { return "^(?:" + str + ")(?![-_a-zA-Z0-9])"; }
  function anyOf(strs) { return "(?:" + strs.join("|") + ")(?![-_a-zA-Z0-9])"; }
  const operator_regex_str = anyOf(["\\+", "-", "\\*", "/", "<=", ">=", "==", "<>", "%",
                                    "<", ">", "and", "or", "is", "raises"]);
  const name = new RegExp("^[_a-zA-Z][-_a-zA-Z0-9]*", STICKY_REGEXP);
  const number = new RegExp("^-?[0-9]+(?:\\.[0-9]+)?", STICKY_REGEXP);
  const rational = new RegExp("^-?[0-9]+/[0-9]+", STICKY_REGEXP);
  const parenparen = new RegExp("^\\((?=\\()", STICKY_REGEXP); // NOTE: Don't include the following paren
  const opparen = new RegExp("^" + operator_regex_str + "(?=\\()", STICKY_REGEXP); // NOTE: likewise
  const spaceparen = new RegExp("^\\s+\\(", STICKY_REGEXP);
  const ws = new RegExp("^\\s+", STICKY_REGEXP);
  const comment = new RegExp("^#.*(?:\\n|\\r|\\r\\n|\\n\\r|$)", STICKY_REGEXP)
  const bar = new RegExp("^\\|", STICKY_REGEXP);
  const langle = new RegExp("^<", STICKY_REGEXP);
  const rangle = new RegExp("^>", STICKY_REGEXP);
  const lbrack = new RegExp("^\\[", STICKY_REGEXP);
  const rbrack = new RegExp("^\\]", STICKY_REGEXP);
  const lbrace = new RegExp("^\\{", STICKY_REGEXP);
  const rbrace = new RegExp("^\\}", STICKY_REGEXP);
  const lparen = new RegExp("^\\(", STICKY_REGEXP);
  const rparen = new RegExp("^\\)", STICKY_REGEXP);
  const period = new RegExp("^\\.", STICKY_REGEXP);
  const bang = new RegExp("^!", STICKY_REGEXP);
  const percent = new RegExp("^%", STICKY_REGEXP);
  const comma = new RegExp("^,", STICKY_REGEXP);
  const thinarrow = new RegExp("^->", STICKY_REGEXP);
  const thickarrow = new RegExp("^=>", STICKY_REGEXP);
  const coloncolon = new RegExp("^::", STICKY_REGEXP);
  const colon = new RegExp("^:", STICKY_REGEXP);
  const caret = new RegExp("^\\^", STICKY_REGEXP);
  const equals = new RegExp("^=", STICKY_REGEXP);
  const colonequals = new RegExp("^:=", STICKY_REGEXP);
  const semi = new RegExp("^;", STICKY_REGEXP);
  const backslash = new RegExp("^\\\\", STICKY_REGEXP);
  const opplus = new RegExp("^\\s+\\+\\s+", STICKY_REGEXP);
  const opminus = new RegExp("^\\s+-\\s+", STICKY_REGEXP);
  const optimes = new RegExp("^\\s+\\*\\s+", STICKY_REGEXP);
  const opdiv = new RegExp("^\\s+/\\s+", STICKY_REGEXP);
  const opleq = new RegExp("^\\s+<=\\s+", STICKY_REGEXP);
  const opgeq = new RegExp("^\\s+>=\\s+", STICKY_REGEXP);
  const opeq = new RegExp("^\\s+==\\s+", STICKY_REGEXP);
  const opneq = new RegExp("^\\s+<>\\s+", STICKY_REGEXP);
  const oplt = new RegExp("^\\s*<\\s*", STICKY_REGEXP);
  const opgt = new RegExp("^\\s*>\\s*", STICKY_REGEXP);
  const opand = new RegExp("^and(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opor = new RegExp("^or(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opis = new RegExp("^is(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opsatisfies = new RegExp("^satisfies(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opraises = new RegExp("^raises(?![-_a-zA-Z0-9])", STICKY_REGEXP);

  const slashable = "[\\\\nrt\"\']"
  const tquot_str =
    new RegExp("^```(?:" +
               "\\\\[01234567]{1,3}" +
               "|\\\\x[0-9a-fA-F]{1,2}" + 
               "|\\\\u[0-9a-fA-f]{1,4}" + 
               "|\\\\[\\\\nrt\"\']" + 
               "|[^`])*```", STICKY_REGEXP); // NOTE: Allow unescaped newlines
  const dquot_str = 
    new RegExp("^\"(?:" +
               "\\\\[01234567]{1,3}" +
               "|\\\\x[0-9a-fA-F]{1,2}" + 
               "|\\\\u[0-9a-fA-f]{1,4}" + 
               "|\\\\[\\\\nrt\"\']" + 
               "|[^\\\\\"\n\r])*\"", STICKY_REGEXP);
  const squot_str = 
    new RegExp("^\'(?:" +
               "\\\\[01234567]{1,3}" +
               "|\\\\x[0-9a-fA-F]{1,2}" + 
               "|\\\\u[0-9a-fA-f]{1,4}" + 
               "|\\\\[\\\\nrt\"\']" + 
               "|[^\\\\\'\n\r])*\'", STICKY_REGEXP);

  const unterminated_string = new RegExp("^[\"\'].*", STICKY_REGEXP);

  const anychar = new RegExp("^[^]", STICKY_REGEXP);
  const Tokens = [
    {name: "PAREN?", val: parenparen, parenIsForExp: true},
    {name: "PAREN?", val: opparen, parenIsForExp: true},
    {name: "PARENSPACE", val: spaceparen, parenIsForExp: true},
    {name: "LPAREN?", val: lparen, parenIsForExp: true},


    {name: "IMPORT", val: new RegExp(kw("import"), STICKY_REGEXP)},
    {name: "PROVIDE-TYPES", val: new RegExp(kw("provide-types"), STICKY_REGEXP)},
    {name: "PROVIDE", val: new RegExp(kw("provide"), STICKY_REGEXP)},
    {name: "AS", val: new RegExp(kw("as"), STICKY_REGEXP)},
    {name: "CONFIRM", val: new RegExp(kw("confirm"), STICKY_REGEXP)},
    {name: "BLESS", val: new RegExp(kw("bless"), STICKY_REGEXP)},
    {name: "NEWTYPE", val: new RegExp(kw("newtype"), STICKY_REGEXP)},
    {name: "TYPE-LET", val: new RegExp(kw("type-let"), STICKY_REGEXP)},
    {name: "TYPE", val: new RegExp(kw("type"), STICKY_REGEXP)},
    {name: "VAR", val: new RegExp(kw("var"), STICKY_REGEXP)},
    {name: "LETREC", val: new RegExp(kw("letrec"), STICKY_REGEXP)},
    {name: "LET", val: new RegExp(kw("let"), STICKY_REGEXP)},
    {name: "FUN", val: new RegExp(kw("fun"), STICKY_REGEXP)},
    {name: "LAM", val: new RegExp(kw("lam"), STICKY_REGEXP)},
    {name: "TRUE", val: new RegExp(kw("true"), STICKY_REGEXP)},
    {name: "FALSE", val: new RegExp(kw("false"), STICKY_REGEXP)},
    {name: "METHOD", val: new RegExp(kw("method"), STICKY_REGEXP)},
    {name: "DOC", val: new RegExp(kw("doc:"), STICKY_REGEXP)},
    {name: "WHERE", val: new RegExp(kw("where:"), STICKY_REGEXP)},
    {name: "CHECKCOLON", val: new RegExp(kw("check:"), STICKY_REGEXP)},
    {name: "CHECK", val: new RegExp(kw("check"), STICKY_REGEXP)},
    {name: "TRY", val: new RegExp(kw("try:"), STICKY_REGEXP)},
    {name: "EXCEPT", val: new RegExp(kw("except"), STICKY_REGEXP)},
    {name: "CASES", val: new RegExp(kw("cases"), STICKY_REGEXP)},
    {name: "WHEN", val: new RegExp(kw("when"), STICKY_REGEXP)},
    {name: "ASKCOLON", val: new RegExp(kw("ask:"), STICKY_REGEXP)},
    {name: "OTHERWISECOLON", val: new RegExp(kw("otherwise:"), STICKY_REGEXP)},
    {name: "IF", val: new RegExp(kw("if"), STICKY_REGEXP)},
    {name: "THENCOLON", val: new RegExp(kw("then:"), STICKY_REGEXP)},
    {name: "ELSECOLON", val: new RegExp(kw("else:"), STICKY_REGEXP)},
    {name: "ELSEIF", val: new RegExp(kw("else if"), STICKY_REGEXP)},
    {name: "ELSE", val: new RegExp(kw("else"), STICKY_REGEXP)},
    {name: "DATA", val: new RegExp(kw("data"), STICKY_REGEXP)},
    {name: "WITH", val: new RegExp(kw("with:"), STICKY_REGEXP)},
    {name: "SHARING", val: new RegExp(kw("sharing:"), STICKY_REGEXP)},
    {name: "SHADOW", val: new RegExp(kw("shadow"), STICKY_REGEXP)},
    {name: "MUTABLE", val: new RegExp(kw("mutable"), STICKY_REGEXP)},
    {name: "CYCLIC", val: new RegExp(kw("cyclic"), STICKY_REGEXP)},
    {name: "DATATYPE", val: new RegExp(kw("datatype"), STICKY_REGEXP)},
    {name: "WITHCONSTRUCTOR", val: new RegExp(kw("with constructor"), STICKY_REGEXP)},
    {name: "GRAPH", val: new RegExp(kw("graph:"), STICKY_REGEXP)},
    {name: "BLOCK", val: new RegExp(kw("block:"), STICKY_REGEXP)},
    {name: "FOR", val: new RegExp(kw("for"), STICKY_REGEXP)},
    {name: "FROM", val: new RegExp(kw("from"), STICKY_REGEXP)},
    {name: "END", val: new RegExp(kw("end"), STICKY_REGEXP)},
    {name: "LAZY", val: new RegExp(kw("lazy"), STICKY_REGEXP)},
    
    {name: "DOT", val: period},
    {name: "BANG", val: bang},
    {name: "PERCENT", val: percent},
    {name: "COMMA", val: comma},
    {name: "THINARROW", val: thinarrow},
    {name: "THICKARROW", val: thickarrow},
    {name: "COLONEQUALS", val: colonequals},
    {name: "COLONCOLON", val: coloncolon},
    {name: "COLON", val: colon},
    {name: "CARET", val: caret},
    {name: "BAR", val: bar},

    {name: "RATIONAL", val: rational},
    {name: "NUMBER", val: number},
    {name: "LONG_STRING", val: tquot_str}, 
    {name: "STRING", val: dquot_str}, 
    {name: "STRING", val: squot_str},

    {name: "PLUS", val: opplus, parenIsForExp: true},
    {name: "DASH", val: opminus, parenIsForExp: true},
    {name: "STAR", val: optimes, parenIsForExp: true},
    {name: "SLASH", val: opdiv, parenIsForExp: true},
    {name: "LEQ", val: opleq, parenIsForExp: true},
    {name: "GEQ", val: opgeq, parenIsForExp: true},
    {name: "EQUALEQUAL", val: opeq, parenIsForExp: true},
    {name: "NEQ", val: opneq, parenIsForExp: true},
    {name: "LT", val: oplt, parenIsForExp: true},
    {name: "GT", val: opgt, parenIsForExp: true},
    {name: "AND", val: opand},
    {name: "OR", val: opor},
    {name: "IS", val: opis},
    {name: "SATISFIES", val: opsatisfies},
    {name: "RAISES", val: opraises},
    {name: "LBRACK", val: lbrack}, 
    {name: "RBRACK", val: rbrack}, 
    {name: "LBRACE", val: lbrace}, 
    {name: "RBRACE", val: rbrace}, 
    {name: "RPAREN", val: rparen}, 
    {name: "LANGLE", val: langle, parenIsForExp: true},
    {name: "RANGLE", val: rangle, parenIsForExp: true},

    {name: "EQUALS", val: equals},

    {name: "COMMENT", val: comment}, 
    {name: "WS", val: ws, parenIsForExp: true},

    {name: "SEMI", val: semi},
    {name: "BACKSLASH", val: backslash},

    {name: "NAME", val: name},

    {name: "UNTERMINATED-STRING", val: unterminated_string},
    {name: "UNKNOWN", val: anychar},
  ];


  return {
    'Tokenizer': new Tokenizer(true, Tokens)
  };
});

define('js/pyret-parser',['../../../lib/jglr/jglr'],
/** @param {{Grammar : {fromSerializable : !Function}, Nonterm : !Object, Token : !Object, Rule : !Object}} E */
function(E) {
  const Grammar = E.Grammar;
  const Nonterm = E.Nonterm;
  const Token = E.Token;
  const Rule = E.Rule;

  var g_json = {
    "start": "START",
    "name": "PyretGrammar",
    "acceptStates": [
      1
    ],
    "mode": "RNGLR",
    "derivable": {
      "program": [
        "prelude",
        "prelude_I0_opt",
        "prelude_I1_opt",
        "prelude_I2_star",
        "ε",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "provide-types-stmt",
        "prelude_I2",
        "import-stmt",
        "block",
        "stmt",
        "block_I0_star",
        "block_I0",
        "type-expr",
        "newtype-expr",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "prelude": [
        "prelude_I0_opt",
        "prelude_I1_opt",
        "prelude_I2_star",
        "ε",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "provide-types-stmt",
        "prelude_I2",
        "import-stmt"
      ],
      "block": [
        "block_I0_star",
        "ε",
        "block_I0",
        "stmt",
        "type-expr",
        "newtype-expr",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "end": [],
      "prelude_I0_opt": [
        "ε",
        "prelude_I0",
        "provide-stmt"
      ],
      "prelude_I1_opt": [
        "ε",
        "prelude_I1",
        "provide-types-stmt"
      ],
      "prelude_I2_star": [
        "ε",
        "prelude_I2",
        "import-stmt"
      ],
      "prelude_I0": [
        "provide-stmt"
      ],
      "provide-stmt": [],
      "prelude_I1": [
        "provide-types-stmt"
      ],
      "provide-types-stmt": [],
      "prelude_I2": [
        "import-stmt"
      ],
      "import-stmt": [],
      "import-stmt_I1": [
        "import-name",
        "import-string"
      ],
      "import-name": [],
      "import-string": [],
      "import-stmt_I2_star": [
        "ε",
        "import-stmt_I2"
      ],
      "import-stmt_I4": [
        "import-name",
        "import-string"
      ],
      "import-stmt_I2": [],
      "stmt": [
        "type-expr",
        "newtype-expr",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "record-ann": [],
      "block_I0_star": [
        "ε",
        "block_I0",
        "stmt",
        "type-expr",
        "newtype-expr",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "block_I0": [
        "stmt",
        "type-expr",
        "newtype-expr",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "type-expr": [],
      "newtype-expr": [],
      "let-expr": [],
      "fun-expr": [],
      "data-expr": [],
      "datatype-expr": [],
      "when-expr": [],
      "var-expr": [],
      "assign-expr": [],
      "check-test": [
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "check-expr": [],
      "graph-expr": [],
      "contract-stmt": [],
      "ann": [
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "toplevel-binding": [
        "binding"
      ],
      "binop-expr": [
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "binding": [],
      "binding_I0_opt": [
        "ε",
        "binding_I0"
      ],
      "binding_I2_opt": [
        "ε",
        "binding_I2"
      ],
      "binding_I0": [],
      "binding_I2": [],
      "toplevel-binding_A1_I0_opt": [
        "ε",
        "toplevel-binding_A1_I0"
      ],
      "noparen-arrow-ann": [],
      "toplevel-binding_A1_I0": [],
      "multi-let-expr": [],
      "multi-let-expr_I1_star": [
        "ε",
        "multi-let-expr_I1",
        "let-binding-elt"
      ],
      "let-binding": [
        "let-expr",
        "var-expr"
      ],
      "multi-let-expr_I1": [
        "let-binding-elt"
      ],
      "let-binding-elt": [],
      "letrec-expr": [],
      "letrec-expr_I1_star": [
        "ε",
        "letrec-expr_I1",
        "letrec-binding"
      ],
      "letrec-expr_I1": [
        "letrec-binding"
      ],
      "letrec-binding": [],
      "type-bind": [],
      "newtype-bind": [],
      "type-let-bind": [
        "type-bind",
        "newtype-bind"
      ],
      "type-let-bind-elt": [],
      "type-let-expr": [],
      "type-let-expr_I1_star": [
        "ε",
        "type-let-expr_I1",
        "type-let-bind-elt"
      ],
      "type-let-expr_I1": [
        "type-let-bind-elt"
      ],
      "bless-expr": [],
      "confirm-expr": [],
      "contract-stmt_I2": [
        "ann",
        "noparen-arrow-ann",
        "record-ann",
        "name-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "fun-header": [],
      "doc-string": [
        "doc-string_I0_opt",
        "ε",
        "doc-string_I0"
      ],
      "where-clause": [
        "where-clause_I0_opt",
        "ε",
        "where-clause_I0"
      ],
      "ty-params": [
        "ty-params_I0_opt",
        "ε",
        "ty-params_I0"
      ],
      "args": [],
      "return-ann": [
        "return-ann_I0_opt",
        "ε",
        "return-ann_I0"
      ],
      "ty-params_I0_opt": [
        "ε",
        "ty-params_I0"
      ],
      "ty-params_I0": [],
      "ty-params_I0_I0": [],
      "ty-params_I0_I1_star": [
        "ε",
        "ty-params_I0_I1",
        "list-ty-param"
      ],
      "ty-params_I0_I3": [],
      "ty-params_I0_I1": [
        "list-ty-param"
      ],
      "list-ty-param": [],
      "args_I0": [],
      "args_I1_opt": [
        "ε",
        "args_I1",
        "binding"
      ],
      "args_I1": [
        "binding"
      ],
      "args_I1_I0_star": [
        "ε",
        "args_I1_I0",
        "list-arg-elt"
      ],
      "args_I1_I0": [
        "list-arg-elt"
      ],
      "list-arg-elt": [],
      "return-ann_I0_opt": [
        "ε",
        "return-ann_I0"
      ],
      "return-ann_I0": [],
      "doc-string_I0_opt": [
        "ε",
        "doc-string_I0"
      ],
      "doc-string_I0": [],
      "where-clause_I0_opt": [
        "ε",
        "where-clause_I0"
      ],
      "where-clause_I0": [],
      "check-op": [],
      "data-mixins": [
        "data-mixins_I0_opt",
        "ε",
        "data-mixins_I0"
      ],
      "data-expr_I5_opt": [
        "ε",
        "data-expr_I5",
        "first-data-variant",
        "variant-constructor"
      ],
      "data-expr_I6_star": [
        "ε",
        "data-expr_I6",
        "data-variant"
      ],
      "data-sharing": [
        "data-sharing_I0_opt",
        "ε",
        "data-sharing_I0"
      ],
      "data-expr_I5": [
        "first-data-variant",
        "variant-constructor"
      ],
      "first-data-variant": [
        "variant-constructor"
      ],
      "data-expr_I6": [
        "data-variant"
      ],
      "data-variant": [],
      "data-mixins_I0_opt": [
        "ε",
        "data-mixins_I0"
      ],
      "data-mixins_I0": [],
      "mixins": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "variant-constructor": [],
      "variant-members": [],
      "data-with": [
        "data-with_I0_opt",
        "ε",
        "data-with_I0"
      ],
      "variant-members_I0": [],
      "variant-members_I1_opt": [
        "ε",
        "variant-members_I1",
        "variant-member",
        "binding"
      ],
      "variant-members_I1": [
        "variant-member",
        "binding"
      ],
      "variant-members_I1_I0_star": [
        "ε",
        "variant-members_I1_I0",
        "list-variant-member"
      ],
      "variant-member": [
        "binding"
      ],
      "variant-members_I1_I0": [
        "list-variant-member"
      ],
      "list-variant-member": [],
      "variant-member_I0_opt": [
        "ε",
        "variant-member_I0"
      ],
      "variant-member_I0": [],
      "data-with_I0_opt": [
        "ε",
        "data-with_I0"
      ],
      "data-with_I0": [],
      "fields": [
        "field"
      ],
      "data-sharing_I0_opt": [
        "ε",
        "data-sharing_I0"
      ],
      "data-sharing_I0": [],
      "mixins_I0_star": [
        "ε",
        "mixins_I0",
        "list-mixin"
      ],
      "mixins_I0": [
        "list-mixin"
      ],
      "list-mixin": [],
      "datatype-expr_I4_opt": [
        "ε",
        "datatype-expr_I4",
        "first-datatype-variant"
      ],
      "datatype-expr_I5_star": [
        "ε",
        "datatype-expr_I5",
        "datatype-variant"
      ],
      "datatype-expr_I4": [
        "first-datatype-variant"
      ],
      "first-datatype-variant": [],
      "datatype-expr_I5": [
        "datatype-variant"
      ],
      "datatype-variant": [],
      "constructor-clause": [],
      "constructor-clause_I1": [],
      "graph-expr_I1_star": [
        "ε",
        "graph-expr_I1",
        "let-expr"
      ],
      "graph-expr_I1": [
        "let-expr"
      ],
      "expr": [
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "binop-expr_I1_star": [
        "ε",
        "binop-expr_I1"
      ],
      "binop-expr_I1": [],
      "binop": [],
      "paren-expr": [],
      "id-expr": [],
      "prim-expr": [
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "lambda-expr": [],
      "method-expr": [],
      "app-expr": [],
      "obj-expr": [],
      "dot-expr": [],
      "bracket-expr": [],
      "get-bang-expr": [],
      "update-expr": [],
      "extend-expr": [],
      "if-expr": [],
      "if-pipe-expr": [],
      "cases-expr": [],
      "for-expr": [],
      "try-expr": [],
      "user-block-expr": [],
      "inst-expr": [],
      "construct-expr": [],
      "bad-expr": [],
      "num-expr": [],
      "frac-expr": [],
      "bool-expr": [],
      "string-expr": [],
      "app-args": [],
      "app-args_I1_opt": [
        "ε",
        "app-args_I1",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-args_I1": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-args_I1_I0_star": [
        "ε",
        "app-args_I1_I0",
        "app-arg-elt"
      ],
      "app-args_I1_I0": [
        "app-arg-elt"
      ],
      "app-arg-elt": [],
      "inst-expr_I1": [],
      "inst-expr_I2_star": [
        "ε",
        "inst-expr_I2",
        "inst-elt"
      ],
      "inst-expr_I4": [],
      "inst-expr_I2": [
        "inst-elt"
      ],
      "inst-elt": [],
      "obj-fields": [
        "obj-field"
      ],
      "obj-fields_I0_star": [
        "ε",
        "obj-fields_I0",
        "list-obj-field"
      ],
      "obj-field": [],
      "obj-fields_I2_opt": [
        "ε",
        "obj-fields_I2"
      ],
      "obj-fields_I0": [
        "list-obj-field"
      ],
      "list-obj-field": [],
      "obj-fields_I2": [],
      "key": [],
      "obj-field_A1_I2_opt": [
        "ε",
        "obj-field_A1_I2"
      ],
      "obj-field_A1_I2": [],
      "fields_I0_star": [
        "ε",
        "fields_I0",
        "list-field"
      ],
      "field": [],
      "fields_I2_opt": [
        "ε",
        "fields_I2"
      ],
      "fields_I0": [
        "list-field"
      ],
      "list-field": [],
      "fields_I2": [],
      "construct-modifier": [
        "ε"
      ],
      "construct-expr_I4_opt": [
        "ε",
        "construct-expr_I4",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "construct-expr_I4": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "construct-expr_I4_I0_star": [
        "ε",
        "construct-expr_I4_I0",
        "list-elt"
      ],
      "construct-expr_I4_I0": [
        "list-elt"
      ],
      "list-elt": [],
      "if-expr_I4_star": [
        "ε",
        "if-expr_I4",
        "else-if"
      ],
      "if-expr_I5_opt": [
        "ε",
        "if-expr_I5"
      ],
      "if-expr_I4": [
        "else-if"
      ],
      "else-if": [],
      "if-expr_I5": [],
      "if-pipe-expr_I1_star": [
        "ε",
        "if-pipe-expr_I1",
        "if-pipe-branch"
      ],
      "if-pipe-expr_I2_opt": [
        "ε",
        "if-pipe-expr_I2"
      ],
      "if-pipe-expr_I1": [
        "if-pipe-branch"
      ],
      "if-pipe-branch": [],
      "if-pipe-expr_I2": [],
      "cases-expr_I1": [],
      "cases-expr_I6_star": [
        "ε",
        "cases-expr_I6",
        "cases-branch"
      ],
      "cases-expr_I7_opt": [
        "ε",
        "cases-expr_I7"
      ],
      "cases-expr_I6": [
        "cases-branch"
      ],
      "cases-branch": [],
      "cases-expr_I7": [],
      "cases-branch_I2_opt": [
        "ε",
        "cases-branch_I2",
        "args"
      ],
      "cases-branch_I2": [
        "args"
      ],
      "for-bind": [],
      "for-bind-elt": [],
      "for-expr_I3_opt": [
        "ε",
        "for-expr_I3",
        "for-bind"
      ],
      "for-expr_I3": [
        "for-bind"
      ],
      "for-expr_I3_I0_star": [
        "ε",
        "for-expr_I3_I0",
        "for-bind-elt"
      ],
      "for-expr_I3_I0": [
        "for-bind-elt"
      ],
      "try-expr_I3": [],
      "name-ann": [],
      "arrow-ann": [],
      "app-ann": [],
      "pred-ann": [],
      "dot-ann": [],
      "record-ann_A0_I1_opt": [
        "ε",
        "record-ann_A0_I1",
        "ann-field"
      ],
      "record-ann_A0_I1": [
        "ann-field"
      ],
      "record-ann_A0_I1_I0_star": [
        "ε",
        "record-ann_A0_I1_I0",
        "list-ann-field"
      ],
      "ann-field": [],
      "record-ann_A0_I1_I0": [
        "list-ann-field"
      ],
      "list-ann-field": [],
      "noparen-arrow-ann_I0_opt": [
        "ε",
        "noparen-arrow-ann_I0",
        "ann",
        "record-ann",
        "name-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "noparen-arrow-ann_I0": [
        "ann",
        "record-ann",
        "name-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "noparen-arrow-ann_I0_I0_star": [
        "ε",
        "noparen-arrow-ann_I0_I0",
        "arrow-ann-elt"
      ],
      "noparen-arrow-ann_I0_I0": [
        "arrow-ann-elt"
      ],
      "arrow-ann-elt": [],
      "arrow-ann_I0": [],
      "arrow-ann_I1_opt": [
        "ε",
        "arrow-ann_I1",
        "ann",
        "record-ann",
        "name-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "arrow-ann_I1": [
        "ann",
        "record-ann",
        "name-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "arrow-ann_I1_I0_star": [
        "ε",
        "arrow-ann_I1_I0",
        "arrow-ann-elt"
      ],
      "arrow-ann_I1_I0": [
        "arrow-ann-elt"
      ],
      "app-ann_I0": [
        "name-ann",
        "dot-ann"
      ],
      "app-ann_I1": [],
      "app-ann_I2_star": [
        "ε",
        "app-ann_I2",
        "app-ann-elt"
      ],
      "app-ann_I4": [],
      "app-ann_I2": [
        "app-ann-elt"
      ],
      "app-ann-elt": [],
      "pred-ann_I2": [],
      "START": [
        "program",
        "ε",
        "prelude",
        "prelude_I0_opt",
        "prelude_I1_opt",
        "prelude_I2_star",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "provide-types-stmt",
        "prelude_I2",
        "import-stmt",
        "block",
        "stmt",
        "block_I0_star",
        "block_I0",
        "type-expr",
        "newtype-expr",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "type-let-expr",
        "bless-expr",
        "confirm-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ]
    },
    "rulesByOldId": {
      "0": {
        "name": "program",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "1": {
        "name": "end",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "END"
          }
        ]
      },
      "2": {
        "name": "end",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SEMI"
          }
        ]
      },
      "3": {
        "name": "prelude",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I2_star"
          }
        ]
      },
      "4": {
        "name": "prelude_I0_opt",
        "position": 0,
        "symbols": []
      },
      "5": {
        "name": "prelude_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0"
          }
        ]
      },
      "6": {
        "name": "prelude_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "provide-stmt"
          }
        ]
      },
      "7": {
        "name": "prelude_I1_opt",
        "position": 0,
        "symbols": []
      },
      "8": {
        "name": "prelude_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I1"
          }
        ]
      },
      "9": {
        "name": "prelude_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "provide-types-stmt"
          }
        ]
      },
      "10": {
        "name": "prelude_I2_star",
        "position": 0,
        "symbols": []
      },
      "11": {
        "name": "prelude_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I2"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I2_star"
          }
        ]
      },
      "12": {
        "name": "prelude_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt"
          }
        ]
      },
      "13": {
        "name": "import-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I1"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "14": {
        "name": "import-stmt_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "15": {
        "name": "import-stmt_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "16": {
        "name": "import-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I4"
          }
        ]
      },
      "17": {
        "name": "import-stmt_I2_star",
        "position": 0,
        "symbols": []
      },
      "18": {
        "name": "import-stmt_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt_I2"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          }
        ]
      },
      "19": {
        "name": "import-stmt_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "20": {
        "name": "import-stmt_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "21": {
        "name": "import-stmt_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "22": {
        "name": "import-name",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "23": {
        "name": "import-string",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "24": {
        "name": "provide-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "25": {
        "name": "provide-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "26": {
        "name": "provide-types-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE-TYPES"
          },
          {
            "type": "Nonterm",
            "name": "record-ann"
          }
        ]
      },
      "27": {
        "name": "provide-types-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE-TYPES"
          },
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "28": {
        "name": "block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "29": {
        "name": "block_I0_star",
        "position": 0,
        "symbols": []
      },
      "30": {
        "name": "block_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0"
          },
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "31": {
        "name": "block_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "32": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-expr"
          }
        ]
      },
      "33": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "newtype-expr"
          }
        ]
      },
      "34": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "35": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fun-expr"
          }
        ]
      },
      "36": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr"
          }
        ]
      },
      "37": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr"
          }
        ]
      },
      "38": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "when-expr"
          }
        ]
      },
      "39": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "40": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "assign-expr"
          }
        ]
      },
      "41": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-test"
          }
        ]
      },
      "42": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr"
          }
        ]
      },
      "43": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr"
          }
        ]
      },
      "44": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "contract-stmt"
          }
        ]
      },
      "45": {
        "name": "type-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "TYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "46": {
        "name": "newtype-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NEWTYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "47": {
        "name": "let-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "48": {
        "name": "binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "49": {
        "name": "binding_I0_opt",
        "position": 0,
        "symbols": []
      },
      "50": {
        "name": "binding_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0"
          }
        ]
      },
      "51": {
        "name": "binding_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "52": {
        "name": "binding_I2_opt",
        "position": 0,
        "symbols": []
      },
      "53": {
        "name": "binding_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I2"
          }
        ]
      },
      "54": {
        "name": "binding_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "55": {
        "name": "toplevel-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "56": {
        "name": "toplevel-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "57": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 0,
        "symbols": []
      },
      "58": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0"
          }
        ]
      },
      "59": {
        "name": "toplevel-binding_A1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "60": {
        "name": "multi-let-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LET"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "61": {
        "name": "multi-let-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "62": {
        "name": "multi-let-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "63": {
        "name": "multi-let-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding-elt"
          }
        ]
      },
      "64": {
        "name": "let-binding-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "65": {
        "name": "let-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "66": {
        "name": "let-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "67": {
        "name": "letrec-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LETREC"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "68": {
        "name": "letrec-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "69": {
        "name": "letrec-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "70": {
        "name": "letrec-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-binding"
          }
        ]
      },
      "71": {
        "name": "letrec-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "72": {
        "name": "type-bind",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "73": {
        "name": "newtype-bind",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NEWTYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "74": {
        "name": "type-let-bind",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-bind"
          }
        ]
      },
      "75": {
        "name": "type-let-bind",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "newtype-bind"
          }
        ]
      },
      "76": {
        "name": "type-let-bind-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-bind"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "77": {
        "name": "type-let-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "TYPE-LET"
          },
          {
            "type": "Nonterm",
            "name": "type-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "type-let-bind"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "78": {
        "name": "type-let-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "79": {
        "name": "type-let-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "type-let-expr_I1_star"
          }
        ]
      },
      "80": {
        "name": "type-let-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-bind-elt"
          }
        ]
      },
      "81": {
        "name": "bless-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BLESS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "82": {
        "name": "confirm-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CONFIRM"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "83": {
        "name": "contract-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "contract-stmt_I2"
          }
        ]
      },
      "84": {
        "name": "contract-stmt_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "85": {
        "name": "contract-stmt_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "86": {
        "name": "fun-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "fun-header"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "87": {
        "name": "fun-header",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "88": {
        "name": "ty-params",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_opt"
          }
        ]
      },
      "89": {
        "name": "ty-params_I0_opt",
        "position": 0,
        "symbols": []
      },
      "90": {
        "name": "ty-params_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0"
          }
        ]
      },
      "91": {
        "name": "ty-params_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I3"
          }
        ]
      },
      "92": {
        "name": "ty-params_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "93": {
        "name": "ty-params_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "94": {
        "name": "ty-params_I0_I1_star",
        "position": 0,
        "symbols": []
      },
      "95": {
        "name": "ty-params_I0_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "96": {
        "name": "ty-params_I0_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ty-param"
          }
        ]
      },
      "97": {
        "name": "ty-params_I0_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "98": {
        "name": "ty-params_I0_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "99": {
        "name": "list-ty-param",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "100": {
        "name": "args",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "101": {
        "name": "args_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "102": {
        "name": "args_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "103": {
        "name": "args_I1_opt",
        "position": 0,
        "symbols": []
      },
      "104": {
        "name": "args_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1"
          }
        ]
      },
      "105": {
        "name": "args_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "106": {
        "name": "args_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "107": {
        "name": "args_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "108": {
        "name": "args_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-arg-elt"
          }
        ]
      },
      "109": {
        "name": "list-arg-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "110": {
        "name": "return-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0_opt"
          }
        ]
      },
      "111": {
        "name": "return-ann_I0_opt",
        "position": 0,
        "symbols": []
      },
      "112": {
        "name": "return-ann_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0"
          }
        ]
      },
      "113": {
        "name": "return-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "114": {
        "name": "doc-string",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0_opt"
          }
        ]
      },
      "115": {
        "name": "doc-string_I0_opt",
        "position": 0,
        "symbols": []
      },
      "116": {
        "name": "doc-string_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0"
          }
        ]
      },
      "117": {
        "name": "doc-string_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DOC"
          },
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "118": {
        "name": "where-clause",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0_opt"
          }
        ]
      },
      "119": {
        "name": "where-clause_I0_opt",
        "position": 0,
        "symbols": []
      },
      "120": {
        "name": "where-clause_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0"
          }
        ]
      },
      "121": {
        "name": "where-clause_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WHERE"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "122": {
        "name": "check-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECK"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "123": {
        "name": "check-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECKCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "124": {
        "name": "check-test",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "check-op"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "125": {
        "name": "check-test",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "126": {
        "name": "data-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "127": {
        "name": "data-expr_I5_opt",
        "position": 0,
        "symbols": []
      },
      "128": {
        "name": "data-expr_I5_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I5"
          }
        ]
      },
      "129": {
        "name": "data-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-data-variant"
          }
        ]
      },
      "130": {
        "name": "data-expr_I6_star",
        "position": 0,
        "symbols": []
      },
      "131": {
        "name": "data-expr_I6_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "132": {
        "name": "data-expr_I6",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-variant"
          }
        ]
      },
      "133": {
        "name": "data-mixins",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0_opt"
          }
        ]
      },
      "134": {
        "name": "data-mixins_I0_opt",
        "position": 0,
        "symbols": []
      },
      "135": {
        "name": "data-mixins_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0"
          }
        ]
      },
      "136": {
        "name": "data-mixins_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DERIVING"
          },
          {
            "type": "Nonterm",
            "name": "mixins"
          }
        ]
      },
      "137": {
        "name": "variant-constructor",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          }
        ]
      },
      "138": {
        "name": "first-data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "139": {
        "name": "first-data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "140": {
        "name": "data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "141": {
        "name": "data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "142": {
        "name": "variant-members",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "143": {
        "name": "variant-members_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "144": {
        "name": "variant-members_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "145": {
        "name": "variant-members_I1_opt",
        "position": 0,
        "symbols": []
      },
      "146": {
        "name": "variant-members_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1"
          }
        ]
      },
      "147": {
        "name": "variant-members_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "variant-member"
          }
        ]
      },
      "148": {
        "name": "variant-members_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "149": {
        "name": "variant-members_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "150": {
        "name": "variant-members_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-variant-member"
          }
        ]
      },
      "151": {
        "name": "list-variant-member",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "152": {
        "name": "variant-member",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "153": {
        "name": "variant-member_I0_opt",
        "position": 0,
        "symbols": []
      },
      "154": {
        "name": "variant-member_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0"
          }
        ]
      },
      "155": {
        "name": "variant-member_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          }
        ]
      },
      "156": {
        "name": "variant-member_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CYCLIC"
          }
        ]
      },
      "157": {
        "name": "data-with",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0_opt"
          }
        ]
      },
      "158": {
        "name": "data-with_I0_opt",
        "position": 0,
        "symbols": []
      },
      "159": {
        "name": "data-with_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0"
          }
        ]
      },
      "160": {
        "name": "data-with_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WITH"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "161": {
        "name": "data-sharing",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0_opt"
          }
        ]
      },
      "162": {
        "name": "data-sharing_I0_opt",
        "position": 0,
        "symbols": []
      },
      "163": {
        "name": "data-sharing_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0"
          }
        ]
      },
      "164": {
        "name": "data-sharing_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHARING"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "165": {
        "name": "mixins",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "166": {
        "name": "mixins_I0_star",
        "position": 0,
        "symbols": []
      },
      "167": {
        "name": "mixins_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "168": {
        "name": "mixins_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-mixin"
          }
        ]
      },
      "169": {
        "name": "list-mixin",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "170": {
        "name": "datatype-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "171": {
        "name": "datatype-expr_I4_opt",
        "position": 0,
        "symbols": []
      },
      "172": {
        "name": "datatype-expr_I4_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4"
          }
        ]
      },
      "173": {
        "name": "datatype-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-datatype-variant"
          }
        ]
      },
      "174": {
        "name": "datatype-expr_I5_star",
        "position": 0,
        "symbols": []
      },
      "175": {
        "name": "datatype-expr_I5_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "176": {
        "name": "datatype-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-variant"
          }
        ]
      },
      "177": {
        "name": "first-datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "178": {
        "name": "first-datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "179": {
        "name": "datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "180": {
        "name": "datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "181": {
        "name": "constructor-clause",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WITHCONSTRUCTOR"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause_I1"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "182": {
        "name": "constructor-clause_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "183": {
        "name": "constructor-clause_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "184": {
        "name": "var-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "VAR"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "185": {
        "name": "assign-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONEQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "186": {
        "name": "graph-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GRAPH"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "187": {
        "name": "graph-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "188": {
        "name": "graph-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "189": {
        "name": "graph-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "190": {
        "name": "when-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WHEN"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "191": {
        "name": "binop-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "192": {
        "name": "binop-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "193": {
        "name": "binop-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "194": {
        "name": "binop-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          }
        ]
      },
      "195": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PLUS"
          }
        ]
      },
      "196": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DASH"
          }
        ]
      },
      "197": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "198": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SLASH"
          }
        ]
      },
      "199": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LEQ"
          }
        ]
      },
      "200": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GEQ"
          }
        ]
      },
      "201": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "EQUALEQUAL"
          }
        ]
      },
      "202": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NEQ"
          }
        ]
      },
      "203": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "204": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "205": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "AND"
          }
        ]
      },
      "206": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "OR"
          }
        ]
      },
      "207": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CARET"
          }
        ]
      },
      "208": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IS"
          }
        ]
      },
      "209": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RAISES"
          }
        ]
      },
      "210": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SATISFIES"
          }
        ]
      },
      "211": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "paren-expr"
          }
        ]
      },
      "212": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          }
        ]
      },
      "213": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prim-expr"
          }
        ]
      },
      "214": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "lambda-expr"
          }
        ]
      },
      "215": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "method-expr"
          }
        ]
      },
      "216": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-expr"
          }
        ]
      },
      "217": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-expr"
          }
        ]
      },
      "218": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-expr"
          }
        ]
      },
      "219": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bracket-expr"
          }
        ]
      },
      "220": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "get-bang-expr"
          }
        ]
      },
      "221": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "update-expr"
          }
        ]
      },
      "222": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "extend-expr"
          }
        ]
      },
      "223": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr"
          }
        ]
      },
      "224": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr"
          }
        ]
      },
      "225": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr"
          }
        ]
      },
      "226": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr"
          }
        ]
      },
      "227": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "try-expr"
          }
        ]
      },
      "228": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "user-block-expr"
          }
        ]
      },
      "229": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr"
          }
        ]
      },
      "230": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr"
          }
        ]
      },
      "231": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr"
          }
        ]
      },
      "232": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-expr"
          }
        ]
      },
      "233": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bless-expr"
          }
        ]
      },
      "234": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "confirm-expr"
          }
        ]
      },
      "235": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr"
          }
        ]
      },
      "236": {
        "name": "bad-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "UNTERMINATED-STRING"
          }
        ]
      },
      "237": {
        "name": "bad-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "UNKNOWN"
          }
        ]
      },
      "238": {
        "name": "paren-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "239": {
        "name": "id-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "240": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "num-expr"
          }
        ]
      },
      "241": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "frac-expr"
          }
        ]
      },
      "242": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bool-expr"
          }
        ]
      },
      "243": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "string-expr"
          }
        ]
      },
      "244": {
        "name": "num-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NUMBER"
          }
        ]
      },
      "245": {
        "name": "frac-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RATIONAL"
          }
        ]
      },
      "246": {
        "name": "bool-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "TRUE"
          }
        ]
      },
      "247": {
        "name": "bool-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FALSE"
          }
        ]
      },
      "248": {
        "name": "string-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "249": {
        "name": "lambda-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LAM"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "250": {
        "name": "method-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "METHOD"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "251": {
        "name": "app-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "app-args"
          }
        ]
      },
      "252": {
        "name": "app-args",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "253": {
        "name": "app-args_I1_opt",
        "position": 0,
        "symbols": []
      },
      "254": {
        "name": "app-args_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1"
          }
        ]
      },
      "255": {
        "name": "app-args_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "256": {
        "name": "app-args_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "257": {
        "name": "app-args_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "258": {
        "name": "app-args_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-arg-elt"
          }
        ]
      },
      "259": {
        "name": "app-arg-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "260": {
        "name": "inst-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I4"
          }
        ]
      },
      "261": {
        "name": "inst-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "262": {
        "name": "inst-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "263": {
        "name": "inst-expr_I2_star",
        "position": 0,
        "symbols": []
      },
      "264": {
        "name": "inst-expr_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "265": {
        "name": "inst-expr_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-elt"
          }
        ]
      },
      "266": {
        "name": "inst-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "267": {
        "name": "inst-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "268": {
        "name": "inst-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "269": {
        "name": "obj-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "270": {
        "name": "obj-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "271": {
        "name": "obj-fields",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "272": {
        "name": "obj-fields_I0_star",
        "position": 0,
        "symbols": []
      },
      "273": {
        "name": "obj-fields_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "274": {
        "name": "obj-fields_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-obj-field"
          }
        ]
      },
      "275": {
        "name": "obj-fields_I2_opt",
        "position": 0,
        "symbols": []
      },
      "276": {
        "name": "obj-fields_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I2"
          }
        ]
      },
      "277": {
        "name": "obj-fields_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "278": {
        "name": "list-obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "279": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "280": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          },
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2_opt"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "281": {
        "name": "obj-field_A1_I2_opt",
        "position": 0,
        "symbols": []
      },
      "282": {
        "name": "obj-field_A1_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2"
          }
        ]
      },
      "283": {
        "name": "obj-field_A1_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "284": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "285": {
        "name": "fields",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "286": {
        "name": "fields_I0_star",
        "position": 0,
        "symbols": []
      },
      "287": {
        "name": "fields_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "288": {
        "name": "fields_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-field"
          }
        ]
      },
      "289": {
        "name": "fields_I2_opt",
        "position": 0,
        "symbols": []
      },
      "290": {
        "name": "fields_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I2"
          }
        ]
      },
      "291": {
        "name": "fields_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "292": {
        "name": "list-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "293": {
        "name": "field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "294": {
        "name": "field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "295": {
        "name": "key",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "296": {
        "name": "key",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "297": {
        "name": "construct-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "construct-modifier"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_opt"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "298": {
        "name": "construct-expr_I4_opt",
        "position": 0,
        "symbols": []
      },
      "299": {
        "name": "construct-expr_I4_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4"
          }
        ]
      },
      "300": {
        "name": "construct-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "301": {
        "name": "construct-expr_I4_I0_star",
        "position": 0,
        "symbols": []
      },
      "302": {
        "name": "construct-expr_I4_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          }
        ]
      },
      "303": {
        "name": "construct-expr_I4_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-elt"
          }
        ]
      },
      "304": {
        "name": "construct-modifier",
        "position": 0,
        "symbols": []
      },
      "305": {
        "name": "construct-modifier",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LAZY"
          }
        ]
      },
      "306": {
        "name": "list-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "307": {
        "name": "dot-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "308": {
        "name": "bracket-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "309": {
        "name": "get-bang-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "310": {
        "name": "extend-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "311": {
        "name": "update-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "312": {
        "name": "if-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "313": {
        "name": "if-expr_I4_star",
        "position": 0,
        "symbols": []
      },
      "314": {
        "name": "if-expr_I4_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "315": {
        "name": "if-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "else-if"
          }
        ]
      },
      "316": {
        "name": "if-expr_I5_opt",
        "position": 0,
        "symbols": []
      },
      "317": {
        "name": "if-expr_I5_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I5"
          }
        ]
      },
      "318": {
        "name": "if-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "319": {
        "name": "else-if",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSEIF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "320": {
        "name": "if-pipe-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "ASKCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "321": {
        "name": "if-pipe-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "322": {
        "name": "if-pipe-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "323": {
        "name": "if-pipe-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-branch"
          }
        ]
      },
      "324": {
        "name": "if-pipe-expr_I2_opt",
        "position": 0,
        "symbols": []
      },
      "325": {
        "name": "if-pipe-expr_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2"
          }
        ]
      },
      "326": {
        "name": "if-pipe-expr_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "OTHERWISECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "327": {
        "name": "if-pipe-branch",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "THENCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "328": {
        "name": "cases-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "329": {
        "name": "cases-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "330": {
        "name": "cases-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "331": {
        "name": "cases-expr_I6_star",
        "position": 0,
        "symbols": []
      },
      "332": {
        "name": "cases-expr_I6_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "333": {
        "name": "cases-expr_I6",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch"
          }
        ]
      },
      "334": {
        "name": "cases-expr_I7_opt",
        "position": 0,
        "symbols": []
      },
      "335": {
        "name": "cases-expr_I7_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I7"
          }
        ]
      },
      "336": {
        "name": "cases-expr_I7",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSE"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "337": {
        "name": "cases-branch",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "cases-branch_I2_opt"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "338": {
        "name": "cases-branch_I2_opt",
        "position": 0,
        "symbols": []
      },
      "339": {
        "name": "cases-branch_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch_I2"
          }
        ]
      },
      "340": {
        "name": "cases-branch_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args"
          }
        ]
      },
      "341": {
        "name": "for-bind",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "342": {
        "name": "for-bind-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "343": {
        "name": "for-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FOR"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "344": {
        "name": "for-expr_I3_opt",
        "position": 0,
        "symbols": []
      },
      "345": {
        "name": "for-expr_I3_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3"
          }
        ]
      },
      "346": {
        "name": "for-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "for-bind"
          }
        ]
      },
      "347": {
        "name": "for-expr_I3_I0_star",
        "position": 0,
        "symbols": []
      },
      "348": {
        "name": "for-expr_I3_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "349": {
        "name": "for-expr_I3_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind-elt"
          }
        ]
      },
      "350": {
        "name": "try-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "TRY"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Token",
            "name": "EXCEPT"
          },
          {
            "type": "Nonterm",
            "name": "try-expr_I3"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "351": {
        "name": "try-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "352": {
        "name": "try-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "353": {
        "name": "user-block-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BLOCK"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "354": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "355": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann"
          }
        ]
      },
      "356": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann"
          }
        ]
      },
      "357": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann"
          }
        ]
      },
      "358": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "pred-ann"
          }
        ]
      },
      "359": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "360": {
        "name": "name-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "361": {
        "name": "record-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_opt"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "362": {
        "name": "record-ann_A0_I1_opt",
        "position": 0,
        "symbols": []
      },
      "363": {
        "name": "record-ann_A0_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1"
          }
        ]
      },
      "364": {
        "name": "record-ann_A0_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann-field"
          }
        ]
      },
      "365": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "366": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "367": {
        "name": "record-ann_A0_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ann-field"
          }
        ]
      },
      "368": {
        "name": "record-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "369": {
        "name": "list-ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "370": {
        "name": "ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "371": {
        "name": "ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "372": {
        "name": "noparen-arrow-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "373": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 0,
        "symbols": []
      },
      "374": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0"
          }
        ]
      },
      "375": {
        "name": "noparen-arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "376": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 0,
        "symbols": []
      },
      "377": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "378": {
        "name": "noparen-arrow-ann_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "379": {
        "name": "arrow-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "380": {
        "name": "arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "381": {
        "name": "arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "382": {
        "name": "arrow-ann_I1_opt",
        "position": 0,
        "symbols": []
      },
      "383": {
        "name": "arrow-ann_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1"
          }
        ]
      },
      "384": {
        "name": "arrow-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "385": {
        "name": "arrow-ann_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "386": {
        "name": "arrow-ann_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "387": {
        "name": "arrow-ann_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "388": {
        "name": "arrow-ann-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "389": {
        "name": "app-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I1"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I4"
          }
        ]
      },
      "390": {
        "name": "app-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "391": {
        "name": "app-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "392": {
        "name": "app-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "393": {
        "name": "app-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "394": {
        "name": "app-ann_I2_star",
        "position": 0,
        "symbols": []
      },
      "395": {
        "name": "app-ann_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "396": {
        "name": "app-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann-elt"
          }
        ]
      },
      "397": {
        "name": "app-ann_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "398": {
        "name": "app-ann_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "399": {
        "name": "app-ann-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "400": {
        "name": "pred-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "PERCENT"
          },
          {
            "type": "Nonterm",
            "name": "pred-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "id-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "401": {
        "name": "pred-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "402": {
        "name": "pred-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "403": {
        "name": "dot-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "404": {
        "name": "START",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "program"
          }
        ]
      },
      "623": {
        "name": "program",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "4846": {
        "name": "prelude",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I2_star"
          }
        ]
      },
      "5056": {
        "name": "prelude_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0"
          }
        ]
      },
      "5093": {
        "name": "prelude_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "provide-stmt"
          }
        ]
      },
      "5380": {
        "name": "program",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "5384": {
        "name": "id-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "5507": {
        "name": "string-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "5562": {
        "name": "block_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "5597": {
        "name": "block",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "5599": {
        "name": "block_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0"
          },
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "5601": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-expr"
          }
        ]
      },
      "5636": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "newtype-expr"
          }
        ]
      },
      "5671": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "5706": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fun-expr"
          }
        ]
      },
      "5741": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr"
          }
        ]
      },
      "5776": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr"
          }
        ]
      },
      "5811": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "when-expr"
          }
        ]
      },
      "5846": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "5881": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "assign-expr"
          }
        ]
      },
      "5916": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-test"
          }
        ]
      },
      "5951": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr"
          }
        ]
      },
      "5986": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr"
          }
        ]
      },
      "6021": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "contract-stmt"
          }
        ]
      },
      "6162": {
        "name": "check-test",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "6297": {
        "name": "toplevel-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "6301": {
        "name": "binding_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0"
          }
        ]
      },
      "6303": {
        "name": "toplevel-binding_A1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "6304": {
        "name": "binding_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "6309": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0"
          }
        ]
      },
      "6311": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr"
          }
        ]
      },
      "6437": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr"
          }
        ]
      },
      "6555": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-expr"
          }
        ]
      },
      "6677": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bless-expr"
          }
        ]
      },
      "6847": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "confirm-expr"
          }
        ]
      },
      "7435": {
        "name": "binop-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "8330": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "paren-expr"
          }
        ]
      },
      "8385": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          }
        ]
      },
      "8440": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prim-expr"
          }
        ]
      },
      "8495": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "lambda-expr"
          }
        ]
      },
      "8550": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "method-expr"
          }
        ]
      },
      "8605": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-expr"
          }
        ]
      },
      "8660": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-expr"
          }
        ]
      },
      "8715": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-expr"
          }
        ]
      },
      "8770": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bracket-expr"
          }
        ]
      },
      "8825": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "get-bang-expr"
          }
        ]
      },
      "8880": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "update-expr"
          }
        ]
      },
      "8935": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "extend-expr"
          }
        ]
      },
      "8990": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr"
          }
        ]
      },
      "9045": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr"
          }
        ]
      },
      "9100": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr"
          }
        ]
      },
      "9155": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr"
          }
        ]
      },
      "9210": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "try-expr"
          }
        ]
      },
      "9265": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "user-block-expr"
          }
        ]
      },
      "9320": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr"
          }
        ]
      },
      "9375": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr"
          }
        ]
      },
      "9430": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "num-expr"
          }
        ]
      },
      "9485": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "frac-expr"
          }
        ]
      },
      "9540": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bool-expr"
          }
        ]
      },
      "9595": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "string-expr"
          }
        ]
      },
      "9650": {
        "name": "num-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NUMBER"
          }
        ]
      },
      "9705": {
        "name": "frac-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RATIONAL"
          }
        ]
      },
      "9760": {
        "name": "bool-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "TRUE"
          }
        ]
      },
      "9815": {
        "name": "bool-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "FALSE"
          }
        ]
      },
      "10669": {
        "name": "prelude",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I2_star"
          }
        ]
      },
      "10877": {
        "name": "prelude_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I1"
          }
        ]
      },
      "10913": {
        "name": "prelude_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "provide-types-stmt"
          }
        ]
      },
      "11208": {
        "name": "provide-stmt",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "12030": {
        "name": "block_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0"
          },
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "12172": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "IS"
          }
        ]
      },
      "12195": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RAISES"
          }
        ]
      },
      "12218": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SATISFIES"
          }
        ]
      },
      "12241": {
        "name": "binding",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "12248": {
        "name": "let-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "12250": {
        "name": "let-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "12316": {
        "name": "multi-let-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "12320": {
        "name": "multi-let-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding-elt"
          }
        ]
      },
      "12383": {
        "name": "letrec-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "12386": {
        "name": "letrec-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-binding"
          }
        ]
      },
      "12393": {
        "name": "type-let-bind",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-bind"
          }
        ]
      },
      "12395": {
        "name": "type-let-bind",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "newtype-bind"
          }
        ]
      },
      "12400": {
        "name": "type-let-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-bind-elt"
          }
        ]
      },
      "12462": {
        "name": "type-let-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "type-let-expr_I1_star"
          }
        ]
      },
      "12676": {
        "name": "ty-params",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_opt"
          }
        ]
      },
      "12678": {
        "name": "ty-params_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0"
          }
        ]
      },
      "12686": {
        "name": "ty-params_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "12688": {
        "name": "ty-params_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "12998": {
        "name": "graph-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "13038": {
        "name": "graph-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "13140": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "13163": {
        "name": "inst-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "13168": {
        "name": "inst-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "13169": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "13196": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "13425": {
        "name": "binop-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "13463": {
        "name": "binop-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "13552": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PLUS"
          }
        ]
      },
      "13575": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "DASH"
          }
        ]
      },
      "13598": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SLASH"
          }
        ]
      },
      "13621": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LEQ"
          }
        ]
      },
      "13644": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GEQ"
          }
        ]
      },
      "13667": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "EQUALEQUAL"
          }
        ]
      },
      "13690": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NEQ"
          }
        ]
      },
      "13713": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "AND"
          }
        ]
      },
      "13736": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "OR"
          }
        ]
      },
      "13759": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "CARET"
          }
        ]
      },
      "13782": {
        "name": "app-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "app-args"
          }
        ]
      },
      "14318": {
        "name": "args_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "14322": {
        "name": "args_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "14326": {
        "name": "key",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "14389": {
        "name": "obj-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "14453": {
        "name": "obj-fields_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "14457": {
        "name": "obj-fields_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-obj-field"
          }
        ]
      },
      "14584": {
        "name": "construct-modifier",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LAZY"
          }
        ]
      },
      "14787": {
        "name": "if-pipe-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "14791": {
        "name": "if-pipe-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-branch"
          }
        ]
      },
      "14795": {
        "name": "cases-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "14800": {
        "name": "cases-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "15173": {
        "name": "prelude",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I2_star"
          }
        ]
      },
      "15208": {
        "name": "prelude_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I2"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I2_star"
          }
        ]
      },
      "15243": {
        "name": "prelude_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt"
          }
        ]
      },
      "15355": {
        "name": "provide-types-stmt",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE-TYPES"
          },
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "15391": {
        "name": "provide-types-stmt",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE-TYPES"
          },
          {
            "type": "Nonterm",
            "name": "record-ann"
          }
        ]
      },
      "15508": {
        "name": "provide-stmt",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "15545": {
        "name": "end",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "END"
          }
        ]
      },
      "15582": {
        "name": "end",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SEMI"
          }
        ]
      },
      "15619": {
        "name": "name-ann",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "15697": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann"
          }
        ]
      },
      "15734": {
        "name": "contract-stmt_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "15811": {
        "name": "contract-stmt_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "15846": {
        "name": "contract-stmt",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "contract-stmt_I2"
          }
        ]
      },
      "15881": {
        "name": "arrow-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "15887": {
        "name": "arrow-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "15897": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "15898": {
        "name": "app-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "15937": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann"
          }
        ]
      },
      "15974": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann"
          }
        ]
      },
      "16011": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "pred-ann"
          }
        ]
      },
      "16048": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "16049": {
        "name": "app-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "16123": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0"
          }
        ]
      },
      "16140": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "16145": {
        "name": "noparen-arrow-ann_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "16247": {
        "name": "assign-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONEQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "16352": {
        "name": "let-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "16387": {
        "name": "check-test",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "check-op"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "16422": {
        "name": "binding",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "16424": {
        "name": "binding_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I2"
          }
        ]
      },
      "16503": {
        "name": "let-binding-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "16507": {
        "name": "multi-let-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "16511": {
        "name": "letrec-binding",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "16569": {
        "name": "letrec-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "16576": {
        "name": "type-let-bind-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-bind"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "16638": {
        "name": "type-let-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "type-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "type-let-expr_I1_star"
          }
        ]
      },
      "16936": {
        "name": "ty-params_I0_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "16938": {
        "name": "ty-params_I0_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ty-param"
          }
        ]
      },
      "16940": {
        "name": "paren-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "17030": {
        "name": "check-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECKCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "17180": {
        "name": "graph-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "GRAPH"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "17215": {
        "name": "graph-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "17386": {
        "name": "app-args_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1"
          }
        ]
      },
      "17390": {
        "name": "app-args_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "17413": {
        "name": "app-args_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-arg-elt"
          }
        ]
      },
      "17445": {
        "name": "binop-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "17483": {
        "name": "binop-expr_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          }
        ]
      },
      "17620": {
        "name": "inst-expr_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "17625": {
        "name": "inst-expr_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-elt"
          }
        ]
      },
      "17630": {
        "name": "dot-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "17806": {
        "name": "get-bang-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "18026": {
        "name": "return-ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0_opt"
          }
        ]
      },
      "18028": {
        "name": "return-ann_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0"
          }
        ]
      },
      "18052": {
        "name": "args_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1"
          }
        ]
      },
      "18057": {
        "name": "args_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "18060": {
        "name": "args_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-arg-elt"
          }
        ]
      },
      "18070": {
        "name": "obj-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "18126": {
        "name": "obj-fields",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "18133": {
        "name": "list-obj-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "18137": {
        "name": "obj-fields_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "18633": {
        "name": "if-pipe-expr_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2"
          }
        ]
      },
      "18636": {
        "name": "if-pipe-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "18835": {
        "name": "user-block-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BLOCK"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "18930": {
        "name": "prelude_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I2"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I2_star"
          }
        ]
      },
      "19002": {
        "name": "import-name",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "19043": {
        "name": "import-stmt_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "19045": {
        "name": "import-stmt_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "19047": {
        "name": "import-string",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "19053": {
        "name": "record-ann",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "19125": {
        "name": "record-ann_A0_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1"
          }
        ]
      },
      "19133": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "19135": {
        "name": "record-ann_A0_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ann-field"
          }
        ]
      },
      "19176": {
        "name": "arrow-ann-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "19258": {
        "name": "noparen-arrow-ann_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "19270": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "19275": {
        "name": "arrow-ann_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "19317": {
        "name": "arrow-ann_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1"
          }
        ]
      },
      "19321": {
        "name": "arrow-ann_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "19326": {
        "name": "app-ann_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "19331": {
        "name": "app-ann_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "19389": {
        "name": "type-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "TYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "19424": {
        "name": "newtype-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "NEWTYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "19462": {
        "name": "binding_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "19474": {
        "name": "toplevel-binding",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "19587": {
        "name": "type-bind",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "19646": {
        "name": "bless-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BLESS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "19701": {
        "name": "confirm-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "CONFIRM"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "19883": {
        "name": "doc-string",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0_opt"
          }
        ]
      },
      "19920": {
        "name": "doc-string_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0"
          }
        ]
      },
      "19994": {
        "name": "fun-header",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "19996": {
        "name": "list-ty-param",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "20002": {
        "name": "ty-params_I0_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "20074": {
        "name": "data-mixins",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0_opt"
          }
        ]
      },
      "20076": {
        "name": "data-mixins_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0"
          }
        ]
      },
      "20225": {
        "name": "var-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "VAR"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "20295": {
        "name": "app-arg-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "20318": {
        "name": "app-args",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "20373": {
        "name": "app-args_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "20375": {
        "name": "app-args_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "20398": {
        "name": "inst-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "20592": {
        "name": "inst-expr_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "20663": {
        "name": "fields_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "20666": {
        "name": "fields_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-field"
          }
        ]
      },
      "20892": {
        "name": "return-ann_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "20904": {
        "name": "list-arg-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "20907": {
        "name": "args",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "20910": {
        "name": "args_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "20913": {
        "name": "args_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "20920": {
        "name": "obj-field_A1_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2"
          }
        ]
      },
      "20922": {
        "name": "obj-fields_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "20924": {
        "name": "obj-fields",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "20926": {
        "name": "obj-fields_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I2"
          }
        ]
      },
      "20928": {
        "name": "obj-field",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "20932": {
        "name": "key",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "21341": {
        "name": "if-pipe-branch",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "THENCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "21437": {
        "name": "if-pipe-expr_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "OTHERWISECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "21440": {
        "name": "if-pipe-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "ASKCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "21557": {
        "name": "for-expr_I3_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind-elt"
          }
        ]
      },
      "21615": {
        "name": "for-expr_I3_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3"
          }
        ]
      },
      "21620": {
        "name": "for-expr_I3_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "21623": {
        "name": "try-expr_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "21626": {
        "name": "try-expr_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "21756": {
        "name": "import-stmt_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt_I2"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          }
        ]
      },
      "21765": {
        "name": "record-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_opt"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "21803": {
        "name": "record-ann_A0_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann-field"
          }
        ]
      },
      "21805": {
        "name": "list-ann-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "21807": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "21809": {
        "name": "dot-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "21848": {
        "name": "pred-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "21850": {
        "name": "pred-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "21889": {
        "name": "noparen-arrow-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "21962": {
        "name": "arrow-ann_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "21964": {
        "name": "arrow-ann_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "22011": {
        "name": "app-ann_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "22016": {
        "name": "app-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann-elt"
          }
        ]
      },
      "22132": {
        "name": "newtype-bind",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "NEWTYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "22327": {
        "name": "doc-string_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "DOC"
          },
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "22364": {
        "name": "fun-header",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "22366": {
        "name": "ty-params_I0",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I3"
          }
        ]
      },
      "22368": {
        "name": "ty-params_I0_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "22370": {
        "name": "ty-params_I0_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "22372": {
        "name": "check-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECK"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "22496": {
        "name": "data-mixins_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "DERIVING"
          },
          {
            "type": "Nonterm",
            "name": "mixins"
          }
        ]
      },
      "22500": {
        "name": "mixins_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "22523": {
        "name": "mixins_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-mixin"
          }
        ]
      },
      "22626": {
        "name": "datatype-expr_I4_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4"
          }
        ]
      },
      "22631": {
        "name": "datatype-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-datatype-variant"
          }
        ]
      },
      "22636": {
        "name": "when-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "WHEN"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "22671": {
        "name": "inst-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "22726": {
        "name": "inst-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "22781": {
        "name": "inst-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I4"
          }
        ]
      },
      "22838": {
        "name": "extend-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "22899": {
        "name": "fields",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "22904": {
        "name": "list-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "22907": {
        "name": "fields_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "22910": {
        "name": "bracket-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "22965": {
        "name": "update-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "23131": {
        "name": "obj-field_A1_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "23215": {
        "name": "construct-expr_I4_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4"
          }
        ]
      },
      "23219": {
        "name": "construct-expr_I4_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          }
        ]
      },
      "23242": {
        "name": "construct-expr_I4_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-elt"
          }
        ]
      },
      "23326": {
        "name": "if-expr_I4_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "23330": {
        "name": "if-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "else-if"
          }
        ]
      },
      "23340": {
        "name": "if-pipe-branch",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "THENCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "23439": {
        "name": "if-pipe-expr_I2",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "OTHERWISECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "23499": {
        "name": "for-bind-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "23558": {
        "name": "for-expr_I3",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "for-bind"
          }
        ]
      },
      "23560": {
        "name": "for-expr_I3_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "23618": {
        "name": "import-stmt",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I1"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "23830": {
        "name": "import-stmt_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt_I2"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          }
        ]
      },
      "23832": {
        "name": "import-stmt_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "23835": {
        "name": "ann-field",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "23837": {
        "name": "ann-field",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "23913": {
        "name": "app-ann-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "24027": {
        "name": "app-ann_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "24032": {
        "name": "multi-let-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "LET"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "24087": {
        "name": "letrec-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "LETREC"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "24142": {
        "name": "type-let-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "TYPE-LET"
          },
          {
            "type": "Nonterm",
            "name": "type-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "type-let-bind"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "24232": {
        "name": "where-clause",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0_opt"
          }
        ]
      },
      "24235": {
        "name": "where-clause_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0"
          }
        ]
      },
      "24238": {
        "name": "where-clause_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "WHERE"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "24241": {
        "name": "first-data-variant",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "24337": {
        "name": "data-expr_I5_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I5"
          }
        ]
      },
      "24343": {
        "name": "data-expr_I5",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-data-variant"
          }
        ]
      },
      "24349": {
        "name": "first-data-variant",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "24355": {
        "name": "list-mixin",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "24378": {
        "name": "mixins",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "24380": {
        "name": "mixins_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "24403": {
        "name": "variant-members_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "24409": {
        "name": "variant-members_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "24415": {
        "name": "variant-constructor",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          }
        ]
      },
      "24447": {
        "name": "first-datatype-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "24459": {
        "name": "first-datatype-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "24509": {
        "name": "datatype-expr_I5_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "24513": {
        "name": "datatype-expr_I5",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-variant"
          }
        ]
      },
      "24518": {
        "name": "field",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "24522": {
        "name": "fields_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "24524": {
        "name": "fields",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "24526": {
        "name": "fields_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I2"
          }
        ]
      },
      "24638": {
        "name": "obj-field",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          },
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2_opt"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "24642": {
        "name": "list-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "24665": {
        "name": "construct-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "construct-modifier"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_opt"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "24720": {
        "name": "construct-expr_I4",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "24722": {
        "name": "construct-expr_I4_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          }
        ]
      },
      "24800": {
        "name": "if-expr_I5_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I5"
          }
        ]
      },
      "24803": {
        "name": "if-expr_I5",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "24806": {
        "name": "if-expr_I4_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "24890": {
        "name": "for-bind",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "25037": {
        "name": "import-stmt_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "25073": {
        "name": "import-stmt_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "25109": {
        "name": "import-stmt",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I4"
          }
        ]
      },
      "25180": {
        "name": "pred-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "PERCENT"
          },
          {
            "type": "Nonterm",
            "name": "pred-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "id-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "25217": {
        "name": "arrow-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "25254": {
        "name": "app-ann_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "25291": {
        "name": "app-ann_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "25328": {
        "name": "app-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I1"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I4"
          }
        ]
      },
      "25365": {
        "name": "fun-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "fun-header"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "25400": {
        "name": "where-clause_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "WHERE"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "25409": {
        "name": "first-data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "25421": {
        "name": "data-with",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0_opt"
          }
        ]
      },
      "25427": {
        "name": "data-with_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0"
          }
        ]
      },
      "25491": {
        "name": "data-expr_I6_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "25496": {
        "name": "data-expr_I6",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-variant"
          }
        ]
      },
      "25514": {
        "name": "first-data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "25522": {
        "name": "variant-members_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1"
          }
        ]
      },
      "25532": {
        "name": "variant-members_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "25537": {
        "name": "variant-members_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-variant-member"
          }
        ]
      },
      "25544": {
        "name": "variant-member_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0"
          }
        ]
      },
      "25547": {
        "name": "variant-member_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          }
        ]
      },
      "25550": {
        "name": "variant-member_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "CYCLIC"
          }
        ]
      },
      "25553": {
        "name": "constructor-clause_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "25555": {
        "name": "constructor-clause_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "25607": {
        "name": "datatype-expr_I5_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "25725": {
        "name": "if-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "25780": {
        "name": "if-expr_I5",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "25783": {
        "name": "else-if",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSEIF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "25853": {
        "name": "cases-expr_I6_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "25857": {
        "name": "cases-expr_I6",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch"
          }
        ]
      },
      "25971": {
        "name": "data-with_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "WITH"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "26027": {
        "name": "data-sharing",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0_opt"
          }
        ]
      },
      "26031": {
        "name": "data-sharing_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0"
          }
        ]
      },
      "26039": {
        "name": "data-expr_I6_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "26044": {
        "name": "data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "26050": {
        "name": "data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "26056": {
        "name": "variant-members",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "26058": {
        "name": "variant-members_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "variant-member"
          }
        ]
      },
      "26061": {
        "name": "list-variant-member",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "26066": {
        "name": "variant-members_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "26071": {
        "name": "variant-member",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "26078": {
        "name": "datatype-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "26083": {
        "name": "datatype-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "26088": {
        "name": "datatype-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26180": {
        "name": "method-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "METHOD"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26239": {
        "name": "else-if",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSEIF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "26310": {
        "name": "cases-expr_I7_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I7"
          }
        ]
      },
      "26313": {
        "name": "cases-expr_I6_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "26462": {
        "name": "data-sharing_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "SHARING"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "26466": {
        "name": "data-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "26472": {
        "name": "data-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "26485": {
        "name": "lambda-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "LAM"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26540": {
        "name": "obj-field",
        "position": 8,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26544": {
        "name": "cases-branch_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args"
          }
        ]
      },
      "26551": {
        "name": "cases-branch_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch_I2"
          }
        ]
      },
      "26556": {
        "name": "cases-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26611": {
        "name": "for-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "FOR"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26666": {
        "name": "try-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "TRY"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Token",
            "name": "EXCEPT"
          },
          {
            "type": "Nonterm",
            "name": "try-expr_I3"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26721": {
        "name": "data-expr",
        "position": 10,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26763": {
        "name": "cases-branch",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "cases-branch_I2_opt"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "26767": {
        "name": "cases-expr_I7",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSE"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "26783": {
        "name": "field",
        "position": 8,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26785": {
        "name": "cases-branch",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "cases-branch_I2_opt"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "26789": {
        "name": "cases-expr_I7",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSE"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "26792": {
        "name": "constructor-clause",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "WITHCONSTRUCTOR"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause_I1"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      }
    },
    "actionsByOldId": {
      "0": "Rule.defaultAction",
      "1": "Rule.defaultAction",
      "2": "Rule.defaultAction",
      "3": "Rule.defaultAction",
      "4": "Rule.Inline",
      "5": "Rule.Inline",
      "6": "Rule.Inline",
      "7": "Rule.Inline",
      "8": "Rule.Inline",
      "9": "Rule.Inline",
      "10": "Rule.Inline",
      "11": "Rule.ListCons(\"prelude_I2\", \"prelude_I2_star\", true)",
      "12": "Rule.Inline",
      "13": "Rule.defaultAction",
      "14": "Rule.Inline",
      "15": "Rule.Inline",
      "16": "Rule.defaultAction",
      "17": "Rule.Inline",
      "18": "Rule.ListCons(\"import-stmt_I2\", \"import-stmt_I2_star\", true)",
      "19": "Rule.Inline",
      "20": "Rule.Inline",
      "21": "Rule.Inline",
      "22": "Rule.defaultAction",
      "23": "Rule.defaultAction",
      "24": "Rule.defaultAction",
      "25": "Rule.defaultAction",
      "26": "Rule.defaultAction",
      "27": "Rule.defaultAction",
      "28": "Rule.defaultAction",
      "29": "Rule.Inline",
      "30": "Rule.ListCons(\"block_I0\", \"block_I0_star\", true)",
      "31": "Rule.Inline",
      "32": "Rule.defaultAction",
      "33": "Rule.defaultAction",
      "34": "Rule.defaultAction",
      "35": "Rule.defaultAction",
      "36": "Rule.defaultAction",
      "37": "Rule.defaultAction",
      "38": "Rule.defaultAction",
      "39": "Rule.defaultAction",
      "40": "Rule.defaultAction",
      "41": "Rule.defaultAction",
      "42": "Rule.defaultAction",
      "43": "Rule.defaultAction",
      "44": "Rule.defaultAction",
      "45": "Rule.defaultAction",
      "46": "Rule.defaultAction",
      "47": "Rule.defaultAction",
      "48": "Rule.defaultAction",
      "49": "Rule.Inline",
      "50": "Rule.Inline",
      "51": "Rule.Inline",
      "52": "Rule.Inline",
      "53": "Rule.Inline",
      "54": "Rule.Inline",
      "55": "Rule.defaultAction",
      "56": "Rule.defaultAction",
      "57": "Rule.Inline",
      "58": "Rule.Inline",
      "59": "Rule.Inline",
      "60": "Rule.defaultAction",
      "61": "Rule.Inline",
      "62": "Rule.ListCons(\"multi-let-expr_I1\", \"multi-let-expr_I1_star\", true)",
      "63": "Rule.Inline",
      "64": "Rule.defaultAction",
      "65": "Rule.defaultAction",
      "66": "Rule.defaultAction",
      "67": "Rule.defaultAction",
      "68": "Rule.Inline",
      "69": "Rule.ListCons(\"letrec-expr_I1\", \"letrec-expr_I1_star\", true)",
      "70": "Rule.Inline",
      "71": "Rule.defaultAction",
      "72": "Rule.defaultAction",
      "73": "Rule.defaultAction",
      "74": "Rule.defaultAction",
      "75": "Rule.defaultAction",
      "76": "Rule.defaultAction",
      "77": "Rule.defaultAction",
      "78": "Rule.Inline",
      "79": "Rule.ListCons(\"type-let-expr_I1\", \"type-let-expr_I1_star\", true)",
      "80": "Rule.Inline",
      "81": "Rule.defaultAction",
      "82": "Rule.defaultAction",
      "83": "Rule.defaultAction",
      "84": "Rule.Inline",
      "85": "Rule.Inline",
      "86": "Rule.defaultAction",
      "87": "Rule.defaultAction",
      "88": "Rule.defaultAction",
      "89": "Rule.Inline",
      "90": "Rule.Inline",
      "91": "Rule.Inline",
      "92": "Rule.Inline",
      "93": "Rule.Inline",
      "94": "Rule.Inline",
      "95": "Rule.ListCons(\"ty-params_I0_I1\", \"ty-params_I0_I1_star\", true)",
      "96": "Rule.Inline",
      "97": "Rule.Inline",
      "98": "Rule.Inline",
      "99": "Rule.defaultAction",
      "100": "Rule.defaultAction",
      "101": "Rule.Inline",
      "102": "Rule.Inline",
      "103": "Rule.Inline",
      "104": "Rule.Inline",
      "105": "Rule.Inline",
      "106": "Rule.Inline",
      "107": "Rule.ListCons(\"args_I1_I0\", \"args_I1_I0_star\", true)",
      "108": "Rule.Inline",
      "109": "Rule.defaultAction",
      "110": "Rule.defaultAction",
      "111": "Rule.Inline",
      "112": "Rule.Inline",
      "113": "Rule.Inline",
      "114": "Rule.defaultAction",
      "115": "Rule.Inline",
      "116": "Rule.Inline",
      "117": "Rule.Inline",
      "118": "Rule.defaultAction",
      "119": "Rule.Inline",
      "120": "Rule.Inline",
      "121": "Rule.Inline",
      "122": "Rule.defaultAction",
      "123": "Rule.defaultAction",
      "124": "Rule.defaultAction",
      "125": "Rule.defaultAction",
      "126": "Rule.defaultAction",
      "127": "Rule.Inline",
      "128": "Rule.Inline",
      "129": "Rule.Inline",
      "130": "Rule.Inline",
      "131": "Rule.ListCons(\"data-expr_I6\", \"data-expr_I6_star\", true)",
      "132": "Rule.Inline",
      "133": "Rule.defaultAction",
      "134": "Rule.Inline",
      "135": "Rule.Inline",
      "136": "Rule.Inline",
      "137": "Rule.defaultAction",
      "138": "Rule.defaultAction",
      "139": "Rule.defaultAction",
      "140": "Rule.defaultAction",
      "141": "Rule.defaultAction",
      "142": "Rule.defaultAction",
      "143": "Rule.Inline",
      "144": "Rule.Inline",
      "145": "Rule.Inline",
      "146": "Rule.Inline",
      "147": "Rule.Inline",
      "148": "Rule.Inline",
      "149": "Rule.ListCons(\"variant-members_I1_I0\", \"variant-members_I1_I0_star\", true)",
      "150": "Rule.Inline",
      "151": "Rule.defaultAction",
      "152": "Rule.defaultAction",
      "153": "Rule.Inline",
      "154": "Rule.Inline",
      "155": "Rule.Inline",
      "156": "Rule.Inline",
      "157": "Rule.defaultAction",
      "158": "Rule.Inline",
      "159": "Rule.Inline",
      "160": "Rule.Inline",
      "161": "Rule.defaultAction",
      "162": "Rule.Inline",
      "163": "Rule.Inline",
      "164": "Rule.Inline",
      "165": "Rule.defaultAction",
      "166": "Rule.Inline",
      "167": "Rule.ListCons(\"mixins_I0\", \"mixins_I0_star\", true)",
      "168": "Rule.Inline",
      "169": "Rule.defaultAction",
      "170": "Rule.defaultAction",
      "171": "Rule.Inline",
      "172": "Rule.Inline",
      "173": "Rule.Inline",
      "174": "Rule.Inline",
      "175": "Rule.ListCons(\"datatype-expr_I5\", \"datatype-expr_I5_star\", true)",
      "176": "Rule.Inline",
      "177": "Rule.defaultAction",
      "178": "Rule.defaultAction",
      "179": "Rule.defaultAction",
      "180": "Rule.defaultAction",
      "181": "Rule.defaultAction",
      "182": "Rule.Inline",
      "183": "Rule.Inline",
      "184": "Rule.defaultAction",
      "185": "Rule.defaultAction",
      "186": "Rule.defaultAction",
      "187": "Rule.Inline",
      "188": "Rule.ListCons(\"graph-expr_I1\", \"graph-expr_I1_star\", true)",
      "189": "Rule.Inline",
      "190": "Rule.defaultAction",
      "191": "Rule.defaultAction",
      "192": "Rule.Inline",
      "193": "Rule.ListCons(\"binop-expr_I1\", \"binop-expr_I1_star\", true)",
      "194": "Rule.Inline",
      "195": "Rule.defaultAction",
      "196": "Rule.defaultAction",
      "197": "Rule.defaultAction",
      "198": "Rule.defaultAction",
      "199": "Rule.defaultAction",
      "200": "Rule.defaultAction",
      "201": "Rule.defaultAction",
      "202": "Rule.defaultAction",
      "203": "Rule.defaultAction",
      "204": "Rule.defaultAction",
      "205": "Rule.defaultAction",
      "206": "Rule.defaultAction",
      "207": "Rule.defaultAction",
      "208": "Rule.defaultAction",
      "209": "Rule.defaultAction",
      "210": "Rule.defaultAction",
      "211": "Rule.defaultAction",
      "212": "Rule.defaultAction",
      "213": "Rule.defaultAction",
      "214": "Rule.defaultAction",
      "215": "Rule.defaultAction",
      "216": "Rule.defaultAction",
      "217": "Rule.defaultAction",
      "218": "Rule.defaultAction",
      "219": "Rule.defaultAction",
      "220": "Rule.defaultAction",
      "221": "Rule.defaultAction",
      "222": "Rule.defaultAction",
      "223": "Rule.defaultAction",
      "224": "Rule.defaultAction",
      "225": "Rule.defaultAction",
      "226": "Rule.defaultAction",
      "227": "Rule.defaultAction",
      "228": "Rule.defaultAction",
      "229": "Rule.defaultAction",
      "230": "Rule.defaultAction",
      "231": "Rule.defaultAction",
      "232": "Rule.defaultAction",
      "233": "Rule.defaultAction",
      "234": "Rule.defaultAction",
      "235": "Rule.defaultAction",
      "236": "Rule.defaultAction",
      "237": "Rule.defaultAction",
      "238": "Rule.defaultAction",
      "239": "Rule.defaultAction",
      "240": "Rule.defaultAction",
      "241": "Rule.defaultAction",
      "242": "Rule.defaultAction",
      "243": "Rule.defaultAction",
      "244": "Rule.defaultAction",
      "245": "Rule.defaultAction",
      "246": "Rule.defaultAction",
      "247": "Rule.defaultAction",
      "248": "Rule.defaultAction",
      "249": "Rule.defaultAction",
      "250": "Rule.defaultAction",
      "251": "Rule.defaultAction",
      "252": "Rule.defaultAction",
      "253": "Rule.Inline",
      "254": "Rule.Inline",
      "255": "Rule.Inline",
      "256": "Rule.Inline",
      "257": "Rule.ListCons(\"app-args_I1_I0\", \"app-args_I1_I0_star\", true)",
      "258": "Rule.Inline",
      "259": "Rule.defaultAction",
      "260": "Rule.defaultAction",
      "261": "Rule.Inline",
      "262": "Rule.Inline",
      "263": "Rule.Inline",
      "264": "Rule.ListCons(\"inst-expr_I2\", \"inst-expr_I2_star\", true)",
      "265": "Rule.Inline",
      "266": "Rule.Inline",
      "267": "Rule.Inline",
      "268": "Rule.defaultAction",
      "269": "Rule.defaultAction",
      "270": "Rule.defaultAction",
      "271": "Rule.defaultAction",
      "272": "Rule.Inline",
      "273": "Rule.ListCons(\"obj-fields_I0\", \"obj-fields_I0_star\", true)",
      "274": "Rule.Inline",
      "275": "Rule.Inline",
      "276": "Rule.Inline",
      "277": "Rule.Inline",
      "278": "Rule.defaultAction",
      "279": "Rule.defaultAction",
      "280": "Rule.defaultAction",
      "281": "Rule.Inline",
      "282": "Rule.Inline",
      "283": "Rule.Inline",
      "284": "Rule.defaultAction",
      "285": "Rule.defaultAction",
      "286": "Rule.Inline",
      "287": "Rule.ListCons(\"fields_I0\", \"fields_I0_star\", true)",
      "288": "Rule.Inline",
      "289": "Rule.Inline",
      "290": "Rule.Inline",
      "291": "Rule.Inline",
      "292": "Rule.defaultAction",
      "293": "Rule.defaultAction",
      "294": "Rule.defaultAction",
      "295": "Rule.defaultAction",
      "296": "Rule.defaultAction",
      "297": "Rule.defaultAction",
      "298": "Rule.Inline",
      "299": "Rule.Inline",
      "300": "Rule.Inline",
      "301": "Rule.Inline",
      "302": "Rule.ListCons(\"construct-expr_I4_I0\", \"construct-expr_I4_I0_star\", true)",
      "303": "Rule.Inline",
      "304": "Rule.defaultAction",
      "305": "Rule.defaultAction",
      "306": "Rule.defaultAction",
      "307": "Rule.defaultAction",
      "308": "Rule.defaultAction",
      "309": "Rule.defaultAction",
      "310": "Rule.defaultAction",
      "311": "Rule.defaultAction",
      "312": "Rule.defaultAction",
      "313": "Rule.Inline",
      "314": "Rule.ListCons(\"if-expr_I4\", \"if-expr_I4_star\", true)",
      "315": "Rule.Inline",
      "316": "Rule.Inline",
      "317": "Rule.Inline",
      "318": "Rule.Inline",
      "319": "Rule.defaultAction",
      "320": "Rule.defaultAction",
      "321": "Rule.Inline",
      "322": "Rule.ListCons(\"if-pipe-expr_I1\", \"if-pipe-expr_I1_star\", true)",
      "323": "Rule.Inline",
      "324": "Rule.Inline",
      "325": "Rule.Inline",
      "326": "Rule.Inline",
      "327": "Rule.defaultAction",
      "328": "Rule.defaultAction",
      "329": "Rule.Inline",
      "330": "Rule.Inline",
      "331": "Rule.Inline",
      "332": "Rule.ListCons(\"cases-expr_I6\", \"cases-expr_I6_star\", true)",
      "333": "Rule.Inline",
      "334": "Rule.Inline",
      "335": "Rule.Inline",
      "336": "Rule.Inline",
      "337": "Rule.defaultAction",
      "338": "Rule.Inline",
      "339": "Rule.Inline",
      "340": "Rule.Inline",
      "341": "Rule.defaultAction",
      "342": "Rule.defaultAction",
      "343": "Rule.defaultAction",
      "344": "Rule.Inline",
      "345": "Rule.Inline",
      "346": "Rule.Inline",
      "347": "Rule.Inline",
      "348": "Rule.ListCons(\"for-expr_I3_I0\", \"for-expr_I3_I0_star\", true)",
      "349": "Rule.Inline",
      "350": "Rule.defaultAction",
      "351": "Rule.Inline",
      "352": "Rule.Inline",
      "353": "Rule.defaultAction",
      "354": "Rule.defaultAction",
      "355": "Rule.defaultAction",
      "356": "Rule.defaultAction",
      "357": "Rule.defaultAction",
      "358": "Rule.defaultAction",
      "359": "Rule.defaultAction",
      "360": "Rule.defaultAction",
      "361": "Rule.defaultAction",
      "362": "Rule.Inline",
      "363": "Rule.Inline",
      "364": "Rule.Inline",
      "365": "Rule.Inline",
      "366": "Rule.ListCons(\"record-ann_A0_I1_I0\", \"record-ann_A0_I1_I0_star\", true)",
      "367": "Rule.Inline",
      "368": "Rule.defaultAction",
      "369": "Rule.defaultAction",
      "370": "Rule.defaultAction",
      "371": "Rule.defaultAction",
      "372": "Rule.defaultAction",
      "373": "Rule.Inline",
      "374": "Rule.Inline",
      "375": "Rule.Inline",
      "376": "Rule.Inline",
      "377": "Rule.ListCons(\"noparen-arrow-ann_I0_I0\", \"noparen-arrow-ann_I0_I0_star\", true)",
      "378": "Rule.Inline",
      "379": "Rule.defaultAction",
      "380": "Rule.Inline",
      "381": "Rule.Inline",
      "382": "Rule.Inline",
      "383": "Rule.Inline",
      "384": "Rule.Inline",
      "385": "Rule.Inline",
      "386": "Rule.ListCons(\"arrow-ann_I1_I0\", \"arrow-ann_I1_I0_star\", true)",
      "387": "Rule.Inline",
      "388": "Rule.defaultAction",
      "389": "Rule.defaultAction",
      "390": "Rule.Inline",
      "391": "Rule.Inline",
      "392": "Rule.Inline",
      "393": "Rule.Inline",
      "394": "Rule.Inline",
      "395": "Rule.ListCons(\"app-ann_I2\", \"app-ann_I2_star\", true)",
      "396": "Rule.Inline",
      "397": "Rule.Inline",
      "398": "Rule.Inline",
      "399": "Rule.defaultAction",
      "400": "Rule.defaultAction",
      "401": "Rule.Inline",
      "402": "Rule.Inline",
      "403": "Rule.defaultAction",
      "404": "Rule.defaultAction"
    },
    "flagsByOldId": {},
    "rules": [
      0,
      1,
      2,
      3,
      4,
      5,
      6,
      7,
      8,
      9,
      10,
      11,
      12,
      13,
      16,
      14,
      15,
      17,
      18,
      19,
      20,
      21,
      22,
      23,
      24,
      25,
      26,
      27,
      28,
      29,
      30,
      31,
      32,
      33,
      34,
      35,
      36,
      37,
      38,
      39,
      40,
      41,
      42,
      43,
      44,
      45,
      46,
      47,
      48,
      49,
      50,
      51,
      52,
      53,
      54,
      55,
      56,
      57,
      58,
      59,
      60,
      61,
      62,
      63,
      64,
      65,
      66,
      67,
      68,
      69,
      70,
      71,
      72,
      73,
      74,
      75,
      76,
      77,
      78,
      79,
      80,
      81,
      82,
      83,
      84,
      85,
      86,
      87,
      88,
      89,
      90,
      91,
      92,
      93,
      94,
      95,
      96,
      97,
      98,
      99,
      100,
      101,
      102,
      103,
      104,
      105,
      106,
      107,
      108,
      109,
      110,
      111,
      112,
      113,
      114,
      115,
      116,
      117,
      118,
      119,
      120,
      121,
      122,
      123,
      124,
      125,
      126,
      127,
      128,
      129,
      130,
      131,
      132,
      133,
      134,
      135,
      136,
      137,
      138,
      139,
      140,
      141,
      142,
      143,
      144,
      145,
      146,
      147,
      148,
      149,
      150,
      151,
      152,
      153,
      154,
      155,
      156,
      157,
      158,
      159,
      160,
      161,
      162,
      163,
      164,
      165,
      166,
      167,
      168,
      169,
      170,
      171,
      172,
      173,
      174,
      175,
      176,
      177,
      178,
      179,
      180,
      181,
      182,
      183,
      184,
      185,
      186,
      187,
      188,
      189,
      190,
      191,
      192,
      193,
      194,
      195,
      196,
      197,
      198,
      199,
      200,
      201,
      202,
      203,
      204,
      205,
      206,
      207,
      208,
      209,
      210,
      211,
      212,
      213,
      214,
      215,
      216,
      217,
      218,
      219,
      220,
      221,
      222,
      223,
      224,
      225,
      226,
      227,
      228,
      229,
      230,
      231,
      232,
      233,
      234,
      235,
      236,
      237,
      238,
      239,
      240,
      241,
      242,
      243,
      244,
      245,
      246,
      247,
      248,
      249,
      250,
      251,
      252,
      253,
      254,
      255,
      256,
      257,
      258,
      259,
      260,
      261,
      262,
      263,
      264,
      265,
      266,
      267,
      268,
      269,
      270,
      271,
      272,
      273,
      274,
      275,
      276,
      277,
      278,
      279,
      280,
      284,
      281,
      282,
      283,
      285,
      286,
      287,
      288,
      289,
      290,
      291,
      292,
      293,
      294,
      295,
      296,
      297,
      298,
      299,
      300,
      301,
      302,
      303,
      304,
      305,
      306,
      307,
      308,
      309,
      310,
      311,
      312,
      313,
      314,
      315,
      316,
      317,
      318,
      319,
      320,
      321,
      322,
      323,
      324,
      325,
      326,
      327,
      328,
      329,
      330,
      331,
      332,
      333,
      334,
      335,
      336,
      337,
      338,
      339,
      340,
      341,
      342,
      343,
      344,
      345,
      346,
      347,
      348,
      349,
      350,
      351,
      352,
      353,
      354,
      355,
      356,
      357,
      358,
      359,
      360,
      361,
      368,
      362,
      363,
      364,
      365,
      366,
      367,
      369,
      370,
      371,
      372,
      373,
      374,
      375,
      376,
      377,
      378,
      379,
      380,
      381,
      382,
      383,
      384,
      385,
      386,
      387,
      388,
      389,
      390,
      391,
      392,
      393,
      394,
      395,
      396,
      397,
      398,
      399,
      400,
      401,
      402,
      403,
      404
    ],
    "rnTable": [
      {
        "program": {
          "push": 1
        },
        "prelude": {
          "push": 2
        },
        "prelude_I0_opt": {
          "push": 3
        },
        "prelude_I0": {
          "push": 4
        },
        "provide-stmt": {
          "push": 5
        },
        "'PROVIDE": {
          "push": 6
        },
        "$": {
          "reductions": [
            [
              0,
              1
            ],
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4,
              3
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'PROVIDE-TYPES": {
          "reductions": [
            [
              4,
              3
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        }
      },
      {
        "$": {
          "accept": true
        }
      },
      {
        "block": {
          "push": 7
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "$": {
          "reductions": [
            [
              623,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "prelude_I1_opt": {
          "push": 94
        },
        "prelude_I1": {
          "push": 95
        },
        "provide-types-stmt": {
          "push": 96
        },
        "'PROVIDE-TYPES": {
          "push": 97
        },
        "$": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4846,
              70
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'PROVIDE-TYPES": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5056,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'PROVIDE-TYPES": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5093,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 98
        },
        "'STAR": {
          "push": 99
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "$": {
          "reductions": [
            [
              5380,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 100
        },
        "'COLONEQUALS": {
          "push": 101
        },
        "$": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5507,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5562,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5597,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5597,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5597,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5597,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5597,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5597,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5597,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5597,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 102
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "$": {
          "reductions": [
            [
              5599,
              8
            ],
            [
              29,
              8
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5599,
              8
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5599,
              8
            ],
            [
              29,
              8
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5599,
              8
            ],
            [
              29,
              8
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5599,
              8
            ],
            [
              29,
              8
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5599,
              8
            ],
            [
              29,
              8
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5599,
              8
            ],
            [
              29,
              8
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5599,
              8
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5601,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5636,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5671,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5706,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5741,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5776,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5811,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5846,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5881,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5916,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5951,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5986,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6021,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 103
        }
      },
      {
        "'NAME": {
          "push": 104
        }
      },
      {
        "'EQUALS": {
          "push": 105
        }
      },
      {
        "check-op": {
          "push": 106
        },
        "'IS": {
          "push": 107
        },
        "'RAISES": {
          "push": 108
        },
        "'SATISFIES": {
          "push": 109
        },
        "$": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6162,
              0
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "reductions": [
            [
              6297,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 110
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              6301,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              6303,
              0
            ],
            [
              6304,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 111
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              6309,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6311,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 112
        },
        "var-expr": {
          "push": 113
        },
        "toplevel-binding": {
          "push": 28
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33,
          "reductions": [
            [
              61,
              12
            ]
          ]
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr_I1_star": {
          "push": 114
        },
        "let-binding": {
          "push": 115
        },
        "multi-let-expr_I1": {
          "push": 116
        },
        "let-binding-elt": {
          "push": 117
        },
        "'VAR": {
          "push": 52,
          "reductions": [
            [
              61,
              12
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              61,
              12
            ],
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6437,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 118
        },
        "toplevel-binding": {
          "push": 28
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33,
          "reductions": [
            [
              68,
              13
            ]
          ]
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "letrec-expr_I1_star": {
          "push": 119
        },
        "letrec-expr_I1": {
          "push": 120
        },
        "letrec-binding": {
          "push": 121
        },
        "'NAME": {
          "reductions": [
            [
              68,
              13
            ],
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6555,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 122,
          "reductions": [
            [
              78,
              14
            ]
          ]
        },
        "'NEWTYPE": {
          "push": 123,
          "reductions": [
            [
              78,
              14
            ]
          ]
        },
        "type-bind": {
          "push": 124
        },
        "newtype-bind": {
          "push": 125
        },
        "type-let-bind": {
          "push": 126
        },
        "type-let-bind-elt": {
          "push": 127
        },
        "type-let-expr_I1_star": {
          "push": 128
        },
        "type-let-expr_I1": {
          "push": 129
        }
      },
      {
        "$": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6677,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 131
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "$": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6847,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 132
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "fun-header": {
          "push": 133
        },
        "ty-params": {
          "push": 134
        },
        "ty-params_I0_opt": {
          "push": 135
        },
        "ty-params_I0": {
          "push": 136
        },
        "ty-params_I0_I0": {
          "push": 137
        },
        "'LANGLE": {
          "push": 138
        },
        "'LT": {
          "push": 139
        },
        "'NAME": {
          "reductions": [
            [
              88,
              15
            ],
            [
              89,
              16
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 140
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'STRING": {
          "push": 141
        }
      },
      {
        "block": {
          "push": 142
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 143
        }
      },
      {
        "'NAME": {
          "push": 144
        }
      },
      {
        "toplevel-binding": {
          "push": 145
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "'NAME": {
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 146
        },
        "toplevel-binding": {
          "push": 28
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "graph-expr_I1_star": {
          "push": 147
        },
        "graph-expr_I1": {
          "push": 148
        },
        "'END": {
          "reductions": [
            [
              187,
              40
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              187,
              40
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 149
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'STAR": {
          "push": 150
        },
        "'LANGLE": {
          "push": 151
        },
        "'LT": {
          "push": 152
        },
        "'GT": {
          "push": 153
        },
        "'PARENNOSPACE": {
          "push": 154
        },
        "binop-expr_I1_star": {
          "push": 155
        },
        "binop-expr_I1": {
          "push": 156
        },
        "binop": {
          "push": 157
        },
        "'PLUS": {
          "push": 158
        },
        "'DASH": {
          "push": 159
        },
        "'SLASH": {
          "push": 160
        },
        "'LEQ": {
          "push": 161
        },
        "'GEQ": {
          "push": 162
        },
        "'EQUALEQUAL": {
          "push": 163
        },
        "'NEQ": {
          "push": 164
        },
        "'AND": {
          "push": 165
        },
        "'OR": {
          "push": 166
        },
        "'CARET": {
          "push": 167
        },
        "app-args": {
          "push": 168
        },
        "inst-expr_I1": {
          "push": 169
        },
        "'DOT": {
          "push": 170
        },
        "'BANG": {
          "push": 171
        },
        "$": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7435,
              41
            ],
            [
              192,
              41
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8330,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8385,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8440,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8495,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8550,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8605,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8660,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8715,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8770,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8825,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8880,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8935,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8990,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9045,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9100,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9155,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9210,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9265,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9320,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9375,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9430,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9485,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9540,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9595,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9650,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9705,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9760,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9815,
              0
            ]
          ]
        }
      },
      {
        "ty-params": {
          "push": 172
        },
        "ty-params_I0_opt": {
          "push": 135
        },
        "ty-params_I0": {
          "push": 136
        },
        "ty-params_I0_I0": {
          "push": 137
        },
        "'LANGLE": {
          "push": 138
        },
        "'LT": {
          "push": 139
        },
        "'PARENSPACE": {
          "reductions": [
            [
              88,
              15
            ],
            [
              89,
              16
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              88,
              15
            ],
            [
              89,
              16
            ]
          ]
        }
      },
      {
        "args": {
          "push": 173
        },
        "args_I0": {
          "push": 174
        },
        "'PARENSPACE": {
          "push": 175
        },
        "'PARENNOSPACE": {
          "push": 176
        }
      },
      {
        "'NAME": {
          "push": 177,
          "reductions": [
            [
              272,
              45
            ]
          ]
        },
        "'MUTABLE": {
          "push": 178,
          "reductions": [
            [
              272,
              45
            ]
          ]
        },
        "obj-fields": {
          "push": 179
        },
        "'RBRACE": {
          "push": 180
        },
        "obj-fields_I0_star": {
          "push": 181
        },
        "obj-field": {
          "push": 182
        },
        "obj-fields_I0": {
          "push": 183
        },
        "list-obj-field": {
          "push": 184
        },
        "key": {
          "push": 185
        },
        "'LBRACK": {
          "push": 186,
          "reductions": [
            [
              272,
              45
            ]
          ]
        }
      },
      {
        "construct-modifier": {
          "push": 187
        },
        "'LAZY": {
          "push": 188
        },
        "'NAME": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              304,
              52
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 189
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'BAR": {
          "push": 190,
          "reductions": [
            [
              321,
              55
            ]
          ]
        },
        "if-pipe-expr_I1_star": {
          "push": 191
        },
        "if-pipe-expr_I1": {
          "push": 192
        },
        "if-pipe-branch": {
          "push": 193
        },
        "'END": {
          "reductions": [
            [
              321,
              55
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              321,
              55
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 194
        },
        "'PARENNOSPACE": {
          "push": 195
        },
        "cases-expr_I1": {
          "push": 196
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 197
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "block": {
          "push": 198
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'EXCEPT": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "block": {
          "push": 199
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "prelude_I2_star": {
          "push": 200
        },
        "prelude_I2": {
          "push": 201
        },
        "import-stmt": {
          "push": 202
        },
        "'IMPORT": {
          "push": 203
        },
        "$": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10669,
              5
            ],
            [
              10,
              5
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10877,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10913,
              0
            ]
          ]
        }
      },
      {
        "'STAR": {
          "push": 204
        },
        "record-ann": {
          "push": 205
        },
        "'LBRACE": {
          "push": 206
        }
      },
      {
        "end": {
          "push": 207
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "$": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'PROVIDE-TYPES": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11208,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              376,
              65
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 212
        },
        "noparen-arrow-ann": {
          "push": 213
        },
        "contract-stmt_I2": {
          "push": 214
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              376,
              65
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              376,
              65
            ]
          ]
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              376,
              65
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "noparen-arrow-ann_I0_opt": {
          "push": 222
        },
        "noparen-arrow-ann_I0": {
          "push": 223
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 224
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 225
        },
        "arrow-ann-elt": {
          "push": 226
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        },
        "'THINARROW": {
          "reductions": [
            [
              373,
              64
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 229
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "$": {
          "reductions": [
            [
              12030,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              12030,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12030,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              12030,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              12030,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              12030,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              12030,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              12030,
              0
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "push": 230
        }
      },
      {
        "'AS": {
          "push": 231
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 232
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 233
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12172,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12195,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12218,
              0
            ]
          ]
        }
      },
      {
        "binding_I2_opt": {
          "push": 234
        },
        "binding_I2": {
          "push": 235
        },
        "'COLONCOLON": {
          "push": 236
        },
        "'FROM": {
          "reductions": [
            [
              12241,
              10
            ],
            [
              52,
              10
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              12241,
              10
            ],
            [
              52,
              10
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              12241,
              10
            ],
            [
              52,
              10
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12241,
              10
            ],
            [
              52,
              10
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 237
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              12248,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12248,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 112
        },
        "var-expr": {
          "push": 113
        },
        "toplevel-binding": {
          "push": 28
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "let-binding": {
          "push": 238
        },
        "'VAR": {
          "push": 52
        },
        "'NAME": {
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 239
        }
      },
      {
        "let-expr": {
          "push": 112
        },
        "var-expr": {
          "push": 113
        },
        "toplevel-binding": {
          "push": 28
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33,
          "reductions": [
            [
              12316,
              12
            ],
            [
              61,
              12
            ]
          ]
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr_I1_star": {
          "push": 240
        },
        "let-binding": {
          "push": 115
        },
        "multi-let-expr_I1": {
          "push": 116
        },
        "let-binding-elt": {
          "push": 117
        },
        "'VAR": {
          "push": 52,
          "reductions": [
            [
              12316,
              12
            ],
            [
              61,
              12
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              12316,
              12
            ],
            [
              61,
              12
            ],
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12320,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12320,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              12320,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 241
        }
      },
      {
        "let-expr": {
          "push": 242
        },
        "toplevel-binding": {
          "push": 28
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "'NAME": {
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 118
        },
        "toplevel-binding": {
          "push": 28
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33,
          "reductions": [
            [
              12383,
              13
            ],
            [
              68,
              13
            ]
          ]
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "letrec-expr_I1_star": {
          "push": 243
        },
        "letrec-expr_I1": {
          "push": 120
        },
        "letrec-binding": {
          "push": 121
        },
        "'NAME": {
          "reductions": [
            [
              12383,
              13
            ],
            [
              68,
              13
            ],
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12386,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12386,
              0
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "push": 244
        }
      },
      {
        "'NAME": {
          "push": 245
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              12393,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12393,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              12395,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12395,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 246
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12400,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              12400,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 122
        },
        "'NEWTYPE": {
          "push": 123
        },
        "type-bind": {
          "push": 124
        },
        "newtype-bind": {
          "push": 125
        },
        "type-let-bind": {
          "push": 247
        }
      },
      {
        "'NAME": {
          "push": 122,
          "reductions": [
            [
              12462,
              14
            ],
            [
              78,
              14
            ]
          ]
        },
        "'NEWTYPE": {
          "push": 123,
          "reductions": [
            [
              12462,
              14
            ],
            [
              78,
              14
            ]
          ]
        },
        "type-bind": {
          "push": 124
        },
        "newtype-bind": {
          "push": 125
        },
        "type-let-bind": {
          "push": 126
        },
        "type-let-bind-elt": {
          "push": 127
        },
        "type-let-expr_I1_star": {
          "push": 248
        },
        "type-let-expr_I1": {
          "push": 129
        }
      },
      {
        "$": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5384,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "push": 249
        }
      },
      {
        "'AS": {
          "push": 250
        }
      },
      {
        "'COLON": {
          "push": 251
        }
      },
      {
        "'NAME": {
          "push": 252
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12676,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12676,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12676,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12676,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              12676,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12678,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12678,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12678,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12678,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              12678,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 253,
          "reductions": [
            [
              94,
              17
            ]
          ]
        },
        "ty-params_I0_I1_star": {
          "push": 254
        },
        "ty-params_I0_I1": {
          "push": 255
        },
        "list-ty-param": {
          "push": 256
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12686,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12688,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 257
        }
      },
      {
        "'COLON": {
          "push": 258
        }
      },
      {
        "end": {
          "push": 259
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "ty-params": {
          "push": 260
        },
        "ty-params_I0_opt": {
          "push": 135
        },
        "ty-params_I0": {
          "push": 136
        },
        "ty-params_I0_I0": {
          "push": 137
        },
        "'LANGLE": {
          "push": 138
        },
        "'LT": {
          "push": 139
        },
        "'COLON": {
          "reductions": [
            [
              88,
              15
            ],
            [
              89,
              16
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              88,
              15
            ],
            [
              89,
              16
            ]
          ]
        }
      },
      {
        "ty-params": {
          "push": 261
        },
        "ty-params_I0_opt": {
          "push": 135
        },
        "ty-params_I0": {
          "push": 136
        },
        "ty-params_I0_I0": {
          "push": 137
        },
        "'LANGLE": {
          "push": 138
        },
        "'LT": {
          "push": 139
        },
        "'COLON": {
          "reductions": [
            [
              88,
              15
            ],
            [
              89,
              16
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "push": 262
        }
      },
      {
        "'END": {
          "reductions": [
            [
              12998,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12998,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              12998,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12998,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 263
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "let-expr": {
          "push": 146
        },
        "toplevel-binding": {
          "push": 28
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "graph-expr_I1_star": {
          "push": 264
        },
        "graph-expr_I1": {
          "push": 148
        },
        "'END": {
          "reductions": [
            [
              13038,
              40
            ],
            [
              187,
              40
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13038,
              40
            ],
            [
              187,
              40
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 265
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13140,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13163,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13163,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13163,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13163,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13168,
              0
            ],
            [
              13169,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13168,
              0
            ],
            [
              13169,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13168,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13168,
              0
            ],
            [
              13169,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13196,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "binop-expr": {
          "push": 266
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 47,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'RATIONAL": {
          "push": 81,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'TRUE": {
          "push": 82,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'FALSE": {
          "push": 83,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'LAM": {
          "push": 84,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'METHOD": {
          "push": 85,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "app-args_I1_opt": {
          "push": 267
        },
        "app-args_I1": {
          "push": 268
        },
        "app-args_I1_I0_star": {
          "push": 269
        },
        "app-args_I1_I0": {
          "push": 270
        },
        "app-arg-elt": {
          "push": 271
        },
        "'LBRACE": {
          "push": 86,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'LBRACK": {
          "push": 87,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'IF": {
          "push": 88,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 89,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'CASES": {
          "push": 90,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'FOR": {
          "push": 91,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'TRY": {
          "push": 92,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'BLOCK": {
          "push": 93,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              253,
              42
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13425,
              0
            ]
          ]
        }
      },
      {
        "'STAR": {
          "push": 150
        },
        "'LT": {
          "push": 272
        },
        "'GT": {
          "push": 153
        },
        "binop-expr_I1_star": {
          "push": 273
        },
        "binop-expr_I1": {
          "push": 156
        },
        "binop": {
          "push": 157
        },
        "'PLUS": {
          "push": 158
        },
        "'DASH": {
          "push": 159
        },
        "'SLASH": {
          "push": 160
        },
        "'LEQ": {
          "push": 161
        },
        "'GEQ": {
          "push": 162
        },
        "'EQUALEQUAL": {
          "push": 163
        },
        "'NEQ": {
          "push": 164
        },
        "'AND": {
          "push": 165
        },
        "'OR": {
          "push": 166
        },
        "'CARET": {
          "push": 167
        },
        "$": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13463,
              41
            ],
            [
              192,
              41
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 274
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13552,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13575,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13598,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13621,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13644,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13667,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13690,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13713,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13736,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13759,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13782,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              263,
              44
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 275
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              263,
              44
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              263,
              44
            ]
          ]
        },
        "inst-expr_I2_star": {
          "push": 276
        },
        "inst-expr_I2": {
          "push": 277
        },
        "inst-elt": {
          "push": 278
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              263,
              44
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "push": 279
        },
        "'LBRACE": {
          "push": 280
        },
        "'LBRACK": {
          "push": 281
        }
      },
      {
        "'NAME": {
          "push": 282
        },
        "'LBRACE": {
          "push": 283
        }
      },
      {
        "args": {
          "push": 284
        },
        "args_I0": {
          "push": 174
        },
        "'PARENSPACE": {
          "push": 175
        },
        "'PARENNOSPACE": {
          "push": 176
        }
      },
      {
        "return-ann": {
          "push": 285
        },
        "return-ann_I0_opt": {
          "push": 286
        },
        "return-ann_I0": {
          "push": 287
        },
        "'THINARROW": {
          "push": 288
        },
        "'COLON": {
          "reductions": [
            [
              110,
              20
            ],
            [
              111,
              21
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 289
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 290,
          "reductions": [
            [
              106,
              19
            ]
          ]
        },
        "args_I1_opt": {
          "push": 291
        },
        "args_I1": {
          "push": 292
        },
        "args_I1_I0_star": {
          "push": 293
        },
        "args_I1_I0": {
          "push": 294
        },
        "list-arg-elt": {
          "push": 295
        },
        "'NAME": {
          "reductions": [
            [
              106,
              19
            ],
            [
              49,
              9
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              103,
              18
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14318,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14318,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14318,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14322,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14322,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14322,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "reductions": [
            [
              14326,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14326,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14326,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14326,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 177
        },
        "key": {
          "push": 296
        },
        "'LBRACK": {
          "push": 186
        }
      },
      {
        "'RBRACE": {
          "push": 297
        }
      },
      {
        "$": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14389,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 177
        },
        "'MUTABLE": {
          "push": 178
        },
        "obj-field": {
          "push": 298
        },
        "key": {
          "push": 185
        },
        "'LBRACK": {
          "push": 186
        }
      },
      {
        "'COMMA": {
          "push": 299
        }
      },
      {
        "'NAME": {
          "push": 177,
          "reductions": [
            [
              14453,
              45
            ],
            [
              272,
              45
            ]
          ]
        },
        "'MUTABLE": {
          "push": 178,
          "reductions": [
            [
              14453,
              45
            ],
            [
              272,
              45
            ]
          ]
        },
        "obj-fields_I0_star": {
          "push": 300
        },
        "obj-field": {
          "push": 182
        },
        "obj-fields_I0": {
          "push": 183
        },
        "list-obj-field": {
          "push": 184
        },
        "key": {
          "push": 185
        },
        "'LBRACK": {
          "push": 186,
          "reductions": [
            [
              14453,
              45
            ],
            [
              272,
              45
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14457,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              14457,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14457,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 301
        },
        "args": {
          "push": 302
        },
        "args_I0": {
          "push": 174
        },
        "'PARENSPACE": {
          "push": 175
        },
        "'PARENNOSPACE": {
          "push": 176
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 303
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 304
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14584,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 305
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 306
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'BAR": {
          "push": 307
        },
        "if-pipe-expr_I2_opt": {
          "push": 308
        },
        "if-pipe-expr_I2": {
          "push": 309
        },
        "'END": {
          "reductions": [
            [
              324,
              56
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              324,
              56
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 190,
          "reductions": [
            [
              14787,
              55
            ],
            [
              321,
              55
            ]
          ]
        },
        "if-pipe-expr_I1_star": {
          "push": 310
        },
        "if-pipe-expr_I1": {
          "push": 192
        },
        "if-pipe-branch": {
          "push": 193
        },
        "'END": {
          "reductions": [
            [
              14787,
              55
            ],
            [
              321,
              55
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14787,
              55
            ],
            [
              321,
              55
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              14791,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14791,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14791,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14795,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14795,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14795,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14795,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14800,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14800,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14800,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14800,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 311
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'LANGLE": {
          "push": 151
        },
        "'LT": {
          "push": 312
        },
        "'PARENNOSPACE": {
          "push": 313
        },
        "app-args": {
          "push": 168
        },
        "inst-expr_I1": {
          "push": 169
        },
        "'DOT": {
          "push": 170
        },
        "'BANG": {
          "push": 171
        }
      },
      {
        "'EXCEPT": {
          "push": 314
        }
      },
      {
        "end": {
          "push": 315
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "$": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15173,
              0
            ]
          ]
        }
      },
      {
        "prelude_I2_star": {
          "push": 316
        },
        "prelude_I2": {
          "push": 201
        },
        "import-stmt": {
          "push": 202
        },
        "'IMPORT": {
          "push": 203
        },
        "$": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15208,
              5
            ],
            [
              10,
              5
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15243,
              0
            ]
          ]
        }
      },
      {
        "import-stmt_I1": {
          "push": 317
        },
        "'NAME": {
          "push": 318
        },
        "import-name": {
          "push": 319
        },
        "import-string": {
          "push": 320
        },
        "'STRING": {
          "push": 321
        }
      },
      {
        "$": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15355,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15391,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 322,
          "reductions": [
            [
              365,
              63
            ]
          ]
        },
        "'RBRACE": {
          "push": 323,
          "reductions": [
            [
              362,
              62
            ]
          ]
        },
        "record-ann_A0_I1_opt": {
          "push": 324
        },
        "record-ann_A0_I1": {
          "push": 325
        },
        "record-ann_A0_I1_I0_star": {
          "push": 326
        },
        "ann-field": {
          "push": 327
        },
        "record-ann_A0_I1_I0": {
          "push": 328
        },
        "list-ann-field": {
          "push": 329
        }
      },
      {
        "$": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'PROVIDE-TYPES": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15508,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'PROVIDE-TYPES": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15545,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'PROVIDE-TYPES": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15582,
              0
            ]
          ]
        }
      },
      {
        "'DOT": {
          "push": 330
        },
        "$": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              15619,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              15697,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 331
        },
        "'PERCENT": {
          "push": 332
        },
        "$": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15734,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15811,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15846,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15881,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15881,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15881,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              15881,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15881,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15887,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15887,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15887,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              15887,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15887,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15898,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15898,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              15897,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              15937,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              15974,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              16011,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              16049,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              16049,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              16048,
              0
            ]
          ]
        }
      },
      {
        "'THINARROW": {
          "push": 333
        }
      },
      {
        "'THINARROW": {
          "reductions": [
            [
              16123,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 334
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              16140,
              65
            ],
            [
              376,
              65
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 335
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              16140,
              65
            ],
            [
              376,
              65
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              16140,
              65
            ],
            [
              376,
              65
            ]
          ]
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              16140,
              65
            ],
            [
              376,
              65
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 336
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 225
        },
        "arrow-ann-elt": {
          "push": 226
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16145,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16145,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16145,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16145,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              385,
              67
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 335
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              385,
              67
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              385,
              67
            ]
          ]
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              385,
              67
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann-elt": {
          "push": 337
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "arrow-ann_I1_opt": {
          "push": 338
        },
        "arrow-ann_I1": {
          "push": 339
        },
        "arrow-ann_I1_I0_star": {
          "push": 340
        },
        "arrow-ann_I1_I0": {
          "push": 341
        },
        "app-ann_I0": {
          "push": 228
        },
        "'THINARROW": {
          "reductions": [
            [
              382,
              66
            ]
          ]
        }
      },
      {
        "'LANGLE": {
          "push": 342
        },
        "'LT": {
          "push": 343
        },
        "app-ann_I1": {
          "push": 344
        }
      },
      {
        "$": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16247,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 345
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "push": 346
        }
      },
      {
        "$": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16352,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16387,
              0
            ]
          ]
        }
      },
      {
        "'FROM": {
          "reductions": [
            [
              16422,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16422,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              16422,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16422,
              0
            ]
          ]
        }
      },
      {
        "'FROM": {
          "reductions": [
            [
              16424,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16424,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              16424,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16424,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 347
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              376,
              65
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 335
        },
        "noparen-arrow-ann": {
          "push": 348
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              376,
              65
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              376,
              65
            ]
          ]
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              376,
              65
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "noparen-arrow-ann_I0_opt": {
          "push": 222
        },
        "noparen-arrow-ann_I0": {
          "push": 223
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 224
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 225
        },
        "arrow-ann-elt": {
          "push": 226
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        },
        "'THINARROW": {
          "reductions": [
            [
              373,
              64
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 349
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16507,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16507,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16507,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16511,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16511,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 350
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16569,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16569,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 351
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'AS": {
          "push": 352
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16576,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              16576,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 353
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 354
        }
      },
      {
        "'NAME": {
          "push": 355
        }
      },
      {
        "doc-string": {
          "push": 356
        },
        "doc-string_I0_opt": {
          "push": 357
        },
        "doc-string_I0": {
          "push": 358
        },
        "'DOC": {
          "push": 359
        },
        "'END": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        }
      },
      {
        "args": {
          "push": 360
        },
        "args_I0": {
          "push": 174
        },
        "'PARENSPACE": {
          "push": 175
        },
        "'PARENNOSPACE": {
          "push": 176
        }
      },
      {
        "'COMMA": {
          "push": 361
        }
      },
      {
        "'NAME": {
          "push": 362
        }
      },
      {
        "'NAME": {
          "push": 253,
          "reductions": [
            [
              16936,
              17
            ],
            [
              94,
              17
            ]
          ]
        },
        "ty-params_I0_I1_star": {
          "push": 363
        },
        "ty-params_I0_I1": {
          "push": 255
        },
        "list-ty-param": {
          "push": 256
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16938,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16940,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 364
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17030,
              0
            ]
          ]
        }
      },
      {
        "data-mixins": {
          "push": 365
        },
        "data-mixins_I0_opt": {
          "push": 366
        },
        "data-mixins_I0": {
          "push": 367
        },
        "'DERIVING": {
          "push": 368
        },
        "'COLON": {
          "reductions": [
            [
              133,
              28
            ],
            [
              134,
              29
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 369
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 370
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "$": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17180,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              17215,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17215,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 371
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 372
        }
      },
      {
        "'RPAREN": {
          "push": 373
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              17386,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 374
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "push": 130,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "binop-expr": {
          "push": 266
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 47,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'RATIONAL": {
          "push": 81,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'TRUE": {
          "push": 82,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'FALSE": {
          "push": 83,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'LAM": {
          "push": 84,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'METHOD": {
          "push": 85,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "app-args_I1_I0_star": {
          "push": 375
        },
        "app-args_I1_I0": {
          "push": 270
        },
        "app-arg-elt": {
          "push": 271
        },
        "'LBRACE": {
          "push": 86,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'LBRACK": {
          "push": 87,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'IF": {
          "push": 88,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 89,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'CASES": {
          "push": 90,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'FOR": {
          "push": 91,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'TRY": {
          "push": 92,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        },
        "'BLOCK": {
          "push": 93,
          "reductions": [
            [
              17390,
              43
            ],
            [
              256,
              43
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17413,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13169,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17445,
              0
            ]
          ]
        }
      },
      {
        "'LANGLE": {
          "push": 151
        },
        "'LT": {
          "push": 312,
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 154
        },
        "app-args": {
          "push": 168
        },
        "inst-expr_I1": {
          "push": 169
        },
        "'DOT": {
          "push": 170
        },
        "'BANG": {
          "push": 171
        },
        "$": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 376
        },
        "'PERCENT": {
          "push": 332
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 377
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              17620,
              44
            ],
            [
              263,
              44
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 275
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              17620,
              44
            ],
            [
              263,
              44
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              17620,
              44
            ],
            [
              263,
              44
            ]
          ]
        },
        "inst-expr_I2_star": {
          "push": 378
        },
        "inst-expr_I2": {
          "push": 277
        },
        "inst-elt": {
          "push": 278
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              17620,
              44
            ],
            [
              263,
              44
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17625,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17625,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17625,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17625,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17630,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 177,
          "reductions": [
            [
              286,
              48
            ]
          ]
        },
        "fields": {
          "push": 379
        },
        "key": {
          "push": 380
        },
        "fields_I0_star": {
          "push": 381
        },
        "field": {
          "push": 382
        },
        "fields_I0": {
          "push": 383
        },
        "list-field": {
          "push": 384
        },
        "'LBRACK": {
          "push": 186,
          "reductions": [
            [
              286,
              48
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 385
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "$": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 177,
          "reductions": [
            [
              286,
              48
            ]
          ]
        },
        "fields": {
          "push": 386
        },
        "key": {
          "push": 380
        },
        "fields_I0_star": {
          "push": 381
        },
        "field": {
          "push": 382
        },
        "fields_I0": {
          "push": 383
        },
        "list-field": {
          "push": 384
        },
        "'LBRACK": {
          "push": 186,
          "reductions": [
            [
              286,
              48
            ]
          ]
        }
      },
      {
        "return-ann": {
          "push": 387
        },
        "return-ann_I0_opt": {
          "push": 286
        },
        "return-ann_I0": {
          "push": 287
        },
        "'THINARROW": {
          "push": 288
        },
        "'COLON": {
          "reductions": [
            [
              110,
              20
            ],
            [
              111,
              21
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 388
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              18026,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              18028,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 389
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'COMMA": {
          "push": 390
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              6304,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 391
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              18052,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 392
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 290
        },
        "'NAME": {
          "reductions": [
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 289
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 290,
          "reductions": [
            [
              18057,
              19
            ],
            [
              106,
              19
            ]
          ]
        },
        "args_I1_I0_star": {
          "push": 393
        },
        "args_I1_I0": {
          "push": 294
        },
        "list-arg-elt": {
          "push": 295
        },
        "'NAME": {
          "reductions": [
            [
              18057,
              19
            ],
            [
              106,
              19
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18060,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18060,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 394
        },
        "obj-field_A1_I2_opt": {
          "push": 395
        },
        "obj-field_A1_I2": {
          "push": 396
        },
        "'COLON": {
          "reductions": [
            [
              281,
              47
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18070,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 397
        },
        "obj-fields_I2_opt": {
          "push": 398
        },
        "obj-fields_I2": {
          "push": 399
        },
        "'RBRACE": {
          "reductions": [
            [
              18126,
              46
            ],
            [
              275,
              46
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18133,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              18133,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18133,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18137,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              18137,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18137,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 400
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "return-ann": {
          "push": 401
        },
        "return-ann_I0_opt": {
          "push": 286
        },
        "return-ann_I0": {
          "push": 287
        },
        "'THINARROW": {
          "push": 288
        },
        "'COLON": {
          "reductions": [
            [
              110,
              20
            ],
            [
              111,
              21
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "push": 402
        }
      },
      {
        "'COLON": {
          "push": 403
        }
      },
      {
        "block": {
          "push": 404
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'THENCOLON": {
          "push": 405
        }
      },
      {
        "'OTHERWISECOLON": {
          "push": 406
        }
      },
      {
        "end": {
          "push": 407
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'END": {
          "reductions": [
            [
              18633,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18633,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              18636,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18636,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18636,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 408
        },
        "'PERCENT": {
          "push": 332
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13168,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13168,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13168,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13168,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130,
          "reductions": [
            [
              347,
              61
            ],
            [
              256,
              43
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "binop-expr": {
          "push": 266
        },
        "binding": {
          "push": 409
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 290,
          "reductions": [
            [
              347,
              61
            ]
          ]
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 47,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'RATIONAL": {
          "push": 81,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'TRUE": {
          "push": 82,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'FALSE": {
          "push": 83,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'LAM": {
          "push": 84,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'METHOD": {
          "push": 85,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "app-args_I1_opt": {
          "push": 267
        },
        "app-args_I1": {
          "push": 268
        },
        "app-args_I1_I0_star": {
          "push": 269
        },
        "app-args_I1_I0": {
          "push": 270
        },
        "app-arg-elt": {
          "push": 271
        },
        "'LBRACE": {
          "push": 86,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'LBRACK": {
          "push": 87,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'IF": {
          "push": 88,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 89,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'CASES": {
          "push": 90,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "for-bind": {
          "push": 410
        },
        "for-bind-elt": {
          "push": 411
        },
        "'FOR": {
          "push": 91,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "for-expr_I3_opt": {
          "push": 412
        },
        "for-expr_I3": {
          "push": 413
        },
        "for-expr_I3_I0_star": {
          "push": 414
        },
        "for-expr_I3_I0": {
          "push": 415
        },
        "'TRY": {
          "push": 92,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'BLOCK": {
          "push": 93,
          "reductions": [
            [
              256,
              43
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              344,
              60
            ],
            [
              253,
              42
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 416
        },
        "'PARENNOSPACE": {
          "push": 417
        },
        "try-expr_I3": {
          "push": 418
        }
      },
      {
        "$": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18835,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18930,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "push": 419
        }
      },
      {
        "import-stmt_I2_star": {
          "push": 420
        },
        "import-stmt_I2": {
          "push": 421
        },
        "'COMMA": {
          "push": 422
        },
        "'AS": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              17,
              6
            ]
          ]
        }
      },
      {
        "'AS": {
          "reductions": [
            [
              19043,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19047,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 423
        },
        "'COLON": {
          "push": 424
        }
      },
      {
        "$": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              19053,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "push": 425
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              19125,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 322
        },
        "ann-field": {
          "push": 426
        }
      },
      {
        "'COMMA": {
          "push": 427
        }
      },
      {
        "'NAME": {
          "push": 322,
          "reductions": [
            [
              19133,
              63
            ],
            [
              365,
              63
            ]
          ]
        },
        "record-ann_A0_I1_I0_star": {
          "push": 428
        },
        "ann-field": {
          "push": 327
        },
        "record-ann_A0_I1_I0": {
          "push": 328
        },
        "list-ann-field": {
          "push": 329
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19135,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 429
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19176,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19176,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19176,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19176,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 430
        },
        "'PARENNOSPACE": {
          "push": 431
        },
        "pred-ann_I2": {
          "push": 432
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 433
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "'THINARROW": {
          "reductions": [
            [
              19258,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 331
        },
        "'PERCENT": {
          "push": 332
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19270,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19270,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19270,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19270,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19275,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19275,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19275,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19275,
              0
            ]
          ]
        }
      },
      {
        "'THINARROW": {
          "push": 434
        }
      },
      {
        "'THINARROW": {
          "reductions": [
            [
              19317,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 435
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              19321,
              67
            ],
            [
              385,
              67
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 335
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              19321,
              67
            ],
            [
              385,
              67
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              19321,
              67
            ],
            [
              385,
              67
            ]
          ]
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              19321,
              67
            ],
            [
              385,
              67
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann-elt": {
          "push": 337
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "arrow-ann_I1_I0_star": {
          "push": 436
        },
        "arrow-ann_I1_I0": {
          "push": 341
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19326,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19326,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19326,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19326,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19331,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19331,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19331,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19331,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              394,
              68
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 437
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              394,
              68
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              394,
              68
            ]
          ]
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              394,
              68
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        },
        "app-ann_I2_star": {
          "push": 438
        },
        "app-ann_I2": {
          "push": 439
        },
        "app-ann-elt": {
          "push": 440
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "$": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19389,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19424,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "'FROM": {
          "reductions": [
            [
              19462,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19462,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              19462,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19462,
              0
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "reductions": [
            [
              19474,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 441
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "block": {
          "push": 442
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "'COMMA": {
          "reductions": [
            [
              19587,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19587,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 443
        }
      },
      {
        "block": {
          "push": 444
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19646,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19701,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 445
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19883,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19920,
              0
            ]
          ]
        }
      },
      {
        "'STRING": {
          "push": 446
        }
      },
      {
        "return-ann": {
          "push": 447
        },
        "return-ann_I0_opt": {
          "push": 286
        },
        "return-ann_I0": {
          "push": 287
        },
        "'THINARROW": {
          "push": 288
        },
        "'COLON": {
          "reductions": [
            [
              19994,
              20
            ],
            [
              110,
              20
            ],
            [
              111,
              21
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19996,
              0
            ]
          ]
        }
      },
      {
        "ty-params_I0_I3": {
          "push": 448
        },
        "'RANGLE": {
          "push": 449
        },
        "'GT": {
          "push": 450
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20002,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 451
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'COLON": {
          "push": 452
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              20074,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              20076,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "binop-expr": {
          "push": 453
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 47,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "mixins": {
          "push": 454
        },
        "mixins_I0_star": {
          "push": 455
        },
        "mixins_I0": {
          "push": 456
        },
        "list-mixin": {
          "push": 457
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'RATIONAL": {
          "push": 81,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'TRUE": {
          "push": 82,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'FALSE": {
          "push": 83,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'LAM": {
          "push": 84,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'METHOD": {
          "push": 85,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'LBRACE": {
          "push": 86,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'LBRACK": {
          "push": 87,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'IF": {
          "push": 88,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 89,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'CASES": {
          "push": 90,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'FOR": {
          "push": 91,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'TRY": {
          "push": 92,
          "reductions": [
            [
              166,
              37
            ]
          ]
        },
        "'BLOCK": {
          "push": 93,
          "reductions": [
            [
              166,
              37
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 458
        },
        "variant-constructor": {
          "push": 459
        },
        "datatype-expr_I4_opt": {
          "push": 460
        },
        "datatype-expr_I4": {
          "push": 461
        },
        "first-datatype-variant": {
          "push": 462
        },
        "'END": {
          "reductions": [
            [
              171,
              38
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              171,
              38
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              171,
              38
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              171,
              38
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20225,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 463
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20295,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20318,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              20373,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20375,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20398,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20398,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20398,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20398,
              0
            ]
          ]
        }
      },
      {
        "'RANGLE": {
          "push": 464
        },
        "'GT": {
          "push": 465
        },
        "inst-expr_I4": {
          "push": 466
        },
        "'PERCENT": {
          "push": 332
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20592,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20592,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20592,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20592,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "push": 467
        }
      },
      {
        "'COLON": {
          "push": 468
        },
        "args": {
          "push": 469
        },
        "args_I0": {
          "push": 174
        },
        "'PARENSPACE": {
          "push": 175
        },
        "'PARENNOSPACE": {
          "push": 176
        }
      },
      {
        "'NAME": {
          "push": 177
        },
        "key": {
          "push": 380
        },
        "field": {
          "push": 470
        },
        "'LBRACK": {
          "push": 186
        }
      },
      {
        "'COMMA": {
          "push": 471
        }
      },
      {
        "'NAME": {
          "push": 177,
          "reductions": [
            [
              20663,
              48
            ],
            [
              286,
              48
            ]
          ]
        },
        "key": {
          "push": 380
        },
        "fields_I0_star": {
          "push": 472
        },
        "field": {
          "push": 382
        },
        "fields_I0": {
          "push": 383
        },
        "list-field": {
          "push": 384
        },
        "'LBRACK": {
          "push": 186,
          "reductions": [
            [
              20663,
              48
            ],
            [
              286,
              48
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20666,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20666,
              0
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "push": 473
        }
      },
      {
        "'RBRACE": {
          "push": 474
        }
      },
      {
        "'COLON": {
          "push": 475
        }
      },
      {
        "doc-string": {
          "push": 476
        },
        "doc-string_I0_opt": {
          "push": 357
        },
        "doc-string_I0": {
          "push": 358
        },
        "'DOC": {
          "push": 359
        },
        "'END": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "'COLON": {
          "reductions": [
            [
              20892,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20904,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20904,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              20907,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              20907,
              0
            ]
          ]
        },
        "'THICKARROW": {
          "reductions": [
            [
              20907,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              20910,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20913,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20913,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 477
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'COLON": {
          "push": 478
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              20920,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              20922,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              20924,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              20926,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              20928,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20928,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 479
        }
      },
      {
        "'COLONCOLON": {
          "reductions": [
            [
              20932,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20932,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20932,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20932,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "binop-expr": {
          "push": 480
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 47,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'RATIONAL": {
          "push": 81,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'TRUE": {
          "push": 82,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'FALSE": {
          "push": 83,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'LAM": {
          "push": 84,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'METHOD": {
          "push": 85,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'LBRACE": {
          "push": 86,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'LBRACK": {
          "push": 87,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "construct-expr_I4_opt": {
          "push": 481
        },
        "construct-expr_I4": {
          "push": 482
        },
        "construct-expr_I4_I0_star": {
          "push": 483
        },
        "construct-expr_I4_I0": {
          "push": 484
        },
        "list-elt": {
          "push": 485
        },
        "'IF": {
          "push": 88,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 89,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'CASES": {
          "push": 90,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'FOR": {
          "push": 91,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'TRY": {
          "push": 92,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'BLOCK": {
          "push": 93,
          "reductions": [
            [
              301,
              51
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              298,
              50
            ]
          ]
        }
      },
      {
        "if-expr_I4_star": {
          "push": 486
        },
        "if-expr_I4": {
          "push": 487
        },
        "else-if": {
          "push": 488
        },
        "'ELSEIF": {
          "push": 489
        },
        "'END": {
          "reductions": [
            [
              313,
              53
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              313,
              53
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              313,
              53
            ]
          ]
        }
      },
      {
        "block": {
          "push": 490
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              21341,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21341,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21341,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "block": {
          "push": 491
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              21437,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21437,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21440,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 492
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'FROM": {
          "push": 493
        }
      },
      {
        "'COMMA": {
          "push": 494
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21557,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21557,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 495
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              21615,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 409
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 290
        },
        "for-bind": {
          "push": 496
        },
        "'NAME": {
          "reductions": [
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 409
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 290,
          "reductions": [
            [
              21620,
              61
            ],
            [
              347,
              61
            ]
          ]
        },
        "for-bind": {
          "push": 410
        },
        "for-bind-elt": {
          "push": 411
        },
        "for-expr_I3_I0_star": {
          "push": 497
        },
        "for-expr_I3_I0": {
          "push": 415
        },
        "'NAME": {
          "reductions": [
            [
              21620,
              61
            ],
            [
              347,
              61
            ],
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21623,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21623,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21626,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21626,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 498
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 290
        },
        "'NAME": {
          "reductions": [
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 499
        }
      },
      {
        "'FROM": {
          "push": 500
        }
      },
      {
        "import-stmt_I2_star": {
          "push": 501
        },
        "import-stmt_I2": {
          "push": 421
        },
        "'COMMA": {
          "push": 422
        },
        "'FROM": {
          "reductions": [
            [
              21756,
              6
            ],
            [
              17,
              6
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 502
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 503
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 504
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "$": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              21765,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              21803,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21805,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21807,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              21809,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21850,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "id-expr": {
          "push": 505
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "$": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21889,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 506
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "'THINARROW": {
          "reductions": [
            [
              21962,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21964,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21964,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21964,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21964,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 507
        },
        "'PERCENT": {
          "push": 332
        }
      },
      {
        "'NAME": {
          "push": 210
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 508
        },
        "'PARENSPACE": {
          "push": 215
        },
        "'PARENNOSPACE": {
          "push": 216
        },
        "'LBRACE": {
          "push": 206
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "push": 210,
          "reductions": [
            [
              22011,
              68
            ],
            [
              394,
              68
            ]
          ]
        },
        "record-ann": {
          "push": 211
        },
        "ann": {
          "push": 437
        },
        "'PARENSPACE": {
          "push": 215,
          "reductions": [
            [
              22011,
              68
            ],
            [
              394,
              68
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 216,
          "reductions": [
            [
              22011,
              68
            ],
            [
              394,
              68
            ]
          ]
        },
        "'LBRACE": {
          "push": 206,
          "reductions": [
            [
              22011,
              68
            ],
            [
              394,
              68
            ]
          ]
        },
        "name-ann": {
          "push": 217
        },
        "arrow-ann": {
          "push": 218
        },
        "app-ann": {
          "push": 219
        },
        "pred-ann": {
          "push": 220
        },
        "dot-ann": {
          "push": 221
        },
        "arrow-ann_I0": {
          "push": 227
        },
        "app-ann_I0": {
          "push": 228
        },
        "app-ann_I2_star": {
          "push": 509
        },
        "app-ann_I2": {
          "push": 439
        },
        "app-ann-elt": {
          "push": 440
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22016,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22016,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22016,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22016,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 510
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "end": {
          "push": 511
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              22132,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22132,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 512
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "where-clause": {
          "push": 513
        },
        "where-clause_I0_opt": {
          "push": 514
        },
        "where-clause_I0": {
          "push": 515
        },
        "'WHERE": {
          "push": 516
        },
        "'END": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22327,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              22364,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22366,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22366,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22366,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22366,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              22366,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22368,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22368,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22368,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22368,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              22368,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22370,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22370,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22370,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22370,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              22370,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22372,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 517
        },
        "data-expr_I5_opt": {
          "push": 518
        },
        "data-expr_I5": {
          "push": 519
        },
        "first-data-variant": {
          "push": 520
        },
        "variant-constructor": {
          "push": 521
        },
        "'END": {
          "reductions": [
            [
              127,
              26
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              127,
              26
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              127,
              26
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              127,
              26
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              127,
              26
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 522
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              22496,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 523
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "push": 130,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "binop-expr": {
          "push": 453
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 47,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "mixins_I0_star": {
          "push": 524
        },
        "mixins_I0": {
          "push": 456
        },
        "list-mixin": {
          "push": 457
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'RATIONAL": {
          "push": 81,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'TRUE": {
          "push": 82,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'FALSE": {
          "push": 83,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'LAM": {
          "push": 84,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'METHOD": {
          "push": 85,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'LBRACE": {
          "push": 86,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'LBRACK": {
          "push": 87,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'IF": {
          "push": 88,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 89,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'CASES": {
          "push": 90,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'FOR": {
          "push": 91,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'TRY": {
          "push": 92,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        },
        "'BLOCK": {
          "push": 93,
          "reductions": [
            [
              22500,
              37
            ],
            [
              166,
              37
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22523,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 525
        },
        "'PARENNOSPACE": {
          "push": 526
        },
        "variant-members": {
          "push": 527
        },
        "variant-members_I0": {
          "push": 528
        },
        "constructor-clause": {
          "push": 529
        },
        "'WITHCONSTRUCTOR": {
          "push": 530
        }
      },
      {
        "constructor-clause": {
          "push": 531
        },
        "'WITHCONSTRUCTOR": {
          "push": 530
        }
      },
      {
        "'BAR": {
          "push": 532
        },
        "datatype-expr_I5_star": {
          "push": 533
        },
        "datatype-expr_I5": {
          "push": 534
        },
        "datatype-variant": {
          "push": 535
        },
        "'END": {
          "reductions": [
            [
              174,
              39
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              174,
              39
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              174,
              39
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22626,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22626,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22626,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22626,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22631,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22631,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22631,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22631,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22636,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22671,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22726,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22781,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22838,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 536
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "return-ann": {
          "push": 537
        },
        "return-ann_I0_opt": {
          "push": 286
        },
        "return-ann_I0": {
          "push": 287
        },
        "'THINARROW": {
          "push": 288
        },
        "'COLON": {
          "reductions": [
            [
              110,
              20
            ],
            [
              111,
              21
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 538
        },
        "fields_I2_opt": {
          "push": 539
        },
        "fields_I2": {
          "push": 540
        },
        "'END": {
          "reductions": [
            [
              22899,
              49
            ],
            [
              289,
              49
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22899,
              49
            ],
            [
              289,
              49
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22899,
              49
            ],
            [
              289,
              49
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22899,
              49
            ],
            [
              289,
              49
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22899,
              49
            ],
            [
              289,
              49
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22899,
              49
            ],
            [
              289,
              49
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22904,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22904,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22907,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22907,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22910,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22965,
              0
            ]
          ]
        }
      },
      {
        "doc-string": {
          "push": 541
        },
        "doc-string_I0_opt": {
          "push": 357
        },
        "doc-string_I0": {
          "push": 358
        },
        "'DOC": {
          "push": 359
        },
        "'END": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        }
      },
      {
        "block": {
          "push": 542
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "'COLON": {
          "reductions": [
            [
              23131,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 543
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "doc-string": {
          "push": 544
        },
        "doc-string_I0_opt": {
          "push": 357
        },
        "doc-string_I0": {
          "push": 358
        },
        "'DOC": {
          "push": 359
        },
        "'END": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 545
        }
      },
      {
        "'RBRACK": {
          "push": 546
        }
      },
      {
        "'RBRACK": {
          "reductions": [
            [
              23215,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 547
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "push": 130,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "binop-expr": {
          "push": 480
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 47,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'RATIONAL": {
          "push": 81,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'TRUE": {
          "push": 82,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'FALSE": {
          "push": 83,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'LAM": {
          "push": 84,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'METHOD": {
          "push": 85,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'LBRACE": {
          "push": 86,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'LBRACK": {
          "push": 87,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "construct-expr_I4_I0_star": {
          "push": 548
        },
        "construct-expr_I4_I0": {
          "push": 484
        },
        "list-elt": {
          "push": 485
        },
        "'IF": {
          "push": 88,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 89,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'CASES": {
          "push": 90,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'FOR": {
          "push": 91,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'TRY": {
          "push": 92,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        },
        "'BLOCK": {
          "push": 93,
          "reductions": [
            [
              23219,
              51
            ],
            [
              301,
              51
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23242,
              0
            ]
          ]
        }
      },
      {
        "if-expr_I5_opt": {
          "push": 549
        },
        "if-expr_I5": {
          "push": 550
        },
        "'ELSECOLON": {
          "push": 551
        },
        "'END": {
          "reductions": [
            [
              316,
              54
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              316,
              54
            ]
          ]
        }
      },
      {
        "if-expr_I4_star": {
          "push": 552
        },
        "if-expr_I4": {
          "push": 487
        },
        "else-if": {
          "push": 488
        },
        "'ELSEIF": {
          "push": 489
        },
        "'END": {
          "reductions": [
            [
              23326,
              53
            ],
            [
              313,
              53
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23326,
              53
            ],
            [
              313,
              53
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23326,
              53
            ],
            [
              313,
              53
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23330,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23330,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23330,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23330,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 553
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23340,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23340,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23340,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23439,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23439,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 554
        },
        "'LANGLE": {
          "push": 151
        },
        "'LT": {
          "push": 312
        },
        "'PARENNOSPACE": {
          "push": 154
        },
        "app-args": {
          "push": 168
        },
        "inst-expr_I1": {
          "push": 169
        },
        "'DOT": {
          "push": 170
        },
        "'BANG": {
          "push": 171
        }
      },
      {
        "'NAME": {
          "push": 130
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 555
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'PARENSPACE": {
          "push": 47
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23499,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23499,
              0
            ]
          ]
        }
      },
      {
        "return-ann": {
          "push": 556
        },
        "return-ann_I0_opt": {
          "push": 286
        },
        "return-ann_I0": {
          "push": 287
        },
        "'THINARROW": {
          "push": 288
        },
        "'COLON": {
          "reductions": [
            [
              110,
              20
            ],
            [
              111,
              21
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              23558,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23560,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23560,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 557
        }
      },
      {
        "$": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23618,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 558
        },
        "import-name": {
          "push": 559
        },
        "import-string": {
          "push": 560
        },
        "import-stmt_I4": {
          "push": 561
        },
        "'STRING": {
          "push": 321
        }
      },
      {
        "'FROM": {
          "reductions": [
            [
              23830,
              0
            ]
          ]
        }
      },
      {
        "'FROM": {
          "reductions": [
            [
              23832,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23832,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "'COMMA": {
          "reductions": [
            [
              23835,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23835,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 332
        },
        "'COMMA": {
          "reductions": [
            [
              23837,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23837,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 562
        }
      },
      {
        "'RPAREN": {
          "push": 563
        },
        "'PERCENT": {
          "push": 332
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        }
      },
      {
        "'RANGLE": {
          "push": 564
        },
        "'GT": {
          "push": 565
        },
        "app-ann_I4": {
          "push": 566
        },
        "'PERCENT": {
          "push": 332
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              24027,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24027,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24027,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24027,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24032,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24087,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24142,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 567
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24232,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24232,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24235,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24235,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 568
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              24238,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24238,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 525
        },
        "'PARENNOSPACE": {
          "push": 526
        },
        "variant-members": {
          "push": 527
        },
        "data-with": {
          "push": 569
        },
        "variant-members_I0": {
          "push": 528
        },
        "data-with_I0_opt": {
          "push": 570
        },
        "data-with_I0": {
          "push": 571
        },
        "'WITH": {
          "push": 572
        },
        "'END": {
          "reductions": [
            [
              24241,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24241,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24241,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24241,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24241,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        }
      },
      {
        "data-expr_I6_star": {
          "push": 573
        },
        "data-expr_I6": {
          "push": 574
        },
        "data-variant": {
          "push": 575
        },
        "'BAR": {
          "push": 576
        },
        "'END": {
          "reductions": [
            [
              130,
              27
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              130,
              27
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              130,
              27
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              130,
              27
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24337,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24337,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24337,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24337,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24337,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24343,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24343,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24343,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24343,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24343,
              0
            ]
          ]
        }
      },
      {
        "data-with": {
          "push": 577
        },
        "data-with_I0_opt": {
          "push": 570
        },
        "data-with_I0": {
          "push": 571
        },
        "'WITH": {
          "push": 572
        },
        "'END": {
          "reductions": [
            [
              24349,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24349,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24349,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24349,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24349,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24355,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              24378,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24380,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              24403,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24403,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24403,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              24403,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              24403,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              24409,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24409,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24409,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              24409,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              24409,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24415,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24415,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24415,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24415,
              0
            ]
          ]
        },
        "'WITH": {
          "reductions": [
            [
              24415,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24415,
              0
            ]
          ]
        },
        "'WITHCONSTRUCTOR": {
          "reductions": [
            [
              24415,
              0
            ]
          ]
        }
      },
      {
        "variant-members_I1_opt": {
          "push": 578
        },
        "variant-members_I1": {
          "push": 579
        },
        "variant-members_I1_I0_star": {
          "push": 580
        },
        "variant-member": {
          "push": 581
        },
        "variant-members_I1_I0": {
          "push": 582
        },
        "list-variant-member": {
          "push": 583
        },
        "variant-member_I0_opt": {
          "push": 584
        },
        "variant-member_I0": {
          "push": 585
        },
        "'MUTABLE": {
          "push": 586,
          "reductions": [
            [
              148,
              31
            ]
          ]
        },
        "'CYCLIC": {
          "push": 587,
          "reductions": [
            [
              148,
              31
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              148,
              31
            ],
            [
              153,
              32
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              148,
              31
            ],
            [
              153,
              32
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              145,
              30
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24447,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24447,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24447,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24447,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 588
        },
        "'PARENNOSPACE": {
          "push": 589
        },
        "constructor-clause_I1": {
          "push": 590
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24459,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24459,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24459,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24459,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 591
        },
        "variant-constructor": {
          "push": 592
        }
      },
      {
        "where-clause": {
          "push": 593
        },
        "where-clause_I0_opt": {
          "push": 514
        },
        "where-clause_I0": {
          "push": 515
        },
        "'WHERE": {
          "push": 516
        },
        "'END": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 532
        },
        "datatype-expr_I5_star": {
          "push": 594
        },
        "datatype-expr_I5": {
          "push": 534
        },
        "datatype-variant": {
          "push": 535
        },
        "'END": {
          "reductions": [
            [
              24509,
              39
            ],
            [
              174,
              39
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24509,
              39
            ],
            [
              174,
              39
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24509,
              39
            ],
            [
              174,
              39
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24513,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24513,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24513,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24513,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24518,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24518,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24518,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24518,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24518,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24518,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24518,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 595
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24522,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24522,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24522,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24522,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24522,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24522,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24524,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24524,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24524,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24524,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24524,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24524,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24526,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24526,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24526,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24526,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24526,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24526,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 596
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 597
        },
        "where-clause_I0_opt": {
          "push": 514
        },
        "where-clause_I0": {
          "push": 515
        },
        "'WHERE": {
          "push": 516
        },
        "'END": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              24638,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24638,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 598
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24642,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24665,
              0
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "reductions": [
            [
              24720,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24722,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 599
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24800,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24800,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 600
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              24803,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24803,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              24806,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24806,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24806,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 601
        }
      },
      {
        "'BAR": {
          "push": 602,
          "reductions": [
            [
              331,
              57
            ]
          ]
        },
        "cases-expr_I6_star": {
          "push": 603
        },
        "cases-expr_I6": {
          "push": 604
        },
        "cases-branch": {
          "push": 605
        },
        "'END": {
          "reductions": [
            [
              331,
              57
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              331,
              57
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              24890,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24890,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 606
        }
      },
      {
        "'COLON": {
          "push": 607
        }
      },
      {
        "$": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19002,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25037,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25073,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25109,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              25180,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              25217,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              25254,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              25291,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              25328,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25365,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25400,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25400,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25409,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25409,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25409,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25409,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25409,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25421,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25421,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25421,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25421,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25421,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25427,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25427,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25427,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25427,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25427,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 177,
          "reductions": [
            [
              286,
              48
            ]
          ]
        },
        "fields": {
          "push": 608
        },
        "key": {
          "push": 380
        },
        "fields_I0_star": {
          "push": 381
        },
        "field": {
          "push": 382
        },
        "fields_I0": {
          "push": 383
        },
        "list-field": {
          "push": 384
        },
        "'LBRACK": {
          "push": 186,
          "reductions": [
            [
              286,
              48
            ]
          ]
        }
      },
      {
        "data-sharing": {
          "push": 609
        },
        "data-sharing_I0_opt": {
          "push": 610
        },
        "data-sharing_I0": {
          "push": 611
        },
        "'SHARING": {
          "push": 612
        },
        "'END": {
          "reductions": [
            [
              161,
              35
            ],
            [
              162,
              36
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              161,
              35
            ],
            [
              162,
              36
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              161,
              35
            ],
            [
              162,
              36
            ]
          ]
        }
      },
      {
        "data-expr_I6_star": {
          "push": 613
        },
        "data-expr_I6": {
          "push": 574
        },
        "data-variant": {
          "push": 575
        },
        "'BAR": {
          "push": 576
        },
        "'END": {
          "reductions": [
            [
              25491,
              27
            ],
            [
              130,
              27
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25491,
              27
            ],
            [
              130,
              27
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25491,
              27
            ],
            [
              130,
              27
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25491,
              27
            ],
            [
              130,
              27
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25496,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25496,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25496,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25496,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25496,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 614
        },
        "variant-constructor": {
          "push": 615
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25514,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25514,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25514,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25514,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25514,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 616
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              25522,
              0
            ]
          ]
        }
      },
      {
        "variant-member": {
          "push": 617
        },
        "variant-member_I0_opt": {
          "push": 584
        },
        "variant-member_I0": {
          "push": 585
        },
        "'MUTABLE": {
          "push": 586
        },
        "'CYCLIC": {
          "push": 587
        },
        "'NAME": {
          "reductions": [
            [
              153,
              32
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              153,
              32
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 618
        }
      },
      {
        "variant-members_I1_I0_star": {
          "push": 619
        },
        "variant-member": {
          "push": 581
        },
        "variant-members_I1_I0": {
          "push": 582
        },
        "list-variant-member": {
          "push": 583
        },
        "variant-member_I0_opt": {
          "push": 584
        },
        "variant-member_I0": {
          "push": 585
        },
        "'MUTABLE": {
          "push": 586,
          "reductions": [
            [
              25532,
              31
            ],
            [
              148,
              31
            ]
          ]
        },
        "'CYCLIC": {
          "push": 587,
          "reductions": [
            [
              25532,
              31
            ],
            [
              148,
              31
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25532,
              31
            ],
            [
              148,
              31
            ],
            [
              153,
              32
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25532,
              31
            ],
            [
              148,
              31
            ],
            [
              153,
              32
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25537,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25537,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              25537,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              25537,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 620
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 290
        },
        "'NAME": {
          "reductions": [
            [
              49,
              9
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25544,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25544,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25547,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25547,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25550,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25550,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25553,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25555,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 621
        }
      },
      {
        "'PARENSPACE": {
          "push": 525
        },
        "'PARENNOSPACE": {
          "push": 526
        },
        "variant-members": {
          "push": 527
        },
        "variant-members_I0": {
          "push": 528
        },
        "constructor-clause": {
          "push": 622
        },
        "'WITHCONSTRUCTOR": {
          "push": 530
        }
      },
      {
        "constructor-clause": {
          "push": 623
        },
        "'WITHCONSTRUCTOR": {
          "push": 530
        }
      },
      {
        "end": {
          "push": 624
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25607,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25607,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25607,
              0
            ]
          ]
        }
      },
      {
        "doc-string": {
          "push": 625
        },
        "doc-string_I0_opt": {
          "push": 357
        },
        "doc-string_I0": {
          "push": 358
        },
        "'DOC": {
          "push": 359
        },
        "'END": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              114,
              22
            ],
            [
              115,
              23
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 626
        },
        "where-clause_I0_opt": {
          "push": 514
        },
        "where-clause_I0": {
          "push": 515
        },
        "'WHERE": {
          "push": 516
        },
        "'END": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        }
      },
      {
        "end": {
          "push": 627
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "where-clause": {
          "push": 628
        },
        "where-clause_I0_opt": {
          "push": 514
        },
        "where-clause_I0": {
          "push": 515
        },
        "'WHERE": {
          "push": 516
        },
        "'END": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25725,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25780,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25780,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 629
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              25783,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25783,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25783,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25783,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 630
        }
      },
      {
        "'BAR": {
          "push": 631
        },
        "cases-expr_I7_opt": {
          "push": 632
        },
        "cases-expr_I7": {
          "push": 633
        },
        "'END": {
          "reductions": [
            [
              334,
              58
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              334,
              58
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 602,
          "reductions": [
            [
              25853,
              57
            ],
            [
              331,
              57
            ]
          ]
        },
        "cases-expr_I6_star": {
          "push": 634
        },
        "cases-expr_I6": {
          "push": 604
        },
        "cases-branch": {
          "push": 605
        },
        "'END": {
          "reductions": [
            [
              25853,
              57
            ],
            [
              331,
              57
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25853,
              57
            ],
            [
              331,
              57
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25857,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25857,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25857,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 635
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "block": {
          "push": 636
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              25971,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25971,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25971,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25971,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25971,
              0
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 637
        },
        "where-clause_I0_opt": {
          "push": 514
        },
        "where-clause_I0": {
          "push": 515
        },
        "'WHERE": {
          "push": 516
        },
        "'END": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26027,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26027,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26027,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26031,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26031,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26031,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 177,
          "reductions": [
            [
              286,
              48
            ]
          ]
        },
        "fields": {
          "push": 638
        },
        "key": {
          "push": 380
        },
        "fields_I0_star": {
          "push": 381
        },
        "field": {
          "push": 382
        },
        "fields_I0": {
          "push": 383
        },
        "list-field": {
          "push": 384
        },
        "'LBRACK": {
          "push": 186,
          "reductions": [
            [
              286,
              48
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26039,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26039,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26039,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26039,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 525
        },
        "'PARENNOSPACE": {
          "push": 526
        },
        "variant-members": {
          "push": 527
        },
        "data-with": {
          "push": 639
        },
        "variant-members_I0": {
          "push": 528
        },
        "data-with_I0_opt": {
          "push": 570
        },
        "data-with_I0": {
          "push": 571
        },
        "'WITH": {
          "push": 572
        },
        "'END": {
          "reductions": [
            [
              26044,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26044,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26044,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26044,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26044,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        }
      },
      {
        "data-with": {
          "push": 640
        },
        "data-with_I0_opt": {
          "push": 570
        },
        "data-with_I0": {
          "push": 571
        },
        "'WITH": {
          "push": 572
        },
        "'END": {
          "reductions": [
            [
              26050,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26050,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26050,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26050,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26050,
              33
            ],
            [
              157,
              33
            ],
            [
              158,
              34
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26056,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26056,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26056,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26056,
              0
            ]
          ]
        },
        "'WITH": {
          "reductions": [
            [
              26056,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26056,
              0
            ]
          ]
        },
        "'WITHCONSTRUCTOR": {
          "reductions": [
            [
              26056,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              26058,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              26061,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26061,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              26061,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              26061,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              26066,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26066,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              26066,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              26066,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              26071,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26071,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 641
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26078,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26078,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26078,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26078,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26083,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26083,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26083,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26083,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26088,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 642
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "end": {
          "push": 643
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "$": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26180,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 644
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26239,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26239,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26239,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26239,
              0
            ]
          ]
        }
      },
      {
        "args": {
          "push": 645
        },
        "args_I0": {
          "push": 174
        },
        "'PARENSPACE": {
          "push": 175
        },
        "'PARENNOSPACE": {
          "push": 176
        },
        "cases-branch_I2_opt": {
          "push": 646
        },
        "cases-branch_I2": {
          "push": 647
        },
        "'THICKARROW": {
          "reductions": [
            [
              338,
              59
            ]
          ]
        }
      },
      {
        "'ELSE": {
          "push": 648
        }
      },
      {
        "end": {
          "push": 649
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26310,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26310,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26313,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26313,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26313,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 650
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "end": {
          "push": 651
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "end": {
          "push": 652
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26462,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26462,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26462,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26466,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26466,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26466,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26466,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26466,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26472,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26472,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26472,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26472,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26472,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 653
        }
      },
      {
        "where-clause": {
          "push": 654
        },
        "where-clause_I0_opt": {
          "push": 514
        },
        "where-clause_I0": {
          "push": 515
        },
        "'WHERE": {
          "push": 516
        },
        "'END": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              118,
              24
            ],
            [
              119,
              25
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26485,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              26540,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26540,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "reductions": [
            [
              26544,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "push": 655
        }
      },
      {
        "'THICKARROW": {
          "reductions": [
            [
              26551,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "push": 656
        }
      },
      {
        "$": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26556,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26611,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26666,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'TYPE": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'NEWTYPE": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'TYPE-LET": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'BLESS": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'CONFIRM": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26721,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 657
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "end": {
          "push": 658
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "block": {
          "push": 659
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              26763,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26763,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26763,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "block": {
          "push": 660
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              57,
              11
            ],
            [
              49,
              9
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "type-expr": {
          "push": 13
        },
        "newtype-expr": {
          "push": 14
        },
        "let-expr": {
          "push": 15
        },
        "fun-expr": {
          "push": 16
        },
        "data-expr": {
          "push": 17
        },
        "datatype-expr": {
          "push": 18
        },
        "when-expr": {
          "push": 19
        },
        "var-expr": {
          "push": 20
        },
        "assign-expr": {
          "push": 21
        },
        "check-test": {
          "push": 22
        },
        "check-expr": {
          "push": 23
        },
        "graph-expr": {
          "push": 24
        },
        "contract-stmt": {
          "push": 25
        },
        "'TYPE": {
          "push": 26
        },
        "'NEWTYPE": {
          "push": 27
        },
        "toplevel-binding": {
          "push": 28
        },
        "binop-expr": {
          "push": 29
        },
        "binding": {
          "push": 30
        },
        "binding_I0_opt": {
          "push": 31
        },
        "binding_I0": {
          "push": 32
        },
        "'SHADOW": {
          "push": 33
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 34
        },
        "toplevel-binding_A1_I0": {
          "push": 35
        },
        "multi-let-expr": {
          "push": 36
        },
        "'LET": {
          "push": 37
        },
        "letrec-expr": {
          "push": 38
        },
        "'LETREC": {
          "push": 39
        },
        "type-let-expr": {
          "push": 40
        },
        "'TYPE-LET": {
          "push": 41
        },
        "bless-expr": {
          "push": 42
        },
        "'BLESS": {
          "push": 43
        },
        "confirm-expr": {
          "push": 44
        },
        "'CONFIRM": {
          "push": 45
        },
        "'FUN": {
          "push": 46
        },
        "'PARENSPACE": {
          "push": 47
        },
        "'CHECK": {
          "push": 48
        },
        "'CHECKCOLON": {
          "push": 49
        },
        "'DATA": {
          "push": 50
        },
        "'DATATYPE": {
          "push": 51
        },
        "'VAR": {
          "push": 52
        },
        "'GRAPH": {
          "push": 53
        },
        "'WHEN": {
          "push": 54
        },
        "expr": {
          "push": 55
        },
        "paren-expr": {
          "push": 56
        },
        "id-expr": {
          "push": 57
        },
        "prim-expr": {
          "push": 58
        },
        "lambda-expr": {
          "push": 59
        },
        "method-expr": {
          "push": 60
        },
        "app-expr": {
          "push": 61
        },
        "obj-expr": {
          "push": 62
        },
        "dot-expr": {
          "push": 63
        },
        "bracket-expr": {
          "push": 64
        },
        "get-bang-expr": {
          "push": 65
        },
        "update-expr": {
          "push": 66
        },
        "extend-expr": {
          "push": 67
        },
        "if-expr": {
          "push": 68
        },
        "if-pipe-expr": {
          "push": 69
        },
        "cases-expr": {
          "push": 70
        },
        "for-expr": {
          "push": 71
        },
        "try-expr": {
          "push": 72
        },
        "user-block-expr": {
          "push": 73
        },
        "inst-expr": {
          "push": 74
        },
        "construct-expr": {
          "push": 75
        },
        "num-expr": {
          "push": 76
        },
        "frac-expr": {
          "push": 77
        },
        "bool-expr": {
          "push": 78
        },
        "string-expr": {
          "push": 79
        },
        "'NUMBER": {
          "push": 80
        },
        "'RATIONAL": {
          "push": 81
        },
        "'TRUE": {
          "push": 82
        },
        "'FALSE": {
          "push": 83
        },
        "'LAM": {
          "push": 84
        },
        "'METHOD": {
          "push": 85
        },
        "'LBRACE": {
          "push": 86
        },
        "'LBRACK": {
          "push": 87
        },
        "'IF": {
          "push": 88
        },
        "'ASKCOLON": {
          "push": 89
        },
        "'CASES": {
          "push": 90
        },
        "'FOR": {
          "push": 91
        },
        "'TRY": {
          "push": 92
        },
        "'BLOCK": {
          "push": 93
        },
        "'END": {
          "reductions": [
            [
              26767,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26767,
              7
            ],
            [
              28,
              7
            ],
            [
              29,
              8
            ]
          ]
        }
      },
      {
        "end": {
          "push": 661
        },
        "'END": {
          "push": 208
        },
        "'SEMI": {
          "push": 209
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26783,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26783,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26783,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26783,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26783,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26783,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26783,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26785,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26785,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26785,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26789,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26789,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              26792,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26792,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26792,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26792,
              0
            ]
          ]
        }
      }
    ],
    "I": {
      "ε": 0,
      "program": 1,
      "prelude": 2,
      "prelude_I0_opt": 3,
      "prelude_I1_opt": 4,
      "prelude_I2_star": 5,
      "import-stmt_I2_star": 6,
      "block": 7,
      "block_I0_star": 8,
      "binding_I0_opt": 9,
      "binding_I2_opt": 10,
      "toplevel-binding_A1_I0_opt": 11,
      "multi-let-expr_I1_star": 12,
      "letrec-expr_I1_star": 13,
      "type-let-expr_I1_star": 14,
      "ty-params": 15,
      "ty-params_I0_opt": 16,
      "ty-params_I0_I1_star": 17,
      "args_I1_opt": 18,
      "args_I1_I0_star": 19,
      "return-ann": 20,
      "return-ann_I0_opt": 21,
      "doc-string": 22,
      "doc-string_I0_opt": 23,
      "where-clause": 24,
      "where-clause_I0_opt": 25,
      "data-expr_I5_opt": 26,
      "data-expr_I6_star": 27,
      "data-mixins": 28,
      "data-mixins_I0_opt": 29,
      "variant-members_I1_opt": 30,
      "variant-members_I1_I0_star": 31,
      "variant-member_I0_opt": 32,
      "data-with": 33,
      "data-with_I0_opt": 34,
      "data-sharing": 35,
      "data-sharing_I0_opt": 36,
      "mixins_I0_star": 37,
      "datatype-expr_I4_opt": 38,
      "datatype-expr_I5_star": 39,
      "graph-expr_I1_star": 40,
      "binop-expr_I1_star": 41,
      "app-args_I1_opt": 42,
      "app-args_I1_I0_star": 43,
      "inst-expr_I2_star": 44,
      "obj-fields_I0_star": 45,
      "obj-fields_I2_opt": 46,
      "obj-field_A1_I2_opt": 47,
      "fields_I0_star": 48,
      "fields_I2_opt": 49,
      "construct-expr_I4_opt": 50,
      "construct-expr_I4_I0_star": 51,
      "construct-modifier": 52,
      "if-expr_I4_star": 53,
      "if-expr_I5_opt": 54,
      "if-pipe-expr_I1_star": 55,
      "if-pipe-expr_I2_opt": 56,
      "cases-expr_I6_star": 57,
      "cases-expr_I7_opt": 58,
      "cases-branch_I2_opt": 59,
      "for-expr_I3_opt": 60,
      "for-expr_I3_I0_star": 61,
      "record-ann_A0_I1_opt": 62,
      "record-ann_A0_I1_I0_star": 63,
      "noparen-arrow-ann_I0_opt": 64,
      "noparen-arrow-ann_I0_I0_star": 65,
      "arrow-ann_I1_opt": 66,
      "arrow-ann_I1_I0_star": 67,
      "app-ann_I2_star": 68,
      "START": 69,
      "prelude_I1_opt,prelude_I2_star": 70
    },
    "eSPPFs": [
      {
        "label": "EPSILON"
      },
      {
        "label": "program",
        "kids": [
          2,
          7
        ],
        "rule": 0
      },
      {
        "label": "prelude",
        "kids": [
          3,
          4,
          5
        ],
        "rule": 3
      },
      {
        "label": "prelude_I0_opt",
        "kids": [],
        "rule": 4
      },
      {
        "label": "prelude_I1_opt",
        "kids": [],
        "rule": 7
      },
      {
        "label": "prelude_I2_star",
        "kids": [],
        "rule": 10
      },
      {
        "label": "import-stmt_I2_star",
        "kids": [],
        "rule": 17
      },
      {
        "label": "block",
        "kids": [
          8
        ],
        "rule": 28
      },
      {
        "label": "block_I0_star",
        "kids": [],
        "rule": 29
      },
      {
        "label": "binding_I0_opt",
        "kids": [],
        "rule": 49
      },
      {
        "label": "binding_I2_opt",
        "kids": [],
        "rule": 52
      },
      {
        "label": "toplevel-binding_A1_I0_opt",
        "kids": [],
        "rule": 57
      },
      {
        "label": "multi-let-expr_I1_star",
        "kids": [],
        "rule": 61
      },
      {
        "label": "letrec-expr_I1_star",
        "kids": [],
        "rule": 68
      },
      {
        "label": "type-let-expr_I1_star",
        "kids": [],
        "rule": 78
      },
      {
        "label": "ty-params",
        "kids": [
          16
        ],
        "rule": 88
      },
      {
        "label": "ty-params_I0_opt",
        "kids": [],
        "rule": 89
      },
      {
        "label": "ty-params_I0_I1_star",
        "kids": [],
        "rule": 94
      },
      {
        "label": "args_I1_opt",
        "kids": [],
        "rule": 103
      },
      {
        "label": "args_I1_I0_star",
        "kids": [],
        "rule": 106
      },
      {
        "label": "return-ann",
        "kids": [
          21
        ],
        "rule": 110
      },
      {
        "label": "return-ann_I0_opt",
        "kids": [],
        "rule": 111
      },
      {
        "label": "doc-string",
        "kids": [
          23
        ],
        "rule": 114
      },
      {
        "label": "doc-string_I0_opt",
        "kids": [],
        "rule": 115
      },
      {
        "label": "where-clause",
        "kids": [
          25
        ],
        "rule": 118
      },
      {
        "label": "where-clause_I0_opt",
        "kids": [],
        "rule": 119
      },
      {
        "label": "data-expr_I5_opt",
        "kids": [],
        "rule": 127
      },
      {
        "label": "data-expr_I6_star",
        "kids": [],
        "rule": 130
      },
      {
        "label": "data-mixins",
        "kids": [
          29
        ],
        "rule": 133
      },
      {
        "label": "data-mixins_I0_opt",
        "kids": [],
        "rule": 134
      },
      {
        "label": "variant-members_I1_opt",
        "kids": [],
        "rule": 145
      },
      {
        "label": "variant-members_I1_I0_star",
        "kids": [],
        "rule": 148
      },
      {
        "label": "variant-member_I0_opt",
        "kids": [],
        "rule": 153
      },
      {
        "label": "data-with",
        "kids": [
          34
        ],
        "rule": 157
      },
      {
        "label": "data-with_I0_opt",
        "kids": [],
        "rule": 158
      },
      {
        "label": "data-sharing",
        "kids": [
          36
        ],
        "rule": 161
      },
      {
        "label": "data-sharing_I0_opt",
        "kids": [],
        "rule": 162
      },
      {
        "label": "mixins_I0_star",
        "kids": [],
        "rule": 166
      },
      {
        "label": "datatype-expr_I4_opt",
        "kids": [],
        "rule": 171
      },
      {
        "label": "datatype-expr_I5_star",
        "kids": [],
        "rule": 174
      },
      {
        "label": "graph-expr_I1_star",
        "kids": [],
        "rule": 187
      },
      {
        "label": "binop-expr_I1_star",
        "kids": [],
        "rule": 192
      },
      {
        "label": "app-args_I1_opt",
        "kids": [],
        "rule": 253
      },
      {
        "label": "app-args_I1_I0_star",
        "kids": [],
        "rule": 256
      },
      {
        "label": "inst-expr_I2_star",
        "kids": [],
        "rule": 263
      },
      {
        "label": "obj-fields_I0_star",
        "kids": [],
        "rule": 272
      },
      {
        "label": "obj-fields_I2_opt",
        "kids": [],
        "rule": 275
      },
      {
        "label": "obj-field_A1_I2_opt",
        "kids": [],
        "rule": 281
      },
      {
        "label": "fields_I0_star",
        "kids": [],
        "rule": 286
      },
      {
        "label": "fields_I2_opt",
        "kids": [],
        "rule": 289
      },
      {
        "label": "construct-expr_I4_opt",
        "kids": [],
        "rule": 298
      },
      {
        "label": "construct-expr_I4_I0_star",
        "kids": [],
        "rule": 301
      },
      {
        "label": "construct-modifier",
        "kids": [],
        "rule": 304
      },
      {
        "label": "if-expr_I4_star",
        "kids": [],
        "rule": 313
      },
      {
        "label": "if-expr_I5_opt",
        "kids": [],
        "rule": 316
      },
      {
        "label": "if-pipe-expr_I1_star",
        "kids": [],
        "rule": 321
      },
      {
        "label": "if-pipe-expr_I2_opt",
        "kids": [],
        "rule": 324
      },
      {
        "label": "cases-expr_I6_star",
        "kids": [],
        "rule": 331
      },
      {
        "label": "cases-expr_I7_opt",
        "kids": [],
        "rule": 334
      },
      {
        "label": "cases-branch_I2_opt",
        "kids": [],
        "rule": 338
      },
      {
        "label": "for-expr_I3_opt",
        "kids": [],
        "rule": 344
      },
      {
        "label": "for-expr_I3_I0_star",
        "kids": [],
        "rule": 347
      },
      {
        "label": "record-ann_A0_I1_opt",
        "kids": [],
        "rule": 362
      },
      {
        "label": "record-ann_A0_I1_I0_star",
        "kids": [],
        "rule": 365
      },
      {
        "label": "noparen-arrow-ann_I0_opt",
        "kids": [],
        "rule": 373
      },
      {
        "label": "noparen-arrow-ann_I0_I0_star",
        "kids": [],
        "rule": 376
      },
      {
        "label": "arrow-ann_I1_opt",
        "kids": [],
        "rule": 382
      },
      {
        "label": "arrow-ann_I1_I0_star",
        "kids": [],
        "rule": 385
      },
      {
        "label": "app-ann_I2_star",
        "kids": [],
        "rule": 394
      },
      {
        "label": "START",
        "kids": [
          1
        ],
        "rule": 404
      },
      {
        "label": "prelude_I1_opt,prelude_I2_star",
        "kids": [
          4,
          5
        ]
      }
    ]
  };
  return { PyretGrammar: Grammar.fromSerializable(g_json) };
});

define('trove/pprint',["trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($arrays12031,$lists32132,$option52233,$error72334,$sets92435) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/trove/pprint.arr30"]) {
return R.modules["$src/arr/trove/pprint.arr30"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/trove/pprint.arr";
var D = R.undefined;
var L = [[M,191,0,6637,191,35,6672],
[M,201,0,7164,201,17,7181],
[M,200,0,7118,200,45,7163],
[M,200,29,7147,200,40,7158],
[M,200,16,7134,200,22,7140],
[M,198,13,7073,198,56,7116],
[M,198,28,7088,198,44,7104],
[M,197,15,7029,197,45,7059],
[M,196,16,6985,196,44,7013],
[M,195,14,6913,195,69,6968],
[M,195,50,6949,195,64,6963],
[M,195,36,6935,195,48,6947],
[M,194,17,6822,194,93,6898],
[M,194,71,6876,194,88,6893],
[M,194,54,6859,194,69,6874],
[M,193,15,6754,193,65,6804],
[M,193,46,6785,193,60,6799],
[M,193,32,6771,193,44,6783],
[M,192,15,6688,192,65,6738],
[M,192,46,6719,192,60,6733],
[M,192,32,6705,192,44,6717],
[M,202,0,7182,202,17,7199],
[M,203,0,7200,203,17,7217],
[M,204,0,7218,204,17,7235],
[M,205,0,7236,205,17,7253],
[M,206,0,7254,206,17,7271],
[M,207,0,7272,207,17,7289],
[M,208,0,7290,208,17,7307],
[M,209,0,7308,209,16,7324],
[M,211,21,7393,211,30,7402],
[M,210,0,7325,210,46,7371],
[M,210,23,7348,210,31,7356],
[M,211,0,7372,211,30,7402],
[M,225,0,7843,225,21,7864],
[M,224,0,7795,224,47,7842],
[M,224,23,7818,224,43,7838],
[M,223,0,7749,223,45,7794],
[M,223,21,7770,223,41,7790],
[M,222,0,7703,222,45,7748],
[M,222,21,7724,222,41,7744],
[M,221,0,7641,221,61,7702],
[M,221,36,7677,221,49,7690],
[M,220,0,7578,220,62,7640],
[M,220,26,7604,220,35,7613],
[M,213,0,7404,219,3,7577],
[M,214,2,7435,218,5,7573],
[M,215,7,7499,215,21,7513],
[M,214,6,7439,214,16,7449],
[M,226,0,7865,226,21,7886],
[M,47,0,849,322,3,11072],
[M,263,0,9331,265,3,9484],
[M,264,35,9427,264,58,9450],
[M,257,0,9086,261,3,9329],
[M,258,5,9236,258,25,9256],
[M,258,5,9236,258,19,9250],
[M,257,132,9218,257,142,9228],
[M,257,27,9113,257,33,9119],
[M,257,40,9126,257,46,9132],
[M,257,56,9142,257,65,9151],
[M,257,75,9161,257,84,9170],
[M,257,93,9179,257,102,9188],
[M,257,113,9199,257,122,9208],
[M,249,0,8889,256,3,9085],
[M,250,2,8943,255,5,9081],
[M,251,7,8996,251,19,9008],
[M,250,6,8947,250,16,8957],
[M,249,39,8928,249,49,8938],
[M,249,20,8909,249,29,8918],
[M,243,0,8611,247,3,8887],
[M,244,5,8723,244,21,8739],
[M,243,23,8634,243,29,8640],
[M,243,36,8647,243,42,8653],
[M,243,52,8663,243,61,8672],
[M,243,75,8686,243,84,8695],
[M,243,95,8706,243,104,8715],
[M,238,0,8360,242,3,8610],
[M,239,5,8467,239,21,8483],
[M,238,18,8378,238,24,8384],
[M,238,31,8391,238,37,8397],
[M,238,47,8407,238,56,8416],
[M,238,70,8430,238,79,8439],
[M,238,90,8450,238,99,8459],
[M,235,0,8225,237,3,8359],
[M,236,24,8341,236,32,8349],
[M,235,21,8246,235,27,8252],
[M,235,34,8259,235,40,8265],
[M,235,48,8273,235,57,8282],
[M,235,64,8289,235,73,8298],
[M,235,80,8305,235,89,8314],
[M,232,0,8096,234,3,8224],
[M,233,20,8202,233,28,8210],
[M,232,15,8111,232,21,8117],
[M,232,28,8124,232,34,8130],
[M,232,42,8138,232,51,8147],
[M,232,58,8154,232,67,8163],
[M,232,74,8170,232,83,8179],
[M,231,0,8034,231,61,8095],
[M,231,42,8076,231,51,8085],
[M,230,0,7996,230,37,8033],
[M,230,22,8018,230,32,8028],
[M,228,0,7941,228,53,7994],
[M,228,21,7962,228,49,7990],
[M,227,0,7887,227,53,7940],
[M,227,21,7908,227,49,7936],
[M,267,0,9486,322,3,11072],
[M,268,15,9508,268,78,9571],
[M,47,0,849,87,3,2712],
[M,268,2,9495,268,87,9580],
[M,268,15,9508,268,82,9575],
[M,269,2,9583,269,25,9606],
[M,271,2,9610,271,66,9674],
[M,271,2,9610,271,17,9625],
[M,271,2,9610,271,13,9621],
[M,271,21,9629,271,66,9674],
[M,272,2,9677,272,69,9744],
[M,272,2,9677,272,17,9692],
[M,272,2,9677,272,13,9688],
[M,272,21,9696,272,69,9744],
[M,273,2,9747,273,69,9814],
[M,273,2,9747,273,17,9762],
[M,273,2,9747,273,13,9758],
[M,273,21,9766,273,69,9814],
[M,274,2,9817,274,75,9890],
[M,274,2,9817,274,17,9832],
[M,274,2,9817,274,13,9828],
[M,274,21,9836,274,75,9890],
[M,292,22,10377,292,43,10398],
[M,286,2,10134,291,5,10354],
[M,288,30,10196,288,39,10205],
[M,288,48,10214,290,53,10347],
[M,289,32,10260,289,43,10271],
[M,289,52,10280,290,52,10346],
[M,290,34,10328,290,45,10339],
[M,282,2,10010,285,5,10131],
[M,284,34,10090,284,43,10099],
[M,276,2,9894,281,5,10007],
[M,277,7,9922,277,18,9933],
[M,292,45,10400,292,66,10421],
[M,292,68,10423,292,88,10443],
[M,292,2,10357,292,89,10444],
[M,293,2,10447,293,69,10514],
[M,293,2,10447,293,23,10468],
[M,293,2,10447,293,19,10464],
[M,293,27,10472,293,69,10514],
[M,294,2,10517,294,75,10590],
[M,294,2,10517,294,23,10538],
[M,294,2,10517,294,19,10534],
[M,294,27,10542,294,75,10590],
[M,295,2,10593,295,80,10671],
[M,295,2,10593,295,23,10614],
[M,295,2,10593,295,19,10610],
[M,295,27,10618,295,80,10671],
[M,296,2,10674,302,15,10785],
[M,296,2,10674,296,22,10694],
[M,296,2,10674,296,19,10691],
[M,297,2,10700,302,15,10785],
[M,303,2,10788,311,15,10921],
[M,303,2,10788,303,22,10808],
[M,303,2,10788,303,19,10805],
[M,304,2,10814,311,15,10921],
[M,312,2,10924,321,13,11068],
[M,312,2,10924,312,22,10944],
[M,312,2,10924,312,19,10941],
[M,313,2,10950,321,13,11068],
[M,288,20,10186,288,43,10209],
[M,288,12,10178,288,44,10210],
[M,288,6,10172,288,45,10211],
[M,289,22,10250,289,47,10275],
[M,289,14,10242,289,48,10276],
[M,289,8,10236,289,49,10277],
[M,290,24,10318,290,49,10343],
[M,290,16,10310,290,50,10344],
[M,290,10,10304,290,51,10345],
[M,284,45,10101,284,52,10108],
[M,284,24,10080,284,53,10109],
[M,284,18,10074,284,54,10110],
[M,284,56,10112,284,66,10122],
[M,284,8,10064,284,67,10123],
[M,283,10,10048,284,68,10124],
[M,277,20,9935,277,21,9936],
[M,278,4,9941,278,26,9963],
[M,278,25,9962,278,26,9963],
[M,279,15,9979,279,24,9988],
[M,278,12,9949,278,23,9960],
[M,279,15,9979,279,29,9993],
[M,279,10,9974,279,29,9993],
[M,264,29,9421,264,59,9451],
[M,264,22,9414,264,87,9479],
[M,264,68,9460,264,77,9469],
[M,264,68,9460,264,86,9478],
[M,264,62,9454,264,86,9478],
[M,264,16,9408,264,87,9479],
[M,264,8,9400,264,88,9480],
[M,258,27,9258,258,31,9262],
[M,259,29,9292,259,48,9311],
[M,259,8,9271,259,56,9319],
[M,251,21,9010,251,24,9013],
[M,252,4,9018,252,29,9043],
[M,252,28,9042,252,29,9043],
[M,253,10,9054,253,23,9067],
[M,252,12,9026,252,26,9040],
[M,244,50,8768,244,59,8777],
[M,245,35,8827,245,44,8836],
[M,244,50,8768,244,71,8789],
[M,244,44,8762,244,71,8789],
[M,244,36,8754,244,72,8790],
[M,244,29,8747,244,73,8791],
[M,244,23,8741,244,73,8791],
[M,245,35,8827,245,56,8848],
[M,245,29,8821,245,56,8848],
[M,245,21,8813,245,57,8849],
[M,245,14,8806,245,85,8877],
[M,245,66,8858,245,75,8867],
[M,245,66,8858,245,84,8876],
[M,245,60,8852,245,84,8876],
[M,245,8,8800,245,85,8877],
[M,239,44,8506,239,53,8515],
[M,240,29,8558,240,38,8567],
[M,239,44,8506,239,65,8527],
[M,239,36,8498,239,65,8527],
[M,239,29,8491,239,66,8528],
[M,239,23,8485,239,66,8528],
[M,240,29,8558,240,50,8579],
[M,240,21,8550,240,50,8579],
[M,240,14,8543,240,71,8600],
[M,240,53,8582,240,62,8591],
[M,240,8,8537,240,71,8600],
[M,236,19,8336,236,37,8354],
[M,233,16,8198,233,34,8216],
[M,231,42,8076,231,56,8090],
[M,231,34,8068,231,56,8090],
[M,231,30,8064,231,57,8091],
[M,220,37,7615,220,50,7628],
[M,215,23,7515,215,30,7522],
[M,216,28,7551,216,35,7558],
[M,216,22,7545,216,36,7559],
[M,216,16,7539,216,36,7559],
[M,216,10,7533,216,36,7559],
[M,123,2,4101,123,31,4130],
[M,186,35,6536,186,79,6580],
[M,186,62,6563,186,78,6579],
[M,186,46,6547,186,60,6561],
[M,186,13,6514,186,81,6582],
[M,141,2,4578,185,5,6500],
[M,142,7,4648,142,22,4663],
[M,141,24,4600,141,30,4606],
[M,141,41,4617,141,51,4627],
[M,133,2,4375,140,5,4575],
[M,134,30,4423,134,38,4431],
[M,134,4,4397,139,7,4569],
[M,135,6,4458,137,9,4537],
[M,135,10,4462,137,9,4537],
[M,135,14,4466,135,24,4476],
[M,134,8,4401,134,18,4411],
[M,130,2,4285,132,5,4372],
[M,131,28,4334,131,49,4355],
[M,131,21,4327,131,50,4356],
[M,131,14,4320,131,51,4357],
[M,127,2,4220,129,5,4282],
[M,128,14,4254,128,35,4275],
[M,124,2,4133,126,5,4217],
[M,125,21,4172,125,30,4181],
[M,125,14,4165,125,46,4197],
[M,186,20,6521,186,80,6581],
[M,186,2,6503,186,82,6583],
[M,122,0,4062,188,3,6602],
[M,142,24,4665,142,31,4672],
[M,147,6,4762,183,9,6486],
[M,172,8,5818,182,13,6476],
[M,173,39,5897,173,55,5913],
[M,173,32,5890,173,56,5914],
[M,174,55,5984,174,72,6001],
[M,174,48,5977,174,73,6002],
[M,175,19,6036,175,34,6051],
[M,174,18,5947,174,30,5959],
[M,173,13,5871,173,14,5872],
[M,166,8,5638,171,13,5809],
[M,167,16,5681,167,43,5708],
[M,167,32,5697,167,42,5707],
[M,169,12,5737,169,26,5751],
[M,167,13,5678,167,14,5679],
[M,164,8,5513,165,85,5629],
[M,165,50,5594,165,54,5598],
[M,165,61,5605,165,65,5609],
[M,165,47,5591,165,48,5592],
[M,165,33,5577,165,70,5614],
[M,165,26,5570,165,71,5615],
[M,158,8,5332,163,13,5504],
[M,159,16,5368,159,59,5411],
[M,161,12,5440,161,27,5455],
[M,159,13,5365,159,14,5366],
[M,157,8,5246,157,85,5323],
[M,157,58,5296,157,64,5302],
[M,157,46,5284,157,71,5309],
[M,156,8,5161,156,84,5237],
[M,156,51,5204,156,69,5222],
[M,156,44,5197,156,70,5223],
[M,153,8,5066,155,41,5152],
[M,154,10,5096,154,24,5110],
[M,150,8,4957,152,50,5057],
[M,151,10,4994,151,22,5006],
[M,149,8,4850,149,106,4948],
[M,149,59,4901,149,74,4916],
[M,149,52,4894,149,92,4934],
[M,148,8,4796,148,53,4841],
[M,148,42,4830,148,52,4840],
[M,147,23,4779,147,30,4786],
[M,146,10,4742,146,23,4755],
[M,145,10,4719,145,22,4731],
[M,144,14,4697,144,25,4708],
[M,141,56,4632,141,63,4639],
[M,173,32,5890,173,70,5928],
[M,173,59,5917,173,69,5927],
[M,173,16,5874,173,70,5928],
[M,174,48,5977,174,87,6016],
[M,174,76,6005,174,86,6015],
[M,174,32,5961,174,87,6016],
[M,175,10,6027,179,66,6378],
[M,179,35,6347,179,51,6363],
[M,179,28,6340,179,52,6364],
[M,181,35,6430,181,52,6447],
[M,181,28,6423,181,53,6448],
[M,175,17,6034,175,49,6066],
[M,179,28,6340,179,66,6378],
[M,179,55,6367,179,65,6377],
[M,179,12,6324,179,66,6378],
[M,181,28,6423,181,67,6462],
[M,181,56,6451,181,66,6461],
[M,181,12,6407,181,67,6462],
[M,170,20,5772,170,31,5783],
[M,170,12,5764,170,43,5795],
[M,170,32,5784,170,42,5794],
[M,165,26,5570,165,85,5629],
[M,165,74,5618,165,84,5628],
[M,162,12,5468,162,34,5490],
[M,162,23,5479,162,33,5489],
[M,157,53,5291,157,70,5308],
[M,157,46,5284,157,85,5323],
[M,157,74,5312,157,84,5322],
[M,156,44,5197,156,84,5237],
[M,156,73,5226,156,83,5236],
[M,155,18,5129,155,29,5140],
[M,155,30,5141,155,40,5151],
[M,152,18,5025,152,38,5045],
[M,152,39,5046,152,49,5056],
[M,149,76,4918,149,91,4933],
[M,149,52,4894,149,106,4948],
[M,149,95,4937,149,105,4947],
[M,138,6,4544,138,15,4553],
[M,131,14,4320,131,60,4366],
[M,125,21,4172,125,46,4197],
[M,125,33,4184,125,45,4196],
[M,125,14,4165,125,60,4211],
[M,125,49,4200,125,60,4211],
[M,89,2,2726,89,62,2786],
[M,57,2,1554,57,72,1624],
[M,56,2,1477,56,76,1551],
[M,55,2,1404,55,72,1474],
[M,54,2,1307,54,96,1401],
[M,53,2,1217,53,89,1304],
[M,52,2,1123,52,93,1214],
[M,51,2,1053,51,69,1120],
[M,50,2,993,50,59,1050],
[M,49,2,925,49,67,990],
[M,48,2,867,48,57,922],
[M,81,33,2606,81,67,2640],
[M,81,6,2579,81,67,2640],
[M,80,26,2544,80,54,2572],
[M,80,6,2524,80,54,2572],
[M,79,26,2482,79,61,2517],
[M,79,6,2462,79,61,2517],
[M,78,37,2399,78,93,2455],
[M,78,73,2435,78,87,2449],
[M,78,6,2368,78,93,2455],
[M,77,33,2308,77,86,2361],
[M,77,69,2344,77,80,2355],
[M,77,6,2281,77,86,2361],
[M,76,34,2220,76,88,2274],
[M,76,69,2255,76,82,2268],
[M,76,6,2192,76,88,2274],
[M,75,26,2157,75,54,2185],
[M,75,6,2137,75,54,2185],
[M,73,6,2061,73,42,2097],
[M,60,24,1680,60,29,1685],
[M,61,12,1698,61,21,1707],
[M,61,4,1690,61,34,1720],
[M,60,7,1663,60,22,1678],
[M,61,30,1716,61,34,1720],
[M,62,12,1733,62,21,1742],
[M,62,4,1725,63,35,1785],
[M,61,12,1698,61,28,1714],
[M,63,18,1768,63,35,1785],
[M,63,18,1768,63,26,1776],
[M,63,6,1756,63,14,1764],
[M,65,9,1805,65,49,1845],
[M,65,30,1826,65,48,1844],
[M,65,9,1805,65,26,1822],
[M,65,50,1846,65,56,1852],
[M,65,50,1846,65,78,1874],
[M,66,32,1907,66,67,1942],
[M,66,50,1925,66,66,1941],
[M,66,32,1907,66,47,1922],
[M,62,12,1733,62,27,1748],
[M,63,6,1756,63,35,1785],
[M,66,12,1887,66,18,1893],
[M,66,12,1887,66,74,1949],
[M,3,0,13,322,3,11072],
[M,190,0,6604,190,32,6636],
[M,123,22,4121,123,30,4129],
[M,123,15,4114,123,31,4130],
[M,122,25,4087,122,34,4096],
[M,88,0,2713,90,3,2790],
[M,89,4,2728,89,62,2786],
[M,89,19,2743,89,25,2749],
[M,89,38,2762,89,45,2769],
[M,89,52,2776,89,61,2785],
[M,89,47,2771,89,61,2785],
[M,89,27,2751,89,45,2769],
[M,89,9,2733,89,25,2749],
[M,48,4,869,48,57,922],
[M,48,25,890,48,31,896],
[M,48,49,914,48,56,921],
[M,49,4,927,49,67,990],
[M,49,13,936,49,19,942],
[M,49,35,958,49,41,964],
[M,49,59,982,49,66,989],
[M,50,4,995,50,59,1050],
[M,50,27,1018,50,33,1024],
[M,50,51,1042,50,58,1049],
[M,51,4,1055,51,69,1120],
[M,51,15,1066,51,21,1072],
[M,51,37,1088,51,43,1094],
[M,51,61,1112,51,68,1119],
[M,52,4,1125,52,93,1214],
[M,52,18,1139,52,27,1148],
[M,52,36,1157,52,45,1166],
[M,52,61,1182,52,67,1188],
[M,52,85,1206,52,92,1213],
[M,53,4,1219,53,89,1304],
[M,53,19,1234,53,25,1240],
[M,53,32,1247,53,41,1256],
[M,53,57,1272,53,63,1278],
[M,53,81,1296,53,88,1303],
[M,54,4,1309,54,96,1401],
[M,54,20,1325,54,29,1334],
[M,54,39,1344,54,48,1353],
[M,54,64,1369,54,70,1375],
[M,54,88,1393,54,95,1400],
[M,55,4,1406,55,72,1474],
[M,55,15,1417,55,24,1426],
[M,55,40,1442,55,46,1448],
[M,55,64,1466,55,71,1473],
[M,56,4,1479,56,76,1551],
[M,56,22,1497,56,28,1503],
[M,56,44,1519,56,50,1525],
[M,56,68,1543,56,75,1550],
[M,57,4,1556,57,72,1624],
[M,57,15,1567,57,24,1576],
[M,57,40,1592,57,46,1598],
[M,57,64,1616,57,71,1623],
[M,57,48,1600,57,71,1623],
[M,57,26,1578,57,46,1598],
[M,57,10,1562,57,24,1576],
[M,56,52,1527,56,75,1550],
[M,56,30,1505,56,50,1525],
[M,56,17,1492,56,28,1503],
[M,55,48,1450,55,71,1473],
[M,55,26,1428,55,46,1448],
[M,55,10,1412,55,24,1426],
[M,54,72,1377,54,95,1400],
[M,54,50,1355,54,70,1375],
[M,54,31,1336,54,48,1353],
[M,54,12,1317,54,29,1334],
[M,53,65,1280,53,88,1303],
[M,53,43,1258,53,63,1278],
[M,53,27,1242,53,41,1256],
[M,53,9,1224,53,25,1240],
[M,52,69,1190,52,92,1213],
[M,52,47,1168,52,67,1188],
[M,52,29,1150,52,45,1166],
[M,52,11,1132,52,27,1148],
[M,51,45,1096,51,68,1119],
[M,51,23,1074,51,43,1094],
[M,51,10,1061,51,21,1072],
[M,50,35,1026,50,58,1049],
[M,50,13,1004,50,33,1024],
[M,49,43,966,49,66,989],
[M,49,21,944,49,41,964],
[M,49,8,931,49,19,942],
[M,48,33,898,48,56,921],
[M,48,11,876,48,31,896],
[M,85,4,2683,85,10,2689],
[M,84,2,2658,86,5,2708],
[M,70,2,1977,83,5,2654],
[M,71,4,1997,82,7,2648],
[M,81,50,2623,81,61,2634],
[M,80,37,2555,80,48,2566],
[M,79,37,2493,79,48,2504],
[M,78,49,2411,78,63,2425],
[M,77,43,2318,77,59,2334],
[M,76,46,2232,76,59,2245],
[M,75,37,2168,75,48,2179],
[M,74,6,2104,74,32,2130],
[M,73,24,2079,73,42,2097],
[M,72,6,2026,72,34,2054],
[M,60,7,1663,60,16,1672],
[M,59,2,1636,69,5,1973]];
var _greaterequal6 = NAMESPACE.get("_greaterequal");
var _minus7 = NAMESPACE.get("_minus");
var _plus8 = NAMESPACE.get("_plus");
var builtins9 = NAMESPACE.get("builtins");
var nothing10 = NAMESPACE.get("nothing");
var raise11 = NAMESPACE.get("raise");
var string_DASH_length12 = NAMESPACE.get("string-length");
var string_DASH_repeat13 = NAMESPACE.get("string-repeat");
var torepr14 = NAMESPACE.get("torepr");
var tostring15 = NAMESPACE.get("tostring");
var $type$Boolean16 = NAMESPACE.get("$type$Boolean");
var $type$Nothing17 = NAMESPACE.get("$type$Nothing");
var $type$Number18 = NAMESPACE.get("$type$Number");
var $type$String19 = NAMESPACE.get("$type$String");
var $Hmt_DASH_doc140836 = function(mt_DASH_doc21537,Item6238,PPrintDoc6039,PPrintDoc6540,align8241,blank7442,group8643,hardline7244,if_DASH_flat8045,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,nest7849,str7050,_plus8,builtins9,nothing10,string_DASH_length12,tostring15,$type$Number18) {
var $z5354 = D;
var $f5960 = function(_) {
return R.isFunction(hardline7244.$var)?hardline7244.$var.app((0),(true)):R.ffi.throwNonFunApp(L[0],hardline7244.$var,[(0),(true)]);
};
try {
if(--R.GAS > 0) {
$z5354 = $f5960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5960,
"from":L[0]});
}
} catch($e5152) {
if(R.isCont($e5152)) {
var $ss5556 = {"from":L[0],
"go":function(hardline21661) {
return $Hhardline140762(hardline21661,Item6238,PPrintDoc6039,PPrintDoc6540,align8241,blank7442,group8643,if_DASH_flat8045,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,mt_DASH_doc21537,nest7849,str7050,_plus8,builtins9,nothing10,string_DASH_length12,tostring15,$type$Number18);
}};
$e5152.stack[R.EXN_STACKHEIGHT++] = $ss5556;
}
if(R.isPyretException($e5152)) {
$e5152.pyretStack.push(L[0]);
}
throw $e5152;
}
var $ret5758 = $Hhardline140762($z5354,Item6238,PPrintDoc6039,PPrintDoc6540,align8241,blank7442,group8643,if_DASH_flat8045,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,mt_DASH_doc21537,nest7849,str7050,_plus8,builtins9,nothing10,string_DASH_length12,tostring15,$type$Number18);
++R.GAS;
return $ret5758;
};
var $Hhardline140762 = function(hardline21661,Item6238,PPrintDoc6039,PPrintDoc6540,align8241,blank7442,group8643,if_DASH_flat8045,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,mt_DASH_doc21537,nest7849,str7050,_plus8,builtins9,nothing10,string_DASH_length12,tostring15,$type$Number18) {
var align21777 = R.makeFunction(function(d218184) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[18],1,arguments);
}
var anf_arg610195 = G(d218184,"flat-width",L[20]);
var anf_arg611196 = G(d218184,"has-hardline",L[19]);
var $z187188 = D;
var $f193194 = function(_) {
return R.isFunction(align8241.$var)?align8241.$var.app(d218184,anf_arg610195,anf_arg611196):R.ffi.throwNonFunApp(L[18],align8241.$var,[d218184,anf_arg610195,anf_arg611196]);
};
try {
if(--R.GAS > 0) {
$z187188 = $f193194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f193194,
"from":L[18]});
}
} catch($e185186) {
if(R.isCont($e185186)) {
var $ss189190 = {"from":L[18],
"go":function(ann_DASH_check_DASH_temp609197) {
return $Hann_DASH_check_DASH_temp1196198(ann_DASH_check_DASH_temp609197);
}};
$e185186.stack[R.EXN_STACKHEIGHT++] = $ss189190;
}
if(R.isPyretException($e185186)) {
$e185186.pyretStack.push(L[18]);
}
throw $e185186;
}
var $ret191192 = $Hann_DASH_check_DASH_temp1196198($z187188);
++R.GAS;
return $ret191192;
});
var group21980 = R.makeFunction(function(d220169) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[15],1,arguments);
}
var anf_arg613180 = G(d220169,"flat-width",L[17]);
var anf_arg614181 = G(d220169,"has-hardline",L[16]);
var $z172173 = D;
var $f178179 = function(_) {
return R.isFunction(group8643.$var)?group8643.$var.app(d220169,anf_arg613180,anf_arg614181):R.ffi.throwNonFunApp(L[15],group8643.$var,[d220169,anf_arg613180,anf_arg614181]);
};
try {
if(--R.GAS > 0) {
$z172173 = $f178179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f178179,
"from":L[15]});
}
} catch($e170171) {
if(R.isCont($e170171)) {
var $ss174175 = {"from":L[15],
"go":function(ann_DASH_check_DASH_temp612182) {
return $Hann_DASH_check_DASH_temp1197183(ann_DASH_check_DASH_temp612182);
}};
$e170171.stack[R.EXN_STACKHEIGHT++] = $ss174175;
}
if(R.isPyretException($e170171)) {
$e170171.pyretStack.push(L[15]);
}
throw $e170171;
}
var $ret176177 = $Hann_DASH_check_DASH_temp1197183($z172173);
++R.GAS;
return $ret176177;
});
var if_DASH_flat22181 = R.makeFunction(function(flat222153,vert223154) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[12],2,arguments);
}
var anf_arg616165 = G(flat222153,"flat-width",L[14]);
var anf_arg617166 = G(flat222153,"has-hardline",L[13]);
var $z157158 = D;
var $f163164 = function(_) {
return R.isFunction(if_DASH_flat8045.$var)?if_DASH_flat8045.$var.app(flat222153,vert223154,anf_arg616165,anf_arg617166):R.ffi.throwNonFunApp(L[12],if_DASH_flat8045.$var,[flat222153,vert223154,anf_arg616165,anf_arg617166]);
};
try {
if(--R.GAS > 0) {
$z157158 = $f163164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f163164,
"from":L[12]});
}
} catch($e155156) {
if(R.isCont($e155156)) {
var $ss159160 = {"from":L[12],
"go":function(ann_DASH_check_DASH_temp615167) {
return $Hann_DASH_check_DASH_temp1198168(ann_DASH_check_DASH_temp615167);
}};
$e155156.stack[R.EXN_STACKHEIGHT++] = $ss159160;
}
if(R.isPyretException($e155156)) {
$e155156.pyretStack.push(L[12]);
}
throw $e155156;
}
var $ret161162 = $Hann_DASH_check_DASH_temp1198168($z157158);
++R.GAS;
return $ret161162;
});
var nest22482 = R.makeFunction(function(n225137,d226138) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[9],2,arguments);
}
var anf_arg619149 = G(d226138,"flat-width",L[11]);
var anf_arg620150 = G(d226138,"has-hardline",L[10]);
var $z141142 = D;
var $f147148 = function(_) {
return R.isFunction(nest7849.$var)?nest7849.$var.app(n225137,d226138,anf_arg619149,anf_arg620150):R.ffi.throwNonFunApp(L[9],nest7849.$var,[n225137,d226138,anf_arg619149,anf_arg620150]);
};
try {
if(--R.GAS > 0) {
$z141142 = $f147148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f147148,
"from":L[9]});
}
} catch($e139140) {
if(R.isCont($e139140)) {
var $ss143144 = {"from":L[9],
"go":function(ann_DASH_check_DASH_temp618151) {
return $Hann_DASH_check_DASH_temp1199152(ann_DASH_check_DASH_temp618151);
}};
$e139140.stack[R.EXN_STACKHEIGHT++] = $ss143144;
}
if(R.isPyretException($e139140)) {
$e139140.pyretStack.push(L[9]);
}
throw $e139140;
}
var $ret145146 = $Hann_DASH_check_DASH_temp1199152($z141142);
++R.GAS;
return $ret145146;
});
var concat22779 = R.makeFunction(function(fst228123,snd229124) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[8],2,arguments);
}
var $z127128 = D;
var $f133134 = function(_) {
return R.isFunction(_plus8)?_plus8.app(fst228123,snd229124):R.ffi.throwNonFunApp(L[8],_plus8,[fst228123,snd229124]);
};
try {
if(--R.GAS > 0) {
$z127128 = $f133134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f133134,
"from":L[8]});
}
} catch($e125126) {
if(R.isCont($e125126)) {
var $ss129130 = {"from":L[8],
"go":function(ann_DASH_check_DASH_temp621135) {
return $Hann_DASH_check_DASH_temp1200136(ann_DASH_check_DASH_temp621135);
}};
$e125126.stack[R.EXN_STACKHEIGHT++] = $ss129130;
}
if(R.isPyretException($e125126)) {
$e125126.pyretStack.push(L[8]);
}
throw $e125126;
}
var $ret131132 = $Hann_DASH_check_DASH_temp1200136($z127128);
++R.GAS;
return $ret131132;
});
var blank23078 = R.makeFunction(function(n231110) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
var $z113114 = D;
var $f119120 = function(_) {
return R.isFunction(blank7442.$var)?blank7442.$var.app(n231110,n231110,(false)):R.ffi.throwNonFunApp(L[7],blank7442.$var,[n231110,n231110,(false)]);
};
try {
if(--R.GAS > 0) {
$z113114 = $f119120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f119120,
"from":L[7]});
}
} catch($e111112) {
if(R.isCont($e111112)) {
var $ss115116 = {"from":L[7],
"go":function(ann_DASH_check_DASH_temp622121) {
return $Hann_DASH_check_DASH_temp1201122(ann_DASH_check_DASH_temp622121);
}};
$e111112.stack[R.EXN_STACKHEIGHT++] = $ss115116;
}
if(R.isPyretException($e111112)) {
$e111112.pyretStack.push(L[7]);
}
throw $e111112;
}
var $ret117118 = $Hann_DASH_check_DASH_temp1201122($z113114);
++R.GAS;
return $ret117118;
});
var str23275 = R.makeFunction(function(s23397) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[5],1,arguments);
}
var $z100101 = D;
var $f106107 = function(_) {
return R.isFunction(string_DASH_length12)?string_DASH_length12.app(s23397):R.ffi.throwNonFunApp(L[6],string_DASH_length12,[s23397]);
};
try {
if(--R.GAS > 0) {
$z100101 = $f106107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f106107,
"from":L[6]});
}
} catch($e9899) {
if(R.isCont($e9899)) {
var $ss102103 = {"from":L[6],
"go":function(anf_arg624108) {
return $Hanf_arg1203109(anf_arg624108,s23397,str7050);
}};
$e9899.stack[R.EXN_STACKHEIGHT++] = $ss102103;
}
if(R.isPyretException($e9899)) {
$e9899.pyretStack.push(L[6]);
}
throw $e9899;
}
var $ret104105 = $Hanf_arg1203109($z100101,s23397,str7050);
++R.GAS;
return $ret104105;
});
var number23463 = {"$var":D,
"$name":"number"};
var anf_assign62764 = R.makeFunction(function(n23584) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
return R.checkAnnArgs([$type$Number18],[n23584],[L[4]],function() {
var $z8788 = D;
var $f9394 = function(_) {
return R.isFunction(tostring15)?tostring15.app(n23584):R.ffi.throwNonFunApp(L[3],tostring15,[n23584]);
};
try {
if(--R.GAS > 0) {
$z8788 = $f9394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9394,
"from":L[3]});
}
} catch($e8586) {
if(R.isCont($e8586)) {
var $ss8990 = {"from":L[3],
"go":function(anf_arg62695) {
return $Hanf_arg120596(anf_arg62695,str23275);
}};
$e8586.stack[R.EXN_STACKHEIGHT++] = $ss8990;
}
if(R.isPyretException($e8586)) {
$e8586.pyretStack.push(L[3]);
}
throw $e8586;
}
var $ret9192 = $Hanf_arg120596($z8788,str23275);
++R.GAS;
return $ret9192;
});
});
number23463.$var = anf_assign62764;
var $z6768 = D;
var $f7374 = function(_) {
return R.isFunction(str23275)?str23275.app(("(")):R.ffi.throwNonFunApp(L[1],str23275,[("(")]);
};
try {
if(--R.GAS > 0) {
$z6768 = $f7374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7374,
"from":L[1]});
}
} catch($e6566) {
if(R.isCont($e6566)) {
var $ss6970 = {"from":L[1],
"go":function(lparen23676) {
return $Hlparen140683(lparen23676,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,mt_DASH_doc21537,nest22482,number23463,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e6566.stack[R.EXN_STACKHEIGHT++] = $ss6970;
}
if(R.isPyretException($e6566)) {
$e6566.pyretStack.push(L[1]);
}
throw $e6566;
}
var $ret7172 = $Hlparen140683($z6768,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,mt_DASH_doc21537,nest22482,number23463,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret7172;
};
var $Hlparen140683 = function(lparen23676,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,mt_DASH_doc21537,nest22482,number23463,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z201202 = D;
var $f207208 = function(_) {
return R.isFunction(str23275)?str23275.app((")")):R.ffi.throwNonFunApp(L[21],str23275,[(")")]);
};
try {
if(--R.GAS > 0) {
$z201202 = $f207208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f207208,
"from":L[21]});
}
} catch($e199200) {
if(R.isCont($e199200)) {
var $ss203204 = {"from":L[21],
"go":function(rparen237209) {
return $Hrparen1405210(rparen237209,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e199200.stack[R.EXN_STACKHEIGHT++] = $ss203204;
}
if(R.isPyretException($e199200)) {
$e199200.pyretStack.push(L[21]);
}
throw $e199200;
}
var $ret205206 = $Hrparen1405210($z201202,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret205206;
};
var $Hrparen1405210 = function(rparen237209,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z213214 = D;
var $f219220 = function(_) {
return R.isFunction(str23275)?str23275.app(("{")):R.ffi.throwNonFunApp(L[22],str23275,[("{")]);
};
try {
if(--R.GAS > 0) {
$z213214 = $f219220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f219220,
"from":L[22]});
}
} catch($e211212) {
if(R.isCont($e211212)) {
var $ss215216 = {"from":L[22],
"go":function(lbrace238221) {
return $Hlbrace1404222(lbrace238221,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e211212.stack[R.EXN_STACKHEIGHT++] = $ss215216;
}
if(R.isPyretException($e211212)) {
$e211212.pyretStack.push(L[22]);
}
throw $e211212;
}
var $ret217218 = $Hlbrace1404222($z213214,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret217218;
};
var $Hlbrace1404222 = function(lbrace238221,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z225226 = D;
var $f231232 = function(_) {
return R.isFunction(str23275)?str23275.app(("}")):R.ffi.throwNonFunApp(L[23],str23275,[("}")]);
};
try {
if(--R.GAS > 0) {
$z225226 = $f231232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f231232,
"from":L[23]});
}
} catch($e223224) {
if(R.isCont($e223224)) {
var $ss227228 = {"from":L[23],
"go":function(rbrace239233) {
return $Hrbrace1403234(rbrace239233,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e223224.stack[R.EXN_STACKHEIGHT++] = $ss227228;
}
if(R.isPyretException($e223224)) {
$e223224.pyretStack.push(L[23]);
}
throw $e223224;
}
var $ret229230 = $Hrbrace1403234($z225226,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret229230;
};
var $Hrbrace1403234 = function(rbrace239233,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z237238 = D;
var $f243244 = function(_) {
return R.isFunction(str23275)?str23275.app(("[")):R.ffi.throwNonFunApp(L[24],str23275,[("[")]);
};
try {
if(--R.GAS > 0) {
$z237238 = $f243244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f243244,
"from":L[24]});
}
} catch($e235236) {
if(R.isCont($e235236)) {
var $ss239240 = {"from":L[24],
"go":function(lbrack240245) {
return $Hlbrack1402246(lbrack240245,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e235236.stack[R.EXN_STACKHEIGHT++] = $ss239240;
}
if(R.isPyretException($e235236)) {
$e235236.pyretStack.push(L[24]);
}
throw $e235236;
}
var $ret241242 = $Hlbrack1402246($z237238,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret241242;
};
var $Hlbrack1402246 = function(lbrack240245,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z249250 = D;
var $f255256 = function(_) {
return R.isFunction(str23275)?str23275.app(("]")):R.ffi.throwNonFunApp(L[25],str23275,[("]")]);
};
try {
if(--R.GAS > 0) {
$z249250 = $f255256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f255256,
"from":L[25]});
}
} catch($e247248) {
if(R.isCont($e247248)) {
var $ss251252 = {"from":L[25],
"go":function(rbrack241257) {
return $Hrbrack1401258(rbrack241257,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e247248.stack[R.EXN_STACKHEIGHT++] = $ss251252;
}
if(R.isPyretException($e247248)) {
$e247248.pyretStack.push(L[25]);
}
throw $e247248;
}
var $ret253254 = $Hrbrack1401258($z249250,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret253254;
};
var $Hrbrack1401258 = function(rbrack241257,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z261262 = D;
var $f267268 = function(_) {
return R.isFunction(str23275)?str23275.app(("<")):R.ffi.throwNonFunApp(L[26],str23275,[("<")]);
};
try {
if(--R.GAS > 0) {
$z261262 = $f267268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f267268,
"from":L[26]});
}
} catch($e259260) {
if(R.isCont($e259260)) {
var $ss263264 = {"from":L[26],
"go":function(langle242269) {
return $Hlangle1400270(langle242269,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e259260.stack[R.EXN_STACKHEIGHT++] = $ss263264;
}
if(R.isPyretException($e259260)) {
$e259260.pyretStack.push(L[26]);
}
throw $e259260;
}
var $ret265266 = $Hlangle1400270($z261262,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret265266;
};
var $Hlangle1400270 = function(langle242269,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z273274 = D;
var $f279280 = function(_) {
return R.isFunction(str23275)?str23275.app((">")):R.ffi.throwNonFunApp(L[27],str23275,[(">")]);
};
try {
if(--R.GAS > 0) {
$z273274 = $f279280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f279280,
"from":L[27]});
}
} catch($e271272) {
if(R.isCont($e271272)) {
var $ss275276 = {"from":L[27],
"go":function(rangle243281) {
return $Hrangle1399282(rangle243281,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e271272.stack[R.EXN_STACKHEIGHT++] = $ss275276;
}
if(R.isPyretException($e271272)) {
$e271272.pyretStack.push(L[27]);
}
throw $e271272;
}
var $ret277278 = $Hrangle1399282($z273274,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret277278;
};
var $Hrangle1399282 = function(rangle243281,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z285286 = D;
var $f291292 = function(_) {
return R.isFunction(str23275)?str23275.app((",")):R.ffi.throwNonFunApp(L[28],str23275,[(",")]);
};
try {
if(--R.GAS > 0) {
$z285286 = $f291292();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f291292,
"from":L[28]});
}
} catch($e283284) {
if(R.isCont($e283284)) {
var $ss287288 = {"from":L[28],
"go":function(comma244293) {
return $Hcomma1398294(comma244293,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e283284.stack[R.EXN_STACKHEIGHT++] = $ss287288;
}
if(R.isPyretException($e283284)) {
$e283284.pyretStack.push(L[28]);
}
throw $e283284;
}
var $ret289290 = $Hcomma1398294($z285286,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret289290;
};
var $Hcomma1398294 = function(comma244293,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var sbreak245295 = {"$var":D,
"$name":"sbreak"};
var anf_assign630296 = R.makeFunction(function(n246309) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
var $z312313 = D;
var $f318319 = function(_) {
return R.isFunction(blank23078)?blank23078.app(n246309):R.ffi.throwNonFunApp(L[31],blank23078,[n246309]);
};
try {
if(--R.GAS > 0) {
$z312313 = $f318319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f318319,
"from":L[31]});
}
} catch($e310311) {
if(R.isCont($e310311)) {
var $ss314315 = {"from":L[31],
"go":function(anf_arg629320) {
return $Hanf_arg1207321(anf_arg629320,hardline21661,if_DASH_flat22181);
}};
$e310311.stack[R.EXN_STACKHEIGHT++] = $ss314315;
}
if(R.isPyretException($e310311)) {
$e310311.pyretStack.push(L[31]);
}
throw $e310311;
}
var $ret316317 = $Hanf_arg1207321($z312313,hardline21661,if_DASH_flat22181);
++R.GAS;
return $ret316317;
});
sbreak245295.$var = anf_assign630296;
var $z299300 = D;
var $f305306 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app((1)):R.ffi.throwNonFunApp(L[29],sbreak245295.$var,[(1)]);
};
try {
if(--R.GAS > 0) {
$z299300 = $f305306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f305306,
"from":L[29]});
}
} catch($e297298) {
if(R.isCont($e297298)) {
var $ss301302 = {"from":L[29],
"go":function(anf_arg631307) {
return $Hanf_arg1397308(anf_arg631307,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,comma244293,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e297298.stack[R.EXN_STACKHEIGHT++] = $ss301302;
}
if(R.isPyretException($e297298)) {
$e297298.pyretStack.push(L[29]);
}
throw $e297298;
}
var $ret303304 = $Hanf_arg1397308($z299300,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,comma244293,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret303304;
};
var $Hanf_arg1397308 = function(anf_arg631307,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,comma244293,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var $z324325 = D;
var $f330331 = function(_) {
return R.isFunction(_plus8)?_plus8.app(comma244293,anf_arg631307):R.ffi.throwNonFunApp(L[32],_plus8,[comma244293,anf_arg631307]);
};
try {
if(--R.GAS > 0) {
$z324325 = $f330331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f330331,
"from":L[32]});
}
} catch($e322323) {
if(R.isCont($e322323)) {
var $ss326327 = {"from":L[32],
"go":function(commabreak247332) {
return $Hcommabreak1396333(commabreak247332,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,comma244293,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,_plus8,builtins9,nothing10,$type$Number18);
}};
$e322323.stack[R.EXN_STACKHEIGHT++] = $ss326327;
}
if(R.isPyretException($e322323)) {
$e322323.pyretStack.push(L[32]);
}
throw $e322323;
}
var $ret328329 = $Hcommabreak1396333($z324325,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,comma244293,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret328329;
};
var $Hcommabreak1396333 = function(commabreak247332,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,comma244293,concat22779,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,_plus8,builtins9,nothing10,$type$Number18) {
var flow_DASH_map248334 = {"$var":D,
"$name":"flow-map"};
var flow249336 = {"$var":D,
"$name":"flow"};
var vert250338 = {"$var":D,
"$name":"vert"};
var parens251340 = {"$var":D,
"$name":"parens"};
var braces252342 = {"$var":D,
"$name":"braces"};
var brackets253344 = {"$var":D,
"$name":"brackets"};
var anf_assign648335 = R.makeFunction(function(sep254426,f255427,items256428) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[44],3,arguments);
}
var anf_fun633439 = G(lists321,"fold",L[47]);
var anf_arg647440 = R.makeFunction(function(acc257443,item258444) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[45],2,arguments);
}
var $z447448 = D;
var $f453454 = function(_) {
return R.isFunction(is_DASH_mt_DASH_doc6747.$var)?is_DASH_mt_DASH_doc6747.$var.app(acc257443):R.ffi.throwNonFunApp(L[46],is_DASH_mt_DASH_doc6747.$var,[acc257443]);
};
try {
if(--R.GAS > 0) {
$z447448 = $f453454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f453454,
"from":L[46]});
}
} catch($e445446) {
if(R.isCont($e445446)) {
var $ss449450 = {"from":L[46],
"go":function(if_DASH_82455) {
return $Hif_DASH_1213456(if_DASH_82455,acc257443,f255427,group21980,item258444,sep254426,_plus8);
}};
$e445446.stack[R.EXN_STACKHEIGHT++] = $ss449450;
}
if(R.isPyretException($e445446)) {
$e445446.pyretStack.push(L[46]);
}
throw $e445446;
}
var $ret451452 = $Hif_DASH_1213456($z447448,acc257443,f255427,group21980,item258444,sep254426,_plus8);
++R.GAS;
return $ret451452;
});
var $z431432 = D;
var $f437438 = function(_) {
return R.isFunction(anf_fun633439)?anf_fun633439.app(anf_arg647440,mt_DASH_doc21537,items256428):R.ffi.throwNonFunApp(L[44],anf_fun633439,[anf_arg647440,mt_DASH_doc21537,items256428]);
};
try {
if(--R.GAS > 0) {
$z431432 = $f437438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f437438,
"from":L[44]});
}
} catch($e429430) {
if(R.isCont($e429430)) {
var $ss433434 = {"from":L[44],
"go":function(ann_DASH_check_DASH_temp632441) {
return $Hann_DASH_check_DASH_temp1214442(ann_DASH_check_DASH_temp632441);
}};
$e429430.stack[R.EXN_STACKHEIGHT++] = $ss433434;
}
if(R.isPyretException($e429430)) {
$e429430.pyretStack.push(L[44]);
}
throw $e429430;
}
var $ret435436 = $Hann_DASH_check_DASH_temp1214442($z431432);
++R.GAS;
return $ret435436;
});
flow_DASH_map248334.$var = anf_assign648335;
var anf_assign653337 = R.makeFunction(function(items259413) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[42],1,arguments);
}
var $z416417 = D;
var $f422423 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app((1)):R.ffi.throwNonFunApp(L[43],sbreak245295.$var,[(1)]);
};
try {
if(--R.GAS > 0) {
$z416417 = $f422423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f422423,
"from":L[43]});
}
} catch($e414415) {
if(R.isCont($e414415)) {
var $ss418419 = {"from":L[43],
"go":function(anf_arg650424) {
return $Hanf_arg1216425(anf_arg650424,flow_DASH_map248334,items259413);
}};
$e414415.stack[R.EXN_STACKHEIGHT++] = $ss418419;
}
if(R.isPyretException($e414415)) {
$e414415.pyretStack.push(L[43]);
}
throw $e414415;
}
var $ret420421 = $Hanf_arg1216425($z416417,flow_DASH_map248334,items259413);
++R.GAS;
return $ret420421;
});
flow249336.$var = anf_assign653337;
var anf_assign657339 = R.makeFunction(function(items261397) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[40],1,arguments);
}
var anf_arg656408 = R.makeFunction(function(x262411) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[41],1,arguments);
}
var ann_DASH_check_DASH_temp655412 = x262411;
return ann_DASH_check_DASH_temp655412;
});
var $z400401 = D;
var $f406407 = function(_) {
return R.isFunction(flow_DASH_map248334.$var)?flow_DASH_map248334.$var.app(hardline21661,anf_arg656408,items261397):R.ffi.throwNonFunApp(L[40],flow_DASH_map248334.$var,[hardline21661,anf_arg656408,items261397]);
};
try {
if(--R.GAS > 0) {
$z400401 = $f406407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f406407,
"from":L[40]});
}
} catch($e398399) {
if(R.isCont($e398399)) {
var $ss402403 = {"from":L[40],
"go":function(ann_DASH_check_DASH_temp654409) {
return $Hann_DASH_check_DASH_temp1217410(ann_DASH_check_DASH_temp654409);
}};
$e398399.stack[R.EXN_STACKHEIGHT++] = $ss402403;
}
if(R.isPyretException($e398399)) {
$e398399.pyretStack.push(L[40]);
}
throw $e398399;
}
var $ret404405 = $Hann_DASH_check_DASH_temp1217410($z400401);
++R.GAS;
return $ret404405;
});
vert250338.$var = anf_assign657339;
var anf_assign661341 = R.makeFunction(function(d263384) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[38],1,arguments);
}
var $z387388 = D;
var $f393394 = function(_) {
return R.isFunction(_plus8)?_plus8.app(lparen23676,d263384):R.ffi.throwNonFunApp(L[39],_plus8,[lparen23676,d263384]);
};
try {
if(--R.GAS > 0) {
$z387388 = $f393394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f393394,
"from":L[39]});
}
} catch($e385386) {
if(R.isCont($e385386)) {
var $ss389390 = {"from":L[39],
"go":function(anf_arg659395) {
return $Hanf_arg1220396(anf_arg659395,group21980,rparen237209,_plus8);
}};
$e385386.stack[R.EXN_STACKHEIGHT++] = $ss389390;
}
if(R.isPyretException($e385386)) {
$e385386.pyretStack.push(L[39]);
}
throw $e385386;
}
var $ret391392 = $Hanf_arg1220396($z387388,group21980,rparen237209,_plus8);
++R.GAS;
return $ret391392;
});
parens251340.$var = anf_assign661341;
var anf_assign665343 = R.makeFunction(function(d264371) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[36],1,arguments);
}
var $z374375 = D;
var $f380381 = function(_) {
return R.isFunction(_plus8)?_plus8.app(lbrace238221,d264371):R.ffi.throwNonFunApp(L[37],_plus8,[lbrace238221,d264371]);
};
try {
if(--R.GAS > 0) {
$z374375 = $f380381();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f380381,
"from":L[37]});
}
} catch($e372373) {
if(R.isCont($e372373)) {
var $ss376377 = {"from":L[37],
"go":function(anf_arg663382) {
return $Hanf_arg1223383(anf_arg663382,group21980,rbrace239233,_plus8);
}};
$e372373.stack[R.EXN_STACKHEIGHT++] = $ss376377;
}
if(R.isPyretException($e372373)) {
$e372373.pyretStack.push(L[37]);
}
throw $e372373;
}
var $ret378379 = $Hanf_arg1223383($z374375,group21980,rbrace239233,_plus8);
++R.GAS;
return $ret378379;
});
braces252342.$var = anf_assign665343;
var anf_assign669345 = R.makeFunction(function(d265358) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[34],1,arguments);
}
var $z361362 = D;
var $f367368 = function(_) {
return R.isFunction(_plus8)?_plus8.app(lbrack240245,d265358):R.ffi.throwNonFunApp(L[35],_plus8,[lbrack240245,d265358]);
};
try {
if(--R.GAS > 0) {
$z361362 = $f367368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f367368,
"from":L[35]});
}
} catch($e359360) {
if(R.isCont($e359360)) {
var $ss363364 = {"from":L[35],
"go":function(anf_arg667369) {
return $Hanf_arg1226370(anf_arg667369,group21980,rbrack241257,_plus8);
}};
$e359360.stack[R.EXN_STACKHEIGHT++] = $ss363364;
}
if(R.isPyretException($e359360)) {
$e359360.pyretStack.push(L[35]);
}
throw $e359360;
}
var $ret365366 = $Hanf_arg1226370($z361362,group21980,rbrack241257,_plus8);
++R.GAS;
return $ret365366;
});
brackets253344.$var = anf_assign669345;
var $z348349 = D;
var $f354355 = function(_) {
return R.isFunction(str23275)?str23275.app(("'")):R.ffi.throwNonFunApp(L[33],str23275,[("'")]);
};
try {
if(--R.GAS > 0) {
$z348349 = $f354355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f354355,
"from":L[33]});
}
} catch($e346347) {
if(R.isCont($e346347)) {
var $ss350351 = {"from":L[33],
"go":function(str_DASH_squote266356) {
return $Hstr_DASH_squote1395357(str_DASH_squote266356,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,flow_DASH_map248334,flow249336,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,vert250338,_plus8,builtins9,nothing10,$type$Number18);
}};
$e346347.stack[R.EXN_STACKHEIGHT++] = $ss350351;
}
if(R.isPyretException($e346347)) {
$e346347.pyretStack.push(L[33]);
}
throw $e346347;
}
var $ret352353 = $Hstr_DASH_squote1395357($z348349,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,flow_DASH_map248334,flow249336,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,vert250338,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret352353;
};
var $Hstr_DASH_squote1395357 = function(str_DASH_squote266356,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,flow_DASH_map248334,flow249336,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str23275,vert250338,_plus8,builtins9,nothing10,$type$Number18) {
var $z459460 = D;
var $f465466 = function(_) {
return R.isFunction(str23275)?str23275.app(("\"")):R.ffi.throwNonFunApp(L[48],str23275,[("\"")]);
};
try {
if(--R.GAS > 0) {
$z459460 = $f465466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f465466,
"from":L[48]});
}
} catch($e457458) {
if(R.isCont($e457458)) {
var $ss461462 = {"from":L[48],
"go":function(str_DASH_dquote267467) {
return $Hstr_DASH_dquote1394468(str_DASH_dquote267467,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,flow_DASH_map248334,flow249336,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str_DASH_squote266356,str23275,vert250338,_plus8,builtins9,nothing10,$type$Number18);
}};
$e457458.stack[R.EXN_STACKHEIGHT++] = $ss461462;
}
if(R.isPyretException($e457458)) {
$e457458.pyretStack.push(L[48]);
}
throw $e457458;
}
var $ret463464 = $Hstr_DASH_dquote1394468($z459460,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,flow_DASH_map248334,flow249336,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str_DASH_squote266356,str23275,vert250338,_plus8,builtins9,nothing10,$type$Number18);
++R.GAS;
return $ret463464;
};
var $Hstr_DASH_dquote1394468 = function(str_DASH_dquote267467,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,flow_DASH_map248334,flow249336,group21980,hardline21661,if_DASH_flat22181,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,langle242269,lbrace238221,lbrack240245,list1948,lists321,lists426,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,rangle243281,rbrace239233,rbrack241257,rparen237209,sbreak245295,str_DASH_squote266356,str23275,vert250338,_plus8,builtins9,nothing10,$type$Number18) {
var dquote268469 = {"$var":D,
"$name":"dquote"};
var squote269471 = {"$var":D,
"$name":"squote"};
var hang270473 = {"$var":D,
"$name":"hang"};
var prefix271475 = {"$var":D,
"$name":"prefix"};
var infix272477 = {"$var":D,
"$name":"infix"};
var infix_DASH_break273479 = {"$var":D,
"$name":"infix-break"};
var surround274481 = {"$var":D,
"$name":"surround"};
var soft_DASH_surround275483 = {"$var":D,
"$name":"soft-surround"};
var separate276485 = {"$var":D,
"$name":"separate"};
var surround_DASH_separate277487 = {"$var":D,
"$name":"surround-separate"};
var label_DASH_align_DASH_surround278489 = {"$var":D,
"$name":"label-align-surround"};
var anf_assign673470 = R.makeFunction(function(s279683) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[102],1,arguments);
}
var $z686687 = D;
var $f692693 = function(_) {
return R.isFunction(_plus8)?_plus8.app(str_DASH_dquote267467,s279683):R.ffi.throwNonFunApp(L[103],_plus8,[str_DASH_dquote267467,s279683]);
};
try {
if(--R.GAS > 0) {
$z686687 = $f692693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f692693,
"from":L[103]});
}
} catch($e684685) {
if(R.isCont($e684685)) {
var $ss688689 = {"from":L[103],
"go":function(anf_arg671694) {
return $Hanf_arg1229695(anf_arg671694,group21980,str_DASH_dquote267467,_plus8);
}};
$e684685.stack[R.EXN_STACKHEIGHT++] = $ss688689;
}
if(R.isPyretException($e684685)) {
$e684685.pyretStack.push(L[103]);
}
throw $e684685;
}
var $ret690691 = $Hanf_arg1229695($z686687,group21980,str_DASH_dquote267467,_plus8);
++R.GAS;
return $ret690691;
});
dquote268469.$var = anf_assign673470;
var anf_assign677472 = R.makeFunction(function(s280670) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[100],1,arguments);
}
var $z673674 = D;
var $f679680 = function(_) {
return R.isFunction(_plus8)?_plus8.app(str_DASH_squote266356,s280670):R.ffi.throwNonFunApp(L[101],_plus8,[str_DASH_squote266356,s280670]);
};
try {
if(--R.GAS > 0) {
$z673674 = $f679680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f679680,
"from":L[101]});
}
} catch($e671672) {
if(R.isCont($e671672)) {
var $ss675676 = {"from":L[101],
"go":function(anf_arg675681) {
return $Hanf_arg1232682(anf_arg675681,group21980,str_DASH_squote266356,_plus8);
}};
$e671672.stack[R.EXN_STACKHEIGHT++] = $ss675676;
}
if(R.isPyretException($e671672)) {
$e671672.pyretStack.push(L[101]);
}
throw $e671672;
}
var $ret677678 = $Hanf_arg1232682($z673674,group21980,str_DASH_squote266356,_plus8);
++R.GAS;
return $ret677678;
});
squote269471.$var = anf_assign677472;
var anf_assign680474 = R.makeFunction(function(i281656,d282657) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[98],2,arguments);
}
var $z660661 = D;
var $f666667 = function(_) {
return R.isFunction(nest22482)?nest22482.app(i281656,d282657):R.ffi.throwNonFunApp(L[99],nest22482,[i281656,d282657]);
};
try {
if(--R.GAS > 0) {
$z660661 = $f666667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f666667,
"from":L[99]});
}
} catch($e658659) {
if(R.isCont($e658659)) {
var $ss662663 = {"from":L[99],
"go":function(anf_arg679668) {
return $Hanf_arg1234669(anf_arg679668,align21777);
}};
$e658659.stack[R.EXN_STACKHEIGHT++] = $ss662663;
}
if(R.isPyretException($e658659)) {
$e658659.pyretStack.push(L[99]);
}
throw $e658659;
}
var $ret664665 = $Hanf_arg1234669($z660661,align21777);
++R.GAS;
return $ret664665;
});
hang270473.$var = anf_assign680474;
var anf_assign686476 = R.makeFunction(function(n283640,b284641,x285642,y286643) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[96],4,arguments);
}
var $z646647 = D;
var $f652653 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app(b284641):R.ffi.throwNonFunApp(L[97],sbreak245295.$var,[b284641]);
};
try {
if(--R.GAS > 0) {
$z646647 = $f652653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f652653,
"from":L[97]});
}
} catch($e644645) {
if(R.isCont($e644645)) {
var $ss648649 = {"from":L[97],
"go":function(anf_arg682654) {
return $Hanf_arg1239655(anf_arg682654,group21980,n283640,nest22482,x285642,y286643,_plus8);
}};
$e644645.stack[R.EXN_STACKHEIGHT++] = $ss648649;
}
if(R.isPyretException($e644645)) {
$e644645.pyretStack.push(L[97]);
}
throw $e644645;
}
var $ret650651 = $Hanf_arg1239655($z646647,group21980,n283640,nest22482,x285642,y286643,_plus8);
++R.GAS;
return $ret650651;
});
prefix271475.$var = anf_assign686476;
var anf_assign691478 = R.makeFunction(function(n287623,b288624,op289625,x290626,y291627) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[89],5,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Number18,PPrintDoc6039,PPrintDoc6039,PPrintDoc6039],[n287623,b288624,op289625,x290626,y291627],[L[91],L[92],L[93],L[94],L[95]],function() {
var $z630631 = D;
var $f636637 = function(_) {
return R.isFunction(blank23078)?blank23078.app(b288624):R.ffi.throwNonFunApp(L[90],blank23078,[b288624]);
};
try {
if(--R.GAS > 0) {
$z630631 = $f636637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f636637,
"from":L[90]});
}
} catch($e628629) {
if(R.isCont($e628629)) {
var $ss632633 = {"from":L[90],
"go":function(anf_arg688638) {
return $Hanf_arg1243639(anf_arg688638,b288624,n287623,op289625,prefix271475,x290626,y291627,_plus8);
}};
$e628629.stack[R.EXN_STACKHEIGHT++] = $ss632633;
}
if(R.isPyretException($e628629)) {
$e628629.pyretStack.push(L[90]);
}
throw $e628629;
}
var $ret634635 = $Hanf_arg1243639($z630631,b288624,n287623,op289625,prefix271475,x290626,y291627,_plus8);
++R.GAS;
return $ret634635;
});
});
infix272477.$var = anf_assign691478;
var anf_assign696480 = R.makeFunction(function(n292606,b293607,op294608,x295609,y296610) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[82],5,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Number18,PPrintDoc6039,PPrintDoc6039,PPrintDoc6039],[n292606,b293607,op294608,x295609,y296610],[L[84],L[85],L[86],L[87],L[88]],function() {
var $z613614 = D;
var $f619620 = function(_) {
return R.isFunction(blank23078)?blank23078.app(b293607):R.ffi.throwNonFunApp(L[83],blank23078,[b293607]);
};
try {
if(--R.GAS > 0) {
$z613614 = $f619620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f619620,
"from":L[83]});
}
} catch($e611612) {
if(R.isCont($e611612)) {
var $ss615616 = {"from":L[83],
"go":function(anf_arg693621) {
return $Hanf_arg1247622(anf_arg693621,b293607,n292606,op294608,prefix271475,x295609,y296610,_plus8);
}};
$e611612.stack[R.EXN_STACKHEIGHT++] = $ss615616;
}
if(R.isPyretException($e611612)) {
$e611612.pyretStack.push(L[83]);
}
throw $e611612;
}
var $ret617618 = $Hanf_arg1247622($z613614,b293607,n292606,op294608,prefix271475,x295609,y296610,_plus8);
++R.GAS;
return $ret617618;
});
});
infix_DASH_break273479.$var = anf_assign696480;
var anf_assign718482 = R.makeFunction(function(n297589,b298590,open299591,contents300592,close301593) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[75],5,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Number18,PPrintDoc6039,PPrintDoc6039,PPrintDoc6039],[n297589,b298590,open299591,contents300592,close301593],[L[77],L[78],L[79],L[80],L[81]],function() {
var $z596597 = D;
var $f602603 = function(_) {
return R.isFunction(is_DASH_mt_DASH_doc6747.$var)?is_DASH_mt_DASH_doc6747.$var.app(close301593):R.ffi.throwNonFunApp(L[76],is_DASH_mt_DASH_doc6747.$var,[close301593]);
};
try {
if(--R.GAS > 0) {
$z596597 = $f602603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f602603,
"from":L[76]});
}
} catch($e594595) {
if(R.isCont($e594595)) {
var $ss598599 = {"from":L[76],
"go":function(if_DASH_83604) {
return $Hif_DASH_1261605(if_DASH_83604,b298590,close301593,contents300592,group21980,n297589,nest22482,open299591,sbreak245295,_plus8);
}};
$e594595.stack[R.EXN_STACKHEIGHT++] = $ss598599;
}
if(R.isPyretException($e594595)) {
$e594595.pyretStack.push(L[76]);
}
throw $e594595;
}
var $ret600601 = $Hif_DASH_1261605($z596597,b298590,close301593,contents300592,group21980,n297589,nest22482,open299591,sbreak245295,_plus8);
++R.GAS;
return $ret600601;
});
});
surround274481.$var = anf_assign718482;
var anf_assign743484 = R.makeFunction(function(n302572,b303573,open304574,contents305575,close306576) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[68],5,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Number18,PPrintDoc6039,PPrintDoc6039,PPrintDoc6039],[n302572,b303573,open304574,contents305575,close306576],[L[70],L[71],L[72],L[73],L[74]],function() {
var $z579580 = D;
var $f585586 = function(_) {
return R.isFunction(is_DASH_mt_DASH_doc6747.$var)?is_DASH_mt_DASH_doc6747.$var.app(close306576):R.ffi.throwNonFunApp(L[69],is_DASH_mt_DASH_doc6747.$var,[close306576]);
};
try {
if(--R.GAS > 0) {
$z579580 = $f585586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f585586,
"from":L[69]});
}
} catch($e577578) {
if(R.isCont($e577578)) {
var $ss581582 = {"from":L[69],
"go":function(if_DASH_84587) {
return $Hif_DASH_1278588(if_DASH_84587,b303573,close306576,contents305575,group21980,n302572,nest22482,open304574,sbreak245295,_plus8);
}};
$e577578.stack[R.EXN_STACKHEIGHT++] = $ss581582;
}
if(R.isPyretException($e577578)) {
$e577578.pyretStack.push(L[69]);
}
throw $e577578;
}
var $ret583584 = $Hif_DASH_1278588($z579580,b303573,close306576,contents305575,group21980,n302572,nest22482,open304574,sbreak245295,_plus8);
++R.GAS;
return $ret583584;
});
});
soft_DASH_surround275483.$var = anf_assign743484;
var anf_assign761486 = R.makeFunction(function(sep307542,docs308543) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[62],2,arguments);
}
return R.checkAnnArgs([PPrintDoc6039,R.getDotAnn(L[66],"lists",lists426,"List")],[sep307542,docs308543],[L[67],L[66]],function() {
var anf_fun745554 = G(lists321,"fold",L[65]);
var anf_arg760555 = R.makeFunction(function(acc309558,d310559) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[63],2,arguments);
}
var $z562563 = D;
var $f568569 = function(_) {
return R.isFunction(is_DASH_mt_DASH_doc6747.$var)?is_DASH_mt_DASH_doc6747.$var.app(d310559):R.ffi.throwNonFunApp(L[64],is_DASH_mt_DASH_doc6747.$var,[d310559]);
};
try {
if(--R.GAS > 0) {
$z562563 = $f568569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f568569,
"from":L[64]});
}
} catch($e560561) {
if(R.isCont($e560561)) {
var $ss564565 = {"from":L[64],
"go":function(if_DASH_86570) {
return $Hif_DASH_1284571(if_DASH_86570,acc309558,d310559,is_DASH_mt_DASH_doc6747,sep307542,_plus8);
}};
$e560561.stack[R.EXN_STACKHEIGHT++] = $ss564565;
}
if(R.isPyretException($e560561)) {
$e560561.pyretStack.push(L[64]);
}
throw $e560561;
}
var $ret566567 = $Hif_DASH_1284571($z562563,acc309558,d310559,is_DASH_mt_DASH_doc6747,sep307542,_plus8);
++R.GAS;
return $ret566567;
});
var $z546547 = D;
var $f552553 = function(_) {
return R.isFunction(anf_fun745554)?anf_fun745554.app(anf_arg760555,mt_DASH_doc21537,docs308543):R.ffi.throwNonFunApp(L[62],anf_fun745554,[anf_arg760555,mt_DASH_doc21537,docs308543]);
};
try {
if(--R.GAS > 0) {
$z546547 = $f552553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f552553,
"from":L[62]});
}
} catch($e544545) {
if(R.isCont($e544545)) {
var $ss548549 = {"from":L[62],
"go":function(ann_DASH_check_DASH_temp744556) {
return $Hann_DASH_check_DASH_temp1285557(ann_DASH_check_DASH_temp744556);
}};
$e544545.stack[R.EXN_STACKHEIGHT++] = $ss548549;
}
if(R.isPyretException($e544545)) {
$e544545.pyretStack.push(L[62]);
}
throw $e544545;
}
var $ret550551 = $Hann_DASH_check_DASH_temp1285557($z546547);
++R.GAS;
return $ret550551;
});
});
separate276485.$var = anf_assign761486;
var anf_assign773488 = R.makeFunction(function(n311522,b312523,void313524,open314525,sep315526,close316527,docs317528) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[52],7,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Number18,PPrintDoc6039,PPrintDoc6039,PPrintDoc6039,PPrintDoc6039,R.getDotAnn(L[55],"lists",lists426,"List")],[n311522,b312523,void313524,open314525,sep315526,close316527,docs317528],[L[56],L[57],L[58],L[59],L[60],L[61],L[55]],function() {
var anf_fun763539 = G(lists321,"is-empty",L[54]);
var $z531532 = D;
var $f537538 = function(_) {
return R.isFunction(anf_fun763539)?anf_fun763539.app(docs317528):R.ffi.throwNonFunApp(L[53],anf_fun763539,[docs317528]);
};
try {
if(--R.GAS > 0) {
$z531532 = $f537538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f537538,
"from":L[53]});
}
} catch($e529530) {
if(R.isCont($e529530)) {
var $ss533534 = {"from":L[53],
"go":function(if_DASH_87540) {
return $Hif_DASH_1289541(if_DASH_87540,b312523,close316527,docs317528,n311522,open314525,sep315526,separate276485,surround274481,void313524);
}};
$e529530.stack[R.EXN_STACKHEIGHT++] = $ss533534;
}
if(R.isPyretException($e529530)) {
$e529530.pyretStack.push(L[53]);
}
throw $e529530;
}
var $ret535536 = $Hif_DASH_1289541($z531532,b312523,close316527,docs317528,n311522,open314525,sep315526,separate276485,surround274481,void313524);
++R.GAS;
return $ret535536;
});
});
surround_DASH_separate277487.$var = anf_assign773488;
var anf_assign784490 = R.makeFunction(function(label318505,open319506,sep320507,contents321508,close322509) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[50],5,arguments);
}
var $z512513 = D;
var $f518519 = function(_) {
return R.isFunction(separate276485.$var)?separate276485.$var.app(sep320507,contents321508):R.ffi.throwNonFunApp(L[51],separate276485.$var,[sep320507,contents321508]);
};
try {
if(--R.GAS > 0) {
$z512513 = $f518519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f518519,
"from":L[51]});
}
} catch($e510511) {
if(R.isCont($e510511)) {
var $ss514515 = {"from":L[51],
"go":function(anf_arg775520) {
return $Hanf_arg1299521(anf_arg775520,align21777,close322509,group21980,label318505,open319506,sbreak245295,_plus8);
}};
$e510511.stack[R.EXN_STACKHEIGHT++] = $ss514515;
}
if(R.isPyretException($e510511)) {
$e510511.pyretStack.push(L[51]);
}
throw $e510511;
}
var $ret516517 = $Hanf_arg1299521($z512513,align21777,close322509,group21980,label318505,open319506,sbreak245295,_plus8);
++R.GAS;
return $ret516517;
});
label_DASH_align_DASH_surround278489.$var = anf_assign784490;
nothing10;
var result_DASH_after_DASH_checks1323503 = nothing10;
var anf_fun785501 = G(builtins9,"current-checker",L[49]);
var $z493494 = D;
var $f499500 = function(_) {
return R.isFunction(anf_fun785501)?anf_fun785501.app():R.ffi.throwNonFunApp(L[49],anf_fun785501,[]);
};
try {
if(--R.GAS > 0) {
$z493494 = $f499500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f499500,
"from":L[49]});
}
} catch($e491492) {
if(R.isCont($e491492)) {
var $ss495496 = {"from":L[49],
"go":function(anf_bracket786502) {
return $Hanf_bracket1393504(anf_bracket786502,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,list1948,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,_plus8,builtins9);
}};
$e491492.stack[R.EXN_STACKHEIGHT++] = $ss495496;
}
if(R.isPyretException($e491492)) {
$e491492.pyretStack.push(L[49]);
}
throw $e491492;
}
var $ret497498 = $Hanf_bracket1393504($z493494,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,list1948,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,_plus8,builtins9);
++R.GAS;
return $ret497498;
};
var $Hanf_bracket1393504 = function(anf_bracket786502,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,list1948,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,_plus8,builtins9) {
var anf_fun787709 = G(anf_bracket786502,"run-checks",L[49]);
var anf_fun788706 = G(list1948,"make",L[49]);
var anf_obj921711 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[104],0,arguments);
}
var anf_fun790723 = G(list1948,"make",L[105]);
var $z715716 = D;
var $f721722 = function(_) {
return R.isFunction(anf_fun790723)?anf_fun790723.app([("This"),("is"),("a"),("sentence"),("with"),("eight"),("words")]):R.ffi.throwNonFunApp(L[105],anf_fun790723,[[("This"),("is"),("a"),("sentence"),("with"),("eight"),("words")]]);
};
try {
if(--R.GAS > 0) {
$z715716 = $f721722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f721722,
"from":L[105]});
}
} catch($e713714) {
if(R.isCont($e713714)) {
var $ss717718 = {"from":L[105],
"go":function(anf_bracket791724) {
return $Hanf_bracket1387725(anf_bracket791724,flow249336,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
}};
$e713714.stack[R.EXN_STACKHEIGHT++] = $ss717718;
}
if(R.isPyretException($e713714)) {
$e713714.pyretStack.push(L[105]);
}
throw $e713714;
}
var $ret719720 = $Hanf_bracket1387725($z715716,flow249336,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
++R.GAS;
return $ret719720;
});
var anf_obj922712 = R.makeSrcloc(L[104]);
var anf_array_val923707 = R.makeObject({"name":("check-block-1"),
"run":anf_obj921711,
"location":anf_obj922712});
var $z698699 = D;
var $f704705 = function(_) {
return R.isFunction(anf_fun788706)?anf_fun788706.app([anf_array_val923707]):R.ffi.throwNonFunApp(L[49],anf_fun788706,[[anf_array_val923707]]);
};
try {
if(--R.GAS > 0) {
$z698699 = $f704705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f704705,
"from":L[49]});
}
} catch($e696697) {
if(R.isCont($e696697)) {
var $ss700701 = {"from":L[49],
"go":function(anf_arg924708) {
return $Hanf_arg1392710(anf_arg924708,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,anf_fun787709,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,builtins9);
}};
$e696697.stack[R.EXN_STACKHEIGHT++] = $ss700701;
}
if(R.isPyretException($e696697)) {
$e696697.pyretStack.push(L[49]);
}
throw $e696697;
}
var $ret702703 = $Hanf_arg1392710($z698699,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,anf_fun787709,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,builtins9);
++R.GAS;
return $ret702703;
};
var $Hanf_arg1392710 = function(anf_arg924708,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,anf_fun787709,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,builtins9) {
var $z728729 = D;
var $f734735 = function(_) {
return R.isFunction(anf_fun787709)?anf_fun787709.app(("src/arr/trove/pprint.arr"),anf_arg924708):R.ffi.throwNonFunApp(L[49],anf_fun787709,[("src/arr/trove/pprint.arr"),anf_arg924708]);
};
try {
if(--R.GAS > 0) {
$z728729 = $f734735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f734735,
"from":L[49]});
}
} catch($e726727) {
if(R.isCont($e726727)) {
var $ss730731 = {"from":L[49],
"go":function(anf_begin_app_dropped1388736) {
return $Hanf_begin_app_dropped1391737(anf_begin_app_dropped1388736,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,builtins9);
}};
$e726727.stack[R.EXN_STACKHEIGHT++] = $ss730731;
}
if(R.isPyretException($e726727)) {
$e726727.pyretStack.push(L[49]);
}
throw $e726727;
}
var $ret732733 = $Hanf_begin_app_dropped1391737($z728729,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,builtins9);
++R.GAS;
return $ret732733;
};
var $Hanf_begin_app_dropped1391737 = function(anf_begin_app_dropped1388736,Item6238,PPrintDoc6039,PPrintDoc6540,align21777,blank23078,braces252342,brackets253344,comma244293,commabreak247332,concat22779,dquote268469,flow_DASH_map248334,flow249336,group21980,hang270473,hardline21661,if_DASH_flat22181,infix_DASH_break273479,infix272477,is_DASH_mt_DASH_doc6747,label_DASH_align_DASH_surround278489,langle242269,lbrace238221,lbrack240245,lparen23676,mt_DASH_doc21537,nest22482,number23463,parens251340,prefix271475,rangle243281,rbrace239233,rbrack241257,result_DASH_after_DASH_checks1323503,rparen237209,sbreak245295,separate276485,soft_DASH_surround275483,squote269471,str23275,surround_DASH_separate277487,surround274481,vert250338,builtins9) {
var provides925750 = R.makeObject({"PPrintDoc":PPrintDoc6540.$var,
"mt-doc":mt_DASH_doc21537,
"is-mt-doc":is_DASH_mt_DASH_doc6747.$var,
"str":str23275,
"number":number23463.$var,
"hardline":hardline21661,
"blank":blank23078,
"sbreak":sbreak245295.$var,
"concat":concat22779,
"nest":nest22482,
"if-flat":if_DASH_flat22181,
"group":group21980,
"flow":flow249336.$var,
"flow-map":flow_DASH_map248334.$var,
"vert":vert250338.$var,
"parens":parens251340.$var,
"braces":braces252342.$var,
"brackets":brackets253344.$var,
"dquote":dquote268469.$var,
"squote":squote269471.$var,
"align":align21777,
"hang":hang270473.$var,
"prefix":prefix271475.$var,
"infix":infix272477.$var,
"infix-break":infix_DASH_break273479.$var,
"separate":separate276485.$var,
"surround":surround274481.$var,
"soft-surround":soft_DASH_surround275483.$var,
"surround-separate":surround_DASH_separate277487.$var,
"label-align-surround":label_DASH_align_DASH_surround278489.$var,
"lparen":lparen23676,
"rparen":rparen237209,
"lbrace":lbrace238221,
"rbrace":rbrace239233,
"lbrack":lbrack240245,
"rbrack":rbrack241257,
"langle":langle242269,
"rangle":rangle243281,
"comma":comma244293,
"commabreak":commabreak247332});
var anf_fun926748 = G(builtins9,"current-checker",L[106]);
var $z740741 = D;
var $f746747 = function(_) {
return R.isFunction(anf_fun926748)?anf_fun926748.app():R.ffi.throwNonFunApp(L[106],anf_fun926748,[]);
};
try {
if(--R.GAS > 0) {
$z740741 = $f746747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f746747,
"from":L[106]});
}
} catch($e738739) {
if(R.isCont($e738739)) {
var $ss742743 = {"from":L[106],
"go":function(anf_bracket927749) {
return $Hanf_bracket1390751(anf_bracket927749,Item6238,PPrintDoc6039,provides925750,result_DASH_after_DASH_checks1323503);
}};
$e738739.stack[R.EXN_STACKHEIGHT++] = $ss742743;
}
if(R.isPyretException($e738739)) {
$e738739.pyretStack.push(L[106]);
}
throw $e738739;
}
var $ret744745 = $Hanf_bracket1390751($z740741,Item6238,PPrintDoc6039,provides925750,result_DASH_after_DASH_checks1323503);
++R.GAS;
return $ret744745;
};
var $Hanf_bracket1390751 = function(anf_bracket927749,Item6238,PPrintDoc6039,provides925750,result_DASH_after_DASH_checks1323503) {
var anf_fun928762 = G(anf_bracket927749,"results",L[106]);
var $z754755 = D;
var $f760761 = function(_) {
return R.isFunction(anf_fun928762)?anf_fun928762.app():R.ffi.throwNonFunApp(L[106],anf_fun928762,[]);
};
try {
if(--R.GAS > 0) {
$z754755 = $f760761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f760761,
"from":L[106]});
}
} catch($e752753) {
if(R.isCont($e752753)) {
var $ss756757 = {"from":L[106],
"go":function(checks929763) {
return $Hchecks1389764(checks929763,Item6238,PPrintDoc6039,provides925750,result_DASH_after_DASH_checks1323503);
}};
$e752753.stack[R.EXN_STACKHEIGHT++] = $ss756757;
}
if(R.isPyretException($e752753)) {
$e752753.pyretStack.push(L[106]);
}
throw $e752753;
}
var $ret758759 = $Hchecks1389764($z754755,Item6238,PPrintDoc6039,provides925750,result_DASH_after_DASH_checks1323503);
++R.GAS;
return $ret758759;
};
var $Hchecks1389764 = function(checks929763,Item6238,PPrintDoc6039,provides925750,result_DASH_after_DASH_checks1323503) {
return R.makeObject({"answer":result_DASH_after_DASH_checks1323503,
"provide-plus-types":R.makeObject({"values":provides925750,
"types":{"PPrintDoc":PPrintDoc6039,
"Item":Item6238}}),
"checks":checks929763});
};
var $Hanf_bracket1387725 = function(anf_bracket791724,flow249336,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9) {
var anf_fun792775 = G(anf_bracket791724,"map",L[108]);
var $z767768 = D;
var $f773774 = function(_) {
return R.isFunction(anf_fun792775)?anf_fun792775.app(str23275):R.ffi.throwNonFunApp(L[107],anf_fun792775,[str23275]);
};
try {
if(--R.GAS > 0) {
$z767768 = $f773774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f773774,
"from":L[107]});
}
} catch($e765766) {
if(R.isCont($e765766)) {
var $ss769770 = {"from":L[107],
"go":function(test_DASH_words324776) {
return $Htest_DASH_words1386777(test_DASH_words324776,flow249336,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
}};
$e765766.stack[R.EXN_STACKHEIGHT++] = $ss769770;
}
if(R.isPyretException($e765766)) {
$e765766.pyretStack.push(L[107]);
}
throw $e765766;
}
var $ret771772 = $Htest_DASH_words1386777($z767768,flow249336,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
++R.GAS;
return $ret771772;
};
var $Htest_DASH_words1386777 = function(test_DASH_words324776,flow249336,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9) {
var $z780781 = D;
var $f786787 = function(_) {
return R.isFunction(flow249336.$var)?flow249336.$var.app(test_DASH_words324776):R.ffi.throwNonFunApp(L[109],flow249336.$var,[test_DASH_words324776]);
};
try {
if(--R.GAS > 0) {
$z780781 = $f786787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f786787,
"from":L[109]});
}
} catch($e778779) {
if(R.isCont($e778779)) {
var $ss782783 = {"from":L[109],
"go":function(test325788) {
return $Htest1385789(test325788,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
}};
$e778779.stack[R.EXN_STACKHEIGHT++] = $ss782783;
}
if(R.isPyretException($e778779)) {
$e778779.pyretStack.push(L[109]);
}
throw $e778779;
}
var $ret784785 = $Htest1385789($z780781,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
++R.GAS;
return $ret784785;
};
var $Htest1385789 = function(test325788,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9) {
var anf_fun793800 = G(builtins9,"current-checker",L[110]);
var $z792793 = D;
var $f798799 = function(_) {
return R.isFunction(anf_fun793800)?anf_fun793800.app():R.ffi.throwNonFunApp(L[110],anf_fun793800,[]);
};
try {
if(--R.GAS > 0) {
$z792793 = $f798799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f798799,
"from":L[110]});
}
} catch($e790791) {
if(R.isCont($e790791)) {
var $ss794795 = {"from":L[110],
"go":function(anf_bracket794801) {
return $Hanf_bracket1384802(anf_bracket794801,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e790791.stack[R.EXN_STACKHEIGHT++] = $ss794795;
}
if(R.isPyretException($e790791)) {
$e790791.pyretStack.push(L[110]);
}
throw $e790791;
}
var $ret796797 = $Hanf_bracket1384802($z792793,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret796797;
};
var $Hanf_bracket1384802 = function(anf_bracket794801,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun795815 = G(anf_bracket794801,"check-is",L[110]);
var anf_fun796813 = G(test325788,"pretty",L[112]);
var $z805806 = D;
var $f811812 = function(_) {
return R.isFunction(anf_fun796813)?anf_fun796813.app((40)):R.ffi.throwNonFunApp(L[111],anf_fun796813,[(40)]);
};
try {
if(--R.GAS > 0) {
$z805806 = $f811812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f811812,
"from":L[111]});
}
} catch($e803804) {
if(R.isCont($e803804)) {
var $ss807808 = {"from":L[111],
"go":function(anf_arg797814) {
return $Hanf_arg1383816(anf_arg797814,anf_fun795815,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e803804.stack[R.EXN_STACKHEIGHT++] = $ss807808;
}
if(R.isPyretException($e803804)) {
$e803804.pyretStack.push(L[111]);
}
throw $e803804;
}
var $ret809810 = $Hanf_arg1383816($z805806,anf_fun795815,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret809810;
};
var $Hanf_arg1383816 = function(anf_arg797814,anf_fun795815,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun798827 = G(list1948,"make",L[113]);
var $z819820 = D;
var $f825826 = function(_) {
return R.isFunction(anf_fun798827)?anf_fun798827.app([("This is a sentence with eight words")]):R.ffi.throwNonFunApp(L[113],anf_fun798827,[[("This is a sentence with eight words")]]);
};
try {
if(--R.GAS > 0) {
$z819820 = $f825826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f825826,
"from":L[113]});
}
} catch($e817818) {
if(R.isCont($e817818)) {
var $ss821822 = {"from":L[113],
"go":function(anf_arg799828) {
return $Hanf_arg1382829(anf_arg799828,anf_arg797814,anf_fun795815,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e817818.stack[R.EXN_STACKHEIGHT++] = $ss821822;
}
if(R.isPyretException($e817818)) {
$e817818.pyretStack.push(L[113]);
}
throw $e817818;
}
var $ret823824 = $Hanf_arg1382829($z819820,anf_arg797814,anf_fun795815,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret823824;
};
var $Hanf_arg1382829 = function(anf_arg799828,anf_arg797814,anf_fun795815,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_arg800840 = R.makeSrcloc(L[110]);
var $z832833 = D;
var $f838839 = function(_) {
return R.isFunction(anf_fun795815)?anf_fun795815.app(("test.pretty(40) is [list: \"This is a sentence with eight words\"]"),anf_arg797814,anf_arg799828,anf_arg800840):R.ffi.throwNonFunApp(L[110],anf_fun795815,[("test.pretty(40) is [list: \"This is a sentence with eight words\"]"),anf_arg797814,anf_arg799828,anf_arg800840]);
};
try {
if(--R.GAS > 0) {
$z832833 = $f838839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f838839,
"from":L[110]});
}
} catch($e830831) {
if(R.isCont($e830831)) {
var $ss834835 = {"from":L[110],
"go":function(anf_begin_app_dropped1300841) {
return $Hanf_begin_app_dropped1381842(anf_begin_app_dropped1300841,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e830831.stack[R.EXN_STACKHEIGHT++] = $ss834835;
}
if(R.isPyretException($e830831)) {
$e830831.pyretStack.push(L[110]);
}
throw $e830831;
}
var $ret836837 = $Hanf_begin_app_dropped1381842($z832833,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret836837;
};
var $Hanf_begin_app_dropped1381842 = function(anf_begin_app_dropped1300841,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun801853 = G(builtins9,"current-checker",L[114]);
var $z845846 = D;
var $f851852 = function(_) {
return R.isFunction(anf_fun801853)?anf_fun801853.app():R.ffi.throwNonFunApp(L[114],anf_fun801853,[]);
};
try {
if(--R.GAS > 0) {
$z845846 = $f851852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f851852,
"from":L[114]});
}
} catch($e843844) {
if(R.isCont($e843844)) {
var $ss847848 = {"from":L[114],
"go":function(anf_bracket802854) {
return $Hanf_bracket1380855(anf_bracket802854,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e843844.stack[R.EXN_STACKHEIGHT++] = $ss847848;
}
if(R.isPyretException($e843844)) {
$e843844.pyretStack.push(L[114]);
}
throw $e843844;
}
var $ret849850 = $Hanf_bracket1380855($z845846,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret849850;
};
var $Hanf_bracket1380855 = function(anf_bracket802854,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun803868 = G(anf_bracket802854,"check-is",L[114]);
var anf_fun804866 = G(test325788,"pretty",L[116]);
var $z858859 = D;
var $f864865 = function(_) {
return R.isFunction(anf_fun804866)?anf_fun804866.app((30)):R.ffi.throwNonFunApp(L[115],anf_fun804866,[(30)]);
};
try {
if(--R.GAS > 0) {
$z858859 = $f864865();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f864865,
"from":L[115]});
}
} catch($e856857) {
if(R.isCont($e856857)) {
var $ss860861 = {"from":L[115],
"go":function(anf_arg805867) {
return $Hanf_arg1379869(anf_arg805867,anf_fun803868,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e856857.stack[R.EXN_STACKHEIGHT++] = $ss860861;
}
if(R.isPyretException($e856857)) {
$e856857.pyretStack.push(L[115]);
}
throw $e856857;
}
var $ret862863 = $Hanf_arg1379869($z858859,anf_fun803868,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret862863;
};
var $Hanf_arg1379869 = function(anf_arg805867,anf_fun803868,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun806880 = G(list1948,"make",L[117]);
var $z872873 = D;
var $f878879 = function(_) {
return R.isFunction(anf_fun806880)?anf_fun806880.app([("This is a sentence with eight"),("words")]):R.ffi.throwNonFunApp(L[117],anf_fun806880,[[("This is a sentence with eight"),("words")]]);
};
try {
if(--R.GAS > 0) {
$z872873 = $f878879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f878879,
"from":L[117]});
}
} catch($e870871) {
if(R.isCont($e870871)) {
var $ss874875 = {"from":L[117],
"go":function(anf_arg807881) {
return $Hanf_arg1378882(anf_arg807881,anf_arg805867,anf_fun803868,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e870871.stack[R.EXN_STACKHEIGHT++] = $ss874875;
}
if(R.isPyretException($e870871)) {
$e870871.pyretStack.push(L[117]);
}
throw $e870871;
}
var $ret876877 = $Hanf_arg1378882($z872873,anf_arg805867,anf_fun803868,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret876877;
};
var $Hanf_arg1378882 = function(anf_arg807881,anf_arg805867,anf_fun803868,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_arg808893 = R.makeSrcloc(L[114]);
var $z885886 = D;
var $f891892 = function(_) {
return R.isFunction(anf_fun803868)?anf_fun803868.app(("test.pretty(30) is [list: \"This is a sentence with eight\", \"words\"]"),anf_arg805867,anf_arg807881,anf_arg808893):R.ffi.throwNonFunApp(L[114],anf_fun803868,[("test.pretty(30) is [list: \"This is a sentence with eight\", \"words\"]"),anf_arg805867,anf_arg807881,anf_arg808893]);
};
try {
if(--R.GAS > 0) {
$z885886 = $f891892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f891892,
"from":L[114]});
}
} catch($e883884) {
if(R.isCont($e883884)) {
var $ss887888 = {"from":L[114],
"go":function(anf_begin_app_dropped1301894) {
return $Hanf_begin_app_dropped1377895(anf_begin_app_dropped1301894,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e883884.stack[R.EXN_STACKHEIGHT++] = $ss887888;
}
if(R.isPyretException($e883884)) {
$e883884.pyretStack.push(L[114]);
}
throw $e883884;
}
var $ret889890 = $Hanf_begin_app_dropped1377895($z885886,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret889890;
};
var $Hanf_begin_app_dropped1377895 = function(anf_begin_app_dropped1301894,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun809906 = G(builtins9,"current-checker",L[118]);
var $z898899 = D;
var $f904905 = function(_) {
return R.isFunction(anf_fun809906)?anf_fun809906.app():R.ffi.throwNonFunApp(L[118],anf_fun809906,[]);
};
try {
if(--R.GAS > 0) {
$z898899 = $f904905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f904905,
"from":L[118]});
}
} catch($e896897) {
if(R.isCont($e896897)) {
var $ss900901 = {"from":L[118],
"go":function(anf_bracket810907) {
return $Hanf_bracket1376908(anf_bracket810907,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e896897.stack[R.EXN_STACKHEIGHT++] = $ss900901;
}
if(R.isPyretException($e896897)) {
$e896897.pyretStack.push(L[118]);
}
throw $e896897;
}
var $ret902903 = $Hanf_bracket1376908($z898899,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret902903;
};
var $Hanf_bracket1376908 = function(anf_bracket810907,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun811921 = G(anf_bracket810907,"check-is",L[118]);
var anf_fun812919 = G(test325788,"pretty",L[120]);
var $z911912 = D;
var $f917918 = function(_) {
return R.isFunction(anf_fun812919)?anf_fun812919.app((20)):R.ffi.throwNonFunApp(L[119],anf_fun812919,[(20)]);
};
try {
if(--R.GAS > 0) {
$z911912 = $f917918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f917918,
"from":L[119]});
}
} catch($e909910) {
if(R.isCont($e909910)) {
var $ss913914 = {"from":L[119],
"go":function(anf_arg813920) {
return $Hanf_arg1375922(anf_arg813920,anf_fun811921,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e909910.stack[R.EXN_STACKHEIGHT++] = $ss913914;
}
if(R.isPyretException($e909910)) {
$e909910.pyretStack.push(L[119]);
}
throw $e909910;
}
var $ret915916 = $Hanf_arg1375922($z911912,anf_fun811921,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret915916;
};
var $Hanf_arg1375922 = function(anf_arg813920,anf_fun811921,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun814933 = G(list1948,"make",L[121]);
var $z925926 = D;
var $f931932 = function(_) {
return R.isFunction(anf_fun814933)?anf_fun814933.app([("This is a sentence"),("with eight words")]):R.ffi.throwNonFunApp(L[121],anf_fun814933,[[("This is a sentence"),("with eight words")]]);
};
try {
if(--R.GAS > 0) {
$z925926 = $f931932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f931932,
"from":L[121]});
}
} catch($e923924) {
if(R.isCont($e923924)) {
var $ss927928 = {"from":L[121],
"go":function(anf_arg815934) {
return $Hanf_arg1374935(anf_arg815934,anf_arg813920,anf_fun811921,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e923924.stack[R.EXN_STACKHEIGHT++] = $ss927928;
}
if(R.isPyretException($e923924)) {
$e923924.pyretStack.push(L[121]);
}
throw $e923924;
}
var $ret929930 = $Hanf_arg1374935($z925926,anf_arg813920,anf_fun811921,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret929930;
};
var $Hanf_arg1374935 = function(anf_arg815934,anf_arg813920,anf_fun811921,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_arg816946 = R.makeSrcloc(L[118]);
var $z938939 = D;
var $f944945 = function(_) {
return R.isFunction(anf_fun811921)?anf_fun811921.app(("test.pretty(20) is [list: \"This is a sentence\", \"with eight words\"]"),anf_arg813920,anf_arg815934,anf_arg816946):R.ffi.throwNonFunApp(L[118],anf_fun811921,[("test.pretty(20) is [list: \"This is a sentence\", \"with eight words\"]"),anf_arg813920,anf_arg815934,anf_arg816946]);
};
try {
if(--R.GAS > 0) {
$z938939 = $f944945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f944945,
"from":L[118]});
}
} catch($e936937) {
if(R.isCont($e936937)) {
var $ss940941 = {"from":L[118],
"go":function(anf_begin_app_dropped1302947) {
return $Hanf_begin_app_dropped1373948(anf_begin_app_dropped1302947,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e936937.stack[R.EXN_STACKHEIGHT++] = $ss940941;
}
if(R.isPyretException($e936937)) {
$e936937.pyretStack.push(L[118]);
}
throw $e936937;
}
var $ret942943 = $Hanf_begin_app_dropped1373948($z938939,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret942943;
};
var $Hanf_begin_app_dropped1373948 = function(anf_begin_app_dropped1302947,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun817959 = G(builtins9,"current-checker",L[122]);
var $z951952 = D;
var $f957958 = function(_) {
return R.isFunction(anf_fun817959)?anf_fun817959.app():R.ffi.throwNonFunApp(L[122],anf_fun817959,[]);
};
try {
if(--R.GAS > 0) {
$z951952 = $f957958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f957958,
"from":L[122]});
}
} catch($e949950) {
if(R.isCont($e949950)) {
var $ss953954 = {"from":L[122],
"go":function(anf_bracket818960) {
return $Hanf_bracket1372961(anf_bracket818960,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
}};
$e949950.stack[R.EXN_STACKHEIGHT++] = $ss953954;
}
if(R.isPyretException($e949950)) {
$e949950.pyretStack.push(L[122]);
}
throw $e949950;
}
var $ret955956 = $Hanf_bracket1372961($z951952,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9);
++R.GAS;
return $ret955956;
};
var $Hanf_bracket1372961 = function(anf_bracket818960,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,test325788,_plus8,builtins9) {
var anf_fun819974 = G(anf_bracket818960,"check-is",L[122]);
var anf_fun820972 = G(test325788,"pretty",L[124]);
var $z964965 = D;
var $f970971 = function(_) {
return R.isFunction(anf_fun820972)?anf_fun820972.app((10)):R.ffi.throwNonFunApp(L[123],anf_fun820972,[(10)]);
};
try {
if(--R.GAS > 0) {
$z964965 = $f970971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f970971,
"from":L[123]});
}
} catch($e962963) {
if(R.isCont($e962963)) {
var $ss966967 = {"from":L[123],
"go":function(anf_arg821973) {
return $Hanf_arg1371975(anf_arg821973,anf_fun819974,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
}};
$e962963.stack[R.EXN_STACKHEIGHT++] = $ss966967;
}
if(R.isPyretException($e962963)) {
$e962963.pyretStack.push(L[123]);
}
throw $e962963;
}
var $ret968969 = $Hanf_arg1371975($z964965,anf_fun819974,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
++R.GAS;
return $ret968969;
};
var $Hanf_arg1371975 = function(anf_arg821973,anf_fun819974,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9) {
var anf_fun822986 = G(list1948,"make",L[125]);
var $z978979 = D;
var $f984985 = function(_) {
return R.isFunction(anf_fun822986)?anf_fun822986.app([("This is a"),("sentence"),("with eight"),("words")]):R.ffi.throwNonFunApp(L[125],anf_fun822986,[[("This is a"),("sentence"),("with eight"),("words")]]);
};
try {
if(--R.GAS > 0) {
$z978979 = $f984985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f984985,
"from":L[125]});
}
} catch($e976977) {
if(R.isCont($e976977)) {
var $ss980981 = {"from":L[125],
"go":function(anf_arg823987) {
return $Hanf_arg1370988(anf_arg823987,anf_arg821973,anf_fun819974,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
}};
$e976977.stack[R.EXN_STACKHEIGHT++] = $ss980981;
}
if(R.isPyretException($e976977)) {
$e976977.pyretStack.push(L[125]);
}
throw $e976977;
}
var $ret982983 = $Hanf_arg1370988($z978979,anf_arg821973,anf_fun819974,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
++R.GAS;
return $ret982983;
};
var $Hanf_arg1370988 = function(anf_arg823987,anf_arg821973,anf_fun819974,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9) {
var anf_arg824999 = R.makeSrcloc(L[122]);
var $z991992 = D;
var $f997998 = function(_) {
return R.isFunction(anf_fun819974)?anf_fun819974.app(("test.pretty(10) is [list: \"This is a\", \"sentence\", \"with eight\", \"words\"]"),anf_arg821973,anf_arg823987,anf_arg824999):R.ffi.throwNonFunApp(L[122],anf_fun819974,[("test.pretty(10) is [list: \"This is a\", \"sentence\", \"with eight\", \"words\"]"),anf_arg821973,anf_arg823987,anf_arg824999]);
};
try {
if(--R.GAS > 0) {
$z991992 = $f997998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f997998,
"from":L[122]});
}
} catch($e989990) {
if(R.isCont($e989990)) {
var $ss993994 = {"from":L[122],
"go":function(anf_begin_app_dropped13031000) {
return $Hanf_begin_app_dropped13691001(anf_begin_app_dropped13031000,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
}};
$e989990.stack[R.EXN_STACKHEIGHT++] = $ss993994;
}
if(R.isPyretException($e989990)) {
$e989990.pyretStack.push(L[122]);
}
throw $e989990;
}
var $ret995996 = $Hanf_begin_app_dropped13691001($z991992,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9);
++R.GAS;
return $ret995996;
};
var $Hanf_begin_app_dropped13691001 = function(anf_begin_app_dropped13031000,group21980,is_DASH_empty2046,list1948,nest22482,sbreak245295,str23275,_plus8,builtins9) {
var opt_DASH_break3261002 = {"$var":D,
"$name":"opt-break"};
var binop3271004 = {"$var":D,
"$name":"binop"};
var ifthen3281006 = {"$var":D,
"$name":"ifthen"};
var anf_assign8401003 = R.makeFunction(function(x3291078,y3301079) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[135],2,arguments);
}
var $z10821083 = D;
var $f10881089 = function(_) {
return R.isFunction(is_DASH_empty2046)?is_DASH_empty2046.app(x3291078):R.ffi.throwNonFunApp(L[136],is_DASH_empty2046,[x3291078]);
};
try {
if(--R.GAS > 0) {
$z10821083 = $f10881089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10881089,
"from":L[136]});
}
} catch($e10801081) {
if(R.isCont($e10801081)) {
var $ss10841085 = {"from":L[136],
"go":function(if_DASH_891090) {
return $Hif_DASH_13101091(if_DASH_891090,is_DASH_empty2046,sbreak245295,x3291078,y3301079,_plus8);
}};
$e10801081.stack[R.EXN_STACKHEIGHT++] = $ss10841085;
}
if(R.isPyretException($e10801081)) {
$e10801081.pyretStack.push(L[136]);
}
throw $e10801081;
}
var $ret10861087 = $Hif_DASH_13101091($z10821083,is_DASH_empty2046,sbreak245295,x3291078,y3301079,_plus8);
++R.GAS;
return $ret10861087;
});
opt_DASH_break3261002.$var = anf_assign8401003;
var anf_assign8491005 = R.makeFunction(function(left3311063,op3321064,right3331065) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[133],3,arguments);
}
var $z10681069 = D;
var $f10741075 = function(_) {
return R.isFunction(str23275)?str23275.app(left3311063):R.ffi.throwNonFunApp(L[134],str23275,[left3311063]);
};
try {
if(--R.GAS > 0) {
$z10681069 = $f10741075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10741075,
"from":L[134]});
}
} catch($e10661067) {
if(R.isCont($e10661067)) {
var $ss10701071 = {"from":L[134],
"go":function(anf_arg8421076) {
return $Hanf_arg13181077(anf_arg8421076,group21980,nest22482,op3321064,opt_DASH_break3261002,right3331065,str23275);
}};
$e10661067.stack[R.EXN_STACKHEIGHT++] = $ss10701071;
}
if(R.isPyretException($e10661067)) {
$e10661067.pyretStack.push(L[134]);
}
throw $e10661067;
}
var $ret10721073 = $Hanf_arg13181077($z10681069,group21980,nest22482,op3321064,opt_DASH_break3261002,right3331065,str23275);
++R.GAS;
return $ret10721073;
});
binop3271004.$var = anf_assign8491005;
var anf_assign8691007 = R.makeFunction(function(c3341020,t3351021,f3361022) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[127],3,arguments);
}
var anf_fun8631034 = R.makeFunction(function(arg_DASH_911036) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[129],1,arguments);
}
var anf_fun8571048 = R.makeFunction(function(arg_DASH_901050) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[131],1,arguments);
}
var $z10531054 = D;
var $f10591060 = function(_) {
return R.isFunction(str23275)?str23275.app(("else")):R.ffi.throwNonFunApp(L[132],str23275,[("else")]);
};
try {
if(--R.GAS > 0) {
$z10531054 = $f10591060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10591060,
"from":L[132]});
}
} catch($e10511052) {
if(R.isCont($e10511052)) {
var $ss10551056 = {"from":L[132],
"go":function(anf_arg8531061) {
return $Hanf_arg13231062(anf_arg8531061,arg_DASH_901050,f3361022,group21980,nest22482,opt_DASH_break3261002);
}};
$e10511052.stack[R.EXN_STACKHEIGHT++] = $ss10551056;
}
if(R.isPyretException($e10511052)) {
$e10511052.pyretStack.push(L[132]);
}
throw $e10511052;
}
var $ret10571058 = $Hanf_arg13231062($z10531054,arg_DASH_901050,f3361022,group21980,nest22482,opt_DASH_break3261002);
++R.GAS;
return $ret10571058;
});
var $z10391040 = D;
var $f10451046 = function(_) {
return R.isFunction(str23275)?str23275.app(("then")):R.ffi.throwNonFunApp(L[130],str23275,[("then")]);
};
try {
if(--R.GAS > 0) {
$z10391040 = $f10451046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10451046,
"from":L[130]});
}
} catch($e10371038) {
if(R.isCont($e10371038)) {
var $ss10411042 = {"from":L[130],
"go":function(anf_arg8581047) {
return $Hanf_arg13291049(anf_arg8581047,anf_fun8571048,arg_DASH_911036,group21980,nest22482,opt_DASH_break3261002,t3351021);
}};
$e10371038.stack[R.EXN_STACKHEIGHT++] = $ss10411042;
}
if(R.isPyretException($e10371038)) {
$e10371038.pyretStack.push(L[130]);
}
throw $e10371038;
}
var $ret10431044 = $Hanf_arg13291049($z10391040,anf_fun8571048,arg_DASH_911036,group21980,nest22482,opt_DASH_break3261002,t3351021);
++R.GAS;
return $ret10431044;
});
var $z10251026 = D;
var $f10311032 = function(_) {
return R.isFunction(str23275)?str23275.app(("if")):R.ffi.throwNonFunApp(L[128],str23275,[("if")]);
};
try {
if(--R.GAS > 0) {
$z10251026 = $f10311032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10311032,
"from":L[128]});
}
} catch($e10231024) {
if(R.isCont($e10231024)) {
var $ss10271028 = {"from":L[128],
"go":function(anf_arg8641033) {
return $Hanf_arg13351035(anf_arg8641033,anf_fun8631034,c3341020,group21980,nest22482,opt_DASH_break3261002);
}};
$e10231024.stack[R.EXN_STACKHEIGHT++] = $ss10271028;
}
if(R.isPyretException($e10231024)) {
$e10231024.pyretStack.push(L[128]);
}
throw $e10231024;
}
var $ret10291030 = $Hanf_arg13351035($z10251026,anf_fun8631034,c3341020,group21980,nest22482,opt_DASH_break3261002);
++R.GAS;
return $ret10291030;
});
ifthen3281006.$var = anf_assign8691007;
var $z10101011 = D;
var $f10161017 = function(_) {
return R.isFunction(binop3271004.$var)?binop3271004.$var.app(("a"),("=="),("b")):R.ffi.throwNonFunApp(L[126],binop3271004.$var,[("a"),("=="),("b")]);
};
try {
if(--R.GAS > 0) {
$z10101011 = $f10161017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10161017,
"from":L[126]});
}
} catch($e10081009) {
if(R.isCont($e10081009)) {
var $ss10121013 = {"from":L[126],
"go":function(anf_arg8701018) {
return $Hanf_arg13681019(anf_arg8701018,binop3271004,ifthen3281006,list1948,builtins9);
}};
$e10081009.stack[R.EXN_STACKHEIGHT++] = $ss10121013;
}
if(R.isPyretException($e10081009)) {
$e10081009.pyretStack.push(L[126]);
}
throw $e10081009;
}
var $ret10141015 = $Hanf_arg13681019($z10101011,binop3271004,ifthen3281006,list1948,builtins9);
++R.GAS;
return $ret10141015;
};
var $Hanf_arg13681019 = function(anf_arg8701018,binop3271004,ifthen3281006,list1948,builtins9) {
var $z10941095 = D;
var $f11001101 = function(_) {
return R.isFunction(binop3271004.$var)?binop3271004.$var.app(("a"),("<<"),("2")):R.ffi.throwNonFunApp(L[137],binop3271004.$var,[("a"),("<<"),("2")]);
};
try {
if(--R.GAS > 0) {
$z10941095 = $f11001101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11001101,
"from":L[137]});
}
} catch($e10921093) {
if(R.isCont($e10921093)) {
var $ss10961097 = {"from":L[137],
"go":function(anf_arg8711102) {
return $Hanf_arg13671103(anf_arg8711102,anf_arg8701018,binop3271004,ifthen3281006,list1948,builtins9);
}};
$e10921093.stack[R.EXN_STACKHEIGHT++] = $ss10961097;
}
if(R.isPyretException($e10921093)) {
$e10921093.pyretStack.push(L[137]);
}
throw $e10921093;
}
var $ret10981099 = $Hanf_arg13671103($z10941095,anf_arg8701018,binop3271004,ifthen3281006,list1948,builtins9);
++R.GAS;
return $ret10981099;
};
var $Hanf_arg13671103 = function(anf_arg8711102,anf_arg8701018,binop3271004,ifthen3281006,list1948,builtins9) {
var $z11061107 = D;
var $f11121113 = function(_) {
return R.isFunction(binop3271004.$var)?binop3271004.$var.app(("a"),("+"),("b")):R.ffi.throwNonFunApp(L[138],binop3271004.$var,[("a"),("+"),("b")]);
};
try {
if(--R.GAS > 0) {
$z11061107 = $f11121113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11121113,
"from":L[138]});
}
} catch($e11041105) {
if(R.isCont($e11041105)) {
var $ss11081109 = {"from":L[138],
"go":function(anf_arg8721114) {
return $Hanf_arg13661115(anf_arg8721114,anf_arg8701018,anf_arg8711102,ifthen3281006,list1948,builtins9);
}};
$e11041105.stack[R.EXN_STACKHEIGHT++] = $ss11081109;
}
if(R.isPyretException($e11041105)) {
$e11041105.pyretStack.push(L[138]);
}
throw $e11041105;
}
var $ret11101111 = $Hanf_arg13661115($z11061107,anf_arg8701018,anf_arg8711102,ifthen3281006,list1948,builtins9);
++R.GAS;
return $ret11101111;
};
var $Hanf_arg13661115 = function(anf_arg8721114,anf_arg8701018,anf_arg8711102,ifthen3281006,list1948,builtins9) {
var $z11181119 = D;
var $f11241125 = function(_) {
return R.isFunction(ifthen3281006.$var)?ifthen3281006.$var.app(anf_arg8701018,anf_arg8711102,anf_arg8721114):R.ffi.throwNonFunApp(L[139],ifthen3281006.$var,[anf_arg8701018,anf_arg8711102,anf_arg8721114]);
};
try {
if(--R.GAS > 0) {
$z11181119 = $f11241125();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11241125,
"from":L[139]});
}
} catch($e11161117) {
if(R.isCont($e11161117)) {
var $ss11201121 = {"from":L[139],
"go":function(ifthenelse3371126) {
return $Hifthenelse13651127(ifthenelse3371126,list1948,builtins9);
}};
$e11161117.stack[R.EXN_STACKHEIGHT++] = $ss11201121;
}
if(R.isPyretException($e11161117)) {
$e11161117.pyretStack.push(L[139]);
}
throw $e11161117;
}
var $ret11221123 = $Hifthenelse13651127($z11181119,list1948,builtins9);
++R.GAS;
return $ret11221123;
};
var $Hifthenelse13651127 = function(ifthenelse3371126,list1948,builtins9) {
var anf_fun8731138 = G(builtins9,"current-checker",L[140]);
var $z11301131 = D;
var $f11361137 = function(_) {
return R.isFunction(anf_fun8731138)?anf_fun8731138.app():R.ffi.throwNonFunApp(L[140],anf_fun8731138,[]);
};
try {
if(--R.GAS > 0) {
$z11301131 = $f11361137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11361137,
"from":L[140]});
}
} catch($e11281129) {
if(R.isCont($e11281129)) {
var $ss11321133 = {"from":L[140],
"go":function(anf_bracket8741139) {
return $Hanf_bracket13641140(anf_bracket8741139,ifthenelse3371126,list1948,builtins9);
}};
$e11281129.stack[R.EXN_STACKHEIGHT++] = $ss11321133;
}
if(R.isPyretException($e11281129)) {
$e11281129.pyretStack.push(L[140]);
}
throw $e11281129;
}
var $ret11341135 = $Hanf_bracket13641140($z11301131,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret11341135;
};
var $Hanf_bracket13641140 = function(anf_bracket8741139,ifthenelse3371126,list1948,builtins9) {
var anf_fun8751153 = G(anf_bracket8741139,"check-is",L[140]);
var anf_fun8761151 = G(ifthenelse3371126,"pretty",L[142]);
var $z11431144 = D;
var $f11491150 = function(_) {
return R.isFunction(anf_fun8761151)?anf_fun8761151.app((32)):R.ffi.throwNonFunApp(L[141],anf_fun8761151,[(32)]);
};
try {
if(--R.GAS > 0) {
$z11431144 = $f11491150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11491150,
"from":L[141]});
}
} catch($e11411142) {
if(R.isCont($e11411142)) {
var $ss11451146 = {"from":L[141],
"go":function(anf_arg8771152) {
return $Hanf_arg13631154(anf_arg8771152,anf_fun8751153,ifthenelse3371126,list1948,builtins9);
}};
$e11411142.stack[R.EXN_STACKHEIGHT++] = $ss11451146;
}
if(R.isPyretException($e11411142)) {
$e11411142.pyretStack.push(L[141]);
}
throw $e11411142;
}
var $ret11471148 = $Hanf_arg13631154($z11431144,anf_fun8751153,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret11471148;
};
var $Hanf_arg13631154 = function(anf_arg8771152,anf_fun8751153,ifthenelse3371126,list1948,builtins9) {
var anf_fun8781165 = G(list1948,"make",L[143]);
var $z11571158 = D;
var $f11631164 = function(_) {
return R.isFunction(anf_fun8781165)?anf_fun8781165.app([("if a == b then a << 2 else a + b")]):R.ffi.throwNonFunApp(L[143],anf_fun8781165,[[("if a == b then a << 2 else a + b")]]);
};
try {
if(--R.GAS > 0) {
$z11571158 = $f11631164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11631164,
"from":L[143]});
}
} catch($e11551156) {
if(R.isCont($e11551156)) {
var $ss11591160 = {"from":L[143],
"go":function(anf_arg8791166) {
return $Hanf_arg13621167(anf_arg8791166,anf_arg8771152,anf_fun8751153,ifthenelse3371126,list1948,builtins9);
}};
$e11551156.stack[R.EXN_STACKHEIGHT++] = $ss11591160;
}
if(R.isPyretException($e11551156)) {
$e11551156.pyretStack.push(L[143]);
}
throw $e11551156;
}
var $ret11611162 = $Hanf_arg13621167($z11571158,anf_arg8771152,anf_fun8751153,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret11611162;
};
var $Hanf_arg13621167 = function(anf_arg8791166,anf_arg8771152,anf_fun8751153,ifthenelse3371126,list1948,builtins9) {
var anf_arg8801178 = R.makeSrcloc(L[140]);
var $z11701171 = D;
var $f11761177 = function(_) {
return R.isFunction(anf_fun8751153)?anf_fun8751153.app(("ifthenelse.pretty(32) is [list: \"if a == b then a << 2 else a + b\"]"),anf_arg8771152,anf_arg8791166,anf_arg8801178):R.ffi.throwNonFunApp(L[140],anf_fun8751153,[("ifthenelse.pretty(32) is [list: \"if a == b then a << 2 else a + b\"]"),anf_arg8771152,anf_arg8791166,anf_arg8801178]);
};
try {
if(--R.GAS > 0) {
$z11701171 = $f11761177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11761177,
"from":L[140]});
}
} catch($e11681169) {
if(R.isCont($e11681169)) {
var $ss11721173 = {"from":L[140],
"go":function(anf_begin_app_dropped13361179) {
return $Hanf_begin_app_dropped13611180(anf_begin_app_dropped13361179,ifthenelse3371126,list1948,builtins9);
}};
$e11681169.stack[R.EXN_STACKHEIGHT++] = $ss11721173;
}
if(R.isPyretException($e11681169)) {
$e11681169.pyretStack.push(L[140]);
}
throw $e11681169;
}
var $ret11741175 = $Hanf_begin_app_dropped13611180($z11701171,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret11741175;
};
var $Hanf_begin_app_dropped13611180 = function(anf_begin_app_dropped13361179,ifthenelse3371126,list1948,builtins9) {
var anf_fun8811191 = G(builtins9,"current-checker",L[144]);
var $z11831184 = D;
var $f11891190 = function(_) {
return R.isFunction(anf_fun8811191)?anf_fun8811191.app():R.ffi.throwNonFunApp(L[144],anf_fun8811191,[]);
};
try {
if(--R.GAS > 0) {
$z11831184 = $f11891190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11891190,
"from":L[144]});
}
} catch($e11811182) {
if(R.isCont($e11811182)) {
var $ss11851186 = {"from":L[144],
"go":function(anf_bracket8821192) {
return $Hanf_bracket13601193(anf_bracket8821192,ifthenelse3371126,list1948,builtins9);
}};
$e11811182.stack[R.EXN_STACKHEIGHT++] = $ss11851186;
}
if(R.isPyretException($e11811182)) {
$e11811182.pyretStack.push(L[144]);
}
throw $e11811182;
}
var $ret11871188 = $Hanf_bracket13601193($z11831184,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret11871188;
};
var $Hanf_bracket13601193 = function(anf_bracket8821192,ifthenelse3371126,list1948,builtins9) {
var anf_fun8831206 = G(anf_bracket8821192,"check-is",L[144]);
var anf_fun8841204 = G(ifthenelse3371126,"pretty",L[146]);
var $z11961197 = D;
var $f12021203 = function(_) {
return R.isFunction(anf_fun8841204)?anf_fun8841204.app((15)):R.ffi.throwNonFunApp(L[145],anf_fun8841204,[(15)]);
};
try {
if(--R.GAS > 0) {
$z11961197 = $f12021203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12021203,
"from":L[145]});
}
} catch($e11941195) {
if(R.isCont($e11941195)) {
var $ss11981199 = {"from":L[145],
"go":function(anf_arg8851205) {
return $Hanf_arg13591207(anf_arg8851205,anf_fun8831206,ifthenelse3371126,list1948,builtins9);
}};
$e11941195.stack[R.EXN_STACKHEIGHT++] = $ss11981199;
}
if(R.isPyretException($e11941195)) {
$e11941195.pyretStack.push(L[145]);
}
throw $e11941195;
}
var $ret12001201 = $Hanf_arg13591207($z11961197,anf_fun8831206,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret12001201;
};
var $Hanf_arg13591207 = function(anf_arg8851205,anf_fun8831206,ifthenelse3371126,list1948,builtins9) {
var anf_fun8861218 = G(list1948,"make",L[147]);
var $z12101211 = D;
var $f12161217 = function(_) {
return R.isFunction(anf_fun8861218)?anf_fun8861218.app([("if a == b"),("then a << 2"),("else a + b")]):R.ffi.throwNonFunApp(L[147],anf_fun8861218,[[("if a == b"),("then a << 2"),("else a + b")]]);
};
try {
if(--R.GAS > 0) {
$z12101211 = $f12161217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12161217,
"from":L[147]});
}
} catch($e12081209) {
if(R.isCont($e12081209)) {
var $ss12121213 = {"from":L[147],
"go":function(anf_arg8871219) {
return $Hanf_arg13581220(anf_arg8871219,anf_arg8851205,anf_fun8831206,ifthenelse3371126,list1948,builtins9);
}};
$e12081209.stack[R.EXN_STACKHEIGHT++] = $ss12121213;
}
if(R.isPyretException($e12081209)) {
$e12081209.pyretStack.push(L[147]);
}
throw $e12081209;
}
var $ret12141215 = $Hanf_arg13581220($z12101211,anf_arg8851205,anf_fun8831206,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret12141215;
};
var $Hanf_arg13581220 = function(anf_arg8871219,anf_arg8851205,anf_fun8831206,ifthenelse3371126,list1948,builtins9) {
var anf_arg8881231 = R.makeSrcloc(L[144]);
var $z12231224 = D;
var $f12291230 = function(_) {
return R.isFunction(anf_fun8831206)?anf_fun8831206.app(("ifthenelse.pretty(15) is [list: \"if a == b\", \"then a << 2\", \"else a + b\"]"),anf_arg8851205,anf_arg8871219,anf_arg8881231):R.ffi.throwNonFunApp(L[144],anf_fun8831206,[("ifthenelse.pretty(15) is [list: \"if a == b\", \"then a << 2\", \"else a + b\"]"),anf_arg8851205,anf_arg8871219,anf_arg8881231]);
};
try {
if(--R.GAS > 0) {
$z12231224 = $f12291230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12291230,
"from":L[144]});
}
} catch($e12211222) {
if(R.isCont($e12211222)) {
var $ss12251226 = {"from":L[144],
"go":function(anf_begin_app_dropped13371232) {
return $Hanf_begin_app_dropped13571233(anf_begin_app_dropped13371232,ifthenelse3371126,list1948,builtins9);
}};
$e12211222.stack[R.EXN_STACKHEIGHT++] = $ss12251226;
}
if(R.isPyretException($e12211222)) {
$e12211222.pyretStack.push(L[144]);
}
throw $e12211222;
}
var $ret12271228 = $Hanf_begin_app_dropped13571233($z12231224,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret12271228;
};
var $Hanf_begin_app_dropped13571233 = function(anf_begin_app_dropped13371232,ifthenelse3371126,list1948,builtins9) {
var anf_fun8891244 = G(builtins9,"current-checker",L[148]);
var $z12361237 = D;
var $f12421243 = function(_) {
return R.isFunction(anf_fun8891244)?anf_fun8891244.app():R.ffi.throwNonFunApp(L[148],anf_fun8891244,[]);
};
try {
if(--R.GAS > 0) {
$z12361237 = $f12421243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12421243,
"from":L[148]});
}
} catch($e12341235) {
if(R.isCont($e12341235)) {
var $ss12381239 = {"from":L[148],
"go":function(anf_bracket8901245) {
return $Hanf_bracket13561246(anf_bracket8901245,ifthenelse3371126,list1948,builtins9);
}};
$e12341235.stack[R.EXN_STACKHEIGHT++] = $ss12381239;
}
if(R.isPyretException($e12341235)) {
$e12341235.pyretStack.push(L[148]);
}
throw $e12341235;
}
var $ret12401241 = $Hanf_bracket13561246($z12361237,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret12401241;
};
var $Hanf_bracket13561246 = function(anf_bracket8901245,ifthenelse3371126,list1948,builtins9) {
var anf_fun8911259 = G(anf_bracket8901245,"check-is",L[148]);
var anf_fun8921257 = G(ifthenelse3371126,"pretty",L[150]);
var $z12491250 = D;
var $f12551256 = function(_) {
return R.isFunction(anf_fun8921257)?anf_fun8921257.app((10)):R.ffi.throwNonFunApp(L[149],anf_fun8921257,[(10)]);
};
try {
if(--R.GAS > 0) {
$z12491250 = $f12551256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12551256,
"from":L[149]});
}
} catch($e12471248) {
if(R.isCont($e12471248)) {
var $ss12511252 = {"from":L[149],
"go":function(anf_arg8931258) {
return $Hanf_arg13551260(anf_arg8931258,anf_fun8911259,ifthenelse3371126,list1948,builtins9);
}};
$e12471248.stack[R.EXN_STACKHEIGHT++] = $ss12511252;
}
if(R.isPyretException($e12471248)) {
$e12471248.pyretStack.push(L[149]);
}
throw $e12471248;
}
var $ret12531254 = $Hanf_arg13551260($z12491250,anf_fun8911259,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret12531254;
};
var $Hanf_arg13551260 = function(anf_arg8931258,anf_fun8911259,ifthenelse3371126,list1948,builtins9) {
var anf_fun8941271 = G(list1948,"make",L[151]);
var $z12631264 = D;
var $f12691270 = function(_) {
return R.isFunction(anf_fun8941271)?anf_fun8941271.app([("if a == b"),("then"),("  a << 2"),("else a + b")]):R.ffi.throwNonFunApp(L[151],anf_fun8941271,[[("if a == b"),("then"),("  a << 2"),("else a + b")]]);
};
try {
if(--R.GAS > 0) {
$z12631264 = $f12691270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12691270,
"from":L[151]});
}
} catch($e12611262) {
if(R.isCont($e12611262)) {
var $ss12651266 = {"from":L[151],
"go":function(anf_arg8951272) {
return $Hanf_arg13541273(anf_arg8951272,anf_arg8931258,anf_fun8911259,ifthenelse3371126,list1948,builtins9);
}};
$e12611262.stack[R.EXN_STACKHEIGHT++] = $ss12651266;
}
if(R.isPyretException($e12611262)) {
$e12611262.pyretStack.push(L[151]);
}
throw $e12611262;
}
var $ret12671268 = $Hanf_arg13541273($z12631264,anf_arg8931258,anf_fun8911259,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret12671268;
};
var $Hanf_arg13541273 = function(anf_arg8951272,anf_arg8931258,anf_fun8911259,ifthenelse3371126,list1948,builtins9) {
var anf_arg8961284 = R.makeSrcloc(L[148]);
var $z12761277 = D;
var $f12821283 = function(_) {
return R.isFunction(anf_fun8911259)?anf_fun8911259.app(("ifthenelse.pretty(10) is [list: \"if a == b\", \"then\", \"  a << 2\", \"else a + b\"]"),anf_arg8931258,anf_arg8951272,anf_arg8961284):R.ffi.throwNonFunApp(L[148],anf_fun8911259,[("ifthenelse.pretty(10) is [list: \"if a == b\", \"then\", \"  a << 2\", \"else a + b\"]"),anf_arg8931258,anf_arg8951272,anf_arg8961284]);
};
try {
if(--R.GAS > 0) {
$z12761277 = $f12821283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12821283,
"from":L[148]});
}
} catch($e12741275) {
if(R.isCont($e12741275)) {
var $ss12781279 = {"from":L[148],
"go":function(anf_begin_app_dropped13381285) {
return $Hanf_begin_app_dropped13531286(anf_begin_app_dropped13381285,ifthenelse3371126,list1948,builtins9);
}};
$e12741275.stack[R.EXN_STACKHEIGHT++] = $ss12781279;
}
if(R.isPyretException($e12741275)) {
$e12741275.pyretStack.push(L[148]);
}
throw $e12741275;
}
var $ret12801281 = $Hanf_begin_app_dropped13531286($z12761277,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret12801281;
};
var $Hanf_begin_app_dropped13531286 = function(anf_begin_app_dropped13381285,ifthenelse3371126,list1948,builtins9) {
var anf_fun8971297 = G(builtins9,"current-checker",L[152]);
var $z12891290 = D;
var $f12951296 = function(_) {
return R.isFunction(anf_fun8971297)?anf_fun8971297.app():R.ffi.throwNonFunApp(L[152],anf_fun8971297,[]);
};
try {
if(--R.GAS > 0) {
$z12891290 = $f12951296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12951296,
"from":L[152]});
}
} catch($e12871288) {
if(R.isCont($e12871288)) {
var $ss12911292 = {"from":L[152],
"go":function(anf_bracket8981298) {
return $Hanf_bracket13521299(anf_bracket8981298,ifthenelse3371126,list1948,builtins9);
}};
$e12871288.stack[R.EXN_STACKHEIGHT++] = $ss12911292;
}
if(R.isPyretException($e12871288)) {
$e12871288.pyretStack.push(L[152]);
}
throw $e12871288;
}
var $ret12931294 = $Hanf_bracket13521299($z12891290,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret12931294;
};
var $Hanf_bracket13521299 = function(anf_bracket8981298,ifthenelse3371126,list1948,builtins9) {
var anf_fun8991312 = G(anf_bracket8981298,"check-is",L[152]);
var anf_fun9001310 = G(ifthenelse3371126,"pretty",L[154]);
var $z13021303 = D;
var $f13081309 = function(_) {
return R.isFunction(anf_fun9001310)?anf_fun9001310.app((8)):R.ffi.throwNonFunApp(L[153],anf_fun9001310,[(8)]);
};
try {
if(--R.GAS > 0) {
$z13021303 = $f13081309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13081309,
"from":L[153]});
}
} catch($e13001301) {
if(R.isCont($e13001301)) {
var $ss13041305 = {"from":L[153],
"go":function(anf_arg9011311) {
return $Hanf_arg13511313(anf_arg9011311,anf_fun8991312,ifthenelse3371126,list1948,builtins9);
}};
$e13001301.stack[R.EXN_STACKHEIGHT++] = $ss13041305;
}
if(R.isPyretException($e13001301)) {
$e13001301.pyretStack.push(L[153]);
}
throw $e13001301;
}
var $ret13061307 = $Hanf_arg13511313($z13021303,anf_fun8991312,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret13061307;
};
var $Hanf_arg13511313 = function(anf_arg9011311,anf_fun8991312,ifthenelse3371126,list1948,builtins9) {
var anf_fun9021324 = G(list1948,"make",L[155]);
var $z13161317 = D;
var $f13221323 = function(_) {
return R.isFunction(anf_fun9021324)?anf_fun9021324.app([("if"),("  a == b"),("then"),("  a << 2"),("else"),("  a + b")]):R.ffi.throwNonFunApp(L[155],anf_fun9021324,[[("if"),("  a == b"),("then"),("  a << 2"),("else"),("  a + b")]]);
};
try {
if(--R.GAS > 0) {
$z13161317 = $f13221323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13221323,
"from":L[155]});
}
} catch($e13141315) {
if(R.isCont($e13141315)) {
var $ss13181319 = {"from":L[155],
"go":function(anf_arg9031325) {
return $Hanf_arg13501326(anf_arg9031325,anf_arg9011311,anf_fun8991312,ifthenelse3371126,list1948,builtins9);
}};
$e13141315.stack[R.EXN_STACKHEIGHT++] = $ss13181319;
}
if(R.isPyretException($e13141315)) {
$e13141315.pyretStack.push(L[155]);
}
throw $e13141315;
}
var $ret13201321 = $Hanf_arg13501326($z13161317,anf_arg9011311,anf_fun8991312,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret13201321;
};
var $Hanf_arg13501326 = function(anf_arg9031325,anf_arg9011311,anf_fun8991312,ifthenelse3371126,list1948,builtins9) {
var anf_arg9041337 = R.makeSrcloc(L[152]);
var $z13291330 = D;
var $f13351336 = function(_) {
return R.isFunction(anf_fun8991312)?anf_fun8991312.app(("ifthenelse.pretty(8) is\n  [list: \"if\", \"  a == b\", \"then\", \"  a << 2\", \"else\", \"  a + b\"]"),anf_arg9011311,anf_arg9031325,anf_arg9041337):R.ffi.throwNonFunApp(L[152],anf_fun8991312,[("ifthenelse.pretty(8) is\n  [list: \"if\", \"  a == b\", \"then\", \"  a << 2\", \"else\", \"  a + b\"]"),anf_arg9011311,anf_arg9031325,anf_arg9041337]);
};
try {
if(--R.GAS > 0) {
$z13291330 = $f13351336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13351336,
"from":L[152]});
}
} catch($e13271328) {
if(R.isCont($e13271328)) {
var $ss13311332 = {"from":L[152],
"go":function(anf_begin_app_dropped13391338) {
return $Hanf_begin_app_dropped13491339(anf_begin_app_dropped13391338,ifthenelse3371126,list1948,builtins9);
}};
$e13271328.stack[R.EXN_STACKHEIGHT++] = $ss13311332;
}
if(R.isPyretException($e13271328)) {
$e13271328.pyretStack.push(L[152]);
}
throw $e13271328;
}
var $ret13331334 = $Hanf_begin_app_dropped13491339($z13291330,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret13331334;
};
var $Hanf_begin_app_dropped13491339 = function(anf_begin_app_dropped13391338,ifthenelse3371126,list1948,builtins9) {
var anf_fun9051350 = G(builtins9,"current-checker",L[156]);
var $z13421343 = D;
var $f13481349 = function(_) {
return R.isFunction(anf_fun9051350)?anf_fun9051350.app():R.ffi.throwNonFunApp(L[156],anf_fun9051350,[]);
};
try {
if(--R.GAS > 0) {
$z13421343 = $f13481349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13481349,
"from":L[156]});
}
} catch($e13401341) {
if(R.isCont($e13401341)) {
var $ss13441345 = {"from":L[156],
"go":function(anf_bracket9061351) {
return $Hanf_bracket13481352(anf_bracket9061351,ifthenelse3371126,list1948,builtins9);
}};
$e13401341.stack[R.EXN_STACKHEIGHT++] = $ss13441345;
}
if(R.isPyretException($e13401341)) {
$e13401341.pyretStack.push(L[156]);
}
throw $e13401341;
}
var $ret13461347 = $Hanf_bracket13481352($z13421343,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret13461347;
};
var $Hanf_bracket13481352 = function(anf_bracket9061351,ifthenelse3371126,list1948,builtins9) {
var anf_fun9071365 = G(anf_bracket9061351,"check-is",L[156]);
var anf_fun9081363 = G(ifthenelse3371126,"pretty",L[158]);
var $z13551356 = D;
var $f13611362 = function(_) {
return R.isFunction(anf_fun9081363)?anf_fun9081363.app((7)):R.ffi.throwNonFunApp(L[157],anf_fun9081363,[(7)]);
};
try {
if(--R.GAS > 0) {
$z13551356 = $f13611362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13611362,
"from":L[157]});
}
} catch($e13531354) {
if(R.isCont($e13531354)) {
var $ss13571358 = {"from":L[157],
"go":function(anf_arg9091364) {
return $Hanf_arg13471366(anf_arg9091364,anf_fun9071365,ifthenelse3371126,list1948,builtins9);
}};
$e13531354.stack[R.EXN_STACKHEIGHT++] = $ss13571358;
}
if(R.isPyretException($e13531354)) {
$e13531354.pyretStack.push(L[157]);
}
throw $e13531354;
}
var $ret13591360 = $Hanf_arg13471366($z13551356,anf_fun9071365,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret13591360;
};
var $Hanf_arg13471366 = function(anf_arg9091364,anf_fun9071365,ifthenelse3371126,list1948,builtins9) {
var anf_fun9101377 = G(list1948,"make",L[159]);
var $z13691370 = D;
var $f13751376 = function(_) {
return R.isFunction(anf_fun9101377)?anf_fun9101377.app([("if"),("  a =="),("    b"),("then"),("  a <<"),("    2"),("else"),("  a + b")]):R.ffi.throwNonFunApp(L[159],anf_fun9101377,[[("if"),("  a =="),("    b"),("then"),("  a <<"),("    2"),("else"),("  a + b")]]);
};
try {
if(--R.GAS > 0) {
$z13691370 = $f13751376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13751376,
"from":L[159]});
}
} catch($e13671368) {
if(R.isCont($e13671368)) {
var $ss13711372 = {"from":L[159],
"go":function(anf_arg9111378) {
return $Hanf_arg13461379(anf_arg9111378,anf_arg9091364,anf_fun9071365,ifthenelse3371126,list1948,builtins9);
}};
$e13671368.stack[R.EXN_STACKHEIGHT++] = $ss13711372;
}
if(R.isPyretException($e13671368)) {
$e13671368.pyretStack.push(L[159]);
}
throw $e13671368;
}
var $ret13731374 = $Hanf_arg13461379($z13691370,anf_arg9091364,anf_fun9071365,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret13731374;
};
var $Hanf_arg13461379 = function(anf_arg9111378,anf_arg9091364,anf_fun9071365,ifthenelse3371126,list1948,builtins9) {
var anf_arg9121390 = R.makeSrcloc(L[156]);
var $z13821383 = D;
var $f13881389 = function(_) {
return R.isFunction(anf_fun9071365)?anf_fun9071365.app(("ifthenelse.pretty(7) is\n  [list: \"if\", \"  a ==\", \"    b\", \"then\", \"  a <<\", \"    2\", \"else\", \"  a + b\"]"),anf_arg9091364,anf_arg9111378,anf_arg9121390):R.ffi.throwNonFunApp(L[156],anf_fun9071365,[("ifthenelse.pretty(7) is\n  [list: \"if\", \"  a ==\", \"    b\", \"then\", \"  a <<\", \"    2\", \"else\", \"  a + b\"]"),anf_arg9091364,anf_arg9111378,anf_arg9121390]);
};
try {
if(--R.GAS > 0) {
$z13821383 = $f13881389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13881389,
"from":L[156]});
}
} catch($e13801381) {
if(R.isCont($e13801381)) {
var $ss13841385 = {"from":L[156],
"go":function(anf_begin_app_dropped13401391) {
return $Hanf_begin_app_dropped13451392(anf_begin_app_dropped13401391,ifthenelse3371126,list1948,builtins9);
}};
$e13801381.stack[R.EXN_STACKHEIGHT++] = $ss13841385;
}
if(R.isPyretException($e13801381)) {
$e13801381.pyretStack.push(L[156]);
}
throw $e13801381;
}
var $ret13861387 = $Hanf_begin_app_dropped13451392($z13821383,ifthenelse3371126,list1948,builtins9);
++R.GAS;
return $ret13861387;
};
var $Hanf_begin_app_dropped13451392 = function(anf_begin_app_dropped13401391,ifthenelse3371126,list1948,builtins9) {
var anf_fun9131403 = G(builtins9,"current-checker",L[160]);
var $z13951396 = D;
var $f14011402 = function(_) {
return R.isFunction(anf_fun9131403)?anf_fun9131403.app():R.ffi.throwNonFunApp(L[160],anf_fun9131403,[]);
};
try {
if(--R.GAS > 0) {
$z13951396 = $f14011402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14011402,
"from":L[160]});
}
} catch($e13931394) {
if(R.isCont($e13931394)) {
var $ss13971398 = {"from":L[160],
"go":function(anf_bracket9141404) {
return $Hanf_bracket13441405(anf_bracket9141404,ifthenelse3371126,list1948);
}};
$e13931394.stack[R.EXN_STACKHEIGHT++] = $ss13971398;
}
if(R.isPyretException($e13931394)) {
$e13931394.pyretStack.push(L[160]);
}
throw $e13931394;
}
var $ret13991400 = $Hanf_bracket13441405($z13951396,ifthenelse3371126,list1948);
++R.GAS;
return $ret13991400;
};
var $Hanf_bracket13441405 = function(anf_bracket9141404,ifthenelse3371126,list1948) {
var anf_fun9151418 = G(anf_bracket9141404,"check-is",L[160]);
var anf_fun9161416 = G(ifthenelse3371126,"pretty",L[162]);
var $z14081409 = D;
var $f14141415 = function(_) {
return R.isFunction(anf_fun9161416)?anf_fun9161416.app((6)):R.ffi.throwNonFunApp(L[161],anf_fun9161416,[(6)]);
};
try {
if(--R.GAS > 0) {
$z14081409 = $f14141415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14141415,
"from":L[161]});
}
} catch($e14061407) {
if(R.isCont($e14061407)) {
var $ss14101411 = {"from":L[161],
"go":function(anf_arg9171417) {
return $Hanf_arg13431419(anf_arg9171417,anf_fun9151418,list1948);
}};
$e14061407.stack[R.EXN_STACKHEIGHT++] = $ss14101411;
}
if(R.isPyretException($e14061407)) {
$e14061407.pyretStack.push(L[161]);
}
throw $e14061407;
}
var $ret14121413 = $Hanf_arg13431419($z14081409,anf_fun9151418,list1948);
++R.GAS;
return $ret14121413;
};
var $Hanf_arg13431419 = function(anf_arg9171417,anf_fun9151418,list1948) {
var anf_fun9181430 = G(list1948,"make",L[163]);
var $z14221423 = D;
var $f14281429 = function(_) {
return R.isFunction(anf_fun9181430)?anf_fun9181430.app([("if"),("  a =="),("    b"),("then"),("  a <<"),("    2"),("else"),("  a +"),("    b")]):R.ffi.throwNonFunApp(L[163],anf_fun9181430,[[("if"),("  a =="),("    b"),("then"),("  a <<"),("    2"),("else"),("  a +"),("    b")]]);
};
try {
if(--R.GAS > 0) {
$z14221423 = $f14281429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14281429,
"from":L[163]});
}
} catch($e14201421) {
if(R.isCont($e14201421)) {
var $ss14241425 = {"from":L[163],
"go":function(anf_arg9191431) {
return $Hanf_arg13421432(anf_arg9191431,anf_arg9171417,anf_fun9151418);
}};
$e14201421.stack[R.EXN_STACKHEIGHT++] = $ss14241425;
}
if(R.isPyretException($e14201421)) {
$e14201421.pyretStack.push(L[163]);
}
throw $e14201421;
}
var $ret14261427 = $Hanf_arg13421432($z14221423,anf_arg9171417,anf_fun9151418);
++R.GAS;
return $ret14261427;
};
var $Hanf_arg13421432 = function(anf_arg9191431,anf_arg9171417,anf_fun9151418) {
var anf_arg9201443 = R.makeSrcloc(L[160]);
var $z14351436 = D;
var $f14411442 = function(_) {
return R.isFunction(anf_fun9151418)?anf_fun9151418.app(("ifthenelse.pretty(6) is\n  [list: \n    \"if\",\n    \"  a ==\",\n    \"    b\",\n    \"then\",\n    \"  a <<\",\n    \"    2\",\n    \"else\",\n    \"  a +\",\n    \"    b\"\n  ]"),anf_arg9171417,anf_arg9191431,anf_arg9201443):R.ffi.throwNonFunApp(L[104],anf_fun9151418,[("ifthenelse.pretty(6) is\n  [list: \n    \"if\",\n    \"  a ==\",\n    \"    b\",\n    \"then\",\n    \"  a <<\",\n    \"    2\",\n    \"else\",\n    \"  a +\",\n    \"    b\"\n  ]"),anf_arg9171417,anf_arg9191431,anf_arg9201443]);
};
try {
if(--R.GAS > 0) {
$z14351436 = $f14411442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14411442,
"from":L[104]});
}
} catch($e14331434) {
if(R.isCont($e14331434)) {
var $ss14371438 = {"from":L[104],
"go":function(ann_DASH_check_DASH_temp7891444) {
return $Hann_DASH_check_DASH_temp13411445(ann_DASH_check_DASH_temp7891444);
}};
$e14331434.stack[R.EXN_STACKHEIGHT++] = $ss14371438;
}
if(R.isPyretException($e14331434)) {
$e14331434.pyretStack.push(L[104]);
}
throw $e14331434;
}
var $ret14391440 = $Hann_DASH_check_DASH_temp13411445($z14351436);
++R.GAS;
return $ret14391440;
};
var $Hann_DASH_check_DASH_temp13411445 = function(ann_DASH_check_DASH_temp7891444) {
return ann_DASH_check_DASH_temp7891444;
};
var $Hanf_arg13351035 = function(anf_arg8641033,anf_fun8631034,c3341020,group21980,nest22482,opt_DASH_break3261002) {
var $z14481449 = D;
var $f14541455 = function(_) {
return R.isFunction(opt_DASH_break3261002.$var)?opt_DASH_break3261002.$var.app(anf_arg8641033,c3341020):R.ffi.throwNonFunApp(L[164],opt_DASH_break3261002.$var,[anf_arg8641033,c3341020]);
};
try {
if(--R.GAS > 0) {
$z14481449 = $f14541455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14541455,
"from":L[164]});
}
} catch($e14461447) {
if(R.isCont($e14461447)) {
var $ss14501451 = {"from":L[164],
"go":function(anf_arg8651456) {
return $Hanf_arg13341457(anf_arg8651456,anf_fun8631034,group21980,nest22482);
}};
$e14461447.stack[R.EXN_STACKHEIGHT++] = $ss14501451;
}
if(R.isPyretException($e14461447)) {
$e14461447.pyretStack.push(L[164]);
}
throw $e14461447;
}
var $ret14521453 = $Hanf_arg13341457($z14481449,anf_fun8631034,group21980,nest22482);
++R.GAS;
return $ret14521453;
};
var $Hanf_arg13341457 = function(anf_arg8651456,anf_fun8631034,group21980,nest22482) {
var $z14601461 = D;
var $f14661467 = function(_) {
return R.isFunction(nest22482)?nest22482.app((2),anf_arg8651456):R.ffi.throwNonFunApp(L[165],nest22482,[(2),anf_arg8651456]);
};
try {
if(--R.GAS > 0) {
$z14601461 = $f14661467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14661467,
"from":L[165]});
}
} catch($e14581459) {
if(R.isCont($e14581459)) {
var $ss14621463 = {"from":L[165],
"go":function(anf_arg8661468) {
return $Hanf_arg13331469(anf_arg8661468,anf_fun8631034,group21980);
}};
$e14581459.stack[R.EXN_STACKHEIGHT++] = $ss14621463;
}
if(R.isPyretException($e14581459)) {
$e14581459.pyretStack.push(L[165]);
}
throw $e14581459;
}
var $ret14641465 = $Hanf_arg13331469($z14601461,anf_fun8631034,group21980);
++R.GAS;
return $ret14641465;
};
var $Hanf_arg13331469 = function(anf_arg8661468,anf_fun8631034,group21980) {
var $z14721473 = D;
var $f14781479 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg8661468):R.ffi.throwNonFunApp(L[166],group21980,[anf_arg8661468]);
};
try {
if(--R.GAS > 0) {
$z14721473 = $f14781479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14781479,
"from":L[166]});
}
} catch($e14701471) {
if(R.isCont($e14701471)) {
var $ss14741475 = {"from":L[166],
"go":function(anf_arg8671480) {
return $Hanf_arg13321481(anf_arg8671480,anf_fun8631034,group21980);
}};
$e14701471.stack[R.EXN_STACKHEIGHT++] = $ss14741475;
}
if(R.isPyretException($e14701471)) {
$e14701471.pyretStack.push(L[166]);
}
throw $e14701471;
}
var $ret14761477 = $Hanf_arg13321481($z14721473,anf_fun8631034,group21980);
++R.GAS;
return $ret14761477;
};
var $Hanf_arg13321481 = function(anf_arg8671480,anf_fun8631034,group21980) {
var $z14841485 = D;
var $f14901491 = function(_) {
return R.isFunction(anf_fun8631034)?anf_fun8631034.app(anf_arg8671480):R.ffi.throwNonFunApp(L[129],anf_fun8631034,[anf_arg8671480]);
};
try {
if(--R.GAS > 0) {
$z14841485 = $f14901491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14901491,
"from":L[129]});
}
} catch($e14821483) {
if(R.isCont($e14821483)) {
var $ss14861487 = {"from":L[129],
"go":function(anf_arg8681492) {
return $Hanf_arg13311493(anf_arg8681492,group21980);
}};
$e14821483.stack[R.EXN_STACKHEIGHT++] = $ss14861487;
}
if(R.isPyretException($e14821483)) {
$e14821483.pyretStack.push(L[129]);
}
throw $e14821483;
}
var $ret14881489 = $Hanf_arg13311493($z14841485,group21980);
++R.GAS;
return $ret14881489;
};
var $Hanf_arg13311493 = function(anf_arg8681492,group21980) {
var $z14961497 = D;
var $f15021503 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg8681492):R.ffi.throwNonFunApp(L[127],group21980,[anf_arg8681492]);
};
try {
if(--R.GAS > 0) {
$z14961497 = $f15021503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15021503,
"from":L[127]});
}
} catch($e14941495) {
if(R.isCont($e14941495)) {
var $ss14981499 = {"from":L[127],
"go":function(ann_DASH_check_DASH_temp8501504) {
return $Hann_DASH_check_DASH_temp13301505(ann_DASH_check_DASH_temp8501504);
}};
$e14941495.stack[R.EXN_STACKHEIGHT++] = $ss14981499;
}
if(R.isPyretException($e14941495)) {
$e14941495.pyretStack.push(L[127]);
}
throw $e14941495;
}
var $ret15001501 = $Hann_DASH_check_DASH_temp13301505($z14961497);
++R.GAS;
return $ret15001501;
};
var $Hann_DASH_check_DASH_temp13301505 = function(ann_DASH_check_DASH_temp8501504) {
return ann_DASH_check_DASH_temp8501504;
};
var $Hanf_arg13291049 = function(anf_arg8581047,anf_fun8571048,arg_DASH_911036,group21980,nest22482,opt_DASH_break3261002,t3351021) {
var $z15081509 = D;
var $f15141515 = function(_) {
return R.isFunction(opt_DASH_break3261002.$var)?opt_DASH_break3261002.$var.app(anf_arg8581047,t3351021):R.ffi.throwNonFunApp(L[167],opt_DASH_break3261002.$var,[anf_arg8581047,t3351021]);
};
try {
if(--R.GAS > 0) {
$z15081509 = $f15141515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15141515,
"from":L[167]});
}
} catch($e15061507) {
if(R.isCont($e15061507)) {
var $ss15101511 = {"from":L[167],
"go":function(anf_arg8591516) {
return $Hanf_arg13281517(anf_arg8591516,anf_fun8571048,arg_DASH_911036,group21980,nest22482,opt_DASH_break3261002);
}};
$e15061507.stack[R.EXN_STACKHEIGHT++] = $ss15101511;
}
if(R.isPyretException($e15061507)) {
$e15061507.pyretStack.push(L[167]);
}
throw $e15061507;
}
var $ret15121513 = $Hanf_arg13281517($z15081509,anf_fun8571048,arg_DASH_911036,group21980,nest22482,opt_DASH_break3261002);
++R.GAS;
return $ret15121513;
};
var $Hanf_arg13281517 = function(anf_arg8591516,anf_fun8571048,arg_DASH_911036,group21980,nest22482,opt_DASH_break3261002) {
var $z15201521 = D;
var $f15261527 = function(_) {
return R.isFunction(nest22482)?nest22482.app((2),anf_arg8591516):R.ffi.throwNonFunApp(L[168],nest22482,[(2),anf_arg8591516]);
};
try {
if(--R.GAS > 0) {
$z15201521 = $f15261527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15261527,
"from":L[168]});
}
} catch($e15181519) {
if(R.isCont($e15181519)) {
var $ss15221523 = {"from":L[168],
"go":function(anf_arg8601528) {
return $Hanf_arg13271529(anf_arg8601528,anf_fun8571048,arg_DASH_911036,group21980,opt_DASH_break3261002);
}};
$e15181519.stack[R.EXN_STACKHEIGHT++] = $ss15221523;
}
if(R.isPyretException($e15181519)) {
$e15181519.pyretStack.push(L[168]);
}
throw $e15181519;
}
var $ret15241525 = $Hanf_arg13271529($z15201521,anf_fun8571048,arg_DASH_911036,group21980,opt_DASH_break3261002);
++R.GAS;
return $ret15241525;
};
var $Hanf_arg13271529 = function(anf_arg8601528,anf_fun8571048,arg_DASH_911036,group21980,opt_DASH_break3261002) {
var $z15321533 = D;
var $f15381539 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg8601528):R.ffi.throwNonFunApp(L[169],group21980,[anf_arg8601528]);
};
try {
if(--R.GAS > 0) {
$z15321533 = $f15381539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15381539,
"from":L[169]});
}
} catch($e15301531) {
if(R.isCont($e15301531)) {
var $ss15341535 = {"from":L[169],
"go":function(anf_arg8611540) {
return $Hanf_arg13261541(anf_arg8611540,anf_fun8571048,arg_DASH_911036,opt_DASH_break3261002);
}};
$e15301531.stack[R.EXN_STACKHEIGHT++] = $ss15341535;
}
if(R.isPyretException($e15301531)) {
$e15301531.pyretStack.push(L[169]);
}
throw $e15301531;
}
var $ret15361537 = $Hanf_arg13261541($z15321533,anf_fun8571048,arg_DASH_911036,opt_DASH_break3261002);
++R.GAS;
return $ret15361537;
};
var $Hanf_arg13261541 = function(anf_arg8611540,anf_fun8571048,arg_DASH_911036,opt_DASH_break3261002) {
var $z15441545 = D;
var $f15501551 = function(_) {
return R.isFunction(anf_fun8571048)?anf_fun8571048.app(anf_arg8611540):R.ffi.throwNonFunApp(L[131],anf_fun8571048,[anf_arg8611540]);
};
try {
if(--R.GAS > 0) {
$z15441545 = $f15501551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15501551,
"from":L[131]});
}
} catch($e15421543) {
if(R.isCont($e15421543)) {
var $ss15461547 = {"from":L[131],
"go":function(anf_arg8621552) {
return $Hanf_arg13251553(anf_arg8621552,arg_DASH_911036,opt_DASH_break3261002);
}};
$e15421543.stack[R.EXN_STACKHEIGHT++] = $ss15461547;
}
if(R.isPyretException($e15421543)) {
$e15421543.pyretStack.push(L[131]);
}
throw $e15421543;
}
var $ret15481549 = $Hanf_arg13251553($z15441545,arg_DASH_911036,opt_DASH_break3261002);
++R.GAS;
return $ret15481549;
};
var $Hanf_arg13251553 = function(anf_arg8621552,arg_DASH_911036,opt_DASH_break3261002) {
var $z15561557 = D;
var $f15621563 = function(_) {
return R.isFunction(opt_DASH_break3261002.$var)?opt_DASH_break3261002.$var.app(arg_DASH_911036,anf_arg8621552):R.ffi.throwNonFunApp(L[129],opt_DASH_break3261002.$var,[arg_DASH_911036,anf_arg8621552]);
};
try {
if(--R.GAS > 0) {
$z15561557 = $f15621563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15621563,
"from":L[129]});
}
} catch($e15541555) {
if(R.isCont($e15541555)) {
var $ss15581559 = {"from":L[129],
"go":function(ann_DASH_check_DASH_temp8511564) {
return $Hann_DASH_check_DASH_temp13241565(ann_DASH_check_DASH_temp8511564);
}};
$e15541555.stack[R.EXN_STACKHEIGHT++] = $ss15581559;
}
if(R.isPyretException($e15541555)) {
$e15541555.pyretStack.push(L[129]);
}
throw $e15541555;
}
var $ret15601561 = $Hann_DASH_check_DASH_temp13241565($z15561557);
++R.GAS;
return $ret15601561;
};
var $Hann_DASH_check_DASH_temp13241565 = function(ann_DASH_check_DASH_temp8511564) {
return ann_DASH_check_DASH_temp8511564;
};
var $Hanf_arg13231062 = function(anf_arg8531061,arg_DASH_901050,f3361022,group21980,nest22482,opt_DASH_break3261002) {
var $z15681569 = D;
var $f15741575 = function(_) {
return R.isFunction(opt_DASH_break3261002.$var)?opt_DASH_break3261002.$var.app(anf_arg8531061,f3361022):R.ffi.throwNonFunApp(L[170],opt_DASH_break3261002.$var,[anf_arg8531061,f3361022]);
};
try {
if(--R.GAS > 0) {
$z15681569 = $f15741575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15741575,
"from":L[170]});
}
} catch($e15661567) {
if(R.isCont($e15661567)) {
var $ss15701571 = {"from":L[170],
"go":function(anf_arg8541576) {
return $Hanf_arg13221577(anf_arg8541576,arg_DASH_901050,group21980,nest22482,opt_DASH_break3261002);
}};
$e15661567.stack[R.EXN_STACKHEIGHT++] = $ss15701571;
}
if(R.isPyretException($e15661567)) {
$e15661567.pyretStack.push(L[170]);
}
throw $e15661567;
}
var $ret15721573 = $Hanf_arg13221577($z15681569,arg_DASH_901050,group21980,nest22482,opt_DASH_break3261002);
++R.GAS;
return $ret15721573;
};
var $Hanf_arg13221577 = function(anf_arg8541576,arg_DASH_901050,group21980,nest22482,opt_DASH_break3261002) {
var $z15801581 = D;
var $f15861587 = function(_) {
return R.isFunction(nest22482)?nest22482.app((2),anf_arg8541576):R.ffi.throwNonFunApp(L[171],nest22482,[(2),anf_arg8541576]);
};
try {
if(--R.GAS > 0) {
$z15801581 = $f15861587();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15861587,
"from":L[171]});
}
} catch($e15781579) {
if(R.isCont($e15781579)) {
var $ss15821583 = {"from":L[171],
"go":function(anf_arg8551588) {
return $Hanf_arg13211589(anf_arg8551588,arg_DASH_901050,group21980,opt_DASH_break3261002);
}};
$e15781579.stack[R.EXN_STACKHEIGHT++] = $ss15821583;
}
if(R.isPyretException($e15781579)) {
$e15781579.pyretStack.push(L[171]);
}
throw $e15781579;
}
var $ret15841585 = $Hanf_arg13211589($z15801581,arg_DASH_901050,group21980,opt_DASH_break3261002);
++R.GAS;
return $ret15841585;
};
var $Hanf_arg13211589 = function(anf_arg8551588,arg_DASH_901050,group21980,opt_DASH_break3261002) {
var $z15921593 = D;
var $f15981599 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg8551588):R.ffi.throwNonFunApp(L[172],group21980,[anf_arg8551588]);
};
try {
if(--R.GAS > 0) {
$z15921593 = $f15981599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15981599,
"from":L[172]});
}
} catch($e15901591) {
if(R.isCont($e15901591)) {
var $ss15941595 = {"from":L[172],
"go":function(anf_arg8561600) {
return $Hanf_arg13201601(anf_arg8561600,arg_DASH_901050,opt_DASH_break3261002);
}};
$e15901591.stack[R.EXN_STACKHEIGHT++] = $ss15941595;
}
if(R.isPyretException($e15901591)) {
$e15901591.pyretStack.push(L[172]);
}
throw $e15901591;
}
var $ret15961597 = $Hanf_arg13201601($z15921593,arg_DASH_901050,opt_DASH_break3261002);
++R.GAS;
return $ret15961597;
};
var $Hanf_arg13201601 = function(anf_arg8561600,arg_DASH_901050,opt_DASH_break3261002) {
var $z16041605 = D;
var $f16101611 = function(_) {
return R.isFunction(opt_DASH_break3261002.$var)?opt_DASH_break3261002.$var.app(arg_DASH_901050,anf_arg8561600):R.ffi.throwNonFunApp(L[131],opt_DASH_break3261002.$var,[arg_DASH_901050,anf_arg8561600]);
};
try {
if(--R.GAS > 0) {
$z16041605 = $f16101611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16101611,
"from":L[131]});
}
} catch($e16021603) {
if(R.isCont($e16021603)) {
var $ss16061607 = {"from":L[131],
"go":function(ann_DASH_check_DASH_temp8521612) {
return $Hann_DASH_check_DASH_temp13191613(ann_DASH_check_DASH_temp8521612);
}};
$e16021603.stack[R.EXN_STACKHEIGHT++] = $ss16061607;
}
if(R.isPyretException($e16021603)) {
$e16021603.pyretStack.push(L[131]);
}
throw $e16021603;
}
var $ret16081609 = $Hann_DASH_check_DASH_temp13191613($z16041605);
++R.GAS;
return $ret16081609;
};
var $Hann_DASH_check_DASH_temp13191613 = function(ann_DASH_check_DASH_temp8521612) {
return ann_DASH_check_DASH_temp8521612;
};
var $Hanf_arg13181077 = function(anf_arg8421076,group21980,nest22482,op3321064,opt_DASH_break3261002,right3331065,str23275) {
var $z16161617 = D;
var $f16221623 = function(_) {
return R.isFunction(str23275)?str23275.app(op3321064):R.ffi.throwNonFunApp(L[173],str23275,[op3321064]);
};
try {
if(--R.GAS > 0) {
$z16161617 = $f16221623();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16221623,
"from":L[173]});
}
} catch($e16141615) {
if(R.isCont($e16141615)) {
var $ss16181619 = {"from":L[173],
"go":function(anf_arg8431624) {
return $Hanf_arg13171625(anf_arg8431624,anf_arg8421076,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275);
}};
$e16141615.stack[R.EXN_STACKHEIGHT++] = $ss16181619;
}
if(R.isPyretException($e16141615)) {
$e16141615.pyretStack.push(L[173]);
}
throw $e16141615;
}
var $ret16201621 = $Hanf_arg13171625($z16161617,anf_arg8421076,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275);
++R.GAS;
return $ret16201621;
};
var $Hanf_arg13171625 = function(anf_arg8431624,anf_arg8421076,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275) {
var $z16281629 = D;
var $f16341635 = function(_) {
return R.isFunction(opt_DASH_break3261002.$var)?opt_DASH_break3261002.$var.app(anf_arg8421076,anf_arg8431624):R.ffi.throwNonFunApp(L[174],opt_DASH_break3261002.$var,[anf_arg8421076,anf_arg8431624]);
};
try {
if(--R.GAS > 0) {
$z16281629 = $f16341635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16341635,
"from":L[174]});
}
} catch($e16261627) {
if(R.isCont($e16261627)) {
var $ss16301631 = {"from":L[174],
"go":function(anf_arg8441636) {
return $Hanf_arg13161637(anf_arg8441636,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275);
}};
$e16261627.stack[R.EXN_STACKHEIGHT++] = $ss16301631;
}
if(R.isPyretException($e16261627)) {
$e16261627.pyretStack.push(L[174]);
}
throw $e16261627;
}
var $ret16321633 = $Hanf_arg13161637($z16281629,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275);
++R.GAS;
return $ret16321633;
};
var $Hanf_arg13161637 = function(anf_arg8441636,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275) {
var $z16401641 = D;
var $f16461647 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg8441636):R.ffi.throwNonFunApp(L[175],group21980,[anf_arg8441636]);
};
try {
if(--R.GAS > 0) {
$z16401641 = $f16461647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16461647,
"from":L[175]});
}
} catch($e16381639) {
if(R.isCont($e16381639)) {
var $ss16421643 = {"from":L[175],
"go":function(anf_arg8451648) {
return $Hanf_arg13151649(anf_arg8451648,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275);
}};
$e16381639.stack[R.EXN_STACKHEIGHT++] = $ss16421643;
}
if(R.isPyretException($e16381639)) {
$e16381639.pyretStack.push(L[175]);
}
throw $e16381639;
}
var $ret16441645 = $Hanf_arg13151649($z16401641,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275);
++R.GAS;
return $ret16441645;
};
var $Hanf_arg13151649 = function(anf_arg8451648,group21980,nest22482,opt_DASH_break3261002,right3331065,str23275) {
var $z16521653 = D;
var $f16581659 = function(_) {
return R.isFunction(str23275)?str23275.app(right3331065):R.ffi.throwNonFunApp(L[176],str23275,[right3331065]);
};
try {
if(--R.GAS > 0) {
$z16521653 = $f16581659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16581659,
"from":L[176]});
}
} catch($e16501651) {
if(R.isCont($e16501651)) {
var $ss16541655 = {"from":L[176],
"go":function(anf_arg8461660) {
return $Hanf_arg13141661(anf_arg8461660,anf_arg8451648,group21980,nest22482,opt_DASH_break3261002);
}};
$e16501651.stack[R.EXN_STACKHEIGHT++] = $ss16541655;
}
if(R.isPyretException($e16501651)) {
$e16501651.pyretStack.push(L[176]);
}
throw $e16501651;
}
var $ret16561657 = $Hanf_arg13141661($z16521653,anf_arg8451648,group21980,nest22482,opt_DASH_break3261002);
++R.GAS;
return $ret16561657;
};
var $Hanf_arg13141661 = function(anf_arg8461660,anf_arg8451648,group21980,nest22482,opt_DASH_break3261002) {
var $z16641665 = D;
var $f16701671 = function(_) {
return R.isFunction(opt_DASH_break3261002.$var)?opt_DASH_break3261002.$var.app(anf_arg8451648,anf_arg8461660):R.ffi.throwNonFunApp(L[177],opt_DASH_break3261002.$var,[anf_arg8451648,anf_arg8461660]);
};
try {
if(--R.GAS > 0) {
$z16641665 = $f16701671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16701671,
"from":L[177]});
}
} catch($e16621663) {
if(R.isCont($e16621663)) {
var $ss16661667 = {"from":L[177],
"go":function(anf_arg8471672) {
return $Hanf_arg13131673(anf_arg8471672,group21980,nest22482);
}};
$e16621663.stack[R.EXN_STACKHEIGHT++] = $ss16661667;
}
if(R.isPyretException($e16621663)) {
$e16621663.pyretStack.push(L[177]);
}
throw $e16621663;
}
var $ret16681669 = $Hanf_arg13131673($z16641665,group21980,nest22482);
++R.GAS;
return $ret16681669;
};
var $Hanf_arg13131673 = function(anf_arg8471672,group21980,nest22482) {
var $z16761677 = D;
var $f16821683 = function(_) {
return R.isFunction(nest22482)?nest22482.app((2),anf_arg8471672):R.ffi.throwNonFunApp(L[178],nest22482,[(2),anf_arg8471672]);
};
try {
if(--R.GAS > 0) {
$z16761677 = $f16821683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16821683,
"from":L[178]});
}
} catch($e16741675) {
if(R.isCont($e16741675)) {
var $ss16781679 = {"from":L[178],
"go":function(anf_arg8481684) {
return $Hanf_arg13121685(anf_arg8481684,group21980);
}};
$e16741675.stack[R.EXN_STACKHEIGHT++] = $ss16781679;
}
if(R.isPyretException($e16741675)) {
$e16741675.pyretStack.push(L[178]);
}
throw $e16741675;
}
var $ret16801681 = $Hanf_arg13121685($z16761677,group21980);
++R.GAS;
return $ret16801681;
};
var $Hanf_arg13121685 = function(anf_arg8481684,group21980) {
var $z16881689 = D;
var $f16941695 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg8481684):R.ffi.throwNonFunApp(L[133],group21980,[anf_arg8481684]);
};
try {
if(--R.GAS > 0) {
$z16881689 = $f16941695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16941695,
"from":L[133]});
}
} catch($e16861687) {
if(R.isCont($e16861687)) {
var $ss16901691 = {"from":L[133],
"go":function(ann_DASH_check_DASH_temp8411696) {
return $Hann_DASH_check_DASH_temp13111697(ann_DASH_check_DASH_temp8411696);
}};
$e16861687.stack[R.EXN_STACKHEIGHT++] = $ss16901691;
}
if(R.isPyretException($e16861687)) {
$e16861687.pyretStack.push(L[133]);
}
throw $e16861687;
}
var $ret16921693 = $Hann_DASH_check_DASH_temp13111697($z16881689);
++R.GAS;
return $ret16921693;
};
var $Hann_DASH_check_DASH_temp13111697 = function(ann_DASH_check_DASH_temp8411696) {
return ann_DASH_check_DASH_temp8411696;
};
var $Hif_DASH_13101091 = function(if_DASH_891090,is_DASH_empty2046,sbreak245295,x3291078,y3301079,_plus8) {
var if_helper8261708 = R.makeFunction(function(if_helper_arg8271728) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[136],1,arguments);
}
var ann_DASH_check_DASH_temp8251729 = if_helper_arg8271728;
return ann_DASH_check_DASH_temp8251729;
});
var anf_if8301727 = R.isBoolean(if_DASH_891090);
if(R.isPyretTrue(anf_if8301727)) {
if(R.isPyretTrue(if_DASH_891090)) {
var $z17001701 = D;
var $f17061707 = function(_) {
return R.isFunction(if_helper8261708)?if_helper8261708.app(y3301079):R.ffi.throwNonFunApp(L[179],if_helper8261708,[y3301079]);
};
try {
if(--R.GAS > 0) {
$z17001701 = $f17061707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17061707,
"from":L[179]});
}
} catch($e16981699) {
if(R.isCont($e16981699)) {
var $ss17021703 = {"from":L[179],
"go":function(cont_tail_app8391709) {
return $Hcont_tail_app13041710(cont_tail_app8391709);
}};
$e16981699.stack[R.EXN_STACKHEIGHT++] = $ss17021703;
}
if(R.isPyretException($e16981699)) {
$e16981699.pyretStack.push(L[179]);
}
throw $e16981699;
}
var $ret17041705 = $Hcont_tail_app13041710($z17001701);
++R.GAS;
return $ret17041705;
} else {
var $z17131714 = D;
var $f17191720 = function(_) {
return R.isFunction(is_DASH_empty2046)?is_DASH_empty2046.app(y3301079):R.ffi.throwNonFunApp(L[180],is_DASH_empty2046,[y3301079]);
};
try {
if(--R.GAS > 0) {
$z17131714 = $f17191720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17191720,
"from":L[180]});
}
} catch($e17111712) {
if(R.isCont($e17111712)) {
var $ss17151716 = {"from":L[180],
"go":function(if_DASH_881721) {
return $Hif_DASH_13091722(if_DASH_881721,if_helper8261708,sbreak245295,x3291078,y3301079,_plus8);
}};
$e17111712.stack[R.EXN_STACKHEIGHT++] = $ss17151716;
}
if(R.isPyretException($e17111712)) {
$e17111712.pyretStack.push(L[180]);
}
throw $e17111712;
}
var $ret17171718 = $Hif_DASH_13091722($z17131714,if_helper8261708,sbreak245295,x3291078,y3301079,_plus8);
++R.GAS;
return $ret17171718;
}
} else {
var cont_tail_arg8281725 = R.throwNonBooleanCondition(L[136],("if"),if_DASH_891090);
if(--R.GAS > 0) {
$z17231724 = R.isFunction(if_helper8261708)?if_helper8261708.app(cont_tail_arg8281725):R.ffi.throwNonFunApp(L[136],if_helper8261708,[cont_tail_arg8281725]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper8261708)?if_helper8261708.app(cont_tail_arg8281725):R.ffi.throwNonFunApp(L[136],if_helper8261708,[cont_tail_arg8281725]);
},
"from":L[136]});
}
++R.GAS;
return $z17231724;
}
};
var $Hcont_tail_app13041710 = function(cont_tail_app8391709) {
return cont_tail_app8391709;
};
var $Hif_DASH_13091722 = function(if_DASH_881721,if_helper8261708,sbreak245295,x3291078,y3301079,_plus8) {
var anf_if8331757 = R.isBoolean(if_DASH_881721);
if(R.isPyretTrue(anf_if8331757)) {
if(R.isPyretTrue(if_DASH_881721)) {
var $z17321733 = D;
var $f17381739 = function(_) {
return R.isFunction(if_helper8261708)?if_helper8261708.app(x3291078):R.ffi.throwNonFunApp(L[181],if_helper8261708,[x3291078]);
};
try {
if(--R.GAS > 0) {
$z17321733 = $f17381739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17381739,
"from":L[181]});
}
} catch($e17301731) {
if(R.isCont($e17301731)) {
var $ss17341735 = {"from":L[181],
"go":function(cont_tail_app8381740) {
return $Hcont_tail_app13051741(cont_tail_app8381740);
}};
$e17301731.stack[R.EXN_STACKHEIGHT++] = $ss17341735;
}
if(R.isPyretException($e17301731)) {
$e17301731.pyretStack.push(L[181]);
}
throw $e17301731;
}
var $ret17361737 = $Hcont_tail_app13051741($z17321733);
++R.GAS;
return $ret17361737;
} else {
var $z17441745 = D;
var $f17501751 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app((1)):R.ffi.throwNonFunApp(L[182],sbreak245295.$var,[(1)]);
};
try {
if(--R.GAS > 0) {
$z17441745 = $f17501751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17501751,
"from":L[182]});
}
} catch($e17421743) {
if(R.isCont($e17421743)) {
var $ss17461747 = {"from":L[182],
"go":function(anf_arg8341752) {
return $Hanf_arg13081753(anf_arg8341752,if_helper8261708,x3291078,y3301079,_plus8);
}};
$e17421743.stack[R.EXN_STACKHEIGHT++] = $ss17461747;
}
if(R.isPyretException($e17421743)) {
$e17421743.pyretStack.push(L[182]);
}
throw $e17421743;
}
var $ret17481749 = $Hanf_arg13081753($z17441745,if_helper8261708,x3291078,y3301079,_plus8);
++R.GAS;
return $ret17481749;
}
} else {
var cont_tail_arg8311756 = R.throwNonBooleanCondition(L[183],("if"),if_DASH_881721);
if(--R.GAS > 0) {
$z17541755 = R.isFunction(if_helper8261708)?if_helper8261708.app(cont_tail_arg8311756):R.ffi.throwNonFunApp(L[183],if_helper8261708,[cont_tail_arg8311756]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper8261708)?if_helper8261708.app(cont_tail_arg8311756):R.ffi.throwNonFunApp(L[183],if_helper8261708,[cont_tail_arg8311756]);
},
"from":L[183]});
}
++R.GAS;
return $z17541755;
}
};
var $Hcont_tail_app13051741 = function(cont_tail_app8381740) {
return cont_tail_app8381740;
};
var $Hanf_arg13081753 = function(anf_arg8341752,if_helper8261708,x3291078,y3301079,_plus8) {
var $z17601761 = D;
var $f17661767 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg8341752,y3301079):R.ffi.throwNonFunApp(L[184],_plus8,[anf_arg8341752,y3301079]);
};
try {
if(--R.GAS > 0) {
$z17601761 = $f17661767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17661767,
"from":L[184]});
}
} catch($e17581759) {
if(R.isCont($e17581759)) {
var $ss17621763 = {"from":L[184],
"go":function(anf_arg8351768) {
return $Hanf_arg13071769(anf_arg8351768,if_helper8261708,x3291078,_plus8);
}};
$e17581759.stack[R.EXN_STACKHEIGHT++] = $ss17621763;
}
if(R.isPyretException($e17581759)) {
$e17581759.pyretStack.push(L[184]);
}
throw $e17581759;
}
var $ret17641765 = $Hanf_arg13071769($z17601761,if_helper8261708,x3291078,_plus8);
++R.GAS;
return $ret17641765;
};
var $Hanf_arg13071769 = function(anf_arg8351768,if_helper8261708,x3291078,_plus8) {
var $z17721773 = D;
var $f17781779 = function(_) {
return R.isFunction(_plus8)?_plus8.app(x3291078,anf_arg8351768):R.ffi.throwNonFunApp(L[185],_plus8,[x3291078,anf_arg8351768]);
};
try {
if(--R.GAS > 0) {
$z17721773 = $f17781779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17781779,
"from":L[185]});
}
} catch($e17701771) {
if(R.isCont($e17701771)) {
var $ss17741775 = {"from":L[185],
"go":function(cont_tail_arg8361780) {
return $Hcont_tail_arg13061781(cont_tail_arg8361780,if_helper8261708);
}};
$e17701771.stack[R.EXN_STACKHEIGHT++] = $ss17741775;
}
if(R.isPyretException($e17701771)) {
$e17701771.pyretStack.push(L[185]);
}
throw $e17701771;
}
var $ret17761777 = $Hcont_tail_arg13061781($z17721773,if_helper8261708);
++R.GAS;
return $ret17761777;
};
var $Hcont_tail_arg13061781 = function(cont_tail_arg8361780,if_helper8261708) {
if(--R.GAS > 0) {
$z17821783 = R.isFunction(if_helper8261708)?if_helper8261708.app(cont_tail_arg8361780):R.ffi.throwNonFunApp(L[185],if_helper8261708,[cont_tail_arg8361780]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper8261708)?if_helper8261708.app(cont_tail_arg8361780):R.ffi.throwNonFunApp(L[185],if_helper8261708,[cont_tail_arg8361780]);
},
"from":L[185]});
}
++R.GAS;
return $z17821783;
};
var $Hanf_arg1299521 = function(anf_arg775520,align21777,close322509,group21980,label318505,open319506,sbreak245295,_plus8) {
var $z17861787 = D;
var $f17921793 = function(_) {
return R.isFunction(align21777)?align21777.app(anf_arg775520):R.ffi.throwNonFunApp(L[186],align21777,[anf_arg775520]);
};
try {
if(--R.GAS > 0) {
$z17861787 = $f17921793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17921793,
"from":L[186]});
}
} catch($e17841785) {
if(R.isCont($e17841785)) {
var $ss17881789 = {"from":L[186],
"go":function(anf_arg7761794) {
return $Hanf_arg12981795(anf_arg7761794,align21777,close322509,group21980,label318505,open319506,sbreak245295,_plus8);
}};
$e17841785.stack[R.EXN_STACKHEIGHT++] = $ss17881789;
}
if(R.isPyretException($e17841785)) {
$e17841785.pyretStack.push(L[186]);
}
throw $e17841785;
}
var $ret17901791 = $Hanf_arg12981795($z17861787,align21777,close322509,group21980,label318505,open319506,sbreak245295,_plus8);
++R.GAS;
return $ret17901791;
};
var $Hanf_arg12981795 = function(anf_arg7761794,align21777,close322509,group21980,label318505,open319506,sbreak245295,_plus8) {
var $z17981799 = D;
var $f18041805 = function(_) {
return R.isFunction(_plus8)?_plus8.app(open319506,anf_arg7761794):R.ffi.throwNonFunApp(L[187],_plus8,[open319506,anf_arg7761794]);
};
try {
if(--R.GAS > 0) {
$z17981799 = $f18041805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18041805,
"from":L[187]});
}
} catch($e17961797) {
if(R.isCont($e17961797)) {
var $ss18001801 = {"from":L[187],
"go":function(anf_arg7771806) {
return $Hanf_arg12971807(anf_arg7771806,align21777,close322509,group21980,label318505,sbreak245295,_plus8);
}};
$e17961797.stack[R.EXN_STACKHEIGHT++] = $ss18001801;
}
if(R.isPyretException($e17961797)) {
$e17961797.pyretStack.push(L[187]);
}
throw $e17961797;
}
var $ret18021803 = $Hanf_arg12971807($z17981799,align21777,close322509,group21980,label318505,sbreak245295,_plus8);
++R.GAS;
return $ret18021803;
};
var $Hanf_arg12971807 = function(anf_arg7771806,align21777,close322509,group21980,label318505,sbreak245295,_plus8) {
var $z18101811 = D;
var $f18161817 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app((0)):R.ffi.throwNonFunApp(L[188],sbreak245295.$var,[(0)]);
};
try {
if(--R.GAS > 0) {
$z18101811 = $f18161817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18161817,
"from":L[188]});
}
} catch($e18081809) {
if(R.isCont($e18081809)) {
var $ss18121813 = {"from":L[188],
"go":function(anf_arg7781818) {
return $Hanf_arg12961819(anf_arg7781818,align21777,anf_arg7771806,close322509,group21980,label318505,_plus8);
}};
$e18081809.stack[R.EXN_STACKHEIGHT++] = $ss18121813;
}
if(R.isPyretException($e18081809)) {
$e18081809.pyretStack.push(L[188]);
}
throw $e18081809;
}
var $ret18141815 = $Hanf_arg12961819($z18101811,align21777,anf_arg7771806,close322509,group21980,label318505,_plus8);
++R.GAS;
return $ret18141815;
};
var $Hanf_arg12961819 = function(anf_arg7781818,align21777,anf_arg7771806,close322509,group21980,label318505,_plus8) {
var $z18221823 = D;
var $f18281829 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7781818,close322509):R.ffi.throwNonFunApp(L[189],_plus8,[anf_arg7781818,close322509]);
};
try {
if(--R.GAS > 0) {
$z18221823 = $f18281829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18281829,
"from":L[189]});
}
} catch($e18201821) {
if(R.isCont($e18201821)) {
var $ss18241825 = {"from":L[189],
"go":function(anf_arg7791830) {
return $Hanf_arg12951831(anf_arg7791830,align21777,anf_arg7771806,group21980,label318505,_plus8);
}};
$e18201821.stack[R.EXN_STACKHEIGHT++] = $ss18241825;
}
if(R.isPyretException($e18201821)) {
$e18201821.pyretStack.push(L[189]);
}
throw $e18201821;
}
var $ret18261827 = $Hanf_arg12951831($z18221823,align21777,anf_arg7771806,group21980,label318505,_plus8);
++R.GAS;
return $ret18261827;
};
var $Hanf_arg12951831 = function(anf_arg7791830,align21777,anf_arg7771806,group21980,label318505,_plus8) {
var $z18341835 = D;
var $f18401841 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7791830):R.ffi.throwNonFunApp(L[190],group21980,[anf_arg7791830]);
};
try {
if(--R.GAS > 0) {
$z18341835 = $f18401841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18401841,
"from":L[190]});
}
} catch($e18321833) {
if(R.isCont($e18321833)) {
var $ss18361837 = {"from":L[190],
"go":function(anf_arg7801842) {
return $Hanf_arg12941843(anf_arg7801842,align21777,anf_arg7771806,group21980,label318505,_plus8);
}};
$e18321833.stack[R.EXN_STACKHEIGHT++] = $ss18361837;
}
if(R.isPyretException($e18321833)) {
$e18321833.pyretStack.push(L[190]);
}
throw $e18321833;
}
var $ret18381839 = $Hanf_arg12941843($z18341835,align21777,anf_arg7771806,group21980,label318505,_plus8);
++R.GAS;
return $ret18381839;
};
var $Hanf_arg12941843 = function(anf_arg7801842,align21777,anf_arg7771806,group21980,label318505,_plus8) {
var $z18461847 = D;
var $f18521853 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7771806,anf_arg7801842):R.ffi.throwNonFunApp(L[187],_plus8,[anf_arg7771806,anf_arg7801842]);
};
try {
if(--R.GAS > 0) {
$z18461847 = $f18521853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18521853,
"from":L[187]});
}
} catch($e18441845) {
if(R.isCont($e18441845)) {
var $ss18481849 = {"from":L[187],
"go":function(anf_arg7811854) {
return $Hanf_arg12931855(anf_arg7811854,align21777,group21980,label318505,_plus8);
}};
$e18441845.stack[R.EXN_STACKHEIGHT++] = $ss18481849;
}
if(R.isPyretException($e18441845)) {
$e18441845.pyretStack.push(L[187]);
}
throw $e18441845;
}
var $ret18501851 = $Hanf_arg12931855($z18461847,align21777,group21980,label318505,_plus8);
++R.GAS;
return $ret18501851;
};
var $Hanf_arg12931855 = function(anf_arg7811854,align21777,group21980,label318505,_plus8) {
var $z18581859 = D;
var $f18641865 = function(_) {
return R.isFunction(align21777)?align21777.app(anf_arg7811854):R.ffi.throwNonFunApp(L[191],align21777,[anf_arg7811854]);
};
try {
if(--R.GAS > 0) {
$z18581859 = $f18641865();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18641865,
"from":L[191]});
}
} catch($e18561857) {
if(R.isCont($e18561857)) {
var $ss18601861 = {"from":L[191],
"go":function(anf_arg7821866) {
return $Hanf_arg12921867(anf_arg7821866,group21980,label318505,_plus8);
}};
$e18561857.stack[R.EXN_STACKHEIGHT++] = $ss18601861;
}
if(R.isPyretException($e18561857)) {
$e18561857.pyretStack.push(L[191]);
}
throw $e18561857;
}
var $ret18621863 = $Hanf_arg12921867($z18581859,group21980,label318505,_plus8);
++R.GAS;
return $ret18621863;
};
var $Hanf_arg12921867 = function(anf_arg7821866,group21980,label318505,_plus8) {
var $z18701871 = D;
var $f18761877 = function(_) {
return R.isFunction(_plus8)?_plus8.app(label318505,anf_arg7821866):R.ffi.throwNonFunApp(L[192],_plus8,[label318505,anf_arg7821866]);
};
try {
if(--R.GAS > 0) {
$z18701871 = $f18761877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18761877,
"from":L[192]});
}
} catch($e18681869) {
if(R.isCont($e18681869)) {
var $ss18721873 = {"from":L[192],
"go":function(anf_arg7831878) {
return $Hanf_arg12911879(anf_arg7831878,group21980);
}};
$e18681869.stack[R.EXN_STACKHEIGHT++] = $ss18721873;
}
if(R.isPyretException($e18681869)) {
$e18681869.pyretStack.push(L[192]);
}
throw $e18681869;
}
var $ret18741875 = $Hanf_arg12911879($z18701871,group21980);
++R.GAS;
return $ret18741875;
};
var $Hanf_arg12911879 = function(anf_arg7831878,group21980) {
var $z18821883 = D;
var $f18881889 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7831878):R.ffi.throwNonFunApp(L[50],group21980,[anf_arg7831878]);
};
try {
if(--R.GAS > 0) {
$z18821883 = $f18881889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18881889,
"from":L[50]});
}
} catch($e18801881) {
if(R.isCont($e18801881)) {
var $ss18841885 = {"from":L[50],
"go":function(ann_DASH_check_DASH_temp7741890) {
return $Hann_DASH_check_DASH_temp12901891(ann_DASH_check_DASH_temp7741890);
}};
$e18801881.stack[R.EXN_STACKHEIGHT++] = $ss18841885;
}
if(R.isPyretException($e18801881)) {
$e18801881.pyretStack.push(L[50]);
}
throw $e18801881;
}
var $ret18861887 = $Hann_DASH_check_DASH_temp12901891($z18821883);
++R.GAS;
return $ret18861887;
};
var $Hann_DASH_check_DASH_temp12901891 = function(ann_DASH_check_DASH_temp7741890) {
return ann_DASH_check_DASH_temp7741890;
};
var $Hif_DASH_1289541 = function(if_DASH_87540,b312523,close316527,docs317528,n311522,open314525,sep315526,separate276485,surround274481,void313524) {
var if_helper7641902 = R.makeFunction(function(if_helper_arg7651921) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[53],1,arguments);
}
var ann_DASH_check_DASH_temp7621922 = if_helper_arg7651921;
return ann_DASH_check_DASH_temp7621922;
});
var anf_if7681920 = R.isBoolean(if_DASH_87540);
if(R.isPyretTrue(anf_if7681920)) {
if(R.isPyretTrue(if_DASH_87540)) {
var $z18941895 = D;
var $f19001901 = function(_) {
return R.isFunction(if_helper7641902)?if_helper7641902.app(void313524):R.ffi.throwNonFunApp(L[193],if_helper7641902,[void313524]);
};
try {
if(--R.GAS > 0) {
$z18941895 = $f19001901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19001901,
"from":L[193]});
}
} catch($e18921893) {
if(R.isCont($e18921893)) {
var $ss18961897 = {"from":L[193],
"go":function(cont_tail_app7721903) {
return $Hcont_tail_app12861904(cont_tail_app7721903);
}};
$e18921893.stack[R.EXN_STACKHEIGHT++] = $ss18961897;
}
if(R.isPyretException($e18921893)) {
$e18921893.pyretStack.push(L[193]);
}
throw $e18921893;
}
var $ret18981899 = $Hcont_tail_app12861904($z18941895);
++R.GAS;
return $ret18981899;
} else {
var $z19071908 = D;
var $f19131914 = function(_) {
return R.isFunction(separate276485.$var)?separate276485.$var.app(sep315526,docs317528):R.ffi.throwNonFunApp(L[194],separate276485.$var,[sep315526,docs317528]);
};
try {
if(--R.GAS > 0) {
$z19071908 = $f19131914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19131914,
"from":L[194]});
}
} catch($e19051906) {
if(R.isCont($e19051906)) {
var $ss19091910 = {"from":L[194],
"go":function(anf_arg7691915) {
return $Hanf_arg12881916(anf_arg7691915,b312523,close316527,if_helper7641902,n311522,open314525,surround274481);
}};
$e19051906.stack[R.EXN_STACKHEIGHT++] = $ss19091910;
}
if(R.isPyretException($e19051906)) {
$e19051906.pyretStack.push(L[194]);
}
throw $e19051906;
}
var $ret19111912 = $Hanf_arg12881916($z19071908,b312523,close316527,if_helper7641902,n311522,open314525,surround274481);
++R.GAS;
return $ret19111912;
}
} else {
var cont_tail_arg7661919 = R.throwNonBooleanCondition(L[53],("if"),if_DASH_87540);
if(--R.GAS > 0) {
$z19171918 = R.isFunction(if_helper7641902)?if_helper7641902.app(cont_tail_arg7661919):R.ffi.throwNonFunApp(L[53],if_helper7641902,[cont_tail_arg7661919]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper7641902)?if_helper7641902.app(cont_tail_arg7661919):R.ffi.throwNonFunApp(L[53],if_helper7641902,[cont_tail_arg7661919]);
},
"from":L[53]});
}
++R.GAS;
return $z19171918;
}
};
var $Hcont_tail_app12861904 = function(cont_tail_app7721903) {
return cont_tail_app7721903;
};
var $Hanf_arg12881916 = function(anf_arg7691915,b312523,close316527,if_helper7641902,n311522,open314525,surround274481) {
var $z19251926 = D;
var $f19311932 = function(_) {
return R.isFunction(surround274481.$var)?surround274481.$var.app(n311522,b312523,open314525,anf_arg7691915,close316527):R.ffi.throwNonFunApp(L[195],surround274481.$var,[n311522,b312523,open314525,anf_arg7691915,close316527]);
};
try {
if(--R.GAS > 0) {
$z19251926 = $f19311932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19311932,
"from":L[195]});
}
} catch($e19231924) {
if(R.isCont($e19231924)) {
var $ss19271928 = {"from":L[195],
"go":function(cont_tail_arg7701933) {
return $Hcont_tail_arg12871934(cont_tail_arg7701933,if_helper7641902);
}};
$e19231924.stack[R.EXN_STACKHEIGHT++] = $ss19271928;
}
if(R.isPyretException($e19231924)) {
$e19231924.pyretStack.push(L[195]);
}
throw $e19231924;
}
var $ret19291930 = $Hcont_tail_arg12871934($z19251926,if_helper7641902);
++R.GAS;
return $ret19291930;
};
var $Hcont_tail_arg12871934 = function(cont_tail_arg7701933,if_helper7641902) {
if(--R.GAS > 0) {
$z19351936 = R.isFunction(if_helper7641902)?if_helper7641902.app(cont_tail_arg7701933):R.ffi.throwNonFunApp(L[195],if_helper7641902,[cont_tail_arg7701933]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper7641902)?if_helper7641902.app(cont_tail_arg7701933):R.ffi.throwNonFunApp(L[195],if_helper7641902,[cont_tail_arg7701933]);
},
"from":L[195]});
}
++R.GAS;
return $z19351936;
};
var $Hann_DASH_check_DASH_temp1285557 = function(ann_DASH_check_DASH_temp744556) {
return ann_DASH_check_DASH_temp744556;
};
var $Hif_DASH_1284571 = function(if_DASH_86570,acc309558,d310559,is_DASH_mt_DASH_doc6747,sep307542,_plus8) {
var if_helper7471947 = R.makeFunction(function(if_helper_arg7481966) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[64],1,arguments);
}
var ann_DASH_check_DASH_temp7461967 = if_helper_arg7481966;
return ann_DASH_check_DASH_temp7461967;
});
var anf_if7511965 = R.isBoolean(if_DASH_86570);
if(R.isPyretTrue(anf_if7511965)) {
if(R.isPyretTrue(if_DASH_86570)) {
var $z19391940 = D;
var $f19451946 = function(_) {
return R.isFunction(if_helper7471947)?if_helper7471947.app(acc309558):R.ffi.throwNonFunApp(L[196],if_helper7471947,[acc309558]);
};
try {
if(--R.GAS > 0) {
$z19391940 = $f19451946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19451946,
"from":L[196]});
}
} catch($e19371938) {
if(R.isCont($e19371938)) {
var $ss19411942 = {"from":L[196],
"go":function(cont_tail_app7591948) {
return $Hcont_tail_app12791949(cont_tail_app7591948);
}};
$e19371938.stack[R.EXN_STACKHEIGHT++] = $ss19411942;
}
if(R.isPyretException($e19371938)) {
$e19371938.pyretStack.push(L[196]);
}
throw $e19371938;
}
var $ret19431944 = $Hcont_tail_app12791949($z19391940);
++R.GAS;
return $ret19431944;
} else {
var $z19521953 = D;
var $f19581959 = function(_) {
return R.isFunction(is_DASH_mt_DASH_doc6747.$var)?is_DASH_mt_DASH_doc6747.$var.app(acc309558):R.ffi.throwNonFunApp(L[197],is_DASH_mt_DASH_doc6747.$var,[acc309558]);
};
try {
if(--R.GAS > 0) {
$z19521953 = $f19581959();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19581959,
"from":L[197]});
}
} catch($e19501951) {
if(R.isCont($e19501951)) {
var $ss19541955 = {"from":L[197],
"go":function(if_DASH_851960) {
return $Hif_DASH_12831961(if_DASH_851960,acc309558,d310559,if_helper7471947,sep307542,_plus8);
}};
$e19501951.stack[R.EXN_STACKHEIGHT++] = $ss19541955;
}
if(R.isPyretException($e19501951)) {
$e19501951.pyretStack.push(L[197]);
}
throw $e19501951;
}
var $ret19561957 = $Hif_DASH_12831961($z19521953,acc309558,d310559,if_helper7471947,sep307542,_plus8);
++R.GAS;
return $ret19561957;
}
} else {
var cont_tail_arg7491964 = R.throwNonBooleanCondition(L[64],("if"),if_DASH_86570);
if(--R.GAS > 0) {
$z19621963 = R.isFunction(if_helper7471947)?if_helper7471947.app(cont_tail_arg7491964):R.ffi.throwNonFunApp(L[64],if_helper7471947,[cont_tail_arg7491964]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper7471947)?if_helper7471947.app(cont_tail_arg7491964):R.ffi.throwNonFunApp(L[64],if_helper7471947,[cont_tail_arg7491964]);
},
"from":L[64]});
}
++R.GAS;
return $z19621963;
}
};
var $Hcont_tail_app12791949 = function(cont_tail_app7591948) {
return cont_tail_app7591948;
};
var $Hif_DASH_12831961 = function(if_DASH_851960,acc309558,d310559,if_helper7471947,sep307542,_plus8) {
var anf_if7541995 = R.isBoolean(if_DASH_851960);
if(R.isPyretTrue(anf_if7541995)) {
if(R.isPyretTrue(if_DASH_851960)) {
var $z19701971 = D;
var $f19761977 = function(_) {
return R.isFunction(if_helper7471947)?if_helper7471947.app(d310559):R.ffi.throwNonFunApp(L[198],if_helper7471947,[d310559]);
};
try {
if(--R.GAS > 0) {
$z19701971 = $f19761977();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19761977,
"from":L[198]});
}
} catch($e19681969) {
if(R.isCont($e19681969)) {
var $ss19721973 = {"from":L[198],
"go":function(cont_tail_app7581978) {
return $Hcont_tail_app12801979(cont_tail_app7581978);
}};
$e19681969.stack[R.EXN_STACKHEIGHT++] = $ss19721973;
}
if(R.isPyretException($e19681969)) {
$e19681969.pyretStack.push(L[198]);
}
throw $e19681969;
}
var $ret19741975 = $Hcont_tail_app12801979($z19701971);
++R.GAS;
return $ret19741975;
} else {
var $z19821983 = D;
var $f19881989 = function(_) {
return R.isFunction(_plus8)?_plus8.app(acc309558,sep307542):R.ffi.throwNonFunApp(L[199],_plus8,[acc309558,sep307542]);
};
try {
if(--R.GAS > 0) {
$z19821983 = $f19881989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19881989,
"from":L[199]});
}
} catch($e19801981) {
if(R.isCont($e19801981)) {
var $ss19841985 = {"from":L[199],
"go":function(anf_arg7551990) {
return $Hanf_arg12821991(anf_arg7551990,d310559,if_helper7471947,_plus8);
}};
$e19801981.stack[R.EXN_STACKHEIGHT++] = $ss19841985;
}
if(R.isPyretException($e19801981)) {
$e19801981.pyretStack.push(L[199]);
}
throw $e19801981;
}
var $ret19861987 = $Hanf_arg12821991($z19821983,d310559,if_helper7471947,_plus8);
++R.GAS;
return $ret19861987;
}
} else {
var cont_tail_arg7521994 = R.throwNonBooleanCondition(L[200],("if"),if_DASH_851960);
if(--R.GAS > 0) {
$z19921993 = R.isFunction(if_helper7471947)?if_helper7471947.app(cont_tail_arg7521994):R.ffi.throwNonFunApp(L[200],if_helper7471947,[cont_tail_arg7521994]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper7471947)?if_helper7471947.app(cont_tail_arg7521994):R.ffi.throwNonFunApp(L[200],if_helper7471947,[cont_tail_arg7521994]);
},
"from":L[200]});
}
++R.GAS;
return $z19921993;
}
};
var $Hcont_tail_app12801979 = function(cont_tail_app7581978) {
return cont_tail_app7581978;
};
var $Hanf_arg12821991 = function(anf_arg7551990,d310559,if_helper7471947,_plus8) {
var $z19981999 = D;
var $f20042005 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7551990,d310559):R.ffi.throwNonFunApp(L[199],_plus8,[anf_arg7551990,d310559]);
};
try {
if(--R.GAS > 0) {
$z19981999 = $f20042005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20042005,
"from":L[199]});
}
} catch($e19961997) {
if(R.isCont($e19961997)) {
var $ss20002001 = {"from":L[199],
"go":function(cont_tail_arg7562006) {
return $Hcont_tail_arg12812007(cont_tail_arg7562006,if_helper7471947);
}};
$e19961997.stack[R.EXN_STACKHEIGHT++] = $ss20002001;
}
if(R.isPyretException($e19961997)) {
$e19961997.pyretStack.push(L[199]);
}
throw $e19961997;
}
var $ret20022003 = $Hcont_tail_arg12812007($z19981999,if_helper7471947);
++R.GAS;
return $ret20022003;
};
var $Hcont_tail_arg12812007 = function(cont_tail_arg7562006,if_helper7471947) {
if(--R.GAS > 0) {
$z20082009 = R.isFunction(if_helper7471947)?if_helper7471947.app(cont_tail_arg7562006):R.ffi.throwNonFunApp(L[199],if_helper7471947,[cont_tail_arg7562006]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper7471947)?if_helper7471947.app(cont_tail_arg7562006):R.ffi.throwNonFunApp(L[199],if_helper7471947,[cont_tail_arg7562006]);
},
"from":L[199]});
}
++R.GAS;
return $z20082009;
};
var $Hif_DASH_1278588 = function(if_DASH_84587,b303573,close306576,contents305575,group21980,n302572,nest22482,open304574,sbreak245295,_plus8) {
var if_helper7202021 = R.makeFunction(function(if_helper_arg7212039) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[69],1,arguments);
}
var ann_DASH_check_DASH_temp7192040 = if_helper_arg7212039;
return ann_DASH_check_DASH_temp7192040;
});
var anf_if7242038 = R.isBoolean(if_DASH_84587);
if(R.isPyretTrue(anf_if7242038)) {
if(R.isPyretTrue(if_DASH_84587)) {
var $z20122013 = D;
var $f20182019 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app(b303573):R.ffi.throwNonFunApp(L[201],sbreak245295.$var,[b303573]);
};
try {
if(--R.GAS > 0) {
$z20122013 = $f20182019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20182019,
"from":L[201]});
}
} catch($e20102011) {
if(R.isCont($e20102011)) {
var $ss20142015 = {"from":L[201],
"go":function(anf_arg7362020) {
return $Hanf_arg12672022(anf_arg7362020,contents305575,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8);
}};
$e20102011.stack[R.EXN_STACKHEIGHT++] = $ss20142015;
}
if(R.isPyretException($e20102011)) {
$e20102011.pyretStack.push(L[201]);
}
throw $e20102011;
}
var $ret20162017 = $Hanf_arg12672022($z20122013,contents305575,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8);
++R.GAS;
return $ret20162017;
} else {
var $z20252026 = D;
var $f20312032 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app(b303573):R.ffi.throwNonFunApp(L[202],sbreak245295.$var,[b303573]);
};
try {
if(--R.GAS > 0) {
$z20252026 = $f20312032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20312032,
"from":L[202]});
}
} catch($e20232024) {
if(R.isCont($e20232024)) {
var $ss20272028 = {"from":L[202],
"go":function(anf_arg7252033) {
return $Hanf_arg12772034(anf_arg7252033,b303573,close306576,contents305575,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8);
}};
$e20232024.stack[R.EXN_STACKHEIGHT++] = $ss20272028;
}
if(R.isPyretException($e20232024)) {
$e20232024.pyretStack.push(L[202]);
}
throw $e20232024;
}
var $ret20292030 = $Hanf_arg12772034($z20252026,b303573,close306576,contents305575,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8);
++R.GAS;
return $ret20292030;
}
} else {
var cont_tail_arg7222037 = R.throwNonBooleanCondition(L[69],("if"),if_DASH_84587);
if(--R.GAS > 0) {
$z20352036 = R.isFunction(if_helper7202021)?if_helper7202021.app(cont_tail_arg7222037):R.ffi.throwNonFunApp(L[69],if_helper7202021,[cont_tail_arg7222037]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper7202021)?if_helper7202021.app(cont_tail_arg7222037):R.ffi.throwNonFunApp(L[69],if_helper7202021,[cont_tail_arg7222037]);
},
"from":L[69]});
}
++R.GAS;
return $z20352036;
}
};
var $Hanf_arg12672022 = function(anf_arg7362020,contents305575,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8) {
var $z20432044 = D;
var $f20492050 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7362020,contents305575):R.ffi.throwNonFunApp(L[203],_plus8,[anf_arg7362020,contents305575]);
};
try {
if(--R.GAS > 0) {
$z20432044 = $f20492050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20492050,
"from":L[203]});
}
} catch($e20412042) {
if(R.isCont($e20412042)) {
var $ss20452046 = {"from":L[203],
"go":function(anf_arg7372051) {
return $Hanf_arg12662052(anf_arg7372051,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8);
}};
$e20412042.stack[R.EXN_STACKHEIGHT++] = $ss20452046;
}
if(R.isPyretException($e20412042)) {
$e20412042.pyretStack.push(L[203]);
}
throw $e20412042;
}
var $ret20472048 = $Hanf_arg12662052($z20432044,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8);
++R.GAS;
return $ret20472048;
};
var $Hanf_arg12662052 = function(anf_arg7372051,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8) {
var $z20552056 = D;
var $f20612062 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7372051):R.ffi.throwNonFunApp(L[204],group21980,[anf_arg7372051]);
};
try {
if(--R.GAS > 0) {
$z20552056 = $f20612062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20612062,
"from":L[204]});
}
} catch($e20532054) {
if(R.isCont($e20532054)) {
var $ss20572058 = {"from":L[204],
"go":function(anf_arg7382063) {
return $Hanf_arg12652064(anf_arg7382063,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8);
}};
$e20532054.stack[R.EXN_STACKHEIGHT++] = $ss20572058;
}
if(R.isPyretException($e20532054)) {
$e20532054.pyretStack.push(L[204]);
}
throw $e20532054;
}
var $ret20592060 = $Hanf_arg12652064($z20552056,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8);
++R.GAS;
return $ret20592060;
};
var $Hanf_arg12652064 = function(anf_arg7382063,group21980,if_helper7202021,n302572,nest22482,open304574,_plus8) {
var $z20672068 = D;
var $f20732074 = function(_) {
return R.isFunction(nest22482)?nest22482.app(n302572,anf_arg7382063):R.ffi.throwNonFunApp(L[205],nest22482,[n302572,anf_arg7382063]);
};
try {
if(--R.GAS > 0) {
$z20672068 = $f20732074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20732074,
"from":L[205]});
}
} catch($e20652066) {
if(R.isCont($e20652066)) {
var $ss20692070 = {"from":L[205],
"go":function(anf_arg7392075) {
return $Hanf_arg12642076(anf_arg7392075,group21980,if_helper7202021,open304574,_plus8);
}};
$e20652066.stack[R.EXN_STACKHEIGHT++] = $ss20692070;
}
if(R.isPyretException($e20652066)) {
$e20652066.pyretStack.push(L[205]);
}
throw $e20652066;
}
var $ret20712072 = $Hanf_arg12642076($z20672068,group21980,if_helper7202021,open304574,_plus8);
++R.GAS;
return $ret20712072;
};
var $Hanf_arg12642076 = function(anf_arg7392075,group21980,if_helper7202021,open304574,_plus8) {
var $z20792080 = D;
var $f20852086 = function(_) {
return R.isFunction(_plus8)?_plus8.app(open304574,anf_arg7392075):R.ffi.throwNonFunApp(L[206],_plus8,[open304574,anf_arg7392075]);
};
try {
if(--R.GAS > 0) {
$z20792080 = $f20852086();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20852086,
"from":L[206]});
}
} catch($e20772078) {
if(R.isCont($e20772078)) {
var $ss20812082 = {"from":L[206],
"go":function(anf_arg7402087) {
return $Hanf_arg12632088(anf_arg7402087,group21980,if_helper7202021);
}};
$e20772078.stack[R.EXN_STACKHEIGHT++] = $ss20812082;
}
if(R.isPyretException($e20772078)) {
$e20772078.pyretStack.push(L[206]);
}
throw $e20772078;
}
var $ret20832084 = $Hanf_arg12632088($z20792080,group21980,if_helper7202021);
++R.GAS;
return $ret20832084;
};
var $Hanf_arg12632088 = function(anf_arg7402087,group21980,if_helper7202021) {
var $z20912092 = D;
var $f20972098 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7402087):R.ffi.throwNonFunApp(L[207],group21980,[anf_arg7402087]);
};
try {
if(--R.GAS > 0) {
$z20912092 = $f20972098();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20972098,
"from":L[207]});
}
} catch($e20892090) {
if(R.isCont($e20892090)) {
var $ss20932094 = {"from":L[207],
"go":function(cont_tail_arg7412099) {
return $Hcont_tail_arg12622100(cont_tail_arg7412099,if_helper7202021);
}};
$e20892090.stack[R.EXN_STACKHEIGHT++] = $ss20932094;
}
if(R.isPyretException($e20892090)) {
$e20892090.pyretStack.push(L[207]);
}
throw $e20892090;
}
var $ret20952096 = $Hcont_tail_arg12622100($z20912092,if_helper7202021);
++R.GAS;
return $ret20952096;
};
var $Hcont_tail_arg12622100 = function(cont_tail_arg7412099,if_helper7202021) {
if(--R.GAS > 0) {
$z21012102 = R.isFunction(if_helper7202021)?if_helper7202021.app(cont_tail_arg7412099):R.ffi.throwNonFunApp(L[207],if_helper7202021,[cont_tail_arg7412099]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper7202021)?if_helper7202021.app(cont_tail_arg7412099):R.ffi.throwNonFunApp(L[207],if_helper7202021,[cont_tail_arg7412099]);
},
"from":L[207]});
}
++R.GAS;
return $z21012102;
};
var $Hanf_arg12772034 = function(anf_arg7252033,b303573,close306576,contents305575,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8) {
var $z21052106 = D;
var $f21112112 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7252033,contents305575):R.ffi.throwNonFunApp(L[208],_plus8,[anf_arg7252033,contents305575]);
};
try {
if(--R.GAS > 0) {
$z21052106 = $f21112112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21112112,
"from":L[208]});
}
} catch($e21032104) {
if(R.isCont($e21032104)) {
var $ss21072108 = {"from":L[208],
"go":function(anf_arg7262113) {
return $Hanf_arg12762114(anf_arg7262113,b303573,close306576,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8);
}};
$e21032104.stack[R.EXN_STACKHEIGHT++] = $ss21072108;
}
if(R.isPyretException($e21032104)) {
$e21032104.pyretStack.push(L[208]);
}
throw $e21032104;
}
var $ret21092110 = $Hanf_arg12762114($z21052106,b303573,close306576,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8);
++R.GAS;
return $ret21092110;
};
var $Hanf_arg12762114 = function(anf_arg7262113,b303573,close306576,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8) {
var $z21172118 = D;
var $f21232124 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7262113):R.ffi.throwNonFunApp(L[209],group21980,[anf_arg7262113]);
};
try {
if(--R.GAS > 0) {
$z21172118 = $f21232124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21232124,
"from":L[209]});
}
} catch($e21152116) {
if(R.isCont($e21152116)) {
var $ss21192120 = {"from":L[209],
"go":function(anf_arg7272125) {
return $Hanf_arg12752126(anf_arg7272125,b303573,close306576,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8);
}};
$e21152116.stack[R.EXN_STACKHEIGHT++] = $ss21192120;
}
if(R.isPyretException($e21152116)) {
$e21152116.pyretStack.push(L[209]);
}
throw $e21152116;
}
var $ret21212122 = $Hanf_arg12752126($z21172118,b303573,close306576,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8);
++R.GAS;
return $ret21212122;
};
var $Hanf_arg12752126 = function(anf_arg7272125,b303573,close306576,group21980,if_helper7202021,n302572,nest22482,open304574,sbreak245295,_plus8) {
var $z21292130 = D;
var $f21352136 = function(_) {
return R.isFunction(nest22482)?nest22482.app(n302572,anf_arg7272125):R.ffi.throwNonFunApp(L[210],nest22482,[n302572,anf_arg7272125]);
};
try {
if(--R.GAS > 0) {
$z21292130 = $f21352136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21352136,
"from":L[210]});
}
} catch($e21272128) {
if(R.isCont($e21272128)) {
var $ss21312132 = {"from":L[210],
"go":function(anf_arg7282137) {
return $Hanf_arg12742138(anf_arg7282137,b303573,close306576,group21980,if_helper7202021,open304574,sbreak245295,_plus8);
}};
$e21272128.stack[R.EXN_STACKHEIGHT++] = $ss21312132;
}
if(R.isPyretException($e21272128)) {
$e21272128.pyretStack.push(L[210]);
}
throw $e21272128;
}
var $ret21332134 = $Hanf_arg12742138($z21292130,b303573,close306576,group21980,if_helper7202021,open304574,sbreak245295,_plus8);
++R.GAS;
return $ret21332134;
};
var $Hanf_arg12742138 = function(anf_arg7282137,b303573,close306576,group21980,if_helper7202021,open304574,sbreak245295,_plus8) {
var $z21412142 = D;
var $f21472148 = function(_) {
return R.isFunction(_plus8)?_plus8.app(open304574,anf_arg7282137):R.ffi.throwNonFunApp(L[211],_plus8,[open304574,anf_arg7282137]);
};
try {
if(--R.GAS > 0) {
$z21412142 = $f21472148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21472148,
"from":L[211]});
}
} catch($e21392140) {
if(R.isCont($e21392140)) {
var $ss21432144 = {"from":L[211],
"go":function(anf_arg7292149) {
return $Hanf_arg12732150(anf_arg7292149,b303573,close306576,group21980,if_helper7202021,sbreak245295,_plus8);
}};
$e21392140.stack[R.EXN_STACKHEIGHT++] = $ss21432144;
}
if(R.isPyretException($e21392140)) {
$e21392140.pyretStack.push(L[211]);
}
throw $e21392140;
}
var $ret21452146 = $Hanf_arg12732150($z21412142,b303573,close306576,group21980,if_helper7202021,sbreak245295,_plus8);
++R.GAS;
return $ret21452146;
};
var $Hanf_arg12732150 = function(anf_arg7292149,b303573,close306576,group21980,if_helper7202021,sbreak245295,_plus8) {
var $z21532154 = D;
var $f21592160 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app(b303573):R.ffi.throwNonFunApp(L[212],sbreak245295.$var,[b303573]);
};
try {
if(--R.GAS > 0) {
$z21532154 = $f21592160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21592160,
"from":L[212]});
}
} catch($e21512152) {
if(R.isCont($e21512152)) {
var $ss21552156 = {"from":L[212],
"go":function(anf_arg7302161) {
return $Hanf_arg12722162(anf_arg7302161,anf_arg7292149,close306576,group21980,if_helper7202021,_plus8);
}};
$e21512152.stack[R.EXN_STACKHEIGHT++] = $ss21552156;
}
if(R.isPyretException($e21512152)) {
$e21512152.pyretStack.push(L[212]);
}
throw $e21512152;
}
var $ret21572158 = $Hanf_arg12722162($z21532154,anf_arg7292149,close306576,group21980,if_helper7202021,_plus8);
++R.GAS;
return $ret21572158;
};
var $Hanf_arg12722162 = function(anf_arg7302161,anf_arg7292149,close306576,group21980,if_helper7202021,_plus8) {
var $z21652166 = D;
var $f21712172 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7302161,close306576):R.ffi.throwNonFunApp(L[213],_plus8,[anf_arg7302161,close306576]);
};
try {
if(--R.GAS > 0) {
$z21652166 = $f21712172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21712172,
"from":L[213]});
}
} catch($e21632164) {
if(R.isCont($e21632164)) {
var $ss21672168 = {"from":L[213],
"go":function(anf_arg7312173) {
return $Hanf_arg12712174(anf_arg7312173,anf_arg7292149,group21980,if_helper7202021,_plus8);
}};
$e21632164.stack[R.EXN_STACKHEIGHT++] = $ss21672168;
}
if(R.isPyretException($e21632164)) {
$e21632164.pyretStack.push(L[213]);
}
throw $e21632164;
}
var $ret21692170 = $Hanf_arg12712174($z21652166,anf_arg7292149,group21980,if_helper7202021,_plus8);
++R.GAS;
return $ret21692170;
};
var $Hanf_arg12712174 = function(anf_arg7312173,anf_arg7292149,group21980,if_helper7202021,_plus8) {
var $z21772178 = D;
var $f21832184 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7312173):R.ffi.throwNonFunApp(L[214],group21980,[anf_arg7312173]);
};
try {
if(--R.GAS > 0) {
$z21772178 = $f21832184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21832184,
"from":L[214]});
}
} catch($e21752176) {
if(R.isCont($e21752176)) {
var $ss21792180 = {"from":L[214],
"go":function(anf_arg7322185) {
return $Hanf_arg12702186(anf_arg7322185,anf_arg7292149,group21980,if_helper7202021,_plus8);
}};
$e21752176.stack[R.EXN_STACKHEIGHT++] = $ss21792180;
}
if(R.isPyretException($e21752176)) {
$e21752176.pyretStack.push(L[214]);
}
throw $e21752176;
}
var $ret21812182 = $Hanf_arg12702186($z21772178,anf_arg7292149,group21980,if_helper7202021,_plus8);
++R.GAS;
return $ret21812182;
};
var $Hanf_arg12702186 = function(anf_arg7322185,anf_arg7292149,group21980,if_helper7202021,_plus8) {
var $z21892190 = D;
var $f21952196 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7292149,anf_arg7322185):R.ffi.throwNonFunApp(L[211],_plus8,[anf_arg7292149,anf_arg7322185]);
};
try {
if(--R.GAS > 0) {
$z21892190 = $f21952196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21952196,
"from":L[211]});
}
} catch($e21872188) {
if(R.isCont($e21872188)) {
var $ss21912192 = {"from":L[211],
"go":function(anf_arg7332197) {
return $Hanf_arg12692198(anf_arg7332197,group21980,if_helper7202021);
}};
$e21872188.stack[R.EXN_STACKHEIGHT++] = $ss21912192;
}
if(R.isPyretException($e21872188)) {
$e21872188.pyretStack.push(L[211]);
}
throw $e21872188;
}
var $ret21932194 = $Hanf_arg12692198($z21892190,group21980,if_helper7202021);
++R.GAS;
return $ret21932194;
};
var $Hanf_arg12692198 = function(anf_arg7332197,group21980,if_helper7202021) {
var $z22012202 = D;
var $f22072208 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7332197):R.ffi.throwNonFunApp(L[215],group21980,[anf_arg7332197]);
};
try {
if(--R.GAS > 0) {
$z22012202 = $f22072208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22072208,
"from":L[215]});
}
} catch($e21992200) {
if(R.isCont($e21992200)) {
var $ss22032204 = {"from":L[215],
"go":function(cont_tail_arg7342209) {
return $Hcont_tail_arg12682210(cont_tail_arg7342209,if_helper7202021);
}};
$e21992200.stack[R.EXN_STACKHEIGHT++] = $ss22032204;
}
if(R.isPyretException($e21992200)) {
$e21992200.pyretStack.push(L[215]);
}
throw $e21992200;
}
var $ret22052206 = $Hcont_tail_arg12682210($z22012202,if_helper7202021);
++R.GAS;
return $ret22052206;
};
var $Hcont_tail_arg12682210 = function(cont_tail_arg7342209,if_helper7202021) {
if(--R.GAS > 0) {
$z22112212 = R.isFunction(if_helper7202021)?if_helper7202021.app(cont_tail_arg7342209):R.ffi.throwNonFunApp(L[215],if_helper7202021,[cont_tail_arg7342209]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper7202021)?if_helper7202021.app(cont_tail_arg7342209):R.ffi.throwNonFunApp(L[215],if_helper7202021,[cont_tail_arg7342209]);
},
"from":L[215]});
}
++R.GAS;
return $z22112212;
};
var $Hif_DASH_1261605 = function(if_DASH_83604,b298590,close301593,contents300592,group21980,n297589,nest22482,open299591,sbreak245295,_plus8) {
var if_helper6982224 = R.makeFunction(function(if_helper_arg6992242) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[76],1,arguments);
}
var ann_DASH_check_DASH_temp6972243 = if_helper_arg6992242;
return ann_DASH_check_DASH_temp6972243;
});
var anf_if7022241 = R.isBoolean(if_DASH_83604);
if(R.isPyretTrue(anf_if7022241)) {
if(R.isPyretTrue(if_DASH_83604)) {
var $z22152216 = D;
var $f22212222 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app(b298590):R.ffi.throwNonFunApp(L[216],sbreak245295.$var,[b298590]);
};
try {
if(--R.GAS > 0) {
$z22152216 = $f22212222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22212222,
"from":L[216]});
}
} catch($e22132214) {
if(R.isCont($e22132214)) {
var $ss22172218 = {"from":L[216],
"go":function(anf_arg7122223) {
return $Hanf_arg12522225(anf_arg7122223,contents300592,group21980,if_helper6982224,n297589,nest22482,open299591,_plus8);
}};
$e22132214.stack[R.EXN_STACKHEIGHT++] = $ss22172218;
}
if(R.isPyretException($e22132214)) {
$e22132214.pyretStack.push(L[216]);
}
throw $e22132214;
}
var $ret22192220 = $Hanf_arg12522225($z22152216,contents300592,group21980,if_helper6982224,n297589,nest22482,open299591,_plus8);
++R.GAS;
return $ret22192220;
} else {
var $z22282229 = D;
var $f22342235 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app(b298590):R.ffi.throwNonFunApp(L[217],sbreak245295.$var,[b298590]);
};
try {
if(--R.GAS > 0) {
$z22282229 = $f22342235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22342235,
"from":L[217]});
}
} catch($e22262227) {
if(R.isCont($e22262227)) {
var $ss22302231 = {"from":L[217],
"go":function(anf_arg7032236) {
return $Hanf_arg12602237(anf_arg7032236,b298590,close301593,contents300592,group21980,if_helper6982224,n297589,nest22482,open299591,sbreak245295,_plus8);
}};
$e22262227.stack[R.EXN_STACKHEIGHT++] = $ss22302231;
}
if(R.isPyretException($e22262227)) {
$e22262227.pyretStack.push(L[217]);
}
throw $e22262227;
}
var $ret22322233 = $Hanf_arg12602237($z22282229,b298590,close301593,contents300592,group21980,if_helper6982224,n297589,nest22482,open299591,sbreak245295,_plus8);
++R.GAS;
return $ret22322233;
}
} else {
var cont_tail_arg7002240 = R.throwNonBooleanCondition(L[76],("if"),if_DASH_83604);
if(--R.GAS > 0) {
$z22382239 = R.isFunction(if_helper6982224)?if_helper6982224.app(cont_tail_arg7002240):R.ffi.throwNonFunApp(L[76],if_helper6982224,[cont_tail_arg7002240]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper6982224)?if_helper6982224.app(cont_tail_arg7002240):R.ffi.throwNonFunApp(L[76],if_helper6982224,[cont_tail_arg7002240]);
},
"from":L[76]});
}
++R.GAS;
return $z22382239;
}
};
var $Hanf_arg12522225 = function(anf_arg7122223,contents300592,group21980,if_helper6982224,n297589,nest22482,open299591,_plus8) {
var $z22462247 = D;
var $f22522253 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7122223,contents300592):R.ffi.throwNonFunApp(L[218],_plus8,[anf_arg7122223,contents300592]);
};
try {
if(--R.GAS > 0) {
$z22462247 = $f22522253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22522253,
"from":L[218]});
}
} catch($e22442245) {
if(R.isCont($e22442245)) {
var $ss22482249 = {"from":L[218],
"go":function(anf_arg7132254) {
return $Hanf_arg12512255(anf_arg7132254,group21980,if_helper6982224,n297589,nest22482,open299591,_plus8);
}};
$e22442245.stack[R.EXN_STACKHEIGHT++] = $ss22482249;
}
if(R.isPyretException($e22442245)) {
$e22442245.pyretStack.push(L[218]);
}
throw $e22442245;
}
var $ret22502251 = $Hanf_arg12512255($z22462247,group21980,if_helper6982224,n297589,nest22482,open299591,_plus8);
++R.GAS;
return $ret22502251;
};
var $Hanf_arg12512255 = function(anf_arg7132254,group21980,if_helper6982224,n297589,nest22482,open299591,_plus8) {
var $z22582259 = D;
var $f22642265 = function(_) {
return R.isFunction(nest22482)?nest22482.app(n297589,anf_arg7132254):R.ffi.throwNonFunApp(L[219],nest22482,[n297589,anf_arg7132254]);
};
try {
if(--R.GAS > 0) {
$z22582259 = $f22642265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22642265,
"from":L[219]});
}
} catch($e22562257) {
if(R.isCont($e22562257)) {
var $ss22602261 = {"from":L[219],
"go":function(anf_arg7142266) {
return $Hanf_arg12502267(anf_arg7142266,group21980,if_helper6982224,open299591,_plus8);
}};
$e22562257.stack[R.EXN_STACKHEIGHT++] = $ss22602261;
}
if(R.isPyretException($e22562257)) {
$e22562257.pyretStack.push(L[219]);
}
throw $e22562257;
}
var $ret22622263 = $Hanf_arg12502267($z22582259,group21980,if_helper6982224,open299591,_plus8);
++R.GAS;
return $ret22622263;
};
var $Hanf_arg12502267 = function(anf_arg7142266,group21980,if_helper6982224,open299591,_plus8) {
var $z22702271 = D;
var $f22762277 = function(_) {
return R.isFunction(_plus8)?_plus8.app(open299591,anf_arg7142266):R.ffi.throwNonFunApp(L[220],_plus8,[open299591,anf_arg7142266]);
};
try {
if(--R.GAS > 0) {
$z22702271 = $f22762277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22762277,
"from":L[220]});
}
} catch($e22682269) {
if(R.isCont($e22682269)) {
var $ss22722273 = {"from":L[220],
"go":function(anf_arg7152278) {
return $Hanf_arg12492279(anf_arg7152278,group21980,if_helper6982224);
}};
$e22682269.stack[R.EXN_STACKHEIGHT++] = $ss22722273;
}
if(R.isPyretException($e22682269)) {
$e22682269.pyretStack.push(L[220]);
}
throw $e22682269;
}
var $ret22742275 = $Hanf_arg12492279($z22702271,group21980,if_helper6982224);
++R.GAS;
return $ret22742275;
};
var $Hanf_arg12492279 = function(anf_arg7152278,group21980,if_helper6982224) {
var $z22822283 = D;
var $f22882289 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7152278):R.ffi.throwNonFunApp(L[221],group21980,[anf_arg7152278]);
};
try {
if(--R.GAS > 0) {
$z22822283 = $f22882289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22882289,
"from":L[221]});
}
} catch($e22802281) {
if(R.isCont($e22802281)) {
var $ss22842285 = {"from":L[221],
"go":function(cont_tail_arg7162290) {
return $Hcont_tail_arg12482291(cont_tail_arg7162290,if_helper6982224);
}};
$e22802281.stack[R.EXN_STACKHEIGHT++] = $ss22842285;
}
if(R.isPyretException($e22802281)) {
$e22802281.pyretStack.push(L[221]);
}
throw $e22802281;
}
var $ret22862287 = $Hcont_tail_arg12482291($z22822283,if_helper6982224);
++R.GAS;
return $ret22862287;
};
var $Hcont_tail_arg12482291 = function(cont_tail_arg7162290,if_helper6982224) {
if(--R.GAS > 0) {
$z22922293 = R.isFunction(if_helper6982224)?if_helper6982224.app(cont_tail_arg7162290):R.ffi.throwNonFunApp(L[221],if_helper6982224,[cont_tail_arg7162290]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper6982224)?if_helper6982224.app(cont_tail_arg7162290):R.ffi.throwNonFunApp(L[221],if_helper6982224,[cont_tail_arg7162290]);
},
"from":L[221]});
}
++R.GAS;
return $z22922293;
};
var $Hanf_arg12602237 = function(anf_arg7032236,b298590,close301593,contents300592,group21980,if_helper6982224,n297589,nest22482,open299591,sbreak245295,_plus8) {
var $z22962297 = D;
var $f23022303 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7032236,contents300592):R.ffi.throwNonFunApp(L[222],_plus8,[anf_arg7032236,contents300592]);
};
try {
if(--R.GAS > 0) {
$z22962297 = $f23022303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23022303,
"from":L[222]});
}
} catch($e22942295) {
if(R.isCont($e22942295)) {
var $ss22982299 = {"from":L[222],
"go":function(anf_arg7042304) {
return $Hanf_arg12592305(anf_arg7042304,b298590,close301593,group21980,if_helper6982224,n297589,nest22482,open299591,sbreak245295,_plus8);
}};
$e22942295.stack[R.EXN_STACKHEIGHT++] = $ss22982299;
}
if(R.isPyretException($e22942295)) {
$e22942295.pyretStack.push(L[222]);
}
throw $e22942295;
}
var $ret23002301 = $Hanf_arg12592305($z22962297,b298590,close301593,group21980,if_helper6982224,n297589,nest22482,open299591,sbreak245295,_plus8);
++R.GAS;
return $ret23002301;
};
var $Hanf_arg12592305 = function(anf_arg7042304,b298590,close301593,group21980,if_helper6982224,n297589,nest22482,open299591,sbreak245295,_plus8) {
var $z23082309 = D;
var $f23142315 = function(_) {
return R.isFunction(nest22482)?nest22482.app(n297589,anf_arg7042304):R.ffi.throwNonFunApp(L[223],nest22482,[n297589,anf_arg7042304]);
};
try {
if(--R.GAS > 0) {
$z23082309 = $f23142315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23142315,
"from":L[223]});
}
} catch($e23062307) {
if(R.isCont($e23062307)) {
var $ss23102311 = {"from":L[223],
"go":function(anf_arg7052316) {
return $Hanf_arg12582317(anf_arg7052316,b298590,close301593,group21980,if_helper6982224,open299591,sbreak245295,_plus8);
}};
$e23062307.stack[R.EXN_STACKHEIGHT++] = $ss23102311;
}
if(R.isPyretException($e23062307)) {
$e23062307.pyretStack.push(L[223]);
}
throw $e23062307;
}
var $ret23122313 = $Hanf_arg12582317($z23082309,b298590,close301593,group21980,if_helper6982224,open299591,sbreak245295,_plus8);
++R.GAS;
return $ret23122313;
};
var $Hanf_arg12582317 = function(anf_arg7052316,b298590,close301593,group21980,if_helper6982224,open299591,sbreak245295,_plus8) {
var $z23202321 = D;
var $f23262327 = function(_) {
return R.isFunction(_plus8)?_plus8.app(open299591,anf_arg7052316):R.ffi.throwNonFunApp(L[224],_plus8,[open299591,anf_arg7052316]);
};
try {
if(--R.GAS > 0) {
$z23202321 = $f23262327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23262327,
"from":L[224]});
}
} catch($e23182319) {
if(R.isCont($e23182319)) {
var $ss23222323 = {"from":L[224],
"go":function(anf_arg7062328) {
return $Hanf_arg12572329(anf_arg7062328,b298590,close301593,group21980,if_helper6982224,sbreak245295,_plus8);
}};
$e23182319.stack[R.EXN_STACKHEIGHT++] = $ss23222323;
}
if(R.isPyretException($e23182319)) {
$e23182319.pyretStack.push(L[224]);
}
throw $e23182319;
}
var $ret23242325 = $Hanf_arg12572329($z23202321,b298590,close301593,group21980,if_helper6982224,sbreak245295,_plus8);
++R.GAS;
return $ret23242325;
};
var $Hanf_arg12572329 = function(anf_arg7062328,b298590,close301593,group21980,if_helper6982224,sbreak245295,_plus8) {
var $z23322333 = D;
var $f23382339 = function(_) {
return R.isFunction(sbreak245295.$var)?sbreak245295.$var.app(b298590):R.ffi.throwNonFunApp(L[225],sbreak245295.$var,[b298590]);
};
try {
if(--R.GAS > 0) {
$z23322333 = $f23382339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23382339,
"from":L[225]});
}
} catch($e23302331) {
if(R.isCont($e23302331)) {
var $ss23342335 = {"from":L[225],
"go":function(anf_arg7072340) {
return $Hanf_arg12562341(anf_arg7072340,anf_arg7062328,close301593,group21980,if_helper6982224,_plus8);
}};
$e23302331.stack[R.EXN_STACKHEIGHT++] = $ss23342335;
}
if(R.isPyretException($e23302331)) {
$e23302331.pyretStack.push(L[225]);
}
throw $e23302331;
}
var $ret23362337 = $Hanf_arg12562341($z23322333,anf_arg7062328,close301593,group21980,if_helper6982224,_plus8);
++R.GAS;
return $ret23362337;
};
var $Hanf_arg12562341 = function(anf_arg7072340,anf_arg7062328,close301593,group21980,if_helper6982224,_plus8) {
var $z23442345 = D;
var $f23502351 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7062328,anf_arg7072340):R.ffi.throwNonFunApp(L[224],_plus8,[anf_arg7062328,anf_arg7072340]);
};
try {
if(--R.GAS > 0) {
$z23442345 = $f23502351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23502351,
"from":L[224]});
}
} catch($e23422343) {
if(R.isCont($e23422343)) {
var $ss23462347 = {"from":L[224],
"go":function(anf_arg7082352) {
return $Hanf_arg12552353(anf_arg7082352,close301593,group21980,if_helper6982224,_plus8);
}};
$e23422343.stack[R.EXN_STACKHEIGHT++] = $ss23462347;
}
if(R.isPyretException($e23422343)) {
$e23422343.pyretStack.push(L[224]);
}
throw $e23422343;
}
var $ret23482349 = $Hanf_arg12552353($z23442345,close301593,group21980,if_helper6982224,_plus8);
++R.GAS;
return $ret23482349;
};
var $Hanf_arg12552353 = function(anf_arg7082352,close301593,group21980,if_helper6982224,_plus8) {
var $z23562357 = D;
var $f23622363 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg7082352,close301593):R.ffi.throwNonFunApp(L[224],_plus8,[anf_arg7082352,close301593]);
};
try {
if(--R.GAS > 0) {
$z23562357 = $f23622363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23622363,
"from":L[224]});
}
} catch($e23542355) {
if(R.isCont($e23542355)) {
var $ss23582359 = {"from":L[224],
"go":function(anf_arg7092364) {
return $Hanf_arg12542365(anf_arg7092364,group21980,if_helper6982224);
}};
$e23542355.stack[R.EXN_STACKHEIGHT++] = $ss23582359;
}
if(R.isPyretException($e23542355)) {
$e23542355.pyretStack.push(L[224]);
}
throw $e23542355;
}
var $ret23602361 = $Hanf_arg12542365($z23562357,group21980,if_helper6982224);
++R.GAS;
return $ret23602361;
};
var $Hanf_arg12542365 = function(anf_arg7092364,group21980,if_helper6982224) {
var $z23682369 = D;
var $f23742375 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg7092364):R.ffi.throwNonFunApp(L[226],group21980,[anf_arg7092364]);
};
try {
if(--R.GAS > 0) {
$z23682369 = $f23742375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23742375,
"from":L[226]});
}
} catch($e23662367) {
if(R.isCont($e23662367)) {
var $ss23702371 = {"from":L[226],
"go":function(cont_tail_arg7102376) {
return $Hcont_tail_arg12532377(cont_tail_arg7102376,if_helper6982224);
}};
$e23662367.stack[R.EXN_STACKHEIGHT++] = $ss23702371;
}
if(R.isPyretException($e23662367)) {
$e23662367.pyretStack.push(L[226]);
}
throw $e23662367;
}
var $ret23722373 = $Hcont_tail_arg12532377($z23682369,if_helper6982224);
++R.GAS;
return $ret23722373;
};
var $Hcont_tail_arg12532377 = function(cont_tail_arg7102376,if_helper6982224) {
if(--R.GAS > 0) {
$z23782379 = R.isFunction(if_helper6982224)?if_helper6982224.app(cont_tail_arg7102376):R.ffi.throwNonFunApp(L[226],if_helper6982224,[cont_tail_arg7102376]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper6982224)?if_helper6982224.app(cont_tail_arg7102376):R.ffi.throwNonFunApp(L[226],if_helper6982224,[cont_tail_arg7102376]);
},
"from":L[226]});
}
++R.GAS;
return $z23782379;
};
var $Hanf_arg1247622 = function(anf_arg693621,b293607,n292606,op294608,prefix271475,x295609,y296610,_plus8) {
var $z23822383 = D;
var $f23882389 = function(_) {
return R.isFunction(_plus8)?_plus8.app(op294608,anf_arg693621):R.ffi.throwNonFunApp(L[227],_plus8,[op294608,anf_arg693621]);
};
try {
if(--R.GAS > 0) {
$z23822383 = $f23882389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23882389,
"from":L[227]});
}
} catch($e23802381) {
if(R.isCont($e23802381)) {
var $ss23842385 = {"from":L[227],
"go":function(anf_arg6942390) {
return $Hanf_arg12462391(anf_arg6942390,b293607,n292606,prefix271475,x295609,y296610,_plus8);
}};
$e23802381.stack[R.EXN_STACKHEIGHT++] = $ss23842385;
}
if(R.isPyretException($e23802381)) {
$e23802381.pyretStack.push(L[227]);
}
throw $e23802381;
}
var $ret23862387 = $Hanf_arg12462391($z23822383,b293607,n292606,prefix271475,x295609,y296610,_plus8);
++R.GAS;
return $ret23862387;
};
var $Hanf_arg12462391 = function(anf_arg6942390,b293607,n292606,prefix271475,x295609,y296610,_plus8) {
var $z23942395 = D;
var $f24002401 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg6942390,y296610):R.ffi.throwNonFunApp(L[227],_plus8,[anf_arg6942390,y296610]);
};
try {
if(--R.GAS > 0) {
$z23942395 = $f24002401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24002401,
"from":L[227]});
}
} catch($e23922393) {
if(R.isCont($e23922393)) {
var $ss23962397 = {"from":L[227],
"go":function(anf_arg6952402) {
return $Hanf_arg12452403(anf_arg6952402,b293607,n292606,prefix271475,x295609);
}};
$e23922393.stack[R.EXN_STACKHEIGHT++] = $ss23962397;
}
if(R.isPyretException($e23922393)) {
$e23922393.pyretStack.push(L[227]);
}
throw $e23922393;
}
var $ret23982399 = $Hanf_arg12452403($z23942395,b293607,n292606,prefix271475,x295609);
++R.GAS;
return $ret23982399;
};
var $Hanf_arg12452403 = function(anf_arg6952402,b293607,n292606,prefix271475,x295609) {
var $z24062407 = D;
var $f24122413 = function(_) {
return R.isFunction(prefix271475.$var)?prefix271475.$var.app(n292606,b293607,x295609,anf_arg6952402):R.ffi.throwNonFunApp(L[82],prefix271475.$var,[n292606,b293607,x295609,anf_arg6952402]);
};
try {
if(--R.GAS > 0) {
$z24062407 = $f24122413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24122413,
"from":L[82]});
}
} catch($e24042405) {
if(R.isCont($e24042405)) {
var $ss24082409 = {"from":L[82],
"go":function(ann_DASH_check_DASH_temp6922414) {
return $Hann_DASH_check_DASH_temp12442415(ann_DASH_check_DASH_temp6922414);
}};
$e24042405.stack[R.EXN_STACKHEIGHT++] = $ss24082409;
}
if(R.isPyretException($e24042405)) {
$e24042405.pyretStack.push(L[82]);
}
throw $e24042405;
}
var $ret24102411 = $Hann_DASH_check_DASH_temp12442415($z24062407);
++R.GAS;
return $ret24102411;
};
var $Hann_DASH_check_DASH_temp12442415 = function(ann_DASH_check_DASH_temp6922414) {
return ann_DASH_check_DASH_temp6922414;
};
var $Hanf_arg1243639 = function(anf_arg688638,b288624,n287623,op289625,prefix271475,x290626,y291627,_plus8) {
var $z24182419 = D;
var $f24242425 = function(_) {
return R.isFunction(_plus8)?_plus8.app(x290626,anf_arg688638):R.ffi.throwNonFunApp(L[228],_plus8,[x290626,anf_arg688638]);
};
try {
if(--R.GAS > 0) {
$z24182419 = $f24242425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24242425,
"from":L[228]});
}
} catch($e24162417) {
if(R.isCont($e24162417)) {
var $ss24202421 = {"from":L[228],
"go":function(anf_arg6892426) {
return $Hanf_arg12422427(anf_arg6892426,b288624,n287623,op289625,prefix271475,y291627,_plus8);
}};
$e24162417.stack[R.EXN_STACKHEIGHT++] = $ss24202421;
}
if(R.isPyretException($e24162417)) {
$e24162417.pyretStack.push(L[228]);
}
throw $e24162417;
}
var $ret24222423 = $Hanf_arg12422427($z24182419,b288624,n287623,op289625,prefix271475,y291627,_plus8);
++R.GAS;
return $ret24222423;
};
var $Hanf_arg12422427 = function(anf_arg6892426,b288624,n287623,op289625,prefix271475,y291627,_plus8) {
var $z24302431 = D;
var $f24362437 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg6892426,op289625):R.ffi.throwNonFunApp(L[228],_plus8,[anf_arg6892426,op289625]);
};
try {
if(--R.GAS > 0) {
$z24302431 = $f24362437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24362437,
"from":L[228]});
}
} catch($e24282429) {
if(R.isCont($e24282429)) {
var $ss24322433 = {"from":L[228],
"go":function(anf_arg6902438) {
return $Hanf_arg12412439(anf_arg6902438,b288624,n287623,prefix271475,y291627);
}};
$e24282429.stack[R.EXN_STACKHEIGHT++] = $ss24322433;
}
if(R.isPyretException($e24282429)) {
$e24282429.pyretStack.push(L[228]);
}
throw $e24282429;
}
var $ret24342435 = $Hanf_arg12412439($z24302431,b288624,n287623,prefix271475,y291627);
++R.GAS;
return $ret24342435;
};
var $Hanf_arg12412439 = function(anf_arg6902438,b288624,n287623,prefix271475,y291627) {
var $z24422443 = D;
var $f24482449 = function(_) {
return R.isFunction(prefix271475.$var)?prefix271475.$var.app(n287623,b288624,anf_arg6902438,y291627):R.ffi.throwNonFunApp(L[89],prefix271475.$var,[n287623,b288624,anf_arg6902438,y291627]);
};
try {
if(--R.GAS > 0) {
$z24422443 = $f24482449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24482449,
"from":L[89]});
}
} catch($e24402441) {
if(R.isCont($e24402441)) {
var $ss24442445 = {"from":L[89],
"go":function(ann_DASH_check_DASH_temp6872450) {
return $Hann_DASH_check_DASH_temp12402451(ann_DASH_check_DASH_temp6872450);
}};
$e24402441.stack[R.EXN_STACKHEIGHT++] = $ss24442445;
}
if(R.isPyretException($e24402441)) {
$e24402441.pyretStack.push(L[89]);
}
throw $e24402441;
}
var $ret24462447 = $Hann_DASH_check_DASH_temp12402451($z24422443);
++R.GAS;
return $ret24462447;
};
var $Hann_DASH_check_DASH_temp12402451 = function(ann_DASH_check_DASH_temp6872450) {
return ann_DASH_check_DASH_temp6872450;
};
var $Hanf_arg1239655 = function(anf_arg682654,group21980,n283640,nest22482,x285642,y286643,_plus8) {
var $z24542455 = D;
var $f24602461 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg682654,y286643):R.ffi.throwNonFunApp(L[229],_plus8,[anf_arg682654,y286643]);
};
try {
if(--R.GAS > 0) {
$z24542455 = $f24602461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24602461,
"from":L[229]});
}
} catch($e24522453) {
if(R.isCont($e24522453)) {
var $ss24562457 = {"from":L[229],
"go":function(anf_arg6832462) {
return $Hanf_arg12382463(anf_arg6832462,group21980,n283640,nest22482,x285642,_plus8);
}};
$e24522453.stack[R.EXN_STACKHEIGHT++] = $ss24562457;
}
if(R.isPyretException($e24522453)) {
$e24522453.pyretStack.push(L[229]);
}
throw $e24522453;
}
var $ret24582459 = $Hanf_arg12382463($z24542455,group21980,n283640,nest22482,x285642,_plus8);
++R.GAS;
return $ret24582459;
};
var $Hanf_arg12382463 = function(anf_arg6832462,group21980,n283640,nest22482,x285642,_plus8) {
var $z24662467 = D;
var $f24722473 = function(_) {
return R.isFunction(nest22482)?nest22482.app(n283640,anf_arg6832462):R.ffi.throwNonFunApp(L[230],nest22482,[n283640,anf_arg6832462]);
};
try {
if(--R.GAS > 0) {
$z24662467 = $f24722473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24722473,
"from":L[230]});
}
} catch($e24642465) {
if(R.isCont($e24642465)) {
var $ss24682469 = {"from":L[230],
"go":function(anf_arg6842474) {
return $Hanf_arg12372475(anf_arg6842474,group21980,x285642,_plus8);
}};
$e24642465.stack[R.EXN_STACKHEIGHT++] = $ss24682469;
}
if(R.isPyretException($e24642465)) {
$e24642465.pyretStack.push(L[230]);
}
throw $e24642465;
}
var $ret24702471 = $Hanf_arg12372475($z24662467,group21980,x285642,_plus8);
++R.GAS;
return $ret24702471;
};
var $Hanf_arg12372475 = function(anf_arg6842474,group21980,x285642,_plus8) {
var $z24782479 = D;
var $f24842485 = function(_) {
return R.isFunction(_plus8)?_plus8.app(x285642,anf_arg6842474):R.ffi.throwNonFunApp(L[231],_plus8,[x285642,anf_arg6842474]);
};
try {
if(--R.GAS > 0) {
$z24782479 = $f24842485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24842485,
"from":L[231]});
}
} catch($e24762477) {
if(R.isCont($e24762477)) {
var $ss24802481 = {"from":L[231],
"go":function(anf_arg6852486) {
return $Hanf_arg12362487(anf_arg6852486,group21980);
}};
$e24762477.stack[R.EXN_STACKHEIGHT++] = $ss24802481;
}
if(R.isPyretException($e24762477)) {
$e24762477.pyretStack.push(L[231]);
}
throw $e24762477;
}
var $ret24822483 = $Hanf_arg12362487($z24782479,group21980);
++R.GAS;
return $ret24822483;
};
var $Hanf_arg12362487 = function(anf_arg6852486,group21980) {
var $z24902491 = D;
var $f24962497 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg6852486):R.ffi.throwNonFunApp(L[96],group21980,[anf_arg6852486]);
};
try {
if(--R.GAS > 0) {
$z24902491 = $f24962497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24962497,
"from":L[96]});
}
} catch($e24882489) {
if(R.isCont($e24882489)) {
var $ss24922493 = {"from":L[96],
"go":function(ann_DASH_check_DASH_temp6812498) {
return $Hann_DASH_check_DASH_temp12352499(ann_DASH_check_DASH_temp6812498);
}};
$e24882489.stack[R.EXN_STACKHEIGHT++] = $ss24922493;
}
if(R.isPyretException($e24882489)) {
$e24882489.pyretStack.push(L[96]);
}
throw $e24882489;
}
var $ret24942495 = $Hann_DASH_check_DASH_temp12352499($z24902491);
++R.GAS;
return $ret24942495;
};
var $Hann_DASH_check_DASH_temp12352499 = function(ann_DASH_check_DASH_temp6812498) {
return ann_DASH_check_DASH_temp6812498;
};
var $Hanf_arg1234669 = function(anf_arg679668,align21777) {
var $z25022503 = D;
var $f25082509 = function(_) {
return R.isFunction(align21777)?align21777.app(anf_arg679668):R.ffi.throwNonFunApp(L[98],align21777,[anf_arg679668]);
};
try {
if(--R.GAS > 0) {
$z25022503 = $f25082509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25082509,
"from":L[98]});
}
} catch($e25002501) {
if(R.isCont($e25002501)) {
var $ss25042505 = {"from":L[98],
"go":function(ann_DASH_check_DASH_temp6782510) {
return $Hann_DASH_check_DASH_temp12332511(ann_DASH_check_DASH_temp6782510);
}};
$e25002501.stack[R.EXN_STACKHEIGHT++] = $ss25042505;
}
if(R.isPyretException($e25002501)) {
$e25002501.pyretStack.push(L[98]);
}
throw $e25002501;
}
var $ret25062507 = $Hann_DASH_check_DASH_temp12332511($z25022503);
++R.GAS;
return $ret25062507;
};
var $Hann_DASH_check_DASH_temp12332511 = function(ann_DASH_check_DASH_temp6782510) {
return ann_DASH_check_DASH_temp6782510;
};
var $Hanf_arg1232682 = function(anf_arg675681,group21980,str_DASH_squote266356,_plus8) {
var $z25142515 = D;
var $f25202521 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg675681,str_DASH_squote266356):R.ffi.throwNonFunApp(L[101],_plus8,[anf_arg675681,str_DASH_squote266356]);
};
try {
if(--R.GAS > 0) {
$z25142515 = $f25202521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25202521,
"from":L[101]});
}
} catch($e25122513) {
if(R.isCont($e25122513)) {
var $ss25162517 = {"from":L[101],
"go":function(anf_arg6762522) {
return $Hanf_arg12312523(anf_arg6762522,group21980);
}};
$e25122513.stack[R.EXN_STACKHEIGHT++] = $ss25162517;
}
if(R.isPyretException($e25122513)) {
$e25122513.pyretStack.push(L[101]);
}
throw $e25122513;
}
var $ret25182519 = $Hanf_arg12312523($z25142515,group21980);
++R.GAS;
return $ret25182519;
};
var $Hanf_arg12312523 = function(anf_arg6762522,group21980) {
var $z25262527 = D;
var $f25322533 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg6762522):R.ffi.throwNonFunApp(L[100],group21980,[anf_arg6762522]);
};
try {
if(--R.GAS > 0) {
$z25262527 = $f25322533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25322533,
"from":L[100]});
}
} catch($e25242525) {
if(R.isCont($e25242525)) {
var $ss25282529 = {"from":L[100],
"go":function(ann_DASH_check_DASH_temp6742534) {
return $Hann_DASH_check_DASH_temp12302535(ann_DASH_check_DASH_temp6742534);
}};
$e25242525.stack[R.EXN_STACKHEIGHT++] = $ss25282529;
}
if(R.isPyretException($e25242525)) {
$e25242525.pyretStack.push(L[100]);
}
throw $e25242525;
}
var $ret25302531 = $Hann_DASH_check_DASH_temp12302535($z25262527);
++R.GAS;
return $ret25302531;
};
var $Hann_DASH_check_DASH_temp12302535 = function(ann_DASH_check_DASH_temp6742534) {
return ann_DASH_check_DASH_temp6742534;
};
var $Hanf_arg1229695 = function(anf_arg671694,group21980,str_DASH_dquote267467,_plus8) {
var $z25382539 = D;
var $f25442545 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg671694,str_DASH_dquote267467):R.ffi.throwNonFunApp(L[103],_plus8,[anf_arg671694,str_DASH_dquote267467]);
};
try {
if(--R.GAS > 0) {
$z25382539 = $f25442545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25442545,
"from":L[103]});
}
} catch($e25362537) {
if(R.isCont($e25362537)) {
var $ss25402541 = {"from":L[103],
"go":function(anf_arg6722546) {
return $Hanf_arg12282547(anf_arg6722546,group21980);
}};
$e25362537.stack[R.EXN_STACKHEIGHT++] = $ss25402541;
}
if(R.isPyretException($e25362537)) {
$e25362537.pyretStack.push(L[103]);
}
throw $e25362537;
}
var $ret25422543 = $Hanf_arg12282547($z25382539,group21980);
++R.GAS;
return $ret25422543;
};
var $Hanf_arg12282547 = function(anf_arg6722546,group21980) {
var $z25502551 = D;
var $f25562557 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg6722546):R.ffi.throwNonFunApp(L[102],group21980,[anf_arg6722546]);
};
try {
if(--R.GAS > 0) {
$z25502551 = $f25562557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25562557,
"from":L[102]});
}
} catch($e25482549) {
if(R.isCont($e25482549)) {
var $ss25522553 = {"from":L[102],
"go":function(ann_DASH_check_DASH_temp6702558) {
return $Hann_DASH_check_DASH_temp12272559(ann_DASH_check_DASH_temp6702558);
}};
$e25482549.stack[R.EXN_STACKHEIGHT++] = $ss25522553;
}
if(R.isPyretException($e25482549)) {
$e25482549.pyretStack.push(L[102]);
}
throw $e25482549;
}
var $ret25542555 = $Hann_DASH_check_DASH_temp12272559($z25502551);
++R.GAS;
return $ret25542555;
};
var $Hann_DASH_check_DASH_temp12272559 = function(ann_DASH_check_DASH_temp6702558) {
return ann_DASH_check_DASH_temp6702558;
};
var $Hanf_arg1226370 = function(anf_arg667369,group21980,rbrack241257,_plus8) {
var $z25622563 = D;
var $f25682569 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg667369,rbrack241257):R.ffi.throwNonFunApp(L[35],_plus8,[anf_arg667369,rbrack241257]);
};
try {
if(--R.GAS > 0) {
$z25622563 = $f25682569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25682569,
"from":L[35]});
}
} catch($e25602561) {
if(R.isCont($e25602561)) {
var $ss25642565 = {"from":L[35],
"go":function(anf_arg6682570) {
return $Hanf_arg12252571(anf_arg6682570,group21980);
}};
$e25602561.stack[R.EXN_STACKHEIGHT++] = $ss25642565;
}
if(R.isPyretException($e25602561)) {
$e25602561.pyretStack.push(L[35]);
}
throw $e25602561;
}
var $ret25662567 = $Hanf_arg12252571($z25622563,group21980);
++R.GAS;
return $ret25662567;
};
var $Hanf_arg12252571 = function(anf_arg6682570,group21980) {
var $z25742575 = D;
var $f25802581 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg6682570):R.ffi.throwNonFunApp(L[34],group21980,[anf_arg6682570]);
};
try {
if(--R.GAS > 0) {
$z25742575 = $f25802581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25802581,
"from":L[34]});
}
} catch($e25722573) {
if(R.isCont($e25722573)) {
var $ss25762577 = {"from":L[34],
"go":function(ann_DASH_check_DASH_temp6662582) {
return $Hann_DASH_check_DASH_temp12242583(ann_DASH_check_DASH_temp6662582);
}};
$e25722573.stack[R.EXN_STACKHEIGHT++] = $ss25762577;
}
if(R.isPyretException($e25722573)) {
$e25722573.pyretStack.push(L[34]);
}
throw $e25722573;
}
var $ret25782579 = $Hann_DASH_check_DASH_temp12242583($z25742575);
++R.GAS;
return $ret25782579;
};
var $Hann_DASH_check_DASH_temp12242583 = function(ann_DASH_check_DASH_temp6662582) {
return ann_DASH_check_DASH_temp6662582;
};
var $Hanf_arg1223383 = function(anf_arg663382,group21980,rbrace239233,_plus8) {
var $z25862587 = D;
var $f25922593 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg663382,rbrace239233):R.ffi.throwNonFunApp(L[37],_plus8,[anf_arg663382,rbrace239233]);
};
try {
if(--R.GAS > 0) {
$z25862587 = $f25922593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25922593,
"from":L[37]});
}
} catch($e25842585) {
if(R.isCont($e25842585)) {
var $ss25882589 = {"from":L[37],
"go":function(anf_arg6642594) {
return $Hanf_arg12222595(anf_arg6642594,group21980);
}};
$e25842585.stack[R.EXN_STACKHEIGHT++] = $ss25882589;
}
if(R.isPyretException($e25842585)) {
$e25842585.pyretStack.push(L[37]);
}
throw $e25842585;
}
var $ret25902591 = $Hanf_arg12222595($z25862587,group21980);
++R.GAS;
return $ret25902591;
};
var $Hanf_arg12222595 = function(anf_arg6642594,group21980) {
var $z25982599 = D;
var $f26042605 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg6642594):R.ffi.throwNonFunApp(L[36],group21980,[anf_arg6642594]);
};
try {
if(--R.GAS > 0) {
$z25982599 = $f26042605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26042605,
"from":L[36]});
}
} catch($e25962597) {
if(R.isCont($e25962597)) {
var $ss26002601 = {"from":L[36],
"go":function(ann_DASH_check_DASH_temp6622606) {
return $Hann_DASH_check_DASH_temp12212607(ann_DASH_check_DASH_temp6622606);
}};
$e25962597.stack[R.EXN_STACKHEIGHT++] = $ss26002601;
}
if(R.isPyretException($e25962597)) {
$e25962597.pyretStack.push(L[36]);
}
throw $e25962597;
}
var $ret26022603 = $Hann_DASH_check_DASH_temp12212607($z25982599);
++R.GAS;
return $ret26022603;
};
var $Hann_DASH_check_DASH_temp12212607 = function(ann_DASH_check_DASH_temp6622606) {
return ann_DASH_check_DASH_temp6622606;
};
var $Hanf_arg1220396 = function(anf_arg659395,group21980,rparen237209,_plus8) {
var $z26102611 = D;
var $f26162617 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg659395,rparen237209):R.ffi.throwNonFunApp(L[39],_plus8,[anf_arg659395,rparen237209]);
};
try {
if(--R.GAS > 0) {
$z26102611 = $f26162617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26162617,
"from":L[39]});
}
} catch($e26082609) {
if(R.isCont($e26082609)) {
var $ss26122613 = {"from":L[39],
"go":function(anf_arg6602618) {
return $Hanf_arg12192619(anf_arg6602618,group21980);
}};
$e26082609.stack[R.EXN_STACKHEIGHT++] = $ss26122613;
}
if(R.isPyretException($e26082609)) {
$e26082609.pyretStack.push(L[39]);
}
throw $e26082609;
}
var $ret26142615 = $Hanf_arg12192619($z26102611,group21980);
++R.GAS;
return $ret26142615;
};
var $Hanf_arg12192619 = function(anf_arg6602618,group21980) {
var $z26222623 = D;
var $f26282629 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg6602618):R.ffi.throwNonFunApp(L[38],group21980,[anf_arg6602618]);
};
try {
if(--R.GAS > 0) {
$z26222623 = $f26282629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26282629,
"from":L[38]});
}
} catch($e26202621) {
if(R.isCont($e26202621)) {
var $ss26242625 = {"from":L[38],
"go":function(ann_DASH_check_DASH_temp6582630) {
return $Hann_DASH_check_DASH_temp12182631(ann_DASH_check_DASH_temp6582630);
}};
$e26202621.stack[R.EXN_STACKHEIGHT++] = $ss26242625;
}
if(R.isPyretException($e26202621)) {
$e26202621.pyretStack.push(L[38]);
}
throw $e26202621;
}
var $ret26262627 = $Hann_DASH_check_DASH_temp12182631($z26222623);
++R.GAS;
return $ret26262627;
};
var $Hann_DASH_check_DASH_temp12182631 = function(ann_DASH_check_DASH_temp6582630) {
return ann_DASH_check_DASH_temp6582630;
};
var $Hann_DASH_check_DASH_temp1217410 = function(ann_DASH_check_DASH_temp654409) {
return ann_DASH_check_DASH_temp654409;
};
var $Hanf_arg1216425 = function(anf_arg650424,flow_DASH_map248334,items259413) {
var anf_arg6522642 = R.makeFunction(function(x2602645) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[232],1,arguments);
}
var ann_DASH_check_DASH_temp6512646 = x2602645;
return ann_DASH_check_DASH_temp6512646;
});
var $z26342635 = D;
var $f26402641 = function(_) {
return R.isFunction(flow_DASH_map248334.$var)?flow_DASH_map248334.$var.app(anf_arg650424,anf_arg6522642,items259413):R.ffi.throwNonFunApp(L[42],flow_DASH_map248334.$var,[anf_arg650424,anf_arg6522642,items259413]);
};
try {
if(--R.GAS > 0) {
$z26342635 = $f26402641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26402641,
"from":L[42]});
}
} catch($e26322633) {
if(R.isCont($e26322633)) {
var $ss26362637 = {"from":L[42],
"go":function(ann_DASH_check_DASH_temp6492643) {
return $Hann_DASH_check_DASH_temp12152644(ann_DASH_check_DASH_temp6492643);
}};
$e26322633.stack[R.EXN_STACKHEIGHT++] = $ss26362637;
}
if(R.isPyretException($e26322633)) {
$e26322633.pyretStack.push(L[42]);
}
throw $e26322633;
}
var $ret26382639 = $Hann_DASH_check_DASH_temp12152644($z26342635);
++R.GAS;
return $ret26382639;
};
var $Hann_DASH_check_DASH_temp12152644 = function(ann_DASH_check_DASH_temp6492643) {
return ann_DASH_check_DASH_temp6492643;
};
var $Hann_DASH_check_DASH_temp1214442 = function(ann_DASH_check_DASH_temp632441) {
return ann_DASH_check_DASH_temp632441;
};
var $Hif_DASH_1213456 = function(if_DASH_82455,acc257443,f255427,group21980,item258444,sep254426,_plus8) {
var if_helper6352658 = R.makeFunction(function(if_helper_arg6362676) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[46],1,arguments);
}
var ann_DASH_check_DASH_temp6342677 = if_helper_arg6362676;
return ann_DASH_check_DASH_temp6342677;
});
var anf_if6392675 = R.isBoolean(if_DASH_82455);
if(R.isPyretTrue(anf_if6392675)) {
if(R.isPyretTrue(if_DASH_82455)) {
var $z26492650 = D;
var $f26552656 = function(_) {
return R.isFunction(f255427)?f255427.app(item258444):R.ffi.throwNonFunApp(L[233],f255427,[item258444]);
};
try {
if(--R.GAS > 0) {
$z26492650 = $f26552656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26552656,
"from":L[233]});
}
} catch($e26472648) {
if(R.isCont($e26472648)) {
var $ss26512652 = {"from":L[233],
"go":function(cont_tail_arg6452657) {
return $Hcont_tail_arg12082659(cont_tail_arg6452657,if_helper6352658);
}};
$e26472648.stack[R.EXN_STACKHEIGHT++] = $ss26512652;
}
if(R.isPyretException($e26472648)) {
$e26472648.pyretStack.push(L[233]);
}
throw $e26472648;
}
var $ret26532654 = $Hcont_tail_arg12082659($z26492650,if_helper6352658);
++R.GAS;
return $ret26532654;
} else {
var $z26622663 = D;
var $f26682669 = function(_) {
return R.isFunction(f255427)?f255427.app(item258444):R.ffi.throwNonFunApp(L[234],f255427,[item258444]);
};
try {
if(--R.GAS > 0) {
$z26622663 = $f26682669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26682669,
"from":L[234]});
}
} catch($e26602661) {
if(R.isCont($e26602661)) {
var $ss26642665 = {"from":L[234],
"go":function(anf_arg6402670) {
return $Hanf_arg12122671(anf_arg6402670,acc257443,group21980,if_helper6352658,sep254426,_plus8);
}};
$e26602661.stack[R.EXN_STACKHEIGHT++] = $ss26642665;
}
if(R.isPyretException($e26602661)) {
$e26602661.pyretStack.push(L[234]);
}
throw $e26602661;
}
var $ret26662667 = $Hanf_arg12122671($z26622663,acc257443,group21980,if_helper6352658,sep254426,_plus8);
++R.GAS;
return $ret26662667;
}
} else {
var cont_tail_arg6372674 = R.throwNonBooleanCondition(L[46],("if"),if_DASH_82455);
if(--R.GAS > 0) {
$z26722673 = R.isFunction(if_helper6352658)?if_helper6352658.app(cont_tail_arg6372674):R.ffi.throwNonFunApp(L[46],if_helper6352658,[cont_tail_arg6372674]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper6352658)?if_helper6352658.app(cont_tail_arg6372674):R.ffi.throwNonFunApp(L[46],if_helper6352658,[cont_tail_arg6372674]);
},
"from":L[46]});
}
++R.GAS;
return $z26722673;
}
};
var $Hcont_tail_arg12082659 = function(cont_tail_arg6452657,if_helper6352658) {
if(--R.GAS > 0) {
$z26782679 = R.isFunction(if_helper6352658)?if_helper6352658.app(cont_tail_arg6452657):R.ffi.throwNonFunApp(L[233],if_helper6352658,[cont_tail_arg6452657]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper6352658)?if_helper6352658.app(cont_tail_arg6452657):R.ffi.throwNonFunApp(L[233],if_helper6352658,[cont_tail_arg6452657]);
},
"from":L[233]});
}
++R.GAS;
return $z26782679;
};
var $Hanf_arg12122671 = function(anf_arg6402670,acc257443,group21980,if_helper6352658,sep254426,_plus8) {
var $z26822683 = D;
var $f26882689 = function(_) {
return R.isFunction(_plus8)?_plus8.app(sep254426,anf_arg6402670):R.ffi.throwNonFunApp(L[235],_plus8,[sep254426,anf_arg6402670]);
};
try {
if(--R.GAS > 0) {
$z26822683 = $f26882689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26882689,
"from":L[235]});
}
} catch($e26802681) {
if(R.isCont($e26802681)) {
var $ss26842685 = {"from":L[235],
"go":function(anf_arg6412690) {
return $Hanf_arg12112691(anf_arg6412690,acc257443,group21980,if_helper6352658,_plus8);
}};
$e26802681.stack[R.EXN_STACKHEIGHT++] = $ss26842685;
}
if(R.isPyretException($e26802681)) {
$e26802681.pyretStack.push(L[235]);
}
throw $e26802681;
}
var $ret26862687 = $Hanf_arg12112691($z26822683,acc257443,group21980,if_helper6352658,_plus8);
++R.GAS;
return $ret26862687;
};
var $Hanf_arg12112691 = function(anf_arg6412690,acc257443,group21980,if_helper6352658,_plus8) {
var $z26942695 = D;
var $f27002701 = function(_) {
return R.isFunction(group21980)?group21980.app(anf_arg6412690):R.ffi.throwNonFunApp(L[236],group21980,[anf_arg6412690]);
};
try {
if(--R.GAS > 0) {
$z26942695 = $f27002701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27002701,
"from":L[236]});
}
} catch($e26922693) {
if(R.isCont($e26922693)) {
var $ss26962697 = {"from":L[236],
"go":function(anf_arg6422702) {
return $Hanf_arg12102703(anf_arg6422702,acc257443,if_helper6352658,_plus8);
}};
$e26922693.stack[R.EXN_STACKHEIGHT++] = $ss26962697;
}
if(R.isPyretException($e26922693)) {
$e26922693.pyretStack.push(L[236]);
}
throw $e26922693;
}
var $ret26982699 = $Hanf_arg12102703($z26942695,acc257443,if_helper6352658,_plus8);
++R.GAS;
return $ret26982699;
};
var $Hanf_arg12102703 = function(anf_arg6422702,acc257443,if_helper6352658,_plus8) {
var $z27062707 = D;
var $f27122713 = function(_) {
return R.isFunction(_plus8)?_plus8.app(acc257443,anf_arg6422702):R.ffi.throwNonFunApp(L[237],_plus8,[acc257443,anf_arg6422702]);
};
try {
if(--R.GAS > 0) {
$z27062707 = $f27122713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27122713,
"from":L[237]});
}
} catch($e27042705) {
if(R.isCont($e27042705)) {
var $ss27082709 = {"from":L[237],
"go":function(cont_tail_arg6432714) {
return $Hcont_tail_arg12092715(cont_tail_arg6432714,if_helper6352658);
}};
$e27042705.stack[R.EXN_STACKHEIGHT++] = $ss27082709;
}
if(R.isPyretException($e27042705)) {
$e27042705.pyretStack.push(L[237]);
}
throw $e27042705;
}
var $ret27102711 = $Hcont_tail_arg12092715($z27062707,if_helper6352658);
++R.GAS;
return $ret27102711;
};
var $Hcont_tail_arg12092715 = function(cont_tail_arg6432714,if_helper6352658) {
if(--R.GAS > 0) {
$z27162717 = R.isFunction(if_helper6352658)?if_helper6352658.app(cont_tail_arg6432714):R.ffi.throwNonFunApp(L[237],if_helper6352658,[cont_tail_arg6432714]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper6352658)?if_helper6352658.app(cont_tail_arg6432714):R.ffi.throwNonFunApp(L[237],if_helper6352658,[cont_tail_arg6432714]);
},
"from":L[237]});
}
++R.GAS;
return $z27162717;
};
var $Hanf_arg1207321 = function(anf_arg629320,hardline21661,if_DASH_flat22181) {
var $z27202721 = D;
var $f27262727 = function(_) {
return R.isFunction(if_DASH_flat22181)?if_DASH_flat22181.app(anf_arg629320,hardline21661):R.ffi.throwNonFunApp(L[30],if_DASH_flat22181,[anf_arg629320,hardline21661]);
};
try {
if(--R.GAS > 0) {
$z27202721 = $f27262727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27262727,
"from":L[30]});
}
} catch($e27182719) {
if(R.isCont($e27182719)) {
var $ss27222723 = {"from":L[30],
"go":function(ann_DASH_check_DASH_temp6282728) {
return $Hann_DASH_check_DASH_temp12062729(ann_DASH_check_DASH_temp6282728);
}};
$e27182719.stack[R.EXN_STACKHEIGHT++] = $ss27222723;
}
if(R.isPyretException($e27182719)) {
$e27182719.pyretStack.push(L[30]);
}
throw $e27182719;
}
var $ret27242725 = $Hann_DASH_check_DASH_temp12062729($z27202721);
++R.GAS;
return $ret27242725;
};
var $Hann_DASH_check_DASH_temp12062729 = function(ann_DASH_check_DASH_temp6282728) {
return ann_DASH_check_DASH_temp6282728;
};
var $Hanf_arg120596 = function(anf_arg62695,str23275) {
var $z27322733 = D;
var $f27382739 = function(_) {
return R.isFunction(str23275)?str23275.app(anf_arg62695):R.ffi.throwNonFunApp(L[2],str23275,[anf_arg62695]);
};
try {
if(--R.GAS > 0) {
$z27322733 = $f27382739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27382739,
"from":L[2]});
}
} catch($e27302731) {
if(R.isCont($e27302731)) {
var $ss27342735 = {"from":L[2],
"go":function(ann_DASH_check_DASH_temp6252740) {
return $Hann_DASH_check_DASH_temp12042741(ann_DASH_check_DASH_temp6252740);
}};
$e27302731.stack[R.EXN_STACKHEIGHT++] = $ss27342735;
}
if(R.isPyretException($e27302731)) {
$e27302731.pyretStack.push(L[2]);
}
throw $e27302731;
}
var $ret27362737 = $Hann_DASH_check_DASH_temp12042741($z27322733);
++R.GAS;
return $ret27362737;
};
var $Hann_DASH_check_DASH_temp12042741 = function(ann_DASH_check_DASH_temp6252740) {
return ann_DASH_check_DASH_temp6252740;
};
var $Hanf_arg1203109 = function(anf_arg624108,s23397,str7050) {
var $z27442745 = D;
var $f27502751 = function(_) {
return R.isFunction(str7050.$var)?str7050.$var.app(s23397,anf_arg624108,(false)):R.ffi.throwNonFunApp(L[5],str7050.$var,[s23397,anf_arg624108,(false)]);
};
try {
if(--R.GAS > 0) {
$z27442745 = $f27502751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27502751,
"from":L[5]});
}
} catch($e27422743) {
if(R.isCont($e27422743)) {
var $ss27462747 = {"from":L[5],
"go":function(ann_DASH_check_DASH_temp6232752) {
return $Hann_DASH_check_DASH_temp12022753(ann_DASH_check_DASH_temp6232752);
}};
$e27422743.stack[R.EXN_STACKHEIGHT++] = $ss27462747;
}
if(R.isPyretException($e27422743)) {
$e27422743.pyretStack.push(L[5]);
}
throw $e27422743;
}
var $ret27482749 = $Hann_DASH_check_DASH_temp12022753($z27442745);
++R.GAS;
return $ret27482749;
};
var $Hann_DASH_check_DASH_temp12022753 = function(ann_DASH_check_DASH_temp6232752) {
return ann_DASH_check_DASH_temp6232752;
};
var $Hann_DASH_check_DASH_temp1201122 = function(ann_DASH_check_DASH_temp622121) {
return ann_DASH_check_DASH_temp622121;
};
var $Hann_DASH_check_DASH_temp1200136 = function(ann_DASH_check_DASH_temp621135) {
return ann_DASH_check_DASH_temp621135;
};
var $Hann_DASH_check_DASH_temp1199152 = function(ann_DASH_check_DASH_temp618151) {
return ann_DASH_check_DASH_temp618151;
};
var $Hann_DASH_check_DASH_temp1198168 = function(ann_DASH_check_DASH_temp615167) {
return ann_DASH_check_DASH_temp615167;
};
var $Hann_DASH_check_DASH_temp1197183 = function(ann_DASH_check_DASH_temp612182) {
return ann_DASH_check_DASH_temp612182;
};
var $Hann_DASH_check_DASH_temp1196198 = function(ann_DASH_check_DASH_temp609197) {
return ann_DASH_check_DASH_temp609197;
};
var $Hanf_array_val11952754 = function(anf_array_val4382755,Item6238,List112756,anf_fun4362757,doc1642758,group8643,is_DASH_empty2046,item912759,list1948,lists321,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,string_DASH_repeat13,$type$Nothing17,$type$Number18) {
var $z27632764 = D;
var $f27692770 = function(_) {
return R.isFunction(anf_fun4362757)?anf_fun4362757.app([anf_array_val4382755]):R.ffi.throwNonFunApp(L[238],anf_fun4362757,[[anf_array_val4382755]]);
};
try {
if(--R.GAS > 0) {
$z27632764 = $f27692770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27692770,
"from":L[238]});
}
} catch($e27612762) {
if(R.isCont($e27612762)) {
var $ss27652766 = {"from":L[238],
"go":function(var_DASH_bind11122771) {
return $Hvar_DASH_bind11942772(var_DASH_bind11122771,Item6238,List112756,doc1642758,group8643,is_DASH_empty2046,item912759,list1948,lists321,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,string_DASH_repeat13,$type$Nothing17,$type$Number18);
}};
$e27612762.stack[R.EXN_STACKHEIGHT++] = $ss27652766;
}
if(R.isPyretException($e27612762)) {
$e27612762.pyretStack.push(L[238]);
}
throw $e27612762;
}
var $ret27672768 = $Hvar_DASH_bind11942772($z27632764,Item6238,List112756,doc1642758,group8643,is_DASH_empty2046,item912759,list1948,lists321,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,string_DASH_repeat13,$type$Nothing17,$type$Number18);
++R.GAS;
return $ret27672768;
};
var $Hvar_DASH_bind11942772 = function(var_DASH_bind11122771,Item6238,List112756,doc1642758,group8643,is_DASH_empty2046,item912759,list1948,lists321,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,string_DASH_repeat13,$type$Nothing17,$type$Number18) {
var output1652826 = {"$var":var_DASH_bind11122771,
"$name":"output"};
var emit_DASH_text1662773 = {"$var":D,
"$name":"emit-text"};
var emit_DASH_spaces1672775 = {"$var":D,
"$name":"emit-spaces"};
var emit_DASH_newline1682777 = {"$var":D,
"$name":"emit-newline"};
var gen_DASH_output1692779 = {"$var":D,
"$name":"gen-output"};
var process1702781 = {"$var":D,
"$name":"process"};
var anf_assign4482774 = R.makeFunction(function(s1712886) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[260],1,arguments);
}
var anf_fun4402899 = G(list1948,"make",L[262]);
var anf_fun4412897 = G(list1948,"make",L[261]);
var $z28892890 = D;
var $f28952896 = function(_) {
return R.isFunction(anf_fun4412897)?anf_fun4412897.app([s1712886]):R.ffi.throwNonFunApp(L[261],anf_fun4412897,[[s1712886]]);
};
try {
if(--R.GAS > 0) {
$z28892890 = $f28952896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28952896,
"from":L[261]});
}
} catch($e28872888) {
if(R.isCont($e28872888)) {
var $ss28912892 = {"from":L[261],
"go":function(anf_arg4422898) {
return $Hanf_arg11162900(anf_arg4422898,anf_fun4402899,output1652826,_plus8);
}};
$e28872888.stack[R.EXN_STACKHEIGHT++] = $ss28912892;
}
if(R.isPyretException($e28872888)) {
$e28872888.pyretStack.push(L[261]);
}
throw $e28872888;
}
var $ret28932894 = $Hanf_arg11162900($z28892890,anf_fun4402899,output1652826,_plus8);
++R.GAS;
return $ret28932894;
});
emit_DASH_text1662773.$var = anf_assign4482774;
var anf_assign4512776 = R.makeFunction(function(n1722873) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[258],1,arguments);
}
var $z28762877 = D;
var $f28822883 = function(_) {
return R.isFunction(string_DASH_repeat13)?string_DASH_repeat13.app((" "),n1722873):R.ffi.throwNonFunApp(L[259],string_DASH_repeat13,[(" "),n1722873]);
};
try {
if(--R.GAS > 0) {
$z28762877 = $f28822883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28822883,
"from":L[259]});
}
} catch($e28742875) {
if(R.isCont($e28742875)) {
var $ss28782879 = {"from":L[259],
"go":function(anf_arg4502884) {
return $Hanf_arg11182885(anf_arg4502884,emit_DASH_text1662773);
}};
$e28742875.stack[R.EXN_STACKHEIGHT++] = $ss28782879;
}
if(R.isPyretException($e28742875)) {
$e28742875.pyretStack.push(L[259]);
}
throw $e28742875;
}
var $ret28802881 = $Hanf_arg11182885($z28762877,emit_DASH_text1662773);
++R.GAS;
return $ret28802881;
});
emit_DASH_spaces1672775.$var = anf_assign4512776;
var anf_assign4592778 = R.makeFunction(function(i1732858) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[254],1,arguments);
}
var anf_fun4532870 = G(list1948,"make",L[257]);
var anf_fun4542871 = G(list1948,"make",L[256]);
var $z28612862 = D;
var $f28672868 = function(_) {
return R.isFunction(string_DASH_repeat13)?string_DASH_repeat13.app((" "),i1732858):R.ffi.throwNonFunApp(L[255],string_DASH_repeat13,[(" "),i1732858]);
};
try {
if(--R.GAS > 0) {
$z28612862 = $f28672868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28672868,
"from":L[255]});
}
} catch($e28592860) {
if(R.isCont($e28592860)) {
var $ss28632864 = {"from":L[255],
"go":function(anf_array_val4552869) {
return $Hanf_array_val11222872(anf_array_val4552869,anf_fun4532870,anf_fun4542871,output1652826,_plus8);
}};
$e28592860.stack[R.EXN_STACKHEIGHT++] = $ss28632864;
}
if(R.isPyretException($e28592860)) {
$e28592860.pyretStack.push(L[255]);
}
throw $e28592860;
}
var $ret28652866 = $Hanf_array_val11222872($z28612862,anf_fun4532870,anf_fun4542871,output1652826,_plus8);
++R.GAS;
return $ret28652866;
});
emit_DASH_newline1682777.$var = anf_assign4592778;
var anf_assign4712780 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[247],0,arguments);
}
var anf_fun4612825 = G(lists321,"fold",L[253]);
var anf_arg4682824 = R.makeFunction(function(lines1742828,line1752829) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[249],2,arguments);
}
var anf_fun4632840 = G(lists321,"fold",L[252]);
var anf_arg4652841 = R.makeFunction(function(acc1772844,piece1782845) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[251],2,arguments);
}
var $z28482849 = D;
var $f28542855 = function(_) {
return R.isFunction(_plus8)?_plus8.app(piece1782845,acc1772844):R.ffi.throwNonFunApp(L[251],_plus8,[piece1782845,acc1772844]);
};
try {
if(--R.GAS > 0) {
$z28482849 = $f28542855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28542855,
"from":L[251]});
}
} catch($e28462847) {
if(R.isCont($e28462847)) {
var $ss28502851 = {"from":L[251],
"go":function(ann_DASH_check_DASH_temp4642856) {
return $Hann_DASH_check_DASH_temp11232857(ann_DASH_check_DASH_temp4642856);
}};
$e28462847.stack[R.EXN_STACKHEIGHT++] = $ss28502851;
}
if(R.isPyretException($e28462847)) {
$e28462847.pyretStack.push(L[251]);
}
throw $e28462847;
}
var $ret28522853 = $Hann_DASH_check_DASH_temp11232857($z28482849);
++R.GAS;
return $ret28522853;
});
var $z28322833 = D;
var $f28382839 = function(_) {
return R.isFunction(anf_fun4632840)?anf_fun4632840.app(anf_arg4652841,(""),line1752829):R.ffi.throwNonFunApp(L[250],anf_fun4632840,[anf_arg4652841,(""),line1752829]);
};
try {
if(--R.GAS > 0) {
$z28322833 = $f28382839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28382839,
"from":L[250]});
}
} catch($e28302831) {
if(R.isCont($e28302831)) {
var $ss28342835 = {"from":L[250],
"go":function(l1762842) {
return $Hl11262843(l1762842,lines1742828,list1948,_plus8);
}};
$e28302831.stack[R.EXN_STACKHEIGHT++] = $ss28342835;
}
if(R.isPyretException($e28302831)) {
$e28302831.pyretStack.push(L[250]);
}
throw $e28302831;
}
var $ret28362837 = $Hl11262843($z28322833,lines1742828,list1948,_plus8);
++R.GAS;
return $ret28362837;
});
var anf_fun4692822 = G(list1948,"make",L[248]);
var $z28142815 = D;
var $f28202821 = function(_) {
return R.isFunction(anf_fun4692822)?anf_fun4692822.app([]):R.ffi.throwNonFunApp(L[248],anf_fun4692822,[[]]);
};
try {
if(--R.GAS > 0) {
$z28142815 = $f28202821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28202821,
"from":L[248]});
}
} catch($e28122813) {
if(R.isCont($e28122813)) {
var $ss28162817 = {"from":L[248],
"go":function(anf_arg4702823) {
return $Hanf_arg11282827(anf_arg4702823,anf_arg4682824,anf_fun4612825,output1652826);
}};
$e28122813.stack[R.EXN_STACKHEIGHT++] = $ss28162817;
}
if(R.isPyretException($e28122813)) {
$e28122813.pyretStack.push(L[248]);
}
throw $e28122813;
}
var $ret28182819 = $Hanf_arg11282827($z28142815,anf_arg4682824,anf_fun4612825,output1652826);
++R.GAS;
return $ret28182819;
});
gen_DASH_output1692779.$var = anf_assign4712780;
var anf_assign6012782 = R.makeFunction(function(column1792798,items1802799) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[243],2,arguments);
}
return R.checkAnnArgs([$type$Number18,List112756],[column1792798,items1802799],[L[245],L[246]],function() {
var $z28022803 = D;
var $f28082809 = function(_) {
return R.isFunction(is_DASH_empty2046)?is_DASH_empty2046.app(items1802799):R.ffi.throwNonFunApp(L[244],is_DASH_empty2046,[items1802799]);
};
try {
if(--R.GAS > 0) {
$z28022803 = $f28082809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28082809,
"from":L[244]});
}
} catch($e28002801) {
if(R.isCont($e28002801)) {
var $ss28042805 = {"from":L[244],
"go":function(if_DASH_812810) {
return $Hif_DASH_11872811(if_DASH_812810,column1792798,emit_DASH_newline1682777,emit_DASH_spaces1672775,emit_DASH_text1662773,item912759,items1802799,list1948,process1702781,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,$type$Nothing17);
}};
$e28002801.stack[R.EXN_STACKHEIGHT++] = $ss28042805;
}
if(R.isPyretException($e28002801)) {
$e28002801.pyretStack.push(L[244]);
}
throw $e28002801;
}
var $ret28062807 = $Hif_DASH_11872811($z28022803,column1792798,emit_DASH_newline1682777,emit_DASH_spaces1672775,emit_DASH_text1662773,item912759,items1802799,list1948,process1702781,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,$type$Nothing17);
++R.GAS;
return $ret28062807;
});
});
process1702781.$var = anf_assign6012782;
var anf_fun6022796 = G(list1948,"make",L[242]);
var anf_arg6032793 = G(doc1642758,"flat-width",L[241]);
var anf_arg6042794 = G(doc1642758,"has-hardline",L[240]);
var $z27852786 = D;
var $f27912792 = function(_) {
return R.isFunction(group8643.$var)?group8643.$var.app(doc1642758,anf_arg6032793,anf_arg6042794):R.ffi.throwNonFunApp(L[239],group8643.$var,[doc1642758,anf_arg6032793,anf_arg6042794]);
};
try {
if(--R.GAS > 0) {
$z27852786 = $f27912792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27912792,
"from":L[239]});
}
} catch($e27832784) {
if(R.isCont($e27832784)) {
var $ss27872788 = {"from":L[239],
"go":function(anf_arg6052795) {
return $Hanf_arg11932797(anf_arg6052795,anf_fun6022796,gen_DASH_output1692779,item912759,process1702781);
}};
$e27832784.stack[R.EXN_STACKHEIGHT++] = $ss27872788;
}
if(R.isPyretException($e27832784)) {
$e27832784.pyretStack.push(L[239]);
}
throw $e27832784;
}
var $ret27892790 = $Hanf_arg11932797($z27852786,anf_fun6022796,gen_DASH_output1692779,item912759,process1702781);
++R.GAS;
return $ret27892790;
};
var $Hanf_arg11932797 = function(anf_arg6052795,anf_fun6022796,gen_DASH_output1692779,item912759,process1702781) {
var $z29032904 = D;
var $f29092910 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app((0),(false),anf_arg6052795):R.ffi.throwNonFunApp(L[263],item912759.$var,[(0),(false),anf_arg6052795]);
};
try {
if(--R.GAS > 0) {
$z29032904 = $f29092910();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29092910,
"from":L[263]});
}
} catch($e29012902) {
if(R.isCont($e29012902)) {
var $ss29052906 = {"from":L[263],
"go":function(anf_array_val6062911) {
return $Hanf_array_val11922912(anf_array_val6062911,anf_fun6022796,gen_DASH_output1692779,process1702781);
}};
$e29012902.stack[R.EXN_STACKHEIGHT++] = $ss29052906;
}
if(R.isPyretException($e29012902)) {
$e29012902.pyretStack.push(L[263]);
}
throw $e29012902;
}
var $ret29072908 = $Hanf_array_val11922912($z29032904,anf_fun6022796,gen_DASH_output1692779,process1702781);
++R.GAS;
return $ret29072908;
};
var $Hanf_array_val11922912 = function(anf_array_val6062911,anf_fun6022796,gen_DASH_output1692779,process1702781) {
var $z29152916 = D;
var $f29212922 = function(_) {
return R.isFunction(anf_fun6022796)?anf_fun6022796.app([anf_array_val6062911]):R.ffi.throwNonFunApp(L[242],anf_fun6022796,[[anf_array_val6062911]]);
};
try {
if(--R.GAS > 0) {
$z29152916 = $f29212922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29212922,
"from":L[242]});
}
} catch($e29132914) {
if(R.isCont($e29132914)) {
var $ss29172918 = {"from":L[242],
"go":function(anf_arg6072923) {
return $Hanf_arg11912924(anf_arg6072923,gen_DASH_output1692779,process1702781);
}};
$e29132914.stack[R.EXN_STACKHEIGHT++] = $ss29172918;
}
if(R.isPyretException($e29132914)) {
$e29132914.pyretStack.push(L[242]);
}
throw $e29132914;
}
var $ret29192920 = $Hanf_arg11912924($z29152916,gen_DASH_output1692779,process1702781);
++R.GAS;
return $ret29192920;
};
var $Hanf_arg11912924 = function(anf_arg6072923,gen_DASH_output1692779,process1702781) {
var $z29272928 = D;
var $f29332934 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app((0),anf_arg6072923):R.ffi.throwNonFunApp(L[264],process1702781.$var,[(0),anf_arg6072923]);
};
try {
if(--R.GAS > 0) {
$z29272928 = $f29332934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29332934,
"from":L[264]});
}
} catch($e29252926) {
if(R.isCont($e29252926)) {
var $ss29292930 = {"from":L[264],
"go":function(anf_begin_app_dropped11882935) {
return $Hanf_begin_app_dropped11902936(anf_begin_app_dropped11882935,gen_DASH_output1692779);
}};
$e29252926.stack[R.EXN_STACKHEIGHT++] = $ss29292930;
}
if(R.isPyretException($e29252926)) {
$e29252926.pyretStack.push(L[264]);
}
throw $e29252926;
}
var $ret29312932 = $Hanf_begin_app_dropped11902936($z29272928,gen_DASH_output1692779);
++R.GAS;
return $ret29312932;
};
var $Hanf_begin_app_dropped11902936 = function(anf_begin_app_dropped11882935,gen_DASH_output1692779) {
var $z29392940 = D;
var $f29452946 = function(_) {
return R.isFunction(gen_DASH_output1692779.$var)?gen_DASH_output1692779.$var.app():R.ffi.throwNonFunApp(L[265],gen_DASH_output1692779.$var,[]);
};
try {
if(--R.GAS > 0) {
$z29392940 = $f29452946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29452946,
"from":L[265]});
}
} catch($e29372938) {
if(R.isCont($e29372938)) {
var $ss29412942 = {"from":L[265],
"go":function(ann_DASH_check_DASH_temp4352947) {
return $Hann_DASH_check_DASH_temp11892948(ann_DASH_check_DASH_temp4352947);
}};
$e29372938.stack[R.EXN_STACKHEIGHT++] = $ss29412942;
}
if(R.isPyretException($e29372938)) {
$e29372938.pyretStack.push(L[265]);
}
throw $e29372938;
}
var $ret29432944 = $Hann_DASH_check_DASH_temp11892948($z29392940);
++R.GAS;
return $ret29432944;
};
var $Hann_DASH_check_DASH_temp11892948 = function(ann_DASH_check_DASH_temp4352947) {
return ann_DASH_check_DASH_temp4352947;
};
var $Hif_DASH_11872811 = function(if_DASH_812810,column1792798,emit_DASH_newline1682777,emit_DASH_spaces1672775,emit_DASH_text1662773,item912759,items1802799,list1948,process1702781,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,$type$Nothing17) {
var if_helper4732959 = R.makeFunction(function(if_helper_arg4743263) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[244],1,arguments);
}
var ann_DASH_check_DASH_temp4723264 = if_helper_arg4743263;
return R.checkAnn(L[310],$type$Nothing17,ann_DASH_check_DASH_temp4723264,function() {
return ann_DASH_check_DASH_temp4723264;
});
});
var anf_if4773262 = R.isBoolean(if_DASH_812810);
if(R.isPyretTrue(anf_if4773262)) {
if(R.isPyretTrue(if_DASH_812810)) {
var $z29512952 = D;
var $f29572958 = function(_) {
return R.isFunction(if_helper4732959)?if_helper4732959.app(nothing10):R.ffi.throwNonFunApp(L[266],if_helper4732959,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z29512952 = $f29572958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29572958,
"from":L[266]});
}
} catch($e29492950) {
if(R.isCont($e29492950)) {
var $ss29532954 = {"from":L[266],
"go":function(cont_tail_app6002960) {
return $Hcont_tail_app11292961(cont_tail_app6002960);
}};
$e29492950.stack[R.EXN_STACKHEIGHT++] = $ss29532954;
}
if(R.isPyretException($e29492950)) {
$e29492950.pyretStack.push(L[266]);
}
throw $e29492950;
}
var $ret29552956 = $Hcont_tail_app11292961($z29512952);
++R.GAS;
return $ret29552956;
} else {
var first1813258 = G(items1802799,"first",L[309]);
var i1823001 = G(first1813258,"indent",L[308]);
var m1833043 = G(first1813258,"is-flat",L[307]);
var cases_DASH_val803257 = G(first1813258,"d",L[306]);
var anf_fun4782972 = G(cases_DASH_val803257,"_match",L[267]);
var anf_obj4812978 = R.makeFunction(function($underscore1843242,$underscore1853243) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[304],2,arguments);
}
var anf_arg4803254 = G(items1802799,"rest",L[305]);
var $z32463247 = D;
var $f32523253 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg4803254):R.ffi.throwNonFunApp(L[304],process1702781.$var,[column1792798,anf_arg4803254]);
};
try {
if(--R.GAS > 0) {
$z32463247 = $f32523253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32523253,
"from":L[304]});
}
} catch($e32443245) {
if(R.isCont($e32443245)) {
var $ss32483249 = {"from":L[304],
"go":function(ann_DASH_check_DASH_temp4793255) {
return $Hann_DASH_check_DASH_temp11303256(ann_DASH_check_DASH_temp4793255);
}};
$e32443245.stack[R.EXN_STACKHEIGHT++] = $ss32483249;
}
if(R.isPyretException($e32443245)) {
$e32443245.pyretStack.push(L[304]);
}
throw $e32443245;
}
var $ret32503251 = $Hann_DASH_check_DASH_temp11303256($z32463247);
++R.GAS;
return $ret32503251;
});
var anf_obj4892979 = R.makeFunction(function(fst1863225,snd1873226,$underscore1883227,$underscore1893228) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[301],4,arguments);
}
var anf_fun4833240 = G(list1948,"make",L[303]);
var $z32313232 = D;
var $f32373238 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(i1823001,m1833043,fst1863225):R.ffi.throwNonFunApp(L[302],item912759.$var,[i1823001,m1833043,fst1863225]);
};
try {
if(--R.GAS > 0) {
$z32313232 = $f32373238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32373238,
"from":L[302]});
}
} catch($e32293230) {
if(R.isCont($e32293230)) {
var $ss32333234 = {"from":L[302],
"go":function(anf_array_val4843239) {
return $Hanf_array_val11353241(anf_array_val4843239,anf_fun4833240,column1792798,i1823001,item912759,items1802799,m1833043,process1702781,snd1873226,_plus8);
}};
$e32293230.stack[R.EXN_STACKHEIGHT++] = $ss32333234;
}
if(R.isPyretException($e32293230)) {
$e32293230.pyretStack.push(L[302]);
}
throw $e32293230;
}
var $ret32353236 = $Hanf_array_val11353241($z32313232,anf_fun4833240,column1792798,i1823001,item912759,items1802799,m1833043,process1702781,snd1873226,_plus8);
++R.GAS;
return $ret32353236;
});
var anf_obj4932980 = R.makeFunction(function(s1903210,flat_DASH_width1913211,$underscore1923212) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[299],3,arguments);
}
var $z32153216 = D;
var $f32213222 = function(_) {
return R.isFunction(emit_DASH_text1662773.$var)?emit_DASH_text1662773.$var.app(s1903210):R.ffi.throwNonFunApp(L[300],emit_DASH_text1662773.$var,[s1903210]);
};
try {
if(--R.GAS > 0) {
$z32153216 = $f32213222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32213222,
"from":L[300]});
}
} catch($e32133214) {
if(R.isCont($e32133214)) {
var $ss32173218 = {"from":L[300],
"go":function(anf_begin_app_dropped11363223) {
return $Hanf_begin_app_dropped11393224(anf_begin_app_dropped11363223,column1792798,flat_DASH_width1913211,items1802799,process1702781,_plus8);
}};
$e32133214.stack[R.EXN_STACKHEIGHT++] = $ss32173218;
}
if(R.isPyretException($e32133214)) {
$e32133214.pyretStack.push(L[300]);
}
throw $e32133214;
}
var $ret32193220 = $Hanf_begin_app_dropped11393224($z32153216,column1792798,flat_DASH_width1913211,items1802799,process1702781,_plus8);
++R.GAS;
return $ret32193220;
});
var anf_obj4972981 = R.makeFunction(function(n1933195,$underscore1943196,$underscore1953197) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[297],3,arguments);
}
var $z32003201 = D;
var $f32063207 = function(_) {
return R.isFunction(emit_DASH_spaces1672775.$var)?emit_DASH_spaces1672775.$var.app(n1933195):R.ffi.throwNonFunApp(L[298],emit_DASH_spaces1672775.$var,[n1933195]);
};
try {
if(--R.GAS > 0) {
$z32003201 = $f32063207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32063207,
"from":L[298]});
}
} catch($e31983199) {
if(R.isCont($e31983199)) {
var $ss32023203 = {"from":L[298],
"go":function(anf_begin_app_dropped11403208) {
return $Hanf_begin_app_dropped11433209(anf_begin_app_dropped11403208,column1792798,items1802799,n1933195,process1702781,_plus8);
}};
$e31983199.stack[R.EXN_STACKHEIGHT++] = $ss32023203;
}
if(R.isPyretException($e31983199)) {
$e31983199.pyretStack.push(L[298]);
}
throw $e31983199;
}
var $ret32043205 = $Hanf_begin_app_dropped11433209($z32003201,column1792798,items1802799,n1933195,process1702781,_plus8);
++R.GAS;
return $ret32043205;
});
var anf_obj5042982 = R.makeFunction(function(d1963179,$underscore1973180,$underscore1983181) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[294],3,arguments);
}
var anf_fun4993193 = G(list1948,"make",L[296]);
var $z31843185 = D;
var $f31903191 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(column1792798,m1833043,d1963179):R.ffi.throwNonFunApp(L[295],item912759.$var,[column1792798,m1833043,d1963179]);
};
try {
if(--R.GAS > 0) {
$z31843185 = $f31903191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31903191,
"from":L[295]});
}
} catch($e31823183) {
if(R.isCont($e31823183)) {
var $ss31863187 = {"from":L[295],
"go":function(anf_array_val5003192) {
return $Hanf_array_val11473194(anf_array_val5003192,anf_fun4993193,column1792798,items1802799,process1702781,_plus8);
}};
$e31823183.stack[R.EXN_STACKHEIGHT++] = $ss31863187;
}
if(R.isPyretException($e31823183)) {
$e31823183.pyretStack.push(L[295]);
}
throw $e31823183;
}
var $ret31883189 = $Hanf_array_val11473194($z31843185,anf_fun4993193,column1792798,items1802799,process1702781,_plus8);
++R.GAS;
return $ret31883189;
});
var anf_obj5122983 = R.makeFunction(function(n1993162,d2003163,$underscore2013164,$underscore2023165) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[291],4,arguments);
}
var anf_fun5063177 = G(list1948,"make",L[293]);
var $z31683169 = D;
var $f31743175 = function(_) {
return R.isFunction(_plus8)?_plus8.app(i1823001,n1993162):R.ffi.throwNonFunApp(L[292],_plus8,[i1823001,n1993162]);
};
try {
if(--R.GAS > 0) {
$z31683169 = $f31743175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31743175,
"from":L[292]});
}
} catch($e31663167) {
if(R.isCont($e31663167)) {
var $ss31703171 = {"from":L[292],
"go":function(anf_arg5073176) {
return $Hanf_arg11523178(anf_arg5073176,anf_fun5063177,column1792798,d2003163,item912759,items1802799,m1833043,process1702781,_plus8);
}};
$e31663167.stack[R.EXN_STACKHEIGHT++] = $ss31703171;
}
if(R.isPyretException($e31663167)) {
$e31663167.pyretStack.push(L[292]);
}
throw $e31663167;
}
var $ret31723173 = $Hanf_arg11523178($z31683169,anf_fun5063177,column1792798,d2003163,item912759,items1802799,m1833043,process1702781,_plus8);
++R.GAS;
return $ret31723173;
});
var anf_obj5242984 = R.makeFunction(function($underscore2033128,$underscore2043129) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[287],2,arguments);
}
var if_DASH_743155 = m1833043;
var if_helper5143141 = R.makeFunction(function(if_helper_arg5153160) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[290],1,arguments);
}
var ann_DASH_check_DASH_temp5133161 = if_helper_arg5153160;
return ann_DASH_check_DASH_temp5133161;
});
var anf_if5183159 = R.isBoolean(if_DASH_743155);
if(R.isPyretTrue(anf_if5183159)) {
if(R.isPyretTrue(if_DASH_743155)) {
var $z31323133 = D;
var $f31383139 = function(_) {
return R.isFunction(raise11)?raise11.app(("Impossible for HardLine to be flat")):R.ffi.throwNonFunApp(L[288],raise11,[("Impossible for HardLine to be flat")]);
};
try {
if(--R.GAS > 0) {
$z31323133 = $f31383139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31383139,
"from":L[288]});
}
} catch($e31303131) {
if(R.isCont($e31303131)) {
var $ss31343135 = {"from":L[288],
"go":function(cont_tail_arg5223140) {
return $Hcont_tail_arg11533142(cont_tail_arg5223140,if_helper5143141);
}};
$e31303131.stack[R.EXN_STACKHEIGHT++] = $ss31343135;
}
if(R.isPyretException($e31303131)) {
$e31303131.pyretStack.push(L[288]);
}
throw $e31303131;
}
var $ret31363137 = $Hcont_tail_arg11533142($z31323133,if_helper5143141);
++R.GAS;
return $ret31363137;
} else {
var $z31453146 = D;
var $f31513152 = function(_) {
return R.isFunction(emit_DASH_newline1682777.$var)?emit_DASH_newline1682777.$var.app(i1823001):R.ffi.throwNonFunApp(L[289],emit_DASH_newline1682777.$var,[i1823001]);
};
try {
if(--R.GAS > 0) {
$z31453146 = $f31513152();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31513152,
"from":L[289]});
}
} catch($e31433144) {
if(R.isCont($e31433144)) {
var $ss31473148 = {"from":L[289],
"go":function(anf_begin_app_dropped11543153) {
return $Hanf_begin_app_dropped11563154(anf_begin_app_dropped11543153,i1823001,if_helper5143141,items1802799,process1702781);
}};
$e31433144.stack[R.EXN_STACKHEIGHT++] = $ss31473148;
}
if(R.isPyretException($e31433144)) {
$e31433144.pyretStack.push(L[289]);
}
throw $e31433144;
}
var $ret31493150 = $Hanf_begin_app_dropped11563154($z31453146,i1823001,if_helper5143141,items1802799,process1702781);
++R.GAS;
return $ret31493150;
}
} else {
var cont_tail_arg5163158 = R.throwNonBooleanCondition(L[290],("if"),if_DASH_743155);
if(--R.GAS > 0) {
$z31563157 = R.isFunction(if_helper5143141)?if_helper5143141.app(cont_tail_arg5163158):R.ffi.throwNonFunApp(L[290],if_helper5143141,[cont_tail_arg5163158]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5143141)?if_helper5143141.app(cont_tail_arg5163158):R.ffi.throwNonFunApp(L[290],if_helper5143141,[cont_tail_arg5163158]);
},
"from":L[290]});
}
++R.GAS;
return $z31563157;
}
});
var anf_obj5382985 = R.makeFunction(function(flat2053080,vert2063081,$underscore2073082,$underscore2083083) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[281],4,arguments);
}
var anf_fun5263126 = G(list1948,"make",L[286]);
var if_DASH_753109 = m1833043;
var if_helper5273094 = R.makeFunction(function(if_helper_arg5283114) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[284],1,arguments);
}
var $z31173118 = D;
var $f31233124 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(i1823001,m1833043,if_helper_arg5283114):R.ffi.throwNonFunApp(L[285],item912759.$var,[i1823001,m1833043,if_helper_arg5283114]);
};
try {
if(--R.GAS > 0) {
$z31173118 = $f31233124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31233124,
"from":L[285]});
}
} catch($e31153116) {
if(R.isCont($e31153116)) {
var $ss31193120 = {"from":L[285],
"go":function(anf_array_val5293125) {
return $Hanf_array_val11603127(anf_array_val5293125,anf_fun5263126,column1792798,items1802799,process1702781,_plus8);
}};
$e31153116.stack[R.EXN_STACKHEIGHT++] = $ss31193120;
}
if(R.isPyretException($e31153116)) {
$e31153116.pyretStack.push(L[285]);
}
throw $e31153116;
}
var $ret31213122 = $Hanf_array_val11603127($z31173118,anf_fun5263126,column1792798,items1802799,process1702781,_plus8);
++R.GAS;
return $ret31213122;
});
var anf_if5353113 = R.isBoolean(if_DASH_753109);
if(R.isPyretTrue(anf_if5353113)) {
if(R.isPyretTrue(if_DASH_753109)) {
var $z30863087 = D;
var $f30923093 = function(_) {
return R.isFunction(if_helper5273094)?if_helper5273094.app(flat2053080):R.ffi.throwNonFunApp(L[282],if_helper5273094,[flat2053080]);
};
try {
if(--R.GAS > 0) {
$z30863087 = $f30923093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30923093,
"from":L[282]});
}
} catch($e30843085) {
if(R.isCont($e30843085)) {
var $ss30883089 = {"from":L[282],
"go":function(cont_tail_app5373095) {
return $Hcont_tail_app11613096(cont_tail_app5373095);
}};
$e30843085.stack[R.EXN_STACKHEIGHT++] = $ss30883089;
}
if(R.isPyretException($e30843085)) {
$e30843085.pyretStack.push(L[282]);
}
throw $e30843085;
}
var $ret30903091 = $Hcont_tail_app11613096($z30863087);
++R.GAS;
return $ret30903091;
} else {
var $z30993100 = D;
var $f31053106 = function(_) {
return R.isFunction(if_helper5273094)?if_helper5273094.app(vert2063081):R.ffi.throwNonFunApp(L[283],if_helper5273094,[vert2063081]);
};
try {
if(--R.GAS > 0) {
$z30993100 = $f31053106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31053106,
"from":L[283]});
}
} catch($e30973098) {
if(R.isCont($e30973098)) {
var $ss31013102 = {"from":L[283],
"go":function(cont_tail_app5363107) {
return $Hcont_tail_app11623108(cont_tail_app5363107);
}};
$e30973098.stack[R.EXN_STACKHEIGHT++] = $ss31013102;
}
if(R.isPyretException($e30973098)) {
$e30973098.pyretStack.push(L[283]);
}
throw $e30973098;
}
var $ret31033104 = $Hcont_tail_app11623108($z30993100);
++R.GAS;
return $ret31033104;
}
} else {
var cont_tail_arg5333112 = R.throwNonBooleanCondition(L[284],("if"),if_DASH_753109);
if(--R.GAS > 0) {
$z31103111 = R.isFunction(if_helper5273094)?if_helper5273094.app(cont_tail_arg5333112):R.ffi.throwNonFunApp(L[284],if_helper5273094,[cont_tail_arg5333112]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5273094)?if_helper5273094.app(cont_tail_arg5333112):R.ffi.throwNonFunApp(L[284],if_helper5273094,[cont_tail_arg5333112]);
},
"from":L[284]});
}
++R.GAS;
return $z31103111;
}
});
var anf_obj5522986 = R.makeFunction(function(n2093044,$underscore2103045,$underscore2113046) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[276],3,arguments);
}
var if_DASH_763073 = m1833043;
var if_helper5403059 = R.makeFunction(function(if_helper_arg5413078) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[280],1,arguments);
}
var ann_DASH_check_DASH_temp5393079 = if_helper_arg5413078;
return ann_DASH_check_DASH_temp5393079;
});
var anf_if5443077 = R.isBoolean(if_DASH_763073);
if(R.isPyretTrue(anf_if5443077)) {
if(R.isPyretTrue(if_DASH_763073)) {
var anf_arg5493057 = G(items1802799,"rest",L[278]);
var $z30493050 = D;
var $f30553056 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg5493057):R.ffi.throwNonFunApp(L[277],process1702781.$var,[column1792798,anf_arg5493057]);
};
try {
if(--R.GAS > 0) {
$z30493050 = $f30553056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30553056,
"from":L[277]});
}
} catch($e30473048) {
if(R.isCont($e30473048)) {
var $ss30513052 = {"from":L[277],
"go":function(cont_tail_arg5503058) {
return $Hcont_tail_arg11633060(cont_tail_arg5503058,if_helper5403059);
}};
$e30473048.stack[R.EXN_STACKHEIGHT++] = $ss30513052;
}
if(R.isPyretException($e30473048)) {
$e30473048.pyretStack.push(L[277]);
}
throw $e30473048;
}
var $ret30533054 = $Hcont_tail_arg11633060($z30493050,if_helper5403059);
++R.GAS;
return $ret30533054;
} else {
var $z30633064 = D;
var $f30693070 = function(_) {
return R.isFunction(emit_DASH_spaces1672775.$var)?emit_DASH_spaces1672775.$var.app(n2093044):R.ffi.throwNonFunApp(L[279],emit_DASH_spaces1672775.$var,[n2093044]);
};
try {
if(--R.GAS > 0) {
$z30633064 = $f30693070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30693070,
"from":L[279]});
}
} catch($e30613062) {
if(R.isCont($e30613062)) {
var $ss30653066 = {"from":L[279],
"go":function(anf_begin_app_dropped11643071) {
return $Hanf_begin_app_dropped11673072(anf_begin_app_dropped11643071,column1792798,if_helper5403059,items1802799,n2093044,process1702781,_plus8);
}};
$e30613062.stack[R.EXN_STACKHEIGHT++] = $ss30653066;
}
if(R.isPyretException($e30613062)) {
$e30613062.pyretStack.push(L[279]);
}
throw $e30613062;
}
var $ret30673068 = $Hanf_begin_app_dropped11673072($z30633064,column1792798,if_helper5403059,items1802799,n2093044,process1702781,_plus8);
++R.GAS;
return $ret30673068;
}
} else {
var cont_tail_arg5423076 = R.throwNonBooleanCondition(L[280],("if"),if_DASH_763073);
if(--R.GAS > 0) {
$z30743075 = R.isFunction(if_helper5403059)?if_helper5403059.app(cont_tail_arg5423076):R.ffi.throwNonFunApp(L[280],if_helper5403059,[cont_tail_arg5423076]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5403059)?if_helper5403059.app(cont_tail_arg5423076):R.ffi.throwNonFunApp(L[280],if_helper5403059,[cont_tail_arg5423076]);
},
"from":L[280]});
}
++R.GAS;
return $z30743075;
}
});
var anf_obj5942987 = R.makeFunction(function(d2122988,flat_DASH_width2132989,has_DASH_hardline2142990) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[268],3,arguments);
}
var if_DASH_793036 = m1833043;
var if_helper5543004 = R.makeFunction(function(if_helper_arg5553041) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[275],1,arguments);
}
var ann_DASH_check_DASH_temp5533042 = if_helper_arg5553041;
return ann_DASH_check_DASH_temp5533042;
});
var anf_if5583040 = R.isBoolean(if_DASH_793036);
if(R.isPyretTrue(anf_if5583040)) {
if(R.isPyretTrue(if_DASH_793036)) {
var anf_fun5873003 = G(list1948,"make",L[270]);
var $z29932994 = D;
var $f29993000 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(i1823001,(true),d2122988):R.ffi.throwNonFunApp(L[269],item912759.$var,[i1823001,(true),d2122988]);
};
try {
if(--R.GAS > 0) {
$z29932994 = $f29993000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29993000,
"from":L[269]});
}
} catch($e29912992) {
if(R.isCont($e29912992)) {
var $ss29952996 = {"from":L[269],
"go":function(anf_array_val5883002) {
return $Hanf_array_val11713005(anf_array_val5883002,anf_fun5873003,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
}};
$e29912992.stack[R.EXN_STACKHEIGHT++] = $ss29952996;
}
if(R.isPyretException($e29912992)) {
$e29912992.pyretStack.push(L[269]);
}
throw $e29912992;
}
var $ret29972998 = $Hanf_array_val11713005($z29932994,anf_fun5873003,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
++R.GAS;
return $ret29972998;
} else {
var if_DASH_783031 = has_DASH_hardline2142990;
var anf_if5613035 = R.isBoolean(if_DASH_783031);
if(R.isPyretTrue(anf_if5613035)) {
if(R.isPyretTrue(if_DASH_783031)) {
var anf_fun5803017 = G(list1948,"make",L[272]);
var $z30083009 = D;
var $f30143015 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(i1823001,(false),d2122988):R.ffi.throwNonFunApp(L[271],item912759.$var,[i1823001,(false),d2122988]);
};
try {
if(--R.GAS > 0) {
$z30083009 = $f30143015();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30143015,
"from":L[271]});
}
} catch($e30063007) {
if(R.isCont($e30063007)) {
var $ss30103011 = {"from":L[271],
"go":function(anf_array_val5813016) {
return $Hanf_array_val11753018(anf_array_val5813016,anf_fun5803017,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
}};
$e30063007.stack[R.EXN_STACKHEIGHT++] = $ss30103011;
}
if(R.isPyretException($e30063007)) {
$e30063007.pyretStack.push(L[271]);
}
throw $e30063007;
}
var $ret30123013 = $Hanf_array_val11753018($z30083009,anf_fun5803017,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
++R.GAS;
return $ret30123013;
} else {
var $z30213022 = D;
var $f30273028 = function(_) {
return R.isFunction(_minus7)?_minus7.app(width1632760,column1792798):R.ffi.throwNonFunApp(L[273],_minus7,[width1632760,column1792798]);
};
try {
if(--R.GAS > 0) {
$z30213022 = $f30273028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30273028,
"from":L[273]});
}
} catch($e30193020) {
if(R.isCont($e30193020)) {
var $ss30233024 = {"from":L[273],
"go":function(anf_arg5623029) {
return $Hanf_arg11853030(anf_arg5623029,column1792798,d2122988,flat_DASH_width2132989,i1823001,if_helper5543004,item912759,items1802799,list1948,process1702781,_greaterequal6,_plus8);
}};
$e30193020.stack[R.EXN_STACKHEIGHT++] = $ss30233024;
}
if(R.isPyretException($e30193020)) {
$e30193020.pyretStack.push(L[273]);
}
throw $e30193020;
}
var $ret30253026 = $Hanf_arg11853030($z30213022,column1792798,d2122988,flat_DASH_width2132989,i1823001,if_helper5543004,item912759,items1802799,list1948,process1702781,_greaterequal6,_plus8);
++R.GAS;
return $ret30253026;
}
} else {
var cont_tail_arg5593034 = R.throwNonBooleanCondition(L[274],("if"),if_DASH_783031);
if(--R.GAS > 0) {
$z30323033 = R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5593034):R.ffi.throwNonFunApp(L[274],if_helper5543004,[cont_tail_arg5593034]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5593034):R.ffi.throwNonFunApp(L[274],if_helper5543004,[cont_tail_arg5593034]);
},
"from":L[274]});
}
++R.GAS;
return $z30323033;
}
}
} else {
var cont_tail_arg5563039 = R.throwNonBooleanCondition(L[275],("if"),if_DASH_793036);
if(--R.GAS > 0) {
$z30373038 = R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5563039):R.ffi.throwNonFunApp(L[275],if_helper5543004,[cont_tail_arg5563039]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5563039):R.ffi.throwNonFunApp(L[275],if_helper5543004,[cont_tail_arg5563039]);
},
"from":L[275]});
}
++R.GAS;
return $z30373038;
}
});
var anf_arg5952973 = R.makeObject({"mt-doc":anf_obj4812978,
"concat":anf_obj4892979,
"str":anf_obj4932980,
"blank":anf_obj4972981,
"align":anf_obj5042982,
"nest":anf_obj5122983,
"hardline":anf_obj5242984,
"if-flat":anf_obj5382985,
"align-spaces":anf_obj5522986,
"group":anf_obj5942987});
var anf_arg5972974 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[267],0,arguments);
}
var ann_DASH_check_DASH_temp5962977 = R.throwNoBranchesMatched(L[267],("cases"));
return ann_DASH_check_DASH_temp5962977;
});
var $z29642965 = D;
var $f29702971 = function(_) {
return R.isFunction(anf_fun4782972)?anf_fun4782972.app(anf_arg5952973,anf_arg5972974):R.ffi.throwNonFunApp(L[267],anf_fun4782972,[anf_arg5952973,anf_arg5972974]);
};
try {
if(--R.GAS > 0) {
$z29642965 = $f29702971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29702971,
"from":L[267]});
}
} catch($e29622963) {
if(R.isCont($e29622963)) {
var $ss29662967 = {"from":L[267],
"go":function(cont_tail_arg5982975) {
return $Hcont_tail_arg11862976(cont_tail_arg5982975,if_helper4732959);
}};
$e29622963.stack[R.EXN_STACKHEIGHT++] = $ss29662967;
}
if(R.isPyretException($e29622963)) {
$e29622963.pyretStack.push(L[267]);
}
throw $e29622963;
}
var $ret29682969 = $Hcont_tail_arg11862976($z29642965,if_helper4732959);
++R.GAS;
return $ret29682969;
}
} else {
var cont_tail_arg4753261 = R.throwNonBooleanCondition(L[244],("if"),if_DASH_812810);
if(--R.GAS > 0) {
$z32593260 = R.isFunction(if_helper4732959)?if_helper4732959.app(cont_tail_arg4753261):R.ffi.throwNonFunApp(L[244],if_helper4732959,[cont_tail_arg4753261]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper4732959)?if_helper4732959.app(cont_tail_arg4753261):R.ffi.throwNonFunApp(L[244],if_helper4732959,[cont_tail_arg4753261]);
},
"from":L[244]});
}
++R.GAS;
return $z32593260;
}
};
var $Hcont_tail_app11292961 = function(cont_tail_app6002960) {
return cont_tail_app6002960;
};
var $Hcont_tail_arg11862976 = function(cont_tail_arg5982975,if_helper4732959) {
if(--R.GAS > 0) {
$z32653266 = R.isFunction(if_helper4732959)?if_helper4732959.app(cont_tail_arg5982975):R.ffi.throwNonFunApp(L[267],if_helper4732959,[cont_tail_arg5982975]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper4732959)?if_helper4732959.app(cont_tail_arg5982975):R.ffi.throwNonFunApp(L[267],if_helper4732959,[cont_tail_arg5982975]);
},
"from":L[267]});
}
++R.GAS;
return $z32653266;
};
var $Hanf_array_val11713005 = function(anf_array_val5883002,anf_fun5873003,column1792798,if_helper5543004,items1802799,process1702781,_plus8) {
var $z32693270 = D;
var $f32753276 = function(_) {
return R.isFunction(anf_fun5873003)?anf_fun5873003.app([anf_array_val5883002]):R.ffi.throwNonFunApp(L[270],anf_fun5873003,[[anf_array_val5883002]]);
};
try {
if(--R.GAS > 0) {
$z32693270 = $f32753276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32753276,
"from":L[270]});
}
} catch($e32673268) {
if(R.isCont($e32673268)) {
var $ss32713272 = {"from":L[270],
"go":function(anf_arg5893277) {
return $Hanf_arg11703278(anf_arg5893277,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
}};
$e32673268.stack[R.EXN_STACKHEIGHT++] = $ss32713272;
}
if(R.isPyretException($e32673268)) {
$e32673268.pyretStack.push(L[270]);
}
throw $e32673268;
}
var $ret32733274 = $Hanf_arg11703278($z32693270,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
++R.GAS;
return $ret32733274;
};
var $Hanf_arg11703278 = function(anf_arg5893277,column1792798,if_helper5543004,items1802799,process1702781,_plus8) {
var anf_arg5903289 = G(items1802799,"rest",L[312]);
var $z32813282 = D;
var $f32873288 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg5893277,anf_arg5903289):R.ffi.throwNonFunApp(L[311],_plus8,[anf_arg5893277,anf_arg5903289]);
};
try {
if(--R.GAS > 0) {
$z32813282 = $f32873288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32873288,
"from":L[311]});
}
} catch($e32793280) {
if(R.isCont($e32793280)) {
var $ss32833284 = {"from":L[311],
"go":function(anf_arg5913290) {
return $Hanf_arg11693291(anf_arg5913290,column1792798,if_helper5543004,process1702781);
}};
$e32793280.stack[R.EXN_STACKHEIGHT++] = $ss32833284;
}
if(R.isPyretException($e32793280)) {
$e32793280.pyretStack.push(L[311]);
}
throw $e32793280;
}
var $ret32853286 = $Hanf_arg11693291($z32813282,column1792798,if_helper5543004,process1702781);
++R.GAS;
return $ret32853286;
};
var $Hanf_arg11693291 = function(anf_arg5913290,column1792798,if_helper5543004,process1702781) {
var $z32943295 = D;
var $f33003301 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg5913290):R.ffi.throwNonFunApp(L[313],process1702781.$var,[column1792798,anf_arg5913290]);
};
try {
if(--R.GAS > 0) {
$z32943295 = $f33003301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33003301,
"from":L[313]});
}
} catch($e32923293) {
if(R.isCont($e32923293)) {
var $ss32963297 = {"from":L[313],
"go":function(cont_tail_arg5923302) {
return $Hcont_tail_arg11683303(cont_tail_arg5923302,if_helper5543004);
}};
$e32923293.stack[R.EXN_STACKHEIGHT++] = $ss32963297;
}
if(R.isPyretException($e32923293)) {
$e32923293.pyretStack.push(L[313]);
}
throw $e32923293;
}
var $ret32983299 = $Hcont_tail_arg11683303($z32943295,if_helper5543004);
++R.GAS;
return $ret32983299;
};
var $Hcont_tail_arg11683303 = function(cont_tail_arg5923302,if_helper5543004) {
if(--R.GAS > 0) {
$z33043305 = R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5923302):R.ffi.throwNonFunApp(L[313],if_helper5543004,[cont_tail_arg5923302]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5923302):R.ffi.throwNonFunApp(L[313],if_helper5543004,[cont_tail_arg5923302]);
},
"from":L[313]});
}
++R.GAS;
return $z33043305;
};
var $Hanf_array_val11753018 = function(anf_array_val5813016,anf_fun5803017,column1792798,if_helper5543004,items1802799,process1702781,_plus8) {
var $z33083309 = D;
var $f33143315 = function(_) {
return R.isFunction(anf_fun5803017)?anf_fun5803017.app([anf_array_val5813016]):R.ffi.throwNonFunApp(L[272],anf_fun5803017,[[anf_array_val5813016]]);
};
try {
if(--R.GAS > 0) {
$z33083309 = $f33143315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33143315,
"from":L[272]});
}
} catch($e33063307) {
if(R.isCont($e33063307)) {
var $ss33103311 = {"from":L[272],
"go":function(anf_arg5823316) {
return $Hanf_arg11743317(anf_arg5823316,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
}};
$e33063307.stack[R.EXN_STACKHEIGHT++] = $ss33103311;
}
if(R.isPyretException($e33063307)) {
$e33063307.pyretStack.push(L[272]);
}
throw $e33063307;
}
var $ret33123313 = $Hanf_arg11743317($z33083309,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
++R.GAS;
return $ret33123313;
};
var $Hanf_arg11743317 = function(anf_arg5823316,column1792798,if_helper5543004,items1802799,process1702781,_plus8) {
var anf_arg5833328 = G(items1802799,"rest",L[315]);
var $z33203321 = D;
var $f33263327 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg5823316,anf_arg5833328):R.ffi.throwNonFunApp(L[314],_plus8,[anf_arg5823316,anf_arg5833328]);
};
try {
if(--R.GAS > 0) {
$z33203321 = $f33263327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33263327,
"from":L[314]});
}
} catch($e33183319) {
if(R.isCont($e33183319)) {
var $ss33223323 = {"from":L[314],
"go":function(anf_arg5843329) {
return $Hanf_arg11733330(anf_arg5843329,column1792798,if_helper5543004,process1702781);
}};
$e33183319.stack[R.EXN_STACKHEIGHT++] = $ss33223323;
}
if(R.isPyretException($e33183319)) {
$e33183319.pyretStack.push(L[314]);
}
throw $e33183319;
}
var $ret33243325 = $Hanf_arg11733330($z33203321,column1792798,if_helper5543004,process1702781);
++R.GAS;
return $ret33243325;
};
var $Hanf_arg11733330 = function(anf_arg5843329,column1792798,if_helper5543004,process1702781) {
var $z33333334 = D;
var $f33393340 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg5843329):R.ffi.throwNonFunApp(L[316],process1702781.$var,[column1792798,anf_arg5843329]);
};
try {
if(--R.GAS > 0) {
$z33333334 = $f33393340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33393340,
"from":L[316]});
}
} catch($e33313332) {
if(R.isCont($e33313332)) {
var $ss33353336 = {"from":L[316],
"go":function(cont_tail_arg5853341) {
return $Hcont_tail_arg11723342(cont_tail_arg5853341,if_helper5543004);
}};
$e33313332.stack[R.EXN_STACKHEIGHT++] = $ss33353336;
}
if(R.isPyretException($e33313332)) {
$e33313332.pyretStack.push(L[316]);
}
throw $e33313332;
}
var $ret33373338 = $Hcont_tail_arg11723342($z33333334,if_helper5543004);
++R.GAS;
return $ret33373338;
};
var $Hcont_tail_arg11723342 = function(cont_tail_arg5853341,if_helper5543004) {
if(--R.GAS > 0) {
$z33433344 = R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5853341):R.ffi.throwNonFunApp(L[316],if_helper5543004,[cont_tail_arg5853341]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5853341):R.ffi.throwNonFunApp(L[316],if_helper5543004,[cont_tail_arg5853341]);
},
"from":L[316]});
}
++R.GAS;
return $z33433344;
};
var $Hanf_arg11853030 = function(anf_arg5623029,column1792798,d2122988,flat_DASH_width2132989,i1823001,if_helper5543004,item912759,items1802799,list1948,process1702781,_greaterequal6,_plus8) {
var $z33473348 = D;
var $f33533354 = function(_) {
return R.isFunction(_greaterequal6)?_greaterequal6.app(anf_arg5623029,flat_DASH_width2132989):R.ffi.throwNonFunApp(L[317],_greaterequal6,[anf_arg5623029,flat_DASH_width2132989]);
};
try {
if(--R.GAS > 0) {
$z33473348 = $f33533354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33533354,
"from":L[317]});
}
} catch($e33453346) {
if(R.isCont($e33453346)) {
var $ss33493350 = {"from":L[317],
"go":function(if_DASH_773355) {
return $Hif_DASH_11843356(if_DASH_773355,column1792798,d2122988,i1823001,if_helper5543004,item912759,items1802799,list1948,process1702781,_plus8);
}};
$e33453346.stack[R.EXN_STACKHEIGHT++] = $ss33493350;
}
if(R.isPyretException($e33453346)) {
$e33453346.pyretStack.push(L[317]);
}
throw $e33453346;
}
var $ret33513352 = $Hif_DASH_11843356($z33473348,column1792798,d2122988,i1823001,if_helper5543004,item912759,items1802799,list1948,process1702781,_plus8);
++R.GAS;
return $ret33513352;
};
var $Hif_DASH_11843356 = function(if_DASH_773355,column1792798,d2122988,i1823001,if_helper5543004,item912759,items1802799,list1948,process1702781,_plus8) {
var anf_if5653386 = R.isBoolean(if_DASH_773355);
if(R.isPyretTrue(anf_if5653386)) {
if(R.isPyretTrue(if_DASH_773355)) {
var anf_fun5733368 = G(list1948,"make",L[319]);
var $z33593360 = D;
var $f33653366 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(i1823001,(true),d2122988):R.ffi.throwNonFunApp(L[318],item912759.$var,[i1823001,(true),d2122988]);
};
try {
if(--R.GAS > 0) {
$z33593360 = $f33653366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33653366,
"from":L[318]});
}
} catch($e33573358) {
if(R.isCont($e33573358)) {
var $ss33613362 = {"from":L[318],
"go":function(anf_array_val5743367) {
return $Hanf_array_val11793369(anf_array_val5743367,anf_fun5733368,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
}};
$e33573358.stack[R.EXN_STACKHEIGHT++] = $ss33613362;
}
if(R.isPyretException($e33573358)) {
$e33573358.pyretStack.push(L[318]);
}
throw $e33573358;
}
var $ret33633364 = $Hanf_array_val11793369($z33593360,anf_fun5733368,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
++R.GAS;
return $ret33633364;
} else {
var anf_fun5663381 = G(list1948,"make",L[321]);
var $z33723373 = D;
var $f33783379 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(i1823001,(false),d2122988):R.ffi.throwNonFunApp(L[320],item912759.$var,[i1823001,(false),d2122988]);
};
try {
if(--R.GAS > 0) {
$z33723373 = $f33783379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33783379,
"from":L[320]});
}
} catch($e33703371) {
if(R.isCont($e33703371)) {
var $ss33743375 = {"from":L[320],
"go":function(anf_array_val5673380) {
return $Hanf_array_val11833382(anf_array_val5673380,anf_fun5663381,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
}};
$e33703371.stack[R.EXN_STACKHEIGHT++] = $ss33743375;
}
if(R.isPyretException($e33703371)) {
$e33703371.pyretStack.push(L[320]);
}
throw $e33703371;
}
var $ret33763377 = $Hanf_array_val11833382($z33723373,anf_fun5663381,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
++R.GAS;
return $ret33763377;
}
} else {
var cont_tail_arg5633385 = R.throwNonBooleanCondition(L[322],("if"),if_DASH_773355);
if(--R.GAS > 0) {
$z33833384 = R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5633385):R.ffi.throwNonFunApp(L[322],if_helper5543004,[cont_tail_arg5633385]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5633385):R.ffi.throwNonFunApp(L[322],if_helper5543004,[cont_tail_arg5633385]);
},
"from":L[322]});
}
++R.GAS;
return $z33833384;
}
};
var $Hanf_array_val11793369 = function(anf_array_val5743367,anf_fun5733368,column1792798,if_helper5543004,items1802799,process1702781,_plus8) {
var $z33893390 = D;
var $f33953396 = function(_) {
return R.isFunction(anf_fun5733368)?anf_fun5733368.app([anf_array_val5743367]):R.ffi.throwNonFunApp(L[319],anf_fun5733368,[[anf_array_val5743367]]);
};
try {
if(--R.GAS > 0) {
$z33893390 = $f33953396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33953396,
"from":L[319]});
}
} catch($e33873388) {
if(R.isCont($e33873388)) {
var $ss33913392 = {"from":L[319],
"go":function(anf_arg5753397) {
return $Hanf_arg11783398(anf_arg5753397,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
}};
$e33873388.stack[R.EXN_STACKHEIGHT++] = $ss33913392;
}
if(R.isPyretException($e33873388)) {
$e33873388.pyretStack.push(L[319]);
}
throw $e33873388;
}
var $ret33933394 = $Hanf_arg11783398($z33893390,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
++R.GAS;
return $ret33933394;
};
var $Hanf_arg11783398 = function(anf_arg5753397,column1792798,if_helper5543004,items1802799,process1702781,_plus8) {
var anf_arg5763409 = G(items1802799,"rest",L[324]);
var $z34013402 = D;
var $f34073408 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg5753397,anf_arg5763409):R.ffi.throwNonFunApp(L[323],_plus8,[anf_arg5753397,anf_arg5763409]);
};
try {
if(--R.GAS > 0) {
$z34013402 = $f34073408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34073408,
"from":L[323]});
}
} catch($e33993400) {
if(R.isCont($e33993400)) {
var $ss34033404 = {"from":L[323],
"go":function(anf_arg5773410) {
return $Hanf_arg11773411(anf_arg5773410,column1792798,if_helper5543004,process1702781);
}};
$e33993400.stack[R.EXN_STACKHEIGHT++] = $ss34033404;
}
if(R.isPyretException($e33993400)) {
$e33993400.pyretStack.push(L[323]);
}
throw $e33993400;
}
var $ret34053406 = $Hanf_arg11773411($z34013402,column1792798,if_helper5543004,process1702781);
++R.GAS;
return $ret34053406;
};
var $Hanf_arg11773411 = function(anf_arg5773410,column1792798,if_helper5543004,process1702781) {
var $z34143415 = D;
var $f34203421 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg5773410):R.ffi.throwNonFunApp(L[325],process1702781.$var,[column1792798,anf_arg5773410]);
};
try {
if(--R.GAS > 0) {
$z34143415 = $f34203421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34203421,
"from":L[325]});
}
} catch($e34123413) {
if(R.isCont($e34123413)) {
var $ss34163417 = {"from":L[325],
"go":function(cont_tail_arg5783422) {
return $Hcont_tail_arg11763423(cont_tail_arg5783422,if_helper5543004);
}};
$e34123413.stack[R.EXN_STACKHEIGHT++] = $ss34163417;
}
if(R.isPyretException($e34123413)) {
$e34123413.pyretStack.push(L[325]);
}
throw $e34123413;
}
var $ret34183419 = $Hcont_tail_arg11763423($z34143415,if_helper5543004);
++R.GAS;
return $ret34183419;
};
var $Hcont_tail_arg11763423 = function(cont_tail_arg5783422,if_helper5543004) {
if(--R.GAS > 0) {
$z34243425 = R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5783422):R.ffi.throwNonFunApp(L[325],if_helper5543004,[cont_tail_arg5783422]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5783422):R.ffi.throwNonFunApp(L[325],if_helper5543004,[cont_tail_arg5783422]);
},
"from":L[325]});
}
++R.GAS;
return $z34243425;
};
var $Hanf_array_val11833382 = function(anf_array_val5673380,anf_fun5663381,column1792798,if_helper5543004,items1802799,process1702781,_plus8) {
var $z34283429 = D;
var $f34343435 = function(_) {
return R.isFunction(anf_fun5663381)?anf_fun5663381.app([anf_array_val5673380]):R.ffi.throwNonFunApp(L[321],anf_fun5663381,[[anf_array_val5673380]]);
};
try {
if(--R.GAS > 0) {
$z34283429 = $f34343435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34343435,
"from":L[321]});
}
} catch($e34263427) {
if(R.isCont($e34263427)) {
var $ss34303431 = {"from":L[321],
"go":function(anf_arg5683436) {
return $Hanf_arg11823437(anf_arg5683436,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
}};
$e34263427.stack[R.EXN_STACKHEIGHT++] = $ss34303431;
}
if(R.isPyretException($e34263427)) {
$e34263427.pyretStack.push(L[321]);
}
throw $e34263427;
}
var $ret34323433 = $Hanf_arg11823437($z34283429,column1792798,if_helper5543004,items1802799,process1702781,_plus8);
++R.GAS;
return $ret34323433;
};
var $Hanf_arg11823437 = function(anf_arg5683436,column1792798,if_helper5543004,items1802799,process1702781,_plus8) {
var anf_arg5693448 = G(items1802799,"rest",L[327]);
var $z34403441 = D;
var $f34463447 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg5683436,anf_arg5693448):R.ffi.throwNonFunApp(L[326],_plus8,[anf_arg5683436,anf_arg5693448]);
};
try {
if(--R.GAS > 0) {
$z34403441 = $f34463447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34463447,
"from":L[326]});
}
} catch($e34383439) {
if(R.isCont($e34383439)) {
var $ss34423443 = {"from":L[326],
"go":function(anf_arg5703449) {
return $Hanf_arg11813450(anf_arg5703449,column1792798,if_helper5543004,process1702781);
}};
$e34383439.stack[R.EXN_STACKHEIGHT++] = $ss34423443;
}
if(R.isPyretException($e34383439)) {
$e34383439.pyretStack.push(L[326]);
}
throw $e34383439;
}
var $ret34443445 = $Hanf_arg11813450($z34403441,column1792798,if_helper5543004,process1702781);
++R.GAS;
return $ret34443445;
};
var $Hanf_arg11813450 = function(anf_arg5703449,column1792798,if_helper5543004,process1702781) {
var $z34533454 = D;
var $f34593460 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg5703449):R.ffi.throwNonFunApp(L[328],process1702781.$var,[column1792798,anf_arg5703449]);
};
try {
if(--R.GAS > 0) {
$z34533454 = $f34593460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34593460,
"from":L[328]});
}
} catch($e34513452) {
if(R.isCont($e34513452)) {
var $ss34553456 = {"from":L[328],
"go":function(cont_tail_arg5713461) {
return $Hcont_tail_arg11803462(cont_tail_arg5713461,if_helper5543004);
}};
$e34513452.stack[R.EXN_STACKHEIGHT++] = $ss34553456;
}
if(R.isPyretException($e34513452)) {
$e34513452.pyretStack.push(L[328]);
}
throw $e34513452;
}
var $ret34573458 = $Hcont_tail_arg11803462($z34533454,if_helper5543004);
++R.GAS;
return $ret34573458;
};
var $Hcont_tail_arg11803462 = function(cont_tail_arg5713461,if_helper5543004) {
if(--R.GAS > 0) {
$z34633464 = R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5713461):R.ffi.throwNonFunApp(L[328],if_helper5543004,[cont_tail_arg5713461]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5543004)?if_helper5543004.app(cont_tail_arg5713461):R.ffi.throwNonFunApp(L[328],if_helper5543004,[cont_tail_arg5713461]);
},
"from":L[328]});
}
++R.GAS;
return $z34633464;
};
var $Hcont_tail_arg11633060 = function(cont_tail_arg5503058,if_helper5403059) {
if(--R.GAS > 0) {
$z34653466 = R.isFunction(if_helper5403059)?if_helper5403059.app(cont_tail_arg5503058):R.ffi.throwNonFunApp(L[277],if_helper5403059,[cont_tail_arg5503058]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5403059)?if_helper5403059.app(cont_tail_arg5503058):R.ffi.throwNonFunApp(L[277],if_helper5403059,[cont_tail_arg5503058]);
},
"from":L[277]});
}
++R.GAS;
return $z34653466;
};
var $Hanf_begin_app_dropped11673072 = function(anf_begin_app_dropped11643071,column1792798,if_helper5403059,items1802799,n2093044,process1702781,_plus8) {
var $z34693470 = D;
var $f34753476 = function(_) {
return R.isFunction(_plus8)?_plus8.app(column1792798,n2093044):R.ffi.throwNonFunApp(L[329],_plus8,[column1792798,n2093044]);
};
try {
if(--R.GAS > 0) {
$z34693470 = $f34753476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34753476,
"from":L[329]});
}
} catch($e34673468) {
if(R.isCont($e34673468)) {
var $ss34713472 = {"from":L[329],
"go":function(anf_arg5453477) {
return $Hanf_arg11663478(anf_arg5453477,if_helper5403059,items1802799,process1702781);
}};
$e34673468.stack[R.EXN_STACKHEIGHT++] = $ss34713472;
}
if(R.isPyretException($e34673468)) {
$e34673468.pyretStack.push(L[329]);
}
throw $e34673468;
}
var $ret34733474 = $Hanf_arg11663478($z34693470,if_helper5403059,items1802799,process1702781);
++R.GAS;
return $ret34733474;
};
var $Hanf_arg11663478 = function(anf_arg5453477,if_helper5403059,items1802799,process1702781) {
var anf_arg5463489 = G(items1802799,"rest",L[331]);
var $z34813482 = D;
var $f34873488 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(anf_arg5453477,anf_arg5463489):R.ffi.throwNonFunApp(L[330],process1702781.$var,[anf_arg5453477,anf_arg5463489]);
};
try {
if(--R.GAS > 0) {
$z34813482 = $f34873488();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34873488,
"from":L[330]});
}
} catch($e34793480) {
if(R.isCont($e34793480)) {
var $ss34833484 = {"from":L[330],
"go":function(cont_tail_arg5473490) {
return $Hcont_tail_arg11653491(cont_tail_arg5473490,if_helper5403059);
}};
$e34793480.stack[R.EXN_STACKHEIGHT++] = $ss34833484;
}
if(R.isPyretException($e34793480)) {
$e34793480.pyretStack.push(L[330]);
}
throw $e34793480;
}
var $ret34853486 = $Hcont_tail_arg11653491($z34813482,if_helper5403059);
++R.GAS;
return $ret34853486;
};
var $Hcont_tail_arg11653491 = function(cont_tail_arg5473490,if_helper5403059) {
if(--R.GAS > 0) {
$z34923493 = R.isFunction(if_helper5403059)?if_helper5403059.app(cont_tail_arg5473490):R.ffi.throwNonFunApp(L[330],if_helper5403059,[cont_tail_arg5473490]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5403059)?if_helper5403059.app(cont_tail_arg5473490):R.ffi.throwNonFunApp(L[330],if_helper5403059,[cont_tail_arg5473490]);
},
"from":L[330]});
}
++R.GAS;
return $z34923493;
};
var $Hcont_tail_app11613096 = function(cont_tail_app5373095) {
return cont_tail_app5373095;
};
var $Hcont_tail_app11623108 = function(cont_tail_app5363107) {
return cont_tail_app5363107;
};
var $Hanf_array_val11603127 = function(anf_array_val5293125,anf_fun5263126,column1792798,items1802799,process1702781,_plus8) {
var $z34963497 = D;
var $f35023503 = function(_) {
return R.isFunction(anf_fun5263126)?anf_fun5263126.app([anf_array_val5293125]):R.ffi.throwNonFunApp(L[286],anf_fun5263126,[[anf_array_val5293125]]);
};
try {
if(--R.GAS > 0) {
$z34963497 = $f35023503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35023503,
"from":L[286]});
}
} catch($e34943495) {
if(R.isCont($e34943495)) {
var $ss34983499 = {"from":L[286],
"go":function(anf_arg5303504) {
return $Hanf_arg11593505(anf_arg5303504,column1792798,items1802799,process1702781,_plus8);
}};
$e34943495.stack[R.EXN_STACKHEIGHT++] = $ss34983499;
}
if(R.isPyretException($e34943495)) {
$e34943495.pyretStack.push(L[286]);
}
throw $e34943495;
}
var $ret35003501 = $Hanf_arg11593505($z34963497,column1792798,items1802799,process1702781,_plus8);
++R.GAS;
return $ret35003501;
};
var $Hanf_arg11593505 = function(anf_arg5303504,column1792798,items1802799,process1702781,_plus8) {
var anf_arg5313516 = G(items1802799,"rest",L[333]);
var $z35083509 = D;
var $f35143515 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg5303504,anf_arg5313516):R.ffi.throwNonFunApp(L[332],_plus8,[anf_arg5303504,anf_arg5313516]);
};
try {
if(--R.GAS > 0) {
$z35083509 = $f35143515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35143515,
"from":L[332]});
}
} catch($e35063507) {
if(R.isCont($e35063507)) {
var $ss35103511 = {"from":L[332],
"go":function(anf_arg5323517) {
return $Hanf_arg11583518(anf_arg5323517,column1792798,process1702781);
}};
$e35063507.stack[R.EXN_STACKHEIGHT++] = $ss35103511;
}
if(R.isPyretException($e35063507)) {
$e35063507.pyretStack.push(L[332]);
}
throw $e35063507;
}
var $ret35123513 = $Hanf_arg11583518($z35083509,column1792798,process1702781);
++R.GAS;
return $ret35123513;
};
var $Hanf_arg11583518 = function(anf_arg5323517,column1792798,process1702781) {
var $z35213522 = D;
var $f35273528 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg5323517):R.ffi.throwNonFunApp(L[281],process1702781.$var,[column1792798,anf_arg5323517]);
};
try {
if(--R.GAS > 0) {
$z35213522 = $f35273528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35273528,
"from":L[281]});
}
} catch($e35193520) {
if(R.isCont($e35193520)) {
var $ss35233524 = {"from":L[281],
"go":function(ann_DASH_check_DASH_temp5253529) {
return $Hann_DASH_check_DASH_temp11573530(ann_DASH_check_DASH_temp5253529);
}};
$e35193520.stack[R.EXN_STACKHEIGHT++] = $ss35233524;
}
if(R.isPyretException($e35193520)) {
$e35193520.pyretStack.push(L[281]);
}
throw $e35193520;
}
var $ret35253526 = $Hann_DASH_check_DASH_temp11573530($z35213522);
++R.GAS;
return $ret35253526;
};
var $Hann_DASH_check_DASH_temp11573530 = function(ann_DASH_check_DASH_temp5253529) {
return ann_DASH_check_DASH_temp5253529;
};
var $Hcont_tail_arg11533142 = function(cont_tail_arg5223140,if_helper5143141) {
if(--R.GAS > 0) {
$z35313532 = R.isFunction(if_helper5143141)?if_helper5143141.app(cont_tail_arg5223140):R.ffi.throwNonFunApp(L[288],if_helper5143141,[cont_tail_arg5223140]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5143141)?if_helper5143141.app(cont_tail_arg5223140):R.ffi.throwNonFunApp(L[288],if_helper5143141,[cont_tail_arg5223140]);
},
"from":L[288]});
}
++R.GAS;
return $z35313532;
};
var $Hanf_begin_app_dropped11563154 = function(anf_begin_app_dropped11543153,i1823001,if_helper5143141,items1802799,process1702781) {
var anf_arg5193543 = G(items1802799,"rest",L[335]);
var $z35353536 = D;
var $f35413542 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(i1823001,anf_arg5193543):R.ffi.throwNonFunApp(L[334],process1702781.$var,[i1823001,anf_arg5193543]);
};
try {
if(--R.GAS > 0) {
$z35353536 = $f35413542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35413542,
"from":L[334]});
}
} catch($e35333534) {
if(R.isCont($e35333534)) {
var $ss35373538 = {"from":L[334],
"go":function(cont_tail_arg5203544) {
return $Hcont_tail_arg11553545(cont_tail_arg5203544,if_helper5143141);
}};
$e35333534.stack[R.EXN_STACKHEIGHT++] = $ss35373538;
}
if(R.isPyretException($e35333534)) {
$e35333534.pyretStack.push(L[334]);
}
throw $e35333534;
}
var $ret35393540 = $Hcont_tail_arg11553545($z35353536,if_helper5143141);
++R.GAS;
return $ret35393540;
};
var $Hcont_tail_arg11553545 = function(cont_tail_arg5203544,if_helper5143141) {
if(--R.GAS > 0) {
$z35463547 = R.isFunction(if_helper5143141)?if_helper5143141.app(cont_tail_arg5203544):R.ffi.throwNonFunApp(L[334],if_helper5143141,[cont_tail_arg5203544]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper5143141)?if_helper5143141.app(cont_tail_arg5203544):R.ffi.throwNonFunApp(L[334],if_helper5143141,[cont_tail_arg5203544]);
},
"from":L[334]});
}
++R.GAS;
return $z35463547;
};
var $Hanf_arg11523178 = function(anf_arg5073176,anf_fun5063177,column1792798,d2003163,item912759,items1802799,m1833043,process1702781,_plus8) {
var $z35503551 = D;
var $f35563557 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(anf_arg5073176,m1833043,d2003163):R.ffi.throwNonFunApp(L[336],item912759.$var,[anf_arg5073176,m1833043,d2003163]);
};
try {
if(--R.GAS > 0) {
$z35503551 = $f35563557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35563557,
"from":L[336]});
}
} catch($e35483549) {
if(R.isCont($e35483549)) {
var $ss35523553 = {"from":L[336],
"go":function(anf_array_val5083558) {
return $Hanf_array_val11513559(anf_array_val5083558,anf_fun5063177,column1792798,items1802799,process1702781,_plus8);
}};
$e35483549.stack[R.EXN_STACKHEIGHT++] = $ss35523553;
}
if(R.isPyretException($e35483549)) {
$e35483549.pyretStack.push(L[336]);
}
throw $e35483549;
}
var $ret35543555 = $Hanf_array_val11513559($z35503551,anf_fun5063177,column1792798,items1802799,process1702781,_plus8);
++R.GAS;
return $ret35543555;
};
var $Hanf_array_val11513559 = function(anf_array_val5083558,anf_fun5063177,column1792798,items1802799,process1702781,_plus8) {
var $z35623563 = D;
var $f35683569 = function(_) {
return R.isFunction(anf_fun5063177)?anf_fun5063177.app([anf_array_val5083558]):R.ffi.throwNonFunApp(L[293],anf_fun5063177,[[anf_array_val5083558]]);
};
try {
if(--R.GAS > 0) {
$z35623563 = $f35683569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35683569,
"from":L[293]});
}
} catch($e35603561) {
if(R.isCont($e35603561)) {
var $ss35643565 = {"from":L[293],
"go":function(anf_arg5093570) {
return $Hanf_arg11503571(anf_arg5093570,column1792798,items1802799,process1702781,_plus8);
}};
$e35603561.stack[R.EXN_STACKHEIGHT++] = $ss35643565;
}
if(R.isPyretException($e35603561)) {
$e35603561.pyretStack.push(L[293]);
}
throw $e35603561;
}
var $ret35663567 = $Hanf_arg11503571($z35623563,column1792798,items1802799,process1702781,_plus8);
++R.GAS;
return $ret35663567;
};
var $Hanf_arg11503571 = function(anf_arg5093570,column1792798,items1802799,process1702781,_plus8) {
var anf_arg5103582 = G(items1802799,"rest",L[338]);
var $z35743575 = D;
var $f35803581 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg5093570,anf_arg5103582):R.ffi.throwNonFunApp(L[337],_plus8,[anf_arg5093570,anf_arg5103582]);
};
try {
if(--R.GAS > 0) {
$z35743575 = $f35803581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35803581,
"from":L[337]});
}
} catch($e35723573) {
if(R.isCont($e35723573)) {
var $ss35763577 = {"from":L[337],
"go":function(anf_arg5113583) {
return $Hanf_arg11493584(anf_arg5113583,column1792798,process1702781);
}};
$e35723573.stack[R.EXN_STACKHEIGHT++] = $ss35763577;
}
if(R.isPyretException($e35723573)) {
$e35723573.pyretStack.push(L[337]);
}
throw $e35723573;
}
var $ret35783579 = $Hanf_arg11493584($z35743575,column1792798,process1702781);
++R.GAS;
return $ret35783579;
};
var $Hanf_arg11493584 = function(anf_arg5113583,column1792798,process1702781) {
var $z35873588 = D;
var $f35933594 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg5113583):R.ffi.throwNonFunApp(L[291],process1702781.$var,[column1792798,anf_arg5113583]);
};
try {
if(--R.GAS > 0) {
$z35873588 = $f35933594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35933594,
"from":L[291]});
}
} catch($e35853586) {
if(R.isCont($e35853586)) {
var $ss35893590 = {"from":L[291],
"go":function(ann_DASH_check_DASH_temp5053595) {
return $Hann_DASH_check_DASH_temp11483596(ann_DASH_check_DASH_temp5053595);
}};
$e35853586.stack[R.EXN_STACKHEIGHT++] = $ss35893590;
}
if(R.isPyretException($e35853586)) {
$e35853586.pyretStack.push(L[291]);
}
throw $e35853586;
}
var $ret35913592 = $Hann_DASH_check_DASH_temp11483596($z35873588);
++R.GAS;
return $ret35913592;
};
var $Hann_DASH_check_DASH_temp11483596 = function(ann_DASH_check_DASH_temp5053595) {
return ann_DASH_check_DASH_temp5053595;
};
var $Hanf_array_val11473194 = function(anf_array_val5003192,anf_fun4993193,column1792798,items1802799,process1702781,_plus8) {
var $z35993600 = D;
var $f36053606 = function(_) {
return R.isFunction(anf_fun4993193)?anf_fun4993193.app([anf_array_val5003192]):R.ffi.throwNonFunApp(L[296],anf_fun4993193,[[anf_array_val5003192]]);
};
try {
if(--R.GAS > 0) {
$z35993600 = $f36053606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36053606,
"from":L[296]});
}
} catch($e35973598) {
if(R.isCont($e35973598)) {
var $ss36013602 = {"from":L[296],
"go":function(anf_arg5013607) {
return $Hanf_arg11463608(anf_arg5013607,column1792798,items1802799,process1702781,_plus8);
}};
$e35973598.stack[R.EXN_STACKHEIGHT++] = $ss36013602;
}
if(R.isPyretException($e35973598)) {
$e35973598.pyretStack.push(L[296]);
}
throw $e35973598;
}
var $ret36033604 = $Hanf_arg11463608($z35993600,column1792798,items1802799,process1702781,_plus8);
++R.GAS;
return $ret36033604;
};
var $Hanf_arg11463608 = function(anf_arg5013607,column1792798,items1802799,process1702781,_plus8) {
var anf_arg5023619 = G(items1802799,"rest",L[340]);
var $z36113612 = D;
var $f36173618 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg5013607,anf_arg5023619):R.ffi.throwNonFunApp(L[339],_plus8,[anf_arg5013607,anf_arg5023619]);
};
try {
if(--R.GAS > 0) {
$z36113612 = $f36173618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36173618,
"from":L[339]});
}
} catch($e36093610) {
if(R.isCont($e36093610)) {
var $ss36133614 = {"from":L[339],
"go":function(anf_arg5033620) {
return $Hanf_arg11453621(anf_arg5033620,column1792798,process1702781);
}};
$e36093610.stack[R.EXN_STACKHEIGHT++] = $ss36133614;
}
if(R.isPyretException($e36093610)) {
$e36093610.pyretStack.push(L[339]);
}
throw $e36093610;
}
var $ret36153616 = $Hanf_arg11453621($z36113612,column1792798,process1702781);
++R.GAS;
return $ret36153616;
};
var $Hanf_arg11453621 = function(anf_arg5033620,column1792798,process1702781) {
var $z36243625 = D;
var $f36303631 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg5033620):R.ffi.throwNonFunApp(L[294],process1702781.$var,[column1792798,anf_arg5033620]);
};
try {
if(--R.GAS > 0) {
$z36243625 = $f36303631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36303631,
"from":L[294]});
}
} catch($e36223623) {
if(R.isCont($e36223623)) {
var $ss36263627 = {"from":L[294],
"go":function(ann_DASH_check_DASH_temp4983632) {
return $Hann_DASH_check_DASH_temp11443633(ann_DASH_check_DASH_temp4983632);
}};
$e36223623.stack[R.EXN_STACKHEIGHT++] = $ss36263627;
}
if(R.isPyretException($e36223623)) {
$e36223623.pyretStack.push(L[294]);
}
throw $e36223623;
}
var $ret36283629 = $Hann_DASH_check_DASH_temp11443633($z36243625);
++R.GAS;
return $ret36283629;
};
var $Hann_DASH_check_DASH_temp11443633 = function(ann_DASH_check_DASH_temp4983632) {
return ann_DASH_check_DASH_temp4983632;
};
var $Hanf_begin_app_dropped11433209 = function(anf_begin_app_dropped11403208,column1792798,items1802799,n1933195,process1702781,_plus8) {
var $z36363637 = D;
var $f36423643 = function(_) {
return R.isFunction(_plus8)?_plus8.app(column1792798,n1933195):R.ffi.throwNonFunApp(L[341],_plus8,[column1792798,n1933195]);
};
try {
if(--R.GAS > 0) {
$z36363637 = $f36423643();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36423643,
"from":L[341]});
}
} catch($e36343635) {
if(R.isCont($e36343635)) {
var $ss36383639 = {"from":L[341],
"go":function(anf_arg4953644) {
return $Hanf_arg11423645(anf_arg4953644,items1802799,process1702781);
}};
$e36343635.stack[R.EXN_STACKHEIGHT++] = $ss36383639;
}
if(R.isPyretException($e36343635)) {
$e36343635.pyretStack.push(L[341]);
}
throw $e36343635;
}
var $ret36403641 = $Hanf_arg11423645($z36363637,items1802799,process1702781);
++R.GAS;
return $ret36403641;
};
var $Hanf_arg11423645 = function(anf_arg4953644,items1802799,process1702781) {
var anf_arg4963656 = G(items1802799,"rest",L[342]);
var $z36483649 = D;
var $f36543655 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(anf_arg4953644,anf_arg4963656):R.ffi.throwNonFunApp(L[297],process1702781.$var,[anf_arg4953644,anf_arg4963656]);
};
try {
if(--R.GAS > 0) {
$z36483649 = $f36543655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36543655,
"from":L[297]});
}
} catch($e36463647) {
if(R.isCont($e36463647)) {
var $ss36503651 = {"from":L[297],
"go":function(ann_DASH_check_DASH_temp4943657) {
return $Hann_DASH_check_DASH_temp11413658(ann_DASH_check_DASH_temp4943657);
}};
$e36463647.stack[R.EXN_STACKHEIGHT++] = $ss36503651;
}
if(R.isPyretException($e36463647)) {
$e36463647.pyretStack.push(L[297]);
}
throw $e36463647;
}
var $ret36523653 = $Hann_DASH_check_DASH_temp11413658($z36483649);
++R.GAS;
return $ret36523653;
};
var $Hann_DASH_check_DASH_temp11413658 = function(ann_DASH_check_DASH_temp4943657) {
return ann_DASH_check_DASH_temp4943657;
};
var $Hanf_begin_app_dropped11393224 = function(anf_begin_app_dropped11363223,column1792798,flat_DASH_width1913211,items1802799,process1702781,_plus8) {
var $z36613662 = D;
var $f36673668 = function(_) {
return R.isFunction(_plus8)?_plus8.app(column1792798,flat_DASH_width1913211):R.ffi.throwNonFunApp(L[343],_plus8,[column1792798,flat_DASH_width1913211]);
};
try {
if(--R.GAS > 0) {
$z36613662 = $f36673668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36673668,
"from":L[343]});
}
} catch($e36593660) {
if(R.isCont($e36593660)) {
var $ss36633664 = {"from":L[343],
"go":function(anf_arg4913669) {
return $Hanf_arg11383670(anf_arg4913669,items1802799,process1702781);
}};
$e36593660.stack[R.EXN_STACKHEIGHT++] = $ss36633664;
}
if(R.isPyretException($e36593660)) {
$e36593660.pyretStack.push(L[343]);
}
throw $e36593660;
}
var $ret36653666 = $Hanf_arg11383670($z36613662,items1802799,process1702781);
++R.GAS;
return $ret36653666;
};
var $Hanf_arg11383670 = function(anf_arg4913669,items1802799,process1702781) {
var anf_arg4923681 = G(items1802799,"rest",L[344]);
var $z36733674 = D;
var $f36793680 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(anf_arg4913669,anf_arg4923681):R.ffi.throwNonFunApp(L[299],process1702781.$var,[anf_arg4913669,anf_arg4923681]);
};
try {
if(--R.GAS > 0) {
$z36733674 = $f36793680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36793680,
"from":L[299]});
}
} catch($e36713672) {
if(R.isCont($e36713672)) {
var $ss36753676 = {"from":L[299],
"go":function(ann_DASH_check_DASH_temp4903682) {
return $Hann_DASH_check_DASH_temp11373683(ann_DASH_check_DASH_temp4903682);
}};
$e36713672.stack[R.EXN_STACKHEIGHT++] = $ss36753676;
}
if(R.isPyretException($e36713672)) {
$e36713672.pyretStack.push(L[299]);
}
throw $e36713672;
}
var $ret36773678 = $Hann_DASH_check_DASH_temp11373683($z36733674);
++R.GAS;
return $ret36773678;
};
var $Hann_DASH_check_DASH_temp11373683 = function(ann_DASH_check_DASH_temp4903682) {
return ann_DASH_check_DASH_temp4903682;
};
var $Hanf_array_val11353241 = function(anf_array_val4843239,anf_fun4833240,column1792798,i1823001,item912759,items1802799,m1833043,process1702781,snd1873226,_plus8) {
var $z36863687 = D;
var $f36923693 = function(_) {
return R.isFunction(item912759.$var)?item912759.$var.app(i1823001,m1833043,snd1873226):R.ffi.throwNonFunApp(L[345],item912759.$var,[i1823001,m1833043,snd1873226]);
};
try {
if(--R.GAS > 0) {
$z36863687 = $f36923693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36923693,
"from":L[345]});
}
} catch($e36843685) {
if(R.isCont($e36843685)) {
var $ss36883689 = {"from":L[345],
"go":function(anf_array_val4853694) {
return $Hanf_array_val11343695(anf_array_val4853694,anf_array_val4843239,anf_fun4833240,column1792798,items1802799,process1702781,_plus8);
}};
$e36843685.stack[R.EXN_STACKHEIGHT++] = $ss36883689;
}
if(R.isPyretException($e36843685)) {
$e36843685.pyretStack.push(L[345]);
}
throw $e36843685;
}
var $ret36903691 = $Hanf_array_val11343695($z36863687,anf_array_val4843239,anf_fun4833240,column1792798,items1802799,process1702781,_plus8);
++R.GAS;
return $ret36903691;
};
var $Hanf_array_val11343695 = function(anf_array_val4853694,anf_array_val4843239,anf_fun4833240,column1792798,items1802799,process1702781,_plus8) {
var $z36983699 = D;
var $f37043705 = function(_) {
return R.isFunction(anf_fun4833240)?anf_fun4833240.app([anf_array_val4843239,anf_array_val4853694]):R.ffi.throwNonFunApp(L[303],anf_fun4833240,[[anf_array_val4843239,anf_array_val4853694]]);
};
try {
if(--R.GAS > 0) {
$z36983699 = $f37043705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37043705,
"from":L[303]});
}
} catch($e36963697) {
if(R.isCont($e36963697)) {
var $ss37003701 = {"from":L[303],
"go":function(anf_arg4863706) {
return $Hanf_arg11333707(anf_arg4863706,column1792798,items1802799,process1702781,_plus8);
}};
$e36963697.stack[R.EXN_STACKHEIGHT++] = $ss37003701;
}
if(R.isPyretException($e36963697)) {
$e36963697.pyretStack.push(L[303]);
}
throw $e36963697;
}
var $ret37023703 = $Hanf_arg11333707($z36983699,column1792798,items1802799,process1702781,_plus8);
++R.GAS;
return $ret37023703;
};
var $Hanf_arg11333707 = function(anf_arg4863706,column1792798,items1802799,process1702781,_plus8) {
var anf_arg4873718 = G(items1802799,"rest",L[347]);
var $z37103711 = D;
var $f37163717 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg4863706,anf_arg4873718):R.ffi.throwNonFunApp(L[346],_plus8,[anf_arg4863706,anf_arg4873718]);
};
try {
if(--R.GAS > 0) {
$z37103711 = $f37163717();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37163717,
"from":L[346]});
}
} catch($e37083709) {
if(R.isCont($e37083709)) {
var $ss37123713 = {"from":L[346],
"go":function(anf_arg4883719) {
return $Hanf_arg11323720(anf_arg4883719,column1792798,process1702781);
}};
$e37083709.stack[R.EXN_STACKHEIGHT++] = $ss37123713;
}
if(R.isPyretException($e37083709)) {
$e37083709.pyretStack.push(L[346]);
}
throw $e37083709;
}
var $ret37143715 = $Hanf_arg11323720($z37103711,column1792798,process1702781);
++R.GAS;
return $ret37143715;
};
var $Hanf_arg11323720 = function(anf_arg4883719,column1792798,process1702781) {
var $z37233724 = D;
var $f37293730 = function(_) {
return R.isFunction(process1702781.$var)?process1702781.$var.app(column1792798,anf_arg4883719):R.ffi.throwNonFunApp(L[301],process1702781.$var,[column1792798,anf_arg4883719]);
};
try {
if(--R.GAS > 0) {
$z37233724 = $f37293730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37293730,
"from":L[301]});
}
} catch($e37213722) {
if(R.isCont($e37213722)) {
var $ss37253726 = {"from":L[301],
"go":function(ann_DASH_check_DASH_temp4823731) {
return $Hann_DASH_check_DASH_temp11313732(ann_DASH_check_DASH_temp4823731);
}};
$e37213722.stack[R.EXN_STACKHEIGHT++] = $ss37253726;
}
if(R.isPyretException($e37213722)) {
$e37213722.pyretStack.push(L[301]);
}
throw $e37213722;
}
var $ret37273728 = $Hann_DASH_check_DASH_temp11313732($z37233724);
++R.GAS;
return $ret37273728;
};
var $Hann_DASH_check_DASH_temp11313732 = function(ann_DASH_check_DASH_temp4823731) {
return ann_DASH_check_DASH_temp4823731;
};
var $Hann_DASH_check_DASH_temp11303256 = function(ann_DASH_check_DASH_temp4793255) {
return ann_DASH_check_DASH_temp4793255;
};
var $Hanf_arg11282827 = function(anf_arg4702823,anf_arg4682824,anf_fun4612825,output1652826) {
var $z37353736 = D;
var $f37413742 = function(_) {
return R.isFunction(anf_fun4612825)?anf_fun4612825.app(anf_arg4682824,anf_arg4702823,output1652826.$var):R.ffi.throwNonFunApp(L[247],anf_fun4612825,[anf_arg4682824,anf_arg4702823,output1652826.$var]);
};
try {
if(--R.GAS > 0) {
$z37353736 = $f37413742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37413742,
"from":L[247]});
}
} catch($e37333734) {
if(R.isCont($e37333734)) {
var $ss37373738 = {"from":L[247],
"go":function(ann_DASH_check_DASH_temp4603743) {
return $Hann_DASH_check_DASH_temp11273744(ann_DASH_check_DASH_temp4603743);
}};
$e37333734.stack[R.EXN_STACKHEIGHT++] = $ss37373738;
}
if(R.isPyretException($e37333734)) {
$e37333734.pyretStack.push(L[247]);
}
throw $e37333734;
}
var $ret37393740 = $Hann_DASH_check_DASH_temp11273744($z37353736);
++R.GAS;
return $ret37393740;
};
var $Hann_DASH_check_DASH_temp11273744 = function(ann_DASH_check_DASH_temp4603743) {
return ann_DASH_check_DASH_temp4603743;
};
var $Hl11262843 = function(l1762842,lines1742828,list1948,_plus8) {
var anf_fun4663755 = G(list1948,"make",L[348]);
var $z37473748 = D;
var $f37533754 = function(_) {
return R.isFunction(anf_fun4663755)?anf_fun4663755.app([l1762842]):R.ffi.throwNonFunApp(L[348],anf_fun4663755,[[l1762842]]);
};
try {
if(--R.GAS > 0) {
$z37473748 = $f37533754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37533754,
"from":L[348]});
}
} catch($e37453746) {
if(R.isCont($e37453746)) {
var $ss37493750 = {"from":L[348],
"go":function(anf_arg4673756) {
return $Hanf_arg11253757(anf_arg4673756,lines1742828,_plus8);
}};
$e37453746.stack[R.EXN_STACKHEIGHT++] = $ss37493750;
}
if(R.isPyretException($e37453746)) {
$e37453746.pyretStack.push(L[348]);
}
throw $e37453746;
}
var $ret37513752 = $Hanf_arg11253757($z37473748,lines1742828,_plus8);
++R.GAS;
return $ret37513752;
};
var $Hanf_arg11253757 = function(anf_arg4673756,lines1742828,_plus8) {
var $z37603761 = D;
var $f37663767 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg4673756,lines1742828):R.ffi.throwNonFunApp(L[249],_plus8,[anf_arg4673756,lines1742828]);
};
try {
if(--R.GAS > 0) {
$z37603761 = $f37663767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37663767,
"from":L[249]});
}
} catch($e37583759) {
if(R.isCont($e37583759)) {
var $ss37623763 = {"from":L[249],
"go":function(ann_DASH_check_DASH_temp4623768) {
return $Hann_DASH_check_DASH_temp11243769(ann_DASH_check_DASH_temp4623768);
}};
$e37583759.stack[R.EXN_STACKHEIGHT++] = $ss37623763;
}
if(R.isPyretException($e37583759)) {
$e37583759.pyretStack.push(L[249]);
}
throw $e37583759;
}
var $ret37643765 = $Hann_DASH_check_DASH_temp11243769($z37603761);
++R.GAS;
return $ret37643765;
};
var $Hann_DASH_check_DASH_temp11243769 = function(ann_DASH_check_DASH_temp4623768) {
return ann_DASH_check_DASH_temp4623768;
};
var $Hann_DASH_check_DASH_temp11232857 = function(ann_DASH_check_DASH_temp4642856) {
return ann_DASH_check_DASH_temp4642856;
};
var $Hanf_array_val11222872 = function(anf_array_val4552869,anf_fun4532870,anf_fun4542871,output1652826,_plus8) {
var $z37723773 = D;
var $f37783779 = function(_) {
return R.isFunction(anf_fun4542871)?anf_fun4542871.app([anf_array_val4552869]):R.ffi.throwNonFunApp(L[256],anf_fun4542871,[[anf_array_val4552869]]);
};
try {
if(--R.GAS > 0) {
$z37723773 = $f37783779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37783779,
"from":L[256]});
}
} catch($e37703771) {
if(R.isCont($e37703771)) {
var $ss37743775 = {"from":L[256],
"go":function(anf_array_val4563780) {
return $Hanf_array_val11213781(anf_array_val4563780,anf_fun4532870,output1652826,_plus8);
}};
$e37703771.stack[R.EXN_STACKHEIGHT++] = $ss37743775;
}
if(R.isPyretException($e37703771)) {
$e37703771.pyretStack.push(L[256]);
}
throw $e37703771;
}
var $ret37763777 = $Hanf_array_val11213781($z37723773,anf_fun4532870,output1652826,_plus8);
++R.GAS;
return $ret37763777;
};
var $Hanf_array_val11213781 = function(anf_array_val4563780,anf_fun4532870,output1652826,_plus8) {
var $z37843785 = D;
var $f37903791 = function(_) {
return R.isFunction(anf_fun4532870)?anf_fun4532870.app([anf_array_val4563780]):R.ffi.throwNonFunApp(L[257],anf_fun4532870,[[anf_array_val4563780]]);
};
try {
if(--R.GAS > 0) {
$z37843785 = $f37903791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37903791,
"from":L[257]});
}
} catch($e37823783) {
if(R.isCont($e37823783)) {
var $ss37863787 = {"from":L[257],
"go":function(anf_arg4573792) {
return $Hanf_arg11203793(anf_arg4573792,output1652826,_plus8);
}};
$e37823783.stack[R.EXN_STACKHEIGHT++] = $ss37863787;
}
if(R.isPyretException($e37823783)) {
$e37823783.pyretStack.push(L[257]);
}
throw $e37823783;
}
var $ret37883789 = $Hanf_arg11203793($z37843785,output1652826,_plus8);
++R.GAS;
return $ret37883789;
};
var $Hanf_arg11203793 = function(anf_arg4573792,output1652826,_plus8) {
var $z37963797 = D;
var $f38023803 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg4573792,output1652826.$var):R.ffi.throwNonFunApp(L[349],_plus8,[anf_arg4573792,output1652826.$var]);
};
try {
if(--R.GAS > 0) {
$z37963797 = $f38023803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38023803,
"from":L[349]});
}
} catch($e37943795) {
if(R.isCont($e37943795)) {
var $ss37983799 = {"from":L[349],
"go":function(anf_assign4583804) {
return $Hanf_assign11193805(anf_assign4583804,output1652826);
}};
$e37943795.stack[R.EXN_STACKHEIGHT++] = $ss37983799;
}
if(R.isPyretException($e37943795)) {
$e37943795.pyretStack.push(L[349]);
}
throw $e37943795;
}
var $ret38003801 = $Hanf_assign11193805($z37963797,output1652826);
++R.GAS;
return $ret38003801;
};
var $Hanf_assign11193805 = function(anf_assign4583804,output1652826) {
var ann_DASH_check_DASH_temp4523806 = output1652826.$var = anf_assign4583804;
return ann_DASH_check_DASH_temp4523806;
};
var $Hanf_arg11182885 = function(anf_arg4502884,emit_DASH_text1662773) {
var $z38093810 = D;
var $f38153816 = function(_) {
return R.isFunction(emit_DASH_text1662773.$var)?emit_DASH_text1662773.$var.app(anf_arg4502884):R.ffi.throwNonFunApp(L[258],emit_DASH_text1662773.$var,[anf_arg4502884]);
};
try {
if(--R.GAS > 0) {
$z38093810 = $f38153816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38153816,
"from":L[258]});
}
} catch($e38073808) {
if(R.isCont($e38073808)) {
var $ss38113812 = {"from":L[258],
"go":function(ann_DASH_check_DASH_temp4493817) {
return $Hann_DASH_check_DASH_temp11173818(ann_DASH_check_DASH_temp4493817);
}};
$e38073808.stack[R.EXN_STACKHEIGHT++] = $ss38113812;
}
if(R.isPyretException($e38073808)) {
$e38073808.pyretStack.push(L[258]);
}
throw $e38073808;
}
var $ret38133814 = $Hann_DASH_check_DASH_temp11173818($z38093810);
++R.GAS;
return $ret38133814;
};
var $Hann_DASH_check_DASH_temp11173818 = function(ann_DASH_check_DASH_temp4493817) {
return ann_DASH_check_DASH_temp4493817;
};
var $Hanf_arg11162900 = function(anf_arg4422898,anf_fun4402899,output1652826,_plus8) {
var anf_arg4433829 = G(output1652826.$var,"first",L[351]);
var $z38213822 = D;
var $f38273828 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg4422898,anf_arg4433829):R.ffi.throwNonFunApp(L[350],_plus8,[anf_arg4422898,anf_arg4433829]);
};
try {
if(--R.GAS > 0) {
$z38213822 = $f38273828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38273828,
"from":L[350]});
}
} catch($e38193820) {
if(R.isCont($e38193820)) {
var $ss38233824 = {"from":L[350],
"go":function(anf_array_val4443830) {
return $Hanf_array_val11153831(anf_array_val4443830,anf_fun4402899,output1652826,_plus8);
}};
$e38193820.stack[R.EXN_STACKHEIGHT++] = $ss38233824;
}
if(R.isPyretException($e38193820)) {
$e38193820.pyretStack.push(L[350]);
}
throw $e38193820;
}
var $ret38253826 = $Hanf_array_val11153831($z38213822,anf_fun4402899,output1652826,_plus8);
++R.GAS;
return $ret38253826;
};
var $Hanf_array_val11153831 = function(anf_array_val4443830,anf_fun4402899,output1652826,_plus8) {
var $z38343835 = D;
var $f38403841 = function(_) {
return R.isFunction(anf_fun4402899)?anf_fun4402899.app([anf_array_val4443830]):R.ffi.throwNonFunApp(L[262],anf_fun4402899,[[anf_array_val4443830]]);
};
try {
if(--R.GAS > 0) {
$z38343835 = $f38403841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38403841,
"from":L[262]});
}
} catch($e38323833) {
if(R.isCont($e38323833)) {
var $ss38363837 = {"from":L[262],
"go":function(anf_arg4453842) {
return $Hanf_arg11143843(anf_arg4453842,output1652826,_plus8);
}};
$e38323833.stack[R.EXN_STACKHEIGHT++] = $ss38363837;
}
if(R.isPyretException($e38323833)) {
$e38323833.pyretStack.push(L[262]);
}
throw $e38323833;
}
var $ret38383839 = $Hanf_arg11143843($z38343835,output1652826,_plus8);
++R.GAS;
return $ret38383839;
};
var $Hanf_arg11143843 = function(anf_arg4453842,output1652826,_plus8) {
var anf_arg4463854 = G(output1652826.$var,"rest",L[353]);
var $z38463847 = D;
var $f38523853 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg4453842,anf_arg4463854):R.ffi.throwNonFunApp(L[352],_plus8,[anf_arg4453842,anf_arg4463854]);
};
try {
if(--R.GAS > 0) {
$z38463847 = $f38523853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38523853,
"from":L[352]});
}
} catch($e38443845) {
if(R.isCont($e38443845)) {
var $ss38483849 = {"from":L[352],
"go":function(anf_assign4473855) {
return $Hanf_assign11133856(anf_assign4473855,output1652826);
}};
$e38443845.stack[R.EXN_STACKHEIGHT++] = $ss38483849;
}
if(R.isPyretException($e38443845)) {
$e38443845.pyretStack.push(L[352]);
}
throw $e38443845;
}
var $ret38503851 = $Hanf_assign11133856($z38463847,output1652826);
++R.GAS;
return $ret38503851;
};
var $Hanf_assign11133856 = function(anf_assign4473855,output1652826) {
var ann_DASH_check_DASH_temp4393857 = output1652826.$var = anf_assign4473855;
return ann_DASH_check_DASH_temp4393857;
};
var $Hanf_arg11113858 = function(anf_arg4183859,self723860,_plus8,torepr14) {
var anf_arg4193871 = G(self723860,"is-flat",L[354]);
var $z38633864 = D;
var $f38693870 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg4193871):R.ffi.throwNonFunApp(L[354],torepr14,[anf_arg4193871]);
};
try {
if(--R.GAS > 0) {
$z38633864 = $f38693870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38693870,
"from":L[354]});
}
} catch($e38613862) {
if(R.isCont($e38613862)) {
var $ss38653866 = {"from":L[354],
"go":function(anf_arg4203872) {
return $Hanf_arg11103873(anf_arg4203872,anf_arg4183859,self723860,_plus8,torepr14);
}};
$e38613862.stack[R.EXN_STACKHEIGHT++] = $ss38653866;
}
if(R.isPyretException($e38613862)) {
$e38613862.pyretStack.push(L[354]);
}
throw $e38613862;
}
var $ret38673868 = $Hanf_arg11103873($z38633864,anf_arg4183859,self723860,_plus8,torepr14);
++R.GAS;
return $ret38673868;
};
var $Hanf_arg11103873 = function(anf_arg4203872,anf_arg4183859,self723860,_plus8,torepr14) {
var $z38763877 = D;
var $f38823883 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg4203872):R.ffi.throwNonFunApp(L[354],_plus8,[(", "),anf_arg4203872]);
};
try {
if(--R.GAS > 0) {
$z38763877 = $f38823883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38823883,
"from":L[354]});
}
} catch($e38743875) {
if(R.isCont($e38743875)) {
var $ss38783879 = {"from":L[354],
"go":function(anf_arg4213884) {
return $Hanf_arg11093885(anf_arg4213884,anf_arg4183859,self723860,_plus8,torepr14);
}};
$e38743875.stack[R.EXN_STACKHEIGHT++] = $ss38783879;
}
if(R.isPyretException($e38743875)) {
$e38743875.pyretStack.push(L[354]);
}
throw $e38743875;
}
var $ret38803881 = $Hanf_arg11093885($z38763877,anf_arg4183859,self723860,_plus8,torepr14);
++R.GAS;
return $ret38803881;
};
var $Hanf_arg11093885 = function(anf_arg4213884,anf_arg4183859,self723860,_plus8,torepr14) {
var $z38883889 = D;
var $f38943895 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg4183859,anf_arg4213884):R.ffi.throwNonFunApp(L[354],_plus8,[anf_arg4183859,anf_arg4213884]);
};
try {
if(--R.GAS > 0) {
$z38883889 = $f38943895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38943895,
"from":L[354]});
}
} catch($e38863887) {
if(R.isCont($e38863887)) {
var $ss38903891 = {"from":L[354],
"go":function(anf_arg4223896) {
return $Hanf_arg11083897(anf_arg4223896,self723860,_plus8,torepr14);
}};
$e38863887.stack[R.EXN_STACKHEIGHT++] = $ss38903891;
}
if(R.isPyretException($e38863887)) {
$e38863887.pyretStack.push(L[354]);
}
throw $e38863887;
}
var $ret38923893 = $Hanf_arg11083897($z38883889,self723860,_plus8,torepr14);
++R.GAS;
return $ret38923893;
};
var $Hanf_arg11083897 = function(anf_arg4223896,self723860,_plus8,torepr14) {
var anf_arg4233908 = G(self723860,"d",L[354]);
var $z39003901 = D;
var $f39063907 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg4233908):R.ffi.throwNonFunApp(L[354],torepr14,[anf_arg4233908]);
};
try {
if(--R.GAS > 0) {
$z39003901 = $f39063907();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39063907,
"from":L[354]});
}
} catch($e38983899) {
if(R.isCont($e38983899)) {
var $ss39023903 = {"from":L[354],
"go":function(anf_arg4243909) {
return $Hanf_arg11073910(anf_arg4243909,anf_arg4223896,_plus8);
}};
$e38983899.stack[R.EXN_STACKHEIGHT++] = $ss39023903;
}
if(R.isPyretException($e38983899)) {
$e38983899.pyretStack.push(L[354]);
}
throw $e38983899;
}
var $ret39043905 = $Hanf_arg11073910($z39003901,anf_arg4223896,_plus8);
++R.GAS;
return $ret39043905;
};
var $Hanf_arg11073910 = function(anf_arg4243909,anf_arg4223896,_plus8) {
var $z39133914 = D;
var $f39193920 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg4243909):R.ffi.throwNonFunApp(L[354],_plus8,[(", "),anf_arg4243909]);
};
try {
if(--R.GAS > 0) {
$z39133914 = $f39193920();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39193920,
"from":L[354]});
}
} catch($e39113912) {
if(R.isCont($e39113912)) {
var $ss39153916 = {"from":L[354],
"go":function(anf_arg4253921) {
return $Hanf_arg11063922(anf_arg4253921,anf_arg4223896,_plus8);
}};
$e39113912.stack[R.EXN_STACKHEIGHT++] = $ss39153916;
}
if(R.isPyretException($e39113912)) {
$e39113912.pyretStack.push(L[354]);
}
throw $e39113912;
}
var $ret39173918 = $Hanf_arg11063922($z39133914,anf_arg4223896,_plus8);
++R.GAS;
return $ret39173918;
};
var $Hanf_arg11063922 = function(anf_arg4253921,anf_arg4223896,_plus8) {
var $z39253926 = D;
var $f39313932 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg4223896,anf_arg4253921):R.ffi.throwNonFunApp(L[354],_plus8,[anf_arg4223896,anf_arg4253921]);
};
try {
if(--R.GAS > 0) {
$z39253926 = $f39313932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39313932,
"from":L[354]});
}
} catch($e39233924) {
if(R.isCont($e39233924)) {
var $ss39273928 = {"from":L[354],
"go":function(anf_arg4263933) {
return $Hanf_arg11053934(anf_arg4263933,_plus8);
}};
$e39233924.stack[R.EXN_STACKHEIGHT++] = $ss39273928;
}
if(R.isPyretException($e39233924)) {
$e39233924.pyretStack.push(L[354]);
}
throw $e39233924;
}
var $ret39293930 = $Hanf_arg11053934($z39253926,_plus8);
++R.GAS;
return $ret39293930;
};
var $Hanf_arg11053934 = function(anf_arg4263933,_plus8) {
var $z39373938 = D;
var $f39433944 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg4263933,(")")):R.ffi.throwNonFunApp(L[354],_plus8,[anf_arg4263933,(")")]);
};
try {
if(--R.GAS > 0) {
$z39373938 = $f39433944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39433944,
"from":L[354]});
}
} catch($e39353936) {
if(R.isCont($e39353936)) {
var $ss39393940 = {"from":L[354],
"go":function(anf_arg4273945) {
return $Hanf_arg11043946(anf_arg4273945,_plus8);
}};
$e39353936.stack[R.EXN_STACKHEIGHT++] = $ss39393940;
}
if(R.isPyretException($e39353936)) {
$e39353936.pyretStack.push(L[354]);
}
throw $e39353936;
}
var $ret39413942 = $Hanf_arg11043946($z39373938,_plus8);
++R.GAS;
return $ret39413942;
};
var $Hanf_arg11043946 = function(anf_arg4273945,_plus8) {
var $z39493950 = D;
var $f39553956 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg4273945):R.ffi.throwNonFunApp(L[354],_plus8,[("("),anf_arg4273945]);
};
try {
if(--R.GAS > 0) {
$z39493950 = $f39553956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39553956,
"from":L[354]});
}
} catch($e39473948) {
if(R.isCont($e39473948)) {
var $ss39513952 = {"from":L[354],
"go":function(anf_arg4283957) {
return $Hanf_arg11033958(anf_arg4283957,_plus8);
}};
$e39473948.stack[R.EXN_STACKHEIGHT++] = $ss39513952;
}
if(R.isPyretException($e39473948)) {
$e39473948.pyretStack.push(L[354]);
}
throw $e39473948;
}
var $ret39533954 = $Hanf_arg11033958($z39493950,_plus8);
++R.GAS;
return $ret39533954;
};
var $Hanf_arg11033958 = function(anf_arg4283957,_plus8) {
var $z39613962 = D;
var $f39673968 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("item"),anf_arg4283957):R.ffi.throwNonFunApp(L[354],_plus8,[("item"),anf_arg4283957]);
};
try {
if(--R.GAS > 0) {
$z39613962 = $f39673968();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39673968,
"from":L[354]});
}
} catch($e39593960) {
if(R.isCont($e39593960)) {
var $ss39633964 = {"from":L[354],
"go":function(ann_DASH_check_DASH_temp4163969) {
return $Hann_DASH_check_DASH_temp11023970(ann_DASH_check_DASH_temp4163969);
}};
$e39593960.stack[R.EXN_STACKHEIGHT++] = $ss39633964;
}
if(R.isPyretException($e39593960)) {
$e39593960.pyretStack.push(L[354]);
}
throw $e39593960;
}
var $ret39653966 = $Hann_DASH_check_DASH_temp11023970($z39613962);
++R.GAS;
return $ret39653966;
};
var $Hann_DASH_check_DASH_temp11023970 = function(ann_DASH_check_DASH_temp4163969) {
return ann_DASH_check_DASH_temp4163969;
};
var $Hcont_tail_arg11003971 = function(cont_tail_arg4133972,if_helper4033973) {
if(--R.GAS > 0) {
$z39743975 = R.isFunction(if_helper4033973)?if_helper4033973.app(cont_tail_arg4133972):R.ffi.throwNonFunApp(L[354],if_helper4033973,[cont_tail_arg4133972]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper4033973)?if_helper4033973.app(cont_tail_arg4133972):R.ffi.throwNonFunApp(L[354],if_helper4033973,[cont_tail_arg4133972]);
},
"from":L[354]});
}
++R.GAS;
return $z39743975;
};
var $Hcont_tail_arg11013976 = function(cont_tail_arg4083977,if_helper4033973) {
if(--R.GAS > 0) {
$z39783979 = R.isFunction(if_helper4033973)?if_helper4033973.app(cont_tail_arg4083977):R.ffi.throwNonFunApp(L[354],if_helper4033973,[cont_tail_arg4083977]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper4033973)?if_helper4033973.app(cont_tail_arg4083977):R.ffi.throwNonFunApp(L[354],if_helper4033973,[cont_tail_arg4083977]);
},
"from":L[354]});
}
++R.GAS;
return $z39783979;
};
var $Hanf_arg10993980 = function(anf_arg3673981,self593982,_plus8,torepr14) {
var anf_arg3683993 = G(self593982,"flat-width",L[355]);
var $z39853986 = D;
var $f39913992 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3683993):R.ffi.throwNonFunApp(L[355],torepr14,[anf_arg3683993]);
};
try {
if(--R.GAS > 0) {
$z39853986 = $f39913992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39913992,
"from":L[355]});
}
} catch($e39833984) {
if(R.isCont($e39833984)) {
var $ss39873988 = {"from":L[355],
"go":function(anf_arg3693994) {
return $Hanf_arg10983995(anf_arg3693994,anf_arg3673981,self593982,_plus8,torepr14);
}};
$e39833984.stack[R.EXN_STACKHEIGHT++] = $ss39873988;
}
if(R.isPyretException($e39833984)) {
$e39833984.pyretStack.push(L[355]);
}
throw $e39833984;
}
var $ret39893990 = $Hanf_arg10983995($z39853986,anf_arg3673981,self593982,_plus8,torepr14);
++R.GAS;
return $ret39893990;
};
var $Hanf_arg10983995 = function(anf_arg3693994,anf_arg3673981,self593982,_plus8,torepr14) {
var $z39983999 = D;
var $f40044005 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg3693994):R.ffi.throwNonFunApp(L[355],_plus8,[(", "),anf_arg3693994]);
};
try {
if(--R.GAS > 0) {
$z39983999 = $f40044005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40044005,
"from":L[355]});
}
} catch($e39963997) {
if(R.isCont($e39963997)) {
var $ss40004001 = {"from":L[355],
"go":function(anf_arg3704006) {
return $Hanf_arg10974007(anf_arg3704006,anf_arg3673981,self593982,_plus8,torepr14);
}};
$e39963997.stack[R.EXN_STACKHEIGHT++] = $ss40004001;
}
if(R.isPyretException($e39963997)) {
$e39963997.pyretStack.push(L[355]);
}
throw $e39963997;
}
var $ret40024003 = $Hanf_arg10974007($z39983999,anf_arg3673981,self593982,_plus8,torepr14);
++R.GAS;
return $ret40024003;
};
var $Hanf_arg10974007 = function(anf_arg3704006,anf_arg3673981,self593982,_plus8,torepr14) {
var $z40104011 = D;
var $f40164017 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3673981,anf_arg3704006):R.ffi.throwNonFunApp(L[355],_plus8,[anf_arg3673981,anf_arg3704006]);
};
try {
if(--R.GAS > 0) {
$z40104011 = $f40164017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40164017,
"from":L[355]});
}
} catch($e40084009) {
if(R.isCont($e40084009)) {
var $ss40124013 = {"from":L[355],
"go":function(anf_arg3714018) {
return $Hanf_arg10964019(anf_arg3714018,self593982,_plus8,torepr14);
}};
$e40084009.stack[R.EXN_STACKHEIGHT++] = $ss40124013;
}
if(R.isPyretException($e40084009)) {
$e40084009.pyretStack.push(L[355]);
}
throw $e40084009;
}
var $ret40144015 = $Hanf_arg10964019($z40104011,self593982,_plus8,torepr14);
++R.GAS;
return $ret40144015;
};
var $Hanf_arg10964019 = function(anf_arg3714018,self593982,_plus8,torepr14) {
var anf_arg3724030 = G(self593982,"has-hardline",L[355]);
var $z40224023 = D;
var $f40284029 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3724030):R.ffi.throwNonFunApp(L[355],torepr14,[anf_arg3724030]);
};
try {
if(--R.GAS > 0) {
$z40224023 = $f40284029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40284029,
"from":L[355]});
}
} catch($e40204021) {
if(R.isCont($e40204021)) {
var $ss40244025 = {"from":L[355],
"go":function(anf_arg3734031) {
return $Hanf_arg10954032(anf_arg3734031,anf_arg3714018,_plus8);
}};
$e40204021.stack[R.EXN_STACKHEIGHT++] = $ss40244025;
}
if(R.isPyretException($e40204021)) {
$e40204021.pyretStack.push(L[355]);
}
throw $e40204021;
}
var $ret40264027 = $Hanf_arg10954032($z40224023,anf_arg3714018,_plus8);
++R.GAS;
return $ret40264027;
};
var $Hanf_arg10954032 = function(anf_arg3734031,anf_arg3714018,_plus8) {
var $z40354036 = D;
var $f40414042 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg3734031):R.ffi.throwNonFunApp(L[355],_plus8,[(", "),anf_arg3734031]);
};
try {
if(--R.GAS > 0) {
$z40354036 = $f40414042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40414042,
"from":L[355]});
}
} catch($e40334034) {
if(R.isCont($e40334034)) {
var $ss40374038 = {"from":L[355],
"go":function(anf_arg3744043) {
return $Hanf_arg10944044(anf_arg3744043,anf_arg3714018,_plus8);
}};
$e40334034.stack[R.EXN_STACKHEIGHT++] = $ss40374038;
}
if(R.isPyretException($e40334034)) {
$e40334034.pyretStack.push(L[355]);
}
throw $e40334034;
}
var $ret40394040 = $Hanf_arg10944044($z40354036,anf_arg3714018,_plus8);
++R.GAS;
return $ret40394040;
};
var $Hanf_arg10944044 = function(anf_arg3744043,anf_arg3714018,_plus8) {
var $z40474048 = D;
var $f40534054 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3714018,anf_arg3744043):R.ffi.throwNonFunApp(L[355],_plus8,[anf_arg3714018,anf_arg3744043]);
};
try {
if(--R.GAS > 0) {
$z40474048 = $f40534054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40534054,
"from":L[355]});
}
} catch($e40454046) {
if(R.isCont($e40454046)) {
var $ss40494050 = {"from":L[355],
"go":function(anf_arg3754055) {
return $Hanf_arg10934056(anf_arg3754055,_plus8);
}};
$e40454046.stack[R.EXN_STACKHEIGHT++] = $ss40494050;
}
if(R.isPyretException($e40454046)) {
$e40454046.pyretStack.push(L[355]);
}
throw $e40454046;
}
var $ret40514052 = $Hanf_arg10934056($z40474048,_plus8);
++R.GAS;
return $ret40514052;
};
var $Hanf_arg10934056 = function(anf_arg3754055,_plus8) {
var $z40594060 = D;
var $f40654066 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3754055,(")")):R.ffi.throwNonFunApp(L[355],_plus8,[anf_arg3754055,(")")]);
};
try {
if(--R.GAS > 0) {
$z40594060 = $f40654066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40654066,
"from":L[355]});
}
} catch($e40574058) {
if(R.isCont($e40574058)) {
var $ss40614062 = {"from":L[355],
"go":function(anf_arg3764067) {
return $Hanf_arg10924068(anf_arg3764067,_plus8);
}};
$e40574058.stack[R.EXN_STACKHEIGHT++] = $ss40614062;
}
if(R.isPyretException($e40574058)) {
$e40574058.pyretStack.push(L[355]);
}
throw $e40574058;
}
var $ret40634064 = $Hanf_arg10924068($z40594060,_plus8);
++R.GAS;
return $ret40634064;
};
var $Hanf_arg10924068 = function(anf_arg3764067,_plus8) {
var $z40714072 = D;
var $f40774078 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg3764067):R.ffi.throwNonFunApp(L[355],_plus8,[("("),anf_arg3764067]);
};
try {
if(--R.GAS > 0) {
$z40714072 = $f40774078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40774078,
"from":L[355]});
}
} catch($e40694070) {
if(R.isCont($e40694070)) {
var $ss40734074 = {"from":L[355],
"go":function(anf_arg3774079) {
return $Hanf_arg10914080(anf_arg3774079,_plus8);
}};
$e40694070.stack[R.EXN_STACKHEIGHT++] = $ss40734074;
}
if(R.isPyretException($e40694070)) {
$e40694070.pyretStack.push(L[355]);
}
throw $e40694070;
}
var $ret40754076 = $Hanf_arg10914080($z40714072,_plus8);
++R.GAS;
return $ret40754076;
};
var $Hanf_arg10914080 = function(anf_arg3774079,_plus8) {
var $z40834084 = D;
var $f40894090 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("group"),anf_arg3774079):R.ffi.throwNonFunApp(L[355],_plus8,[("group"),anf_arg3774079]);
};
try {
if(--R.GAS > 0) {
$z40834084 = $f40894090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40894090,
"from":L[355]});
}
} catch($e40814082) {
if(R.isCont($e40814082)) {
var $ss40854086 = {"from":L[355],
"go":function(ann_DASH_check_DASH_temp3654091) {
return $Hann_DASH_check_DASH_temp10904092(ann_DASH_check_DASH_temp3654091);
}};
$e40814082.stack[R.EXN_STACKHEIGHT++] = $ss40854086;
}
if(R.isPyretException($e40814082)) {
$e40814082.pyretStack.push(L[355]);
}
throw $e40814082;
}
var $ret40874088 = $Hann_DASH_check_DASH_temp10904092($z40834084);
++R.GAS;
return $ret40874088;
};
var $Hann_DASH_check_DASH_temp10904092 = function(ann_DASH_check_DASH_temp3654091) {
return ann_DASH_check_DASH_temp3654091;
};
var $Hcont_tail_arg10884093 = function(cont_tail_arg3624094,if_helper3524095) {
if(--R.GAS > 0) {
$z40964097 = R.isFunction(if_helper3524095)?if_helper3524095.app(cont_tail_arg3624094):R.ffi.throwNonFunApp(L[355],if_helper3524095,[cont_tail_arg3624094]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper3524095)?if_helper3524095.app(cont_tail_arg3624094):R.ffi.throwNonFunApp(L[355],if_helper3524095,[cont_tail_arg3624094]);
},
"from":L[355]});
}
++R.GAS;
return $z40964097;
};
var $Hcont_tail_arg10894098 = function(cont_tail_arg3574099,if_helper3524095) {
if(--R.GAS > 0) {
$z41004101 = R.isFunction(if_helper3524095)?if_helper3524095.app(cont_tail_arg3574099):R.ffi.throwNonFunApp(L[355],if_helper3524095,[cont_tail_arg3574099]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper3524095)?if_helper3524095.app(cont_tail_arg3574099):R.ffi.throwNonFunApp(L[355],if_helper3524095,[cont_tail_arg3574099]);
},
"from":L[355]});
}
++R.GAS;
return $z41004101;
};
var $Hanf_arg10874102 = function(anf_arg3394103,self534104,_plus8,torepr14) {
var anf_arg3404115 = G(self534104,"flat-width",L[356]);
var $z41074108 = D;
var $f41134114 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3404115):R.ffi.throwNonFunApp(L[356],torepr14,[anf_arg3404115]);
};
try {
if(--R.GAS > 0) {
$z41074108 = $f41134114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41134114,
"from":L[356]});
}
} catch($e41054106) {
if(R.isCont($e41054106)) {
var $ss41094110 = {"from":L[356],
"go":function(anf_arg3414116) {
return $Hanf_arg10864117(anf_arg3414116,anf_arg3394103,self534104,_plus8,torepr14);
}};
$e41054106.stack[R.EXN_STACKHEIGHT++] = $ss41094110;
}
if(R.isPyretException($e41054106)) {
$e41054106.pyretStack.push(L[356]);
}
throw $e41054106;
}
var $ret41114112 = $Hanf_arg10864117($z41074108,anf_arg3394103,self534104,_plus8,torepr14);
++R.GAS;
return $ret41114112;
};
var $Hanf_arg10864117 = function(anf_arg3414116,anf_arg3394103,self534104,_plus8,torepr14) {
var $z41204121 = D;
var $f41264127 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg3414116):R.ffi.throwNonFunApp(L[356],_plus8,[(", "),anf_arg3414116]);
};
try {
if(--R.GAS > 0) {
$z41204121 = $f41264127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41264127,
"from":L[356]});
}
} catch($e41184119) {
if(R.isCont($e41184119)) {
var $ss41224123 = {"from":L[356],
"go":function(anf_arg3424128) {
return $Hanf_arg10854129(anf_arg3424128,anf_arg3394103,self534104,_plus8,torepr14);
}};
$e41184119.stack[R.EXN_STACKHEIGHT++] = $ss41224123;
}
if(R.isPyretException($e41184119)) {
$e41184119.pyretStack.push(L[356]);
}
throw $e41184119;
}
var $ret41244125 = $Hanf_arg10854129($z41204121,anf_arg3394103,self534104,_plus8,torepr14);
++R.GAS;
return $ret41244125;
};
var $Hanf_arg10854129 = function(anf_arg3424128,anf_arg3394103,self534104,_plus8,torepr14) {
var $z41324133 = D;
var $f41384139 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3394103,anf_arg3424128):R.ffi.throwNonFunApp(L[356],_plus8,[anf_arg3394103,anf_arg3424128]);
};
try {
if(--R.GAS > 0) {
$z41324133 = $f41384139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41384139,
"from":L[356]});
}
} catch($e41304131) {
if(R.isCont($e41304131)) {
var $ss41344135 = {"from":L[356],
"go":function(anf_arg3434140) {
return $Hanf_arg10844141(anf_arg3434140,self534104,_plus8,torepr14);
}};
$e41304131.stack[R.EXN_STACKHEIGHT++] = $ss41344135;
}
if(R.isPyretException($e41304131)) {
$e41304131.pyretStack.push(L[356]);
}
throw $e41304131;
}
var $ret41364137 = $Hanf_arg10844141($z41324133,self534104,_plus8,torepr14);
++R.GAS;
return $ret41364137;
};
var $Hanf_arg10844141 = function(anf_arg3434140,self534104,_plus8,torepr14) {
var anf_arg3444152 = G(self534104,"has-hardline",L[356]);
var $z41444145 = D;
var $f41504151 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3444152):R.ffi.throwNonFunApp(L[356],torepr14,[anf_arg3444152]);
};
try {
if(--R.GAS > 0) {
$z41444145 = $f41504151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41504151,
"from":L[356]});
}
} catch($e41424143) {
if(R.isCont($e41424143)) {
var $ss41464147 = {"from":L[356],
"go":function(anf_arg3454153) {
return $Hanf_arg10834154(anf_arg3454153,anf_arg3434140,_plus8);
}};
$e41424143.stack[R.EXN_STACKHEIGHT++] = $ss41464147;
}
if(R.isPyretException($e41424143)) {
$e41424143.pyretStack.push(L[356]);
}
throw $e41424143;
}
var $ret41484149 = $Hanf_arg10834154($z41444145,anf_arg3434140,_plus8);
++R.GAS;
return $ret41484149;
};
var $Hanf_arg10834154 = function(anf_arg3454153,anf_arg3434140,_plus8) {
var $z41574158 = D;
var $f41634164 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg3454153):R.ffi.throwNonFunApp(L[356],_plus8,[(", "),anf_arg3454153]);
};
try {
if(--R.GAS > 0) {
$z41574158 = $f41634164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41634164,
"from":L[356]});
}
} catch($e41554156) {
if(R.isCont($e41554156)) {
var $ss41594160 = {"from":L[356],
"go":function(anf_arg3464165) {
return $Hanf_arg10824166(anf_arg3464165,anf_arg3434140,_plus8);
}};
$e41554156.stack[R.EXN_STACKHEIGHT++] = $ss41594160;
}
if(R.isPyretException($e41554156)) {
$e41554156.pyretStack.push(L[356]);
}
throw $e41554156;
}
var $ret41614162 = $Hanf_arg10824166($z41574158,anf_arg3434140,_plus8);
++R.GAS;
return $ret41614162;
};
var $Hanf_arg10824166 = function(anf_arg3464165,anf_arg3434140,_plus8) {
var $z41694170 = D;
var $f41754176 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3434140,anf_arg3464165):R.ffi.throwNonFunApp(L[356],_plus8,[anf_arg3434140,anf_arg3464165]);
};
try {
if(--R.GAS > 0) {
$z41694170 = $f41754176();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41754176,
"from":L[356]});
}
} catch($e41674168) {
if(R.isCont($e41674168)) {
var $ss41714172 = {"from":L[356],
"go":function(anf_arg3474177) {
return $Hanf_arg10814178(anf_arg3474177,_plus8);
}};
$e41674168.stack[R.EXN_STACKHEIGHT++] = $ss41714172;
}
if(R.isPyretException($e41674168)) {
$e41674168.pyretStack.push(L[356]);
}
throw $e41674168;
}
var $ret41734174 = $Hanf_arg10814178($z41694170,_plus8);
++R.GAS;
return $ret41734174;
};
var $Hanf_arg10814178 = function(anf_arg3474177,_plus8) {
var $z41814182 = D;
var $f41874188 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3474177,(")")):R.ffi.throwNonFunApp(L[356],_plus8,[anf_arg3474177,(")")]);
};
try {
if(--R.GAS > 0) {
$z41814182 = $f41874188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41874188,
"from":L[356]});
}
} catch($e41794180) {
if(R.isCont($e41794180)) {
var $ss41834184 = {"from":L[356],
"go":function(anf_arg3484189) {
return $Hanf_arg10804190(anf_arg3484189,_plus8);
}};
$e41794180.stack[R.EXN_STACKHEIGHT++] = $ss41834184;
}
if(R.isPyretException($e41794180)) {
$e41794180.pyretStack.push(L[356]);
}
throw $e41794180;
}
var $ret41854186 = $Hanf_arg10804190($z41814182,_plus8);
++R.GAS;
return $ret41854186;
};
var $Hanf_arg10804190 = function(anf_arg3484189,_plus8) {
var $z41934194 = D;
var $f41994200 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg3484189):R.ffi.throwNonFunApp(L[356],_plus8,[("("),anf_arg3484189]);
};
try {
if(--R.GAS > 0) {
$z41934194 = $f41994200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41994200,
"from":L[356]});
}
} catch($e41914192) {
if(R.isCont($e41914192)) {
var $ss41954196 = {"from":L[356],
"go":function(anf_arg3494201) {
return $Hanf_arg10794202(anf_arg3494201,_plus8);
}};
$e41914192.stack[R.EXN_STACKHEIGHT++] = $ss41954196;
}
if(R.isPyretException($e41914192)) {
$e41914192.pyretStack.push(L[356]);
}
throw $e41914192;
}
var $ret41974198 = $Hanf_arg10794202($z41934194,_plus8);
++R.GAS;
return $ret41974198;
};
var $Hanf_arg10794202 = function(anf_arg3494201,_plus8) {
var $z42054206 = D;
var $f42114212 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("align-spaces"),anf_arg3494201):R.ffi.throwNonFunApp(L[356],_plus8,[("align-spaces"),anf_arg3494201]);
};
try {
if(--R.GAS > 0) {
$z42054206 = $f42114212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42114212,
"from":L[356]});
}
} catch($e42034204) {
if(R.isCont($e42034204)) {
var $ss42074208 = {"from":L[356],
"go":function(ann_DASH_check_DASH_temp3374213) {
return $Hann_DASH_check_DASH_temp10784214(ann_DASH_check_DASH_temp3374213);
}};
$e42034204.stack[R.EXN_STACKHEIGHT++] = $ss42074208;
}
if(R.isPyretException($e42034204)) {
$e42034204.pyretStack.push(L[356]);
}
throw $e42034204;
}
var $ret42094210 = $Hann_DASH_check_DASH_temp10784214($z42054206);
++R.GAS;
return $ret42094210;
};
var $Hann_DASH_check_DASH_temp10784214 = function(ann_DASH_check_DASH_temp3374213) {
return ann_DASH_check_DASH_temp3374213;
};
var $Hcont_tail_arg10764215 = function(cont_tail_arg3344216,if_helper3244217) {
if(--R.GAS > 0) {
$z42184219 = R.isFunction(if_helper3244217)?if_helper3244217.app(cont_tail_arg3344216):R.ffi.throwNonFunApp(L[356],if_helper3244217,[cont_tail_arg3344216]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper3244217)?if_helper3244217.app(cont_tail_arg3344216):R.ffi.throwNonFunApp(L[356],if_helper3244217,[cont_tail_arg3344216]);
},
"from":L[356]});
}
++R.GAS;
return $z42184219;
};
var $Hcont_tail_arg10774220 = function(cont_tail_arg3294221,if_helper3244217) {
if(--R.GAS > 0) {
$z42224223 = R.isFunction(if_helper3244217)?if_helper3244217.app(cont_tail_arg3294221):R.ffi.throwNonFunApp(L[356],if_helper3244217,[cont_tail_arg3294221]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper3244217)?if_helper3244217.app(cont_tail_arg3294221):R.ffi.throwNonFunApp(L[356],if_helper3244217,[cont_tail_arg3294221]);
},
"from":L[356]});
}
++R.GAS;
return $z42224223;
};
var $Hanf_arg10754224 = function(anf_arg3114225,self474226,_plus8,torepr14) {
var anf_arg3124237 = G(self474226,"flat-width",L[357]);
var $z42294230 = D;
var $f42354236 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3124237):R.ffi.throwNonFunApp(L[357],torepr14,[anf_arg3124237]);
};
try {
if(--R.GAS > 0) {
$z42294230 = $f42354236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42354236,
"from":L[357]});
}
} catch($e42274228) {
if(R.isCont($e42274228)) {
var $ss42314232 = {"from":L[357],
"go":function(anf_arg3134238) {
return $Hanf_arg10744239(anf_arg3134238,anf_arg3114225,self474226,_plus8,torepr14);
}};
$e42274228.stack[R.EXN_STACKHEIGHT++] = $ss42314232;
}
if(R.isPyretException($e42274228)) {
$e42274228.pyretStack.push(L[357]);
}
throw $e42274228;
}
var $ret42334234 = $Hanf_arg10744239($z42294230,anf_arg3114225,self474226,_plus8,torepr14);
++R.GAS;
return $ret42334234;
};
var $Hanf_arg10744239 = function(anf_arg3134238,anf_arg3114225,self474226,_plus8,torepr14) {
var $z42424243 = D;
var $f42484249 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg3134238):R.ffi.throwNonFunApp(L[357],_plus8,[(", "),anf_arg3134238]);
};
try {
if(--R.GAS > 0) {
$z42424243 = $f42484249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42484249,
"from":L[357]});
}
} catch($e42404241) {
if(R.isCont($e42404241)) {
var $ss42444245 = {"from":L[357],
"go":function(anf_arg3144250) {
return $Hanf_arg10734251(anf_arg3144250,anf_arg3114225,self474226,_plus8,torepr14);
}};
$e42404241.stack[R.EXN_STACKHEIGHT++] = $ss42444245;
}
if(R.isPyretException($e42404241)) {
$e42404241.pyretStack.push(L[357]);
}
throw $e42404241;
}
var $ret42464247 = $Hanf_arg10734251($z42424243,anf_arg3114225,self474226,_plus8,torepr14);
++R.GAS;
return $ret42464247;
};
var $Hanf_arg10734251 = function(anf_arg3144250,anf_arg3114225,self474226,_plus8,torepr14) {
var $z42544255 = D;
var $f42604261 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3114225,anf_arg3144250):R.ffi.throwNonFunApp(L[357],_plus8,[anf_arg3114225,anf_arg3144250]);
};
try {
if(--R.GAS > 0) {
$z42544255 = $f42604261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42604261,
"from":L[357]});
}
} catch($e42524253) {
if(R.isCont($e42524253)) {
var $ss42564257 = {"from":L[357],
"go":function(anf_arg3154262) {
return $Hanf_arg10724263(anf_arg3154262,self474226,_plus8,torepr14);
}};
$e42524253.stack[R.EXN_STACKHEIGHT++] = $ss42564257;
}
if(R.isPyretException($e42524253)) {
$e42524253.pyretStack.push(L[357]);
}
throw $e42524253;
}
var $ret42584259 = $Hanf_arg10724263($z42544255,self474226,_plus8,torepr14);
++R.GAS;
return $ret42584259;
};
var $Hanf_arg10724263 = function(anf_arg3154262,self474226,_plus8,torepr14) {
var anf_arg3164274 = G(self474226,"has-hardline",L[357]);
var $z42664267 = D;
var $f42724273 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3164274):R.ffi.throwNonFunApp(L[357],torepr14,[anf_arg3164274]);
};
try {
if(--R.GAS > 0) {
$z42664267 = $f42724273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42724273,
"from":L[357]});
}
} catch($e42644265) {
if(R.isCont($e42644265)) {
var $ss42684269 = {"from":L[357],
"go":function(anf_arg3174275) {
return $Hanf_arg10714276(anf_arg3174275,anf_arg3154262,_plus8);
}};
$e42644265.stack[R.EXN_STACKHEIGHT++] = $ss42684269;
}
if(R.isPyretException($e42644265)) {
$e42644265.pyretStack.push(L[357]);
}
throw $e42644265;
}
var $ret42704271 = $Hanf_arg10714276($z42664267,anf_arg3154262,_plus8);
++R.GAS;
return $ret42704271;
};
var $Hanf_arg10714276 = function(anf_arg3174275,anf_arg3154262,_plus8) {
var $z42794280 = D;
var $f42854286 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg3174275):R.ffi.throwNonFunApp(L[357],_plus8,[(", "),anf_arg3174275]);
};
try {
if(--R.GAS > 0) {
$z42794280 = $f42854286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42854286,
"from":L[357]});
}
} catch($e42774278) {
if(R.isCont($e42774278)) {
var $ss42814282 = {"from":L[357],
"go":function(anf_arg3184287) {
return $Hanf_arg10704288(anf_arg3184287,anf_arg3154262,_plus8);
}};
$e42774278.stack[R.EXN_STACKHEIGHT++] = $ss42814282;
}
if(R.isPyretException($e42774278)) {
$e42774278.pyretStack.push(L[357]);
}
throw $e42774278;
}
var $ret42834284 = $Hanf_arg10704288($z42794280,anf_arg3154262,_plus8);
++R.GAS;
return $ret42834284;
};
var $Hanf_arg10704288 = function(anf_arg3184287,anf_arg3154262,_plus8) {
var $z42914292 = D;
var $f42974298 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3154262,anf_arg3184287):R.ffi.throwNonFunApp(L[357],_plus8,[anf_arg3154262,anf_arg3184287]);
};
try {
if(--R.GAS > 0) {
$z42914292 = $f42974298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42974298,
"from":L[357]});
}
} catch($e42894290) {
if(R.isCont($e42894290)) {
var $ss42934294 = {"from":L[357],
"go":function(anf_arg3194299) {
return $Hanf_arg10694300(anf_arg3194299,_plus8);
}};
$e42894290.stack[R.EXN_STACKHEIGHT++] = $ss42934294;
}
if(R.isPyretException($e42894290)) {
$e42894290.pyretStack.push(L[357]);
}
throw $e42894290;
}
var $ret42954296 = $Hanf_arg10694300($z42914292,_plus8);
++R.GAS;
return $ret42954296;
};
var $Hanf_arg10694300 = function(anf_arg3194299,_plus8) {
var $z43034304 = D;
var $f43094310 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg3194299,(")")):R.ffi.throwNonFunApp(L[357],_plus8,[anf_arg3194299,(")")]);
};
try {
if(--R.GAS > 0) {
$z43034304 = $f43094310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43094310,
"from":L[357]});
}
} catch($e43014302) {
if(R.isCont($e43014302)) {
var $ss43054306 = {"from":L[357],
"go":function(anf_arg3204311) {
return $Hanf_arg10684312(anf_arg3204311,_plus8);
}};
$e43014302.stack[R.EXN_STACKHEIGHT++] = $ss43054306;
}
if(R.isPyretException($e43014302)) {
$e43014302.pyretStack.push(L[357]);
}
throw $e43014302;
}
var $ret43074308 = $Hanf_arg10684312($z43034304,_plus8);
++R.GAS;
return $ret43074308;
};
var $Hanf_arg10684312 = function(anf_arg3204311,_plus8) {
var $z43154316 = D;
var $f43214322 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg3204311):R.ffi.throwNonFunApp(L[357],_plus8,[("("),anf_arg3204311]);
};
try {
if(--R.GAS > 0) {
$z43154316 = $f43214322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43214322,
"from":L[357]});
}
} catch($e43134314) {
if(R.isCont($e43134314)) {
var $ss43174318 = {"from":L[357],
"go":function(anf_arg3214323) {
return $Hanf_arg10674324(anf_arg3214323,_plus8);
}};
$e43134314.stack[R.EXN_STACKHEIGHT++] = $ss43174318;
}
if(R.isPyretException($e43134314)) {
$e43134314.pyretStack.push(L[357]);
}
throw $e43134314;
}
var $ret43194320 = $Hanf_arg10674324($z43154316,_plus8);
++R.GAS;
return $ret43194320;
};
var $Hanf_arg10674324 = function(anf_arg3214323,_plus8) {
var $z43274328 = D;
var $f43334334 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("align"),anf_arg3214323):R.ffi.throwNonFunApp(L[357],_plus8,[("align"),anf_arg3214323]);
};
try {
if(--R.GAS > 0) {
$z43274328 = $f43334334();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43334334,
"from":L[357]});
}
} catch($e43254326) {
if(R.isCont($e43254326)) {
var $ss43294330 = {"from":L[357],
"go":function(ann_DASH_check_DASH_temp3094335) {
return $Hann_DASH_check_DASH_temp10664336(ann_DASH_check_DASH_temp3094335);
}};
$e43254326.stack[R.EXN_STACKHEIGHT++] = $ss43294330;
}
if(R.isPyretException($e43254326)) {
$e43254326.pyretStack.push(L[357]);
}
throw $e43254326;
}
var $ret43314332 = $Hann_DASH_check_DASH_temp10664336($z43274328);
++R.GAS;
return $ret43314332;
};
var $Hann_DASH_check_DASH_temp10664336 = function(ann_DASH_check_DASH_temp3094335) {
return ann_DASH_check_DASH_temp3094335;
};
var $Hcont_tail_arg10644337 = function(cont_tail_arg3064338,if_helper2964339) {
if(--R.GAS > 0) {
$z43404341 = R.isFunction(if_helper2964339)?if_helper2964339.app(cont_tail_arg3064338):R.ffi.throwNonFunApp(L[357],if_helper2964339,[cont_tail_arg3064338]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2964339)?if_helper2964339.app(cont_tail_arg3064338):R.ffi.throwNonFunApp(L[357],if_helper2964339,[cont_tail_arg3064338]);
},
"from":L[357]});
}
++R.GAS;
return $z43404341;
};
var $Hcont_tail_arg10654342 = function(cont_tail_arg3014343,if_helper2964339) {
if(--R.GAS > 0) {
$z43444345 = R.isFunction(if_helper2964339)?if_helper2964339.app(cont_tail_arg3014343):R.ffi.throwNonFunApp(L[357],if_helper2964339,[cont_tail_arg3014343]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2964339)?if_helper2964339.app(cont_tail_arg3014343):R.ffi.throwNonFunApp(L[357],if_helper2964339,[cont_tail_arg3014343]);
},
"from":L[357]});
}
++R.GAS;
return $z43444345;
};
var $Hanf_arg10634346 = function(anf_arg2794347,self414348,_plus8,torepr14) {
var anf_arg2804359 = G(self414348,"vert",L[358]);
var $z43514352 = D;
var $f43574358 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2804359):R.ffi.throwNonFunApp(L[358],torepr14,[anf_arg2804359]);
};
try {
if(--R.GAS > 0) {
$z43514352 = $f43574358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43574358,
"from":L[358]});
}
} catch($e43494350) {
if(R.isCont($e43494350)) {
var $ss43534354 = {"from":L[358],
"go":function(anf_arg2814360) {
return $Hanf_arg10624361(anf_arg2814360,anf_arg2794347,self414348,_plus8,torepr14);
}};
$e43494350.stack[R.EXN_STACKHEIGHT++] = $ss43534354;
}
if(R.isPyretException($e43494350)) {
$e43494350.pyretStack.push(L[358]);
}
throw $e43494350;
}
var $ret43554356 = $Hanf_arg10624361($z43514352,anf_arg2794347,self414348,_plus8,torepr14);
++R.GAS;
return $ret43554356;
};
var $Hanf_arg10624361 = function(anf_arg2814360,anf_arg2794347,self414348,_plus8,torepr14) {
var $z43644365 = D;
var $f43704371 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2814360):R.ffi.throwNonFunApp(L[358],_plus8,[(", "),anf_arg2814360]);
};
try {
if(--R.GAS > 0) {
$z43644365 = $f43704371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43704371,
"from":L[358]});
}
} catch($e43624363) {
if(R.isCont($e43624363)) {
var $ss43664367 = {"from":L[358],
"go":function(anf_arg2824372) {
return $Hanf_arg10614373(anf_arg2824372,anf_arg2794347,self414348,_plus8,torepr14);
}};
$e43624363.stack[R.EXN_STACKHEIGHT++] = $ss43664367;
}
if(R.isPyretException($e43624363)) {
$e43624363.pyretStack.push(L[358]);
}
throw $e43624363;
}
var $ret43684369 = $Hanf_arg10614373($z43644365,anf_arg2794347,self414348,_plus8,torepr14);
++R.GAS;
return $ret43684369;
};
var $Hanf_arg10614373 = function(anf_arg2824372,anf_arg2794347,self414348,_plus8,torepr14) {
var $z43764377 = D;
var $f43824383 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2794347,anf_arg2824372):R.ffi.throwNonFunApp(L[358],_plus8,[anf_arg2794347,anf_arg2824372]);
};
try {
if(--R.GAS > 0) {
$z43764377 = $f43824383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43824383,
"from":L[358]});
}
} catch($e43744375) {
if(R.isCont($e43744375)) {
var $ss43784379 = {"from":L[358],
"go":function(anf_arg2834384) {
return $Hanf_arg10604385(anf_arg2834384,self414348,_plus8,torepr14);
}};
$e43744375.stack[R.EXN_STACKHEIGHT++] = $ss43784379;
}
if(R.isPyretException($e43744375)) {
$e43744375.pyretStack.push(L[358]);
}
throw $e43744375;
}
var $ret43804381 = $Hanf_arg10604385($z43764377,self414348,_plus8,torepr14);
++R.GAS;
return $ret43804381;
};
var $Hanf_arg10604385 = function(anf_arg2834384,self414348,_plus8,torepr14) {
var anf_arg2844396 = G(self414348,"flat-width",L[358]);
var $z43884389 = D;
var $f43944395 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2844396):R.ffi.throwNonFunApp(L[358],torepr14,[anf_arg2844396]);
};
try {
if(--R.GAS > 0) {
$z43884389 = $f43944395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43944395,
"from":L[358]});
}
} catch($e43864387) {
if(R.isCont($e43864387)) {
var $ss43904391 = {"from":L[358],
"go":function(anf_arg2854397) {
return $Hanf_arg10594398(anf_arg2854397,anf_arg2834384,self414348,_plus8,torepr14);
}};
$e43864387.stack[R.EXN_STACKHEIGHT++] = $ss43904391;
}
if(R.isPyretException($e43864387)) {
$e43864387.pyretStack.push(L[358]);
}
throw $e43864387;
}
var $ret43924393 = $Hanf_arg10594398($z43884389,anf_arg2834384,self414348,_plus8,torepr14);
++R.GAS;
return $ret43924393;
};
var $Hanf_arg10594398 = function(anf_arg2854397,anf_arg2834384,self414348,_plus8,torepr14) {
var $z44014402 = D;
var $f44074408 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2854397):R.ffi.throwNonFunApp(L[358],_plus8,[(", "),anf_arg2854397]);
};
try {
if(--R.GAS > 0) {
$z44014402 = $f44074408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44074408,
"from":L[358]});
}
} catch($e43994400) {
if(R.isCont($e43994400)) {
var $ss44034404 = {"from":L[358],
"go":function(anf_arg2864409) {
return $Hanf_arg10584410(anf_arg2864409,anf_arg2834384,self414348,_plus8,torepr14);
}};
$e43994400.stack[R.EXN_STACKHEIGHT++] = $ss44034404;
}
if(R.isPyretException($e43994400)) {
$e43994400.pyretStack.push(L[358]);
}
throw $e43994400;
}
var $ret44054406 = $Hanf_arg10584410($z44014402,anf_arg2834384,self414348,_plus8,torepr14);
++R.GAS;
return $ret44054406;
};
var $Hanf_arg10584410 = function(anf_arg2864409,anf_arg2834384,self414348,_plus8,torepr14) {
var $z44134414 = D;
var $f44194420 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2834384,anf_arg2864409):R.ffi.throwNonFunApp(L[358],_plus8,[anf_arg2834384,anf_arg2864409]);
};
try {
if(--R.GAS > 0) {
$z44134414 = $f44194420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44194420,
"from":L[358]});
}
} catch($e44114412) {
if(R.isCont($e44114412)) {
var $ss44154416 = {"from":L[358],
"go":function(anf_arg2874421) {
return $Hanf_arg10574422(anf_arg2874421,self414348,_plus8,torepr14);
}};
$e44114412.stack[R.EXN_STACKHEIGHT++] = $ss44154416;
}
if(R.isPyretException($e44114412)) {
$e44114412.pyretStack.push(L[358]);
}
throw $e44114412;
}
var $ret44174418 = $Hanf_arg10574422($z44134414,self414348,_plus8,torepr14);
++R.GAS;
return $ret44174418;
};
var $Hanf_arg10574422 = function(anf_arg2874421,self414348,_plus8,torepr14) {
var anf_arg2884433 = G(self414348,"has-hardline",L[358]);
var $z44254426 = D;
var $f44314432 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2884433):R.ffi.throwNonFunApp(L[358],torepr14,[anf_arg2884433]);
};
try {
if(--R.GAS > 0) {
$z44254426 = $f44314432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44314432,
"from":L[358]});
}
} catch($e44234424) {
if(R.isCont($e44234424)) {
var $ss44274428 = {"from":L[358],
"go":function(anf_arg2894434) {
return $Hanf_arg10564435(anf_arg2894434,anf_arg2874421,_plus8);
}};
$e44234424.stack[R.EXN_STACKHEIGHT++] = $ss44274428;
}
if(R.isPyretException($e44234424)) {
$e44234424.pyretStack.push(L[358]);
}
throw $e44234424;
}
var $ret44294430 = $Hanf_arg10564435($z44254426,anf_arg2874421,_plus8);
++R.GAS;
return $ret44294430;
};
var $Hanf_arg10564435 = function(anf_arg2894434,anf_arg2874421,_plus8) {
var $z44384439 = D;
var $f44444445 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2894434):R.ffi.throwNonFunApp(L[358],_plus8,[(", "),anf_arg2894434]);
};
try {
if(--R.GAS > 0) {
$z44384439 = $f44444445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44444445,
"from":L[358]});
}
} catch($e44364437) {
if(R.isCont($e44364437)) {
var $ss44404441 = {"from":L[358],
"go":function(anf_arg2904446) {
return $Hanf_arg10554447(anf_arg2904446,anf_arg2874421,_plus8);
}};
$e44364437.stack[R.EXN_STACKHEIGHT++] = $ss44404441;
}
if(R.isPyretException($e44364437)) {
$e44364437.pyretStack.push(L[358]);
}
throw $e44364437;
}
var $ret44424443 = $Hanf_arg10554447($z44384439,anf_arg2874421,_plus8);
++R.GAS;
return $ret44424443;
};
var $Hanf_arg10554447 = function(anf_arg2904446,anf_arg2874421,_plus8) {
var $z44504451 = D;
var $f44564457 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2874421,anf_arg2904446):R.ffi.throwNonFunApp(L[358],_plus8,[anf_arg2874421,anf_arg2904446]);
};
try {
if(--R.GAS > 0) {
$z44504451 = $f44564457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44564457,
"from":L[358]});
}
} catch($e44484449) {
if(R.isCont($e44484449)) {
var $ss44524453 = {"from":L[358],
"go":function(anf_arg2914458) {
return $Hanf_arg10544459(anf_arg2914458,_plus8);
}};
$e44484449.stack[R.EXN_STACKHEIGHT++] = $ss44524453;
}
if(R.isPyretException($e44484449)) {
$e44484449.pyretStack.push(L[358]);
}
throw $e44484449;
}
var $ret44544455 = $Hanf_arg10544459($z44504451,_plus8);
++R.GAS;
return $ret44544455;
};
var $Hanf_arg10544459 = function(anf_arg2914458,_plus8) {
var $z44624463 = D;
var $f44684469 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2914458,(")")):R.ffi.throwNonFunApp(L[358],_plus8,[anf_arg2914458,(")")]);
};
try {
if(--R.GAS > 0) {
$z44624463 = $f44684469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44684469,
"from":L[358]});
}
} catch($e44604461) {
if(R.isCont($e44604461)) {
var $ss44644465 = {"from":L[358],
"go":function(anf_arg2924470) {
return $Hanf_arg10534471(anf_arg2924470,_plus8);
}};
$e44604461.stack[R.EXN_STACKHEIGHT++] = $ss44644465;
}
if(R.isPyretException($e44604461)) {
$e44604461.pyretStack.push(L[358]);
}
throw $e44604461;
}
var $ret44664467 = $Hanf_arg10534471($z44624463,_plus8);
++R.GAS;
return $ret44664467;
};
var $Hanf_arg10534471 = function(anf_arg2924470,_plus8) {
var $z44744475 = D;
var $f44804481 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg2924470):R.ffi.throwNonFunApp(L[358],_plus8,[("("),anf_arg2924470]);
};
try {
if(--R.GAS > 0) {
$z44744475 = $f44804481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44804481,
"from":L[358]});
}
} catch($e44724473) {
if(R.isCont($e44724473)) {
var $ss44764477 = {"from":L[358],
"go":function(anf_arg2934482) {
return $Hanf_arg10524483(anf_arg2934482,_plus8);
}};
$e44724473.stack[R.EXN_STACKHEIGHT++] = $ss44764477;
}
if(R.isPyretException($e44724473)) {
$e44724473.pyretStack.push(L[358]);
}
throw $e44724473;
}
var $ret44784479 = $Hanf_arg10524483($z44744475,_plus8);
++R.GAS;
return $ret44784479;
};
var $Hanf_arg10524483 = function(anf_arg2934482,_plus8) {
var $z44864487 = D;
var $f44924493 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("if-flat"),anf_arg2934482):R.ffi.throwNonFunApp(L[358],_plus8,[("if-flat"),anf_arg2934482]);
};
try {
if(--R.GAS > 0) {
$z44864487 = $f44924493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44924493,
"from":L[358]});
}
} catch($e44844485) {
if(R.isCont($e44844485)) {
var $ss44884489 = {"from":L[358],
"go":function(ann_DASH_check_DASH_temp2774494) {
return $Hann_DASH_check_DASH_temp10514495(ann_DASH_check_DASH_temp2774494);
}};
$e44844485.stack[R.EXN_STACKHEIGHT++] = $ss44884489;
}
if(R.isPyretException($e44844485)) {
$e44844485.pyretStack.push(L[358]);
}
throw $e44844485;
}
var $ret44904491 = $Hann_DASH_check_DASH_temp10514495($z44864487);
++R.GAS;
return $ret44904491;
};
var $Hann_DASH_check_DASH_temp10514495 = function(ann_DASH_check_DASH_temp2774494) {
return ann_DASH_check_DASH_temp2774494;
};
var $Hcont_tail_arg10494496 = function(cont_tail_arg2744497,if_helper2634498) {
if(--R.GAS > 0) {
$z44994500 = R.isFunction(if_helper2634498)?if_helper2634498.app(cont_tail_arg2744497):R.ffi.throwNonFunApp(L[358],if_helper2634498,[cont_tail_arg2744497]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2634498)?if_helper2634498.app(cont_tail_arg2744497):R.ffi.throwNonFunApp(L[358],if_helper2634498,[cont_tail_arg2744497]);
},
"from":L[358]});
}
++R.GAS;
return $z44994500;
};
var $Hcont_tail_arg10504501 = function(cont_tail_arg2684502,if_helper2634498) {
if(--R.GAS > 0) {
$z45034504 = R.isFunction(if_helper2634498)?if_helper2634498.app(cont_tail_arg2684502):R.ffi.throwNonFunApp(L[358],if_helper2634498,[cont_tail_arg2684502]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2634498)?if_helper2634498.app(cont_tail_arg2684502):R.ffi.throwNonFunApp(L[358],if_helper2634498,[cont_tail_arg2684502]);
},
"from":L[358]});
}
++R.GAS;
return $z45034504;
};
var $Hanf_arg10484505 = function(anf_arg2464506,self354507,_plus8,torepr14) {
var anf_arg2474518 = G(self354507,"d",L[359]);
var $z45104511 = D;
var $f45164517 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2474518):R.ffi.throwNonFunApp(L[359],torepr14,[anf_arg2474518]);
};
try {
if(--R.GAS > 0) {
$z45104511 = $f45164517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45164517,
"from":L[359]});
}
} catch($e45084509) {
if(R.isCont($e45084509)) {
var $ss45124513 = {"from":L[359],
"go":function(anf_arg2484519) {
return $Hanf_arg10474520(anf_arg2484519,anf_arg2464506,self354507,_plus8,torepr14);
}};
$e45084509.stack[R.EXN_STACKHEIGHT++] = $ss45124513;
}
if(R.isPyretException($e45084509)) {
$e45084509.pyretStack.push(L[359]);
}
throw $e45084509;
}
var $ret45144515 = $Hanf_arg10474520($z45104511,anf_arg2464506,self354507,_plus8,torepr14);
++R.GAS;
return $ret45144515;
};
var $Hanf_arg10474520 = function(anf_arg2484519,anf_arg2464506,self354507,_plus8,torepr14) {
var $z45234524 = D;
var $f45294530 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2484519):R.ffi.throwNonFunApp(L[359],_plus8,[(", "),anf_arg2484519]);
};
try {
if(--R.GAS > 0) {
$z45234524 = $f45294530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45294530,
"from":L[359]});
}
} catch($e45214522) {
if(R.isCont($e45214522)) {
var $ss45254526 = {"from":L[359],
"go":function(anf_arg2494531) {
return $Hanf_arg10464532(anf_arg2494531,anf_arg2464506,self354507,_plus8,torepr14);
}};
$e45214522.stack[R.EXN_STACKHEIGHT++] = $ss45254526;
}
if(R.isPyretException($e45214522)) {
$e45214522.pyretStack.push(L[359]);
}
throw $e45214522;
}
var $ret45274528 = $Hanf_arg10464532($z45234524,anf_arg2464506,self354507,_plus8,torepr14);
++R.GAS;
return $ret45274528;
};
var $Hanf_arg10464532 = function(anf_arg2494531,anf_arg2464506,self354507,_plus8,torepr14) {
var $z45354536 = D;
var $f45414542 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2464506,anf_arg2494531):R.ffi.throwNonFunApp(L[359],_plus8,[anf_arg2464506,anf_arg2494531]);
};
try {
if(--R.GAS > 0) {
$z45354536 = $f45414542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45414542,
"from":L[359]});
}
} catch($e45334534) {
if(R.isCont($e45334534)) {
var $ss45374538 = {"from":L[359],
"go":function(anf_arg2504543) {
return $Hanf_arg10454544(anf_arg2504543,self354507,_plus8,torepr14);
}};
$e45334534.stack[R.EXN_STACKHEIGHT++] = $ss45374538;
}
if(R.isPyretException($e45334534)) {
$e45334534.pyretStack.push(L[359]);
}
throw $e45334534;
}
var $ret45394540 = $Hanf_arg10454544($z45354536,self354507,_plus8,torepr14);
++R.GAS;
return $ret45394540;
};
var $Hanf_arg10454544 = function(anf_arg2504543,self354507,_plus8,torepr14) {
var anf_arg2514555 = G(self354507,"flat-width",L[359]);
var $z45474548 = D;
var $f45534554 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2514555):R.ffi.throwNonFunApp(L[359],torepr14,[anf_arg2514555]);
};
try {
if(--R.GAS > 0) {
$z45474548 = $f45534554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45534554,
"from":L[359]});
}
} catch($e45454546) {
if(R.isCont($e45454546)) {
var $ss45494550 = {"from":L[359],
"go":function(anf_arg2524556) {
return $Hanf_arg10444557(anf_arg2524556,anf_arg2504543,self354507,_plus8,torepr14);
}};
$e45454546.stack[R.EXN_STACKHEIGHT++] = $ss45494550;
}
if(R.isPyretException($e45454546)) {
$e45454546.pyretStack.push(L[359]);
}
throw $e45454546;
}
var $ret45514552 = $Hanf_arg10444557($z45474548,anf_arg2504543,self354507,_plus8,torepr14);
++R.GAS;
return $ret45514552;
};
var $Hanf_arg10444557 = function(anf_arg2524556,anf_arg2504543,self354507,_plus8,torepr14) {
var $z45604561 = D;
var $f45664567 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2524556):R.ffi.throwNonFunApp(L[359],_plus8,[(", "),anf_arg2524556]);
};
try {
if(--R.GAS > 0) {
$z45604561 = $f45664567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45664567,
"from":L[359]});
}
} catch($e45584559) {
if(R.isCont($e45584559)) {
var $ss45624563 = {"from":L[359],
"go":function(anf_arg2534568) {
return $Hanf_arg10434569(anf_arg2534568,anf_arg2504543,self354507,_plus8,torepr14);
}};
$e45584559.stack[R.EXN_STACKHEIGHT++] = $ss45624563;
}
if(R.isPyretException($e45584559)) {
$e45584559.pyretStack.push(L[359]);
}
throw $e45584559;
}
var $ret45644565 = $Hanf_arg10434569($z45604561,anf_arg2504543,self354507,_plus8,torepr14);
++R.GAS;
return $ret45644565;
};
var $Hanf_arg10434569 = function(anf_arg2534568,anf_arg2504543,self354507,_plus8,torepr14) {
var $z45724573 = D;
var $f45784579 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2504543,anf_arg2534568):R.ffi.throwNonFunApp(L[359],_plus8,[anf_arg2504543,anf_arg2534568]);
};
try {
if(--R.GAS > 0) {
$z45724573 = $f45784579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45784579,
"from":L[359]});
}
} catch($e45704571) {
if(R.isCont($e45704571)) {
var $ss45744575 = {"from":L[359],
"go":function(anf_arg2544580) {
return $Hanf_arg10424581(anf_arg2544580,self354507,_plus8,torepr14);
}};
$e45704571.stack[R.EXN_STACKHEIGHT++] = $ss45744575;
}
if(R.isPyretException($e45704571)) {
$e45704571.pyretStack.push(L[359]);
}
throw $e45704571;
}
var $ret45764577 = $Hanf_arg10424581($z45724573,self354507,_plus8,torepr14);
++R.GAS;
return $ret45764577;
};
var $Hanf_arg10424581 = function(anf_arg2544580,self354507,_plus8,torepr14) {
var anf_arg2554592 = G(self354507,"has-hardline",L[359]);
var $z45844585 = D;
var $f45904591 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2554592):R.ffi.throwNonFunApp(L[359],torepr14,[anf_arg2554592]);
};
try {
if(--R.GAS > 0) {
$z45844585 = $f45904591();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45904591,
"from":L[359]});
}
} catch($e45824583) {
if(R.isCont($e45824583)) {
var $ss45864587 = {"from":L[359],
"go":function(anf_arg2564593) {
return $Hanf_arg10414594(anf_arg2564593,anf_arg2544580,_plus8);
}};
$e45824583.stack[R.EXN_STACKHEIGHT++] = $ss45864587;
}
if(R.isPyretException($e45824583)) {
$e45824583.pyretStack.push(L[359]);
}
throw $e45824583;
}
var $ret45884589 = $Hanf_arg10414594($z45844585,anf_arg2544580,_plus8);
++R.GAS;
return $ret45884589;
};
var $Hanf_arg10414594 = function(anf_arg2564593,anf_arg2544580,_plus8) {
var $z45974598 = D;
var $f46034604 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2564593):R.ffi.throwNonFunApp(L[359],_plus8,[(", "),anf_arg2564593]);
};
try {
if(--R.GAS > 0) {
$z45974598 = $f46034604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46034604,
"from":L[359]});
}
} catch($e45954596) {
if(R.isCont($e45954596)) {
var $ss45994600 = {"from":L[359],
"go":function(anf_arg2574605) {
return $Hanf_arg10404606(anf_arg2574605,anf_arg2544580,_plus8);
}};
$e45954596.stack[R.EXN_STACKHEIGHT++] = $ss45994600;
}
if(R.isPyretException($e45954596)) {
$e45954596.pyretStack.push(L[359]);
}
throw $e45954596;
}
var $ret46014602 = $Hanf_arg10404606($z45974598,anf_arg2544580,_plus8);
++R.GAS;
return $ret46014602;
};
var $Hanf_arg10404606 = function(anf_arg2574605,anf_arg2544580,_plus8) {
var $z46094610 = D;
var $f46154616 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2544580,anf_arg2574605):R.ffi.throwNonFunApp(L[359],_plus8,[anf_arg2544580,anf_arg2574605]);
};
try {
if(--R.GAS > 0) {
$z46094610 = $f46154616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46154616,
"from":L[359]});
}
} catch($e46074608) {
if(R.isCont($e46074608)) {
var $ss46114612 = {"from":L[359],
"go":function(anf_arg2584617) {
return $Hanf_arg10394618(anf_arg2584617,_plus8);
}};
$e46074608.stack[R.EXN_STACKHEIGHT++] = $ss46114612;
}
if(R.isPyretException($e46074608)) {
$e46074608.pyretStack.push(L[359]);
}
throw $e46074608;
}
var $ret46134614 = $Hanf_arg10394618($z46094610,_plus8);
++R.GAS;
return $ret46134614;
};
var $Hanf_arg10394618 = function(anf_arg2584617,_plus8) {
var $z46214622 = D;
var $f46274628 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2584617,(")")):R.ffi.throwNonFunApp(L[359],_plus8,[anf_arg2584617,(")")]);
};
try {
if(--R.GAS > 0) {
$z46214622 = $f46274628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46274628,
"from":L[359]});
}
} catch($e46194620) {
if(R.isCont($e46194620)) {
var $ss46234624 = {"from":L[359],
"go":function(anf_arg2594629) {
return $Hanf_arg10384630(anf_arg2594629,_plus8);
}};
$e46194620.stack[R.EXN_STACKHEIGHT++] = $ss46234624;
}
if(R.isPyretException($e46194620)) {
$e46194620.pyretStack.push(L[359]);
}
throw $e46194620;
}
var $ret46254626 = $Hanf_arg10384630($z46214622,_plus8);
++R.GAS;
return $ret46254626;
};
var $Hanf_arg10384630 = function(anf_arg2594629,_plus8) {
var $z46334634 = D;
var $f46394640 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg2594629):R.ffi.throwNonFunApp(L[359],_plus8,[("("),anf_arg2594629]);
};
try {
if(--R.GAS > 0) {
$z46334634 = $f46394640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46394640,
"from":L[359]});
}
} catch($e46314632) {
if(R.isCont($e46314632)) {
var $ss46354636 = {"from":L[359],
"go":function(anf_arg2604641) {
return $Hanf_arg10374642(anf_arg2604641,_plus8);
}};
$e46314632.stack[R.EXN_STACKHEIGHT++] = $ss46354636;
}
if(R.isPyretException($e46314632)) {
$e46314632.pyretStack.push(L[359]);
}
throw $e46314632;
}
var $ret46374638 = $Hanf_arg10374642($z46334634,_plus8);
++R.GAS;
return $ret46374638;
};
var $Hanf_arg10374642 = function(anf_arg2604641,_plus8) {
var $z46454646 = D;
var $f46514652 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("nest"),anf_arg2604641):R.ffi.throwNonFunApp(L[359],_plus8,[("nest"),anf_arg2604641]);
};
try {
if(--R.GAS > 0) {
$z46454646 = $f46514652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46514652,
"from":L[359]});
}
} catch($e46434644) {
if(R.isCont($e46434644)) {
var $ss46474648 = {"from":L[359],
"go":function(ann_DASH_check_DASH_temp2444653) {
return $Hann_DASH_check_DASH_temp10364654(ann_DASH_check_DASH_temp2444653);
}};
$e46434644.stack[R.EXN_STACKHEIGHT++] = $ss46474648;
}
if(R.isPyretException($e46434644)) {
$e46434644.pyretStack.push(L[359]);
}
throw $e46434644;
}
var $ret46494650 = $Hann_DASH_check_DASH_temp10364654($z46454646);
++R.GAS;
return $ret46494650;
};
var $Hann_DASH_check_DASH_temp10364654 = function(ann_DASH_check_DASH_temp2444653) {
return ann_DASH_check_DASH_temp2444653;
};
var $Hcont_tail_arg10344655 = function(cont_tail_arg2414656,if_helper2304657) {
if(--R.GAS > 0) {
$z46584659 = R.isFunction(if_helper2304657)?if_helper2304657.app(cont_tail_arg2414656):R.ffi.throwNonFunApp(L[359],if_helper2304657,[cont_tail_arg2414656]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2304657)?if_helper2304657.app(cont_tail_arg2414656):R.ffi.throwNonFunApp(L[359],if_helper2304657,[cont_tail_arg2414656]);
},
"from":L[359]});
}
++R.GAS;
return $z46584659;
};
var $Hcont_tail_arg10354660 = function(cont_tail_arg2354661,if_helper2304657) {
if(--R.GAS > 0) {
$z46624663 = R.isFunction(if_helper2304657)?if_helper2304657.app(cont_tail_arg2354661):R.ffi.throwNonFunApp(L[359],if_helper2304657,[cont_tail_arg2354661]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2304657)?if_helper2304657.app(cont_tail_arg2354661):R.ffi.throwNonFunApp(L[359],if_helper2304657,[cont_tail_arg2354661]);
},
"from":L[359]});
}
++R.GAS;
return $z46624663;
};
var $Hanf_arg10334664 = function(anf_arg2134665,self294666,_plus8,torepr14) {
var anf_arg2144677 = G(self294666,"snd",L[360]);
var $z46694670 = D;
var $f46754676 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2144677):R.ffi.throwNonFunApp(L[360],torepr14,[anf_arg2144677]);
};
try {
if(--R.GAS > 0) {
$z46694670 = $f46754676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46754676,
"from":L[360]});
}
} catch($e46674668) {
if(R.isCont($e46674668)) {
var $ss46714672 = {"from":L[360],
"go":function(anf_arg2154678) {
return $Hanf_arg10324679(anf_arg2154678,anf_arg2134665,self294666,_plus8,torepr14);
}};
$e46674668.stack[R.EXN_STACKHEIGHT++] = $ss46714672;
}
if(R.isPyretException($e46674668)) {
$e46674668.pyretStack.push(L[360]);
}
throw $e46674668;
}
var $ret46734674 = $Hanf_arg10324679($z46694670,anf_arg2134665,self294666,_plus8,torepr14);
++R.GAS;
return $ret46734674;
};
var $Hanf_arg10324679 = function(anf_arg2154678,anf_arg2134665,self294666,_plus8,torepr14) {
var $z46824683 = D;
var $f46884689 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2154678):R.ffi.throwNonFunApp(L[360],_plus8,[(", "),anf_arg2154678]);
};
try {
if(--R.GAS > 0) {
$z46824683 = $f46884689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46884689,
"from":L[360]});
}
} catch($e46804681) {
if(R.isCont($e46804681)) {
var $ss46844685 = {"from":L[360],
"go":function(anf_arg2164690) {
return $Hanf_arg10314691(anf_arg2164690,anf_arg2134665,self294666,_plus8,torepr14);
}};
$e46804681.stack[R.EXN_STACKHEIGHT++] = $ss46844685;
}
if(R.isPyretException($e46804681)) {
$e46804681.pyretStack.push(L[360]);
}
throw $e46804681;
}
var $ret46864687 = $Hanf_arg10314691($z46824683,anf_arg2134665,self294666,_plus8,torepr14);
++R.GAS;
return $ret46864687;
};
var $Hanf_arg10314691 = function(anf_arg2164690,anf_arg2134665,self294666,_plus8,torepr14) {
var $z46944695 = D;
var $f47004701 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2134665,anf_arg2164690):R.ffi.throwNonFunApp(L[360],_plus8,[anf_arg2134665,anf_arg2164690]);
};
try {
if(--R.GAS > 0) {
$z46944695 = $f47004701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47004701,
"from":L[360]});
}
} catch($e46924693) {
if(R.isCont($e46924693)) {
var $ss46964697 = {"from":L[360],
"go":function(anf_arg2174702) {
return $Hanf_arg10304703(anf_arg2174702,self294666,_plus8,torepr14);
}};
$e46924693.stack[R.EXN_STACKHEIGHT++] = $ss46964697;
}
if(R.isPyretException($e46924693)) {
$e46924693.pyretStack.push(L[360]);
}
throw $e46924693;
}
var $ret46984699 = $Hanf_arg10304703($z46944695,self294666,_plus8,torepr14);
++R.GAS;
return $ret46984699;
};
var $Hanf_arg10304703 = function(anf_arg2174702,self294666,_plus8,torepr14) {
var anf_arg2184714 = G(self294666,"flat-width",L[360]);
var $z47064707 = D;
var $f47124713 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2184714):R.ffi.throwNonFunApp(L[360],torepr14,[anf_arg2184714]);
};
try {
if(--R.GAS > 0) {
$z47064707 = $f47124713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47124713,
"from":L[360]});
}
} catch($e47044705) {
if(R.isCont($e47044705)) {
var $ss47084709 = {"from":L[360],
"go":function(anf_arg2194715) {
return $Hanf_arg10294716(anf_arg2194715,anf_arg2174702,self294666,_plus8,torepr14);
}};
$e47044705.stack[R.EXN_STACKHEIGHT++] = $ss47084709;
}
if(R.isPyretException($e47044705)) {
$e47044705.pyretStack.push(L[360]);
}
throw $e47044705;
}
var $ret47104711 = $Hanf_arg10294716($z47064707,anf_arg2174702,self294666,_plus8,torepr14);
++R.GAS;
return $ret47104711;
};
var $Hanf_arg10294716 = function(anf_arg2194715,anf_arg2174702,self294666,_plus8,torepr14) {
var $z47194720 = D;
var $f47254726 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2194715):R.ffi.throwNonFunApp(L[360],_plus8,[(", "),anf_arg2194715]);
};
try {
if(--R.GAS > 0) {
$z47194720 = $f47254726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47254726,
"from":L[360]});
}
} catch($e47174718) {
if(R.isCont($e47174718)) {
var $ss47214722 = {"from":L[360],
"go":function(anf_arg2204727) {
return $Hanf_arg10284728(anf_arg2204727,anf_arg2174702,self294666,_plus8,torepr14);
}};
$e47174718.stack[R.EXN_STACKHEIGHT++] = $ss47214722;
}
if(R.isPyretException($e47174718)) {
$e47174718.pyretStack.push(L[360]);
}
throw $e47174718;
}
var $ret47234724 = $Hanf_arg10284728($z47194720,anf_arg2174702,self294666,_plus8,torepr14);
++R.GAS;
return $ret47234724;
};
var $Hanf_arg10284728 = function(anf_arg2204727,anf_arg2174702,self294666,_plus8,torepr14) {
var $z47314732 = D;
var $f47374738 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2174702,anf_arg2204727):R.ffi.throwNonFunApp(L[360],_plus8,[anf_arg2174702,anf_arg2204727]);
};
try {
if(--R.GAS > 0) {
$z47314732 = $f47374738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47374738,
"from":L[360]});
}
} catch($e47294730) {
if(R.isCont($e47294730)) {
var $ss47334734 = {"from":L[360],
"go":function(anf_arg2214739) {
return $Hanf_arg10274740(anf_arg2214739,self294666,_plus8,torepr14);
}};
$e47294730.stack[R.EXN_STACKHEIGHT++] = $ss47334734;
}
if(R.isPyretException($e47294730)) {
$e47294730.pyretStack.push(L[360]);
}
throw $e47294730;
}
var $ret47354736 = $Hanf_arg10274740($z47314732,self294666,_plus8,torepr14);
++R.GAS;
return $ret47354736;
};
var $Hanf_arg10274740 = function(anf_arg2214739,self294666,_plus8,torepr14) {
var anf_arg2224751 = G(self294666,"has-hardline",L[360]);
var $z47434744 = D;
var $f47494750 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2224751):R.ffi.throwNonFunApp(L[360],torepr14,[anf_arg2224751]);
};
try {
if(--R.GAS > 0) {
$z47434744 = $f47494750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47494750,
"from":L[360]});
}
} catch($e47414742) {
if(R.isCont($e47414742)) {
var $ss47454746 = {"from":L[360],
"go":function(anf_arg2234752) {
return $Hanf_arg10264753(anf_arg2234752,anf_arg2214739,_plus8);
}};
$e47414742.stack[R.EXN_STACKHEIGHT++] = $ss47454746;
}
if(R.isPyretException($e47414742)) {
$e47414742.pyretStack.push(L[360]);
}
throw $e47414742;
}
var $ret47474748 = $Hanf_arg10264753($z47434744,anf_arg2214739,_plus8);
++R.GAS;
return $ret47474748;
};
var $Hanf_arg10264753 = function(anf_arg2234752,anf_arg2214739,_plus8) {
var $z47564757 = D;
var $f47624763 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg2234752):R.ffi.throwNonFunApp(L[360],_plus8,[(", "),anf_arg2234752]);
};
try {
if(--R.GAS > 0) {
$z47564757 = $f47624763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47624763,
"from":L[360]});
}
} catch($e47544755) {
if(R.isCont($e47544755)) {
var $ss47584759 = {"from":L[360],
"go":function(anf_arg2244764) {
return $Hanf_arg10254765(anf_arg2244764,anf_arg2214739,_plus8);
}};
$e47544755.stack[R.EXN_STACKHEIGHT++] = $ss47584759;
}
if(R.isPyretException($e47544755)) {
$e47544755.pyretStack.push(L[360]);
}
throw $e47544755;
}
var $ret47604761 = $Hanf_arg10254765($z47564757,anf_arg2214739,_plus8);
++R.GAS;
return $ret47604761;
};
var $Hanf_arg10254765 = function(anf_arg2244764,anf_arg2214739,_plus8) {
var $z47684769 = D;
var $f47744775 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2214739,anf_arg2244764):R.ffi.throwNonFunApp(L[360],_plus8,[anf_arg2214739,anf_arg2244764]);
};
try {
if(--R.GAS > 0) {
$z47684769 = $f47744775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47744775,
"from":L[360]});
}
} catch($e47664767) {
if(R.isCont($e47664767)) {
var $ss47704771 = {"from":L[360],
"go":function(anf_arg2254776) {
return $Hanf_arg10244777(anf_arg2254776,_plus8);
}};
$e47664767.stack[R.EXN_STACKHEIGHT++] = $ss47704771;
}
if(R.isPyretException($e47664767)) {
$e47664767.pyretStack.push(L[360]);
}
throw $e47664767;
}
var $ret47724773 = $Hanf_arg10244777($z47684769,_plus8);
++R.GAS;
return $ret47724773;
};
var $Hanf_arg10244777 = function(anf_arg2254776,_plus8) {
var $z47804781 = D;
var $f47864787 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg2254776,(")")):R.ffi.throwNonFunApp(L[360],_plus8,[anf_arg2254776,(")")]);
};
try {
if(--R.GAS > 0) {
$z47804781 = $f47864787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47864787,
"from":L[360]});
}
} catch($e47784779) {
if(R.isCont($e47784779)) {
var $ss47824783 = {"from":L[360],
"go":function(anf_arg2264788) {
return $Hanf_arg10234789(anf_arg2264788,_plus8);
}};
$e47784779.stack[R.EXN_STACKHEIGHT++] = $ss47824783;
}
if(R.isPyretException($e47784779)) {
$e47784779.pyretStack.push(L[360]);
}
throw $e47784779;
}
var $ret47844785 = $Hanf_arg10234789($z47804781,_plus8);
++R.GAS;
return $ret47844785;
};
var $Hanf_arg10234789 = function(anf_arg2264788,_plus8) {
var $z47924793 = D;
var $f47984799 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg2264788):R.ffi.throwNonFunApp(L[360],_plus8,[("("),anf_arg2264788]);
};
try {
if(--R.GAS > 0) {
$z47924793 = $f47984799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47984799,
"from":L[360]});
}
} catch($e47904791) {
if(R.isCont($e47904791)) {
var $ss47944795 = {"from":L[360],
"go":function(anf_arg2274800) {
return $Hanf_arg10224801(anf_arg2274800,_plus8);
}};
$e47904791.stack[R.EXN_STACKHEIGHT++] = $ss47944795;
}
if(R.isPyretException($e47904791)) {
$e47904791.pyretStack.push(L[360]);
}
throw $e47904791;
}
var $ret47964797 = $Hanf_arg10224801($z47924793,_plus8);
++R.GAS;
return $ret47964797;
};
var $Hanf_arg10224801 = function(anf_arg2274800,_plus8) {
var $z48044805 = D;
var $f48104811 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("concat"),anf_arg2274800):R.ffi.throwNonFunApp(L[360],_plus8,[("concat"),anf_arg2274800]);
};
try {
if(--R.GAS > 0) {
$z48044805 = $f48104811();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48104811,
"from":L[360]});
}
} catch($e48024803) {
if(R.isCont($e48024803)) {
var $ss48064807 = {"from":L[360],
"go":function(ann_DASH_check_DASH_temp2114812) {
return $Hann_DASH_check_DASH_temp10214813(ann_DASH_check_DASH_temp2114812);
}};
$e48024803.stack[R.EXN_STACKHEIGHT++] = $ss48064807;
}
if(R.isPyretException($e48024803)) {
$e48024803.pyretStack.push(L[360]);
}
throw $e48024803;
}
var $ret48084809 = $Hann_DASH_check_DASH_temp10214813($z48044805);
++R.GAS;
return $ret48084809;
};
var $Hann_DASH_check_DASH_temp10214813 = function(ann_DASH_check_DASH_temp2114812) {
return ann_DASH_check_DASH_temp2114812;
};
var $Hcont_tail_arg10194814 = function(cont_tail_arg2084815,if_helper1974816) {
if(--R.GAS > 0) {
$z48174818 = R.isFunction(if_helper1974816)?if_helper1974816.app(cont_tail_arg2084815):R.ffi.throwNonFunApp(L[360],if_helper1974816,[cont_tail_arg2084815]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1974816)?if_helper1974816.app(cont_tail_arg2084815):R.ffi.throwNonFunApp(L[360],if_helper1974816,[cont_tail_arg2084815]);
},
"from":L[360]});
}
++R.GAS;
return $z48174818;
};
var $Hcont_tail_arg10204819 = function(cont_tail_arg2024820,if_helper1974816) {
if(--R.GAS > 0) {
$z48214822 = R.isFunction(if_helper1974816)?if_helper1974816.app(cont_tail_arg2024820):R.ffi.throwNonFunApp(L[360],if_helper1974816,[cont_tail_arg2024820]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1974816)?if_helper1974816.app(cont_tail_arg2024820):R.ffi.throwNonFunApp(L[360],if_helper1974816,[cont_tail_arg2024820]);
},
"from":L[360]});
}
++R.GAS;
return $z48214822;
};
var $Hanf_arg10184823 = function(anf_arg1844824,self234825,_plus8,torepr14) {
var anf_arg1854836 = G(self234825,"flat-width",L[361]);
var $z48284829 = D;
var $f48344835 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1854836):R.ffi.throwNonFunApp(L[361],torepr14,[anf_arg1854836]);
};
try {
if(--R.GAS > 0) {
$z48284829 = $f48344835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48344835,
"from":L[361]});
}
} catch($e48264827) {
if(R.isCont($e48264827)) {
var $ss48304831 = {"from":L[361],
"go":function(anf_arg1864837) {
return $Hanf_arg10174838(anf_arg1864837,anf_arg1844824,self234825,_plus8,torepr14);
}};
$e48264827.stack[R.EXN_STACKHEIGHT++] = $ss48304831;
}
if(R.isPyretException($e48264827)) {
$e48264827.pyretStack.push(L[361]);
}
throw $e48264827;
}
var $ret48324833 = $Hanf_arg10174838($z48284829,anf_arg1844824,self234825,_plus8,torepr14);
++R.GAS;
return $ret48324833;
};
var $Hanf_arg10174838 = function(anf_arg1864837,anf_arg1844824,self234825,_plus8,torepr14) {
var $z48414842 = D;
var $f48474848 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg1864837):R.ffi.throwNonFunApp(L[361],_plus8,[(", "),anf_arg1864837]);
};
try {
if(--R.GAS > 0) {
$z48414842 = $f48474848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48474848,
"from":L[361]});
}
} catch($e48394840) {
if(R.isCont($e48394840)) {
var $ss48434844 = {"from":L[361],
"go":function(anf_arg1874849) {
return $Hanf_arg10164850(anf_arg1874849,anf_arg1844824,self234825,_plus8,torepr14);
}};
$e48394840.stack[R.EXN_STACKHEIGHT++] = $ss48434844;
}
if(R.isPyretException($e48394840)) {
$e48394840.pyretStack.push(L[361]);
}
throw $e48394840;
}
var $ret48454846 = $Hanf_arg10164850($z48414842,anf_arg1844824,self234825,_plus8,torepr14);
++R.GAS;
return $ret48454846;
};
var $Hanf_arg10164850 = function(anf_arg1874849,anf_arg1844824,self234825,_plus8,torepr14) {
var $z48534854 = D;
var $f48594860 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1844824,anf_arg1874849):R.ffi.throwNonFunApp(L[361],_plus8,[anf_arg1844824,anf_arg1874849]);
};
try {
if(--R.GAS > 0) {
$z48534854 = $f48594860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48594860,
"from":L[361]});
}
} catch($e48514852) {
if(R.isCont($e48514852)) {
var $ss48554856 = {"from":L[361],
"go":function(anf_arg1884861) {
return $Hanf_arg10154862(anf_arg1884861,self234825,_plus8,torepr14);
}};
$e48514852.stack[R.EXN_STACKHEIGHT++] = $ss48554856;
}
if(R.isPyretException($e48514852)) {
$e48514852.pyretStack.push(L[361]);
}
throw $e48514852;
}
var $ret48574858 = $Hanf_arg10154862($z48534854,self234825,_plus8,torepr14);
++R.GAS;
return $ret48574858;
};
var $Hanf_arg10154862 = function(anf_arg1884861,self234825,_plus8,torepr14) {
var anf_arg1894873 = G(self234825,"has-hardline",L[361]);
var $z48654866 = D;
var $f48714872 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1894873):R.ffi.throwNonFunApp(L[361],torepr14,[anf_arg1894873]);
};
try {
if(--R.GAS > 0) {
$z48654866 = $f48714872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48714872,
"from":L[361]});
}
} catch($e48634864) {
if(R.isCont($e48634864)) {
var $ss48674868 = {"from":L[361],
"go":function(anf_arg1904874) {
return $Hanf_arg10144875(anf_arg1904874,anf_arg1884861,_plus8);
}};
$e48634864.stack[R.EXN_STACKHEIGHT++] = $ss48674868;
}
if(R.isPyretException($e48634864)) {
$e48634864.pyretStack.push(L[361]);
}
throw $e48634864;
}
var $ret48694870 = $Hanf_arg10144875($z48654866,anf_arg1884861,_plus8);
++R.GAS;
return $ret48694870;
};
var $Hanf_arg10144875 = function(anf_arg1904874,anf_arg1884861,_plus8) {
var $z48784879 = D;
var $f48844885 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg1904874):R.ffi.throwNonFunApp(L[361],_plus8,[(", "),anf_arg1904874]);
};
try {
if(--R.GAS > 0) {
$z48784879 = $f48844885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48844885,
"from":L[361]});
}
} catch($e48764877) {
if(R.isCont($e48764877)) {
var $ss48804881 = {"from":L[361],
"go":function(anf_arg1914886) {
return $Hanf_arg10134887(anf_arg1914886,anf_arg1884861,_plus8);
}};
$e48764877.stack[R.EXN_STACKHEIGHT++] = $ss48804881;
}
if(R.isPyretException($e48764877)) {
$e48764877.pyretStack.push(L[361]);
}
throw $e48764877;
}
var $ret48824883 = $Hanf_arg10134887($z48784879,anf_arg1884861,_plus8);
++R.GAS;
return $ret48824883;
};
var $Hanf_arg10134887 = function(anf_arg1914886,anf_arg1884861,_plus8) {
var $z48904891 = D;
var $f48964897 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1884861,anf_arg1914886):R.ffi.throwNonFunApp(L[361],_plus8,[anf_arg1884861,anf_arg1914886]);
};
try {
if(--R.GAS > 0) {
$z48904891 = $f48964897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48964897,
"from":L[361]});
}
} catch($e48884889) {
if(R.isCont($e48884889)) {
var $ss48924893 = {"from":L[361],
"go":function(anf_arg1924898) {
return $Hanf_arg10124899(anf_arg1924898,_plus8);
}};
$e48884889.stack[R.EXN_STACKHEIGHT++] = $ss48924893;
}
if(R.isPyretException($e48884889)) {
$e48884889.pyretStack.push(L[361]);
}
throw $e48884889;
}
var $ret48944895 = $Hanf_arg10124899($z48904891,_plus8);
++R.GAS;
return $ret48944895;
};
var $Hanf_arg10124899 = function(anf_arg1924898,_plus8) {
var $z49024903 = D;
var $f49084909 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1924898,(")")):R.ffi.throwNonFunApp(L[361],_plus8,[anf_arg1924898,(")")]);
};
try {
if(--R.GAS > 0) {
$z49024903 = $f49084909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49084909,
"from":L[361]});
}
} catch($e49004901) {
if(R.isCont($e49004901)) {
var $ss49044905 = {"from":L[361],
"go":function(anf_arg1934910) {
return $Hanf_arg10114911(anf_arg1934910,_plus8);
}};
$e49004901.stack[R.EXN_STACKHEIGHT++] = $ss49044905;
}
if(R.isPyretException($e49004901)) {
$e49004901.pyretStack.push(L[361]);
}
throw $e49004901;
}
var $ret49064907 = $Hanf_arg10114911($z49024903,_plus8);
++R.GAS;
return $ret49064907;
};
var $Hanf_arg10114911 = function(anf_arg1934910,_plus8) {
var $z49144915 = D;
var $f49204921 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg1934910):R.ffi.throwNonFunApp(L[361],_plus8,[("("),anf_arg1934910]);
};
try {
if(--R.GAS > 0) {
$z49144915 = $f49204921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49204921,
"from":L[361]});
}
} catch($e49124913) {
if(R.isCont($e49124913)) {
var $ss49164917 = {"from":L[361],
"go":function(anf_arg1944922) {
return $Hanf_arg10104923(anf_arg1944922,_plus8);
}};
$e49124913.stack[R.EXN_STACKHEIGHT++] = $ss49164917;
}
if(R.isPyretException($e49124913)) {
$e49124913.pyretStack.push(L[361]);
}
throw $e49124913;
}
var $ret49184919 = $Hanf_arg10104923($z49144915,_plus8);
++R.GAS;
return $ret49184919;
};
var $Hanf_arg10104923 = function(anf_arg1944922,_plus8) {
var $z49264927 = D;
var $f49324933 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("blank"),anf_arg1944922):R.ffi.throwNonFunApp(L[361],_plus8,[("blank"),anf_arg1944922]);
};
try {
if(--R.GAS > 0) {
$z49264927 = $f49324933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49324933,
"from":L[361]});
}
} catch($e49244925) {
if(R.isCont($e49244925)) {
var $ss49284929 = {"from":L[361],
"go":function(ann_DASH_check_DASH_temp1824934) {
return $Hann_DASH_check_DASH_temp10094935(ann_DASH_check_DASH_temp1824934);
}};
$e49244925.stack[R.EXN_STACKHEIGHT++] = $ss49284929;
}
if(R.isPyretException($e49244925)) {
$e49244925.pyretStack.push(L[361]);
}
throw $e49244925;
}
var $ret49304931 = $Hann_DASH_check_DASH_temp10094935($z49264927);
++R.GAS;
return $ret49304931;
};
var $Hann_DASH_check_DASH_temp10094935 = function(ann_DASH_check_DASH_temp1824934) {
return ann_DASH_check_DASH_temp1824934;
};
var $Hcont_tail_arg10074936 = function(cont_tail_arg1794937,if_helper1694938) {
if(--R.GAS > 0) {
$z49394940 = R.isFunction(if_helper1694938)?if_helper1694938.app(cont_tail_arg1794937):R.ffi.throwNonFunApp(L[361],if_helper1694938,[cont_tail_arg1794937]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1694938)?if_helper1694938.app(cont_tail_arg1794937):R.ffi.throwNonFunApp(L[361],if_helper1694938,[cont_tail_arg1794937]);
},
"from":L[361]});
}
++R.GAS;
return $z49394940;
};
var $Hcont_tail_arg10084941 = function(cont_tail_arg1744942,if_helper1694938) {
if(--R.GAS > 0) {
$z49434944 = R.isFunction(if_helper1694938)?if_helper1694938.app(cont_tail_arg1744942):R.ffi.throwNonFunApp(L[361],if_helper1694938,[cont_tail_arg1744942]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1694938)?if_helper1694938.app(cont_tail_arg1744942):R.ffi.throwNonFunApp(L[361],if_helper1694938,[cont_tail_arg1744942]);
},
"from":L[361]});
}
++R.GAS;
return $z49434944;
};
var $Hanf_arg10064945 = function(anf_arg1604946,self174947,_plus8,torepr14) {
var anf_arg1614958 = G(self174947,"has-hardline",L[362]);
var $z49504951 = D;
var $f49564957 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1614958):R.ffi.throwNonFunApp(L[362],torepr14,[anf_arg1614958]);
};
try {
if(--R.GAS > 0) {
$z49504951 = $f49564957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49564957,
"from":L[362]});
}
} catch($e49484949) {
if(R.isCont($e49484949)) {
var $ss49524953 = {"from":L[362],
"go":function(anf_arg1624959) {
return $Hanf_arg10054960(anf_arg1624959,anf_arg1604946,_plus8);
}};
$e49484949.stack[R.EXN_STACKHEIGHT++] = $ss49524953;
}
if(R.isPyretException($e49484949)) {
$e49484949.pyretStack.push(L[362]);
}
throw $e49484949;
}
var $ret49544955 = $Hanf_arg10054960($z49504951,anf_arg1604946,_plus8);
++R.GAS;
return $ret49544955;
};
var $Hanf_arg10054960 = function(anf_arg1624959,anf_arg1604946,_plus8) {
var $z49634964 = D;
var $f49694970 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg1624959):R.ffi.throwNonFunApp(L[362],_plus8,[(", "),anf_arg1624959]);
};
try {
if(--R.GAS > 0) {
$z49634964 = $f49694970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49694970,
"from":L[362]});
}
} catch($e49614962) {
if(R.isCont($e49614962)) {
var $ss49654966 = {"from":L[362],
"go":function(anf_arg1634971) {
return $Hanf_arg10044972(anf_arg1634971,anf_arg1604946,_plus8);
}};
$e49614962.stack[R.EXN_STACKHEIGHT++] = $ss49654966;
}
if(R.isPyretException($e49614962)) {
$e49614962.pyretStack.push(L[362]);
}
throw $e49614962;
}
var $ret49674968 = $Hanf_arg10044972($z49634964,anf_arg1604946,_plus8);
++R.GAS;
return $ret49674968;
};
var $Hanf_arg10044972 = function(anf_arg1634971,anf_arg1604946,_plus8) {
var $z49754976 = D;
var $f49814982 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1604946,anf_arg1634971):R.ffi.throwNonFunApp(L[362],_plus8,[anf_arg1604946,anf_arg1634971]);
};
try {
if(--R.GAS > 0) {
$z49754976 = $f49814982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49814982,
"from":L[362]});
}
} catch($e49734974) {
if(R.isCont($e49734974)) {
var $ss49774978 = {"from":L[362],
"go":function(anf_arg1644983) {
return $Hanf_arg10034984(anf_arg1644983,_plus8);
}};
$e49734974.stack[R.EXN_STACKHEIGHT++] = $ss49774978;
}
if(R.isPyretException($e49734974)) {
$e49734974.pyretStack.push(L[362]);
}
throw $e49734974;
}
var $ret49794980 = $Hanf_arg10034984($z49754976,_plus8);
++R.GAS;
return $ret49794980;
};
var $Hanf_arg10034984 = function(anf_arg1644983,_plus8) {
var $z49874988 = D;
var $f49934994 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1644983,(")")):R.ffi.throwNonFunApp(L[362],_plus8,[anf_arg1644983,(")")]);
};
try {
if(--R.GAS > 0) {
$z49874988 = $f49934994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49934994,
"from":L[362]});
}
} catch($e49854986) {
if(R.isCont($e49854986)) {
var $ss49894990 = {"from":L[362],
"go":function(anf_arg1654995) {
return $Hanf_arg10024996(anf_arg1654995,_plus8);
}};
$e49854986.stack[R.EXN_STACKHEIGHT++] = $ss49894990;
}
if(R.isPyretException($e49854986)) {
$e49854986.pyretStack.push(L[362]);
}
throw $e49854986;
}
var $ret49914992 = $Hanf_arg10024996($z49874988,_plus8);
++R.GAS;
return $ret49914992;
};
var $Hanf_arg10024996 = function(anf_arg1654995,_plus8) {
var $z49995000 = D;
var $f50055006 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg1654995):R.ffi.throwNonFunApp(L[362],_plus8,[("("),anf_arg1654995]);
};
try {
if(--R.GAS > 0) {
$z49995000 = $f50055006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50055006,
"from":L[362]});
}
} catch($e49974998) {
if(R.isCont($e49974998)) {
var $ss50015002 = {"from":L[362],
"go":function(anf_arg1665007) {
return $Hanf_arg10015008(anf_arg1665007,_plus8);
}};
$e49974998.stack[R.EXN_STACKHEIGHT++] = $ss50015002;
}
if(R.isPyretException($e49974998)) {
$e49974998.pyretStack.push(L[362]);
}
throw $e49974998;
}
var $ret50035004 = $Hanf_arg10015008($z49995000,_plus8);
++R.GAS;
return $ret50035004;
};
var $Hanf_arg10015008 = function(anf_arg1665007,_plus8) {
var $z50115012 = D;
var $f50175018 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("hardline"),anf_arg1665007):R.ffi.throwNonFunApp(L[362],_plus8,[("hardline"),anf_arg1665007]);
};
try {
if(--R.GAS > 0) {
$z50115012 = $f50175018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50175018,
"from":L[362]});
}
} catch($e50095010) {
if(R.isCont($e50095010)) {
var $ss50135014 = {"from":L[362],
"go":function(ann_DASH_check_DASH_temp1585019) {
return $Hann_DASH_check_DASH_temp10005020(ann_DASH_check_DASH_temp1585019);
}};
$e50095010.stack[R.EXN_STACKHEIGHT++] = $ss50135014;
}
if(R.isPyretException($e50095010)) {
$e50095010.pyretStack.push(L[362]);
}
throw $e50095010;
}
var $ret50155016 = $Hann_DASH_check_DASH_temp10005020($z50115012);
++R.GAS;
return $ret50155016;
};
var $Hann_DASH_check_DASH_temp10005020 = function(ann_DASH_check_DASH_temp1585019) {
return ann_DASH_check_DASH_temp1585019;
};
var $Hcont_tail_arg9985021 = function(cont_tail_arg1555022,if_helper1465023) {
if(--R.GAS > 0) {
$z50245025 = R.isFunction(if_helper1465023)?if_helper1465023.app(cont_tail_arg1555022):R.ffi.throwNonFunApp(L[362],if_helper1465023,[cont_tail_arg1555022]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1465023)?if_helper1465023.app(cont_tail_arg1555022):R.ffi.throwNonFunApp(L[362],if_helper1465023,[cont_tail_arg1555022]);
},
"from":L[362]});
}
++R.GAS;
return $z50245025;
};
var $Hcont_tail_arg9995026 = function(cont_tail_arg1515027,if_helper1465023) {
if(--R.GAS > 0) {
$z50285029 = R.isFunction(if_helper1465023)?if_helper1465023.app(cont_tail_arg1515027):R.ffi.throwNonFunApp(L[362],if_helper1465023,[cont_tail_arg1515027]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1465023)?if_helper1465023.app(cont_tail_arg1515027):R.ffi.throwNonFunApp(L[362],if_helper1465023,[cont_tail_arg1515027]);
},
"from":L[362]});
}
++R.GAS;
return $z50285029;
};
var $Hanf_arg9975030 = function(anf_arg1335031,self115032,_plus8,torepr14) {
var anf_arg1345043 = G(self115032,"flat-width",L[363]);
var $z50355036 = D;
var $f50415042 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1345043):R.ffi.throwNonFunApp(L[363],torepr14,[anf_arg1345043]);
};
try {
if(--R.GAS > 0) {
$z50355036 = $f50415042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50415042,
"from":L[363]});
}
} catch($e50335034) {
if(R.isCont($e50335034)) {
var $ss50375038 = {"from":L[363],
"go":function(anf_arg1355044) {
return $Hanf_arg9965045(anf_arg1355044,anf_arg1335031,self115032,_plus8,torepr14);
}};
$e50335034.stack[R.EXN_STACKHEIGHT++] = $ss50375038;
}
if(R.isPyretException($e50335034)) {
$e50335034.pyretStack.push(L[363]);
}
throw $e50335034;
}
var $ret50395040 = $Hanf_arg9965045($z50355036,anf_arg1335031,self115032,_plus8,torepr14);
++R.GAS;
return $ret50395040;
};
var $Hanf_arg9965045 = function(anf_arg1355044,anf_arg1335031,self115032,_plus8,torepr14) {
var $z50485049 = D;
var $f50545055 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg1355044):R.ffi.throwNonFunApp(L[363],_plus8,[(", "),anf_arg1355044]);
};
try {
if(--R.GAS > 0) {
$z50485049 = $f50545055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50545055,
"from":L[363]});
}
} catch($e50465047) {
if(R.isCont($e50465047)) {
var $ss50505051 = {"from":L[363],
"go":function(anf_arg1365056) {
return $Hanf_arg9955057(anf_arg1365056,anf_arg1335031,self115032,_plus8,torepr14);
}};
$e50465047.stack[R.EXN_STACKHEIGHT++] = $ss50505051;
}
if(R.isPyretException($e50465047)) {
$e50465047.pyretStack.push(L[363]);
}
throw $e50465047;
}
var $ret50525053 = $Hanf_arg9955057($z50485049,anf_arg1335031,self115032,_plus8,torepr14);
++R.GAS;
return $ret50525053;
};
var $Hanf_arg9955057 = function(anf_arg1365056,anf_arg1335031,self115032,_plus8,torepr14) {
var $z50605061 = D;
var $f50665067 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1335031,anf_arg1365056):R.ffi.throwNonFunApp(L[363],_plus8,[anf_arg1335031,anf_arg1365056]);
};
try {
if(--R.GAS > 0) {
$z50605061 = $f50665067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50665067,
"from":L[363]});
}
} catch($e50585059) {
if(R.isCont($e50585059)) {
var $ss50625063 = {"from":L[363],
"go":function(anf_arg1375068) {
return $Hanf_arg9945069(anf_arg1375068,self115032,_plus8,torepr14);
}};
$e50585059.stack[R.EXN_STACKHEIGHT++] = $ss50625063;
}
if(R.isPyretException($e50585059)) {
$e50585059.pyretStack.push(L[363]);
}
throw $e50585059;
}
var $ret50645065 = $Hanf_arg9945069($z50605061,self115032,_plus8,torepr14);
++R.GAS;
return $ret50645065;
};
var $Hanf_arg9945069 = function(anf_arg1375068,self115032,_plus8,torepr14) {
var anf_arg1385080 = G(self115032,"has-hardline",L[363]);
var $z50725073 = D;
var $f50785079 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1385080):R.ffi.throwNonFunApp(L[363],torepr14,[anf_arg1385080]);
};
try {
if(--R.GAS > 0) {
$z50725073 = $f50785079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50785079,
"from":L[363]});
}
} catch($e50705071) {
if(R.isCont($e50705071)) {
var $ss50745075 = {"from":L[363],
"go":function(anf_arg1395081) {
return $Hanf_arg9935082(anf_arg1395081,anf_arg1375068,_plus8);
}};
$e50705071.stack[R.EXN_STACKHEIGHT++] = $ss50745075;
}
if(R.isPyretException($e50705071)) {
$e50705071.pyretStack.push(L[363]);
}
throw $e50705071;
}
var $ret50765077 = $Hanf_arg9935082($z50725073,anf_arg1375068,_plus8);
++R.GAS;
return $ret50765077;
};
var $Hanf_arg9935082 = function(anf_arg1395081,anf_arg1375068,_plus8) {
var $z50855086 = D;
var $f50915092 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg1395081):R.ffi.throwNonFunApp(L[363],_plus8,[(", "),anf_arg1395081]);
};
try {
if(--R.GAS > 0) {
$z50855086 = $f50915092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50915092,
"from":L[363]});
}
} catch($e50835084) {
if(R.isCont($e50835084)) {
var $ss50875088 = {"from":L[363],
"go":function(anf_arg1405093) {
return $Hanf_arg9925094(anf_arg1405093,anf_arg1375068,_plus8);
}};
$e50835084.stack[R.EXN_STACKHEIGHT++] = $ss50875088;
}
if(R.isPyretException($e50835084)) {
$e50835084.pyretStack.push(L[363]);
}
throw $e50835084;
}
var $ret50895090 = $Hanf_arg9925094($z50855086,anf_arg1375068,_plus8);
++R.GAS;
return $ret50895090;
};
var $Hanf_arg9925094 = function(anf_arg1405093,anf_arg1375068,_plus8) {
var $z50975098 = D;
var $f51035104 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1375068,anf_arg1405093):R.ffi.throwNonFunApp(L[363],_plus8,[anf_arg1375068,anf_arg1405093]);
};
try {
if(--R.GAS > 0) {
$z50975098 = $f51035104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51035104,
"from":L[363]});
}
} catch($e50955096) {
if(R.isCont($e50955096)) {
var $ss50995100 = {"from":L[363],
"go":function(anf_arg1415105) {
return $Hanf_arg9915106(anf_arg1415105,_plus8);
}};
$e50955096.stack[R.EXN_STACKHEIGHT++] = $ss50995100;
}
if(R.isPyretException($e50955096)) {
$e50955096.pyretStack.push(L[363]);
}
throw $e50955096;
}
var $ret51015102 = $Hanf_arg9915106($z50975098,_plus8);
++R.GAS;
return $ret51015102;
};
var $Hanf_arg9915106 = function(anf_arg1415105,_plus8) {
var $z51095110 = D;
var $f51155116 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1415105,(")")):R.ffi.throwNonFunApp(L[363],_plus8,[anf_arg1415105,(")")]);
};
try {
if(--R.GAS > 0) {
$z51095110 = $f51155116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51155116,
"from":L[363]});
}
} catch($e51075108) {
if(R.isCont($e51075108)) {
var $ss51115112 = {"from":L[363],
"go":function(anf_arg1425117) {
return $Hanf_arg9905118(anf_arg1425117,_plus8);
}};
$e51075108.stack[R.EXN_STACKHEIGHT++] = $ss51115112;
}
if(R.isPyretException($e51075108)) {
$e51075108.pyretStack.push(L[363]);
}
throw $e51075108;
}
var $ret51135114 = $Hanf_arg9905118($z51095110,_plus8);
++R.GAS;
return $ret51135114;
};
var $Hanf_arg9905118 = function(anf_arg1425117,_plus8) {
var $z51215122 = D;
var $f51275128 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg1425117):R.ffi.throwNonFunApp(L[363],_plus8,[("("),anf_arg1425117]);
};
try {
if(--R.GAS > 0) {
$z51215122 = $f51275128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51275128,
"from":L[363]});
}
} catch($e51195120) {
if(R.isCont($e51195120)) {
var $ss51235124 = {"from":L[363],
"go":function(anf_arg1435129) {
return $Hanf_arg9895130(anf_arg1435129,_plus8);
}};
$e51195120.stack[R.EXN_STACKHEIGHT++] = $ss51235124;
}
if(R.isPyretException($e51195120)) {
$e51195120.pyretStack.push(L[363]);
}
throw $e51195120;
}
var $ret51255126 = $Hanf_arg9895130($z51215122,_plus8);
++R.GAS;
return $ret51255126;
};
var $Hanf_arg9895130 = function(anf_arg1435129,_plus8) {
var $z51335134 = D;
var $f51395140 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("str"),anf_arg1435129):R.ffi.throwNonFunApp(L[363],_plus8,[("str"),anf_arg1435129]);
};
try {
if(--R.GAS > 0) {
$z51335134 = $f51395140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51395140,
"from":L[363]});
}
} catch($e51315132) {
if(R.isCont($e51315132)) {
var $ss51355136 = {"from":L[363],
"go":function(ann_DASH_check_DASH_temp1315141) {
return $Hann_DASH_check_DASH_temp9885142(ann_DASH_check_DASH_temp1315141);
}};
$e51315132.stack[R.EXN_STACKHEIGHT++] = $ss51355136;
}
if(R.isPyretException($e51315132)) {
$e51315132.pyretStack.push(L[363]);
}
throw $e51315132;
}
var $ret51375138 = $Hann_DASH_check_DASH_temp9885142($z51335134);
++R.GAS;
return $ret51375138;
};
var $Hann_DASH_check_DASH_temp9885142 = function(ann_DASH_check_DASH_temp1315141) {
return ann_DASH_check_DASH_temp1315141;
};
var $Hcont_tail_arg9865143 = function(cont_tail_arg1285144,if_helper1185145) {
if(--R.GAS > 0) {
$z51465147 = R.isFunction(if_helper1185145)?if_helper1185145.app(cont_tail_arg1285144):R.ffi.throwNonFunApp(L[363],if_helper1185145,[cont_tail_arg1285144]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1185145)?if_helper1185145.app(cont_tail_arg1285144):R.ffi.throwNonFunApp(L[363],if_helper1185145,[cont_tail_arg1285144]);
},
"from":L[363]});
}
++R.GAS;
return $z51465147;
};
var $Hcont_tail_arg9875148 = function(cont_tail_arg1235149,if_helper1185145) {
if(--R.GAS > 0) {
$z51505151 = R.isFunction(if_helper1185145)?if_helper1185145.app(cont_tail_arg1235149):R.ffi.throwNonFunApp(L[363],if_helper1185145,[cont_tail_arg1235149]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1185145)?if_helper1185145.app(cont_tail_arg1235149):R.ffi.throwNonFunApp(L[363],if_helper1185145,[cont_tail_arg1235149]);
},
"from":L[363]});
}
++R.GAS;
return $z51505151;
};
var $Hanf_arg9855152 = function(anf_arg1095153,self55154,_plus8,torepr14) {
var anf_arg1105165 = G(self55154,"has-hardline",L[364]);
var $z51575158 = D;
var $f51635164 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1105165):R.ffi.throwNonFunApp(L[364],torepr14,[anf_arg1105165]);
};
try {
if(--R.GAS > 0) {
$z51575158 = $f51635164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51635164,
"from":L[364]});
}
} catch($e51555156) {
if(R.isCont($e51555156)) {
var $ss51595160 = {"from":L[364],
"go":function(anf_arg1115166) {
return $Hanf_arg9845167(anf_arg1115166,anf_arg1095153,_plus8);
}};
$e51555156.stack[R.EXN_STACKHEIGHT++] = $ss51595160;
}
if(R.isPyretException($e51555156)) {
$e51555156.pyretStack.push(L[364]);
}
throw $e51555156;
}
var $ret51615162 = $Hanf_arg9845167($z51575158,anf_arg1095153,_plus8);
++R.GAS;
return $ret51615162;
};
var $Hanf_arg9845167 = function(anf_arg1115166,anf_arg1095153,_plus8) {
var $z51705171 = D;
var $f51765177 = function(_) {
return R.isFunction(_plus8)?_plus8.app((", "),anf_arg1115166):R.ffi.throwNonFunApp(L[364],_plus8,[(", "),anf_arg1115166]);
};
try {
if(--R.GAS > 0) {
$z51705171 = $f51765177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51765177,
"from":L[364]});
}
} catch($e51685169) {
if(R.isCont($e51685169)) {
var $ss51725173 = {"from":L[364],
"go":function(anf_arg1125178) {
return $Hanf_arg9835179(anf_arg1125178,anf_arg1095153,_plus8);
}};
$e51685169.stack[R.EXN_STACKHEIGHT++] = $ss51725173;
}
if(R.isPyretException($e51685169)) {
$e51685169.pyretStack.push(L[364]);
}
throw $e51685169;
}
var $ret51745175 = $Hanf_arg9835179($z51705171,anf_arg1095153,_plus8);
++R.GAS;
return $ret51745175;
};
var $Hanf_arg9835179 = function(anf_arg1125178,anf_arg1095153,_plus8) {
var $z51825183 = D;
var $f51885189 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1095153,anf_arg1125178):R.ffi.throwNonFunApp(L[364],_plus8,[anf_arg1095153,anf_arg1125178]);
};
try {
if(--R.GAS > 0) {
$z51825183 = $f51885189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51885189,
"from":L[364]});
}
} catch($e51805181) {
if(R.isCont($e51805181)) {
var $ss51845185 = {"from":L[364],
"go":function(anf_arg1135190) {
return $Hanf_arg9825191(anf_arg1135190,_plus8);
}};
$e51805181.stack[R.EXN_STACKHEIGHT++] = $ss51845185;
}
if(R.isPyretException($e51805181)) {
$e51805181.pyretStack.push(L[364]);
}
throw $e51805181;
}
var $ret51865187 = $Hanf_arg9825191($z51825183,_plus8);
++R.GAS;
return $ret51865187;
};
var $Hanf_arg9825191 = function(anf_arg1135190,_plus8) {
var $z51945195 = D;
var $f52005201 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg1135190,(")")):R.ffi.throwNonFunApp(L[364],_plus8,[anf_arg1135190,(")")]);
};
try {
if(--R.GAS > 0) {
$z51945195 = $f52005201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52005201,
"from":L[364]});
}
} catch($e51925193) {
if(R.isCont($e51925193)) {
var $ss51965197 = {"from":L[364],
"go":function(anf_arg1145202) {
return $Hanf_arg9815203(anf_arg1145202,_plus8);
}};
$e51925193.stack[R.EXN_STACKHEIGHT++] = $ss51965197;
}
if(R.isPyretException($e51925193)) {
$e51925193.pyretStack.push(L[364]);
}
throw $e51925193;
}
var $ret51985199 = $Hanf_arg9815203($z51945195,_plus8);
++R.GAS;
return $ret51985199;
};
var $Hanf_arg9815203 = function(anf_arg1145202,_plus8) {
var $z52065207 = D;
var $f52125213 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("("),anf_arg1145202):R.ffi.throwNonFunApp(L[364],_plus8,[("("),anf_arg1145202]);
};
try {
if(--R.GAS > 0) {
$z52065207 = $f52125213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52125213,
"from":L[364]});
}
} catch($e52045205) {
if(R.isCont($e52045205)) {
var $ss52085209 = {"from":L[364],
"go":function(anf_arg1155214) {
return $Hanf_arg9805215(anf_arg1155214,_plus8);
}};
$e52045205.stack[R.EXN_STACKHEIGHT++] = $ss52085209;
}
if(R.isPyretException($e52045205)) {
$e52045205.pyretStack.push(L[364]);
}
throw $e52045205;
}
var $ret52105211 = $Hanf_arg9805215($z52065207,_plus8);
++R.GAS;
return $ret52105211;
};
var $Hanf_arg9805215 = function(anf_arg1155214,_plus8) {
var $z52185219 = D;
var $f52245225 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("mt-doc"),anf_arg1155214):R.ffi.throwNonFunApp(L[364],_plus8,[("mt-doc"),anf_arg1155214]);
};
try {
if(--R.GAS > 0) {
$z52185219 = $f52245225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52245225,
"from":L[364]});
}
} catch($e52165217) {
if(R.isCont($e52165217)) {
var $ss52205221 = {"from":L[364],
"go":function(ann_DASH_check_DASH_temp1075226) {
return $Hann_DASH_check_DASH_temp9795227(ann_DASH_check_DASH_temp1075226);
}};
$e52165217.stack[R.EXN_STACKHEIGHT++] = $ss52205221;
}
if(R.isPyretException($e52165217)) {
$e52165217.pyretStack.push(L[364]);
}
throw $e52165217;
}
var $ret52225223 = $Hann_DASH_check_DASH_temp9795227($z52185219);
++R.GAS;
return $ret52225223;
};
var $Hann_DASH_check_DASH_temp9795227 = function(ann_DASH_check_DASH_temp1075226) {
return ann_DASH_check_DASH_temp1075226;
};
var $Hcont_tail_arg9775228 = function(cont_tail_arg1045229,if_helper955230) {
if(--R.GAS > 0) {
$z52315232 = R.isFunction(if_helper955230)?if_helper955230.app(cont_tail_arg1045229):R.ffi.throwNonFunApp(L[364],if_helper955230,[cont_tail_arg1045229]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper955230)?if_helper955230.app(cont_tail_arg1045229):R.ffi.throwNonFunApp(L[364],if_helper955230,[cont_tail_arg1045229]);
},
"from":L[364]});
}
++R.GAS;
return $z52315232;
};
var $Hcont_tail_arg9785233 = function(cont_tail_arg1005234,if_helper955230) {
if(--R.GAS > 0) {
$z52355236 = R.isFunction(if_helper955230)?if_helper955230.app(cont_tail_arg1005234):R.ffi.throwNonFunApp(L[364],if_helper955230,[cont_tail_arg1005234]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper955230)?if_helper955230.app(cont_tail_arg1005234):R.ffi.throwNonFunApp(L[364],if_helper955230,[cont_tail_arg1005234]);
},
"from":L[364]});
}
++R.GAS;
return $z52355236;
};
var $Hann_DASH_check_DASH_temp9765237 = function(ann_DASH_check_DASH_temp925238) {
return ann_DASH_check_DASH_temp925238;
};
var $Hann_DASH_check_DASH_temp9755239 = function(ann_DASH_check_DASH_temp415240) {
return ann_DASH_check_DASH_temp415240;
};
var $Hanf_arg9745241 = function(anf_arg855242,_plus8) {
var $z52455246 = D;
var $f52515252 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("AlignSpaces("),anf_arg855242):R.ffi.throwNonFunApp(L[365],_plus8,[("AlignSpaces("),anf_arg855242]);
};
try {
if(--R.GAS > 0) {
$z52455246 = $f52515252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52515252,
"from":L[365]});
}
} catch($e52435244) {
if(R.isCont($e52435244)) {
var $ss52475248 = {"from":L[365],
"go":function(anf_arg865253) {
return $Hanf_arg9735254(anf_arg865253,_plus8);
}};
$e52435244.stack[R.EXN_STACKHEIGHT++] = $ss52475248;
}
if(R.isPyretException($e52435244)) {
$e52435244.pyretStack.push(L[365]);
}
throw $e52435244;
}
var $ret52495250 = $Hanf_arg9735254($z52455246,_plus8);
++R.GAS;
return $ret52495250;
};
var $Hanf_arg9735254 = function(anf_arg865253,_plus8) {
var $z52575258 = D;
var $f52635264 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg865253,(")")):R.ffi.throwNonFunApp(L[366],_plus8,[anf_arg865253,(")")]);
};
try {
if(--R.GAS > 0) {
$z52575258 = $f52635264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52635264,
"from":L[366]});
}
} catch($e52555256) {
if(R.isCont($e52555256)) {
var $ss52595260 = {"from":L[366],
"go":function(ann_DASH_check_DASH_temp845265) {
return $Hann_DASH_check_DASH_temp9725266(ann_DASH_check_DASH_temp845265);
}};
$e52555256.stack[R.EXN_STACKHEIGHT++] = $ss52595260;
}
if(R.isPyretException($e52555256)) {
$e52555256.pyretStack.push(L[366]);
}
throw $e52555256;
}
var $ret52615262 = $Hann_DASH_check_DASH_temp9725266($z52575258);
++R.GAS;
return $ret52615262;
};
var $Hann_DASH_check_DASH_temp9725266 = function(ann_DASH_check_DASH_temp845265) {
return ann_DASH_check_DASH_temp845265;
};
var $Hanf_arg9715267 = function(anf_arg815268,_plus8) {
var $z52715272 = D;
var $f52775278 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("Align("),anf_arg815268):R.ffi.throwNonFunApp(L[367],_plus8,[("Align("),anf_arg815268]);
};
try {
if(--R.GAS > 0) {
$z52715272 = $f52775278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52775278,
"from":L[367]});
}
} catch($e52695270) {
if(R.isCont($e52695270)) {
var $ss52735274 = {"from":L[367],
"go":function(anf_arg825279) {
return $Hanf_arg9705280(anf_arg825279,_plus8);
}};
$e52695270.stack[R.EXN_STACKHEIGHT++] = $ss52735274;
}
if(R.isPyretException($e52695270)) {
$e52695270.pyretStack.push(L[367]);
}
throw $e52695270;
}
var $ret52755276 = $Hanf_arg9705280($z52715272,_plus8);
++R.GAS;
return $ret52755276;
};
var $Hanf_arg9705280 = function(anf_arg825279,_plus8) {
var $z52835284 = D;
var $f52895290 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg825279,(")")):R.ffi.throwNonFunApp(L[368],_plus8,[anf_arg825279,(")")]);
};
try {
if(--R.GAS > 0) {
$z52835284 = $f52895290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52895290,
"from":L[368]});
}
} catch($e52815282) {
if(R.isCont($e52815282)) {
var $ss52855286 = {"from":L[368],
"go":function(ann_DASH_check_DASH_temp805291) {
return $Hann_DASH_check_DASH_temp9695292(ann_DASH_check_DASH_temp805291);
}};
$e52815282.stack[R.EXN_STACKHEIGHT++] = $ss52855286;
}
if(R.isPyretException($e52815282)) {
$e52815282.pyretStack.push(L[368]);
}
throw $e52815282;
}
var $ret52875288 = $Hann_DASH_check_DASH_temp9695292($z52835284);
++R.GAS;
return $ret52875288;
};
var $Hann_DASH_check_DASH_temp9695292 = function(ann_DASH_check_DASH_temp805291) {
return ann_DASH_check_DASH_temp805291;
};
var $Hanf_arg9685293 = function(anf_arg765294,_plus8) {
var $z52975298 = D;
var $f53035304 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("Group("),anf_arg765294):R.ffi.throwNonFunApp(L[369],_plus8,[("Group("),anf_arg765294]);
};
try {
if(--R.GAS > 0) {
$z52975298 = $f53035304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53035304,
"from":L[369]});
}
} catch($e52955296) {
if(R.isCont($e52955296)) {
var $ss52995300 = {"from":L[369],
"go":function(anf_arg775305) {
return $Hanf_arg9675306(anf_arg775305,_plus8);
}};
$e52955296.stack[R.EXN_STACKHEIGHT++] = $ss52995300;
}
if(R.isPyretException($e52955296)) {
$e52955296.pyretStack.push(L[369]);
}
throw $e52955296;
}
var $ret53015302 = $Hanf_arg9675306($z52975298,_plus8);
++R.GAS;
return $ret53015302;
};
var $Hanf_arg9675306 = function(anf_arg775305,_plus8) {
var $z53095310 = D;
var $f53155316 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg775305,(", ")):R.ffi.throwNonFunApp(L[369],_plus8,[anf_arg775305,(", ")]);
};
try {
if(--R.GAS > 0) {
$z53095310 = $f53155316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53155316,
"from":L[369]});
}
} catch($e53075308) {
if(R.isCont($e53075308)) {
var $ss53115312 = {"from":L[369],
"go":function(anf_arg785317) {
return $Hanf_arg9665318(anf_arg785317,_plus8);
}};
$e53075308.stack[R.EXN_STACKHEIGHT++] = $ss53115312;
}
if(R.isPyretException($e53075308)) {
$e53075308.pyretStack.push(L[369]);
}
throw $e53075308;
}
var $ret53135314 = $Hanf_arg9665318($z53095310,_plus8);
++R.GAS;
return $ret53135314;
};
var $Hanf_arg9665318 = function(anf_arg785317,_plus8) {
var $z53215322 = D;
var $f53275328 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg785317,(")")):R.ffi.throwNonFunApp(L[370],_plus8,[anf_arg785317,(")")]);
};
try {
if(--R.GAS > 0) {
$z53215322 = $f53275328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53275328,
"from":L[370]});
}
} catch($e53195320) {
if(R.isCont($e53195320)) {
var $ss53235324 = {"from":L[370],
"go":function(ann_DASH_check_DASH_temp755329) {
return $Hann_DASH_check_DASH_temp9655330(ann_DASH_check_DASH_temp755329);
}};
$e53195320.stack[R.EXN_STACKHEIGHT++] = $ss53235324;
}
if(R.isPyretException($e53195320)) {
$e53195320.pyretStack.push(L[370]);
}
throw $e53195320;
}
var $ret53255326 = $Hann_DASH_check_DASH_temp9655330($z53215322);
++R.GAS;
return $ret53255326;
};
var $Hann_DASH_check_DASH_temp9655330 = function(ann_DASH_check_DASH_temp755329) {
return ann_DASH_check_DASH_temp755329;
};
var $Hanf_arg9645331 = function(anf_arg695332,vert1465333,_plus8,tostring15) {
var $z53365337 = D;
var $f53425343 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("IfFlat("),anf_arg695332):R.ffi.throwNonFunApp(L[371],_plus8,[("IfFlat("),anf_arg695332]);
};
try {
if(--R.GAS > 0) {
$z53365337 = $f53425343();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53425343,
"from":L[371]});
}
} catch($e53345335) {
if(R.isCont($e53345335)) {
var $ss53385339 = {"from":L[371],
"go":function(anf_arg705344) {
return $Hanf_arg9635345(anf_arg705344,vert1465333,_plus8,tostring15);
}};
$e53345335.stack[R.EXN_STACKHEIGHT++] = $ss53385339;
}
if(R.isPyretException($e53345335)) {
$e53345335.pyretStack.push(L[371]);
}
throw $e53345335;
}
var $ret53405341 = $Hanf_arg9635345($z53365337,vert1465333,_plus8,tostring15);
++R.GAS;
return $ret53405341;
};
var $Hanf_arg9635345 = function(anf_arg705344,vert1465333,_plus8,tostring15) {
var $z53485349 = D;
var $f53545355 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg705344,(", ")):R.ffi.throwNonFunApp(L[371],_plus8,[anf_arg705344,(", ")]);
};
try {
if(--R.GAS > 0) {
$z53485349 = $f53545355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53545355,
"from":L[371]});
}
} catch($e53465347) {
if(R.isCont($e53465347)) {
var $ss53505351 = {"from":L[371],
"go":function(anf_arg715356) {
return $Hanf_arg9625357(anf_arg715356,vert1465333,_plus8,tostring15);
}};
$e53465347.stack[R.EXN_STACKHEIGHT++] = $ss53505351;
}
if(R.isPyretException($e53465347)) {
$e53465347.pyretStack.push(L[371]);
}
throw $e53465347;
}
var $ret53525353 = $Hanf_arg9625357($z53485349,vert1465333,_plus8,tostring15);
++R.GAS;
return $ret53525353;
};
var $Hanf_arg9625357 = function(anf_arg715356,vert1465333,_plus8,tostring15) {
var $z53605361 = D;
var $f53665367 = function(_) {
return R.isFunction(tostring15)?tostring15.app(vert1465333):R.ffi.throwNonFunApp(L[372],tostring15,[vert1465333]);
};
try {
if(--R.GAS > 0) {
$z53605361 = $f53665367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53665367,
"from":L[372]});
}
} catch($e53585359) {
if(R.isCont($e53585359)) {
var $ss53625363 = {"from":L[372],
"go":function(anf_arg725368) {
return $Hanf_arg9615369(anf_arg725368,anf_arg715356,_plus8);
}};
$e53585359.stack[R.EXN_STACKHEIGHT++] = $ss53625363;
}
if(R.isPyretException($e53585359)) {
$e53585359.pyretStack.push(L[372]);
}
throw $e53585359;
}
var $ret53645365 = $Hanf_arg9615369($z53605361,anf_arg715356,_plus8);
++R.GAS;
return $ret53645365;
};
var $Hanf_arg9615369 = function(anf_arg725368,anf_arg715356,_plus8) {
var $z53725373 = D;
var $f53785379 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg715356,anf_arg725368):R.ffi.throwNonFunApp(L[371],_plus8,[anf_arg715356,anf_arg725368]);
};
try {
if(--R.GAS > 0) {
$z53725373 = $f53785379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53785379,
"from":L[371]});
}
} catch($e53705371) {
if(R.isCont($e53705371)) {
var $ss53745375 = {"from":L[371],
"go":function(anf_arg735380) {
return $Hanf_arg9605381(anf_arg735380,_plus8);
}};
$e53705371.stack[R.EXN_STACKHEIGHT++] = $ss53745375;
}
if(R.isPyretException($e53705371)) {
$e53705371.pyretStack.push(L[371]);
}
throw $e53705371;
}
var $ret53765377 = $Hanf_arg9605381($z53725373,_plus8);
++R.GAS;
return $ret53765377;
};
var $Hanf_arg9605381 = function(anf_arg735380,_plus8) {
var $z53845385 = D;
var $f53905391 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg735380,(")")):R.ffi.throwNonFunApp(L[373],_plus8,[anf_arg735380,(")")]);
};
try {
if(--R.GAS > 0) {
$z53845385 = $f53905391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53905391,
"from":L[373]});
}
} catch($e53825383) {
if(R.isCont($e53825383)) {
var $ss53865387 = {"from":L[373],
"go":function(ann_DASH_check_DASH_temp685392) {
return $Hann_DASH_check_DASH_temp9595393(ann_DASH_check_DASH_temp685392);
}};
$e53825383.stack[R.EXN_STACKHEIGHT++] = $ss53865387;
}
if(R.isPyretException($e53825383)) {
$e53825383.pyretStack.push(L[373]);
}
throw $e53825383;
}
var $ret53885389 = $Hann_DASH_check_DASH_temp9595393($z53845385);
++R.GAS;
return $ret53885389;
};
var $Hann_DASH_check_DASH_temp9595393 = function(ann_DASH_check_DASH_temp685392) {
return ann_DASH_check_DASH_temp685392;
};
var $Hanf_arg9585394 = function(anf_arg625395,d1425396,_plus8,tostring15) {
var $z53995400 = D;
var $f54055406 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("Nest("),anf_arg625395):R.ffi.throwNonFunApp(L[374],_plus8,[("Nest("),anf_arg625395]);
};
try {
if(--R.GAS > 0) {
$z53995400 = $f54055406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54055406,
"from":L[374]});
}
} catch($e53975398) {
if(R.isCont($e53975398)) {
var $ss54015402 = {"from":L[374],
"go":function(anf_arg635407) {
return $Hanf_arg9575408(anf_arg635407,d1425396,_plus8,tostring15);
}};
$e53975398.stack[R.EXN_STACKHEIGHT++] = $ss54015402;
}
if(R.isPyretException($e53975398)) {
$e53975398.pyretStack.push(L[374]);
}
throw $e53975398;
}
var $ret54035404 = $Hanf_arg9575408($z53995400,d1425396,_plus8,tostring15);
++R.GAS;
return $ret54035404;
};
var $Hanf_arg9575408 = function(anf_arg635407,d1425396,_plus8,tostring15) {
var $z54115412 = D;
var $f54175418 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg635407,(", ")):R.ffi.throwNonFunApp(L[374],_plus8,[anf_arg635407,(", ")]);
};
try {
if(--R.GAS > 0) {
$z54115412 = $f54175418();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54175418,
"from":L[374]});
}
} catch($e54095410) {
if(R.isCont($e54095410)) {
var $ss54135414 = {"from":L[374],
"go":function(anf_arg645419) {
return $Hanf_arg9565420(anf_arg645419,d1425396,_plus8,tostring15);
}};
$e54095410.stack[R.EXN_STACKHEIGHT++] = $ss54135414;
}
if(R.isPyretException($e54095410)) {
$e54095410.pyretStack.push(L[374]);
}
throw $e54095410;
}
var $ret54155416 = $Hanf_arg9565420($z54115412,d1425396,_plus8,tostring15);
++R.GAS;
return $ret54155416;
};
var $Hanf_arg9565420 = function(anf_arg645419,d1425396,_plus8,tostring15) {
var $z54235424 = D;
var $f54295430 = function(_) {
return R.isFunction(tostring15)?tostring15.app(d1425396):R.ffi.throwNonFunApp(L[375],tostring15,[d1425396]);
};
try {
if(--R.GAS > 0) {
$z54235424 = $f54295430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54295430,
"from":L[375]});
}
} catch($e54215422) {
if(R.isCont($e54215422)) {
var $ss54255426 = {"from":L[375],
"go":function(anf_arg655431) {
return $Hanf_arg9555432(anf_arg655431,anf_arg645419,_plus8);
}};
$e54215422.stack[R.EXN_STACKHEIGHT++] = $ss54255426;
}
if(R.isPyretException($e54215422)) {
$e54215422.pyretStack.push(L[375]);
}
throw $e54215422;
}
var $ret54275428 = $Hanf_arg9555432($z54235424,anf_arg645419,_plus8);
++R.GAS;
return $ret54275428;
};
var $Hanf_arg9555432 = function(anf_arg655431,anf_arg645419,_plus8) {
var $z54355436 = D;
var $f54415442 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg645419,anf_arg655431):R.ffi.throwNonFunApp(L[374],_plus8,[anf_arg645419,anf_arg655431]);
};
try {
if(--R.GAS > 0) {
$z54355436 = $f54415442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54415442,
"from":L[374]});
}
} catch($e54335434) {
if(R.isCont($e54335434)) {
var $ss54375438 = {"from":L[374],
"go":function(anf_arg665443) {
return $Hanf_arg9545444(anf_arg665443,_plus8);
}};
$e54335434.stack[R.EXN_STACKHEIGHT++] = $ss54375438;
}
if(R.isPyretException($e54335434)) {
$e54335434.pyretStack.push(L[374]);
}
throw $e54335434;
}
var $ret54395440 = $Hanf_arg9545444($z54355436,_plus8);
++R.GAS;
return $ret54395440;
};
var $Hanf_arg9545444 = function(anf_arg665443,_plus8) {
var $z54475448 = D;
var $f54535454 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg665443,(")")):R.ffi.throwNonFunApp(L[376],_plus8,[anf_arg665443,(")")]);
};
try {
if(--R.GAS > 0) {
$z54475448 = $f54535454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54535454,
"from":L[376]});
}
} catch($e54455446) {
if(R.isCont($e54455446)) {
var $ss54495450 = {"from":L[376],
"go":function(ann_DASH_check_DASH_temp615455) {
return $Hann_DASH_check_DASH_temp9535456(ann_DASH_check_DASH_temp615455);
}};
$e54455446.stack[R.EXN_STACKHEIGHT++] = $ss54495450;
}
if(R.isPyretException($e54455446)) {
$e54455446.pyretStack.push(L[376]);
}
throw $e54455446;
}
var $ret54515452 = $Hann_DASH_check_DASH_temp9535456($z54475448);
++R.GAS;
return $ret54515452;
};
var $Hann_DASH_check_DASH_temp9535456 = function(ann_DASH_check_DASH_temp615455) {
return ann_DASH_check_DASH_temp615455;
};
var $Hanf_arg9525457 = function(anf_arg555458,snd1385459,_plus8,tostring15) {
var $z54625463 = D;
var $f54685469 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("Concat("),anf_arg555458):R.ffi.throwNonFunApp(L[377],_plus8,[("Concat("),anf_arg555458]);
};
try {
if(--R.GAS > 0) {
$z54625463 = $f54685469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54685469,
"from":L[377]});
}
} catch($e54605461) {
if(R.isCont($e54605461)) {
var $ss54645465 = {"from":L[377],
"go":function(anf_arg565470) {
return $Hanf_arg9515471(anf_arg565470,snd1385459,_plus8,tostring15);
}};
$e54605461.stack[R.EXN_STACKHEIGHT++] = $ss54645465;
}
if(R.isPyretException($e54605461)) {
$e54605461.pyretStack.push(L[377]);
}
throw $e54605461;
}
var $ret54665467 = $Hanf_arg9515471($z54625463,snd1385459,_plus8,tostring15);
++R.GAS;
return $ret54665467;
};
var $Hanf_arg9515471 = function(anf_arg565470,snd1385459,_plus8,tostring15) {
var $z54745475 = D;
var $f54805481 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg565470,(", ")):R.ffi.throwNonFunApp(L[377],_plus8,[anf_arg565470,(", ")]);
};
try {
if(--R.GAS > 0) {
$z54745475 = $f54805481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54805481,
"from":L[377]});
}
} catch($e54725473) {
if(R.isCont($e54725473)) {
var $ss54765477 = {"from":L[377],
"go":function(anf_arg575482) {
return $Hanf_arg9505483(anf_arg575482,snd1385459,_plus8,tostring15);
}};
$e54725473.stack[R.EXN_STACKHEIGHT++] = $ss54765477;
}
if(R.isPyretException($e54725473)) {
$e54725473.pyretStack.push(L[377]);
}
throw $e54725473;
}
var $ret54785479 = $Hanf_arg9505483($z54745475,snd1385459,_plus8,tostring15);
++R.GAS;
return $ret54785479;
};
var $Hanf_arg9505483 = function(anf_arg575482,snd1385459,_plus8,tostring15) {
var $z54865487 = D;
var $f54925493 = function(_) {
return R.isFunction(tostring15)?tostring15.app(snd1385459):R.ffi.throwNonFunApp(L[378],tostring15,[snd1385459]);
};
try {
if(--R.GAS > 0) {
$z54865487 = $f54925493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54925493,
"from":L[378]});
}
} catch($e54845485) {
if(R.isCont($e54845485)) {
var $ss54885489 = {"from":L[378],
"go":function(anf_arg585494) {
return $Hanf_arg9495495(anf_arg585494,anf_arg575482,_plus8);
}};
$e54845485.stack[R.EXN_STACKHEIGHT++] = $ss54885489;
}
if(R.isPyretException($e54845485)) {
$e54845485.pyretStack.push(L[378]);
}
throw $e54845485;
}
var $ret54905491 = $Hanf_arg9495495($z54865487,anf_arg575482,_plus8);
++R.GAS;
return $ret54905491;
};
var $Hanf_arg9495495 = function(anf_arg585494,anf_arg575482,_plus8) {
var $z54985499 = D;
var $f55045505 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg575482,anf_arg585494):R.ffi.throwNonFunApp(L[377],_plus8,[anf_arg575482,anf_arg585494]);
};
try {
if(--R.GAS > 0) {
$z54985499 = $f55045505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55045505,
"from":L[377]});
}
} catch($e54965497) {
if(R.isCont($e54965497)) {
var $ss55005501 = {"from":L[377],
"go":function(anf_arg595506) {
return $Hanf_arg9485507(anf_arg595506,_plus8);
}};
$e54965497.stack[R.EXN_STACKHEIGHT++] = $ss55005501;
}
if(R.isPyretException($e54965497)) {
$e54965497.pyretStack.push(L[377]);
}
throw $e54965497;
}
var $ret55025503 = $Hanf_arg9485507($z54985499,_plus8);
++R.GAS;
return $ret55025503;
};
var $Hanf_arg9485507 = function(anf_arg595506,_plus8) {
var $z55105511 = D;
var $f55165517 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg595506,(")")):R.ffi.throwNonFunApp(L[379],_plus8,[anf_arg595506,(")")]);
};
try {
if(--R.GAS > 0) {
$z55105511 = $f55165517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55165517,
"from":L[379]});
}
} catch($e55085509) {
if(R.isCont($e55085509)) {
var $ss55125513 = {"from":L[379],
"go":function(ann_DASH_check_DASH_temp545518) {
return $Hann_DASH_check_DASH_temp9475519(ann_DASH_check_DASH_temp545518);
}};
$e55085509.stack[R.EXN_STACKHEIGHT++] = $ss55125513;
}
if(R.isPyretException($e55085509)) {
$e55085509.pyretStack.push(L[379]);
}
throw $e55085509;
}
var $ret55145515 = $Hann_DASH_check_DASH_temp9475519($z55105511);
++R.GAS;
return $ret55145515;
};
var $Hann_DASH_check_DASH_temp9475519 = function(ann_DASH_check_DASH_temp545518) {
return ann_DASH_check_DASH_temp545518;
};
var $Hanf_arg9465520 = function(anf_arg515521,_plus8) {
var $z55245525 = D;
var $f55305531 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("Blank("),anf_arg515521):R.ffi.throwNonFunApp(L[380],_plus8,[("Blank("),anf_arg515521]);
};
try {
if(--R.GAS > 0) {
$z55245525 = $f55305531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55305531,
"from":L[380]});
}
} catch($e55225523) {
if(R.isCont($e55225523)) {
var $ss55265527 = {"from":L[380],
"go":function(anf_arg525532) {
return $Hanf_arg9455533(anf_arg525532,_plus8);
}};
$e55225523.stack[R.EXN_STACKHEIGHT++] = $ss55265527;
}
if(R.isPyretException($e55225523)) {
$e55225523.pyretStack.push(L[380]);
}
throw $e55225523;
}
var $ret55285529 = $Hanf_arg9455533($z55245525,_plus8);
++R.GAS;
return $ret55285529;
};
var $Hanf_arg9455533 = function(anf_arg525532,_plus8) {
var $z55365537 = D;
var $f55425543 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg525532,(")")):R.ffi.throwNonFunApp(L[381],_plus8,[anf_arg525532,(")")]);
};
try {
if(--R.GAS > 0) {
$z55365537 = $f55425543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55425543,
"from":L[381]});
}
} catch($e55345535) {
if(R.isCont($e55345535)) {
var $ss55385539 = {"from":L[381],
"go":function(ann_DASH_check_DASH_temp505544) {
return $Hann_DASH_check_DASH_temp9445545(ann_DASH_check_DASH_temp505544);
}};
$e55345535.stack[R.EXN_STACKHEIGHT++] = $ss55385539;
}
if(R.isPyretException($e55345535)) {
$e55345535.pyretStack.push(L[381]);
}
throw $e55345535;
}
var $ret55405541 = $Hann_DASH_check_DASH_temp9445545($z55365537);
++R.GAS;
return $ret55405541;
};
var $Hann_DASH_check_DASH_temp9445545 = function(ann_DASH_check_DASH_temp505544) {
return ann_DASH_check_DASH_temp505544;
};
var $Hanf_arg9435546 = function(anf_arg465547,_plus8) {
var $z55505551 = D;
var $f55565557 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg465547,("')")):R.ffi.throwNonFunApp(L[382],_plus8,[anf_arg465547,("')")]);
};
try {
if(--R.GAS > 0) {
$z55505551 = $f55565557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55565557,
"from":L[382]});
}
} catch($e55485549) {
if(R.isCont($e55485549)) {
var $ss55525553 = {"from":L[382],
"go":function(ann_DASH_check_DASH_temp455558) {
return $Hann_DASH_check_DASH_temp9425559(ann_DASH_check_DASH_temp455558);
}};
$e55485549.stack[R.EXN_STACKHEIGHT++] = $ss55525553;
}
if(R.isPyretException($e55485549)) {
$e55485549.pyretStack.push(L[382]);
}
throw $e55485549;
}
var $ret55545555 = $Hann_DASH_check_DASH_temp9425559($z55505551);
++R.GAS;
return $ret55545555;
};
var $Hann_DASH_check_DASH_temp9425559 = function(ann_DASH_check_DASH_temp455558) {
return ann_DASH_check_DASH_temp455558;
};
var $Hif_DASH_9415560 = function(if_DASH_665561,concat765562,is_DASH_concat755563,is_DASH_mt_DASH_doc6747,other1255564,self1245565,_plus8) {
var if_helper25576 = R.makeFunction(function(if_helper_arg35595) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[386],1,arguments);
}
var ann_DASH_check_DASH_temp15596 = if_helper_arg35595;
return ann_DASH_check_DASH_temp15596;
});
var anf_if65594 = R.isBoolean(if_DASH_665561);
if(R.isPyretTrue(anf_if65594)) {
if(R.isPyretTrue(if_DASH_665561)) {
var $z55685569 = D;
var $f55745575 = function(_) {
return R.isFunction(if_helper25576)?if_helper25576.app(other1255564):R.ffi.throwNonFunApp(L[383],if_helper25576,[other1255564]);
};
try {
if(--R.GAS > 0) {
$z55685569 = $f55745575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55745575,
"from":L[383]});
}
} catch($e55665567) {
if(R.isCont($e55665567)) {
var $ss55705571 = {"from":L[383],
"go":function(cont_tail_app395577) {
return $Hcont_tail_app9305578(cont_tail_app395577);
}};
$e55665567.stack[R.EXN_STACKHEIGHT++] = $ss55705571;
}
if(R.isPyretException($e55665567)) {
$e55665567.pyretStack.push(L[383]);
}
throw $e55665567;
}
var $ret55725573 = $Hcont_tail_app9305578($z55685569);
++R.GAS;
return $ret55725573;
} else {
var $z55815582 = D;
var $f55875588 = function(_) {
return R.isFunction(is_DASH_mt_DASH_doc6747.$var === D?U(L[384],"is-mt-doc"):is_DASH_mt_DASH_doc6747.$var)?is_DASH_mt_DASH_doc6747.$var === D?U(L[384],"is-mt-doc"):is_DASH_mt_DASH_doc6747.$var.app(other1255564):R.ffi.throwNonFunApp(L[385],is_DASH_mt_DASH_doc6747.$var === D?U(L[384],"is-mt-doc"):is_DASH_mt_DASH_doc6747.$var,[other1255564]);
};
try {
if(--R.GAS > 0) {
$z55815582 = $f55875588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55875588,
"from":L[385]});
}
} catch($e55795580) {
if(R.isCont($e55795580)) {
var $ss55835584 = {"from":L[385],
"go":function(if_DASH_655589) {
return $Hif_DASH_9405590(if_DASH_655589,concat765562,if_helper25576,is_DASH_concat755563,other1255564,self1245565,_plus8);
}};
$e55795580.stack[R.EXN_STACKHEIGHT++] = $ss55835584;
}
if(R.isPyretException($e55795580)) {
$e55795580.pyretStack.push(L[385]);
}
throw $e55795580;
}
var $ret55855586 = $Hif_DASH_9405590($z55815582,concat765562,if_helper25576,is_DASH_concat755563,other1255564,self1245565,_plus8);
++R.GAS;
return $ret55855586;
}
} else {
var cont_tail_arg45593 = R.throwNonBooleanCondition(L[386],("if"),if_DASH_665561);
if(--R.GAS > 0) {
$z55915592 = R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg45593):R.ffi.throwNonFunApp(L[386],if_helper25576,[cont_tail_arg45593]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg45593):R.ffi.throwNonFunApp(L[386],if_helper25576,[cont_tail_arg45593]);
},
"from":L[386]});
}
++R.GAS;
return $z55915592;
}
};
var $Hcont_tail_app9305578 = function(cont_tail_app395577) {
return cont_tail_app395577;
};
var $Hif_DASH_9405590 = function(if_DASH_655589,concat765562,if_helper25576,is_DASH_concat755563,other1255564,self1245565,_plus8) {
var anf_if95624 = R.isBoolean(if_DASH_655589);
if(R.isPyretTrue(anf_if95624)) {
if(R.isPyretTrue(if_DASH_655589)) {
var $z55995600 = D;
var $f56055606 = function(_) {
return R.isFunction(if_helper25576)?if_helper25576.app(self1245565):R.ffi.throwNonFunApp(L[387],if_helper25576,[self1245565]);
};
try {
if(--R.GAS > 0) {
$z55995600 = $f56055606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56055606,
"from":L[387]});
}
} catch($e55975598) {
if(R.isCont($e55975598)) {
var $ss56015602 = {"from":L[387],
"go":function(cont_tail_app385607) {
return $Hcont_tail_app9315608(cont_tail_app385607);
}};
$e55975598.stack[R.EXN_STACKHEIGHT++] = $ss56015602;
}
if(R.isPyretException($e55975598)) {
$e55975598.pyretStack.push(L[387]);
}
throw $e55975598;
}
var $ret56035604 = $Hcont_tail_app9315608($z55995600);
++R.GAS;
return $ret56035604;
} else {
var $z56115612 = D;
var $f56175618 = function(_) {
return R.isFunction(is_DASH_concat755563.$var === D?U(L[388],"is-concat"):is_DASH_concat755563.$var)?is_DASH_concat755563.$var === D?U(L[388],"is-concat"):is_DASH_concat755563.$var.app(self1245565):R.ffi.throwNonFunApp(L[389],is_DASH_concat755563.$var === D?U(L[388],"is-concat"):is_DASH_concat755563.$var,[self1245565]);
};
try {
if(--R.GAS > 0) {
$z56115612 = $f56175618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56175618,
"from":L[389]});
}
} catch($e56095610) {
if(R.isCont($e56095610)) {
var $ss56135614 = {"from":L[389],
"go":function(if_DASH_645619) {
return $Hif_DASH_9395620(if_DASH_645619,concat765562,if_helper25576,other1255564,self1245565,_plus8);
}};
$e56095610.stack[R.EXN_STACKHEIGHT++] = $ss56135614;
}
if(R.isPyretException($e56095610)) {
$e56095610.pyretStack.push(L[389]);
}
throw $e56095610;
}
var $ret56155616 = $Hif_DASH_9395620($z56115612,concat765562,if_helper25576,other1255564,self1245565,_plus8);
++R.GAS;
return $ret56155616;
}
} else {
var cont_tail_arg75623 = R.throwNonBooleanCondition(L[390],("if"),if_DASH_655589);
if(--R.GAS > 0) {
$z56215622 = R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg75623):R.ffi.throwNonFunApp(L[390],if_helper25576,[cont_tail_arg75623]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg75623):R.ffi.throwNonFunApp(L[390],if_helper25576,[cont_tail_arg75623]);
},
"from":L[390]});
}
++R.GAS;
return $z56215622;
}
};
var $Hcont_tail_app9315608 = function(cont_tail_app385607) {
return cont_tail_app385607;
};
var $Hif_DASH_9395620 = function(if_DASH_645619,concat765562,if_helper25576,other1255564,self1245565,_plus8) {
var anf_if125709 = R.isBoolean(if_DASH_645619);
if(R.isPyretTrue(anf_if125709)) {
if(R.isPyretTrue(if_DASH_645619)) {
var anf_arg335637 = G(self1245565,"fst",L[393]);
var anf_arg345635 = G(self1245565,"snd",L[392]);
var $z56275628 = D;
var $f56335634 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg345635,other1255564):R.ffi.throwNonFunApp(L[391],_plus8,[anf_arg345635,other1255564]);
};
try {
if(--R.GAS > 0) {
$z56275628 = $f56335634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56335634,
"from":L[391]});
}
} catch($e56255626) {
if(R.isCont($e56255626)) {
var $ss56295630 = {"from":L[391],
"go":function(anf_arg355636) {
return $Hanf_arg9335638(anf_arg355636,anf_arg335637,if_helper25576,_plus8);
}};
$e56255626.stack[R.EXN_STACKHEIGHT++] = $ss56295630;
}
if(R.isPyretException($e56255626)) {
$e56255626.pyretStack.push(L[391]);
}
throw $e56255626;
}
var $ret56315632 = $Hanf_arg9335638($z56275628,anf_arg335637,if_helper25576,_plus8);
++R.GAS;
return $ret56315632;
} else {
var or_DASH_oper_DASH_625669 = G(self1245565,"has-hardline",L[396]);
var if_helper135649 = R.makeFunction(function(if_helper_arg145674) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[394],1,arguments);
}
var if_DASH_615701 = if_helper_arg145674;
var anf_if175705 = R.isBoolean(if_DASH_615701);
if(R.isPyretTrue(anf_if175705)) {
if(R.isPyretTrue(if_DASH_615701)) {
var $z56775678 = D;
var $f56835684 = function(_) {
return R.isFunction(concat765562.$var === D?U(L[397],"concat"):concat765562.$var)?concat765562.$var === D?U(L[397],"concat"):concat765562.$var.app(self1245565,other1255564,(0),(true)):R.ffi.throwNonFunApp(L[398],concat765562.$var === D?U(L[397],"concat"):concat765562.$var,[self1245565,other1255564,(0),(true)]);
};
try {
if(--R.GAS > 0) {
$z56775678 = $f56835684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56835684,
"from":L[398]});
}
} catch($e56755676) {
if(R.isCont($e56755676)) {
var $ss56795680 = {"from":L[398],
"go":function(cont_tail_arg235685) {
return $Hcont_tail_arg9345686(cont_tail_arg235685,if_helper25576);
}};
$e56755676.stack[R.EXN_STACKHEIGHT++] = $ss56795680;
}
if(R.isPyretException($e56755676)) {
$e56755676.pyretStack.push(L[398]);
}
throw $e56755676;
}
var $ret56815682 = $Hcont_tail_arg9345686($z56775678,if_helper25576);
++R.GAS;
return $ret56815682;
} else {
var anf_arg185697 = G(self1245565,"flat-width",L[401]);
var anf_arg195698 = G(other1255564,"flat-width",L[400]);
var $z56895690 = D;
var $f56955696 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg185697,anf_arg195698):R.ffi.throwNonFunApp(L[399],_plus8,[anf_arg185697,anf_arg195698]);
};
try {
if(--R.GAS > 0) {
$z56895690 = $f56955696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56955696,
"from":L[399]});
}
} catch($e56875688) {
if(R.isCont($e56875688)) {
var $ss56915692 = {"from":L[399],
"go":function(anf_arg205699) {
return $Hanf_arg9365700(anf_arg205699,concat765562,if_helper25576,other1255564,self1245565);
}};
$e56875688.stack[R.EXN_STACKHEIGHT++] = $ss56915692;
}
if(R.isPyretException($e56875688)) {
$e56875688.pyretStack.push(L[399]);
}
throw $e56875688;
}
var $ret56935694 = $Hanf_arg9365700($z56895690,concat765562,if_helper25576,other1255564,self1245565);
++R.GAS;
return $ret56935694;
}
} else {
var cont_tail_arg155704 = R.throwNonBooleanCondition(L[394],("if"),if_DASH_615701);
if(--R.GAS > 0) {
$z57025703 = R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg155704):R.ffi.throwNonFunApp(L[394],if_helper25576,[cont_tail_arg155704]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg155704):R.ffi.throwNonFunApp(L[394],if_helper25576,[cont_tail_arg155704]);
},
"from":L[394]});
}
++R.GAS;
return $z57025703;
}
});
var anf_if275673 = R.isBoolean(or_DASH_oper_DASH_625669);
if(R.isPyretTrue(anf_if275673)) {
if(R.isPyretTrue(or_DASH_oper_DASH_625669)) {
var $z56415642 = D;
var $f56475648 = function(_) {
return R.isFunction(if_helper135649)?if_helper135649.app((true)):R.ffi.throwNonFunApp(L[394],if_helper135649,[(true)]);
};
try {
if(--R.GAS > 0) {
$z56415642 = $f56475648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56475648,
"from":L[394]});
}
} catch($e56395640) {
if(R.isCont($e56395640)) {
var $ss56435644 = {"from":L[394],
"go":function(cont_tail_app325650) {
return $Hcont_tail_app9375651(cont_tail_app325650);
}};
$e56395640.stack[R.EXN_STACKHEIGHT++] = $ss56435644;
}
if(R.isPyretException($e56395640)) {
$e56395640.pyretStack.push(L[394]);
}
throw $e56395640;
}
var $ret56455646 = $Hcont_tail_app9375651($z56415642);
++R.GAS;
return $ret56455646;
} else {
var or_DASH_oper_DASH_635662 = G(other1255564,"has-hardline",L[395]);
var anf_if305668 = R.isBoolean(or_DASH_oper_DASH_635662);
if(R.isPyretTrue(anf_if305668)) {
var $z56545655 = D;
var $f56605661 = function(_) {
return R.isFunction(if_helper135649)?if_helper135649.app(or_DASH_oper_DASH_635662):R.ffi.throwNonFunApp(L[394],if_helper135649,[or_DASH_oper_DASH_635662]);
};
try {
if(--R.GAS > 0) {
$z56545655 = $f56605661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56605661,
"from":L[394]});
}
} catch($e56525653) {
if(R.isCont($e56525653)) {
var $ss56565657 = {"from":L[394],
"go":function(cont_tail_app315663) {
return $Hcont_tail_app9385664(cont_tail_app315663);
}};
$e56525653.stack[R.EXN_STACKHEIGHT++] = $ss56565657;
}
if(R.isPyretException($e56525653)) {
$e56525653.pyretStack.push(L[394]);
}
throw $e56525653;
}
var $ret56585659 = $Hcont_tail_app9385664($z56545655);
++R.GAS;
return $ret56585659;
} else {
var cont_tail_arg285667 = R.throwNonBooleanOp(L[395],("second"),("or"),or_DASH_oper_DASH_635662);
if(--R.GAS > 0) {
$z56655666 = R.isFunction(if_helper135649)?if_helper135649.app(cont_tail_arg285667):R.ffi.throwNonFunApp(L[395],if_helper135649,[cont_tail_arg285667]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper135649)?if_helper135649.app(cont_tail_arg285667):R.ffi.throwNonFunApp(L[395],if_helper135649,[cont_tail_arg285667]);
},
"from":L[395]});
}
++R.GAS;
return $z56655666;
}
}
} else {
var cont_tail_arg255672 = R.throwNonBooleanOp(L[396],("first"),("or"),or_DASH_oper_DASH_625669);
if(--R.GAS > 0) {
$z56705671 = R.isFunction(if_helper135649)?if_helper135649.app(cont_tail_arg255672):R.ffi.throwNonFunApp(L[396],if_helper135649,[cont_tail_arg255672]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper135649)?if_helper135649.app(cont_tail_arg255672):R.ffi.throwNonFunApp(L[396],if_helper135649,[cont_tail_arg255672]);
},
"from":L[396]});
}
++R.GAS;
return $z56705671;
}
}
} else {
var cont_tail_arg105708 = R.throwNonBooleanCondition(L[402],("if"),if_DASH_645619);
if(--R.GAS > 0) {
$z57065707 = R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg105708):R.ffi.throwNonFunApp(L[402],if_helper25576,[cont_tail_arg105708]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg105708):R.ffi.throwNonFunApp(L[402],if_helper25576,[cont_tail_arg105708]);
},
"from":L[402]});
}
++R.GAS;
return $z57065707;
}
};
var $Hanf_arg9335638 = function(anf_arg355636,anf_arg335637,if_helper25576,_plus8) {
var $z57125713 = D;
var $f57185719 = function(_) {
return R.isFunction(_plus8)?_plus8.app(anf_arg335637,anf_arg355636):R.ffi.throwNonFunApp(L[403],_plus8,[anf_arg335637,anf_arg355636]);
};
try {
if(--R.GAS > 0) {
$z57125713 = $f57185719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57185719,
"from":L[403]});
}
} catch($e57105711) {
if(R.isCont($e57105711)) {
var $ss57145715 = {"from":L[403],
"go":function(cont_tail_arg365720) {
return $Hcont_tail_arg9325721(cont_tail_arg365720,if_helper25576);
}};
$e57105711.stack[R.EXN_STACKHEIGHT++] = $ss57145715;
}
if(R.isPyretException($e57105711)) {
$e57105711.pyretStack.push(L[403]);
}
throw $e57105711;
}
var $ret57165717 = $Hcont_tail_arg9325721($z57125713,if_helper25576);
++R.GAS;
return $ret57165717;
};
var $Hcont_tail_arg9325721 = function(cont_tail_arg365720,if_helper25576) {
if(--R.GAS > 0) {
$z57225723 = R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg365720):R.ffi.throwNonFunApp(L[403],if_helper25576,[cont_tail_arg365720]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg365720):R.ffi.throwNonFunApp(L[403],if_helper25576,[cont_tail_arg365720]);
},
"from":L[403]});
}
++R.GAS;
return $z57225723;
};
var $Hcont_tail_app9375651 = function(cont_tail_app325650) {
return cont_tail_app325650;
};
var $Hcont_tail_app9385664 = function(cont_tail_app315663) {
return cont_tail_app315663;
};
var $Hcont_tail_arg9345686 = function(cont_tail_arg235685,if_helper25576) {
if(--R.GAS > 0) {
$z57245725 = R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg235685):R.ffi.throwNonFunApp(L[398],if_helper25576,[cont_tail_arg235685]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg235685):R.ffi.throwNonFunApp(L[398],if_helper25576,[cont_tail_arg235685]);
},
"from":L[398]});
}
++R.GAS;
return $z57245725;
};
var $Hanf_arg9365700 = function(anf_arg205699,concat765562,if_helper25576,other1255564,self1245565) {
var $z57285729 = D;
var $f57345735 = function(_) {
return R.isFunction(concat765562.$var === D?U(L[404],"concat"):concat765562.$var)?concat765562.$var === D?U(L[404],"concat"):concat765562.$var.app(self1245565,other1255564,anf_arg205699,(false)):R.ffi.throwNonFunApp(L[405],concat765562.$var === D?U(L[404],"concat"):concat765562.$var,[self1245565,other1255564,anf_arg205699,(false)]);
};
try {
if(--R.GAS > 0) {
$z57285729 = $f57345735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57345735,
"from":L[405]});
}
} catch($e57265727) {
if(R.isCont($e57265727)) {
var $ss57305731 = {"from":L[405],
"go":function(cont_tail_arg215736) {
return $Hcont_tail_arg9355737(cont_tail_arg215736,if_helper25576);
}};
$e57265727.stack[R.EXN_STACKHEIGHT++] = $ss57305731;
}
if(R.isPyretException($e57265727)) {
$e57265727.pyretStack.push(L[405]);
}
throw $e57265727;
}
var $ret57325733 = $Hcont_tail_arg9355737($z57285729,if_helper25576);
++R.GAS;
return $ret57325733;
};
var $Hcont_tail_arg9355737 = function(cont_tail_arg215736,if_helper25576) {
if(--R.GAS > 0) {
$z57385739 = R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg215736):R.ffi.throwNonFunApp(L[405],if_helper25576,[cont_tail_arg215736]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper25576)?if_helper25576.app(cont_tail_arg215736):R.ffi.throwNonFunApp(L[405],if_helper25576,[cont_tail_arg215736]);
},
"from":L[405]});
}
++R.GAS;
return $z57385739;
};
return R.loadModulesNew(NAMESPACE,[$arrays12031,$lists32132,$option52233,$error72334,$sets92435],function($arrays12031,$lists32132,$option52233,$error72334,$sets92435) {
var arrays120 = R.getField($arrays12031,"values");
var lists321 = R.getField($lists32132,"values");
var option522 = R.getField($option52233,"values");
var error723 = R.getField($error72334,"values");
var sets924 = R.getField($sets92435,"values");
var arrays225 = R.getField($arrays12031,"types");
var lists426 = R.getField($lists32132,"types");
var option627 = R.getField($option52233,"types");
var error828 = R.getField($error72334,"types");
var sets1029 = R.getField($sets92435,"types");
return R.safeCall(function() {
var List112756 = R.getDotAnn(L[406],"lists",lists426,"List");
var Option125740 = R.getDotAnn(L[406],"option",option627,"Option");
var Array135741 = R.getDotAnn(L[406],"arrays",arrays225,"Array");
var Set145742 = R.getDotAnn(L[406],"sets",sets1029,"Set");
var array156622 = G(arrays120,"array",L[406]);
var build_DASH_array166621 = G(arrays120,"build-array",L[406]);
var array_DASH_from_DASH_list176620 = G(arrays120,"array-from-list",L[406]);
var is_DASH_array186619 = G(arrays120,"is-array",L[406]);
var list1948 = G(lists321,"list",L[406]);
var is_DASH_empty2046 = G(lists321,"is-empty",L[406]);
var is_DASH_link216618 = G(lists321,"is-link",L[406]);
var empty226617 = G(lists321,"empty",L[406]);
var link236616 = G(lists321,"link",L[406]);
var range246615 = G(lists321,"range",L[406]);
var repeat256614 = G(lists321,"repeat",L[406]);
var filter266613 = G(lists321,"filter",L[406]);
var partition276612 = G(lists321,"partition",L[406]);
var split_DASH_at286611 = G(lists321,"split-at",L[406]);
var any296610 = G(lists321,"any",L[406]);
var find306609 = G(lists321,"find",L[406]);
var map316608 = G(lists321,"map",L[406]);
var map2326607 = G(lists321,"map2",L[406]);
var map3336606 = G(lists321,"map3",L[406]);
var map4346605 = G(lists321,"map4",L[406]);
var map_n356604 = G(lists321,"map_n",L[406]);
var map2_n366603 = G(lists321,"map2_n",L[406]);
var map3_n376602 = G(lists321,"map3_n",L[406]);
var map4_n386601 = G(lists321,"map4_n",L[406]);
var each396600 = G(lists321,"each",L[406]);
var each2406599 = G(lists321,"each2",L[406]);
var each3416598 = G(lists321,"each3",L[406]);
var each4426597 = G(lists321,"each4",L[406]);
var each_n436596 = G(lists321,"each_n",L[406]);
var each2_n446595 = G(lists321,"each2_n",L[406]);
var each3_n456594 = G(lists321,"each3_n",L[406]);
var each4_n466593 = G(lists321,"each4_n",L[406]);
var fold476592 = G(lists321,"fold",L[406]);
var fold2486591 = G(lists321,"fold2",L[406]);
var fold3496590 = G(lists321,"fold3",L[406]);
var fold4506589 = G(lists321,"fold4",L[406]);
var index516588 = G(lists321,"index",L[406]);
var Option526587 = G(option522,"Option",L[406]);
var is_DASH_none536586 = G(option522,"is-none",L[406]);
var is_DASH_some546585 = G(option522,"is-some",L[406]);
var none556584 = G(option522,"none",L[406]);
var some566583 = G(option522,"some",L[406]);
var set576582 = G(sets924,"set",L[406]);
var tree_DASH_set586581 = G(sets924,"tree-set",L[406]);
var list_DASH_set596580 = G(sets924,"list-set",L[406]);
var PPrintDocT2615743 = R.namedBrander("PPrintDoc");
var PPrintDoc6039 = R.makeBranderAnn(PPrintDocT2615743,"PPrintDoc");
var ItemT3635744 = R.namedBrander("Item");
var Item6238 = R.makeBranderAnn(ItemT3635744,"Item");
var PPrintDoc4645745 = {"$var":D,
"$name":"PPrintDoc4"};
var PPrintDoc6540 = {"$var":D,
"$name":"PPrintDoc"};
var is_DASH_PPrintDoc665748 = {"$var":D,
"$name":"is-PPrintDoc"};
var is_DASH_mt_DASH_doc6747 = {"$var":D,
"$name":"is-mt-doc"};
var mt_DASH_doc685751 = {"$var":D,
"$name":"mt-doc"};
var is_DASH_str695753 = {"$var":D,
"$name":"is-str"};
var str7050 = {"$var":D,
"$name":"str"};
var is_DASH_hardline715756 = {"$var":D,
"$name":"is-hardline"};
var hardline7244 = {"$var":D,
"$name":"hardline"};
var is_DASH_blank735759 = {"$var":D,
"$name":"is-blank"};
var blank7442 = {"$var":D,
"$name":"blank"};
var is_DASH_concat755563 = {"$var":D,
"$name":"is-concat"};
var concat765562 = {"$var":D,
"$name":"concat"};
var is_DASH_nest775764 = {"$var":D,
"$name":"is-nest"};
var nest7849 = {"$var":D,
"$name":"nest"};
var is_DASH_if_DASH_flat795767 = {"$var":D,
"$name":"is-if-flat"};
var if_DASH_flat8045 = {"$var":D,
"$name":"if-flat"};
var is_DASH_align815770 = {"$var":D,
"$name":"is-align"};
var align8241 = {"$var":D,
"$name":"align"};
var is_DASH_align_DASH_spaces835773 = {"$var":D,
"$name":"is-align-spaces"};
var align_DASH_spaces845775 = {"$var":D,
"$name":"align-spaces"};
var is_DASH_group855777 = {"$var":D,
"$name":"is-group"};
var group8643 = {"$var":D,
"$name":"group"};
var Item5875780 = {"$var":D,
"$name":"Item5"};
var Item885782 = {"$var":D,
"$name":"Item"};
var is_DASH_Item895784 = {"$var":D,
"$name":"is-Item"};
var is_DASH_item905786 = {"$var":D,
"$name":"is-item"};
var item912759 = {"$var":D,
"$name":"item"};
var format925789 = {"$var":D,
"$name":"format"};
var anf_shared405867 = R.makeMethod(function(self1245565) {
return function(other1255564) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[506],1,arguments);
}
var $z65726573 = D;
var $f65786579 = function(_) {
return R.isFunction(is_DASH_mt_DASH_doc6747.$var === D?U(L[505],"is-mt-doc"):is_DASH_mt_DASH_doc6747.$var)?is_DASH_mt_DASH_doc6747.$var === D?U(L[505],"is-mt-doc"):is_DASH_mt_DASH_doc6747.$var.app(self1245565):R.ffi.throwNonFunApp(L[386],is_DASH_mt_DASH_doc6747.$var === D?U(L[505],"is-mt-doc"):is_DASH_mt_DASH_doc6747.$var,[self1245565]);
};
try {
if(--R.GAS > 0) {
$z65726573 = $f65786579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65786579,
"from":L[386]});
}
} catch($e65706571) {
if(R.isCont($e65706571)) {
var $ss65746575 = {"from":L[386],
"go":function(if_DASH_665561) {
return $Hif_DASH_9415560(if_DASH_665561,concat765562,is_DASH_concat755563,is_DASH_mt_DASH_doc6747,other1255564,self1245565,_plus8);
}};
$e65706571.stack[R.EXN_STACKHEIGHT++] = $ss65746575;
}
if(R.isPyretException($e65706571)) {
$e65706571.pyretStack.push(L[386]);
}
throw $e65706571;
}
var $ret65766577 = $Hif_DASH_9415560($z65726573,concat765562,is_DASH_concat755563,is_DASH_mt_DASH_doc6747,other1255564,self1245565,_plus8);
++R.GAS;
return $ret65766577;
};
},{"length":2});
var anf_shared915868 = R.makeMethod(function(self1266569) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[493],0,arguments);
}
var cases_DASH_val676568 = self1266569;
var anf_fun426444 = G(cases_DASH_val676568,"_match",L[494]);
var anf_obj446448 = R.makeFunction(function($underscore1276565,$underscore1286566) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[504],2,arguments);
}
var ann_DASH_check_DASH_temp436567 = ("EmptyDoc");
return ann_DASH_check_DASH_temp436567;
});
var anf_obj476449 = R.makeFunction(function(s1296552,$underscore1306553,$underscore1316554) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[382],3,arguments);
}
var $z65576558 = D;
var $f65636564 = function(_) {
return R.isFunction(_plus8)?_plus8.app(("Str('"),s1296552):R.ffi.throwNonFunApp(L[503],_plus8,[("Str('"),s1296552]);
};
try {
if(--R.GAS > 0) {
$z65576558 = $f65636564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65636564,
"from":L[503]});
}
} catch($e65556556) {
if(R.isCont($e65556556)) {
var $ss65596560 = {"from":L[503],
"go":function(anf_arg465547) {
return $Hanf_arg9435546(anf_arg465547,_plus8);
}};
$e65556556.stack[R.EXN_STACKHEIGHT++] = $ss65596560;
}
if(R.isPyretException($e65556556)) {
$e65556556.pyretStack.push(L[503]);
}
throw $e65556556;
}
var $ret65616562 = $Hanf_arg9435546($z65576558,_plus8);
++R.GAS;
return $ret65616562;
});
var anf_obj496450 = R.makeFunction(function($underscore1326549,$underscore1336550) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[502],2,arguments);
}
var ann_DASH_check_DASH_temp486551 = ("CRLF");
return ann_DASH_check_DASH_temp486551;
});
var anf_obj536451 = R.makeFunction(function(n1346536,$underscore1356537,$underscore1366538) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[381],3,arguments);
}
var $z65416542 = D;
var $f65476548 = function(_) {
return R.isFunction(tostring15)?tostring15.app(n1346536):R.ffi.throwNonFunApp(L[501],tostring15,[n1346536]);
};
try {
if(--R.GAS > 0) {
$z65416542 = $f65476548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65476548,
"from":L[501]});
}
} catch($e65396540) {
if(R.isCont($e65396540)) {
var $ss65436544 = {"from":L[501],
"go":function(anf_arg515521) {
return $Hanf_arg9465520(anf_arg515521,_plus8);
}};
$e65396540.stack[R.EXN_STACKHEIGHT++] = $ss65436544;
}
if(R.isPyretException($e65396540)) {
$e65396540.pyretStack.push(L[501]);
}
throw $e65396540;
}
var $ret65456546 = $Hanf_arg9465520($z65416542,_plus8);
++R.GAS;
return $ret65456546;
});
var anf_obj606452 = R.makeFunction(function(fst1376523,snd1385459,$underscore1396524,$underscore1406525) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[379],4,arguments);
}
var $z65286529 = D;
var $f65346535 = function(_) {
return R.isFunction(tostring15)?tostring15.app(fst1376523):R.ffi.throwNonFunApp(L[500],tostring15,[fst1376523]);
};
try {
if(--R.GAS > 0) {
$z65286529 = $f65346535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65346535,
"from":L[500]});
}
} catch($e65266527) {
if(R.isCont($e65266527)) {
var $ss65306531 = {"from":L[500],
"go":function(anf_arg555458) {
return $Hanf_arg9525457(anf_arg555458,snd1385459,_plus8,tostring15);
}};
$e65266527.stack[R.EXN_STACKHEIGHT++] = $ss65306531;
}
if(R.isPyretException($e65266527)) {
$e65266527.pyretStack.push(L[500]);
}
throw $e65266527;
}
var $ret65326533 = $Hanf_arg9525457($z65286529,snd1385459,_plus8,tostring15);
++R.GAS;
return $ret65326533;
});
var anf_obj676453 = R.makeFunction(function(indent1416510,d1425396,$underscore1436511,$underscore1446512) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[376],4,arguments);
}
var $z65156516 = D;
var $f65216522 = function(_) {
return R.isFunction(tostring15)?tostring15.app(indent1416510):R.ffi.throwNonFunApp(L[499],tostring15,[indent1416510]);
};
try {
if(--R.GAS > 0) {
$z65156516 = $f65216522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65216522,
"from":L[499]});
}
} catch($e65136514) {
if(R.isCont($e65136514)) {
var $ss65176518 = {"from":L[499],
"go":function(anf_arg625395) {
return $Hanf_arg9585394(anf_arg625395,d1425396,_plus8,tostring15);
}};
$e65136514.stack[R.EXN_STACKHEIGHT++] = $ss65176518;
}
if(R.isPyretException($e65136514)) {
$e65136514.pyretStack.push(L[499]);
}
throw $e65136514;
}
var $ret65196520 = $Hanf_arg9585394($z65156516,d1425396,_plus8,tostring15);
++R.GAS;
return $ret65196520;
});
var anf_obj746454 = R.makeFunction(function(flat1456497,vert1465333,$underscore1476498,$underscore1486499) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[373],4,arguments);
}
var $z65026503 = D;
var $f65086509 = function(_) {
return R.isFunction(tostring15)?tostring15.app(flat1456497):R.ffi.throwNonFunApp(L[498],tostring15,[flat1456497]);
};
try {
if(--R.GAS > 0) {
$z65026503 = $f65086509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65086509,
"from":L[498]});
}
} catch($e65006501) {
if(R.isCont($e65006501)) {
var $ss65046505 = {"from":L[498],
"go":function(anf_arg695332) {
return $Hanf_arg9645331(anf_arg695332,vert1465333,_plus8,tostring15);
}};
$e65006501.stack[R.EXN_STACKHEIGHT++] = $ss65046505;
}
if(R.isPyretException($e65006501)) {
$e65006501.pyretStack.push(L[498]);
}
throw $e65006501;
}
var $ret65066507 = $Hanf_arg9645331($z65026503,vert1465333,_plus8,tostring15);
++R.GAS;
return $ret65066507;
});
var anf_obj796455 = R.makeFunction(function(d1496484,$underscore1506485,$underscore1516486) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[370],3,arguments);
}
var $z64896490 = D;
var $f64956496 = function(_) {
return R.isFunction(tostring15)?tostring15.app(d1496484):R.ffi.throwNonFunApp(L[497],tostring15,[d1496484]);
};
try {
if(--R.GAS > 0) {
$z64896490 = $f64956496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64956496,
"from":L[497]});
}
} catch($e64876488) {
if(R.isCont($e64876488)) {
var $ss64916492 = {"from":L[497],
"go":function(anf_arg765294) {
return $Hanf_arg9685293(anf_arg765294,_plus8);
}};
$e64876488.stack[R.EXN_STACKHEIGHT++] = $ss64916492;
}
if(R.isPyretException($e64876488)) {
$e64876488.pyretStack.push(L[497]);
}
throw $e64876488;
}
var $ret64936494 = $Hanf_arg9685293($z64896490,_plus8);
++R.GAS;
return $ret64936494;
});
var anf_obj836456 = R.makeFunction(function(d1526471,$underscore1536472,$underscore1546473) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[368],3,arguments);
}
var $z64766477 = D;
var $f64826483 = function(_) {
return R.isFunction(tostring15)?tostring15.app(d1526471):R.ffi.throwNonFunApp(L[496],tostring15,[d1526471]);
};
try {
if(--R.GAS > 0) {
$z64766477 = $f64826483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64826483,
"from":L[496]});
}
} catch($e64746475) {
if(R.isCont($e64746475)) {
var $ss64786479 = {"from":L[496],
"go":function(anf_arg815268) {
return $Hanf_arg9715267(anf_arg815268,_plus8);
}};
$e64746475.stack[R.EXN_STACKHEIGHT++] = $ss64786479;
}
if(R.isPyretException($e64746475)) {
$e64746475.pyretStack.push(L[496]);
}
throw $e64746475;
}
var $ret64806481 = $Hanf_arg9715267($z64766477,_plus8);
++R.GAS;
return $ret64806481;
});
var anf_obj876457 = R.makeFunction(function(n1556458,$underscore1566459,$underscore1576460) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[366],3,arguments);
}
var $z64636464 = D;
var $f64696470 = function(_) {
return R.isFunction(tostring15)?tostring15.app(n1556458):R.ffi.throwNonFunApp(L[495],tostring15,[n1556458]);
};
try {
if(--R.GAS > 0) {
$z64636464 = $f64696470();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64696470,
"from":L[495]});
}
} catch($e64616462) {
if(R.isCont($e64616462)) {
var $ss64656466 = {"from":L[495],
"go":function(anf_arg855242) {
return $Hanf_arg9745241(anf_arg855242,_plus8);
}};
$e64616462.stack[R.EXN_STACKHEIGHT++] = $ss64656466;
}
if(R.isPyretException($e64616462)) {
$e64616462.pyretStack.push(L[495]);
}
throw $e64616462;
}
var $ret64676468 = $Hanf_arg9745241($z64636464,_plus8);
++R.GAS;
return $ret64676468;
});
var anf_arg886445 = R.makeObject({"mt-doc":anf_obj446448,
"str":anf_obj476449,
"hardline":anf_obj496450,
"blank":anf_obj536451,
"concat":anf_obj606452,
"nest":anf_obj676453,
"if-flat":anf_obj746454,
"group":anf_obj796455,
"align":anf_obj836456,
"align-spaces":anf_obj876457});
var anf_arg906446 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[494],0,arguments);
}
var ann_DASH_check_DASH_temp896447 = R.throwNoBranchesMatched(L[494],("cases"));
return ann_DASH_check_DASH_temp896447;
});
var $z64366437 = D;
var $f64426443 = function(_) {
return R.isFunction(anf_fun426444)?anf_fun426444.app(anf_arg886445,anf_arg906446):R.ffi.throwNonFunApp(L[493],anf_fun426444,[anf_arg886445,anf_arg906446]);
};
try {
if(--R.GAS > 0) {
$z64366437 = $f64426443();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64426443,
"from":L[493]});
}
} catch($e64346435) {
if(R.isCont($e64346435)) {
var $ss64386439 = {"from":L[493],
"go":function(ann_DASH_check_DASH_temp415240) {
return $Hann_DASH_check_DASH_temp9755239(ann_DASH_check_DASH_temp415240);
}};
$e64346435.stack[R.EXN_STACKHEIGHT++] = $ss64386439;
}
if(R.isPyretException($e64346435)) {
$e64346435.pyretStack.push(L[493]);
}
throw $e64346435;
}
var $ret64406441 = $Hann_DASH_check_DASH_temp9755239($z64366437);
++R.GAS;
return $ret64406441;
};
},{"length":1});
var anf_shared935869 = R.makeMethod(function(self1586433) {
return function(width1596432) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[492],1,arguments);
}
var $z64246425 = D;
var $f64306431 = function(_) {
return R.isFunction(format925789.$var === D?U(L[491],"format"):format925789.$var)?format925789.$var === D?U(L[491],"format"):format925789.$var.app(width1596432,self1586433):R.ffi.throwNonFunApp(L[492],format925789.$var === D?U(L[491],"format"):format925789.$var,[width1596432,self1586433]);
};
try {
if(--R.GAS > 0) {
$z64246425 = $f64306431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64306431,
"from":L[492]});
}
} catch($e64226423) {
if(R.isCont($e64226423)) {
var $ss64266427 = {"from":L[492],
"go":function(ann_DASH_check_DASH_temp925238) {
return $Hann_DASH_check_DASH_temp9765237(ann_DASH_check_DASH_temp925238);
}};
$e64226423.stack[R.EXN_STACKHEIGHT++] = $ss64266427;
}
if(R.isPyretException($e64226423)) {
$e64226423.pyretStack.push(L[492]);
}
throw $e64226423;
}
var $ret64286429 = $Hann_DASH_check_DASH_temp9765237($z64246425);
++R.GAS;
return $ret64286429;
};
},{"length":2});
var anf_variant_member1065875 = R.makeMethod(function(self26402) {
return function(cases_DASH_funs36403,else_DASH_clause46414) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[364],2,arguments);
}
var if_DASH_66415 = R.hasField(cases_DASH_funs36403,("mt-doc"));
var if_helper955230 = R.makeFunction(function(if_helper_arg966420) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[364],1,arguments);
}
var ann_DASH_check_DASH_temp946421 = if_helper_arg966420;
return ann_DASH_check_DASH_temp946421;
});
var anf_if996419 = R.isBoolean(if_DASH_66415);
if(R.isPyretTrue(anf_if996419)) {
if(R.isPyretTrue(if_DASH_66415)) {
var call_DASH_mt_DASH_doc16399 = G(cases_DASH_funs36403,"mt-doc",L[364]);
var anf_arg1026400 = G(self26402,"flat-width",L[490]);
var anf_arg1036401 = G(self26402,"has-hardline",L[489]);
var $z63916392 = D;
var $f63976398 = function(_) {
return R.isFunction(call_DASH_mt_DASH_doc16399)?call_DASH_mt_DASH_doc16399.app(anf_arg1026400,anf_arg1036401):R.ffi.throwNonFunApp(L[364],call_DASH_mt_DASH_doc16399,[anf_arg1026400,anf_arg1036401]);
};
try {
if(--R.GAS > 0) {
$z63916392 = $f63976398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63976398,
"from":L[364]});
}
} catch($e63896390) {
if(R.isCont($e63896390)) {
var $ss63936394 = {"from":L[364],
"go":function(cont_tail_arg1045229) {
return $Hcont_tail_arg9775228(cont_tail_arg1045229,if_helper955230);
}};
$e63896390.stack[R.EXN_STACKHEIGHT++] = $ss63936394;
}
if(R.isPyretException($e63896390)) {
$e63896390.pyretStack.push(L[364]);
}
throw $e63896390;
}
var $ret63956396 = $Hcont_tail_arg9775228($z63916392,if_helper955230);
++R.GAS;
return $ret63956396;
} else {
var $z64066407 = D;
var $f64126413 = function(_) {
return R.isFunction(else_DASH_clause46414)?else_DASH_clause46414.app():R.ffi.throwNonFunApp(L[364],else_DASH_clause46414,[]);
};
try {
if(--R.GAS > 0) {
$z64066407 = $f64126413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64126413,
"from":L[364]});
}
} catch($e64046405) {
if(R.isCont($e64046405)) {
var $ss64086409 = {"from":L[364],
"go":function(cont_tail_arg1005234) {
return $Hcont_tail_arg9785233(cont_tail_arg1005234,if_helper955230);
}};
$e64046405.stack[R.EXN_STACKHEIGHT++] = $ss64086409;
}
if(R.isPyretException($e64046405)) {
$e64046405.pyretStack.push(L[364]);
}
throw $e64046405;
}
var $ret64106411 = $Hcont_tail_arg9785233($z64066407,if_helper955230);
++R.GAS;
return $ret64106411;
}
} else {
var cont_tail_arg976418 = R.throwNonBooleanCondition(L[364],("if"),if_DASH_66415);
if(--R.GAS > 0) {
$z64166417 = R.isFunction(if_helper955230)?if_helper955230.app(cont_tail_arg976418):R.ffi.throwNonFunApp(L[364],if_helper955230,[cont_tail_arg976418]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper955230)?if_helper955230.app(cont_tail_arg976418):R.ffi.throwNonFunApp(L[364],if_helper955230,[cont_tail_arg976418]);
},
"from":L[364]});
}
++R.GAS;
return $z64166417;
}
};
},{"length":3});
var anf_variant_member1165876 = R.makeMethod(function(self55154) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[364],0,arguments);
}
var anf_arg1086388 = G(self55154,"flat-width",L[364]);
var $z63806381 = D;
var $f63866387 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1086388):R.ffi.throwNonFunApp(L[364],torepr14,[anf_arg1086388]);
};
try {
if(--R.GAS > 0) {
$z63806381 = $f63866387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63866387,
"from":L[364]});
}
} catch($e63786379) {
if(R.isCont($e63786379)) {
var $ss63826383 = {"from":L[364],
"go":function(anf_arg1095153) {
return $Hanf_arg9855152(anf_arg1095153,self55154,_plus8,torepr14);
}};
$e63786379.stack[R.EXN_STACKHEIGHT++] = $ss63826383;
}
if(R.isPyretException($e63786379)) {
$e63786379.pyretStack.push(L[364]);
}
throw $e63786379;
}
var $ret63846385 = $Hanf_arg9855152($z63806381,self55154,_plus8,torepr14);
++R.GAS;
return $ret63846385;
};
},{"length":1});
var anf_variant_member1305884 = R.makeMethod(function(self86358) {
return function(cases_DASH_funs96359,else_DASH_clause106370) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[363],2,arguments);
}
var if_DASH_126371 = R.hasField(cases_DASH_funs96359,("str"));
var if_helper1185145 = R.makeFunction(function(if_helper_arg1196376) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[363],1,arguments);
}
var ann_DASH_check_DASH_temp1176377 = if_helper_arg1196376;
return ann_DASH_check_DASH_temp1176377;
});
var anf_if1226375 = R.isBoolean(if_DASH_126371);
if(R.isPyretTrue(anf_if1226375)) {
if(R.isPyretTrue(if_DASH_126371)) {
var call_DASH_str76354 = G(cases_DASH_funs96359,"str",L[363]);
var anf_arg1256355 = G(self86358,"s",L[488]);
var anf_arg1266356 = G(self86358,"flat-width",L[487]);
var anf_arg1276357 = G(self86358,"has-hardline",L[486]);
var $z63466347 = D;
var $f63526353 = function(_) {
return R.isFunction(call_DASH_str76354)?call_DASH_str76354.app(anf_arg1256355,anf_arg1266356,anf_arg1276357):R.ffi.throwNonFunApp(L[363],call_DASH_str76354,[anf_arg1256355,anf_arg1266356,anf_arg1276357]);
};
try {
if(--R.GAS > 0) {
$z63466347 = $f63526353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63526353,
"from":L[363]});
}
} catch($e63446345) {
if(R.isCont($e63446345)) {
var $ss63486349 = {"from":L[363],
"go":function(cont_tail_arg1285144) {
return $Hcont_tail_arg9865143(cont_tail_arg1285144,if_helper1185145);
}};
$e63446345.stack[R.EXN_STACKHEIGHT++] = $ss63486349;
}
if(R.isPyretException($e63446345)) {
$e63446345.pyretStack.push(L[363]);
}
throw $e63446345;
}
var $ret63506351 = $Hcont_tail_arg9865143($z63466347,if_helper1185145);
++R.GAS;
return $ret63506351;
} else {
var $z63626363 = D;
var $f63686369 = function(_) {
return R.isFunction(else_DASH_clause106370)?else_DASH_clause106370.app():R.ffi.throwNonFunApp(L[363],else_DASH_clause106370,[]);
};
try {
if(--R.GAS > 0) {
$z63626363 = $f63686369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63686369,
"from":L[363]});
}
} catch($e63606361) {
if(R.isCont($e63606361)) {
var $ss63646365 = {"from":L[363],
"go":function(cont_tail_arg1235149) {
return $Hcont_tail_arg9875148(cont_tail_arg1235149,if_helper1185145);
}};
$e63606361.stack[R.EXN_STACKHEIGHT++] = $ss63646365;
}
if(R.isPyretException($e63606361)) {
$e63606361.pyretStack.push(L[363]);
}
throw $e63606361;
}
var $ret63666367 = $Hcont_tail_arg9875148($z63626363,if_helper1185145);
++R.GAS;
return $ret63666367;
}
} else {
var cont_tail_arg1206374 = R.throwNonBooleanCondition(L[363],("if"),if_DASH_126371);
if(--R.GAS > 0) {
$z63726373 = R.isFunction(if_helper1185145)?if_helper1185145.app(cont_tail_arg1206374):R.ffi.throwNonFunApp(L[363],if_helper1185145,[cont_tail_arg1206374]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1185145)?if_helper1185145.app(cont_tail_arg1206374):R.ffi.throwNonFunApp(L[363],if_helper1185145,[cont_tail_arg1206374]);
},
"from":L[363]});
}
++R.GAS;
return $z63726373;
}
};
},{"length":3});
var anf_variant_member1445885 = R.makeMethod(function(self115032) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[363],0,arguments);
}
var anf_arg1326343 = G(self115032,"s",L[363]);
var $z63356336 = D;
var $f63416342 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1326343):R.ffi.throwNonFunApp(L[363],torepr14,[anf_arg1326343]);
};
try {
if(--R.GAS > 0) {
$z63356336 = $f63416342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63416342,
"from":L[363]});
}
} catch($e63336334) {
if(R.isCont($e63336334)) {
var $ss63376338 = {"from":L[363],
"go":function(anf_arg1335031) {
return $Hanf_arg9975030(anf_arg1335031,self115032,_plus8,torepr14);
}};
$e63336334.stack[R.EXN_STACKHEIGHT++] = $ss63376338;
}
if(R.isPyretException($e63336334)) {
$e63336334.pyretStack.push(L[363]);
}
throw $e63336334;
}
var $ret63396340 = $Hanf_arg9975030($z63356336,self115032,_plus8,torepr14);
++R.GAS;
return $ret63396340;
};
},{"length":1});
var anf_variant_member1575894 = R.makeMethod(function(self146313) {
return function(cases_DASH_funs156314,else_DASH_clause166325) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[362],2,arguments);
}
var if_DASH_186326 = R.hasField(cases_DASH_funs156314,("hardline"));
var if_helper1465023 = R.makeFunction(function(if_helper_arg1476331) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[362],1,arguments);
}
var ann_DASH_check_DASH_temp1456332 = if_helper_arg1476331;
return ann_DASH_check_DASH_temp1456332;
});
var anf_if1506330 = R.isBoolean(if_DASH_186326);
if(R.isPyretTrue(anf_if1506330)) {
if(R.isPyretTrue(if_DASH_186326)) {
var call_DASH_hardline136310 = G(cases_DASH_funs156314,"hardline",L[362]);
var anf_arg1536311 = G(self146313,"flat-width",L[485]);
var anf_arg1546312 = G(self146313,"has-hardline",L[484]);
var $z63026303 = D;
var $f63086309 = function(_) {
return R.isFunction(call_DASH_hardline136310)?call_DASH_hardline136310.app(anf_arg1536311,anf_arg1546312):R.ffi.throwNonFunApp(L[362],call_DASH_hardline136310,[anf_arg1536311,anf_arg1546312]);
};
try {
if(--R.GAS > 0) {
$z63026303 = $f63086309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63086309,
"from":L[362]});
}
} catch($e63006301) {
if(R.isCont($e63006301)) {
var $ss63046305 = {"from":L[362],
"go":function(cont_tail_arg1555022) {
return $Hcont_tail_arg9985021(cont_tail_arg1555022,if_helper1465023);
}};
$e63006301.stack[R.EXN_STACKHEIGHT++] = $ss63046305;
}
if(R.isPyretException($e63006301)) {
$e63006301.pyretStack.push(L[362]);
}
throw $e63006301;
}
var $ret63066307 = $Hcont_tail_arg9985021($z63026303,if_helper1465023);
++R.GAS;
return $ret63066307;
} else {
var $z63176318 = D;
var $f63236324 = function(_) {
return R.isFunction(else_DASH_clause166325)?else_DASH_clause166325.app():R.ffi.throwNonFunApp(L[362],else_DASH_clause166325,[]);
};
try {
if(--R.GAS > 0) {
$z63176318 = $f63236324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63236324,
"from":L[362]});
}
} catch($e63156316) {
if(R.isCont($e63156316)) {
var $ss63196320 = {"from":L[362],
"go":function(cont_tail_arg1515027) {
return $Hcont_tail_arg9995026(cont_tail_arg1515027,if_helper1465023);
}};
$e63156316.stack[R.EXN_STACKHEIGHT++] = $ss63196320;
}
if(R.isPyretException($e63156316)) {
$e63156316.pyretStack.push(L[362]);
}
throw $e63156316;
}
var $ret63216322 = $Hcont_tail_arg9995026($z63176318,if_helper1465023);
++R.GAS;
return $ret63216322;
}
} else {
var cont_tail_arg1486329 = R.throwNonBooleanCondition(L[362],("if"),if_DASH_186326);
if(--R.GAS > 0) {
$z63276328 = R.isFunction(if_helper1465023)?if_helper1465023.app(cont_tail_arg1486329):R.ffi.throwNonFunApp(L[362],if_helper1465023,[cont_tail_arg1486329]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1465023)?if_helper1465023.app(cont_tail_arg1486329):R.ffi.throwNonFunApp(L[362],if_helper1465023,[cont_tail_arg1486329]);
},
"from":L[362]});
}
++R.GAS;
return $z63276328;
}
};
},{"length":3});
var anf_variant_member1675895 = R.makeMethod(function(self174947) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[362],0,arguments);
}
var anf_arg1596299 = G(self174947,"flat-width",L[362]);
var $z62916292 = D;
var $f62976298 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1596299):R.ffi.throwNonFunApp(L[362],torepr14,[anf_arg1596299]);
};
try {
if(--R.GAS > 0) {
$z62916292 = $f62976298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62976298,
"from":L[362]});
}
} catch($e62896290) {
if(R.isCont($e62896290)) {
var $ss62936294 = {"from":L[362],
"go":function(anf_arg1604946) {
return $Hanf_arg10064945(anf_arg1604946,self174947,_plus8,torepr14);
}};
$e62896290.stack[R.EXN_STACKHEIGHT++] = $ss62936294;
}
if(R.isPyretException($e62896290)) {
$e62896290.pyretStack.push(L[362]);
}
throw $e62896290;
}
var $ret62956296 = $Hanf_arg10064945($z62916292,self174947,_plus8,torepr14);
++R.GAS;
return $ret62956296;
};
},{"length":1});
var anf_variant_member1815903 = R.makeMethod(function(self206269) {
return function(cases_DASH_funs216270,else_DASH_clause226281) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[361],2,arguments);
}
var if_DASH_246282 = R.hasField(cases_DASH_funs216270,("blank"));
var if_helper1694938 = R.makeFunction(function(if_helper_arg1706287) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[361],1,arguments);
}
var ann_DASH_check_DASH_temp1686288 = if_helper_arg1706287;
return ann_DASH_check_DASH_temp1686288;
});
var anf_if1736286 = R.isBoolean(if_DASH_246282);
if(R.isPyretTrue(anf_if1736286)) {
if(R.isPyretTrue(if_DASH_246282)) {
var call_DASH_blank196265 = G(cases_DASH_funs216270,"blank",L[361]);
var anf_arg1766266 = G(self206269,"n",L[483]);
var anf_arg1776267 = G(self206269,"flat-width",L[482]);
var anf_arg1786268 = G(self206269,"has-hardline",L[481]);
var $z62576258 = D;
var $f62636264 = function(_) {
return R.isFunction(call_DASH_blank196265)?call_DASH_blank196265.app(anf_arg1766266,anf_arg1776267,anf_arg1786268):R.ffi.throwNonFunApp(L[361],call_DASH_blank196265,[anf_arg1766266,anf_arg1776267,anf_arg1786268]);
};
try {
if(--R.GAS > 0) {
$z62576258 = $f62636264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62636264,
"from":L[361]});
}
} catch($e62556256) {
if(R.isCont($e62556256)) {
var $ss62596260 = {"from":L[361],
"go":function(cont_tail_arg1794937) {
return $Hcont_tail_arg10074936(cont_tail_arg1794937,if_helper1694938);
}};
$e62556256.stack[R.EXN_STACKHEIGHT++] = $ss62596260;
}
if(R.isPyretException($e62556256)) {
$e62556256.pyretStack.push(L[361]);
}
throw $e62556256;
}
var $ret62616262 = $Hcont_tail_arg10074936($z62576258,if_helper1694938);
++R.GAS;
return $ret62616262;
} else {
var $z62736274 = D;
var $f62796280 = function(_) {
return R.isFunction(else_DASH_clause226281)?else_DASH_clause226281.app():R.ffi.throwNonFunApp(L[361],else_DASH_clause226281,[]);
};
try {
if(--R.GAS > 0) {
$z62736274 = $f62796280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62796280,
"from":L[361]});
}
} catch($e62716272) {
if(R.isCont($e62716272)) {
var $ss62756276 = {"from":L[361],
"go":function(cont_tail_arg1744942) {
return $Hcont_tail_arg10084941(cont_tail_arg1744942,if_helper1694938);
}};
$e62716272.stack[R.EXN_STACKHEIGHT++] = $ss62756276;
}
if(R.isPyretException($e62716272)) {
$e62716272.pyretStack.push(L[361]);
}
throw $e62716272;
}
var $ret62776278 = $Hcont_tail_arg10084941($z62736274,if_helper1694938);
++R.GAS;
return $ret62776278;
}
} else {
var cont_tail_arg1716285 = R.throwNonBooleanCondition(L[361],("if"),if_DASH_246282);
if(--R.GAS > 0) {
$z62836284 = R.isFunction(if_helper1694938)?if_helper1694938.app(cont_tail_arg1716285):R.ffi.throwNonFunApp(L[361],if_helper1694938,[cont_tail_arg1716285]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1694938)?if_helper1694938.app(cont_tail_arg1716285):R.ffi.throwNonFunApp(L[361],if_helper1694938,[cont_tail_arg1716285]);
},
"from":L[361]});
}
++R.GAS;
return $z62836284;
}
};
},{"length":3});
var anf_variant_member1955904 = R.makeMethod(function(self234825) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[361],0,arguments);
}
var anf_arg1836254 = G(self234825,"n",L[361]);
var $z62466247 = D;
var $f62526253 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1836254):R.ffi.throwNonFunApp(L[361],torepr14,[anf_arg1836254]);
};
try {
if(--R.GAS > 0) {
$z62466247 = $f62526253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62526253,
"from":L[361]});
}
} catch($e62446245) {
if(R.isCont($e62446245)) {
var $ss62486249 = {"from":L[361],
"go":function(anf_arg1844824) {
return $Hanf_arg10184823(anf_arg1844824,self234825,_plus8,torepr14);
}};
$e62446245.stack[R.EXN_STACKHEIGHT++] = $ss62486249;
}
if(R.isPyretException($e62446245)) {
$e62446245.pyretStack.push(L[361]);
}
throw $e62446245;
}
var $ret62506251 = $Hanf_arg10184823($z62466247,self234825,_plus8,torepr14);
++R.GAS;
return $ret62506251;
};
},{"length":1});
var anf_variant_member2105913 = R.makeMethod(function(self266224) {
return function(cases_DASH_funs276225,else_DASH_clause286236) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[360],2,arguments);
}
var if_DASH_306237 = R.hasField(cases_DASH_funs276225,("concat"));
var if_helper1974816 = R.makeFunction(function(if_helper_arg1986242) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[360],1,arguments);
}
var ann_DASH_check_DASH_temp1966243 = if_helper_arg1986242;
return ann_DASH_check_DASH_temp1966243;
});
var anf_if2016241 = R.isBoolean(if_DASH_306237);
if(R.isPyretTrue(anf_if2016241)) {
if(R.isPyretTrue(if_DASH_306237)) {
var call_DASH_concat256219 = G(cases_DASH_funs276225,"concat",L[360]);
var anf_arg2046220 = G(self266224,"fst",L[480]);
var anf_arg2056221 = G(self266224,"snd",L[479]);
var anf_arg2066222 = G(self266224,"flat-width",L[478]);
var anf_arg2076223 = G(self266224,"has-hardline",L[477]);
var $z62116212 = D;
var $f62176218 = function(_) {
return R.isFunction(call_DASH_concat256219)?call_DASH_concat256219.app(anf_arg2046220,anf_arg2056221,anf_arg2066222,anf_arg2076223):R.ffi.throwNonFunApp(L[360],call_DASH_concat256219,[anf_arg2046220,anf_arg2056221,anf_arg2066222,anf_arg2076223]);
};
try {
if(--R.GAS > 0) {
$z62116212 = $f62176218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62176218,
"from":L[360]});
}
} catch($e62096210) {
if(R.isCont($e62096210)) {
var $ss62136214 = {"from":L[360],
"go":function(cont_tail_arg2084815) {
return $Hcont_tail_arg10194814(cont_tail_arg2084815,if_helper1974816);
}};
$e62096210.stack[R.EXN_STACKHEIGHT++] = $ss62136214;
}
if(R.isPyretException($e62096210)) {
$e62096210.pyretStack.push(L[360]);
}
throw $e62096210;
}
var $ret62156216 = $Hcont_tail_arg10194814($z62116212,if_helper1974816);
++R.GAS;
return $ret62156216;
} else {
var $z62286229 = D;
var $f62346235 = function(_) {
return R.isFunction(else_DASH_clause286236)?else_DASH_clause286236.app():R.ffi.throwNonFunApp(L[360],else_DASH_clause286236,[]);
};
try {
if(--R.GAS > 0) {
$z62286229 = $f62346235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62346235,
"from":L[360]});
}
} catch($e62266227) {
if(R.isCont($e62266227)) {
var $ss62306231 = {"from":L[360],
"go":function(cont_tail_arg2024820) {
return $Hcont_tail_arg10204819(cont_tail_arg2024820,if_helper1974816);
}};
$e62266227.stack[R.EXN_STACKHEIGHT++] = $ss62306231;
}
if(R.isPyretException($e62266227)) {
$e62266227.pyretStack.push(L[360]);
}
throw $e62266227;
}
var $ret62326233 = $Hcont_tail_arg10204819($z62286229,if_helper1974816);
++R.GAS;
return $ret62326233;
}
} else {
var cont_tail_arg1996240 = R.throwNonBooleanCondition(L[360],("if"),if_DASH_306237);
if(--R.GAS > 0) {
$z62386239 = R.isFunction(if_helper1974816)?if_helper1974816.app(cont_tail_arg1996240):R.ffi.throwNonFunApp(L[360],if_helper1974816,[cont_tail_arg1996240]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper1974816)?if_helper1974816.app(cont_tail_arg1996240):R.ffi.throwNonFunApp(L[360],if_helper1974816,[cont_tail_arg1996240]);
},
"from":L[360]});
}
++R.GAS;
return $z62386239;
}
};
},{"length":3});
var anf_variant_member2285914 = R.makeMethod(function(self294666) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[360],0,arguments);
}
var anf_arg2126208 = G(self294666,"fst",L[360]);
var $z62006201 = D;
var $f62066207 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2126208):R.ffi.throwNonFunApp(L[360],torepr14,[anf_arg2126208]);
};
try {
if(--R.GAS > 0) {
$z62006201 = $f62066207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62066207,
"from":L[360]});
}
} catch($e61986199) {
if(R.isCont($e61986199)) {
var $ss62026203 = {"from":L[360],
"go":function(anf_arg2134665) {
return $Hanf_arg10334664(anf_arg2134665,self294666,_plus8,torepr14);
}};
$e61986199.stack[R.EXN_STACKHEIGHT++] = $ss62026203;
}
if(R.isPyretException($e61986199)) {
$e61986199.pyretStack.push(L[360]);
}
throw $e61986199;
}
var $ret62046205 = $Hanf_arg10334664($z62006201,self294666,_plus8,torepr14);
++R.GAS;
return $ret62046205;
};
},{"length":1});
var anf_variant_member2435924 = R.makeMethod(function(self326178) {
return function(cases_DASH_funs336179,else_DASH_clause346190) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[359],2,arguments);
}
var if_DASH_366191 = R.hasField(cases_DASH_funs336179,("nest"));
var if_helper2304657 = R.makeFunction(function(if_helper_arg2316196) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[359],1,arguments);
}
var ann_DASH_check_DASH_temp2296197 = if_helper_arg2316196;
return ann_DASH_check_DASH_temp2296197;
});
var anf_if2346195 = R.isBoolean(if_DASH_366191);
if(R.isPyretTrue(anf_if2346195)) {
if(R.isPyretTrue(if_DASH_366191)) {
var call_DASH_nest316173 = G(cases_DASH_funs336179,"nest",L[359]);
var anf_arg2376174 = G(self326178,"indent",L[476]);
var anf_arg2386175 = G(self326178,"d",L[475]);
var anf_arg2396176 = G(self326178,"flat-width",L[474]);
var anf_arg2406177 = G(self326178,"has-hardline",L[473]);
var $z61656166 = D;
var $f61716172 = function(_) {
return R.isFunction(call_DASH_nest316173)?call_DASH_nest316173.app(anf_arg2376174,anf_arg2386175,anf_arg2396176,anf_arg2406177):R.ffi.throwNonFunApp(L[359],call_DASH_nest316173,[anf_arg2376174,anf_arg2386175,anf_arg2396176,anf_arg2406177]);
};
try {
if(--R.GAS > 0) {
$z61656166 = $f61716172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61716172,
"from":L[359]});
}
} catch($e61636164) {
if(R.isCont($e61636164)) {
var $ss61676168 = {"from":L[359],
"go":function(cont_tail_arg2414656) {
return $Hcont_tail_arg10344655(cont_tail_arg2414656,if_helper2304657);
}};
$e61636164.stack[R.EXN_STACKHEIGHT++] = $ss61676168;
}
if(R.isPyretException($e61636164)) {
$e61636164.pyretStack.push(L[359]);
}
throw $e61636164;
}
var $ret61696170 = $Hcont_tail_arg10344655($z61656166,if_helper2304657);
++R.GAS;
return $ret61696170;
} else {
var $z61826183 = D;
var $f61886189 = function(_) {
return R.isFunction(else_DASH_clause346190)?else_DASH_clause346190.app():R.ffi.throwNonFunApp(L[359],else_DASH_clause346190,[]);
};
try {
if(--R.GAS > 0) {
$z61826183 = $f61886189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61886189,
"from":L[359]});
}
} catch($e61806181) {
if(R.isCont($e61806181)) {
var $ss61846185 = {"from":L[359],
"go":function(cont_tail_arg2354661) {
return $Hcont_tail_arg10354660(cont_tail_arg2354661,if_helper2304657);
}};
$e61806181.stack[R.EXN_STACKHEIGHT++] = $ss61846185;
}
if(R.isPyretException($e61806181)) {
$e61806181.pyretStack.push(L[359]);
}
throw $e61806181;
}
var $ret61866187 = $Hcont_tail_arg10354660($z61826183,if_helper2304657);
++R.GAS;
return $ret61866187;
}
} else {
var cont_tail_arg2326194 = R.throwNonBooleanCondition(L[359],("if"),if_DASH_366191);
if(--R.GAS > 0) {
$z61926193 = R.isFunction(if_helper2304657)?if_helper2304657.app(cont_tail_arg2326194):R.ffi.throwNonFunApp(L[359],if_helper2304657,[cont_tail_arg2326194]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2304657)?if_helper2304657.app(cont_tail_arg2326194):R.ffi.throwNonFunApp(L[359],if_helper2304657,[cont_tail_arg2326194]);
},
"from":L[359]});
}
++R.GAS;
return $z61926193;
}
};
},{"length":3});
var anf_variant_member2615925 = R.makeMethod(function(self354507) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[359],0,arguments);
}
var anf_arg2456162 = G(self354507,"indent",L[359]);
var $z61546155 = D;
var $f61606161 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2456162):R.ffi.throwNonFunApp(L[359],torepr14,[anf_arg2456162]);
};
try {
if(--R.GAS > 0) {
$z61546155 = $f61606161();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61606161,
"from":L[359]});
}
} catch($e61526153) {
if(R.isCont($e61526153)) {
var $ss61566157 = {"from":L[359],
"go":function(anf_arg2464506) {
return $Hanf_arg10484505(anf_arg2464506,self354507,_plus8,torepr14);
}};
$e61526153.stack[R.EXN_STACKHEIGHT++] = $ss61566157;
}
if(R.isPyretException($e61526153)) {
$e61526153.pyretStack.push(L[359]);
}
throw $e61526153;
}
var $ret61586159 = $Hanf_arg10484505($z61546155,self354507,_plus8,torepr14);
++R.GAS;
return $ret61586159;
};
},{"length":1});
var anf_variant_member2765935 = R.makeMethod(function(self386132) {
return function(cases_DASH_funs396133,else_DASH_clause406144) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[358],2,arguments);
}
var if_DASH_426145 = R.hasField(cases_DASH_funs396133,("if-flat"));
var if_helper2634498 = R.makeFunction(function(if_helper_arg2646150) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[358],1,arguments);
}
var ann_DASH_check_DASH_temp2626151 = if_helper_arg2646150;
return ann_DASH_check_DASH_temp2626151;
});
var anf_if2676149 = R.isBoolean(if_DASH_426145);
if(R.isPyretTrue(anf_if2676149)) {
if(R.isPyretTrue(if_DASH_426145)) {
var call_DASH_if_DASH_flat376127 = G(cases_DASH_funs396133,"if-flat",L[358]);
var anf_arg2706128 = G(self386132,"flat",L[472]);
var anf_arg2716129 = G(self386132,"vert",L[471]);
var anf_arg2726130 = G(self386132,"flat-width",L[470]);
var anf_arg2736131 = G(self386132,"has-hardline",L[469]);
var $z61196120 = D;
var $f61256126 = function(_) {
return R.isFunction(call_DASH_if_DASH_flat376127)?call_DASH_if_DASH_flat376127.app(anf_arg2706128,anf_arg2716129,anf_arg2726130,anf_arg2736131):R.ffi.throwNonFunApp(L[358],call_DASH_if_DASH_flat376127,[anf_arg2706128,anf_arg2716129,anf_arg2726130,anf_arg2736131]);
};
try {
if(--R.GAS > 0) {
$z61196120 = $f61256126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61256126,
"from":L[358]});
}
} catch($e61176118) {
if(R.isCont($e61176118)) {
var $ss61216122 = {"from":L[358],
"go":function(cont_tail_arg2744497) {
return $Hcont_tail_arg10494496(cont_tail_arg2744497,if_helper2634498);
}};
$e61176118.stack[R.EXN_STACKHEIGHT++] = $ss61216122;
}
if(R.isPyretException($e61176118)) {
$e61176118.pyretStack.push(L[358]);
}
throw $e61176118;
}
var $ret61236124 = $Hcont_tail_arg10494496($z61196120,if_helper2634498);
++R.GAS;
return $ret61236124;
} else {
var $z61366137 = D;
var $f61426143 = function(_) {
return R.isFunction(else_DASH_clause406144)?else_DASH_clause406144.app():R.ffi.throwNonFunApp(L[358],else_DASH_clause406144,[]);
};
try {
if(--R.GAS > 0) {
$z61366137 = $f61426143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61426143,
"from":L[358]});
}
} catch($e61346135) {
if(R.isCont($e61346135)) {
var $ss61386139 = {"from":L[358],
"go":function(cont_tail_arg2684502) {
return $Hcont_tail_arg10504501(cont_tail_arg2684502,if_helper2634498);
}};
$e61346135.stack[R.EXN_STACKHEIGHT++] = $ss61386139;
}
if(R.isPyretException($e61346135)) {
$e61346135.pyretStack.push(L[358]);
}
throw $e61346135;
}
var $ret61406141 = $Hcont_tail_arg10504501($z61366137,if_helper2634498);
++R.GAS;
return $ret61406141;
}
} else {
var cont_tail_arg2656148 = R.throwNonBooleanCondition(L[358],("if"),if_DASH_426145);
if(--R.GAS > 0) {
$z61466147 = R.isFunction(if_helper2634498)?if_helper2634498.app(cont_tail_arg2656148):R.ffi.throwNonFunApp(L[358],if_helper2634498,[cont_tail_arg2656148]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2634498)?if_helper2634498.app(cont_tail_arg2656148):R.ffi.throwNonFunApp(L[358],if_helper2634498,[cont_tail_arg2656148]);
},
"from":L[358]});
}
++R.GAS;
return $z61466147;
}
};
},{"length":3});
var anf_variant_member2945936 = R.makeMethod(function(self414348) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[358],0,arguments);
}
var anf_arg2786116 = G(self414348,"flat",L[358]);
var $z61086109 = D;
var $f61146115 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2786116):R.ffi.throwNonFunApp(L[358],torepr14,[anf_arg2786116]);
};
try {
if(--R.GAS > 0) {
$z61086109 = $f61146115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61146115,
"from":L[358]});
}
} catch($e61066107) {
if(R.isCont($e61066107)) {
var $ss61106111 = {"from":L[358],
"go":function(anf_arg2794347) {
return $Hanf_arg10634346(anf_arg2794347,self414348,_plus8,torepr14);
}};
$e61066107.stack[R.EXN_STACKHEIGHT++] = $ss61106111;
}
if(R.isPyretException($e61066107)) {
$e61066107.pyretStack.push(L[358]);
}
throw $e61066107;
}
var $ret61126113 = $Hanf_arg10634346($z61086109,self414348,_plus8,torepr14);
++R.GAS;
return $ret61126113;
};
},{"length":1});
var anf_variant_member3085946 = R.makeMethod(function(self446086) {
return function(cases_DASH_funs456087,else_DASH_clause466098) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[357],2,arguments);
}
var if_DASH_486099 = R.hasField(cases_DASH_funs456087,("align"));
var if_helper2964339 = R.makeFunction(function(if_helper_arg2976104) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[357],1,arguments);
}
var ann_DASH_check_DASH_temp2956105 = if_helper_arg2976104;
return ann_DASH_check_DASH_temp2956105;
});
var anf_if3006103 = R.isBoolean(if_DASH_486099);
if(R.isPyretTrue(anf_if3006103)) {
if(R.isPyretTrue(if_DASH_486099)) {
var call_DASH_align436082 = G(cases_DASH_funs456087,"align",L[357]);
var anf_arg3036083 = G(self446086,"d",L[468]);
var anf_arg3046084 = G(self446086,"flat-width",L[467]);
var anf_arg3056085 = G(self446086,"has-hardline",L[466]);
var $z60746075 = D;
var $f60806081 = function(_) {
return R.isFunction(call_DASH_align436082)?call_DASH_align436082.app(anf_arg3036083,anf_arg3046084,anf_arg3056085):R.ffi.throwNonFunApp(L[357],call_DASH_align436082,[anf_arg3036083,anf_arg3046084,anf_arg3056085]);
};
try {
if(--R.GAS > 0) {
$z60746075 = $f60806081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60806081,
"from":L[357]});
}
} catch($e60726073) {
if(R.isCont($e60726073)) {
var $ss60766077 = {"from":L[357],
"go":function(cont_tail_arg3064338) {
return $Hcont_tail_arg10644337(cont_tail_arg3064338,if_helper2964339);
}};
$e60726073.stack[R.EXN_STACKHEIGHT++] = $ss60766077;
}
if(R.isPyretException($e60726073)) {
$e60726073.pyretStack.push(L[357]);
}
throw $e60726073;
}
var $ret60786079 = $Hcont_tail_arg10644337($z60746075,if_helper2964339);
++R.GAS;
return $ret60786079;
} else {
var $z60906091 = D;
var $f60966097 = function(_) {
return R.isFunction(else_DASH_clause466098)?else_DASH_clause466098.app():R.ffi.throwNonFunApp(L[357],else_DASH_clause466098,[]);
};
try {
if(--R.GAS > 0) {
$z60906091 = $f60966097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60966097,
"from":L[357]});
}
} catch($e60886089) {
if(R.isCont($e60886089)) {
var $ss60926093 = {"from":L[357],
"go":function(cont_tail_arg3014343) {
return $Hcont_tail_arg10654342(cont_tail_arg3014343,if_helper2964339);
}};
$e60886089.stack[R.EXN_STACKHEIGHT++] = $ss60926093;
}
if(R.isPyretException($e60886089)) {
$e60886089.pyretStack.push(L[357]);
}
throw $e60886089;
}
var $ret60946095 = $Hcont_tail_arg10654342($z60906091,if_helper2964339);
++R.GAS;
return $ret60946095;
}
} else {
var cont_tail_arg2986102 = R.throwNonBooleanCondition(L[357],("if"),if_DASH_486099);
if(--R.GAS > 0) {
$z61006101 = R.isFunction(if_helper2964339)?if_helper2964339.app(cont_tail_arg2986102):R.ffi.throwNonFunApp(L[357],if_helper2964339,[cont_tail_arg2986102]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper2964339)?if_helper2964339.app(cont_tail_arg2986102):R.ffi.throwNonFunApp(L[357],if_helper2964339,[cont_tail_arg2986102]);
},
"from":L[357]});
}
++R.GAS;
return $z61006101;
}
};
},{"length":3});
var anf_variant_member3225947 = R.makeMethod(function(self474226) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[357],0,arguments);
}
var anf_arg3106071 = G(self474226,"d",L[357]);
var $z60636064 = D;
var $f60696070 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3106071):R.ffi.throwNonFunApp(L[357],torepr14,[anf_arg3106071]);
};
try {
if(--R.GAS > 0) {
$z60636064 = $f60696070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60696070,
"from":L[357]});
}
} catch($e60616062) {
if(R.isCont($e60616062)) {
var $ss60656066 = {"from":L[357],
"go":function(anf_arg3114225) {
return $Hanf_arg10754224(anf_arg3114225,self474226,_plus8,torepr14);
}};
$e60616062.stack[R.EXN_STACKHEIGHT++] = $ss60656066;
}
if(R.isPyretException($e60616062)) {
$e60616062.pyretStack.push(L[357]);
}
throw $e60616062;
}
var $ret60676068 = $Hanf_arg10754224($z60636064,self474226,_plus8,torepr14);
++R.GAS;
return $ret60676068;
};
},{"length":1});
var anf_variant_member3365956 = R.makeMethod(function(self506041) {
return function(cases_DASH_funs516042,else_DASH_clause526053) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[356],2,arguments);
}
var if_DASH_546054 = R.hasField(cases_DASH_funs516042,("align-spaces"));
var if_helper3244217 = R.makeFunction(function(if_helper_arg3256059) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[356],1,arguments);
}
var ann_DASH_check_DASH_temp3236060 = if_helper_arg3256059;
return ann_DASH_check_DASH_temp3236060;
});
var anf_if3286058 = R.isBoolean(if_DASH_546054);
if(R.isPyretTrue(anf_if3286058)) {
if(R.isPyretTrue(if_DASH_546054)) {
var call_DASH_align_DASH_spaces496037 = G(cases_DASH_funs516042,"align-spaces",L[356]);
var anf_arg3316038 = G(self506041,"n",L[465]);
var anf_arg3326039 = G(self506041,"flat-width",L[464]);
var anf_arg3336040 = G(self506041,"has-hardline",L[463]);
var $z60296030 = D;
var $f60356036 = function(_) {
return R.isFunction(call_DASH_align_DASH_spaces496037)?call_DASH_align_DASH_spaces496037.app(anf_arg3316038,anf_arg3326039,anf_arg3336040):R.ffi.throwNonFunApp(L[356],call_DASH_align_DASH_spaces496037,[anf_arg3316038,anf_arg3326039,anf_arg3336040]);
};
try {
if(--R.GAS > 0) {
$z60296030 = $f60356036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60356036,
"from":L[356]});
}
} catch($e60276028) {
if(R.isCont($e60276028)) {
var $ss60316032 = {"from":L[356],
"go":function(cont_tail_arg3344216) {
return $Hcont_tail_arg10764215(cont_tail_arg3344216,if_helper3244217);
}};
$e60276028.stack[R.EXN_STACKHEIGHT++] = $ss60316032;
}
if(R.isPyretException($e60276028)) {
$e60276028.pyretStack.push(L[356]);
}
throw $e60276028;
}
var $ret60336034 = $Hcont_tail_arg10764215($z60296030,if_helper3244217);
++R.GAS;
return $ret60336034;
} else {
var $z60456046 = D;
var $f60516052 = function(_) {
return R.isFunction(else_DASH_clause526053)?else_DASH_clause526053.app():R.ffi.throwNonFunApp(L[356],else_DASH_clause526053,[]);
};
try {
if(--R.GAS > 0) {
$z60456046 = $f60516052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60516052,
"from":L[356]});
}
} catch($e60436044) {
if(R.isCont($e60436044)) {
var $ss60476048 = {"from":L[356],
"go":function(cont_tail_arg3294221) {
return $Hcont_tail_arg10774220(cont_tail_arg3294221,if_helper3244217);
}};
$e60436044.stack[R.EXN_STACKHEIGHT++] = $ss60476048;
}
if(R.isPyretException($e60436044)) {
$e60436044.pyretStack.push(L[356]);
}
throw $e60436044;
}
var $ret60496050 = $Hcont_tail_arg10774220($z60456046,if_helper3244217);
++R.GAS;
return $ret60496050;
}
} else {
var cont_tail_arg3266057 = R.throwNonBooleanCondition(L[356],("if"),if_DASH_546054);
if(--R.GAS > 0) {
$z60556056 = R.isFunction(if_helper3244217)?if_helper3244217.app(cont_tail_arg3266057):R.ffi.throwNonFunApp(L[356],if_helper3244217,[cont_tail_arg3266057]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper3244217)?if_helper3244217.app(cont_tail_arg3266057):R.ffi.throwNonFunApp(L[356],if_helper3244217,[cont_tail_arg3266057]);
},
"from":L[356]});
}
++R.GAS;
return $z60556056;
}
};
},{"length":3});
var anf_variant_member3505957 = R.makeMethod(function(self534104) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[356],0,arguments);
}
var anf_arg3386026 = G(self534104,"n",L[356]);
var $z60186019 = D;
var $f60246025 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3386026):R.ffi.throwNonFunApp(L[356],torepr14,[anf_arg3386026]);
};
try {
if(--R.GAS > 0) {
$z60186019 = $f60246025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60246025,
"from":L[356]});
}
} catch($e60166017) {
if(R.isCont($e60166017)) {
var $ss60206021 = {"from":L[356],
"go":function(anf_arg3394103) {
return $Hanf_arg10874102(anf_arg3394103,self534104,_plus8,torepr14);
}};
$e60166017.stack[R.EXN_STACKHEIGHT++] = $ss60206021;
}
if(R.isPyretException($e60166017)) {
$e60166017.pyretStack.push(L[356]);
}
throw $e60166017;
}
var $ret60226023 = $Hanf_arg10874102($z60186019,self534104,_plus8,torepr14);
++R.GAS;
return $ret60226023;
};
},{"length":1});
var anf_variant_member3645966 = R.makeMethod(function(self565996) {
return function(cases_DASH_funs575997,else_DASH_clause586008) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[355],2,arguments);
}
var if_DASH_606009 = R.hasField(cases_DASH_funs575997,("group"));
var if_helper3524095 = R.makeFunction(function(if_helper_arg3536014) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[355],1,arguments);
}
var ann_DASH_check_DASH_temp3516015 = if_helper_arg3536014;
return ann_DASH_check_DASH_temp3516015;
});
var anf_if3566013 = R.isBoolean(if_DASH_606009);
if(R.isPyretTrue(anf_if3566013)) {
if(R.isPyretTrue(if_DASH_606009)) {
var call_DASH_group555992 = G(cases_DASH_funs575997,"group",L[355]);
var anf_arg3595993 = G(self565996,"d",L[462]);
var anf_arg3605994 = G(self565996,"flat-width",L[461]);
var anf_arg3615995 = G(self565996,"has-hardline",L[460]);
var $z59845985 = D;
var $f59905991 = function(_) {
return R.isFunction(call_DASH_group555992)?call_DASH_group555992.app(anf_arg3595993,anf_arg3605994,anf_arg3615995):R.ffi.throwNonFunApp(L[355],call_DASH_group555992,[anf_arg3595993,anf_arg3605994,anf_arg3615995]);
};
try {
if(--R.GAS > 0) {
$z59845985 = $f59905991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59905991,
"from":L[355]});
}
} catch($e59825983) {
if(R.isCont($e59825983)) {
var $ss59865987 = {"from":L[355],
"go":function(cont_tail_arg3624094) {
return $Hcont_tail_arg10884093(cont_tail_arg3624094,if_helper3524095);
}};
$e59825983.stack[R.EXN_STACKHEIGHT++] = $ss59865987;
}
if(R.isPyretException($e59825983)) {
$e59825983.pyretStack.push(L[355]);
}
throw $e59825983;
}
var $ret59885989 = $Hcont_tail_arg10884093($z59845985,if_helper3524095);
++R.GAS;
return $ret59885989;
} else {
var $z60006001 = D;
var $f60066007 = function(_) {
return R.isFunction(else_DASH_clause586008)?else_DASH_clause586008.app():R.ffi.throwNonFunApp(L[355],else_DASH_clause586008,[]);
};
try {
if(--R.GAS > 0) {
$z60006001 = $f60066007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60066007,
"from":L[355]});
}
} catch($e59985999) {
if(R.isCont($e59985999)) {
var $ss60026003 = {"from":L[355],
"go":function(cont_tail_arg3574099) {
return $Hcont_tail_arg10894098(cont_tail_arg3574099,if_helper3524095);
}};
$e59985999.stack[R.EXN_STACKHEIGHT++] = $ss60026003;
}
if(R.isPyretException($e59985999)) {
$e59985999.pyretStack.push(L[355]);
}
throw $e59985999;
}
var $ret60046005 = $Hcont_tail_arg10894098($z60006001,if_helper3524095);
++R.GAS;
return $ret60046005;
}
} else {
var cont_tail_arg3546012 = R.throwNonBooleanCondition(L[355],("if"),if_DASH_606009);
if(--R.GAS > 0) {
$z60106011 = R.isFunction(if_helper3524095)?if_helper3524095.app(cont_tail_arg3546012):R.ffi.throwNonFunApp(L[355],if_helper3524095,[cont_tail_arg3546012]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper3524095)?if_helper3524095.app(cont_tail_arg3546012):R.ffi.throwNonFunApp(L[355],if_helper3524095,[cont_tail_arg3546012]);
},
"from":L[355]});
}
++R.GAS;
return $z60106011;
}
};
},{"length":3});
var anf_variant_member3785967 = R.makeMethod(function(self593982) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[355],0,arguments);
}
var anf_arg3665981 = G(self593982,"d",L[355]);
var $z59735974 = D;
var $f59795980 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg3665981):R.ffi.throwNonFunApp(L[355],torepr14,[anf_arg3665981]);
};
try {
if(--R.GAS > 0) {
$z59735974 = $f59795980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59795980,
"from":L[355]});
}
} catch($e59715972) {
if(R.isCont($e59715972)) {
var $ss59755976 = {"from":L[355],
"go":function(anf_arg3673981) {
return $Hanf_arg10993980(anf_arg3673981,self593982,_plus8,torepr14);
}};
$e59715972.stack[R.EXN_STACKHEIGHT++] = $ss59755976;
}
if(R.isPyretException($e59715972)) {
$e59715972.pyretStack.push(L[355]);
}
throw $e59715972;
}
var $ret59775978 = $Hanf_arg10993980($z59735974,self593982,_plus8,torepr14);
++R.GAS;
return $ret59775978;
};
},{"length":1});
var anf_assign3795746 = (function() {
var $mt_DASH_doc_DASH_base58705871 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member1065875,
"_torepr":anf_variant_member1165876};
var $mt_DASH_doc_DASH_brands58735874 = {"$brand-mt-doc5872":true};
$mt_DASH_doc_DASH_brands58735874[PPrintDocT2615743._brand] = true
var $str_DASH_base58795880 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member1305884,
"_torepr":anf_variant_member1445885};
var $str_DASH_brands58825883 = {"$brand-str5881":true};
$str_DASH_brands58825883[PPrintDocT2615743._brand] = true
var $hardline_DASH_base58895890 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member1575894,
"_torepr":anf_variant_member1675895};
var $hardline_DASH_brands58925893 = {"$brand-hardline5891":true};
$hardline_DASH_brands58925893[PPrintDocT2615743._brand] = true
var $blank_DASH_base58985899 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member1815903,
"_torepr":anf_variant_member1955904};
var $blank_DASH_brands59015902 = {"$brand-blank5900":true};
$blank_DASH_brands59015902[PPrintDocT2615743._brand] = true
var $concat_DASH_base59085909 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member2105913,
"_torepr":anf_variant_member2285914};
var $concat_DASH_brands59115912 = {"$brand-concat5910":true};
$concat_DASH_brands59115912[PPrintDocT2615743._brand] = true
var $nest_DASH_base59195920 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member2435924,
"_torepr":anf_variant_member2615925};
var $nest_DASH_brands59225923 = {"$brand-nest5921":true};
$nest_DASH_brands59225923[PPrintDocT2615743._brand] = true
var $if_DASH_flat_DASH_base59305931 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member2765935,
"_torepr":anf_variant_member2945936};
var $if_DASH_flat_DASH_brands59335934 = {"$brand-if-flat5932":true};
$if_DASH_flat_DASH_brands59335934[PPrintDocT2615743._brand] = true
var $align_DASH_base59415942 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member3085946,
"_torepr":anf_variant_member3225947};
var $align_DASH_brands59445945 = {"$brand-align5943":true};
$align_DASH_brands59445945[PPrintDocT2615743._brand] = true
var $align_DASH_spaces_DASH_base59515952 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member3365956,
"_torepr":anf_variant_member3505957};
var $align_DASH_spaces_DASH_brands59545955 = {"$brand-align-spaces5953":true};
$align_DASH_spaces_DASH_brands59545955[PPrintDocT2615743._brand] = true
var $group_DASH_base59615962 = {"_plus":anf_shared405867,
"tostring":anf_shared915868,
"pretty":anf_shared935869,
"_match":anf_variant_member3645966,
"_torepr":anf_variant_member3785967};
var $group_DASH_brands59645965 = {"$brand-group5963":true};
$group_DASH_brands59645965[PPrintDocT2615743._brand] = true
return R.makeObject({"PPrintDoc":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[106],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,PPrintDocT2615743._brand));
}),
"is-mt-doc":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[364],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-mt-doc5872"));
}),
"mt-doc":R.makeFunction(function(flat_DASH_width935877,has_DASH_hardline945878) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[419],2,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Boolean16],[flat_DASH_width935877,has_DASH_hardline945878],[L[420],L[421]],function() {
var dict = R.create($mt_DASH_doc_DASH_base58705871);
dict["flat-width"] = flat_DASH_width935877
dict["has-hardline"] = has_DASH_hardline945878
return R.makeBrandedObject(dict,$mt_DASH_doc_DASH_brands58735874);
});
}),
"is-str":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[363],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-str5881"));
}),
"str":R.makeFunction(function(s955886,flat_DASH_width965887,has_DASH_hardline975888) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[422],3,arguments);
}
return R.checkAnnArgs([$type$String19,$type$Number18,$type$Boolean16],[s955886,flat_DASH_width965887,has_DASH_hardline975888],[L[423],L[424],L[425]],function() {
var dict = R.create($str_DASH_base58795880);
dict["s"] = s955886
dict["flat-width"] = flat_DASH_width965887
dict["has-hardline"] = has_DASH_hardline975888
return R.makeBrandedObject(dict,$str_DASH_brands58825883);
});
}),
"is-hardline":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[362],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-hardline5891"));
}),
"hardline":R.makeFunction(function(flat_DASH_width985896,has_DASH_hardline995897) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[426],2,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Boolean16],[flat_DASH_width985896,has_DASH_hardline995897],[L[427],L[428]],function() {
var dict = R.create($hardline_DASH_base58895890);
dict["flat-width"] = flat_DASH_width985896
dict["has-hardline"] = has_DASH_hardline995897
return R.makeBrandedObject(dict,$hardline_DASH_brands58925893);
});
}),
"is-blank":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[361],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-blank5900"));
}),
"blank":R.makeFunction(function(n1005905,flat_DASH_width1015906,has_DASH_hardline1025907) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[429],3,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Number18,$type$Boolean16],[n1005905,flat_DASH_width1015906,has_DASH_hardline1025907],[L[430],L[431],L[432]],function() {
var dict = R.create($blank_DASH_base58985899);
dict["n"] = n1005905
dict["flat-width"] = flat_DASH_width1015906
dict["has-hardline"] = has_DASH_hardline1025907
return R.makeBrandedObject(dict,$blank_DASH_brands59015902);
});
}),
"is-concat":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[360],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat5910"));
}),
"concat":R.makeFunction(function(fst1035915,snd1045916,flat_DASH_width1055917,has_DASH_hardline1065918) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[433],4,arguments);
}
return R.checkAnnArgs([PPrintDoc6039,PPrintDoc6039,$type$Number18,$type$Boolean16],[fst1035915,snd1045916,flat_DASH_width1055917,has_DASH_hardline1065918],[L[434],L[435],L[436],L[437]],function() {
var dict = R.create($concat_DASH_base59085909);
dict["fst"] = fst1035915
dict["snd"] = snd1045916
dict["flat-width"] = flat_DASH_width1055917
dict["has-hardline"] = has_DASH_hardline1065918
return R.makeBrandedObject(dict,$concat_DASH_brands59115912);
});
}),
"is-nest":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[359],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-nest5921"));
}),
"nest":R.makeFunction(function(indent1075926,d1085927,flat_DASH_width1095928,has_DASH_hardline1105929) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[438],4,arguments);
}
return R.checkAnnArgs([$type$Number18,PPrintDoc6039,$type$Number18,$type$Boolean16],[indent1075926,d1085927,flat_DASH_width1095928,has_DASH_hardline1105929],[L[439],L[440],L[441],L[442]],function() {
var dict = R.create($nest_DASH_base59195920);
dict["indent"] = indent1075926
dict["d"] = d1085927
dict["flat-width"] = flat_DASH_width1095928
dict["has-hardline"] = has_DASH_hardline1105929
return R.makeBrandedObject(dict,$nest_DASH_brands59225923);
});
}),
"is-if-flat":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[358],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-if-flat5932"));
}),
"if-flat":R.makeFunction(function(flat1115937,vert1125938,flat_DASH_width1135939,has_DASH_hardline1145940) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[443],4,arguments);
}
return R.checkAnnArgs([PPrintDoc6039,PPrintDoc6039,$type$Number18,$type$Boolean16],[flat1115937,vert1125938,flat_DASH_width1135939,has_DASH_hardline1145940],[L[444],L[445],L[446],L[447]],function() {
var dict = R.create($if_DASH_flat_DASH_base59305931);
dict["flat"] = flat1115937
dict["vert"] = vert1125938
dict["flat-width"] = flat_DASH_width1135939
dict["has-hardline"] = has_DASH_hardline1145940
return R.makeBrandedObject(dict,$if_DASH_flat_DASH_brands59335934);
});
}),
"is-align":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[357],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-align5943"));
}),
"align":R.makeFunction(function(d1155948,flat_DASH_width1165949,has_DASH_hardline1175950) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[448],3,arguments);
}
return R.checkAnnArgs([PPrintDoc6039,$type$Number18,$type$Boolean16],[d1155948,flat_DASH_width1165949,has_DASH_hardline1175950],[L[449],L[450],L[451]],function() {
var dict = R.create($align_DASH_base59415942);
dict["d"] = d1155948
dict["flat-width"] = flat_DASH_width1165949
dict["has-hardline"] = has_DASH_hardline1175950
return R.makeBrandedObject(dict,$align_DASH_brands59445945);
});
}),
"is-align-spaces":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[356],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-align-spaces5953"));
}),
"align-spaces":R.makeFunction(function(n1185958,flat_DASH_width1195959,has_DASH_hardline1205960) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[452],3,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Number18,$type$Boolean16],[n1185958,flat_DASH_width1195959,has_DASH_hardline1205960],[L[453],L[454],L[455]],function() {
var dict = R.create($align_DASH_spaces_DASH_base59515952);
dict["n"] = n1185958
dict["flat-width"] = flat_DASH_width1195959
dict["has-hardline"] = has_DASH_hardline1205960
return R.makeBrandedObject(dict,$align_DASH_spaces_DASH_brands59545955);
});
}),
"is-group":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[355],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-group5963"));
}),
"group":R.makeFunction(function(d1215968,flat_DASH_width1225969,has_DASH_hardline1235970) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[456],3,arguments);
}
return R.checkAnnArgs([PPrintDoc6039,$type$Number18,$type$Boolean16],[d1215968,flat_DASH_width1225969,has_DASH_hardline1235970],[L[457],L[458],L[459]],function() {
var dict = R.create($group_DASH_base59615962);
dict["d"] = d1215968
dict["flat-width"] = flat_DASH_width1225969
dict["has-hardline"] = has_DASH_hardline1235970
return R.makeBrandedObject(dict,$group_DASH_brands59645965);
});
})});
})();
PPrintDoc4645745.$var = anf_assign3795746;
var anf_assign3805747 = G(PPrintDoc4645745.$var,"PPrintDoc",L[106]);
PPrintDoc6540.$var = anf_assign3805747;
var anf_assign3815749 = G(PPrintDoc4645745.$var,"PPrintDoc",L[106]);
is_DASH_PPrintDoc665748.$var = anf_assign3815749;
var anf_assign3825750 = G(PPrintDoc4645745.$var,"is-mt-doc",L[364]);
is_DASH_mt_DASH_doc6747.$var = anf_assign3825750;
var anf_assign3835752 = G(PPrintDoc4645745.$var,"mt-doc",L[364]);
mt_DASH_doc685751.$var = anf_assign3835752;
var anf_assign3845754 = G(PPrintDoc4645745.$var,"is-str",L[363]);
is_DASH_str695753.$var = anf_assign3845754;
var anf_assign3855755 = G(PPrintDoc4645745.$var,"str",L[363]);
str7050.$var = anf_assign3855755;
var anf_assign3865757 = G(PPrintDoc4645745.$var,"is-hardline",L[362]);
is_DASH_hardline715756.$var = anf_assign3865757;
var anf_assign3875758 = G(PPrintDoc4645745.$var,"hardline",L[362]);
hardline7244.$var = anf_assign3875758;
var anf_assign3885760 = G(PPrintDoc4645745.$var,"is-blank",L[361]);
is_DASH_blank735759.$var = anf_assign3885760;
var anf_assign3895761 = G(PPrintDoc4645745.$var,"blank",L[361]);
blank7442.$var = anf_assign3895761;
var anf_assign3905762 = G(PPrintDoc4645745.$var,"is-concat",L[360]);
is_DASH_concat755563.$var = anf_assign3905762;
var anf_assign3915763 = G(PPrintDoc4645745.$var,"concat",L[360]);
concat765562.$var = anf_assign3915763;
var anf_assign3925765 = G(PPrintDoc4645745.$var,"is-nest",L[359]);
is_DASH_nest775764.$var = anf_assign3925765;
var anf_assign3935766 = G(PPrintDoc4645745.$var,"nest",L[359]);
nest7849.$var = anf_assign3935766;
var anf_assign3945768 = G(PPrintDoc4645745.$var,"is-if-flat",L[358]);
is_DASH_if_DASH_flat795767.$var = anf_assign3945768;
var anf_assign3955769 = G(PPrintDoc4645745.$var,"if-flat",L[358]);
if_DASH_flat8045.$var = anf_assign3955769;
var anf_assign3965771 = G(PPrintDoc4645745.$var,"is-align",L[357]);
is_DASH_align815770.$var = anf_assign3965771;
var anf_assign3975772 = G(PPrintDoc4645745.$var,"align",L[357]);
align8241.$var = anf_assign3975772;
var anf_assign3985774 = G(PPrintDoc4645745.$var,"is-align-spaces",L[356]);
is_DASH_align_DASH_spaces835773.$var = anf_assign3985774;
var anf_assign3995776 = G(PPrintDoc4645745.$var,"align-spaces",L[356]);
align_DASH_spaces845775.$var = anf_assign3995776;
var anf_assign4005778 = G(PPrintDoc4645745.$var,"is-group",L[355]);
is_DASH_group855777.$var = anf_assign4005778;
var anf_assign4015779 = G(PPrintDoc4645745.$var,"group",L[355]);
group8643.$var = anf_assign4015779;
var anf_variant_member4155817 = R.makeMethod(function(self695847) {
return function(cases_DASH_funs705848,else_DASH_clause715859) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[354],2,arguments);
}
var if_DASH_735860 = R.hasField(cases_DASH_funs705848,("item"));
var if_helper4033973 = R.makeFunction(function(if_helper_arg4045865) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[354],1,arguments);
}
var ann_DASH_check_DASH_temp4025866 = if_helper_arg4045865;
return ann_DASH_check_DASH_temp4025866;
});
var anf_if4075864 = R.isBoolean(if_DASH_735860);
if(R.isPyretTrue(anf_if4075864)) {
if(R.isPyretTrue(if_DASH_735860)) {
var call_DASH_item685843 = G(cases_DASH_funs705848,"item",L[354]);
var anf_arg4105844 = G(self695847,"indent",L[418]);
var anf_arg4115845 = G(self695847,"is-flat",L[417]);
var anf_arg4125846 = G(self695847,"d",L[416]);
var $z58355836 = D;
var $f58415842 = function(_) {
return R.isFunction(call_DASH_item685843)?call_DASH_item685843.app(anf_arg4105844,anf_arg4115845,anf_arg4125846):R.ffi.throwNonFunApp(L[354],call_DASH_item685843,[anf_arg4105844,anf_arg4115845,anf_arg4125846]);
};
try {
if(--R.GAS > 0) {
$z58355836 = $f58415842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58415842,
"from":L[354]});
}
} catch($e58335834) {
if(R.isCont($e58335834)) {
var $ss58375838 = {"from":L[354],
"go":function(cont_tail_arg4133972) {
return $Hcont_tail_arg11003971(cont_tail_arg4133972,if_helper4033973);
}};
$e58335834.stack[R.EXN_STACKHEIGHT++] = $ss58375838;
}
if(R.isPyretException($e58335834)) {
$e58335834.pyretStack.push(L[354]);
}
throw $e58335834;
}
var $ret58395840 = $Hcont_tail_arg11003971($z58355836,if_helper4033973);
++R.GAS;
return $ret58395840;
} else {
var $z58515852 = D;
var $f58575858 = function(_) {
return R.isFunction(else_DASH_clause715859)?else_DASH_clause715859.app():R.ffi.throwNonFunApp(L[354],else_DASH_clause715859,[]);
};
try {
if(--R.GAS > 0) {
$z58515852 = $f58575858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58575858,
"from":L[354]});
}
} catch($e58495850) {
if(R.isCont($e58495850)) {
var $ss58535854 = {"from":L[354],
"go":function(cont_tail_arg4083977) {
return $Hcont_tail_arg11013976(cont_tail_arg4083977,if_helper4033973);
}};
$e58495850.stack[R.EXN_STACKHEIGHT++] = $ss58535854;
}
if(R.isPyretException($e58495850)) {
$e58495850.pyretStack.push(L[354]);
}
throw $e58495850;
}
var $ret58555856 = $Hcont_tail_arg11013976($z58515852,if_helper4033973);
++R.GAS;
return $ret58555856;
}
} else {
var cont_tail_arg4055863 = R.throwNonBooleanCondition(L[354],("if"),if_DASH_735860);
if(--R.GAS > 0) {
$z58615862 = R.isFunction(if_helper4033973)?if_helper4033973.app(cont_tail_arg4055863):R.ffi.throwNonFunApp(L[354],if_helper4033973,[cont_tail_arg4055863]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1726) {
return R.isFunction(if_helper4033973)?if_helper4033973.app(cont_tail_arg4055863):R.ffi.throwNonFunApp(L[354],if_helper4033973,[cont_tail_arg4055863]);
},
"from":L[354]});
}
++R.GAS;
return $z58615862;
}
};
},{"length":3});
var anf_variant_member4295818 = R.makeMethod(function(self723860) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[354],0,arguments);
}
var anf_arg4175832 = G(self723860,"indent",L[354]);
var $z58245825 = D;
var $f58305831 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg4175832):R.ffi.throwNonFunApp(L[354],torepr14,[anf_arg4175832]);
};
try {
if(--R.GAS > 0) {
$z58245825 = $f58305831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58305831,
"from":L[354]});
}
} catch($e58225823) {
if(R.isCont($e58225823)) {
var $ss58265827 = {"from":L[354],
"go":function(anf_arg4183859) {
return $Hanf_arg11113858(anf_arg4183859,self723860,_plus8,torepr14);
}};
$e58225823.stack[R.EXN_STACKHEIGHT++] = $ss58265827;
}
if(R.isPyretException($e58225823)) {
$e58225823.pyretStack.push(L[354]);
}
throw $e58225823;
}
var $ret58285829 = $Hanf_arg11113858($z58245825,self723860,_plus8,torepr14);
++R.GAS;
return $ret58285829;
};
},{"length":1});
var anf_assign4305781 = (function() {
var $item_DASH_base58125813 = {"_match":anf_variant_member4155817,
"_torepr":anf_variant_member4295818};
var $item_DASH_brands58155816 = {"$brand-item5814":true};
$item_DASH_brands58155816[ItemT3635744._brand] = true
return R.makeObject({"Item":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[411],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ItemT3635744._brand));
}),
"is-item":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[354],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-item5814"));
}),
"item":R.makeFunction(function(indent1605819,is_DASH_flat1615820,d1625821) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[412],3,arguments);
}
return R.checkAnnArgs([$type$Number18,$type$Boolean16,PPrintDoc6039],[indent1605819,is_DASH_flat1615820,d1625821],[L[413],L[414],L[415]],function() {
var dict = R.create($item_DASH_base58125813);
dict["indent"] = indent1605819
dict["is-flat"] = is_DASH_flat1615820
dict["d"] = d1625821
return R.makeBrandedObject(dict,$item_DASH_brands58155816);
});
})});
})();
Item5875780.$var = anf_assign4305781;
var anf_assign4315783 = G(Item5875780.$var,"Item",L[411]);
Item885782.$var = anf_assign4315783;
var anf_assign4325785 = G(Item5875780.$var,"Item",L[411]);
is_DASH_Item895784.$var = anf_assign4325785;
var anf_assign4335787 = G(Item5875780.$var,"is-item",L[354]);
is_DASH_item905786.$var = anf_assign4335787;
var anf_assign4345788 = G(Item5875780.$var,"item",L[354]);
item912759.$var = anf_assign4345788;
var anf_assign6085790 = R.makeFunction(function(width1632760,doc1642758) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[265],2,arguments);
}
return R.checkAnnArgs([PPrintDoc6039],[doc1642758],[L[410]],function() {
var anf_fun4362757 = G(list1948,"make",L[409]);
var anf_fun4375811 = G(list1948,"make",L[408]);
var $z58035804 = D;
var $f58095810 = function(_) {
return R.isFunction(anf_fun4375811)?anf_fun4375811.app([]):R.ffi.throwNonFunApp(L[408],anf_fun4375811,[[]]);
};
try {
if(--R.GAS > 0) {
$z58035804 = $f58095810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58095810,
"from":L[408]});
}
} catch($e58015802) {
if(R.isCont($e58015802)) {
var $ss58055806 = {"from":L[408],
"go":function(anf_array_val4382755) {
return $Hanf_array_val11952754(anf_array_val4382755,Item6238,List112756,anf_fun4362757,doc1642758,group8643,is_DASH_empty2046,item912759,list1948,lists321,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,string_DASH_repeat13,$type$Nothing17,$type$Number18);
}};
$e58015802.stack[R.EXN_STACKHEIGHT++] = $ss58055806;
}
if(R.isPyretException($e58015802)) {
$e58015802.pyretStack.push(L[408]);
}
throw $e58015802;
}
var $ret58075808 = $Hanf_array_val11952754($z58035804,Item6238,List112756,anf_fun4362757,doc1642758,group8643,is_DASH_empty2046,item912759,list1948,lists321,width1632760,_greaterequal6,_minus7,_plus8,nothing10,raise11,string_DASH_repeat13,$type$Nothing17,$type$Number18);
++R.GAS;
return $ret58075808;
});
});
format925789.$var = anf_assign6085790;
var $z57935794 = D;
var $f57995800 = function(_) {
return R.isFunction(mt_DASH_doc685751.$var)?mt_DASH_doc685751.$var.app((0),(false)):R.ffi.throwNonFunApp(L[407],mt_DASH_doc685751.$var,[(0),(false)]);
};
try {
if(--R.GAS > 0) {
$z57935794 = $f57995800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57995800,
"from":L[407]});
}
} catch($e57915792) {
if(R.isCont($e57915792)) {
var $ss57955796 = {"from":L[407],
"go":function(mt_DASH_doc21537) {
return $Hmt_DASH_doc140836(mt_DASH_doc21537,Item6238,PPrintDoc6039,PPrintDoc6540,align8241,blank7442,group8643,hardline7244,if_DASH_flat8045,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,nest7849,str7050,_plus8,builtins9,nothing10,string_DASH_length12,tostring15,$type$Number18);
}};
$e57915792.stack[R.EXN_STACKHEIGHT++] = $ss57955796;
}
if(R.isPyretException($e57915792)) {
$e57915792.pyretStack.push(L[407]);
}
throw $e57915792;
}
var $ret57975798 = $Hmt_DASH_doc140836($z57935794,Item6238,PPrintDoc6039,PPrintDoc6540,align8241,blank7442,group8643,hardline7244,if_DASH_flat8045,is_DASH_empty2046,is_DASH_mt_DASH_doc6747,list1948,lists321,lists426,nest7849,str7050,_plus8,builtins9,nothing10,string_DASH_length12,tostring15,$type$Number18);
++R.GAS;
return $ret57975798;
},function(moduleVal) {
R.modules["$src/arr/trove/pprint.arr30"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/ast',["trove/pprint",
"trove/srcloc",
"trove/contracts",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($PP17087,$S37188,$C57289,$arrays77390,$lists97491,$option117592,$error137693,$sets157794) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/trove/ast.arr86"]) {
return R.modules["$src/arr/trove/ast.arr86"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/trove/ast.arr";
var D = R.undefined;
var L = [[M,15,0,175,15,24,199],
[M,15,12,187,15,21,196],
[M,16,0,200,16,23,223],
[M,16,10,210,16,16,216],
[M,17,0,224,17,24,248],
[M,17,12,236,17,18,242],
[M,18,0,249,18,30,279],
[M,18,17,266,18,23,272],
[M,19,0,280,19,21,301],
[M,19,9,289,19,15,295],
[M,20,0,302,20,22,324],
[M,20,12,314,20,18,320],
[M,21,0,325,21,23,348],
[M,21,10,335,21,16,341],
[M,22,0,349,22,33,382],
[M,22,15,364,22,21,370],
[M,23,0,383,23,29,412],
[M,23,13,396,23,19,402],
[M,24,0,413,24,28,441],
[M,24,12,425,24,18,431],
[M,25,0,442,25,33,475],
[M,25,15,457,25,21,463],
[M,26,0,476,26,27,503],
[M,26,12,488,26,18,494],
[M,27,0,504,27,23,527],
[M,27,12,516,27,18,522],
[M,28,0,528,28,33,561],
[M,28,17,545,28,23,551],
[M,29,0,562,29,39,601],
[M,29,20,582,29,26,588],
[M,30,0,602,30,23,625],
[M,30,12,614,30,18,620],
[M,31,0,626,31,29,655],
[M,31,17,643,31,23,649],
[M,32,0,656,32,29,685],
[M,32,17,673,32,23,679],
[M,33,0,686,33,26,712],
[M,33,14,700,33,20,706],
[M,34,0,713,34,44,757],
[M,34,18,731,34,24,737],
[M,35,0,758,35,26,784],
[M,35,11,769,35,17,775],
[M,36,0,785,36,36,821],
[M,36,16,801,36,22,807],
[M,37,0,822,37,34,856],
[M,37,15,837,37,21,843],
[M,38,0,857,38,34,891],
[M,38,15,872,38,21,878],
[M,39,0,892,39,25,917],
[M,39,10,902,39,16,908],
[M,40,0,918,40,36,954],
[M,40,17,935,40,23,941],
[M,41,0,955,41,31,986],
[M,41,16,971,41,22,977],
[M,42,0,987,42,41,1028],
[M,42,21,1008,42,27,1014],
[M,43,0,1029,43,31,1060],
[M,43,16,1045,43,22,1051],
[M,44,0,1061,44,23,1084],
[M,44,10,1071,44,16,1077],
[M,45,0,1085,45,29,1114],
[M,45,13,1098,45,19,1104],
[M,46,0,1115,46,24,1139],
[M,46,10,1125,46,16,1131],
[M,47,0,1140,47,25,1165],
[M,47,11,1151,47,17,1157],
[M,48,0,1166,48,23,1189],
[M,48,10,1176,48,16,1182],
[M,49,0,1190,49,23,1213],
[M,49,10,1200,49,16,1206],
[M,50,0,1214,50,28,1242],
[M,50,12,1226,50,18,1232],
[M,51,0,1243,51,22,1265],
[M,51,9,1252,51,15,1258],
[M,52,0,1266,52,29,1295],
[M,52,15,1281,52,21,1287],
[M,53,0,1296,53,29,1325],
[M,53,13,1309,53,19,1315],
[M,54,0,1326,54,29,1355],
[M,54,13,1339,54,19,1345],
[M,55,0,1356,55,31,1387],
[M,55,14,1370,55,20,1376],
[M,56,0,1388,56,24,1412],
[M,56,13,1401,56,19,1407],
[M,57,0,1413,57,22,1435],
[M,57,11,1424,57,17,1430],
[M,58,0,1436,58,28,1464],
[M,58,16,1452,58,22,1458],
[M,59,0,1465,59,31,1496],
[M,59,14,1479,59,20,1485],
[M,60,0,1497,60,43,1540],
[M,60,20,1517,60,26,1523],
[M,61,0,1541,61,38,1579],
[M,61,19,1560,61,25,1566],
[M,62,0,1580,62,50,1630],
[M,62,25,1605,62,31,1611],
[M,63,0,1631,63,32,1663],
[M,63,14,1645,63,20,1651],
[M,64,0,1664,64,23,1687],
[M,64,12,1676,64,18,1682],
[M,65,0,1688,65,35,1723],
[M,65,22,1710,65,28,1716],
[M,66,0,1724,66,29,1753],
[M,66,17,1741,66,23,1747],
[M,67,0,1754,67,31,1785],
[M,67,16,1770,67,22,1776],
[M,68,0,1786,68,29,1815],
[M,68,17,1803,68,23,1809],
[M,69,0,1816,69,24,1840],
[M,69,10,1826,69,16,1832],
[M,70,0,1841,70,30,1871],
[M,70,14,1855,70,20,1861],
[M,71,0,1872,71,24,1896],
[M,71,10,1882,71,16,1888],
[M,72,0,1897,72,29,1926],
[M,72,14,1911,72,20,1917],
[M,73,0,1927,73,26,1953],
[M,73,11,1938,73,17,1944],
[M,74,0,1954,74,28,1982],
[M,74,12,1966,74,18,1972],
[M,75,0,1983,75,32,2015],
[M,75,14,1997,75,20,2003],
[M,76,0,2016,76,24,2040],
[M,76,10,2026,76,16,2032],
[M,77,0,2041,77,25,2066],
[M,77,11,2052,77,17,2058],
[M,78,0,2067,78,28,2095],
[M,78,12,2079,78,18,2085],
[M,79,0,2096,79,26,2122],
[M,79,11,2107,79,17,2113],
[M,153,0,4573,153,26,4599],
[M,131,0,4096,151,3,4571],
[M,133,2,4139,139,5,4308],
[M,134,13,4168,134,28,4183],
[M,114,2,3368,120,62,3732],
[M,106,2,3070,112,38,3364],
[M,98,2,2800,104,37,3066],
[M,90,2,2468,96,35,2796],
[M,82,2,2137,88,32,2464],
[M,81,0,2124,129,3,4094],
[M,82,4,2139,82,26,2161],
[M,82,22,2157,82,25,2160],
[M,90,4,2470,90,33,2499],
[M,90,16,2482,90,19,2485],
[M,90,26,2492,90,32,2498],
[M,98,4,2802,98,25,2823],
[M,98,18,2816,98,24,2822],
[M,106,4,3072,106,30,3098],
[M,106,23,3091,106,29,3097],
[M,114,4,3370,114,44,3410],
[M,114,19,3385,114,25,3391],
[M,114,37,3403,114,43,3409],
[M,120,15,3685,120,58,3728],
[M,120,25,3695,120,34,3704],
[M,120,4,3674,120,62,3732],
[M,119,18,3655,119,27,3664],
[M,119,4,3641,119,31,3668],
[M,118,4,3597,118,42,3635],
[M,118,20,3613,118,36,3629],
[M,117,27,3568,117,45,3586],
[M,117,27,3568,117,43,3584],
[M,117,20,3561,117,26,3567],
[M,117,4,3545,117,50,3591],
[M,116,35,3514,116,56,3535],
[M,116,44,3523,116,55,3534],
[M,116,23,3502,116,32,3511],
[M,116,4,3483,116,60,3539],
[M,115,37,3454,115,55,3472],
[M,115,37,3454,115,53,3470],
[M,115,30,3447,115,36,3453],
[M,115,4,3421,115,60,3477],
[M,114,27,3393,114,43,3409],
[M,114,11,3377,114,25,3391],
[M,112,4,3330,112,38,3364],
[M,112,28,3354,112,34,3360],
[M,111,18,3314,111,24,3320],
[M,111,4,3300,111,28,3324],
[M,110,4,3257,110,41,3294],
[M,110,31,3284,110,37,3290],
[M,109,4,3217,109,38,3251],
[M,109,27,3240,109,33,3246],
[M,109,20,3233,109,26,3239],
[M,108,4,3171,108,44,3211],
[M,108,34,3201,108,40,3207],
[M,107,37,3142,107,55,3160],
[M,107,37,3142,107,53,3158],
[M,107,30,3135,107,36,3141],
[M,107,4,3109,107,60,3165],
[M,106,18,3086,106,29,3097],
[M,104,4,3033,104,37,3066],
[M,104,27,3056,104,33,3062],
[M,103,18,3017,103,24,3023],
[M,103,4,3003,103,28,3027],
[M,102,20,2987,102,26,2993],
[M,102,4,2971,102,30,2997],
[M,101,4,2931,101,38,2965],
[M,101,27,2954,101,33,2960],
[M,101,20,2947,101,26,2953],
[M,100,23,2915,100,29,2921],
[M,100,4,2896,100,33,2925],
[M,99,37,2867,99,55,2885],
[M,99,37,2867,99,53,2883],
[M,99,30,2860,99,36,2866],
[M,99,4,2834,99,60,2890],
[M,98,13,2811,98,24,2822],
[M,96,4,2765,96,35,2796],
[M,96,25,2786,96,31,2792],
[M,95,18,2749,95,24,2755],
[M,95,4,2735,95,28,2759],
[M,94,20,2719,94,26,2725],
[M,94,4,2703,94,30,2729],
[M,93,4,2663,93,38,2697],
[M,93,27,2686,93,33,2692],
[M,93,20,2679,93,26,2685],
[M,92,29,2615,92,67,2653],
[M,92,60,2646,92,66,2652],
[M,92,4,2590,92,71,2657],
[M,91,36,2542,91,74,2580],
[M,91,67,2573,91,73,2579],
[M,91,4,2510,91,78,2584],
[M,90,21,2487,90,32,2498],
[M,90,11,2477,90,19,2485],
[M,88,4,2436,88,32,2464],
[M,87,4,2373,87,61,2430],
[M,86,4,2344,86,27,2367],
[M,85,4,2307,85,35,2338],
[M,85,20,2323,85,26,2329],
[M,84,4,2243,84,62,2301],
[M,83,4,2172,83,69,2237],
[M,82,17,2152,82,25,2160],
[M,126,2,3978,128,5,4090],
[M,127,25,4025,127,83,4083],
[M,127,64,4064,127,78,4078],
[M,127,4,4004,127,15,4015],
[M,125,30,3945,125,40,3955],
[M,125,30,3945,125,38,3953],
[M,125,2,3917,125,59,3974],
[M,124,29,3885,124,39,3895],
[M,124,29,3885,124,37,3893],
[M,124,2,3858,124,57,3913],
[M,123,27,3825,123,37,3835],
[M,123,27,3825,123,35,3833],
[M,123,2,3800,123,56,3854],
[M,122,26,3768,122,36,3778],
[M,122,26,3768,122,34,3776],
[M,122,2,3744,122,54,3796],
[M,2495,23,79458,2495,39,79474],
[M,2495,23,79458,2495,33,79468],
[M,2494,2,79406,2496,5,79498],
[M,2491,2,79336,2493,5,79402],
[M,2489,22,79293,2489,37,79308],
[M,2489,22,79293,2489,31,79302],
[M,2488,2,79244,2490,5,79332],
[M,2486,21,79193,2486,36,79208],
[M,2486,21,79193,2486,30,79202],
[M,2485,2,79145,2487,5,79240],
[M,2483,24,79109,2483,49,79134],
[M,2483,35,79120,2483,48,79133],
[M,2483,24,79109,2483,34,79119],
[M,2482,2,79058,2484,5,79141],
[M,2480,24,79007,2480,47,79030],
[M,2480,33,79016,2480,46,79029],
[M,2480,24,79007,2480,32,79015],
[M,2479,2,78953,2481,5,79054],
[M,2477,23,78890,2477,46,78913],
[M,2477,32,78899,2477,45,78912],
[M,2477,23,78890,2477,31,78898],
[M,2476,2,78826,2478,5,78949],
[M,2475,41,78803,2475,55,78817],
[M,2475,41,78803,2475,49,78811],
[M,2475,2,78764,2475,60,78822],
[M,2474,2,78738,2474,24,78760],
[M,2473,2,78708,2473,28,78734],
[M,2470,48,78680,2470,64,78696],
[M,2470,48,78680,2470,58,78690],
[M,2466,11,78573,2466,14,78576],
[M,2467,18,78596,2467,24,78602],
[M,2468,14,78618,2468,18,78622],
[M,2464,2,78526,2471,5,78703],
[M,2462,50,78492,2462,73,78515],
[M,2462,50,78492,2462,67,78509],
[M,2458,11,78375,2458,14,78378],
[M,2459,14,78394,2459,20,78400],
[M,2460,21,78423,2460,32,78434],
[M,2456,2,78322,2463,5,78522],
[M,2454,40,78260,2454,66,78286],
[M,2454,52,78272,2454,65,78285],
[M,2454,40,78260,2454,51,78271],
[M,2449,11,78115,2449,14,78118],
[M,2450,14,78134,2450,20,78140],
[M,2451,17,78159,2451,36,78178],
[M,2452,21,78201,2452,32,78212],
[M,2447,2,78072,2455,5,78318],
[M,2445,41,78030,2445,72,78061],
[M,2445,58,78047,2445,71,78060],
[M,2445,41,78030,2445,57,78046],
[M,2441,11,77920,2441,14,77923],
[M,2442,14,77939,2442,20,77945],
[M,2443,22,77969,2444,4,77986],
[M,2439,2,77876,2446,5,78068],
[M,2437,42,77806,2437,68,77832],
[M,2437,54,77818,2437,67,77831],
[M,2437,42,77806,2437,53,77817],
[M,2431,11,77632,2431,14,77635],
[M,2432,20,77657,2432,23,77660],
[M,2433,14,77676,2433,20,77682],
[M,2434,17,77701,2434,36,77720],
[M,2435,22,77744,2436,4,77761],
[M,2429,2,77598,2438,5,77872],
[M,2427,45,77571,2427,61,77587],
[M,2427,45,77571,2427,55,77581],
[M,2426,30,77472,2426,33,77475],
[M,2426,50,77492,2426,67,77509],
[M,2426,77,77519,2426,81,77523],
[M,2426,2,77444,2428,5,77594],
[M,2424,26,77395,2424,42,77411],
[M,2424,26,77395,2424,36,77405],
[M,2423,24,77334,2423,27,77337],
[M,2423,37,77347,2423,41,77351],
[M,2423,52,77362,2423,56,77366],
[M,2423,2,77312,2425,5,77440],
[M,2415,8,77177,2415,31,77200],
[M,2415,17,77186,2415,30,77199],
[M,2415,8,77177,2415,16,77185],
[M,2404,11,76937,2404,14,76940],
[M,2405,14,76956,2405,18,76960],
[M,2406,14,76976,2406,24,76986],
[M,2407,13,77020,2407,16,77023],
[M,2408,13,77052,2408,19,77058],
[M,2409,14,77074,2409,18,77078],
[M,2410,16,77096,2411,4,77113],
[M,2402,2,76898,2421,5,77307],
[M,2400,28,76835,2400,44,76851],
[M,2400,28,76835,2400,38,76845],
[M,2399,26,76760,2399,29,76763],
[M,2399,39,76773,2399,43,76777],
[M,2399,52,76786,2399,55,76789],
[M,2399,66,76800,2399,70,76804],
[M,2399,2,76736,2401,5,76894],
[M,2397,31,76673,2397,47,76689],
[M,2397,31,76673,2397,41,76683],
[M,2396,29,76595,2396,32,76598],
[M,2396,42,76608,2396,46,76612],
[M,2396,55,76621,2396,58,76624],
[M,2396,69,76635,2396,73,76639],
[M,2396,2,76568,2398,5,76732],
[M,2394,28,76522,2394,44,76538],
[M,2394,28,76522,2394,38,76532],
[M,2393,26,76459,2393,29,76462],
[M,2393,39,76472,2393,43,76476],
[M,2393,54,76487,2393,58,76491],
[M,2393,2,76435,2395,5,76564],
[M,2390,29,76392,2390,45,76408],
[M,2390,29,76392,2390,39,76402],
[M,2389,21,76293,2389,24,76296],
[M,2389,34,76306,2389,48,76320],
[M,2389,58,76330,2389,62,76334],
[M,2389,81,76353,2389,88,76360],
[M,2389,2,76274,2391,5,76430],
[M,2387,21,76179,2387,41,76199],
[M,2387,21,76179,2387,35,76193],
[M,2381,11,76052,2381,14,76055],
[M,2382,18,76075,2382,22,76079],
[M,2383,18,76099,2383,31,76112],
[M,2384,13,76127,2384,16,76130],
[M,2385,14,76146,2385,18,76150],
[M,2379,2,76022,2388,5,76270],
[M,2371,8,75808,2371,25,75825],
[M,2371,8,75808,2371,19,75819],
[M,2359,11,75523,2359,14,75526],
[M,2360,14,75542,2360,20,75548],
[M,2361,15,75565,2361,21,75571],
[M,2362,16,75589,2362,26,75599],
[M,2363,16,75631,2363,26,75641],
[M,2364,18,75661,2364,31,75674],
[M,2365,24,75700,2365,36,75712],
[M,2366,16,75730,2367,4,75747],
[M,2357,2,75487,2378,5,76018],
[M,2350,8,75300,2350,33,75325],
[M,2350,19,75311,2350,32,75324],
[M,2350,8,75300,2350,18,75310],
[M,2339,11,75043,2339,14,75046],
[M,2340,14,75062,2340,20,75068],
[M,2341,16,75086,2341,26,75096],
[M,2342,16,75128,2342,26,75138],
[M,2343,18,75158,2343,31,75171],
[M,2344,24,75197,2344,36,75209],
[M,2345,16,75227,2346,4,75244],
[M,2337,2,75012,2356,5,75483],
[M,2335,25,74967,2335,40,74982],
[M,2335,25,74967,2335,34,74976],
[M,2334,23,74908,2334,26,74911],
[M,2334,35,74920,2334,39,74924],
[M,2334,50,74935,2334,54,74939],
[M,2334,2,74887,2336,5,75008],
[M,2332,26,74854,2332,41,74869],
[M,2332,26,74854,2332,35,74863],
[M,2331,24,74792,2331,27,74795],
[M,2331,36,74804,2331,40,74808],
[M,2331,51,74819,2331,57,74825],
[M,2331,2,74770,2333,5,74883],
[M,2329,21,74737,2329,36,74752],
[M,2329,21,74737,2329,30,74746],
[M,2328,19,74680,2328,22,74683],
[M,2328,31,74692,2328,35,74696],
[M,2328,46,74707,2328,52,74713],
[M,2328,2,74663,2330,5,74766],
[M,2325,2,74594,2327,5,74659],
[M,2325,19,74611,2325,22,74614],
[M,2325,29,74621,2325,35,74627],
[M,2322,2,74522,2324,5,74590],
[M,2322,20,74540,2322,23,74543],
[M,2322,30,74550,2322,37,74557],
[M,2319,2,74427,2321,5,74518],
[M,2319,20,74445,2319,23,74448],
[M,2319,32,74457,2319,38,74463],
[M,2319,47,74472,2319,53,74478],
[M,2316,2,74358,2318,5,74423],
[M,2316,19,74375,2316,22,74378],
[M,2316,29,74385,2316,35,74391],
[M,2313,2,74289,2315,5,74354],
[M,2310,2,74229,2312,5,74285],
[M,2310,25,74252,2310,28,74255],
[M,2308,27,74198,2308,41,74212],
[M,2308,27,74198,2308,35,74206],
[M,2307,25,74136,2307,28,74139],
[M,2307,36,74147,2307,40,74151],
[M,2307,50,74161,2307,57,74168],
[M,2307,2,74113,2309,5,74225],
[M,2305,24,74088,2305,38,74102],
[M,2305,24,74088,2305,32,74096],
[M,2304,22,74046,2304,25,74049],
[M,2304,33,74057,2304,37,74061],
[M,2304,2,74026,2306,5,74109],
[M,2302,20,74001,2302,34,74015],
[M,2302,20,74001,2302,28,74009],
[M,2301,18,73963,2301,21,73966],
[M,2301,29,73974,2301,33,73978],
[M,2301,2,73947,2303,5,74022],
[M,2298,2,73862,2300,5,73943],
[M,2298,24,73884,2298,27,73887],
[M,2298,37,73897,2298,43,73903],
[M,2296,32,73828,2296,55,73851],
[M,2296,41,73837,2296,54,73850],
[M,2296,32,73828,2296,40,73836],
[M,2295,24,73754,2295,27,73757],
[M,2295,37,73767,2295,43,73773],
[M,2295,53,73783,2295,63,73793],
[M,2295,2,73732,2297,5,73858],
[M,2293,21,73680,2293,37,73696],
[M,2293,21,73680,2293,31,73690],
[M,2292,19,73619,2292,22,73622],
[M,2292,32,73632,2292,36,73636],
[M,2292,46,73646,2292,56,73656],
[M,2292,2,73602,2294,5,73728],
[M,2290,32,73541,2290,55,73564],
[M,2290,32,73541,2290,49,73558],
[M,2289,25,73434,2289,28,73437],
[M,2289,37,73446,2289,54,73463],
[M,2289,71,73480,2289,75,73484],
[M,2289,87,73496,2289,97,73506],
[M,2289,2,73411,2291,5,73598],
[M,2287,25,73367,2287,41,73383],
[M,2287,25,73367,2287,35,73377],
[M,2286,23,73309,2286,26,73312],
[M,2286,36,73322,2286,40,73326],
[M,2286,49,73335,2286,53,73339],
[M,2286,2,73288,2288,5,73407],
[M,2284,23,73244,2284,39,73260],
[M,2284,23,73244,2284,33,73254],
[M,2283,21,73188,2283,24,73191],
[M,2283,34,73201,2283,38,73205],
[M,2283,47,73214,2283,51,73218],
[M,2283,2,73169,2285,5,73284],
[M,2281,23,73133,2281,48,73158],
[M,2281,34,73144,2281,47,73157],
[M,2281,23,73133,2281,33,73143],
[M,2280,21,73082,2280,24,73085],
[M,2280,36,73097,2280,46,73107],
[M,2280,2,73063,2282,5,73165],
[M,2278,21,73027,2278,46,73052],
[M,2278,32,73038,2278,45,73051],
[M,2278,21,73027,2278,31,73037],
[M,2277,19,72976,2277,22,72979],
[M,2277,34,72991,2277,46,73003],
[M,2277,2,72959,2279,5,73059],
[M,2275,24,72905,2275,40,72921],
[M,2275,24,72905,2275,34,72915],
[M,2274,22,72837,2274,25,72840],
[M,2274,35,72850,2274,39,72854],
[M,2274,51,72866,2274,63,72878],
[M,2274,2,72817,2276,5,72955],
[M,2272,24,72763,2272,40,72779],
[M,2272,24,72763,2272,34,72773],
[M,2271,22,72695,2271,25,72698],
[M,2271,35,72708,2271,39,72712],
[M,2271,51,72724,2271,63,72736],
[M,2271,2,72675,2273,5,72813],
[M,2269,24,72580,2269,47,72603],
[M,2269,33,72589,2269,46,72602],
[M,2269,24,72580,2269,32,72588],
[M,2262,11,72397,2262,14,72400],
[M,2263,14,72416,2263,24,72426],
[M,2264,13,72460,2264,16,72463],
[M,2265,13,72492,2265,19,72498],
[M,2266,14,72514,2266,18,72518],
[M,2267,16,72536,2268,4,72553],
[M,2260,2,72364,2270,5,72671],
[M,2258,21,72242,2258,46,72267],
[M,2258,32,72253,2258,45,72266],
[M,2258,21,72242,2258,31,72252],
[M,2250,11,72067,2250,14,72070],
[M,2251,16,72088,2251,26,72098],
[M,2252,14,72114,2252,24,72124],
[M,2253,13,72139,2253,16,72142],
[M,2254,13,72157,2254,19,72163],
[M,2255,14,72179,2255,18,72183],
[M,2256,16,72201,2257,4,72218],
[M,2248,2,72037,2259,5,72360],
[M,2245,23,72009,2245,39,72025],
[M,2245,23,72009,2245,33,72019],
[M,2244,21,71966,2244,24,71969],
[M,2244,34,71979,2244,38,71983],
[M,2244,2,71947,2246,5,72032],
[M,2241,32,71900,2241,48,71916],
[M,2241,32,71900,2241,42,71910],
[M,2240,26,71819,2240,29,71822],
[M,2240,37,71830,2240,43,71836],
[M,2240,53,71846,2240,57,71850],
[M,2240,68,71861,2240,72,71865],
[M,2240,2,71795,2242,5,71942],
[M,2237,24,71748,2237,40,71764],
[M,2237,24,71748,2237,34,71758],
[M,2236,18,71675,2236,21,71678],
[M,2236,29,71686,2236,35,71692],
[M,2236,45,71702,2236,49,71706],
[M,2236,60,71717,2236,64,71721],
[M,2236,2,71659,2238,5,71790],
[M,2233,21,71594,2233,37,71610],
[M,2233,21,71594,2233,31,71604],
[M,2232,19,71524,2232,22,71527],
[M,2232,32,71537,2232,36,71541],
[M,2232,44,71549,2232,48,71553],
[M,2232,61,71566,2232,65,71570],
[M,2232,2,71507,2234,5,71654],
[M,2229,28,71415,2229,43,71430],
[M,2229,28,71415,2229,37,71424],
[M,2228,26,71310,2228,29,71313],
[M,2228,38,71322,2228,41,71325],
[M,2228,50,71334,2228,54,71338],
[M,2228,68,71352,2228,85,71369],
[M,2228,96,71380,2228,100,71384],
[M,2228,2,71286,2230,5,71502],
[M,2226,23,71214,2226,38,71229],
[M,2226,23,71214,2226,32,71223],
[M,2225,21,71129,2225,24,71132],
[M,2225,33,71141,2225,36,71144],
[M,2225,45,71153,2225,49,71157],
[M,2225,63,71171,2225,80,71188],
[M,2225,2,71110,2227,5,71282],
[M,2222,36,71057,2222,59,71080],
[M,2222,45,71066,2222,58,71079],
[M,2222,36,71057,2222,44,71065],
[M,2221,28,70965,2221,31,70968],
[M,2221,41,70978,2221,47,70984],
[M,2221,57,70994,2221,67,71004],
[M,2221,77,71014,2221,81,71018],
[M,2221,2,70939,2223,5,71105],
[M,2218,30,70881,2218,57,70908],
[M,2218,43,70894,2218,56,70907],
[M,2218,30,70881,2218,42,70893],
[M,2217,28,70798,2217,31,70801],
[M,2217,45,70815,2217,63,70833],
[M,2217,74,70844,2217,78,70848],
[M,2217,2,70772,2219,5,70934],
[M,2215,25,70734,2215,52,70761],
[M,2215,38,70747,2215,51,70760],
[M,2215,25,70734,2215,37,70746],
[M,2214,23,70671,2214,26,70674],
[M,2214,40,70688,2214,58,70706],
[M,2214,2,70650,2216,5,70768],
[M,2211,25,70590,2211,52,70617],
[M,2211,38,70603,2211,51,70616],
[M,2211,25,70590,2211,37,70602],
[M,2210,23,70516,2210,26,70519],
[M,2210,40,70533,2210,54,70547],
[M,2210,65,70558,2210,69,70562],
[M,2210,2,70495,2212,5,70643],
[M,2208,20,70457,2208,47,70484],
[M,2208,33,70470,2208,46,70483],
[M,2208,20,70457,2208,32,70469],
[M,2207,18,70403,2207,21,70406],
[M,2207,35,70420,2207,49,70434],
[M,2207,2,70387,2209,5,70491],
[M,2204,32,70341,2204,48,70357],
[M,2204,32,70341,2204,42,70351],
[M,2203,30,70275,2203,33,70278],
[M,2203,43,70288,2203,47,70292],
[M,2203,57,70302,2203,61,70306],
[M,2203,2,70247,2205,5,70382],
[M,2200,27,70201,2200,43,70217],
[M,2200,27,70201,2200,37,70211],
[M,2199,25,70140,2199,28,70143],
[M,2199,38,70153,2199,42,70157],
[M,2199,52,70167,2199,56,70171],
[M,2199,2,70117,2201,5,70242],
[M,2196,24,70072,2196,38,70086],
[M,2196,24,70072,2196,32,70080],
[M,2195,22,70015,2195,25,70018],
[M,2195,33,70026,2195,37,70030],
[M,2195,48,70041,2195,52,70045],
[M,2195,2,69995,2197,5,70112],
[M,2192,26,69950,2192,42,69966],
[M,2192,26,69950,2192,36,69960],
[M,2191,2,69892,2193,5,69990],
[M,2188,22,69845,2188,38,69861],
[M,2188,22,69845,2188,32,69855],
[M,2187,20,69788,2187,23,69791],
[M,2187,33,69801,2187,37,69805],
[M,2187,48,69816,2187,52,69820],
[M,2187,2,69770,2189,5,69887],
[M,2184,23,69731,2184,50,69758],
[M,2184,36,69744,2184,49,69757],
[M,2184,23,69731,2184,35,69743],
[M,2183,21,69667,2183,24,69670],
[M,2183,38,69684,2183,59,69705],
[M,2183,2,69648,2185,5,69765],
[M,2180,21,69587,2180,37,69603],
[M,2180,21,69587,2180,31,69597],
[M,2179,19,69507,2179,22,69510],
[M,2179,32,69520,2179,36,69524],
[M,2179,47,69535,2179,51,69539],
[M,2179,68,69556,2179,75,69563],
[M,2179,2,69490,2181,5,69643],
[M,2176,21,69443,2176,37,69459],
[M,2176,21,69443,2176,31,69453],
[M,2175,19,69387,2175,22,69390],
[M,2175,32,69400,2175,36,69404],
[M,2175,47,69415,2175,51,69419],
[M,2175,2,69370,2177,5,69485],
[M,2172,25,69323,2172,41,69339],
[M,2172,25,69323,2172,35,69333],
[M,2171,23,69263,2171,26,69266],
[M,2171,36,69276,2171,40,69280],
[M,2171,51,69291,2171,55,69295],
[M,2171,2,69242,2173,5,69365],
[M,2168,22,69197,2168,38,69213],
[M,2168,22,69197,2168,32,69207],
[M,2167,20,69143,2167,23,69146],
[M,2167,33,69156,2167,37,69160],
[M,2167,46,69169,2167,49,69172],
[M,2167,2,69125,2169,5,69237],
[M,2164,27,69002,2164,52,69027],
[M,2164,38,69013,2164,51,69026],
[M,2164,27,69002,2164,37,69012],
[M,2163,2,68915,2165,5,69120],
[M,2160,28,68887,2160,44,68903],
[M,2160,28,68887,2160,38,68897],
[M,2159,26,68839,2159,29,68842],
[M,2159,39,68852,2159,43,68856],
[M,2159,2,68815,2161,5,68910],
[M,2156,23,68779,2156,47,68803],
[M,2156,33,68789,2156,46,68802],
[M,2156,23,68779,2156,32,68788],
[M,2155,2,68731,2157,5,68810],
[M,2152,29,68676,2152,45,68692],
[M,2152,29,68676,2152,39,68686],
[M,2151,27,68606,2151,30,68609],
[M,2151,40,68619,2151,44,68623],
[M,2151,56,68635,2151,65,68644],
[M,2151,2,68581,2153,5,68726],
[M,2148,33,68554,2148,48,68569],
[M,2148,33,68554,2148,42,68563],
[M,2147,24,68481,2147,27,68484],
[M,2147,38,68495,2147,48,68505],
[M,2147,57,68514,2147,61,68518],
[M,2147,2,68459,2149,5,68576],
[M,2144,24,68405,2144,48,68429],
[M,2144,34,68415,2144,47,68428],
[M,2144,24,68405,2144,33,68414],
[M,2143,2,68349,2145,5,68454],
[M,2140,29,68303,2140,45,68319],
[M,2140,29,68303,2140,39,68313],
[M,2139,2,68238,2141,5,68344],
[M,2136,26,68184,2136,50,68208],
[M,2136,36,68194,2136,49,68207],
[M,2136,26,68184,2136,35,68193],
[M,2135,2,68124,2137,5,68233],
[M,2132,31,68070,2132,55,68094],
[M,2132,41,68080,2132,54,68093],
[M,2132,31,68070,2132,40,68079],
[M,2131,2,68000,2133,5,68119],
[M,2128,22,67953,2128,38,67969],
[M,2128,22,67953,2128,32,67963],
[M,2127,2,67893,2129,5,67995],
[M,2123,2,67812,2125,5,67888],
[M,2120,26,67766,2120,42,67782],
[M,2120,26,67766,2120,36,67776],
[M,2119,2,67707,2121,5,67807],
[M,2117,26,67662,2117,42,67678],
[M,2117,26,67662,2117,36,67672],
[M,2116,2,67603,2118,5,67703],
[M,2113,31,67558,2113,47,67574],
[M,2113,31,67558,2113,41,67568],
[M,2112,2,67490,2114,5,67598],
[M,2108,2,67413,2110,5,67485],
[M,2105,2,67339,2107,5,67409],
[M,2103,25,67305,2103,48,67328],
[M,2103,34,67314,2103,47,67327],
[M,2103,25,67305,2103,33,67313],
[M,2102,2,67248,2104,5,67335],
[M,2099,2,67184,2101,5,67244],
[M,2096,2,67122,2098,5,67180],
[M,2094,25,67095,2094,41,67111],
[M,2094,25,67095,2094,35,67105],
[M,2093,2,67044,2095,5,67118],
[M,2091,31,66983,2091,56,67008],
[M,2091,42,66994,2091,55,67007],
[M,2091,31,66983,2091,41,66993],
[M,2090,2,66905,2092,5,67040],
[M,2088,30,66834,2088,53,66857],
[M,2088,30,66834,2088,47,66851],
[M,2087,2,66753,2089,5,66901],
[M,2085,24,66701,2085,47,66724],
[M,2085,24,66701,2085,41,66718],
[M,2084,2,66639,2086,5,66749],
[M,2081,2,66548,2083,5,66635],
[M,2081,28,66574,2081,31,66577],
[M,2081,40,66586,2081,46,66592],
[M,2078,2,66457,2080,5,66544],
[M,2078,27,66482,2078,30,66485],
[M,2078,40,66495,2078,46,66501],
[M,2075,25,66351,2075,45,66371],
[M,2075,25,66351,2075,39,66365],
[M,2074,2,66265,2076,5,66452],
[M,2071,6,66158,2071,24,66176],
[M,2071,6,66158,2071,18,66170],
[M,2069,2,66076,2072,5,66258],
[M,2065,2,66011,2067,5,66069],
[M,2062,2,65957,2064,5,66007],
[M,2059,2,65913,2061,5,65953],
[M,2056,2,65859,2058,5,65909],
[M,2053,2,65799,2055,5,65855],
[M,2046,2,65679,2051,5,65794],
[M,2047,4,65702,2050,7,65788],
[M,2049,6,65748,2049,38,65780],
[M,2049,24,65766,2049,37,65779],
[M,2049,24,65766,2049,31,65773],
[M,2048,6,65727,2048,20,65741],
[M,2040,2,65597,2042,5,65651],
[M,2041,4,65630,2041,13,65639],
[M,2037,2,65540,2039,5,65593],
[M,2038,4,65572,2038,13,65581],
[M,2035,4,65495,2035,39,65530],
[M,2035,4,65495,2035,13,65504],
[M,2034,2,65464,2036,5,65536],
[M,2032,4,65404,2032,54,65454],
[M,2032,4,65404,2032,13,65413],
[M,2031,2,65373,2033,5,65460],
[M,2028,2,65300,2030,5,65369],
[M,2029,14,65341,2029,27,65354],
[M,2029,4,65331,2029,13,65340],
[M,2026,4,65240,2026,54,65290],
[M,2026,14,65250,2026,27,65263],
[M,2026,4,65240,2026,13,65249],
[M,2025,2,65206,2027,5,65296],
[M,2023,4,65146,2023,54,65196],
[M,2023,14,65156,2023,27,65169],
[M,2023,4,65146,2023,13,65155],
[M,2022,2,65110,2024,5,65202],
[M,2019,2,65071,2021,5,65106],
[M,2016,2,65040,2018,5,65067],
[M,2013,2,65007,2015,5,65036],
[M,2005,2,64871,2012,5,65003],
[M,2011,4,64981,2011,14,64991],
[M,2007,11,64918,2007,14,64921],
[M,2008,18,64941,2008,24,64947],
[M,2009,14,64963,2009,18,64967],
[M,1997,2,64712,2004,5,64867],
[M,2003,4,64838,2003,21,64855],
[M,1999,11,64765,1999,14,64768],
[M,2000,14,64784,2000,20,64790],
[M,2001,21,64813,2001,32,64824],
[M,1995,4,64641,1995,65,64702],
[M,1995,14,64651,1995,27,64664],
[M,1995,4,64641,1995,13,64650],
[M,1990,11,64530,1990,14,64533],
[M,1991,14,64549,1991,20,64555],
[M,1992,17,64574,1992,36,64593],
[M,1993,21,64616,1993,32,64627],
[M,1988,2,64487,1996,5,64708],
[M,1980,2,64320,1987,5,64483],
[M,1986,14,64449,1986,27,64462],
[M,1986,4,64439,1986,13,64448],
[M,1982,11,64364,1982,14,64367],
[M,1983,14,64383,1983,20,64389],
[M,1984,22,64413,1985,6,64432],
[M,1978,4,64234,1978,80,64310],
[M,1978,14,64244,1978,27,64257],
[M,1978,4,64234,1978,13,64243],
[M,1972,11,64096,1972,14,64099],
[M,1973,20,64121,1973,23,64124],
[M,1974,14,64140,1974,20,64146],
[M,1975,17,64165,1975,36,64184],
[M,1976,22,64208,1977,6,64227],
[M,1970,2,64062,1979,5,64316],
[M,1967,2,63950,1969,5,64058],
[M,1968,4,64036,1968,14,64046],
[M,1967,30,63978,1967,33,63981],
[M,1967,50,63998,1967,67,64015],
[M,1967,77,64025,1967,81,64029],
[M,1965,4,63902,1965,42,63940],
[M,1965,4,63902,1965,14,63912],
[M,1964,24,63863,1964,27,63866],
[M,1964,37,63876,1964,41,63880],
[M,1964,52,63891,1964,56,63895],
[M,1964,2,63841,1966,5,63946],
[M,1957,4,63696,1961,27,63828],
[M,1957,4,63696,1957,14,63706],
[M,1949,11,63511,1949,14,63514],
[M,1950,14,63530,1950,18,63534],
[M,1951,14,63550,1951,24,63560],
[M,1952,13,63594,1952,16,63597],
[M,1953,13,63626,1953,19,63632],
[M,1954,14,63648,1954,18,63652],
[M,1955,16,63670,1956,6,63689],
[M,1947,2,63472,1962,5,63834],
[M,1945,4,63404,1945,62,63462],
[M,1945,4,63404,1945,14,63414],
[M,1944,26,63353,1944,29,63356],
[M,1944,39,63366,1944,43,63370],
[M,1944,52,63379,1944,55,63382],
[M,1944,66,63393,1944,70,63397],
[M,1944,2,63329,1946,5,63468],
[M,1942,4,63261,1942,62,63319],
[M,1942,4,63261,1942,14,63271],
[M,1941,29,63210,1941,32,63213],
[M,1941,42,63223,1941,46,63227],
[M,1941,55,63236,1941,58,63239],
[M,1941,69,63250,1941,73,63254],
[M,1941,2,63183,1943,5,63325],
[M,1939,4,63135,1939,42,63173],
[M,1939,4,63135,1939,14,63145],
[M,1938,26,63096,1938,29,63099],
[M,1938,39,63109,1938,43,63113],
[M,1938,54,63124,1938,58,63128],
[M,1938,2,63072,1940,5,63179],
[M,1934,2,62950,1936,5,63065],
[M,1935,4,63043,1935,14,63053],
[M,1934,21,62969,1934,24,62972],
[M,1934,34,62982,1934,48,62996],
[M,1934,58,63006,1934,62,63010],
[M,1934,81,63029,1934,88,63036],
[M,1932,4,62840,1932,104,62940],
[M,1932,4,62840,1932,18,62854],
[M,1926,11,62728,1926,14,62731],
[M,1927,18,62751,1927,22,62755],
[M,1928,18,62775,1928,31,62788],
[M,1929,13,62803,1929,16,62806],
[M,1930,14,62822,1930,18,62826],
[M,1924,2,62698,1933,5,62946],
[M,1917,4,62469,1922,27,62688],
[M,1917,4,62469,1917,15,62480],
[M,1908,11,62238,1908,14,62241],
[M,1909,14,62257,1909,20,62263],
[M,1910,15,62280,1910,19,62284],
[M,1911,16,62302,1911,26,62312],
[M,1912,16,62344,1912,26,62354],
[M,1913,18,62374,1913,31,62387],
[M,1914,24,62413,1914,36,62425],
[M,1915,16,62443,1916,6,62462],
[M,1906,2,62202,1923,5,62694],
[M,1900,4,61998,1904,27,62192],
[M,1900,14,62008,1900,27,62021],
[M,1900,4,61998,1900,13,62007],
[M,1892,11,61788,1892,14,61791],
[M,1893,14,61807,1893,20,61813],
[M,1894,16,61831,1894,26,61841],
[M,1895,16,61873,1895,26,61883],
[M,1896,18,61903,1896,31,61916],
[M,1897,24,61942,1897,36,61954],
[M,1898,16,61972,1899,6,61991],
[M,1890,2,61757,1905,5,62198],
[M,1888,4,61710,1888,41,61747],
[M,1888,4,61710,1888,13,61719],
[M,1887,23,61672,1887,26,61675],
[M,1887,35,61684,1887,39,61688],
[M,1887,50,61699,1887,54,61703],
[M,1887,2,61651,1889,5,61753],
[M,1884,2,61564,1886,5,61647],
[M,1885,4,61626,1885,13,61635],
[M,1884,24,61586,1884,27,61589],
[M,1884,36,61598,1884,40,61602],
[M,1884,51,61613,1884,57,61619],
[M,1881,2,61482,1883,5,61560],
[M,1882,4,61539,1882,13,61548],
[M,1881,19,61499,1881,22,61502],
[M,1881,31,61511,1881,35,61515],
[M,1881,46,61526,1881,52,61532],
[M,1878,19,61445,1878,22,61448],
[M,1878,29,61455,1878,35,61461],
[M,1878,2,61428,1880,5,61478],
[M,1875,20,61390,1875,23,61393],
[M,1875,30,61400,1875,37,61407],
[M,1875,2,61372,1877,5,61424],
[M,1872,20,61318,1872,23,61321],
[M,1872,32,61330,1872,38,61336],
[M,1872,47,61345,1872,53,61351],
[M,1872,2,61300,1874,5,61368],
[M,1869,19,61263,1869,22,61266],
[M,1869,29,61273,1869,35,61279],
[M,1869,2,61246,1871,5,61296],
[M,1866,2,61197,1868,5,61242],
[M,1863,25,61173,1863,28,61176],
[M,1863,2,61150,1865,5,61193],
[M,1860,2,61064,1862,5,61146],
[M,1861,4,61126,1861,12,61134],
[M,1860,25,61087,1860,28,61090],
[M,1860,36,61098,1860,40,61102],
[M,1860,50,61112,1860,57,61119],
[M,1857,2,60998,1859,5,61060],
[M,1858,4,61040,1858,12,61048],
[M,1857,22,61018,1857,25,61021],
[M,1857,33,61029,1857,37,61033],
[M,1854,2,60936,1856,5,60994],
[M,1855,4,60974,1855,12,60982],
[M,1854,18,60952,1854,21,60955],
[M,1854,29,60963,1854,33,60967],
[M,1851,24,60896,1851,27,60899],
[M,1851,37,60909,1851,43,60915],
[M,1851,2,60874,1853,5,60932],
[M,1848,2,60766,1850,5,60870],
[M,1849,14,60844,1849,27,60857],
[M,1849,4,60834,1849,13,60843],
[M,1848,24,60788,1848,27,60791],
[M,1848,37,60801,1848,43,60807],
[M,1848,53,60817,1848,63,60827],
[M,1846,4,60705,1846,55,60756],
[M,1846,4,60705,1846,14,60715],
[M,1845,19,60661,1845,22,60664],
[M,1845,32,60674,1845,36,60678],
[M,1845,46,60688,1845,56,60698],
[M,1845,2,60644,1847,5,60762],
[M,1843,4,60574,1843,64,60634],
[M,1843,4,60574,1843,21,60591],
[M,1842,25,60495,1842,28,60498],
[M,1842,37,60507,1842,54,60524],
[M,1842,71,60541,1842,75,60545],
[M,1842,87,60557,1842,97,60567],
[M,1842,2,60472,1844,5,60640],
[M,1840,4,60426,1840,40,60462],
[M,1840,4,60426,1840,14,60436],
[M,1839,23,60389,1839,26,60392],
[M,1839,36,60402,1839,40,60406],
[M,1839,49,60415,1839,53,60419],
[M,1839,2,60368,1841,5,60468],
[M,1837,4,60322,1837,40,60358],
[M,1837,4,60322,1837,14,60332],
[M,1836,21,60285,1836,24,60288],
[M,1836,34,60298,1836,38,60302],
[M,1836,47,60311,1836,51,60315],
[M,1836,2,60266,1838,5,60364],
[M,1833,2,60173,1835,5,60262],
[M,1834,14,60234,1834,27,60247],
[M,1834,4,60224,1834,13,60233],
[M,1833,21,60192,1833,24,60195],
[M,1833,36,60207,1833,46,60217],
[M,1830,2,60080,1832,5,60169],
[M,1831,14,60141,1831,27,60154],
[M,1831,4,60131,1831,13,60140],
[M,1830,19,60097,1830,22,60100],
[M,1830,34,60112,1830,46,60124],
[M,1828,4,60017,1828,57,60070],
[M,1828,4,60017,1828,14,60027],
[M,1827,22,59969,1827,25,59972],
[M,1827,35,59982,1827,39,59986],
[M,1827,51,59998,1827,63,60010],
[M,1827,2,59949,1829,5,60076],
[M,1825,4,59886,1825,57,59939],
[M,1825,4,59886,1825,14,59896],
[M,1824,22,59838,1824,25,59841],
[M,1824,35,59851,1824,39,59855],
[M,1824,51,59867,1824,63,59879],
[M,1824,2,59818,1826,5,59945],
[M,1822,4,59713,1822,99,59808],
[M,1822,14,59723,1822,27,59736],
[M,1822,4,59713,1822,13,59722],
[M,1815,11,59548,1815,14,59551],
[M,1816,14,59567,1816,24,59577],
[M,1817,13,59611,1817,16,59614],
[M,1818,13,59643,1818,19,59649],
[M,1819,14,59665,1819,18,59669],
[M,1820,16,59687,1821,6,59706],
[M,1813,2,59515,1823,5,59814],
[M,1810,4,59369,1811,103,59505],
[M,1810,14,59379,1810,27,59392],
[M,1810,4,59369,1810,13,59378],
[M,1802,11,59209,1802,14,59212],
[M,1803,16,59230,1803,26,59240],
[M,1804,14,59256,1804,24,59266],
[M,1805,13,59281,1805,16,59284],
[M,1806,13,59299,1806,19,59305],
[M,1807,14,59321,1807,18,59325],
[M,1808,16,59343,1809,6,59362],
[M,1800,2,59179,1812,5,59511],
[M,1796,2,59107,1798,5,59172],
[M,1797,4,59150,1797,14,59160],
[M,1796,21,59126,1796,24,59129],
[M,1796,34,59139,1796,38,59143],
[M,1793,4,59056,1793,42,59094],
[M,1793,4,59056,1793,14,59066],
[M,1792,26,59003,1792,29,59006],
[M,1792,37,59014,1792,43,59020],
[M,1792,53,59030,1792,57,59034],
[M,1792,68,59045,1792,72,59049],
[M,1792,2,58979,1794,5,59100],
[M,1789,4,58928,1789,42,58966],
[M,1789,4,58928,1789,14,58938],
[M,1788,18,58875,1788,21,58878],
[M,1788,29,58886,1788,35,58892],
[M,1788,45,58902,1788,49,58906],
[M,1788,60,58917,1788,64,58921],
[M,1788,2,58859,1790,5,58972],
[M,1785,4,58787,1785,63,58846],
[M,1785,4,58787,1785,14,58797],
[M,1784,19,58734,1784,22,58737],
[M,1784,32,58747,1784,36,58751],
[M,1784,44,58759,1784,48,58763],
[M,1784,61,58776,1784,65,58780],
[M,1784,2,58717,1786,5,58852],
[M,1781,4,58608,1781,100,58704],
[M,1781,4,58608,1781,13,58617],
[M,1780,26,58527,1780,29,58530],
[M,1780,38,58539,1780,41,58542],
[M,1780,50,58551,1780,54,58555],
[M,1780,68,58569,1780,85,58586],
[M,1780,96,58597,1780,100,58601],
[M,1780,2,58503,1782,5,58710],
[M,1778,4,58419,1778,78,58493],
[M,1778,4,58419,1778,13,58428],
[M,1777,21,58353,1777,24,58356],
[M,1777,33,58365,1777,36,58368],
[M,1777,45,58377,1777,49,58381],
[M,1777,63,58395,1777,80,58412],
[M,1777,2,58334,1779,5,58499],
[M,1774,4,58270,1774,55,58321],
[M,1774,14,58280,1774,27,58293],
[M,1774,4,58270,1774,13,58279],
[M,1773,28,58210,1773,31,58213],
[M,1773,41,58223,1773,47,58229],
[M,1773,57,58239,1773,67,58249],
[M,1773,77,58259,1773,81,58263],
[M,1773,2,58184,1775,5,58327],
[M,1770,4,58115,1770,60,58171],
[M,1770,14,58125,1770,27,58138],
[M,1770,4,58115,1770,13,58124],
[M,1769,28,58058,1769,31,58061],
[M,1769,45,58075,1769,63,58093],
[M,1769,74,58104,1769,78,58108],
[M,1769,2,58032,1771,5,58177],
[M,1766,2,57925,1768,5,58028],
[M,1767,14,57998,1767,27,58011],
[M,1767,4,57988,1767,13,57997],
[M,1766,23,57946,1766,26,57949],
[M,1766,40,57963,1766,58,57981],
[M,1763,4,57856,1763,60,57912],
[M,1763,14,57866,1763,27,57879],
[M,1763,4,57856,1763,13,57865],
[M,1762,23,57803,1762,26,57806],
[M,1762,40,57820,1762,54,57834],
[M,1762,65,57845,1762,69,57849],
[M,1762,2,57782,1764,5,57918],
[M,1759,2,57684,1761,5,57778],
[M,1760,14,57748,1760,27,57761],
[M,1760,4,57738,1760,13,57747],
[M,1759,18,57700,1759,21,57703],
[M,1759,35,57717,1759,49,57731],
[M,1756,4,57634,1756,41,57671],
[M,1756,4,57634,1756,14,57644],
[M,1755,30,57596,1755,33,57599],
[M,1755,43,57609,1755,47,57613],
[M,1755,57,57623,1755,61,57627],
[M,1755,2,57568,1757,5,57677],
[M,1752,4,57518,1752,41,57555],
[M,1752,4,57518,1752,14,57528],
[M,1751,25,57480,1751,28,57483],
[M,1751,38,57493,1751,42,57497],
[M,1751,52,57507,1751,56,57511],
[M,1751,2,57457,1753,5,57561],
[M,1748,4,57408,1748,40,57444],
[M,1748,4,57408,1748,12,57416],
[M,1747,22,57371,1747,25,57374],
[M,1747,33,57382,1747,37,57386],
[M,1747,48,57397,1747,52,57401],
[M,1747,2,57351,1749,5,57450],
[M,1744,4,57302,1744,40,57338],
[M,1744,4,57302,1744,14,57312],
[M,1743,24,57266,1743,27,57269],
[M,1743,37,57279,1743,41,57283],
[M,1743,50,57292,1743,53,57295],
[M,1743,2,57244,1745,5,57344],
[M,1740,4,57195,1740,42,57233],
[M,1740,4,57195,1740,14,57205],
[M,1739,20,57156,1739,23,57159],
[M,1739,33,57169,1739,37,57173],
[M,1739,48,57184,1739,52,57188],
[M,1739,2,57138,1741,5,57239],
[M,1735,2,57027,1737,5,57131],
[M,1736,14,57101,1736,27,57114],
[M,1736,4,57091,1736,13,57100],
[M,1735,21,57046,1735,24,57049],
[M,1735,38,57063,1735,59,57084],
[M,1732,4,56976,1732,42,57014],
[M,1732,4,56976,1732,14,56986],
[M,1731,19,56913,1731,22,56916],
[M,1731,32,56926,1731,36,56930],
[M,1731,47,56941,1731,51,56945],
[M,1731,68,56962,1731,75,56969],
[M,1731,2,56896,1733,5,57020],
[M,1728,4,56845,1728,42,56883],
[M,1728,4,56845,1728,14,56855],
[M,1727,19,56806,1727,22,56809],
[M,1727,32,56819,1727,36,56823],
[M,1727,47,56834,1727,51,56838],
[M,1727,2,56789,1729,5,56889],
[M,1724,4,56740,1724,42,56778],
[M,1724,4,56740,1724,14,56750],
[M,1723,23,56701,1723,26,56704],
[M,1723,36,56714,1723,40,56718],
[M,1723,51,56729,1723,55,56733],
[M,1723,2,56680,1725,5,56784],
[M,1720,4,56631,1720,40,56667],
[M,1720,4,56631,1720,14,56641],
[M,1719,20,56595,1719,23,56598],
[M,1719,33,56608,1719,37,56612],
[M,1719,46,56621,1719,49,56624],
[M,1719,2,56577,1721,5,56673],
[M,1715,4,56430,1716,103,56566],
[M,1715,14,56440,1715,27,56453],
[M,1715,4,56430,1715,13,56439],
[M,1714,2,56366,1717,5,56572],
[M,1710,2,56289,1712,5,56359],
[M,1711,4,56337,1711,14,56347],
[M,1710,26,56313,1710,29,56316],
[M,1710,39,56326,1710,43,56330],
[M,1706,2,56216,1708,5,56282],
[M,1707,14,56255,1707,27,56268],
[M,1707,4,56245,1707,13,56254],
[M,1703,4,56150,1703,57,56203],
[M,1703,4,56150,1703,14,56160],
[M,1702,27,56105,1702,30,56108],
[M,1702,40,56118,1702,44,56122],
[M,1702,56,56134,1702,65,56143],
[M,1702,2,56080,1704,5,56209],
[M,1698,2,55986,1700,5,56073],
[M,1699,4,56052,1699,13,56061],
[M,1698,24,56008,1698,27,56011],
[M,1698,38,56022,1698,48,56032],
[M,1698,57,56041,1698,61,56045],
[M,1695,4,55921,1695,56,55973],
[M,1695,14,55931,1695,27,55944],
[M,1695,4,55921,1695,13,55930],
[M,1694,2,55885,1696,5,55979],
[M,1691,4,55835,1691,41,55872],
[M,1691,4,55835,1691,14,55845],
[M,1690,2,55795,1692,5,55878],
[M,1687,4,55730,1687,56,55782],
[M,1687,14,55740,1687,27,55753],
[M,1687,4,55730,1687,13,55739],
[M,1686,2,55692,1688,5,55788],
[M,1683,4,55629,1683,56,55681],
[M,1683,14,55639,1683,27,55652],
[M,1683,4,55629,1683,13,55638],
[M,1682,2,55586,1684,5,55687],
[M,1679,4,55537,1679,42,55575],
[M,1679,4,55537,1679,14,55547],
[M,1678,2,55495,1680,5,55581],
[M,1675,4,55448,1675,40,55484],
[M,1675,4,55448,1675,14,55458],
[M,1674,2,55411,1676,5,55490],
[M,1671,4,55361,1671,41,55398],
[M,1671,4,55361,1671,14,55371],
[M,1670,2,55324,1672,5,55404],
[M,1668,4,55277,1668,41,55314],
[M,1668,4,55277,1668,14,55287],
[M,1667,2,55240,1669,5,55320],
[M,1664,4,55191,1664,40,55227],
[M,1664,4,55191,1664,14,55201],
[M,1663,2,55150,1665,5,55233],
[M,1659,2,55098,1661,5,55143],
[M,1656,2,55050,1658,5,55094],
[M,1653,2,54974,1655,5,55046],
[M,1654,14,55020,1654,27,55033],
[M,1654,4,55010,1654,13,55019],
[M,1650,2,54931,1652,5,54970],
[M,1647,2,54889,1649,5,54927],
[M,1644,2,54833,1646,5,54885],
[M,1645,4,54863,1645,14,54873],
[M,1641,2,54740,1643,5,54829],
[M,1642,14,54801,1642,27,54814],
[M,1642,4,54791,1642,13,54800],
[M,1639,4,54692,1639,42,54730],
[M,1639,4,54692,1639,14,54702],
[M,1638,2,54637,1640,5,54736],
[M,1635,2,54589,1637,5,54633],
[M,1632,2,54541,1634,5,54585],
[M,1630,4,54487,1630,48,54531],
[M,1630,4,54487,1630,21,54504],
[M,1629,2,54445,1631,5,54537],
[M,1623,4,54296,1626,24,54432],
[M,1623,4,54296,1623,18,54310],
[M,1622,2,54231,1627,5,54438],
[M,1619,4,54116,1619,106,54218],
[M,1619,4,54116,1619,16,54128],
[M,1618,2,54060,1620,5,54224],
[M,1614,2,54011,1616,5,54053],
[M,1611,2,53969,1613,5,54007],
[M,1608,2,53932,1610,5,53965],
[M,1605,2,53894,1607,5,53928],
[M,1602,2,53853,1604,5,53890],
[M,1595,2,53739,1600,5,53848],
[M,1596,4,53762,1599,7,53842],
[M,1598,6,53808,1598,32,53834],
[M,1598,19,53821,1598,26,53828],
[M,1597,6,53787,1597,20,53801],
[M,1589,21,53685,1589,36,53700],
[M,1589,21,53685,1589,30,53694],
[M,1588,2,53635,1590,5,53707],
[M,1586,13,53602,1586,28,53617],
[M,1586,13,53602,1586,22,53611],
[M,1585,2,53561,1587,5,53631],
[M,1583,14,53518,1583,29,53533],
[M,1583,14,53518,1583,23,53527],
[M,1582,2,53477,1584,5,53557],
[M,1580,13,53426,1580,28,53441],
[M,1580,13,53426,1580,22,53435],
[M,1579,2,53386,1581,5,53473],
[M,1577,16,53350,1577,41,53375],
[M,1577,27,53361,1577,40,53374],
[M,1577,16,53350,1577,26,53360],
[M,1576,2,53307,1578,5,53382],
[M,1574,16,53256,1574,39,53279],
[M,1574,25,53265,1574,38,53278],
[M,1574,16,53256,1574,24,53264],
[M,1573,2,53210,1575,5,53303],
[M,1571,15,53147,1571,38,53170],
[M,1571,24,53156,1571,37,53169],
[M,1571,15,53147,1571,23,53155],
[M,1570,2,53091,1572,5,53206],
[M,1569,33,53068,1569,47,53082],
[M,1569,33,53068,1569,41,53076],
[M,1569,2,53037,1569,52,53087],
[M,1568,2,53011,1568,24,53033],
[M,1567,2,52981,1567,28,53007],
[M,1564,40,52953,1564,56,52969],
[M,1564,40,52953,1564,50,52963],
[M,1560,11,52854,1560,14,52857],
[M,1561,18,52877,1561,24,52883],
[M,1562,14,52899,1562,18,52903],
[M,1558,2,52807,1565,5,52976],
[M,1556,42,52773,1556,65,52796],
[M,1556,42,52773,1556,59,52790],
[M,1552,11,52664,1552,14,52667],
[M,1553,14,52683,1553,20,52689],
[M,1554,21,52712,1554,32,52723],
[M,1550,2,52611,1557,5,52803],
[M,1548,32,52549,1548,58,52575],
[M,1548,44,52561,1548,57,52574],
[M,1548,32,52549,1548,43,52560],
[M,1543,11,52412,1543,14,52415],
[M,1544,14,52431,1544,20,52437],
[M,1545,17,52456,1545,36,52475],
[M,1546,21,52498,1546,32,52509],
[M,1541,2,52369,1549,5,52607],
[M,1539,33,52327,1539,64,52358],
[M,1539,50,52344,1539,63,52357],
[M,1539,33,52327,1539,49,52343],
[M,1535,11,52225,1535,14,52228],
[M,1536,14,52244,1536,20,52250],
[M,1537,22,52274,1538,4,52291],
[M,1533,2,52181,1540,5,52365],
[M,1531,35,52111,1531,61,52137],
[M,1531,47,52123,1531,60,52136],
[M,1531,35,52111,1531,46,52122],
[M,1525,11,51944,1525,14,51947],
[M,1526,20,51969,1526,23,51972],
[M,1527,14,51988,1527,20,51994],
[M,1528,17,52013,1528,36,52032],
[M,1529,22,52056,1530,4,52073],
[M,1523,2,51910,1532,5,52177],
[M,1521,37,51883,1521,53,51899],
[M,1521,37,51883,1521,47,51893],
[M,1520,30,51792,1520,33,51795],
[M,1520,50,51812,1520,67,51829],
[M,1520,77,51839,1520,81,51843],
[M,1520,2,51764,1522,5,51906],
[M,1518,18,51715,1518,34,51731],
[M,1518,18,51715,1518,28,51725],
[M,1517,24,51662,1517,27,51665],
[M,1517,37,51675,1517,41,51679],
[M,1517,52,51690,1517,56,51694],
[M,1517,2,51640,1519,5,51760],
[M,1508,8,51479,1508,24,51495],
[M,1508,8,51479,1508,18,51489],
[M,1498,11,51261,1498,14,51264],
[M,1499,14,51280,1499,18,51284],
[M,1500,14,51300,1500,24,51310],
[M,1501,13,51344,1501,16,51347],
[M,1502,13,51376,1502,19,51382],
[M,1503,14,51398,1503,18,51402],
[M,1504,16,51420,1505,4,51437],
[M,1496,2,51222,1515,5,51635],
[M,1494,20,51159,1494,36,51175],
[M,1494,20,51159,1494,30,51169],
[M,1493,26,51092,1493,29,51095],
[M,1493,39,51105,1493,43,51109],
[M,1493,52,51118,1493,55,51121],
[M,1493,66,51132,1493,70,51136],
[M,1493,2,51068,1495,5,51218],
[M,1491,23,51005,1491,39,51021],
[M,1491,23,51005,1491,33,51015],
[M,1490,29,50935,1490,32,50938],
[M,1490,42,50948,1490,46,50952],
[M,1490,55,50961,1490,58,50964],
[M,1490,69,50975,1490,73,50979],
[M,1490,2,50908,1492,5,51064],
[M,1488,20,50862,1488,36,50878],
[M,1488,20,50862,1488,30,50872],
[M,1487,26,50807,1487,29,50810],
[M,1487,39,50820,1487,43,50824],
[M,1487,54,50835,1487,58,50839],
[M,1487,2,50783,1489,5,50904],
[M,1484,21,50740,1484,37,50756],
[M,1484,21,50740,1484,31,50750],
[M,1483,21,50649,1483,24,50652],
[M,1483,34,50662,1483,48,50676],
[M,1483,58,50686,1483,62,50690],
[M,1483,81,50709,1483,88,50716],
[M,1483,2,50630,1485,5,50778],
[M,1481,13,50535,1481,33,50555],
[M,1481,13,50535,1481,27,50549],
[M,1475,11,50416,1475,14,50419],
[M,1476,18,50439,1476,22,50443],
[M,1477,18,50463,1477,31,50476],
[M,1478,13,50491,1478,16,50494],
[M,1479,14,50510,1479,18,50514],
[M,1473,2,50386,1482,5,50626],
[M,1465,8,50172,1465,25,50189],
[M,1465,8,50172,1465,19,50183],
[M,1453,11,49897,1453,14,49900],
[M,1454,14,49916,1454,20,49922],
[M,1455,15,49939,1455,19,49943],
[M,1456,16,49961,1456,26,49971],
[M,1457,16,50003,1457,26,50013],
[M,1458,18,50033,1458,31,50046],
[M,1459,24,50072,1459,36,50084],
[M,1460,16,50102,1461,4,50119],
[M,1451,2,49861,1472,5,50382],
[M,1444,8,49674,1444,33,49699],
[M,1444,19,49685,1444,32,49698],
[M,1444,8,49674,1444,18,49684],
[M,1433,11,49425,1433,14,49428],
[M,1434,14,49444,1434,20,49450],
[M,1435,16,49468,1435,26,49478],
[M,1436,16,49510,1436,26,49520],
[M,1437,18,49540,1437,31,49553],
[M,1438,24,49579,1438,36,49591],
[M,1439,16,49609,1440,4,49626],
[M,1431,2,49394,1450,5,49857],
[M,1429,17,49349,1429,32,49364],
[M,1429,17,49349,1429,26,49358],
[M,1428,23,49298,1428,26,49301],
[M,1428,35,49310,1428,39,49314],
[M,1428,50,49325,1428,54,49329],
[M,1428,2,49277,1430,5,49390],
[M,1426,18,49244,1426,33,49259],
[M,1426,18,49244,1426,27,49253],
[M,1425,24,49190,1425,27,49193],
[M,1425,36,49202,1425,40,49206],
[M,1425,51,49217,1425,57,49223],
[M,1425,2,49168,1427,5,49273],
[M,1423,13,49135,1423,28,49150],
[M,1423,13,49135,1423,22,49144],
[M,1422,19,49086,1422,22,49089],
[M,1422,31,49098,1422,35,49102],
[M,1422,46,49113,1422,52,49119],
[M,1422,2,49069,1424,5,49164],
[M,1419,2,49008,1421,5,49065],
[M,1419,19,49025,1419,22,49028],
[M,1419,29,49035,1419,35,49041],
[M,1416,2,48944,1418,5,49004],
[M,1416,20,48962,1416,23,48965],
[M,1416,30,48972,1416,37,48979],
[M,1413,2,48857,1415,5,48940],
[M,1413,20,48875,1413,23,48878],
[M,1413,32,48887,1413,38,48893],
[M,1413,47,48902,1413,53,48908],
[M,1410,2,48796,1412,5,48853],
[M,1410,19,48813,1410,22,48816],
[M,1410,29,48823,1410,35,48829],
[M,1407,2,48735,1409,5,48792],
[M,1404,2,48675,1406,5,48731],
[M,1404,25,48698,1404,28,48701],
[M,1402,19,48644,1402,33,48658],
[M,1402,19,48644,1402,27,48652],
[M,1401,25,48590,1401,28,48593],
[M,1401,36,48601,1401,40,48605],
[M,1401,50,48615,1401,57,48622],
[M,1401,2,48567,1403,5,48671],
[M,1399,16,48542,1399,30,48556],
[M,1399,16,48542,1399,24,48550],
[M,1398,22,48508,1398,25,48511],
[M,1398,33,48519,1398,37,48523],
[M,1398,2,48488,1400,5,48563],
[M,1396,12,48463,1396,26,48477],
[M,1396,12,48463,1396,20,48471],
[M,1395,18,48433,1395,21,48436],
[M,1395,29,48444,1395,33,48448],
[M,1395,2,48417,1397,5,48484],
[M,1392,2,48340,1394,5,48413],
[M,1392,24,48362,1392,27,48365],
[M,1392,37,48375,1392,43,48381],
[M,1390,24,48306,1390,47,48329],
[M,1390,33,48315,1390,46,48328],
[M,1390,24,48306,1390,32,48314],
[M,1389,24,48240,1389,27,48243],
[M,1389,37,48253,1389,43,48259],
[M,1389,53,48269,1389,63,48279],
[M,1389,2,48218,1391,5,48336],
[M,1387,13,48166,1387,29,48182],
[M,1387,13,48166,1387,23,48176],
[M,1386,19,48113,1386,22,48116],
[M,1386,32,48126,1386,36,48130],
[M,1386,46,48140,1386,56,48150],
[M,1386,2,48096,1388,5,48214],
[M,1384,24,48035,1384,47,48058],
[M,1384,24,48035,1384,41,48052],
[M,1383,25,47936,1383,28,47939],
[M,1383,37,47948,1383,54,47965],
[M,1383,71,47982,1383,75,47986],
[M,1383,87,47998,1383,97,48008],
[M,1383,2,47913,1385,5,48092],
[M,1381,17,47869,1381,33,47885],
[M,1381,17,47869,1381,27,47879],
[M,1380,23,47819,1380,26,47822],
[M,1380,36,47832,1380,40,47836],
[M,1380,49,47845,1380,53,47849],
[M,1380,2,47798,1382,5,47909],
[M,1378,15,47754,1378,31,47770],
[M,1378,15,47754,1378,25,47764],
[M,1377,21,47706,1377,24,47709],
[M,1377,34,47719,1377,38,47723],
[M,1377,47,47732,1377,51,47736],
[M,1377,2,47687,1379,5,47794],
[M,1375,15,47651,1375,40,47676],
[M,1375,26,47662,1375,39,47675],
[M,1375,15,47651,1375,25,47661],
[M,1374,21,47608,1374,24,47611],
[M,1374,36,47623,1374,46,47633],
[M,1374,2,47589,1376,5,47683],
[M,1372,13,47553,1372,38,47578],
[M,1372,24,47564,1372,37,47577],
[M,1372,13,47553,1372,23,47563],
[M,1371,19,47510,1371,22,47513],
[M,1371,34,47525,1371,46,47537],
[M,1371,2,47493,1373,5,47585],
[M,1369,16,47439,1369,32,47455],
[M,1369,16,47439,1369,26,47449],
[M,1368,22,47379,1368,25,47382],
[M,1368,35,47392,1368,39,47396],
[M,1368,51,47408,1368,63,47420],
[M,1368,2,47359,1370,5,47489],
[M,1366,16,47305,1366,32,47321],
[M,1366,16,47305,1366,26,47315],
[M,1365,22,47245,1365,25,47248],
[M,1365,35,47258,1365,39,47262],
[M,1365,51,47274,1365,63,47286],
[M,1365,2,47225,1367,5,47355],
[M,1363,16,47130,1363,39,47153],
[M,1363,25,47139,1363,38,47152],
[M,1363,16,47130,1363,24,47138],
[M,1356,11,46955,1356,14,46958],
[M,1357,14,46974,1357,24,46984],
[M,1358,13,47018,1358,16,47021],
[M,1359,13,47050,1359,19,47056],
[M,1360,14,47072,1360,18,47076],
[M,1361,16,47094,1362,4,47111],
[M,1354,2,46922,1364,5,47221],
[M,1352,13,46800,1352,38,46825],
[M,1352,24,46811,1352,37,46824],
[M,1352,13,46800,1352,23,46810],
[M,1344,11,46633,1344,14,46636],
[M,1345,16,46654,1345,26,46664],
[M,1346,14,46680,1346,24,46690],
[M,1347,13,46705,1347,16,46708],
[M,1348,13,46723,1348,19,46729],
[M,1349,14,46745,1349,18,46749],
[M,1350,16,46767,1351,4,46784],
[M,1342,2,46603,1353,5,46918],
[M,1339,15,46575,1339,31,46591],
[M,1339,15,46575,1339,25,46585],
[M,1338,21,46540,1338,24,46543],
[M,1338,34,46553,1338,38,46557],
[M,1338,2,46521,1340,5,46598],
[M,1335,24,46474,1335,40,46490],
[M,1335,24,46474,1335,34,46484],
[M,1334,26,46401,1334,29,46404],
[M,1334,37,46412,1334,43,46418],
[M,1334,53,46428,1334,57,46432],
[M,1334,68,46443,1334,72,46447],
[M,1334,2,46377,1336,5,46516],
[M,1331,16,46330,1331,32,46346],
[M,1331,16,46330,1331,26,46340],
[M,1330,18,46265,1330,21,46268],
[M,1330,29,46276,1330,35,46282],
[M,1330,45,46292,1330,49,46296],
[M,1330,60,46307,1330,64,46311],
[M,1330,2,46249,1332,5,46372],
[M,1327,13,46184,1327,29,46200],
[M,1327,13,46184,1327,23,46194],
[M,1326,19,46122,1326,22,46125],
[M,1326,32,46135,1326,36,46139],
[M,1326,44,46147,1326,48,46151],
[M,1326,61,46164,1326,65,46168],
[M,1326,2,46105,1328,5,46244],
[M,1323,20,46013,1323,35,46028],
[M,1323,20,46013,1323,29,46022],
[M,1322,26,45916,1322,29,45919],
[M,1322,38,45928,1322,41,45931],
[M,1322,50,45940,1322,54,45944],
[M,1322,68,45958,1322,85,45975],
[M,1322,96,45986,1322,100,45990],
[M,1322,2,45892,1324,5,46100],
[M,1320,15,45820,1320,30,45835],
[M,1320,15,45820,1320,24,45829],
[M,1319,21,45743,1319,24,45746],
[M,1319,33,45755,1319,36,45758],
[M,1319,45,45767,1319,49,45771],
[M,1319,63,45785,1319,80,45802],
[M,1319,2,45724,1321,5,45888],
[M,1316,28,45671,1316,51,45694],
[M,1316,37,45680,1316,50,45693],
[M,1316,28,45671,1316,36,45679],
[M,1315,28,45587,1315,31,45590],
[M,1315,41,45600,1315,47,45606],
[M,1315,57,45616,1315,67,45626],
[M,1315,77,45636,1315,81,45640],
[M,1315,2,45561,1317,5,45719],
[M,1312,22,45503,1312,49,45530],
[M,1312,35,45516,1312,48,45529],
[M,1312,22,45503,1312,34,45515],
[M,1311,28,45428,1311,31,45431],
[M,1311,45,45445,1311,63,45463],
[M,1311,74,45474,1311,78,45478],
[M,1311,2,45402,1313,5,45556],
[M,1309,17,45364,1309,44,45391],
[M,1309,30,45377,1309,43,45390],
[M,1309,17,45364,1309,29,45376],
[M,1308,23,45309,1308,26,45312],
[M,1308,40,45326,1308,58,45344],
[M,1308,2,45288,1310,5,45398],
[M,1305,17,45228,1305,44,45255],
[M,1305,30,45241,1305,43,45254],
[M,1305,17,45228,1305,29,45240],
[M,1304,23,45162,1304,26,45165],
[M,1304,40,45179,1304,54,45193],
[M,1304,65,45204,1304,69,45208],
[M,1304,2,45141,1306,5,45281],
[M,1302,12,45103,1302,39,45130],
[M,1302,25,45116,1302,38,45129],
[M,1302,12,45103,1302,24,45115],
[M,1301,18,45057,1301,21,45060],
[M,1301,35,45074,1301,49,45088],
[M,1301,2,45041,1303,5,45137],
[M,1298,24,44995,1298,40,45011],
[M,1298,24,44995,1298,34,45005],
[M,1297,30,44937,1297,33,44940],
[M,1297,43,44950,1297,47,44954],
[M,1297,57,44964,1297,61,44968],
[M,1297,2,44909,1299,5,45036],
[M,1294,19,44863,1294,35,44879],
[M,1294,19,44863,1294,29,44873],
[M,1293,25,44810,1293,28,44813],
[M,1293,38,44823,1293,42,44827],
[M,1293,52,44837,1293,56,44841],
[M,1293,2,44787,1295,5,44904],
[M,1290,16,44742,1290,30,44756],
[M,1290,16,44742,1290,24,44750],
[M,1289,22,44693,1289,25,44696],
[M,1289,33,44704,1289,37,44708],
[M,1289,48,44719,1289,52,44723],
[M,1289,2,44673,1291,5,44782],
[M,1286,18,44628,1286,34,44644],
[M,1286,18,44628,1286,28,44638],
[M,1285,2,44578,1287,5,44668],
[M,1282,14,44531,1282,30,44547],
[M,1282,14,44531,1282,24,44541],
[M,1281,20,44482,1281,23,44485],
[M,1281,33,44495,1281,37,44499],
[M,1281,48,44510,1281,52,44514],
[M,1281,2,44464,1283,5,44573],
[M,1278,15,44425,1278,42,44452],
[M,1278,28,44438,1278,41,44451],
[M,1278,15,44425,1278,27,44437],
[M,1277,21,44369,1277,24,44372],
[M,1277,38,44386,1277,59,44407],
[M,1277,2,44350,1279,5,44459],
[M,1274,13,44289,1274,29,44305],
[M,1274,13,44289,1274,23,44299],
[M,1273,19,44217,1273,22,44220],
[M,1273,32,44230,1273,36,44234],
[M,1273,47,44245,1273,51,44249],
[M,1273,68,44266,1273,75,44273],
[M,1273,2,44200,1275,5,44345],
[M,1270,13,44153,1270,29,44169],
[M,1270,13,44153,1270,23,44163],
[M,1269,19,44105,1269,22,44108],
[M,1269,32,44118,1269,36,44122],
[M,1269,47,44133,1269,51,44137],
[M,1269,2,44088,1271,5,44195],
[M,1266,17,44041,1266,33,44057],
[M,1266,17,44041,1266,27,44051],
[M,1265,23,43989,1265,26,43992],
[M,1265,36,44002,1265,40,44006],
[M,1265,51,44017,1265,55,44021],
[M,1265,2,43968,1267,5,44083],
[M,1262,14,43923,1262,30,43939],
[M,1262,14,43923,1262,24,43933],
[M,1261,20,43877,1261,23,43880],
[M,1261,33,43890,1261,37,43894],
[M,1261,46,43903,1261,49,43906],
[M,1261,2,43859,1263,5,43963],
[M,1258,27,43763,1258,50,43786],
[M,1258,36,43772,1258,49,43785],
[M,1258,27,43763,1258,35,43771],
[M,1257,2,43676,1259,5,43854],
[M,1254,20,43648,1254,36,43664],
[M,1254,20,43648,1254,30,43658],
[M,1253,26,43608,1253,29,43611],
[M,1253,39,43621,1253,43,43625],
[M,1253,2,43584,1255,5,43671],
[M,1250,15,43548,1250,39,43572],
[M,1250,25,43558,1250,38,43571],
[M,1250,15,43548,1250,24,43557],
[M,1249,2,43508,1251,5,43579],
[M,1246,21,43453,1246,37,43469],
[M,1246,21,43453,1246,31,43463],
[M,1245,27,43391,1245,30,43394],
[M,1245,40,43404,1245,44,43408],
[M,1245,56,43420,1245,65,43429],
[M,1245,2,43366,1247,5,43503],
[M,1242,25,43339,1242,40,43354],
[M,1242,25,43339,1242,34,43348],
[M,1241,24,43274,1241,27,43277],
[M,1241,38,43288,1241,48,43298],
[M,1241,57,43307,1241,61,43311],
[M,1241,2,43252,1243,5,43361],
[M,1238,16,43198,1238,40,43222],
[M,1238,26,43208,1238,39,43221],
[M,1238,16,43198,1238,25,43207],
[M,1237,2,43150,1239,5,43247],
[M,1234,21,43104,1234,37,43120],
[M,1234,21,43104,1234,31,43114],
[M,1233,2,43047,1235,5,43145],
[M,1230,18,42993,1230,42,43017],
[M,1230,28,43003,1230,41,43016],
[M,1230,18,42993,1230,27,43002],
[M,1229,2,42941,1231,5,43042],
[M,1226,23,42887,1226,47,42911],
[M,1226,33,42897,1226,46,42910],
[M,1226,23,42887,1226,32,42896],
[M,1225,2,42825,1227,5,42936],
[M,1222,22,42778,1222,38,42794],
[M,1222,22,42778,1222,32,42788],
[M,1221,2,42718,1223,5,42820],
[M,1218,19,42673,1218,35,42689],
[M,1218,19,42673,1218,29,42683],
[M,1217,2,42621,1219,5,42713],
[M,1214,18,42575,1214,34,42591],
[M,1214,18,42575,1214,28,42585],
[M,1213,2,42524,1215,5,42616],
[M,1211,18,42479,1211,34,42495],
[M,1211,18,42479,1211,28,42489],
[M,1210,2,42428,1212,5,42520],
[M,1207,23,42383,1207,39,42399],
[M,1207,23,42383,1207,33,42393],
[M,1206,2,42323,1208,5,42423],
[M,1202,2,42254,1204,5,42318],
[M,1199,2,42188,1201,5,42250],
[M,1197,23,42154,1197,46,42177],
[M,1197,32,42163,1197,45,42176],
[M,1197,23,42154,1197,31,42162],
[M,1196,2,42099,1198,5,42184],
[M,1193,2,42043,1195,5,42095],
[M,1190,2,41989,1192,5,42039],
[M,1188,17,41962,1188,33,41978],
[M,1188,17,41962,1188,27,41972],
[M,1187,2,41919,1189,5,41985],
[M,1185,23,41870,1185,48,41895],
[M,1185,34,41881,1185,47,41894],
[M,1185,23,41870,1185,33,41880],
[M,1184,2,41800,1186,5,41915],
[M,1182,35,41754,1182,51,41770],
[M,1182,35,41754,1182,45,41764],
[M,1181,2,41668,1183,5,41796],
[M,1178,2,41602,1180,5,41664],
[M,1175,2,41536,1177,5,41598],
[M,1173,16,41484,1173,39,41507],
[M,1173,16,41484,1173,33,41501],
[M,1172,2,41430,1174,5,41532],
[M,1169,17,41324,1169,37,41344],
[M,1169,17,41324,1169,31,41338],
[M,1168,2,41246,1170,5,41425],
[M,1165,16,41139,1165,34,41157],
[M,1165,16,41139,1165,28,41151],
[M,1164,2,41071,1166,5,41239],
[M,1160,2,41008,1162,5,41066],
[M,1156,2,40963,1158,5,41003],
[M,1152,2,40908,1154,5,40958],
[M,1148,2,40861,1150,5,40903],
[M,1144,2,40808,1146,5,40856],
[M,1137,2,40688,1142,5,40803],
[M,1138,4,40711,1141,7,40797],
[M,1140,6,40757,1140,38,40789],
[M,1140,24,40775,1140,37,40788],
[M,1140,24,40775,1140,31,40782],
[M,1139,6,40736,1139,20,40750],
[M,1129,0,40469,1134,3,40660],
[M,1130,2,40523,1133,5,40656],
[M,1131,4,40551,1131,46,40593],
[M,1129,28,40497,1129,35,40504],
[M,1122,0,40277,1127,3,40467],
[M,1123,2,40332,1126,5,40463],
[M,1124,4,40351,1124,58,40405],
[M,1124,35,40382,1124,57,40404],
[M,1124,35,40382,1124,44,40391],
[M,1122,19,40296,1122,36,40313],
[M,1104,0,39542,1120,3,40275],
[M,1111,2,39856,1119,5,40271],
[M,1118,14,40257,1118,22,40265],
[M,1116,4,40086,1117,113,40242],
[M,1117,6,40135,1117,21,40150],
[M,1117,24,40153,1117,113,40242],
[M,1117,42,40171,1117,65,40194],
[M,1117,69,40198,1117,112,40241],
[M,1117,85,40214,1117,110,40239],
[M,1117,85,40214,1117,97,40226],
[M,1115,4,40021,1115,64,40081],
[M,1115,38,40055,1115,63,40080],
[M,1115,38,40055,1115,50,40067],
[M,1114,4,39955,1114,65,40016],
[M,1114,49,40000,1114,64,40015],
[M,1114,42,39993,1114,65,40016],
[M,1113,4,39918,1113,36,39950],
[M,1113,31,39945,1113,35,39949],
[M,1113,24,39938,1113,36,39950],
[M,1112,4,39878,1112,39,39913],
[M,1112,34,39908,1112,38,39912],
[M,1112,27,39901,1112,39,39913],
[M,1105,2,39581,1110,5,39853],
[M,1106,4,39611,1109,7,39847],
[M,1108,6,39743,1108,102,39839],
[M,1108,50,39787,1108,65,39802],
[M,1108,43,39780,1108,102,39839],
[M,1107,6,39641,1107,101,39736],
[M,1107,47,39682,1107,63,39698],
[M,1107,40,39675,1107,101,39736],
[M,1097,0,39340,1102,3,39540],
[M,1098,2,39400,1101,5,39536],
[M,1099,4,39419,1099,63,39478],
[M,1099,35,39450,1099,62,39477],
[M,1099,35,39450,1099,44,39459],
[M,1097,24,39364,1097,41,39381],
[M,1088,0,39013,1095,3,39338],
[M,1089,2,39057,1094,5,39334],
[M,1092,4,39222,1092,90,39308],
[M,1092,73,39291,1092,88,39306],
[M,1092,40,39258,1092,90,39308],
[M,1091,4,39152,1091,69,39217],
[M,1091,28,39176,1091,69,39217],
[M,1090,4,39079,1090,72,39147],
[M,1090,31,39106,1090,72,39147],
[M,1082,0,38885,1086,3,39011],
[M,1083,24,38945,1083,32,38953],
[M,1083,2,38923,1085,5,39007],
[M,1082,29,38914,1082,33,38918],
[M,1080,0,38841,1080,42,38883],
[M,1067,2,38453,1073,7,38713],
[M,1066,0,38438,1078,3,38839],
[M,1067,4,38455,1067,49,38500],
[M,1067,17,38468,1067,20,38471],
[M,1067,30,38481,1067,36,38487],
[M,1067,45,38496,1067,48,38499],
[M,1070,9,38568,1070,29,38588],
[M,1070,20,38579,1070,28,38587],
[M,1069,4,38543,1073,7,38713],
[M,1068,4,38511,1068,30,38537],
[M,1067,38,38489,1067,48,38499],
[M,1067,22,38473,1067,36,38487],
[M,1067,12,38463,1067,20,38471],
[M,1075,2,38725,1077,5,38835],
[M,1076,25,38772,1076,81,38828],
[M,1076,64,38811,1076,76,38823],
[M,1076,64,38811,1076,74,38821],
[M,1076,4,38751,1076,15,38762],
[M,1057,2,38156,1059,70,38310],
[M,1054,2,37996,1056,76,38153],
[M,1047,2,37714,1053,7,37993],
[M,1041,2,37463,1046,7,37711],
[M,1038,2,37322,1040,47,37460],
[M,1029,2,36927,1037,7,37319],
[M,1026,2,36814,1028,42,36924],
[M,1023,2,36736,1025,31,36811],
[M,1020,2,36654,1022,31,36733],
[M,1019,0,36642,1064,3,38436],
[M,1026,4,36816,1026,32,36844],
[M,1026,16,36828,1026,19,36831],
[M,1026,27,36839,1026,31,36843],
[M,1029,4,36929,1029,75,37000],
[M,1029,17,36942,1029,20,36945],
[M,1029,30,36955,1029,39,36964],
[M,1029,48,36973,1029,51,36976],
[M,1029,67,36992,1029,74,36999],
[M,1038,4,37324,1038,53,37373],
[M,1038,18,37338,1038,21,37341],
[M,1038,31,37351,1038,40,37360],
[M,1038,49,37369,1038,52,37372],
[M,1041,4,37465,1041,46,37507],
[M,1041,18,37479,1041,21,37482],
[M,1041,33,37494,1041,45,37506],
[M,1047,4,37716,1047,50,37762],
[M,1047,15,37727,1047,18,37730],
[M,1047,27,37739,1047,30,37742],
[M,1047,40,37752,1047,49,37761],
[M,1054,4,37998,1054,45,38039],
[M,1054,16,38010,1054,19,38013],
[M,1054,28,38022,1054,31,38025],
[M,1054,40,38034,1054,44,38038],
[M,1057,4,38158,1057,49,38203],
[M,1057,15,38169,1057,18,38172],
[M,1057,27,38181,1057,31,38185],
[M,1057,42,38196,1057,48,38202],
[M,1059,20,38260,1059,39,38279],
[M,1059,20,38260,1059,37,38277],
[M,1059,20,38260,1059,28,38268],
[M,1059,4,38244,1059,70,38310],
[M,1058,4,38214,1058,28,38238],
[M,1057,33,38187,1057,48,38202],
[M,1057,20,38174,1057,31,38185],
[M,1057,10,38164,1057,18,38172],
[M,1056,20,38097,1056,39,38116],
[M,1056,20,38097,1056,37,38114],
[M,1056,20,38097,1056,28,38105],
[M,1056,4,38081,1056,76,38153],
[M,1055,4,38050,1055,29,38075],
[M,1054,33,38027,1054,44,38038],
[M,1054,21,38015,1054,31,38025],
[M,1054,11,38005,1054,19,38013],
[M,1050,15,37834,1050,34,37853],
[M,1050,15,37834,1050,32,37851],
[M,1050,15,37834,1050,23,37842],
[M,1050,6,37825,1050,14,37833],
[M,1049,4,37803,1053,7,37993],
[M,1048,4,37773,1048,28,37797],
[M,1047,32,37744,1047,49,37761],
[M,1047,20,37732,1047,30,37742],
[M,1047,10,37722,1047,18,37730],
[M,1044,38,37605,1044,60,37627],
[M,1044,50,37617,1044,59,37626],
[M,1044,38,37605,1044,47,37614],
[M,1044,6,37573,1044,26,37593],
[M,1043,4,37551,1046,7,37711],
[M,1042,4,37518,1042,31,37545],
[M,1041,23,37484,1041,45,37506],
[M,1041,13,37474,1041,21,37482],
[M,1040,4,37417,1040,47,37460],
[M,1040,20,37433,1040,26,37439],
[M,1039,4,37384,1039,31,37411],
[M,1038,42,37362,1038,52,37372],
[M,1038,23,37343,1038,40,37360],
[M,1038,13,37333,1038,21,37341],
[M,1033,42,37136,1033,69,37163],
[M,1033,56,37150,1033,68,37162],
[M,1033,42,37136,1033,55,37149],
[M,1033,42,37136,1033,51,37145],
[M,1033,27,37121,1033,40,37134],
[M,1033,15,37109,1033,26,37120],
[M,1033,8,37102,1033,71,37165],
[M,1032,12,37071,1032,23,37082],
[M,1031,4,37043,1037,7,37319],
[M,1030,4,37011,1030,30,37037],
[M,1029,53,36978,1029,74,36999],
[M,1029,41,36966,1029,51,36976],
[M,1029,22,36947,1029,39,36964],
[M,1029,12,36937,1029,20,36945],
[M,1028,4,36886,1028,42,36924],
[M,1028,20,36902,1028,36,36918],
[M,1028,20,36902,1028,27,36909],
[M,1027,4,36855,1027,29,36880],
[M,1026,21,36833,1026,31,36843],
[M,1026,11,36823,1026,19,36831],
[M,1025,4,36784,1025,31,36811],
[M,1024,4,36754,1024,28,36778],
[M,1022,4,36706,1022,31,36733],
[M,1021,4,36674,1021,30,36700],
[M,1061,2,38322,1063,5,38432],
[M,1062,25,38369,1062,81,38425],
[M,1062,64,38408,1062,76,38420],
[M,1062,64,38408,1062,74,38418],
[M,1062,4,38348,1062,15,38359],
[M,1004,2,36080,1012,7,36514],
[M,1003,0,36060,1017,3,36640],
[M,1004,4,36082,1004,78,36156],
[M,1004,24,36102,1004,27,36105],
[M,1004,37,36115,1004,43,36121],
[M,1004,53,36131,1004,63,36141],
[M,1004,73,36151,1004,77,36155],
[M,1008,24,36268,1008,41,36285],
[M,1008,31,36275,1008,40,36284],
[M,1008,17,36261,1008,23,36267],
[M,1008,8,36252,1008,16,36260],
[M,1007,6,36228,1007,13,36235],
[M,1006,4,36206,1012,7,36514],
[M,1005,4,36167,1005,37,36200],
[M,1004,65,36143,1004,77,36155],
[M,1004,45,36123,1004,63,36141],
[M,1004,29,36107,1004,43,36121],
[M,1004,19,36097,1004,27,36105],
[M,1014,2,36526,1016,5,36636],
[M,1015,25,36573,1015,81,36629],
[M,1015,64,36612,1015,76,36624],
[M,1015,64,36612,1015,74,36622],
[M,1015,4,36552,1015,15,36563],
[M,990,2,35641,996,7,35932],
[M,989,0,35620,1001,3,36058],
[M,990,4,35643,990,58,35697],
[M,990,26,35665,990,29,35668],
[M,990,39,35678,990,43,35682],
[M,990,53,35692,990,57,35696],
[M,994,18,35803,994,29,35814],
[M,994,10,35795,994,17,35802],
[M,992,4,35749,996,7,35932],
[M,991,4,35708,991,39,35743],
[M,990,45,35684,990,57,35696],
[M,990,31,35670,990,43,35682],
[M,990,21,35660,990,29,35668],
[M,998,2,35944,1000,5,36054],
[M,999,25,35991,999,81,36047],
[M,999,64,36030,999,76,36042],
[M,999,64,36030,999,74,36040],
[M,999,4,35970,999,15,35981],
[M,976,2,35234,982,7,35492],
[M,975,0,35217,987,3,35618],
[M,976,4,35236,976,53,35285],
[M,976,21,35253,976,24,35256],
[M,976,34,35266,976,38,35270],
[M,976,48,35280,976,52,35284],
[M,980,18,35379,980,29,35390],
[M,980,10,35371,980,17,35378],
[M,978,4,35332,982,7,35492],
[M,977,4,35296,977,34,35326],
[M,976,40,35272,976,52,35284],
[M,976,26,35258,976,38,35270],
[M,976,16,35248,976,24,35256],
[M,984,2,35504,986,5,35614],
[M,985,25,35551,985,81,35607],
[M,985,64,35590,985,76,35602],
[M,985,64,35590,985,74,35600],
[M,985,4,35530,985,15,35541],
[M,960,2,34847,968,7,35089],
[M,959,0,34827,973,3,35215],
[M,960,4,34849,964,7,34937],
[M,961,11,34884,961,14,34887],
[M,962,14,34903,962,20,34909],
[M,963,14,34925,963,18,34929],
[M,966,4,34995,968,7,35089],
[M,967,6,35017,967,12,35023],
[M,965,4,34948,965,45,34989],
[M,963,6,34917,963,18,34929],
[M,962,6,34895,962,20,34909],
[M,961,6,34879,961,14,34887],
[M,970,2,35101,972,5,35211],
[M,971,25,35148,971,81,35204],
[M,971,64,35187,971,76,35199],
[M,971,64,35187,971,74,35197],
[M,971,4,35127,971,15,35138],
[M,944,2,34433,952,7,34699],
[M,934,2,34146,943,7,34430],
[M,933,0,34122,957,3,34825],
[M,934,4,34148,939,5,34282],
[M,935,11,34179,935,14,34182],
[M,936,14,34198,936,20,34204],
[M,937,17,34223,937,36,34242],
[M,938,21,34265,938,32,34276],
[M,944,4,34435,948,5,34541],
[M,945,11,34476,945,14,34479],
[M,946,14,34495,946,20,34501],
[M,947,21,34524,947,32,34535],
[M,950,4,34605,952,7,34699],
[M,951,6,34627,951,12,34633],
[M,949,4,34552,949,51,34599],
[M,947,6,34509,947,32,34535],
[M,946,6,34487,946,20,34501],
[M,945,6,34471,945,14,34479],
[M,941,4,34336,943,7,34430],
[M,942,6,34358,942,12,34364],
[M,940,4,34293,940,41,34330],
[M,938,6,34250,938,32,34276],
[M,937,6,34212,937,36,34242],
[M,936,6,34190,936,20,34204],
[M,935,6,34174,935,14,34182],
[M,954,2,34711,956,5,34821],
[M,955,25,34758,955,81,34814],
[M,955,64,34797,955,76,34809],
[M,955,64,34797,955,74,34807],
[M,955,4,34737,955,15,34748],
[M,913,2,33501,926,7,33994],
[M,894,2,32812,912,7,33498],
[M,893,0,32796,931,3,34120],
[M,894,4,32814,900,5,32966],
[M,895,11,32836,895,14,32839],
[M,896,20,32861,896,23,32864],
[M,897,14,32880,897,20,32886],
[M,898,17,32905,898,36,32924],
[M,899,22,32948,900,4,32965],
[M,913,4,33503,917,5,33602],
[M,914,11,33535,914,14,33538],
[M,915,14,33554,915,20,33560],
[M,916,22,33584,917,4,33601],
[M,920,6,33679,920,39,33712],
[M,920,29,33702,920,38,33711],
[M,920,22,33695,920,28,33701],
[M,919,4,33657,926,7,33994],
[M,918,4,33613,918,42,33651],
[M,916,6,33568,917,4,33601],
[M,915,6,33546,915,20,33560],
[M,914,6,33530,914,14,33538],
[M,904,8,33057,904,25,33074],
[M,904,15,33064,904,24,33073],
[M,904,8,33057,904,14,33063],
[M,902,4,33011,912,7,33498],
[M,901,4,32977,901,32,33005],
[M,899,6,32932,900,4,32965],
[M,898,6,32894,898,36,32924],
[M,897,6,32872,897,20,32886],
[M,896,6,32847,896,23,32864],
[M,895,6,32831,895,14,32839],
[M,928,2,34006,930,5,34116],
[M,929,25,34053,929,81,34109],
[M,929,64,34092,929,76,34104],
[M,929,64,34092,929,74,34102],
[M,929,4,34032,929,15,34043],
[M,882,2,32460,886,7,32668],
[M,881,0,32438,891,3,32794],
[M,882,4,32462,882,78,32536],
[M,882,26,32484,882,29,32487],
[M,882,46,32504,882,63,32521],
[M,882,73,32531,882,77,32535],
[M,885,6,32610,885,33,32637],
[M,885,6,32610,885,31,32635],
[M,885,6,32610,885,22,32626],
[M,884,4,32588,886,7,32668],
[M,883,4,32547,883,39,32582],
[M,882,65,32523,882,77,32535],
[M,882,31,32489,882,63,32521],
[M,882,21,32479,882,29,32487],
[M,888,2,32680,890,5,32790],
[M,889,25,32727,889,81,32783],
[M,889,64,32766,889,76,32778],
[M,889,64,32766,889,74,32776],
[M,889,4,32706,889,15,32717],
[M,872,2,32216,874,42,32310],
[M,869,2,32118,871,41,32209],
[M,866,2,32032,868,33,32115],
[M,865,0,32006,879,3,32436],
[M,874,4,32272,874,42,32310],
[M,874,20,32288,874,26,32294],
[M,873,4,32238,873,32,32266],
[M,871,4,32172,871,41,32209],
[M,871,20,32188,871,26,32194],
[M,870,4,32139,870,31,32166],
[M,868,20,32102,868,29,32111],
[M,868,4,32086,868,33,32115],
[M,867,4,32053,867,31,32080],
[M,876,2,32322,878,5,32432],
[M,877,25,32369,877,81,32425],
[M,877,64,32408,877,76,32420],
[M,877,64,32408,877,74,32418],
[M,877,4,32348,877,15,32359],
[M,854,2,31662,858,7,31878],
[M,853,0,31646,863,3,32004],
[M,854,4,31664,854,53,31713],
[M,854,20,31680,854,23,31683],
[M,854,33,31693,854,37,31697],
[M,854,48,31708,854,52,31712],
[M,857,15,31790,857,35,31810],
[M,857,15,31790,857,33,31808],
[M,857,15,31790,857,24,31799],
[M,857,6,31781,857,14,31789],
[M,856,4,31759,858,7,31878],
[M,855,4,31724,855,33,31753],
[M,854,39,31699,854,52,31712],
[M,854,25,31685,854,37,31697],
[M,854,15,31675,854,23,31683],
[M,860,2,31890,862,5,32000],
[M,861,25,31937,861,81,31993],
[M,861,64,31976,861,76,31988],
[M,861,64,31976,861,74,31986],
[M,861,4,31916,861,15,31927],
[M,829,2,30998,846,7,31518],
[M,827,2,30888,828,35,30995],
[M,824,2,30614,826,156,30885],
[M,821,2,30411,823,103,30611],
[M,820,0,30396,851,3,31644],
[M,821,4,30413,821,55,30464],
[M,821,22,30431,821,25,30434],
[M,821,35,30444,821,39,30448],
[M,821,50,30459,821,54,30463],
[M,824,4,30616,824,70,30682],
[M,824,25,30637,824,28,30640],
[M,824,38,30650,824,42,30654],
[M,824,51,30663,824,54,30666],
[M,824,65,30677,824,69,30681],
[M,827,4,30890,827,67,30953],
[M,827,22,30908,827,25,30911],
[M,827,35,30921,827,39,30925],
[M,827,48,30934,827,51,30937],
[M,827,62,30948,827,66,30952],
[M,829,4,31000,837,5,31204],
[M,830,11,31027,830,14,31030],
[M,831,14,31046,831,18,31050],
[M,832,14,31066,832,24,31076],
[M,833,13,31110,833,16,31113],
[M,834,13,31142,834,19,31148],
[M,835,14,31164,835,18,31168],
[M,836,16,31186,837,4,31203],
[M,840,6,31278,843,9,31396],
[M,840,18,31290,843,9,31396],
[M,842,18,31366,842,36,31384],
[M,842,18,31366,842,27,31375],
[M,841,8,31321,841,34,31347],
[M,841,25,31338,841,31,31344],
[M,840,30,31302,840,39,31311],
[M,839,4,31256,846,7,31518],
[M,838,6,31217,838,39,31250],
[M,836,6,31176,837,4,31203],
[M,835,6,31156,835,18,31168],
[M,834,6,31135,834,19,31148],
[M,833,6,31103,833,16,31113],
[M,832,6,31058,832,24,31076],
[M,831,6,31038,831,18,31050],
[M,830,6,31022,830,14,31030],
[M,828,4,30964,828,35,30995],
[M,827,53,30939,827,66,30952],
[M,827,41,30927,827,51,30937],
[M,827,27,30913,827,39,30925],
[M,827,17,30903,827,25,30911],
[M,826,50,30779,826,70,30799],
[M,826,50,30779,826,68,30797],
[M,826,50,30779,826,59,30788],
[M,826,20,30749,826,27,30756],
[M,826,4,30733,826,155,30884],
[M,825,4,30693,825,38,30727],
[M,824,56,30668,824,69,30681],
[M,824,44,30656,824,54,30666],
[M,824,30,30642,824,42,30654],
[M,824,20,30632,824,28,30640],
[M,823,36,30544,823,56,30564],
[M,823,36,30544,823,54,30562],
[M,823,36,30544,823,45,30553],
[M,823,20,30528,823,27,30535],
[M,823,4,30512,823,102,30610],
[M,822,4,30475,822,35,30506],
[M,821,41,30450,821,54,30463],
[M,821,27,30436,821,39,30448],
[M,821,17,30426,821,25,30434],
[M,848,2,31530,850,5,31640],
[M,849,25,31577,849,81,31633],
[M,849,64,31616,849,76,31628],
[M,849,64,31616,849,74,31626],
[M,849,4,31556,849,15,31567],
[M,800,2,29744,813,29,30268],
[M,799,0,29731,818,3,30394],
[M,800,4,29746,800,64,29806],
[M,800,16,29758,800,19,29761],
[M,800,32,29774,800,39,29781],
[M,800,47,29789,800,51,29793],
[M,800,60,29802,800,63,29805],
[M,813,4,30243,813,29,30268],
[M,802,9,29842,802,19,29852],
[M,802,9,29842,802,29,29862],
[M,802,20,29853,802,28,29861],
[M,801,4,29817,812,7,30237],
[M,800,53,29795,800,63,29805],
[M,800,41,29783,800,51,29793],
[M,800,21,29763,800,39,29781],
[M,800,11,29753,800,19,29761],
[M,815,2,30280,817,5,30390],
[M,816,25,30327,816,81,30383],
[M,816,64,30366,816,76,30378],
[M,816,64,30366,816,74,30376],
[M,816,4,30306,816,15,30317],
[M,789,2,29494,791,38,29598],
[M,786,2,29388,788,33,29491],
[M,785,0,29362,796,3,29724],
[M,791,4,29564,791,38,29598],
[M,791,20,29580,791,26,29586],
[M,790,4,29523,790,39,29558],
[M,788,20,29478,788,29,29487],
[M,788,4,29462,788,33,29491],
[M,787,4,29419,787,41,29456],
[M,793,2,29610,795,5,29720],
[M,794,25,29657,794,81,29713],
[M,794,64,29696,794,76,29708],
[M,794,64,29696,794,74,29706],
[M,794,4,29636,794,15,29647],
[M,761,2,28632,778,7,29234],
[M,744,2,28015,760,7,28629],
[M,711,2,26546,743,7,28012],
[M,679,2,25148,710,7,26543],
[M,674,2,24892,678,7,25145],
[M,671,2,24695,673,100,24889],
[M,668,2,24506,670,102,24692],
[M,665,2,24390,667,46,24503],
[M,662,2,24269,664,48,24387],
[M,659,2,24101,661,79,24266],
[M,656,2,23990,658,41,24098],
[M,653,2,23867,655,48,23987],
[M,650,2,23755,652,43,23864],
[M,647,2,23601,649,56,23752],
[M,644,2,23470,646,56,23598],
[M,641,2,23361,643,42,23467],
[M,638,2,23237,640,41,23358],
[M,631,2,22965,637,7,23234],
[M,624,2,22702,630,7,22962],
[M,619,2,22503,623,7,22699],
[M,614,2,22298,618,7,22500],
[M,603,2,21787,613,7,22295],
[M,597,2,21525,602,7,21784],
[M,591,2,21280,596,7,21522],
[M,589,2,21180,590,32,21277],
[M,582,2,20857,588,7,21177],
[M,569,2,20492,581,7,20854],
[M,555,2,20086,568,7,20489],
[M,552,2,19956,554,55,20083],
[M,550,2,19729,551,150,19953],
[M,524,2,18696,549,7,19726],
[M,515,2,18289,523,7,18693],
[M,506,2,17772,514,7,18286],
[M,497,2,17339,505,7,17769],
[M,489,2,16947,496,7,17336],
[M,482,2,16681,488,7,16944],
[M,475,2,16270,481,7,16678],
[M,468,2,15957,474,7,16267],
[M,463,2,15730,467,7,15954],
[M,455,2,15469,462,7,15727],
[M,450,2,15264,454,7,15466],
[M,442,2,14992,449,7,15261],
[M,435,2,14675,441,7,14989],
[M,428,2,14425,434,7,14672],
[M,421,2,14159,427,7,14422],
[M,415,2,13921,420,7,14156],
[M,400,2,13489,414,7,13918],
[M,395,2,13306,399,7,13486],
[M,390,2,13140,394,7,13303],
[M,383,2,12837,389,7,13137],
[M,377,2,12584,382,7,12834],
[M,369,2,12208,376,7,12581],
[M,361,2,11842,368,7,12205],
[M,353,2,11452,360,7,11839],
[M,343,2,10799,352,7,11449],
[M,342,0,10786,783,3,29360],
[M,343,4,10801,343,95,10892],
[M,343,18,10815,343,21,10818],
[M,343,33,10830,343,37,10834],
[M,343,51,10848,343,55,10852],
[M,343,66,10863,343,78,10875],
[M,343,90,10887,343,94,10891],
[M,353,4,11454,353,71,11521],
[M,353,25,11475,353,28,11478],
[M,353,39,11489,353,56,11506],
[M,353,66,11516,353,70,11520],
[M,361,4,11844,361,62,11902],
[M,361,20,11860,361,23,11863],
[M,361,34,11874,361,47,11887],
[M,361,57,11897,361,61,11901],
[M,369,4,12210,369,63,12269],
[M,369,18,12224,369,21,12227],
[M,369,32,12238,369,48,12254],
[M,369,58,12264,369,62,12268],
[M,377,4,12586,377,58,12640],
[M,377,20,12602,377,23,12605],
[M,377,34,12616,377,44,12626],
[M,377,53,12635,377,57,12639],
[M,383,4,12839,383,62,12897],
[M,383,23,12858,383,26,12861],
[M,383,36,12871,383,40,12875],
[M,383,52,12887,383,61,12896],
[M,390,4,13142,390,42,13180],
[M,390,17,13155,390,20,13158],
[M,390,31,13169,390,41,13179],
[M,395,4,13308,395,40,13344],
[M,395,22,13326,395,25,13329],
[M,395,35,13339,395,39,13343],
[M,400,4,13491,409,5,13734],
[M,401,11,13509,401,14,13512],
[M,402,14,13528,402,20,13534],
[M,403,16,13552,403,26,13562],
[M,404,14,13596,404,24,13606],
[M,405,13,13640,405,16,13643],
[M,406,13,13672,406,19,13678],
[M,407,14,13694,407,18,13698],
[M,408,16,13716,409,4,13733],
[M,415,4,13923,415,46,13965],
[M,415,16,13935,415,19,13938],
[M,415,29,13948,415,33,13952],
[M,415,42,13961,415,45,13964],
[M,421,4,14161,421,52,14209],
[M,421,19,14176,421,22,14179],
[M,421,32,14189,421,36,14193],
[M,421,47,14204,421,51,14208],
[M,428,4,14427,428,48,14471],
[M,428,15,14438,428,18,14441],
[M,428,28,14451,428,32,14455],
[M,428,43,14466,428,47,14470],
[M,435,4,14677,435,72,14745],
[M,435,15,14688,435,18,14691],
[M,435,28,14701,435,32,14705],
[M,435,43,14716,435,47,14720],
[M,435,64,14737,435,71,14744],
[M,442,4,14994,442,56,15046],
[M,442,17,15007,442,20,15010],
[M,442,34,15024,442,55,15045],
[M,450,4,15266,450,50,15312],
[M,450,20,15282,450,23,15285],
[M,450,33,15295,450,37,15299],
[M,450,46,15308,450,49,15311],
[M,455,4,15471,455,49,15516],
[M,455,16,15483,455,19,15486],
[M,455,29,15496,455,33,15500],
[M,455,44,15511,455,48,15515],
[M,463,4,15732,463,49,15777],
[M,463,18,15746,463,21,15749],
[M,463,29,15757,463,33,15761],
[M,463,44,15772,463,48,15776],
[M,468,4,15959,468,55,16010],
[M,468,19,15974,468,22,15977],
[M,468,36,15991,468,54,16009],
[M,475,4,16272,475,75,16343],
[M,475,24,16292,475,27,16295],
[M,475,41,16309,475,59,16327],
[M,475,70,16338,475,74,16342],
[M,482,4,16683,482,46,16725],
[M,482,14,16693,482,17,16696],
[M,482,31,16710,482,45,16724],
[M,489,4,16949,489,66,17011],
[M,489,19,16964,489,22,16967],
[M,489,36,16981,489,50,16995],
[M,489,61,17006,489,65,17010],
[M,497,4,17341,497,77,17414],
[M,497,17,17354,497,20,17357],
[M,497,29,17366,497,32,17369],
[M,497,41,17378,497,45,17382],
[M,497,59,17396,497,76,17413],
[M,506,4,17774,506,97,17867],
[M,506,22,17792,506,25,17795],
[M,506,34,17804,506,37,17807],
[M,506,46,17816,506,50,17820],
[M,506,64,17834,506,81,17851],
[M,506,92,17862,506,96,17866],
[M,515,4,18291,515,62,18349],
[M,515,15,18302,515,18,18305],
[M,515,28,18315,515,32,18319],
[M,515,40,18327,515,44,18331],
[M,515,57,18344,515,61,18348],
[M,524,4,18698,524,61,18755],
[M,524,14,18708,524,17,18711],
[M,524,25,18719,524,31,18725],
[M,524,41,18735,524,45,18739],
[M,524,56,18750,524,60,18754],
[M,550,4,19731,550,69,19796],
[M,550,22,19749,550,25,19752],
[M,550,33,19760,550,39,19766],
[M,550,49,19776,550,53,19780],
[M,550,64,19791,550,68,19795],
[M,552,4,19958,552,35,19989],
[M,552,17,19971,552,20,19974],
[M,552,30,19984,552,34,19988],
[M,555,4,20088,563,5,20309],
[M,556,11,20106,556,14,20109],
[M,557,16,20127,557,26,20137],
[M,558,14,20171,558,24,20181],
[M,559,13,20215,559,16,20218],
[M,560,13,20247,560,19,20253],
[M,561,14,20269,561,18,20273],
[M,562,16,20291,563,4,20308],
[M,569,4,20494,576,5,20672],
[M,570,11,20515,570,14,20518],
[M,571,14,20534,571,24,20544],
[M,572,13,20578,572,16,20581],
[M,573,13,20610,573,19,20616],
[M,574,14,20632,574,18,20636],
[M,575,16,20654,576,4,20671],
[M,582,4,20859,582,60,20915],
[M,582,18,20873,582,21,20876],
[M,582,31,20886,582,35,20890],
[M,582,47,20902,582,59,20914],
[M,589,4,21182,589,60,21238],
[M,589,18,21196,589,21,21199],
[M,589,31,21209,589,35,21213],
[M,589,47,21225,589,59,21237],
[M,591,4,21282,591,43,21321],
[M,591,15,21293,591,18,21296],
[M,591,30,21308,591,42,21320],
[M,597,4,21527,597,43,21566],
[M,597,17,21540,597,20,21543],
[M,597,32,21555,597,42,21565],
[M,603,4,21789,603,99,21884],
[M,603,21,21806,603,24,21809],
[M,603,38,21823,603,55,21840],
[M,603,72,21857,603,76,21861],
[M,603,88,21873,603,98,21883],
[M,614,4,22300,614,50,22346],
[M,614,19,22315,614,22,22318],
[M,614,32,22328,614,36,22332],
[M,614,45,22341,614,49,22345],
[M,619,4,22505,619,48,22549],
[M,619,17,22518,619,20,22521],
[M,619,30,22531,619,34,22535],
[M,619,43,22544,619,47,22548],
[M,624,4,22704,624,53,22753],
[M,624,15,22715,624,18,22718],
[M,624,28,22728,624,32,22732],
[M,624,42,22742,624,52,22752],
[M,631,4,22967,631,60,23023],
[M,631,20,22983,631,23,22986],
[M,631,33,22996,631,39,23002],
[M,631,49,23012,631,59,23022],
[M,638,4,23239,638,40,23275],
[M,638,20,23255,638,23,23258],
[M,638,33,23268,638,39,23274],
[M,641,4,23363,641,30,23389],
[M,641,14,23373,641,17,23376],
[M,641,25,23384,641,29,23388],
[M,644,4,23472,644,34,23502],
[M,644,18,23486,644,21,23489],
[M,644,29,23497,644,33,23501],
[M,647,4,23603,647,54,23653],
[M,647,21,23620,647,24,23623],
[M,647,32,23631,647,36,23635],
[M,647,46,23645,647,53,23652],
[M,650,4,23757,650,25,23778],
[M,650,21,23774,650,24,23777],
[M,653,4,23869,653,34,23899],
[M,653,18,23883,653,21,23886],
[M,653,30,23895,653,33,23898],
[M,656,4,23992,656,32,24020],
[M,656,15,24003,656,18,24006],
[M,656,25,24013,656,31,24019],
[M,659,4,24103,659,50,24149],
[M,659,16,24115,659,19,24118],
[M,659,28,24127,659,34,24133],
[M,659,43,24142,659,49,24148],
[M,662,4,24271,662,34,24301],
[M,662,16,24283,662,19,24286],
[M,662,26,24293,662,33,24300],
[M,665,4,24392,665,32,24420],
[M,665,15,24403,665,18,24406],
[M,665,25,24413,665,31,24419],
[M,668,4,24508,668,49,24553],
[M,668,15,24519,668,18,24522],
[M,668,27,24531,668,31,24535],
[M,668,42,24546,668,48,24552],
[M,671,4,24697,671,54,24747],
[M,671,20,24713,671,23,24716],
[M,671,32,24725,671,36,24729],
[M,671,47,24740,671,53,24746],
[M,674,4,24894,674,51,24941],
[M,674,19,24909,674,22,24912],
[M,674,31,24921,674,35,24925],
[M,674,46,24936,674,50,24940],
[M,679,4,25150,687,7,25373],
[M,680,11,25169,680,14,25172],
[M,681,14,25188,681,20,25194],
[M,682,16,25212,682,26,25222],
[M,683,16,25254,683,26,25264],
[M,684,18,25284,684,31,25297],
[M,685,24,25323,685,36,25335],
[M,686,16,25353,687,6,25372],
[M,711,4,26548,720,5,26795],
[M,712,11,26572,712,14,26575],
[M,713,14,26591,713,20,26597],
[M,714,15,26614,714,19,26618],
[M,715,16,26636,715,26,26646],
[M,716,16,26678,716,26,26688],
[M,717,18,26708,717,31,26721],
[M,718,24,26747,718,36,26759],
[M,719,16,26777,720,4,26794],
[M,744,4,28017,750,5,28139],
[M,745,11,28035,745,14,28038],
[M,746,18,28058,746,22,28062],
[M,747,18,28082,747,31,28095],
[M,748,13,28110,748,16,28113],
[M,749,14,28129,749,18,28133],
[M,761,4,28634,766,5,28745],
[M,762,11,28654,762,14,28657],
[M,763,14,28673,763,28,28687],
[M,764,14,28703,764,18,28707],
[M,765,23,28732,765,30,28739],
[M,768,4,28790,778,7,29234],
[M,769,6,28812,777,9,29226],
[M,773,8,29008,776,42,29216],
[M,774,35,29082,774,51,29098],
[M,774,35,29082,774,41,29088],
[M,774,58,29105,774,77,29124],
[M,774,58,29105,774,64,29111],
[M,774,15,29062,774,33,29080],
[M,775,16,29145,775,31,29160],
[M,775,16,29145,775,25,29154],
[M,773,24,29024,773,35,29035],
[M,770,8,28845,772,42,28999],
[M,771,35,28913,771,49,28927],
[M,771,56,28934,771,73,28951],
[M,771,15,28893,771,33,28911],
[M,772,12,28969,772,32,28989],
[M,772,12,28969,772,30,28987],
[M,772,12,28969,772,21,28978],
[M,770,18,28855,770,29,28866],
[M,769,20,28826,769,29,28835],
[M,767,6,28758,767,32,28784],
[M,765,6,28715,765,30,28739],
[M,764,6,28695,764,18,28707],
[M,763,6,28665,763,28,28687],
[M,762,6,28649,762,14,28657],
[M,754,12,28242,754,36,28266],
[M,754,12,28242,754,34,28264],
[M,754,12,28242,754,25,28255],
[M,753,15,28213,753,23,28221],
[M,752,4,28182,760,7,28629],
[M,751,6,28152,751,30,28176],
[M,749,6,28121,749,18,28133],
[M,748,6,28103,748,16,28113],
[M,747,6,28070,747,31,28095],
[M,746,6,28046,746,22,28062],
[M,745,6,28030,745,14,28038],
[M,728,33,27080,728,44,27091],
[M,728,12,27059,728,32,27079],
[M,723,6,26866,727,9,27046],
[M,724,11,26913,724,32,26934],
[M,724,11,26913,724,23,26925],
[M,722,4,26844,743,7,28012],
[M,721,6,26808,721,36,26838],
[M,719,6,26767,720,4,26794],
[M,718,6,26729,718,36,26759],
[M,717,6,26696,717,31,26721],
[M,716,6,26668,716,26,26688],
[M,715,6,26626,715,26,26646],
[M,714,6,26605,714,19,26618],
[M,713,6,26583,713,20,26597],
[M,712,6,26567,712,14,26575],
[M,695,33,25651,695,44,25662],
[M,695,12,25630,695,32,25650],
[M,690,6,25437,694,9,25617],
[M,691,11,25484,691,32,25505],
[M,691,11,25484,691,23,25496],
[M,689,4,25415,710,7,26543],
[M,688,4,25384,688,29,25409],
[M,686,6,25343,687,6,25372],
[M,685,6,25305,685,36,25335],
[M,684,6,25272,684,31,25297],
[M,683,6,25244,683,26,25264],
[M,682,6,25202,682,26,25222],
[M,681,6,25180,681,20,25194],
[M,680,6,25164,680,14,25172],
[M,676,58,25040,676,77,25059],
[M,676,58,25040,676,75,25057],
[M,676,58,25040,676,66,25048],
[M,676,20,25002,676,34,25016],
[M,676,4,24986,678,7,25145],
[M,675,4,24952,675,32,24980],
[M,674,37,24927,674,50,24940],
[M,674,24,24914,674,35,24925],
[M,674,14,24904,674,22,24912],
[M,673,56,24845,673,75,24864],
[M,673,56,24845,673,73,24862],
[M,673,56,24845,673,64,24853],
[M,673,20,24809,673,34,24823],
[M,673,4,24793,673,100,24889],
[M,672,4,24758,672,33,24787],
[M,671,38,24731,671,53,24746],
[M,671,25,24718,671,36,24729],
[M,671,15,24708,671,23,24716],
[M,670,58,24648,670,77,24667],
[M,670,58,24648,670,75,24665],
[M,670,58,24648,670,66,24656],
[M,670,20,24610,670,34,24624],
[M,670,4,24594,670,102,24692],
[M,669,4,24564,669,28,24588],
[M,668,33,24537,668,48,24552],
[M,668,20,24524,668,31,24535],
[M,668,10,24514,668,18,24522],
[M,667,27,24484,667,41,24498],
[M,667,34,24491,667,40,24497],
[M,667,20,24477,667,26,24483],
[M,667,4,24461,667,46,24503],
[M,666,4,24431,666,28,24455],
[M,665,20,24408,665,31,24419],
[M,665,10,24398,665,18,24406],
[M,664,27,24366,664,43,24382],
[M,664,36,24375,664,42,24381],
[M,664,20,24359,664,26,24365],
[M,664,4,24343,664,48,24387],
[M,663,4,24312,663,29,24337],
[M,662,21,24288,662,33,24300],
[M,662,11,24278,662,19,24286],
[M,661,20,24207,661,39,24226],
[M,661,30,24217,661,38,24225],
[M,661,20,24207,661,29,24216],
[M,661,4,24191,661,79,24266],
[M,660,4,24160,660,29,24185],
[M,659,36,24135,659,49,24148],
[M,659,21,24120,659,34,24133],
[M,659,11,24110,659,19,24118],
[M,658,4,24061,658,41,24098],
[M,658,30,24087,658,36,24093],
[M,658,20,24077,658,29,24086],
[M,657,4,24031,657,28,24055],
[M,656,20,24008,656,31,24019],
[M,656,10,23998,656,18,24006],
[M,655,27,23966,655,43,23982],
[M,655,34,23973,655,42,23981],
[M,655,20,23959,655,26,23965],
[M,655,4,23943,655,48,23987],
[M,654,4,23910,654,31,23937],
[M,653,23,23888,653,33,23898],
[M,653,13,23878,653,21,23886],
[M,652,4,23825,652,43,23864],
[M,652,20,23841,652,26,23847],
[M,651,4,23789,651,34,23819],
[M,650,16,23769,650,24,23777],
[M,649,20,23716,649,31,23727],
[M,649,20,23716,649,26,23722],
[M,649,4,23700,649,56,23752],
[M,648,4,23664,648,34,23694],
[M,647,38,23637,647,53,23652],
[M,647,26,23625,647,36,23635],
[M,647,16,23615,647,24,23623],
[M,646,20,23562,646,31,23573],
[M,646,20,23562,646,26,23568],
[M,646,4,23546,646,56,23598],
[M,645,4,23513,645,31,23540],
[M,644,23,23491,644,33,23501],
[M,644,13,23481,644,21,23489],
[M,643,4,23429,643,42,23467],
[M,643,20,23445,643,36,23461],
[M,643,20,23445,643,27,23452],
[M,642,4,23400,642,27,23423],
[M,641,19,23378,641,29,23388],
[M,641,9,23368,641,17,23376],
[M,640,4,23321,640,41,23358],
[M,640,27,23344,640,36,23353],
[M,640,20,23337,640,26,23343],
[M,639,4,23286,639,33,23315],
[M,638,25,23260,638,39,23274],
[M,638,15,23250,638,23,23258],
[M,634,15,23100,634,32,23117],
[M,634,22,23107,634,31,23116],
[M,634,15,23100,634,21,23106],
[M,634,6,23091,634,14,23099],
[M,633,4,23069,637,7,23234],
[M,632,4,23034,632,33,23063],
[M,631,41,23004,631,59,23022],
[M,631,25,22988,631,39,23002],
[M,631,15,22978,631,23,22986],
[M,627,15,22825,627,35,22845],
[M,627,15,22825,627,33,22843],
[M,627,15,22825,627,24,22834],
[M,627,6,22816,627,14,22824],
[M,626,4,22794,630,7,22962],
[M,625,4,22764,625,28,22788],
[M,624,34,22734,624,52,22752],
[M,624,20,22720,624,32,22732],
[M,624,10,22710,624,18,22718],
[M,622,32,22640,622,52,22660],
[M,622,32,22640,622,50,22658],
[M,622,32,22640,622,41,22649],
[M,622,14,22622,622,82,22690],
[M,622,6,22614,622,13,22621],
[M,621,4,22592,623,7,22699],
[M,620,4,22560,620,30,22586],
[M,619,36,22537,619,47,22548],
[M,619,22,22523,619,34,22535],
[M,619,12,22513,619,20,22521],
[M,617,34,22441,617,54,22461],
[M,617,34,22441,617,52,22459],
[M,617,34,22441,617,43,22450],
[M,617,14,22421,617,84,22491],
[M,617,6,22413,617,13,22420],
[M,616,4,22391,618,7,22500],
[M,615,4,22357,615,32,22385],
[M,614,38,22334,614,49,22345],
[M,614,24,22320,614,36,22332],
[M,614,14,22310,614,22,22318],
[M,607,31,22003,607,43,22015],
[M,607,31,22003,607,40,22012],
[M,607,19,21991,607,30,22002],
[M,607,10,21982,607,18,21990],
[M,606,15,21962,606,24,21971],
[M,605,4,21931,613,7,22295],
[M,604,4,21895,604,34,21925],
[M,603,78,21863,603,98,21883],
[M,603,57,21842,603,76,21861],
[M,603,26,21811,603,55,21840],
[M,603,16,21801,603,24,21809],
[M,600,38,21663,600,61,21686],
[M,600,38,21663,600,44,21669],
[M,600,6,21631,600,26,21651],
[M,599,4,21609,602,7,21784],
[M,598,4,21577,598,30,21603],
[M,597,22,21545,597,42,21565],
[M,597,12,21535,597,20,21543],
[M,594,38,21416,594,60,21438],
[M,594,50,21428,594,59,21437],
[M,594,38,21416,594,47,21425],
[M,594,6,21384,594,26,21404],
[M,593,4,21362,596,7,21522],
[M,592,4,21332,592,28,21356],
[M,591,20,21298,591,42,21320],
[M,591,10,21288,591,18,21296],
[M,590,4,21249,590,31,21276],
[M,589,37,21215,589,59,21237],
[M,589,23,21201,589,35,21213],
[M,589,13,21191,589,21,21199],
[M,585,15,20990,585,35,21010],
[M,585,15,20990,585,33,21008],
[M,585,15,20990,585,24,20999],
[M,585,6,20981,585,14,20989],
[M,584,4,20959,588,7,21177],
[M,583,4,20926,583,31,20953],
[M,582,37,20892,582,59,20914],
[M,582,23,20878,582,35,20890],
[M,582,13,20868,582,21,20876],
[M,578,4,20716,581,7,20854],
[M,580,68,20834,580,79,20845],
[M,580,57,20823,580,66,20832],
[M,580,47,20813,580,55,20821],
[M,580,37,20803,580,45,20811],
[M,580,26,20792,580,35,20801],
[M,577,4,20683,577,31,20710],
[M,575,6,20644,576,4,20671],
[M,574,6,20624,574,18,20636],
[M,573,6,20603,573,19,20616],
[M,572,6,20571,572,16,20581],
[M,571,6,20526,571,24,20544],
[M,570,6,20510,570,14,20518],
[M,565,4,20350,568,7,20489],
[M,567,72,20469,567,83,20480],
[M,567,61,20458,567,70,20467],
[M,567,51,20448,567,59,20456],
[M,567,41,20438,567,49,20446],
[M,567,30,20427,567,39,20436],
[M,567,17,20414,567,28,20425],
[M,564,4,20320,564,28,20344],
[M,562,6,20281,563,4,20308],
[M,561,6,20261,561,18,20273],
[M,560,6,20240,560,19,20253],
[M,559,6,20208,559,16,20218],
[M,558,6,20163,558,24,20181],
[M,557,6,20117,557,26,20137],
[M,556,6,20101,556,14,20109],
[M,554,30,20058,554,50,20078],
[M,554,30,20058,554,48,20076],
[M,554,30,20058,554,39,20067],
[M,554,20,20048,554,29,20057],
[M,554,4,20032,554,55,20083],
[M,553,4,20000,553,30,20026],
[M,552,22,19976,552,34,19988],
[M,552,12,19966,552,20,19974],
[M,551,76,19879,551,98,19901],
[M,551,90,19893,551,97,19900],
[M,551,64,19867,551,71,19874],
[M,551,40,19843,551,46,19849],
[M,551,20,19823,551,28,19831],
[M,551,4,19807,551,150,19953],
[M,550,55,19782,550,68,19795],
[M,550,41,19768,550,53,19780],
[M,550,27,19754,550,39,19766],
[M,550,17,19744,550,25,19752],
[M,535,17,19096,535,49,19128],
[M,535,39,19118,535,48,19127],
[M,528,6,18863,534,9,19078],
[M,529,11,18906,529,18,18913],
[M,529,11,18906,529,48,18943],
[M,527,4,18841,549,7,19726],
[M,526,4,18812,526,27,18835],
[M,524,47,18741,524,60,18754],
[M,524,33,18727,524,45,18739],
[M,524,19,18713,524,31,18725],
[M,524,9,18703,524,17,18711],
[M,518,13,18419,519,59,18498],
[M,517,4,18390,523,7,18693],
[M,516,4,18360,516,28,18384],
[M,515,46,18333,515,61,18348],
[M,515,34,18321,515,44,18331],
[M,515,20,18307,515,32,18319],
[M,515,10,18297,515,18,18305],
[M,509,37,17968,509,56,17987],
[M,509,37,17968,509,54,17985],
[M,509,37,17968,509,45,17976],
[M,509,27,17958,509,36,17967],
[M,508,4,17915,514,7,18286],
[M,507,4,17878,507,35,17909],
[M,506,83,17853,506,96,17866],
[M,506,52,17822,506,81,17851],
[M,506,39,17809,506,50,17820],
[M,506,27,17797,506,37,17807],
[M,506,17,17787,506,25,17795],
[M,500,37,17510,500,56,17529],
[M,500,37,17510,500,54,17527],
[M,500,37,17510,500,45,17518],
[M,500,27,17500,500,36,17509],
[M,499,4,17457,505,7,17769],
[M,498,4,17425,498,30,17451],
[M,497,47,17384,497,76,17413],
[M,497,34,17371,497,45,17382],
[M,497,22,17359,497,32,17369],
[M,497,12,17349,497,20,17357],
[M,492,29,17101,492,55,17127],
[M,492,17,17089,492,28,17100],
[M,491,4,17056,496,7,17336],
[M,490,4,17022,490,32,17050],
[M,489,52,16997,489,65,17010],
[M,489,24,16969,489,50,16995],
[M,489,14,16959,489,22,16967],
[M,485,29,16810,485,55,16836],
[M,485,17,16798,485,28,16809],
[M,484,4,16765,488,7,16944],
[M,483,4,16736,483,27,16759],
[M,482,19,16698,482,45,16724],
[M,482,9,16688,482,17,16696],
[M,478,36,16445,478,89,16498],
[M,478,54,16463,478,88,16497],
[M,478,71,16480,478,83,16492],
[M,478,71,16480,478,81,16490],
[M,478,62,16471,478,70,16479],
[M,478,36,16445,478,53,16462],
[M,478,36,16445,478,49,16458],
[M,478,13,16422,478,24,16433],
[M,477,4,16393,481,7,16678],
[M,476,4,16354,476,37,16387],
[M,475,61,16329,475,74,16342],
[M,475,29,16297,475,59,16327],
[M,475,19,16287,475,27,16295],
[M,471,38,16109,471,73,16144],
[M,471,6,16077,471,26,16097],
[M,470,4,16055,474,7,16267],
[M,469,4,16021,469,32,16049],
[M,468,24,15979,468,54,16009],
[M,468,14,15969,468,22,15977],
[M,466,31,15868,466,49,15886],
[M,466,31,15868,466,47,15884],
[M,466,31,15868,466,38,15875],
[M,466,15,15852,466,22,15859],
[M,466,6,15843,466,14,15851],
[M,465,4,15821,467,7,15954],
[M,464,4,15788,464,31,15815],
[M,463,35,15763,463,48,15776],
[M,463,23,15751,463,33,15761],
[M,463,13,15741,463,21,15749],
[M,459,29,15637,459,49,15657],
[M,459,29,15637,459,47,15655],
[M,459,29,15637,459,38,15646],
[M,459,19,15627,459,28,15636],
[M,458,6,15580,458,22,15596],
[M,457,4,15558,462,7,15727],
[M,456,4,15527,456,29,15552],
[M,455,35,15502,455,48,15515],
[M,455,21,15488,455,33,15500],
[M,455,11,15478,455,19,15486],
[M,453,42,15416,453,62,15436],
[M,453,42,15416,453,60,15434],
[M,453,42,15416,453,51,15425],
[M,453,6,15380,453,14,15388],
[M,452,4,15358,454,7,15466],
[M,451,4,15323,451,33,15352],
[M,450,39,15301,450,49,15311],
[M,450,25,15287,450,37,15299],
[M,450,15,15277,450,23,15285],
[M,447,8,15182,447,61,15235],
[M,447,47,15221,447,60,15234],
[M,447,33,15207,447,45,15219],
[M,447,20,15194,447,31,15205],
[M,447,8,15182,447,19,15193],
[M,445,6,15111,445,22,15127],
[M,444,4,15089,449,7,15261],
[M,443,4,15057,443,30,15083],
[M,442,22,15012,442,55,15045],
[M,442,12,15002,442,20,15010],
[M,439,31,14864,439,38,14871],
[M,439,45,14878,439,54,14887],
[M,439,13,14846,439,29,14862],
[M,440,14,14906,440,34,14926],
[M,440,14,14906,440,32,14924],
[M,440,14,14906,440,23,14915],
[M,438,15,14817,438,22,14824],
[M,438,6,14808,438,14,14816],
[M,437,4,14786,441,7,14989],
[M,436,4,14756,436,28,14780],
[M,435,49,14722,435,71,14744],
[M,435,34,14707,435,47,14720],
[M,435,20,14693,435,32,14705],
[M,435,10,14683,435,18,14691],
[M,432,35,14577,432,55,14597],
[M,432,35,14577,432,53,14595],
[M,432,35,14577,432,44,14586],
[M,432,19,14561,432,26,14568],
[M,432,10,14552,432,18,14560],
[M,430,4,14512,434,7,14672],
[M,429,4,14482,429,28,14506],
[M,428,34,14457,428,47,14470],
[M,428,20,14443,428,32,14455],
[M,428,10,14433,428,18,14441],
[M,424,45,14315,424,65,14335],
[M,424,45,14315,424,63,14333],
[M,424,45,14315,424,54,14324],
[M,424,15,14285,424,22,14292],
[M,424,6,14276,424,14,14284],
[M,423,4,14254,427,7,14422],
[M,422,4,14220,422,32,14248],
[M,421,38,14195,421,51,14208],
[M,421,24,14181,421,36,14193],
[M,421,14,14171,421,22,14179],
[M,419,21,14075,419,41,14095],
[M,419,21,14075,419,39,14093],
[M,419,21,14075,419,30,14084],
[M,418,15,14038,418,22,14045],
[M,418,6,14029,418,14,14037],
[M,417,4,14007,420,7,14156],
[M,416,4,13976,416,29,14001],
[M,415,35,13954,415,45,13964],
[M,415,21,13940,415,33,13952],
[M,415,11,13930,415,19,13938],
[M,411,4,13777,414,7,13918],
[M,413,74,13898,413,85,13909],
[M,413,63,13887,413,72,13896],
[M,413,53,13877,413,61,13885],
[M,413,43,13867,413,51,13875],
[M,413,32,13856,413,41,13865],
[M,413,19,13843,413,30,13854],
[M,413,8,13832,413,17,13841],
[M,410,6,13747,410,30,13771],
[M,408,6,13706,409,4,13733],
[M,407,6,13686,407,18,13698],
[M,406,6,13665,406,19,13678],
[M,405,6,13633,405,16,13643],
[M,404,6,13588,404,24,13606],
[M,403,6,13542,403,26,13562],
[M,402,6,13520,402,20,13534],
[M,401,6,13504,401,14,13512],
[M,398,40,13448,398,60,13468],
[M,398,40,13448,398,58,13466],
[M,398,40,13448,398,49,13457],
[M,398,6,13414,398,17,13425],
[M,397,4,13392,399,7,13486],
[M,396,4,13355,396,35,13386],
[M,395,27,13331,395,39,13343],
[M,395,17,13321,395,25,13329],
[M,392,4,13223,394,7,13303],
[M,393,45,13284,393,55,13294],
[M,393,31,13270,393,43,13282],
[M,393,18,13257,393,29,13268],
[M,393,6,13245,393,17,13256],
[M,391,4,13191,391,30,13217],
[M,390,22,13160,390,41,13179],
[M,390,12,13150,390,20,13158],
[M,386,15,12977,386,35,12997],
[M,386,15,12977,386,33,12995],
[M,386,15,12977,386,24,12986],
[M,386,6,12968,386,14,12976],
[M,385,4,12946,389,7,13137],
[M,384,4,12908,384,36,12940],
[M,383,42,12877,383,61,12896],
[M,383,28,12863,383,40,12875],
[M,383,18,12853,383,26,12861],
[M,380,6,12708,380,82,12784],
[M,380,71,12773,380,81,12783],
[M,380,31,12733,380,69,12771],
[M,380,53,12755,380,65,12767],
[M,380,53,12755,380,63,12765],
[M,380,18,12720,380,29,12731],
[M,380,6,12708,380,17,12719],
[M,379,4,12686,382,7,12834],
[M,378,4,12651,378,33,12680],
[M,377,46,12628,377,57,12639],
[M,377,25,12607,377,44,12626],
[M,377,15,12597,377,23,12605],
[M,372,36,12365,372,47,12376],
[M,372,15,12344,372,35,12364],
[M,371,4,12313,376,7,12581],
[M,370,4,12280,370,31,12307],
[M,369,50,12256,369,62,12268],
[M,369,23,12229,369,48,12254],
[M,369,13,12219,369,21,12227],
[M,364,36,11995,364,47,12006],
[M,364,15,11974,364,35,11994],
[M,363,4,11943,368,7,12205],
[M,362,4,11913,362,28,11937],
[M,361,49,11889,361,61,11901],
[M,361,25,11865,361,47,11887],
[M,361,15,11855,361,23,11863],
[M,356,36,11619,356,47,11630],
[M,356,15,11598,356,35,11618],
[M,355,4,11567,360,7,11839],
[M,354,4,11532,354,33,11561],
[M,353,58,11508,353,70,11520],
[M,353,30,11480,353,56,11506],
[M,353,20,11470,353,28,11478],
[M,346,6,10958,346,22,10974],
[M,346,6,10958,346,12,10964],
[M,345,4,10936,352,7,11449],
[M,344,4,10903,344,31,10930],
[M,343,80,10877,343,94,10891],
[M,343,57,10854,343,78,10875],
[M,343,39,10836,343,55,10852],
[M,343,23,10820,343,37,10834],
[M,343,13,10810,343,21,10818],
[M,780,2,29246,782,5,29356],
[M,781,25,29293,781,81,29349],
[M,781,64,29332,781,76,29344],
[M,781,64,29332,781,74,29342],
[M,781,4,29272,781,15,29283],
[M,328,2,10384,334,7,10657],
[M,323,2,10157,327,7,10381],
[M,322,0,10137,339,3,10783],
[M,323,4,10159,323,51,10206],
[M,323,21,10176,323,24,10179],
[M,323,34,10189,323,38,10193],
[M,323,47,10202,323,50,10205],
[M,328,4,10386,328,57,10439],
[M,328,24,10406,328,27,10409],
[M,328,37,10419,328,41,10423],
[M,328,52,10434,328,56,10438],
[M,331,45,10550,331,65,10570],
[M,331,45,10550,331,63,10568],
[M,331,45,10550,331,54,10559],
[M,331,15,10520,331,22,10527],
[M,331,6,10511,331,14,10519],
[M,330,4,10489,334,7,10657],
[M,329,4,10450,329,37,10483],
[M,328,43,10425,328,56,10438],
[M,328,29,10411,328,41,10423],
[M,328,19,10401,328,27,10409],
[M,326,31,10300,326,51,10320],
[M,326,31,10300,326,49,10318],
[M,326,31,10300,326,40,10309],
[M,326,15,10284,326,22,10291],
[M,326,6,10275,326,14,10283],
[M,325,4,10253,327,7,10381],
[M,324,4,10217,324,34,10247],
[M,323,40,10195,323,50,10205],
[M,323,26,10181,323,38,10193],
[M,323,16,10171,323,24,10179],
[M,336,2,10669,338,5,10779],
[M,337,25,10716,337,81,10772],
[M,337,64,10755,337,76,10767],
[M,337,64,10755,337,74,10765],
[M,337,4,10695,337,15,10706],
[M,312,2,9820,315,7,10009],
[M,311,0,9801,320,3,10135],
[M,312,4,9822,312,53,9871],
[M,312,23,9841,312,26,9844],
[M,312,33,9851,312,37,9855],
[M,312,48,9866,312,52,9870],
[M,314,31,9929,314,48,9946],
[M,314,31,9929,314,46,9944],
[M,314,31,9929,314,37,9935],
[M,314,15,9913,314,22,9920],
[M,314,6,9904,314,14,9912],
[M,313,4,9882,315,7,10009],
[M,312,39,9857,312,52,9870],
[M,312,28,9846,312,37,9855],
[M,312,18,9836,312,26,9844],
[M,317,2,10021,319,5,10131],
[M,318,25,10068,318,81,10124],
[M,318,64,10107,318,76,10119],
[M,318,64,10107,318,74,10117],
[M,318,4,10047,318,15,10058],
[M,301,2,9470,304,7,9673],
[M,297,2,9281,300,7,9467],
[M,296,0,9265,309,3,9799],
[M,297,4,9283,297,50,9329],
[M,297,20,9299,297,23,9302],
[M,297,30,9309,297,34,9313],
[M,297,45,9324,297,49,9328],
[M,301,4,9472,301,50,9518],
[M,301,20,9488,301,23,9491],
[M,301,30,9498,301,34,9502],
[M,301,45,9513,301,49,9517],
[M,303,31,9576,303,45,9590],
[M,303,31,9576,303,37,9582],
[M,303,15,9560,303,22,9567],
[M,303,6,9551,303,14,9559],
[M,302,4,9529,304,7,9673],
[M,301,36,9504,301,49,9517],
[M,301,25,9493,301,34,9502],
[M,301,15,9483,301,23,9491],
[M,299,31,9387,299,48,9404],
[M,299,31,9387,299,46,9402],
[M,299,31,9387,299,37,9393],
[M,299,15,9371,299,22,9378],
[M,299,6,9362,299,14,9370],
[M,298,4,9340,300,7,9467],
[M,297,36,9315,297,49,9328],
[M,297,25,9304,297,34,9313],
[M,297,15,9294,297,23,9302],
[M,306,2,9685,308,5,9795],
[M,307,25,9732,307,81,9788],
[M,307,64,9771,307,76,9783],
[M,307,64,9771,307,74,9781],
[M,307,4,9711,307,15,9722],
[M,288,2,9036,289,73,9137],
[M,287,0,9023,294,3,9263],
[M,288,4,9038,288,23,9057],
[M,288,19,9053,288,22,9056],
[M,289,51,9115,289,67,9131],
[M,289,60,9124,289,66,9130],
[M,289,44,9108,289,50,9114],
[M,289,34,9098,289,43,9107],
[M,289,4,9068,289,73,9137],
[M,288,14,9048,288,22,9056],
[M,291,2,9149,293,5,9259],
[M,292,25,9196,292,81,9252],
[M,292,64,9235,292,76,9247],
[M,292,64,9235,292,74,9245],
[M,292,4,9175,292,15,9186],
[M,278,2,8768,280,40,8895],
[M,275,2,8630,277,49,8765],
[M,274,0,8611,285,3,9021],
[M,275,4,8632,275,43,8671],
[M,275,23,8651,275,26,8654],
[M,275,36,8664,275,42,8670],
[M,278,4,8770,278,43,8809],
[M,278,24,8790,278,27,8793],
[M,278,36,8802,278,42,8808],
[M,280,4,8859,280,40,8895],
[M,280,27,8882,280,35,8890],
[M,280,20,8875,280,26,8881],
[M,279,4,8820,279,37,8853],
[M,278,29,8795,278,42,8808],
[M,278,19,8785,278,27,8793],
[M,277,27,8743,277,44,8760],
[M,277,34,8750,277,43,8759],
[M,277,20,8736,277,26,8742],
[M,277,4,8720,277,49,8765],
[M,276,4,8682,276,36,8714],
[M,275,28,8656,275,42,8670],
[M,275,18,8646,275,26,8654],
[M,282,2,8907,284,5,9017],
[M,283,25,8954,283,81,9010],
[M,283,64,8993,283,76,9005],
[M,283,64,8993,283,74,9003],
[M,283,4,8933,283,15,8944],
[M,264,2,8361,266,33,8478],
[M,261,2,8230,263,46,8358],
[M,254,2,7900,260,7,8227],
[M,253,0,7879,271,3,8604],
[M,254,4,7902,254,50,7948],
[M,254,25,7923,254,28,7926],
[M,254,37,7935,254,49,7947],
[M,261,4,8232,261,33,8261],
[M,261,29,8257,261,32,8260],
[M,264,4,8363,264,34,8393],
[M,264,30,8389,264,33,8392],
[M,266,20,8465,266,29,8474],
[M,266,4,8449,266,33,8478],
[M,265,4,8404,265,43,8443],
[M,264,25,8384,264,33,8392],
[M,263,4,8316,263,46,8358],
[M,262,4,8272,262,42,8310],
[M,261,24,8252,261,32,8260],
[M,257,38,8052,257,92,8106],
[M,257,6,8020,257,26,8040],
[M,256,4,7998,260,7,8227],
[M,255,4,7959,255,37,7992],
[M,254,30,7928,254,49,7947],
[M,254,20,7918,254,28,7926],
[M,268,2,8490,270,5,8600],
[M,269,25,8537,269,81,8593],
[M,269,64,8576,269,76,8588],
[M,269,64,8576,269,74,8586],
[M,269,4,8516,269,15,8527],
[M,244,2,7646,246,33,7751],
[M,241,2,7533,243,40,7643],
[M,235,2,7339,240,7,7530],
[M,234,0,7323,251,3,7877],
[M,235,4,7341,235,38,7375],
[M,235,19,7356,235,22,7359],
[M,235,33,7370,235,37,7374],
[M,241,4,7535,241,27,7558],
[M,241,23,7554,241,26,7557],
[M,244,4,7648,244,28,7672],
[M,244,24,7668,244,27,7671],
[M,246,20,7738,246,29,7747],
[M,246,4,7722,246,33,7751],
[M,245,4,7683,245,37,7716],
[M,244,19,7663,244,27,7671],
[M,243,4,7607,243,40,7643],
[M,242,4,7569,242,36,7601],
[M,241,18,7549,241,26,7557],
[M,239,8,7491,239,29,7512],
[M,239,8,7491,239,27,7510],
[M,239,8,7491,239,18,7501],
[M,238,6,7442,238,22,7458],
[M,237,4,7420,240,7,7530],
[M,236,4,7386,236,32,7414],
[M,235,24,7361,235,37,7374],
[M,235,14,7351,235,22,7359],
[M,248,2,7763,250,5,7873],
[M,249,25,7810,249,81,7866],
[M,249,64,7849,249,76,7861],
[M,249,64,7849,249,74,7859],
[M,249,4,7789,249,15,7800],
[M,221,2,6911,227,7,7195],
[M,216,2,6641,220,7,6908],
[M,211,2,6431,215,7,6638],
[M,210,0,6416,232,3,7321],
[M,211,4,6433,211,56,6485],
[M,211,18,6447,211,21,6450],
[M,211,31,6460,211,41,6470],
[M,211,51,6480,211,55,6484],
[M,216,4,6643,216,77,6716],
[M,216,24,6663,216,27,6666],
[M,216,37,6676,216,47,6686],
[M,216,57,6696,216,61,6700],
[M,216,72,6711,216,76,6715],
[M,221,4,6913,221,71,6980],
[M,221,25,6934,221,28,6937],
[M,221,40,6949,221,50,6959],
[M,221,60,6969,221,70,6979],
[M,225,10,7090,225,63,7143],
[M,225,51,7131,225,62,7142],
[M,225,37,7117,225,49,7129],
[M,225,22,7102,225,35,7115],
[M,225,10,7090,225,21,7101],
[M,224,14,7061,226,41,7186],
[M,224,6,7053,224,13,7060],
[M,223,4,7031,227,7,7195],
[M,222,4,6991,222,38,7025],
[M,221,52,6961,221,70,6979],
[M,221,30,6939,221,50,6959],
[M,221,20,6929,221,28,6937],
[M,219,33,6815,219,53,6835],
[M,219,33,6815,219,51,6833],
[M,219,33,6815,219,42,6824],
[M,219,14,6796,219,117,6899],
[M,219,6,6788,219,13,6795],
[M,218,4,6766,220,7,6908],
[M,217,4,6727,217,37,6760],
[M,216,63,6702,216,76,6715],
[M,216,49,6688,216,61,6700],
[M,216,29,6668,216,47,6686],
[M,216,19,6658,216,27,6666],
[M,214,33,6578,214,53,6598],
[M,214,33,6578,214,51,6596],
[M,214,33,6578,214,42,6587],
[M,214,14,6559,214,84,6629],
[M,214,6,6551,214,13,6558],
[M,213,4,6529,215,7,6638],
[M,212,4,6496,212,31,6523],
[M,211,43,6472,211,55,6484],
[M,211,23,6452,211,41,6470],
[M,211,13,6442,211,21,6450],
[M,229,2,7207,231,5,7317],
[M,230,25,7254,230,81,7310],
[M,230,64,7293,230,76,7305],
[M,230,64,7293,230,74,7303],
[M,230,4,7233,230,15,7244],
[M,192,2,5872,203,7,6288],
[M,191,0,5856,208,3,6414],
[M,192,4,5874,192,116,5986],
[M,192,19,5889,192,22,5892],
[M,192,36,5906,192,43,5913],
[M,192,63,5933,192,75,5945],
[M,192,88,5958,192,100,5970],
[M,192,111,5981,192,115,5985],
[M,198,12,6109,198,36,6133],
[M,198,12,6109,198,34,6131],
[M,198,12,6109,198,25,6122],
[M,197,10,6090,199,43,6178],
[M,196,8,6071,196,15,6078],
[M,195,6,6053,195,14,6061],
[M,194,4,6031,203,7,6288],
[M,193,4,5997,193,32,6025],
[M,192,102,5972,192,115,5985],
[M,192,77,5947,192,100,5970],
[M,192,45,5915,192,75,5945],
[M,192,24,5894,192,43,5913],
[M,192,14,5884,192,22,5892],
[M,205,2,6300,207,5,6410],
[M,206,25,6347,206,81,6403],
[M,206,64,6386,206,76,6398],
[M,206,64,6386,206,74,6396],
[M,206,4,6326,206,15,6337],
[M,155,0,4601,189,3,5854],
[M,158,7,4770,158,25,4788],
[M,155,51,4652,155,61,4662],
[M,156,11,4675,156,14,4678],
[M,156,23,4687,156,29,4693],
[M,156,39,4703,156,43,4707],
[M,156,55,4719,156,67,4731],
[M,2495,41,79476,2495,56,79491],
[M,2495,41,79476,2495,50,79485],
[M,2489,39,79310,2489,54,79325],
[M,2489,39,79310,2489,48,79319],
[M,2486,38,79210,2486,61,79233],
[M,2486,47,79219,2486,60,79232],
[M,2486,38,79210,2486,46,79218],
[M,2480,49,79032,2480,64,79047],
[M,2480,49,79032,2480,58,79041],
[M,2477,48,78915,2477,63,78930],
[M,2477,48,78915,2477,57,78924],
[M,2454,68,78288,2454,91,78311],
[M,2454,68,78288,2454,85,78305],
[M,2437,70,77834,2437,101,77865],
[M,2437,87,77851,2437,100,77864],
[M,2437,70,77834,2437,86,77850],
[M,2424,44,77413,2424,61,77430],
[M,2424,44,77413,2424,55,77424],
[M,2416,8,77210,2416,23,77225],
[M,2416,8,77210,2416,17,77219],
[M,2418,8,77248,2418,24,77264],
[M,2418,8,77248,2418,18,77258],
[M,2419,8,77274,2419,27,77293],
[M,2419,8,77274,2419,19,77285],
[M,2400,46,76853,2400,61,76868],
[M,2400,46,76853,2400,55,76862],
[M,2400,63,76870,2400,80,76887],
[M,2400,63,76870,2400,74,76881],
[M,2397,49,76691,2397,64,76706],
[M,2397,49,76691,2397,58,76700],
[M,2397,66,76708,2397,83,76725],
[M,2397,66,76708,2397,77,76719],
[M,2394,46,76540,2394,63,76557],
[M,2394,46,76540,2394,57,76551],
[M,2387,43,76201,2387,70,76228],
[M,2387,56,76214,2387,69,76227],
[M,2387,43,76201,2387,55,76213],
[M,2387,72,76230,2387,87,76245],
[M,2387,72,76230,2387,81,76239],
[M,2387,89,76247,2387,105,76263],
[M,2387,89,76247,2387,99,76257],
[M,2372,8,75835,2372,33,75860],
[M,2372,19,75846,2372,32,75859],
[M,2372,8,75835,2372,18,75845],
[M,2373,8,75870,2373,33,75895],
[M,2373,19,75881,2373,32,75894],
[M,2373,8,75870,2373,18,75880],
[M,2374,8,75905,2374,35,75932],
[M,2374,21,75918,2374,34,75931],
[M,2374,8,75905,2374,20,75917],
[M,2375,8,75942,2375,41,75975],
[M,2375,27,75961,2375,40,75974],
[M,2375,8,75942,2375,26,75960],
[M,2376,8,75985,2376,27,76004],
[M,2376,8,75985,2376,19,75996],
[M,2351,8,75335,2351,33,75360],
[M,2351,19,75346,2351,32,75359],
[M,2351,8,75335,2351,18,75345],
[M,2352,8,75370,2352,35,75397],
[M,2352,21,75383,2352,34,75396],
[M,2352,8,75370,2352,20,75382],
[M,2353,8,75407,2353,41,75440],
[M,2353,27,75426,2353,40,75439],
[M,2353,8,75407,2353,26,75425],
[M,2354,8,75450,2354,27,75469],
[M,2354,8,75450,2354,19,75461],
[M,2335,42,74984,2335,59,75001],
[M,2335,42,74984,2335,53,74995],
[M,2293,39,73698,2293,62,73721],
[M,2293,48,73707,2293,61,73720],
[M,2293,39,73698,2293,47,73706],
[M,2290,57,73566,2290,82,73591],
[M,2290,68,73577,2290,81,73590],
[M,2290,57,73566,2290,67,73576],
[M,2287,43,73385,2287,58,73400],
[M,2287,43,73385,2287,52,73394],
[M,2284,41,73262,2284,56,73277],
[M,2284,41,73262,2284,50,73271],
[M,2275,42,72923,2275,67,72948],
[M,2275,53,72934,2275,66,72947],
[M,2275,42,72923,2275,52,72933],
[M,2272,42,72781,2272,67,72806],
[M,2272,53,72792,2272,66,72805],
[M,2272,42,72781,2272,52,72791],
[M,2269,49,72605,2269,64,72620],
[M,2269,49,72605,2269,58,72614],
[M,2269,71,72627,2269,87,72643],
[M,2269,71,72627,2269,81,72637],
[M,2269,89,72645,2269,108,72664],
[M,2269,89,72645,2269,100,72656],
[M,2258,48,72269,2258,71,72292],
[M,2258,57,72278,2258,70,72291],
[M,2258,48,72269,2258,56,72277],
[M,2258,73,72294,2258,88,72309],
[M,2258,73,72294,2258,82,72303],
[M,2258,95,72316,2258,111,72332],
[M,2258,95,72316,2258,105,72326],
[M,2258,113,72334,2258,132,72353],
[M,2258,113,72334,2258,124,72345],
[M,2241,50,71918,2241,67,71935],
[M,2241,50,71918,2241,61,71929],
[M,2237,42,71766,2237,59,71783],
[M,2237,42,71766,2237,53,71777],
[M,2233,39,71612,2233,53,71626],
[M,2233,39,71612,2233,47,71620],
[M,2233,55,71628,2233,74,71647],
[M,2233,55,71628,2233,68,71641],
[M,2229,45,71432,2229,60,71447],
[M,2229,45,71432,2229,54,71441],
[M,2229,62,71449,2229,89,71476],
[M,2229,75,71462,2229,88,71475],
[M,2229,62,71449,2229,74,71461],
[M,2229,91,71478,2229,108,71495],
[M,2229,91,71478,2229,102,71489],
[M,2226,40,71231,2226,55,71246],
[M,2226,40,71231,2226,49,71240],
[M,2226,57,71248,2226,84,71275],
[M,2226,70,71261,2226,83,71274],
[M,2226,57,71248,2226,69,71260],
[M,2222,61,71082,2222,77,71098],
[M,2222,61,71082,2222,71,71092],
[M,2218,59,70910,2218,76,70927],
[M,2218,59,70910,2218,70,70921],
[M,2211,54,70619,2211,71,70636],
[M,2211,54,70619,2211,65,70630],
[M,2204,50,70359,2204,66,70375],
[M,2204,50,70359,2204,60,70369],
[M,2200,45,70219,2200,61,70235],
[M,2200,45,70219,2200,55,70229],
[M,2196,40,70088,2196,57,70105],
[M,2196,40,70088,2196,51,70099],
[M,2192,44,69968,2192,59,69983],
[M,2192,44,69968,2192,53,69977],
[M,2188,40,69863,2188,57,69880],
[M,2188,40,69863,2188,51,69874],
[M,2180,39,69605,2180,56,69622],
[M,2180,39,69605,2180,50,69616],
[M,2176,39,69461,2176,56,69478],
[M,2176,39,69461,2176,50,69472],
[M,2172,43,69341,2172,60,69358],
[M,2172,43,69341,2172,54,69352],
[M,2168,40,69215,2168,55,69230],
[M,2168,40,69215,2168,49,69224],
[M,2164,54,69029,2164,77,69052],
[M,2164,63,69038,2164,76,69051],
[M,2164,54,69029,2164,62,69037],
[M,2164,79,69054,2164,94,69069],
[M,2164,79,69054,2164,88,69063],
[M,2164,101,69076,2164,117,69092],
[M,2164,101,69076,2164,111,69086],
[M,2164,119,69094,2164,138,69113],
[M,2164,119,69094,2164,130,69105],
[M,2152,47,68694,2152,72,68719],
[M,2152,58,68705,2152,71,68718],
[M,2152,47,68694,2152,57,68704],
[M,2144,50,68431,2144,66,68447],
[M,2144,50,68431,2144,60,68441],
[M,2140,47,68321,2140,63,68337],
[M,2140,47,68321,2140,57,68331],
[M,2136,52,68210,2136,68,68226],
[M,2136,52,68210,2136,62,68220],
[M,2132,57,68096,2132,73,68112],
[M,2132,57,68096,2132,67,68106],
[M,2128,40,67971,2128,57,67988],
[M,2128,40,67971,2128,51,67982],
[M,2120,44,67784,2120,60,67800],
[M,2120,44,67784,2120,54,67794],
[M,2117,44,67680,2117,60,67696],
[M,2117,44,67680,2117,54,67690],
[M,2113,49,67576,2113,64,67591],
[M,2113,49,67576,2113,58,67585],
[M,2091,58,67010,2091,81,67033],
[M,2091,58,67010,2091,75,67027],
[M,2088,55,66859,2088,71,66875],
[M,2088,55,66859,2088,65,66869],
[M,2088,73,66877,2088,90,66894],
[M,2088,73,66877,2088,84,66888],
[M,2085,49,66726,2085,65,66742],
[M,2085,49,66726,2085,59,66736],
[M,2075,47,66373,2075,73,66399],
[M,2075,47,66373,2075,67,66393],
[M,2075,75,66401,2075,101,66427],
[M,2075,87,66413,2075,100,66426],
[M,2075,75,66401,2075,86,66412],
[M,2075,103,66429,2075,119,66445],
[M,2075,103,66429,2075,113,66439],
[M,2071,26,66178,2071,46,66198],
[M,2071,26,66178,2071,40,66192],
[M,2071,48,66200,2071,79,66231],
[M,2071,58,66210,2071,71,66223],
[M,2071,48,66200,2071,57,66209],
[M,2071,81,66233,2071,99,66251],
[M,2071,81,66233,2071,93,66245],
[M,2035,24,65515,2035,33,65524],
[M,2035,4,65495,2035,19,65510],
[M,2035,24,65515,2035,39,65530],
[M,2032,34,65434,2032,47,65447],
[M,2032,24,65424,2032,33,65433],
[M,2032,4,65404,2032,19,65419],
[M,2032,24,65424,2032,54,65454],
[M,2026,39,65275,2026,48,65284],
[M,2026,4,65240,2026,34,65270],
[M,2026,39,65275,2026,54,65290],
[M,2023,39,65181,2023,48,65190],
[M,2023,4,65146,2023,34,65176],
[M,2023,39,65181,2023,54,65196],
[M,1995,42,64679,1995,59,64696],
[M,1995,4,64641,1995,37,64674],
[M,1995,42,64679,1995,65,64702],
[M,1978,52,64282,1978,65,64295],
[M,1978,42,64272,1978,51,64281],
[M,1978,4,64234,1978,37,64267],
[M,1978,42,64272,1978,80,64310],
[M,1965,25,63923,1965,36,63934],
[M,1965,4,63902,1965,20,63918],
[M,1965,25,63923,1965,42,63940],
[M,1958,18,63731,1958,31,63744],
[M,1958,8,63721,1958,17,63730],
[M,1957,4,63696,1957,20,63712],
[M,1959,8,63760,1959,17,63769],
[M,1958,8,63721,1958,38,63751],
[M,1960,8,63784,1960,18,63794],
[M,1959,8,63760,1959,23,63775],
[M,1961,8,63809,1961,19,63820],
[M,1960,8,63784,1960,24,63800],
[M,1961,8,63809,1961,27,63828],
[M,1945,25,63425,1945,34,63434],
[M,1945,4,63404,1945,20,63420],
[M,1945,45,63445,1945,56,63456],
[M,1945,25,63425,1945,40,63440],
[M,1945,45,63445,1945,62,63462],
[M,1942,25,63282,1942,34,63291],
[M,1942,4,63261,1942,20,63277],
[M,1942,45,63302,1942,56,63313],
[M,1942,25,63282,1942,40,63297],
[M,1942,45,63302,1942,62,63319],
[M,1939,25,63156,1939,36,63167],
[M,1939,4,63135,1939,20,63151],
[M,1939,25,63156,1939,42,63173],
[M,1932,39,62875,1932,52,62888],
[M,1932,29,62865,1932,38,62874],
[M,1932,4,62840,1932,24,62860],
[M,1932,68,62904,1932,77,62913],
[M,1932,29,62865,1932,63,62899],
[M,1932,88,62924,1932,98,62934],
[M,1932,68,62904,1932,83,62919],
[M,1932,88,62924,1932,104,62940],
[M,1918,18,62505,1918,31,62518],
[M,1918,8,62495,1918,17,62504],
[M,1917,4,62469,1917,21,62486],
[M,1919,18,62546,1919,31,62559],
[M,1919,8,62536,1919,17,62545],
[M,1918,8,62495,1918,40,62527],
[M,1920,18,62587,1920,31,62600],
[M,1920,8,62577,1920,17,62586],
[M,1919,8,62536,1919,40,62568],
[M,1921,18,62630,1921,31,62643],
[M,1921,8,62620,1921,17,62629],
[M,1920,8,62577,1920,42,62611],
[M,1922,8,62669,1922,19,62680],
[M,1921,8,62620,1921,48,62660],
[M,1922,8,62669,1922,27,62688],
[M,1901,18,62049,1901,31,62062],
[M,1901,8,62039,1901,17,62048],
[M,1900,4,61998,1900,36,62030],
[M,1902,18,62091,1902,31,62104],
[M,1902,8,62081,1902,17,62090],
[M,1901,8,62039,1901,40,62071],
[M,1903,18,62134,1903,31,62147],
[M,1903,8,62124,1903,17,62133],
[M,1902,8,62081,1902,42,62115],
[M,1904,8,62173,1904,19,62184],
[M,1903,8,62124,1903,48,62164],
[M,1904,8,62173,1904,27,62192],
[M,1888,24,61730,1888,35,61741],
[M,1888,4,61710,1888,19,61725],
[M,1888,24,61730,1888,41,61747],
[M,1846,35,60736,1846,48,60749],
[M,1846,25,60726,1846,34,60735],
[M,1846,4,60705,1846,20,60721],
[M,1846,25,60726,1846,55,60756],
[M,1843,42,60612,1843,55,60625],
[M,1843,32,60602,1843,41,60611],
[M,1843,4,60574,1843,27,60597],
[M,1843,32,60602,1843,64,60634],
[M,1840,25,60447,1840,34,60456],
[M,1840,4,60426,1840,20,60442],
[M,1840,25,60447,1840,40,60462],
[M,1837,25,60343,1837,34,60352],
[M,1837,4,60322,1837,20,60338],
[M,1837,25,60343,1837,40,60358],
[M,1828,35,60048,1828,48,60061],
[M,1828,25,60038,1828,34,60047],
[M,1828,4,60017,1828,20,60033],
[M,1828,25,60038,1828,57,60070],
[M,1825,35,59917,1825,48,59930],
[M,1825,25,59907,1825,34,59916],
[M,1825,4,59886,1825,20,59902],
[M,1825,25,59907,1825,57,59939],
[M,1822,39,59748,1822,48,59757],
[M,1822,4,59713,1822,34,59743],
[M,1822,59,59768,1822,69,59778],
[M,1822,39,59748,1822,54,59763],
[M,1822,80,59789,1822,91,59800],
[M,1822,59,59768,1822,75,59784],
[M,1822,80,59789,1822,99,59808],
[M,1811,18,59420,1811,31,59433],
[M,1811,8,59410,1811,17,59419],
[M,1810,4,59369,1810,36,59401],
[M,1811,43,59445,1811,52,59454],
[M,1811,8,59410,1811,38,59440],
[M,1811,63,59465,1811,73,59475],
[M,1811,43,59445,1811,58,59460],
[M,1811,84,59486,1811,95,59497],
[M,1811,63,59465,1811,79,59481],
[M,1811,84,59486,1811,103,59505],
[M,1793,25,59077,1793,36,59088],
[M,1793,4,59056,1793,20,59072],
[M,1793,25,59077,1793,42,59094],
[M,1789,25,58949,1789,36,58960],
[M,1789,4,58928,1789,20,58944],
[M,1789,25,58949,1789,42,58966],
[M,1785,25,58808,1785,33,58816],
[M,1785,4,58787,1785,20,58803],
[M,1785,44,58827,1785,57,58840],
[M,1785,25,58808,1785,39,58822],
[M,1785,44,58827,1785,63,58846],
[M,1781,24,58628,1781,33,58637],
[M,1781,4,58608,1781,19,58623],
[M,1781,54,58658,1781,67,58671],
[M,1781,44,58648,1781,53,58657],
[M,1781,24,58628,1781,39,58643],
[M,1781,83,58687,1781,94,58698],
[M,1781,44,58648,1781,78,58682],
[M,1781,83,58687,1781,100,58704],
[M,1778,24,58439,1778,33,58448],
[M,1778,4,58419,1778,19,58434],
[M,1778,54,58469,1778,67,58482],
[M,1778,44,58459,1778,53,58468],
[M,1778,24,58439,1778,39,58454],
[M,1778,44,58459,1778,78,58493],
[M,1774,39,58305,1774,49,58315],
[M,1774,4,58270,1774,34,58300],
[M,1774,39,58305,1774,55,58321],
[M,1770,43,58154,1770,54,58165],
[M,1770,4,58115,1770,38,58149],
[M,1770,43,58154,1770,60,58171],
[M,1763,43,57895,1763,54,57906],
[M,1763,4,57856,1763,38,57890],
[M,1763,43,57895,1763,60,57912],
[M,1756,25,57655,1756,35,57665],
[M,1756,4,57634,1756,20,57650],
[M,1756,25,57655,1756,41,57671],
[M,1752,25,57539,1752,35,57549],
[M,1752,4,57518,1752,20,57534],
[M,1752,25,57539,1752,41,57555],
[M,1748,23,57427,1748,34,57438],
[M,1748,4,57408,1748,18,57422],
[M,1748,23,57427,1748,40,57444],
[M,1744,25,57323,1744,34,57332],
[M,1744,4,57302,1744,20,57318],
[M,1744,25,57323,1744,40,57338],
[M,1740,25,57216,1740,36,57227],
[M,1740,4,57195,1740,20,57211],
[M,1740,25,57216,1740,42,57233],
[M,1732,25,56997,1732,36,57008],
[M,1732,4,56976,1732,20,56992],
[M,1732,25,56997,1732,42,57014],
[M,1728,25,56866,1728,36,56877],
[M,1728,4,56845,1728,20,56861],
[M,1728,25,56866,1728,42,56883],
[M,1724,25,56761,1724,36,56772],
[M,1724,4,56740,1724,20,56756],
[M,1724,25,56761,1724,42,56778],
[M,1720,25,56652,1720,34,56661],
[M,1720,4,56631,1720,20,56647],
[M,1720,25,56652,1720,40,56667],
[M,1716,18,56481,1716,31,56494],
[M,1716,8,56471,1716,17,56480],
[M,1715,4,56430,1715,36,56462],
[M,1716,43,56506,1716,52,56515],
[M,1716,8,56471,1716,38,56501],
[M,1716,63,56526,1716,73,56536],
[M,1716,43,56506,1716,58,56521],
[M,1716,84,56547,1716,95,56558],
[M,1716,63,56526,1716,79,56542],
[M,1716,84,56547,1716,103,56566],
[M,1703,35,56181,1703,48,56194],
[M,1703,25,56171,1703,34,56180],
[M,1703,4,56150,1703,20,56166],
[M,1703,25,56171,1703,57,56203],
[M,1695,40,55957,1695,50,55967],
[M,1695,4,55921,1695,35,55952],
[M,1695,40,55957,1695,56,55973],
[M,1691,25,55856,1691,35,55866],
[M,1691,4,55835,1691,20,55851],
[M,1691,25,55856,1691,41,55872],
[M,1687,40,55766,1687,50,55776],
[M,1687,4,55730,1687,35,55761],
[M,1687,40,55766,1687,56,55782],
[M,1683,40,55665,1683,50,55675],
[M,1683,4,55629,1683,35,55660],
[M,1683,40,55665,1683,56,55681],
[M,1679,25,55558,1679,36,55569],
[M,1679,4,55537,1679,20,55553],
[M,1679,25,55558,1679,42,55575],
[M,1675,25,55469,1675,34,55478],
[M,1675,4,55448,1675,20,55464],
[M,1675,25,55469,1675,40,55484],
[M,1671,25,55382,1671,35,55392],
[M,1671,4,55361,1671,20,55377],
[M,1671,25,55382,1671,41,55398],
[M,1668,25,55298,1668,35,55308],
[M,1668,4,55277,1668,20,55293],
[M,1668,25,55298,1668,41,55314],
[M,1664,25,55212,1664,34,55221],
[M,1664,4,55191,1664,20,55207],
[M,1664,25,55212,1664,40,55227],
[M,1639,25,54713,1639,36,54724],
[M,1639,4,54692,1639,20,54708],
[M,1639,25,54713,1639,42,54730],
[M,1630,32,54515,1630,42,54525],
[M,1630,4,54487,1630,27,54510],
[M,1630,32,54515,1630,48,54531],
[M,1624,18,54335,1624,31,54348],
[M,1624,8,54325,1624,17,54334],
[M,1623,4,54296,1623,24,54316],
[M,1625,18,54384,1625,31,54397],
[M,1625,8,54374,1625,17,54383],
[M,1624,8,54325,1624,48,54365],
[M,1626,8,54416,1626,18,54426],
[M,1625,8,54374,1625,41,54407],
[M,1626,8,54416,1626,24,54432],
[M,1619,27,54139,1619,41,54153],
[M,1619,4,54116,1619,22,54134],
[M,1619,62,54174,1619,75,54187],
[M,1619,52,54164,1619,61,54173],
[M,1619,27,54139,1619,47,54159],
[M,1619,88,54200,1619,100,54212],
[M,1619,52,54164,1619,83,54195],
[M,1619,88,54200,1619,106,54218],
[M,1583,31,53535,1583,46,53550],
[M,1583,31,53535,1583,40,53544],
[M,1580,30,53443,1580,53,53466],
[M,1580,39,53452,1580,52,53465],
[M,1580,30,53443,1580,38,53451],
[M,1574,41,53281,1574,56,53296],
[M,1574,41,53281,1574,50,53290],
[M,1571,40,53172,1571,55,53187],
[M,1571,40,53172,1571,49,53181],
[M,1548,60,52577,1548,83,52600],
[M,1548,60,52577,1548,77,52594],
[M,1531,63,52139,1531,94,52170],
[M,1531,80,52156,1531,93,52169],
[M,1531,63,52139,1531,79,52155],
[M,1518,36,51733,1518,53,51750],
[M,1518,36,51733,1518,47,51744],
[M,1509,8,51505,1509,31,51528],
[M,1509,17,51514,1509,30,51527],
[M,1509,8,51505,1509,16,51513],
[M,1510,8,51538,1510,23,51553],
[M,1510,8,51538,1510,17,51547],
[M,1512,8,51576,1512,24,51592],
[M,1512,8,51576,1512,18,51586],
[M,1513,8,51602,1513,27,51621],
[M,1513,8,51602,1513,19,51613],
[M,1494,38,51177,1494,53,51192],
[M,1494,38,51177,1494,47,51186],
[M,1494,55,51194,1494,72,51211],
[M,1494,55,51194,1494,66,51205],
[M,1491,41,51023,1491,56,51038],
[M,1491,41,51023,1491,50,51032],
[M,1491,58,51040,1491,75,51057],
[M,1491,58,51040,1491,69,51051],
[M,1488,38,50880,1488,55,50897],
[M,1488,38,50880,1488,49,50891],
[M,1481,35,50557,1481,62,50584],
[M,1481,48,50570,1481,61,50583],
[M,1481,35,50557,1481,47,50569],
[M,1481,64,50586,1481,79,50601],
[M,1481,64,50586,1481,73,50595],
[M,1481,81,50603,1481,97,50619],
[M,1481,81,50603,1481,91,50613],
[M,1466,8,50199,1466,33,50224],
[M,1466,19,50210,1466,32,50223],
[M,1466,8,50199,1466,18,50209],
[M,1467,8,50234,1467,33,50259],
[M,1467,19,50245,1467,32,50258],
[M,1467,8,50234,1467,18,50244],
[M,1468,8,50269,1468,35,50296],
[M,1468,21,50282,1468,34,50295],
[M,1468,8,50269,1468,20,50281],
[M,1469,8,50306,1469,41,50339],
[M,1469,27,50325,1469,40,50338],
[M,1469,8,50306,1469,26,50324],
[M,1470,8,50349,1470,27,50368],
[M,1470,8,50349,1470,19,50360],
[M,1445,8,49709,1445,33,49734],
[M,1445,19,49720,1445,32,49733],
[M,1445,8,49709,1445,18,49719],
[M,1446,8,49744,1446,35,49771],
[M,1446,21,49757,1446,34,49770],
[M,1446,8,49744,1446,20,49756],
[M,1447,8,49781,1447,41,49814],
[M,1447,27,49800,1447,40,49813],
[M,1447,8,49781,1447,26,49799],
[M,1448,8,49824,1448,27,49843],
[M,1448,8,49824,1448,19,49835],
[M,1429,34,49366,1429,51,49383],
[M,1429,34,49366,1429,45,49377],
[M,1387,31,48184,1387,54,48207],
[M,1387,40,48193,1387,53,48206],
[M,1387,31,48184,1387,39,48192],
[M,1384,49,48060,1384,74,48085],
[M,1384,60,48071,1384,73,48084],
[M,1384,49,48060,1384,59,48070],
[M,1381,35,47887,1381,50,47902],
[M,1381,35,47887,1381,44,47896],
[M,1378,33,47772,1378,48,47787],
[M,1378,33,47772,1378,42,47781],
[M,1369,34,47457,1369,59,47482],
[M,1369,45,47468,1369,58,47481],
[M,1369,34,47457,1369,44,47467],
[M,1366,34,47323,1366,59,47348],
[M,1366,45,47334,1366,58,47347],
[M,1366,34,47323,1366,44,47333],
[M,1363,41,47155,1363,56,47170],
[M,1363,41,47155,1363,50,47164],
[M,1363,63,47177,1363,79,47193],
[M,1363,63,47177,1363,73,47187],
[M,1363,81,47195,1363,100,47214],
[M,1363,81,47195,1363,92,47206],
[M,1352,40,46827,1352,63,46850],
[M,1352,49,46836,1352,62,46849],
[M,1352,40,46827,1352,48,46835],
[M,1352,65,46852,1352,80,46867],
[M,1352,65,46852,1352,74,46861],
[M,1352,87,46874,1352,103,46890],
[M,1352,87,46874,1352,97,46884],
[M,1352,105,46892,1352,124,46911],
[M,1352,105,46892,1352,116,46903],
[M,1335,42,46492,1335,59,46509],
[M,1335,42,46492,1335,53,46503],
[M,1331,34,46348,1331,51,46365],
[M,1331,34,46348,1331,45,46359],
[M,1327,31,46202,1327,45,46216],
[M,1327,31,46202,1327,39,46210],
[M,1327,47,46218,1327,66,46237],
[M,1327,47,46218,1327,60,46231],
[M,1323,37,46030,1323,52,46045],
[M,1323,37,46030,1323,46,46039],
[M,1323,54,46047,1323,81,46074],
[M,1323,67,46060,1323,80,46073],
[M,1323,54,46047,1323,66,46059],
[M,1323,83,46076,1323,100,46093],
[M,1323,83,46076,1323,94,46087],
[M,1320,32,45837,1320,47,45852],
[M,1320,32,45837,1320,41,45846],
[M,1320,49,45854,1320,76,45881],
[M,1320,62,45867,1320,75,45880],
[M,1320,49,45854,1320,61,45866],
[M,1316,53,45696,1316,69,45712],
[M,1316,53,45696,1316,63,45706],
[M,1312,51,45532,1312,68,45549],
[M,1312,51,45532,1312,62,45543],
[M,1305,46,45257,1305,63,45274],
[M,1305,46,45257,1305,57,45268],
[M,1298,42,45013,1298,58,45029],
[M,1298,42,45013,1298,52,45023],
[M,1294,37,44881,1294,53,44897],
[M,1294,37,44881,1294,47,44891],
[M,1290,32,44758,1290,49,44775],
[M,1290,32,44758,1290,43,44769],
[M,1286,36,44646,1286,51,44661],
[M,1286,36,44646,1286,45,44655],
[M,1282,32,44549,1282,49,44566],
[M,1282,32,44549,1282,43,44560],
[M,1274,31,44307,1274,48,44324],
[M,1274,31,44307,1274,42,44318],
[M,1270,31,44171,1270,48,44188],
[M,1270,31,44171,1270,42,44182],
[M,1266,35,44059,1266,52,44076],
[M,1266,35,44059,1266,46,44070],
[M,1262,32,43941,1262,47,43956],
[M,1262,32,43941,1262,41,43950],
[M,1258,52,43788,1258,67,43803],
[M,1258,52,43788,1258,61,43797],
[M,1258,74,43810,1258,90,43826],
[M,1258,74,43810,1258,84,43820],
[M,1258,92,43828,1258,111,43847],
[M,1258,92,43828,1258,103,43839],
[M,1246,39,43471,1246,64,43496],
[M,1246,50,43482,1246,63,43495],
[M,1246,39,43471,1246,49,43481],
[M,1238,42,43224,1238,58,43240],
[M,1238,42,43224,1238,52,43234],
[M,1234,39,43122,1234,55,43138],
[M,1234,39,43122,1234,49,43132],
[M,1230,44,43019,1230,60,43035],
[M,1230,44,43019,1230,54,43029],
[M,1226,49,42913,1226,65,42929],
[M,1226,49,42913,1226,59,42923],
[M,1222,40,42796,1222,57,42813],
[M,1222,40,42796,1222,51,42807],
[M,1218,37,42691,1218,52,42706],
[M,1218,37,42691,1218,46,42700],
[M,1214,36,42593,1214,52,42609],
[M,1214,36,42593,1214,46,42603],
[M,1211,36,42497,1211,52,42513],
[M,1211,36,42497,1211,46,42507],
[M,1207,41,42401,1207,56,42416],
[M,1207,41,42401,1207,50,42410],
[M,1182,53,41772,1182,70,41789],
[M,1182,53,41772,1182,64,41783],
[M,1173,41,41509,1173,57,41525],
[M,1173,41,41509,1173,51,41519],
[M,1169,39,41346,1169,65,41372],
[M,1169,39,41346,1169,59,41366],
[M,1169,67,41374,1169,93,41400],
[M,1169,79,41386,1169,92,41399],
[M,1169,67,41374,1169,78,41385],
[M,1169,95,41402,1169,111,41418],
[M,1169,95,41402,1169,105,41412],
[M,1165,36,41159,1165,56,41179],
[M,1165,36,41159,1165,50,41173],
[M,1165,58,41181,1165,89,41212],
[M,1165,68,41191,1165,81,41204],
[M,1165,58,41181,1165,67,41190],
[M,1165,91,41214,1165,109,41232],
[M,1165,91,41214,1165,103,41226],
[M,1117,32,40161,1117,66,40195],
[M,1117,77,40206,1117,111,40240],
[M,1108,77,39814,1108,100,39837],
[M,1108,67,39804,1108,101,39838],
[M,1107,76,39711,1107,99,39734],
[M,1107,65,39700,1107,100,39735],
[M,1070,31,38590,1070,48,38607],
[M,1070,38,38597,1070,47,38606],
[M,1070,31,38590,1070,37,38596],
[M,1071,48,38656,1071,65,38673],
[M,1071,55,38663,1071,64,38672],
[M,1071,48,38656,1071,54,38662],
[M,1071,12,38620,1071,20,38628],
[M,1071,67,38675,1071,86,38694],
[M,1071,67,38675,1071,84,38692],
[M,1071,67,38675,1071,75,38683],
[M,1071,12,38620,1071,87,38695],
[M,1076,38,38785,1076,77,38824],
[M,1059,49,38289,1059,66,38306],
[M,1059,55,38295,1059,65,38305],
[M,1059,42,38282,1059,48,38288],
[M,1059,42,38282,1059,66,38306],
[M,1056,52,38129,1056,71,38148],
[M,1056,52,38129,1056,69,38146],
[M,1056,52,38129,1056,60,38137],
[M,1056,42,38119,1056,51,38128],
[M,1056,42,38119,1056,72,38149],
[M,1052,39,37942,1052,66,37969],
[M,1052,53,37956,1052,65,37968],
[M,1052,39,37942,1052,52,37955],
[M,1052,39,37942,1052,48,37951],
[M,1052,24,37927,1052,37,37940],
[M,1052,12,37915,1052,23,37926],
[M,1051,33,37887,1051,40,37894],
[M,1051,21,37875,1051,30,37884],
[M,1051,12,37866,1051,20,37874],
[M,1052,12,37915,1052,67,37970],
[M,1051,33,37887,1052,68,37971],
[M,1051,21,37875,1052,81,37984],
[M,1052,71,37974,1052,80,37983],
[M,1051,12,37866,1052,81,37984],
[M,1050,15,37834,1052,82,37985],
[M,1045,8,37673,1045,37,37702],
[M,1045,24,37689,1045,36,37701],
[M,1045,8,37673,1045,23,37688],
[M,1045,8,37673,1045,19,37684],
[M,1044,87,37654,1044,96,37663],
[M,1044,72,37639,1044,85,37652],
[M,1044,61,37628,1044,70,37637],
[M,1033,15,37109,1033,70,37164],
[M,1033,92,37186,1033,111,37205],
[M,1033,92,37186,1033,109,37203],
[M,1033,92,37186,1033,100,37194],
[M,1033,74,37168,1033,112,37206],
[M,1033,8,37102,1033,113,37207],
[M,1032,6,37065,1033,113,37207],
[M,1034,28,37236,1034,77,37285],
[M,1034,67,37275,1034,76,37284],
[M,1034,51,37259,1034,60,37268],
[M,1034,28,37236,1034,39,37247],
[M,1035,12,37298,1035,15,37301],
[M,1034,8,37216,1034,26,37234],
[M,1034,10,37218,1034,25,37233],
[M,1062,38,38382,1062,77,38421],
[M,1008,17,36261,1008,41,36285],
[M,1010,12,36392,1010,51,36431],
[M,1010,26,36406,1010,50,36430],
[M,1010,34,36414,1010,44,36424],
[M,1010,12,36392,1010,25,36405],
[M,1010,12,36392,1010,21,36401],
[M,1009,83,36369,1009,92,36378],
[M,1009,68,36354,1009,81,36367],
[M,1009,57,36343,1009,66,36352],
[M,1009,46,36332,1009,55,36341],
[M,1009,14,36300,1009,34,36320],
[M,1009,14,36300,1010,52,36432],
[M,1008,17,36261,1010,82,36462],
[M,1008,8,36252,1010,82,36462],
[M,1008,8,36252,1011,29,36506],
[M,1011,8,36485,1011,28,36505],
[M,1011,8,36485,1011,26,36503],
[M,1011,8,36485,1011,17,36494],
[M,1015,38,36586,1015,77,36625],
[M,994,30,35815,994,50,35835],
[M,994,30,35815,994,48,35833],
[M,994,30,35815,994,39,35824],
[M,994,30,35815,994,79,35864],
[M,994,10,35795,994,79,35864],
[M,993,6,35771,995,59,35924],
[M,995,38,35903,995,58,35923],
[M,995,38,35903,995,56,35921],
[M,995,38,35903,995,47,35912],
[M,995,10,35875,995,17,35882],
[M,995,26,35891,995,59,35924],
[M,995,10,35875,995,59,35924],
[M,999,38,36004,999,77,36043],
[M,980,30,35391,980,50,35411],
[M,980,30,35391,980,48,35409],
[M,980,30,35391,980,39,35400],
[M,980,30,35391,980,63,35424],
[M,980,10,35371,980,63,35424],
[M,979,6,35354,981,59,35484],
[M,981,38,35463,981,58,35483],
[M,981,38,35463,981,56,35481],
[M,981,38,35463,981,47,35472],
[M,981,10,35435,981,17,35442],
[M,981,26,35451,981,59,35484],
[M,981,10,35435,981,59,35484],
[M,985,38,35564,985,77,35603],
[M,971,38,35161,971,77,35200],
[M,955,38,34771,955,77,34810],
[M,921,24,33737,921,61,33774],
[M,921,15,33728,921,23,33736],
[M,921,6,33719,921,61,33774],
[M,922,6,33781,922,61,33836],
[M,922,36,33811,922,60,33835],
[M,922,44,33819,922,54,33829],
[M,922,14,33789,922,35,33810],
[M,922,14,33789,922,31,33806],
[M,923,9,33846,923,30,33867],
[M,923,9,33846,923,23,33860],
[M,923,32,33869,923,45,33882],
[M,924,58,33941,924,91,33974],
[M,924,70,33953,924,83,33966],
[M,924,58,33941,924,69,33952],
[M,924,30,33913,924,37,33920],
[M,924,21,33904,924,29,33912],
[M,924,46,33929,924,92,33975],
[M,924,30,33913,924,92,33975],
[M,924,21,33904,924,93,33976],
[M,924,12,33895,924,93,33976],
[M,906,8,33173,906,50,33215],
[M,906,25,33190,906,49,33214],
[M,906,33,33198,906,43,33208],
[M,906,8,33173,906,24,33189],
[M,906,8,33173,906,20,33185],
[M,905,79,33154,905,88,33163],
[M,905,64,33139,905,77,33152],
[M,905,53,33128,905,62,33137],
[M,905,42,33117,905,51,33126],
[M,905,10,33085,905,30,33105],
[M,905,10,33085,906,51,33216],
[M,903,6,33033,906,51,33216],
[M,907,24,33241,907,61,33278],
[M,907,15,33232,907,23,33240],
[M,907,6,33223,907,61,33278],
[M,908,6,33285,908,61,33340],
[M,908,36,33315,908,60,33339],
[M,908,44,33323,908,54,33333],
[M,908,14,33293,908,35,33314],
[M,908,14,33293,908,31,33310],
[M,909,9,33350,909,30,33371],
[M,909,9,33350,909,23,33364],
[M,909,32,33373,909,45,33386],
[M,910,58,33445,910,91,33478],
[M,910,70,33457,910,83,33470],
[M,910,58,33445,910,69,33456],
[M,910,30,33417,910,37,33424],
[M,910,21,33408,910,29,33416],
[M,910,46,33433,910,92,33479],
[M,910,30,33417,910,92,33479],
[M,910,21,33408,910,93,33480],
[M,910,12,33399,910,93,33480],
[M,929,38,34066,929,77,34105],
[M,885,36,32640,885,56,32660],
[M,885,36,32640,885,54,32658],
[M,885,36,32640,885,45,32649],
[M,889,38,32740,889,77,32779],
[M,877,38,32382,877,77,32421],
[M,857,15,31790,857,95,31870],
[M,857,73,31848,857,94,31869],
[M,857,73,31848,857,92,31867],
[M,857,73,31848,857,83,31858],
[M,861,38,31950,861,77,31989],
[M,845,68,31498,845,79,31509],
[M,845,57,31487,845,66,31496],
[M,845,47,31477,845,55,31485],
[M,845,37,31467,845,45,31475],
[M,845,26,31456,845,35,31465],
[M,826,36,30765,826,151,30880],
[M,826,90,30819,826,109,30838],
[M,826,90,30819,826,107,30836],
[M,826,90,30819,826,98,30827],
[M,826,129,30858,826,150,30879],
[M,826,129,30858,826,148,30877],
[M,826,129,30858,826,139,30868],
[M,823,36,30544,823,98,30606],
[M,823,76,30584,823,97,30605],
[M,823,76,30584,823,95,30603],
[M,823,76,30584,823,86,30594],
[M,849,38,31590,849,77,31629],
[M,803,25,29889,803,42,29906],
[M,803,25,29889,803,31,29895],
[M,804,14,29942,804,32,29960],
[M,804,14,29942,804,30,29958],
[M,804,14,29942,804,21,29949],
[M,803,11,29875,803,23,29887],
[M,808,46,30056,808,63,30073],
[M,808,46,30056,808,52,30062],
[M,808,10,30020,808,18,30028],
[M,809,50,30167,809,68,30185],
[M,809,50,30167,809,66,30183],
[M,809,50,30167,809,57,30174],
[M,809,14,30131,809,22,30139],
[M,807,11,29996,807,23,30008],
[M,803,45,29909,803,63,29927],
[M,803,45,29909,803,61,29925],
[M,803,45,29909,803,52,29916],
[M,803,25,29889,803,63,29927],
[M,808,66,30076,808,84,30094],
[M,808,66,30076,808,82,30092],
[M,808,66,30076,808,73,30083],
[M,808,46,30056,808,85,30095],
[M,808,86,30096,808,105,30115],
[M,808,86,30096,808,103,30113],
[M,808,86,30096,808,94,30104],
[M,808,10,30020,808,106,30116],
[M,809,70,30187,809,89,30206],
[M,809,70,30187,809,87,30204],
[M,809,70,30187,809,78,30195],
[M,809,14,30131,809,90,30207],
[M,816,38,30340,816,77,30379],
[M,794,38,29670,794,77,29709],
[M,774,12,29059,775,44,29173],
[M,776,12,29186,776,32,29206],
[M,776,12,29186,776,30,29204],
[M,776,12,29186,776,21,29195],
[M,753,24,28222,758,82,28553],
[M,755,33,28300,755,44,28311],
[M,755,12,28279,755,32,28299],
[M,755,48,28315,755,70,28337],
[M,755,60,28327,755,69,28336],
[M,755,48,28315,755,57,28324],
[M,756,10,28385,756,53,28428],
[M,756,28,28403,756,52,28427],
[M,756,36,28411,756,46,28421],
[M,756,10,28385,756,27,28402],
[M,756,10,28385,756,23,28398],
[M,755,97,28364,755,106,28373],
[M,755,82,28349,755,95,28362],
[M,755,71,28338,755,80,28347],
[M,755,12,28279,756,54,28429],
[M,757,29,28459,757,40,28470],
[M,757,21,28451,757,28,28458],
[M,757,12,28442,757,20,28450],
[M,758,12,28483,758,80,28551],
[M,758,48,28519,758,67,28538],
[M,758,48,28519,758,65,28536],
[M,758,48,28519,758,56,28527],
[M,757,21,28451,758,80,28551],
[M,757,12,28442,758,81,28552],
[M,753,6,28204,758,82,28553],
[M,759,37,28591,759,57,28611],
[M,759,37,28591,759,55,28609],
[M,759,37,28591,759,46,28600],
[M,759,6,28560,759,17,28571],
[M,729,8,27151,729,37,27180],
[M,729,24,27167,729,36,27179],
[M,729,8,27151,729,23,27166],
[M,729,8,27151,729,19,27162],
[M,728,85,27132,728,94,27141],
[M,728,70,27117,728,83,27130],
[M,728,59,27106,728,68,27115],
[M,728,48,27095,728,57,27104],
[M,728,6,27053,729,38,27181],
[M,730,31,27213,730,48,27230],
[M,730,38,27220,730,47,27229],
[M,730,31,27213,730,37,27219],
[M,730,15,27197,730,101,27283],
[M,730,51,27233,730,59,27241],
[M,730,62,27244,730,83,27265],
[M,730,62,27244,730,81,27263],
[M,730,62,27244,730,72,27254],
[M,730,6,27188,730,101,27283],
[M,732,51,27353,732,76,27378],
[M,732,40,27342,732,49,27351],
[M,732,8,27310,732,28,27330],
[M,732,103,27405,732,144,27446],
[M,732,119,27421,732,143,27445],
[M,732,127,27429,732,137,27439],
[M,732,103,27405,732,118,27420],
[M,732,103,27405,732,114,27416],
[M,732,92,27394,732,101,27403],
[M,732,77,27379,732,90,27392],
[M,731,6,27290,732,145,27447],
[M,733,29,27477,733,55,27503],
[M,733,17,27465,733,28,27476],
[M,734,20,27524,734,95,27599],
[M,734,34,27538,734,94,27598],
[M,734,52,27556,734,93,27597],
[M,734,76,27580,734,88,27592],
[M,734,76,27580,734,86,27590],
[M,734,60,27564,734,67,27571],
[M,734,34,27538,734,51,27555],
[M,734,34,27538,734,47,27551],
[M,734,20,27524,734,30,27534],
[M,733,6,27454,734,96,27600],
[M,736,35,27681,736,84,27730],
[M,736,59,27705,736,83,27729],
[M,736,67,27713,736,77,27723],
[M,736,35,27681,736,58,27704],
[M,736,35,27681,736,54,27700],
[M,736,20,27666,736,33,27679],
[M,736,8,27654,736,19,27665],
[M,736,8,27654,736,85,27731],
[M,735,6,27607,736,86,27732],
[M,737,6,27739,740,9,27879],
[M,737,15,27748,740,9,27879],
[M,739,8,27811,739,66,27869],
[M,739,51,27854,739,65,27868],
[M,739,51,27854,739,63,27866],
[M,738,8,27783,738,27,27802],
[M,738,18,27793,738,27,27802],
[M,737,29,27762,737,40,27773],
[M,741,6,27886,741,34,27914],
[M,742,6,27921,742,89,28004],
[M,742,36,27951,742,61,27976],
[M,742,36,27951,742,43,27958],
[M,742,27,27942,742,35,27950],
[M,742,36,27951,742,89,28004],
[M,742,27,27942,742,89,28004],
[M,724,34,26936,724,43,26945],
[M,725,51,26997,725,77,27023],
[M,725,35,26981,725,42,26988],
[M,725,26,26972,725,34,26980],
[M,725,35,26981,725,77,27023],
[M,725,26,26972,725,78,27024],
[M,725,14,26960,725,78,27024],
[M,696,8,25722,696,37,25751],
[M,696,24,25738,696,36,25750],
[M,696,8,25722,696,23,25737],
[M,696,8,25722,696,19,25733],
[M,695,85,25703,695,94,25712],
[M,695,70,25688,695,83,25701],
[M,695,59,25677,695,68,25686],
[M,695,48,25666,695,57,25675],
[M,695,6,25624,696,38,25752],
[M,697,26,25779,697,43,25796],
[M,697,33,25786,697,42,25795],
[M,697,26,25779,697,32,25785],
[M,697,15,25768,697,61,25814],
[M,697,6,25759,697,61,25814],
[M,699,51,25884,699,76,25909],
[M,699,40,25873,699,49,25882],
[M,699,8,25841,699,28,25861],
[M,699,103,25936,699,144,25977],
[M,699,119,25952,699,143,25976],
[M,699,127,25960,699,137,25970],
[M,699,103,25936,699,118,25951],
[M,699,103,25936,699,114,25947],
[M,699,92,25925,699,101,25934],
[M,699,77,25910,699,90,25923],
[M,698,6,25821,699,145,25978],
[M,700,29,26008,700,55,26034],
[M,700,17,25996,700,28,26007],
[M,701,20,26055,701,95,26130],
[M,701,34,26069,701,94,26129],
[M,701,52,26087,701,93,26128],
[M,701,76,26111,701,88,26123],
[M,701,76,26111,701,86,26121],
[M,701,60,26095,701,67,26102],
[M,701,34,26069,701,51,26086],
[M,701,34,26069,701,47,26082],
[M,701,20,26055,701,30,26065],
[M,700,6,25985,701,96,26131],
[M,703,35,26212,703,84,26261],
[M,703,59,26236,703,83,26260],
[M,703,67,26244,703,77,26254],
[M,703,35,26212,703,58,26235],
[M,703,35,26212,703,54,26231],
[M,703,20,26197,703,33,26210],
[M,703,8,26185,703,19,26196],
[M,703,8,26185,703,85,26262],
[M,702,6,26138,703,86,26263],
[M,704,6,26270,707,9,26410],
[M,704,15,26279,707,9,26410],
[M,706,8,26342,706,66,26400],
[M,706,51,26385,706,65,26399],
[M,706,51,26385,706,63,26397],
[M,705,8,26314,705,27,26333],
[M,705,18,26324,705,27,26333],
[M,704,29,26293,704,40,26304],
[M,708,6,26417,708,34,26445],
[M,709,6,26452,709,89,26535],
[M,709,36,26482,709,61,26507],
[M,709,36,26482,709,43,26489],
[M,709,27,26473,709,35,26481],
[M,709,36,26482,709,89,26535],
[M,709,27,26473,709,89,26535],
[M,691,34,25507,691,43,25516],
[M,692,51,25568,692,77,25594],
[M,692,35,25552,692,42,25559],
[M,692,26,25543,692,34,25551],
[M,692,35,25552,692,77,25594],
[M,692,26,25543,692,78,25595],
[M,692,14,25531,692,78,25595],
[M,677,42,25103,677,63,25124],
[M,677,42,25103,677,61,25122],
[M,677,42,25103,677,52,25113],
[M,677,31,25092,677,40,25101],
[M,677,8,25069,677,19,25080],
[M,677,8,25069,677,75,25136],
[M,677,65,25126,677,74,25135],
[M,673,77,24866,673,95,24884],
[M,673,84,24873,673,94,24883],
[M,673,77,24866,673,83,24872],
[M,670,79,24669,670,97,24687],
[M,670,86,24676,670,96,24686],
[M,670,79,24669,670,85,24675],
[M,661,42,24229,661,53,24240],
[M,661,42,24229,661,48,24235],
[M,661,20,24207,661,75,24262],
[M,661,56,24243,661,75,24262],
[M,661,66,24253,661,74,24261],
[M,661,56,24243,661,65,24252],
[M,649,34,23730,649,52,23748],
[M,649,34,23730,649,50,23746],
[M,649,34,23730,649,41,23737],
[M,646,34,23576,646,52,23594],
[M,646,34,23576,646,50,23592],
[M,646,34,23576,646,41,23583],
[M,636,39,23195,636,66,23222],
[M,636,53,23209,636,65,23221],
[M,636,39,23195,636,52,23208],
[M,636,39,23195,636,48,23204],
[M,636,24,23180,636,37,23193],
[M,636,12,23168,636,23,23179],
[M,635,22,23140,635,29,23147],
[M,635,12,23130,635,21,23139],
[M,636,12,23168,636,67,23223],
[M,635,22,23140,636,68,23224],
[M,635,12,23130,636,69,23225],
[M,634,15,23100,636,70,23226],
[M,629,39,22923,629,66,22950],
[M,629,53,22937,629,65,22949],
[M,629,39,22923,629,52,22936],
[M,629,39,22923,629,48,22932],
[M,629,24,22908,629,37,22921],
[M,629,12,22896,629,23,22907],
[M,628,22,22868,628,29,22875],
[M,628,12,22858,628,21,22867],
[M,629,12,22896,629,67,22951],
[M,628,22,22868,629,68,22952],
[M,628,12,22858,629,69,22953],
[M,627,15,22825,629,70,22954],
[M,622,62,22670,622,81,22689],
[M,622,62,22670,622,79,22687],
[M,622,62,22670,622,70,22678],
[M,617,64,22471,617,83,22490],
[M,617,64,22471,617,81,22488],
[M,617,64,22471,617,72,22479],
[M,607,52,22024,607,76,22048],
[M,607,52,22024,607,74,22046],
[M,607,52,22024,607,65,22037],
[M,607,45,22017,607,106,22078],
[M,607,78,22050,607,105,22077],
[M,607,78,22050,607,103,22075],
[M,607,78,22050,607,94,22066],
[M,607,19,21991,607,107,22079],
[M,607,10,21982,607,108,22080],
[M,606,15,21962,608,24,22105],
[M,606,6,21953,608,24,22105],
[M,609,9,22115,609,30,22136],
[M,609,18,22124,609,29,22135],
[M,609,32,22138,609,50,22156],
[M,609,41,22147,609,50,22156],
[M,611,66,22235,611,95,22264],
[M,611,82,22251,611,94,22263],
[M,611,66,22235,611,81,22250],
[M,611,66,22235,611,77,22246],
[M,611,51,22220,611,64,22233],
[M,611,39,22208,611,50,22219],
[M,611,8,22177,611,19,22188],
[M,611,39,22208,611,96,22265],
[M,611,8,22177,611,108,22277],
[M,611,98,22267,611,107,22276],
[M,600,63,21688,600,85,21710],
[M,600,63,21688,600,69,21694],
[M,601,8,21746,601,37,21775],
[M,601,24,21762,601,36,21774],
[M,601,8,21746,601,23,21761],
[M,601,8,21746,601,19,21757],
[M,600,102,21727,600,111,21736],
[M,600,87,21712,600,100,21725],
[M,595,45,21484,595,74,21513],
[M,595,61,21500,595,73,21512],
[M,595,45,21484,595,60,21499],
[M,595,45,21484,595,56,21495],
[M,595,34,21473,595,43,21482],
[M,595,19,21458,595,32,21471],
[M,595,8,21447,595,17,21456],
[M,585,15,20990,587,78,21169],
[M,586,44,21068,586,66,21090],
[M,586,56,21080,586,65,21089],
[M,586,44,21068,586,53,21077],
[M,586,12,21036,586,32,21056],
[M,587,47,21138,587,76,21167],
[M,587,63,21154,587,75,21166],
[M,587,47,21138,587,62,21153],
[M,587,47,21138,587,58,21149],
[M,587,36,21127,587,45,21136],
[M,587,21,21112,587,34,21125],
[M,587,10,21101,587,19,21110],
[M,586,12,21036,587,77,21168],
[M,551,47,19850,551,99,19902],
[M,551,40,19843,551,100,19903],
[M,551,102,19905,551,122,19925],
[M,551,102,19905,551,120,19923],
[M,551,102,19905,551,111,19914],
[M,551,124,19927,551,145,19948],
[M,551,124,19927,551,143,19946],
[M,551,124,19927,551,134,19937],
[M,535,52,19131,535,85,19164],
[M,535,74,19153,535,84,19163],
[M,535,6,19085,535,85,19164],
[M,536,6,19171,548,9,19718],
[M,538,8,19230,547,13,19708],
[M,539,10,19263,547,13,19708],
[M,541,12,19333,546,71,19694],
[M,542,67,19425,542,89,19447],
[M,542,81,19439,542,88,19446],
[M,542,55,19413,542,62,19420],
[M,542,31,19389,542,37,19395],
[M,540,12,19293,540,39,19320],
[M,540,23,19304,540,37,19318],
[M,537,8,19201,537,28,19221],
[M,537,19,19212,537,28,19221],
[M,542,38,19396,542,90,19448],
[M,542,31,19389,542,91,19449],
[M,542,19,19377,542,103,19461],
[M,542,14,19372,542,103,19461],
[M,543,47,19509,543,64,19526],
[M,543,47,19509,543,62,19524],
[M,543,23,19485,545,17,19622],
[M,544,36,19585,544,54,19603],
[M,544,36,19585,544,52,19601],
[M,544,22,19571,544,30,19579],
[M,543,27,19489,543,37,19499],
[M,543,14,19476,545,17,19622],
[M,546,23,19646,546,39,19662],
[M,546,23,19646,546,37,19660],
[M,546,14,19637,546,22,19645],
[M,546,23,19646,546,71,19694],
[M,546,47,19670,546,70,19693],
[M,546,47,19670,546,54,19677],
[M,544,31,19580,544,55,19604],
[M,544,22,19571,544,55,19604],
[M,529,27,18922,529,47,18942],
[M,529,39,18934,529,46,18941],
[M,529,29,18924,529,35,18930],
[M,529,11,18906,529,23,18918],
[M,530,10,18954,530,41,18985],
[M,530,32,18976,530,40,18984],
[M,532,10,19045,532,21,19056],
[M,530,44,18988,530,76,19020],
[M,530,66,19010,530,75,19019],
[M,530,10,18954,530,76,19020],
[M,519,26,18465,519,46,18485],
[M,519,26,18465,519,44,18483],
[M,519,26,18465,519,35,18474],
[M,519,10,18449,519,17,18456],
[M,519,10,18449,519,47,18486],
[M,518,6,18412,519,59,18498],
[M,520,39,18538,520,57,18556],
[M,520,39,18538,520,55,18554],
[M,520,39,18538,520,46,18545],
[M,520,29,18528,520,38,18537],
[M,520,29,18528,520,58,18557],
[M,520,16,18515,521,62,18644],
[M,521,26,18608,521,49,18631],
[M,521,26,18608,521,47,18629],
[M,521,26,18608,521,38,18620],
[M,521,10,18592,521,17,18599],
[M,521,10,18592,521,50,18632],
[M,520,6,18505,521,62,18644],
[M,522,15,18660,522,40,18685],
[M,522,6,18651,522,14,18659],
[M,509,27,17958,509,57,17988],
[M,509,15,17946,510,41,18042],
[M,510,10,18011,510,29,18030],
[M,510,10,18011,510,27,18028],
[M,510,10,18011,510,18,18019],
[M,509,6,17937,510,41,18042],
[M,511,36,18079,511,89,18132],
[M,511,54,18097,511,88,18131],
[M,511,71,18114,511,83,18126],
[M,511,71,18114,511,81,18124],
[M,511,62,18105,511,70,18113],
[M,511,36,18079,511,53,18096],
[M,511,36,18079,511,49,18092],
[M,511,13,18056,511,24,18067],
[M,511,13,18056,511,90,18133],
[M,511,13,18056,512,82,18216],
[M,512,31,18165,512,82,18216],
[M,512,22,18156,512,30,18164],
[M,512,60,18194,512,81,18215],
[M,512,60,18194,512,79,18213],
[M,512,60,18194,512,70,18204],
[M,512,22,18156,512,82,18216],
[M,511,6,18049,512,82,18216],
[M,513,29,18246,513,45,18262],
[M,513,29,18246,513,37,18254],
[M,513,6,18223,513,17,18234],
[M,500,27,17500,500,57,17530],
[M,500,15,17488,501,41,17584],
[M,501,10,17553,501,29,17572],
[M,501,10,17553,501,27,17570],
[M,501,10,17553,501,18,17561],
[M,500,6,17479,501,41,17584],
[M,502,38,17623,502,67,17652],
[M,502,6,17591,502,26,17611],
[M,503,8,17661,503,24,17677],
[M,503,8,17661,503,16,17669],
[M,504,8,17707,504,61,17760],
[M,504,26,17725,504,60,17759],
[M,504,43,17742,504,55,17754],
[M,504,43,17742,504,53,17752],
[M,504,34,17733,504,42,17741],
[M,504,8,17707,504,25,17724],
[M,504,8,17707,504,21,17720],
[M,493,8,17136,493,51,17179],
[M,493,26,17154,493,50,17178],
[M,493,34,17162,493,44,17172],
[M,493,8,17136,493,25,17153],
[M,493,8,17136,493,21,17149],
[M,492,6,17078,493,52,17180],
[M,494,58,17239,494,79,17260],
[M,494,58,17239,494,77,17258],
[M,494,58,17239,494,68,17249],
[M,494,30,17211,494,37,17218],
[M,494,46,17227,494,80,17261],
[M,494,30,17211,494,80,17261],
[M,494,6,17187,494,80,17261],
[M,495,15,17277,495,66,17328],
[M,495,6,17268,495,14,17276],
[M,486,8,16845,486,51,16888],
[M,486,26,16863,486,50,16887],
[M,486,34,16871,486,44,16881],
[M,486,8,16845,486,25,16862],
[M,486,8,16845,486,21,16858],
[M,485,6,16787,486,52,16889],
[M,487,15,16905,487,46,16936],
[M,487,6,16896,487,14,16904],
[M,478,13,16422,478,90,16499],
[M,478,13,16422,479,102,16602],
[M,479,31,16531,479,102,16602],
[M,479,22,16522,479,30,16530],
[M,479,80,16580,479,101,16601],
[M,479,80,16580,479,99,16599],
[M,479,80,16580,479,90,16590],
[M,479,22,16522,479,102,16602],
[M,478,6,16415,479,102,16602],
[M,480,29,16632,480,51,16654],
[M,480,29,16632,480,37,16640],
[M,480,6,16609,480,17,16620],
[M,472,8,16153,472,30,16175],
[M,472,8,16153,472,16,16161],
[M,473,8,16205,473,61,16258],
[M,473,26,16223,473,60,16257],
[M,473,43,16240,473,55,16252],
[M,473,43,16240,473,53,16250],
[M,473,34,16231,473,42,16239],
[M,473,8,16205,473,25,16222],
[M,473,8,16205,473,21,16218],
[M,466,31,15868,466,108,15945],
[M,466,86,15923,466,107,15944],
[M,466,86,15923,466,105,15942],
[M,466,86,15923,466,96,15933],
[M,466,15,15852,466,108,15945],
[M,459,19,15627,459,50,15658],
[M,459,8,15616,459,63,15671],
[M,460,8,15680,460,29,15701],
[M,460,8,15680,460,27,15699],
[M,460,8,15680,460,18,15690],
[M,453,64,15438,453,83,15457],
[M,453,64,15438,453,81,15455],
[M,453,64,15438,453,72,15446],
[M,439,10,14843,440,88,14980],
[M,440,66,14958,440,87,14979],
[M,440,66,14958,440,85,14977],
[M,440,66,14958,440,76,14968],
[M,438,15,14817,440,88,14980],
[M,432,35,14577,433,65,14663],
[M,433,43,14641,433,64,14662],
[M,433,43,14641,433,62,14660],
[M,433,43,14641,433,53,14651],
[M,432,19,14561,433,65,14663],
[M,432,10,14552,433,66,14664],
[M,424,31,14301,426,46,14413],
[M,426,24,14391,426,45,14412],
[M,426,24,14391,426,43,14410],
[M,426,24,14391,426,34,14401],
[M,424,15,14285,426,46,14413],
[M,419,10,14064,419,93,14147],
[M,419,73,14127,419,92,14146],
[M,419,73,14127,419,90,14144],
[M,419,73,14127,419,81,14135],
[M,418,15,14038,419,93,14147],
[M,388,12,13100,388,39,13127],
[M,388,28,13116,388,38,13126],
[M,388,12,13100,388,27,13115],
[M,388,12,13100,388,23,13111],
[M,387,77,13077,387,86,13086],
[M,387,62,13062,387,75,13075],
[M,387,51,13051,387,60,13060],
[M,387,40,13040,387,49,13049],
[M,387,8,13008,387,28,13028],
[M,387,8,13008,388,40,13128],
[M,386,15,12977,388,41,13129],
[M,380,6,12708,381,27,12826],
[M,380,85,12787,380,96,12798],
[M,381,10,12809,381,27,12826],
[M,381,10,12809,381,25,12824],
[M,381,10,12809,381,16,12815],
[M,372,76,12405,372,87,12416],
[M,372,76,12405,372,82,12411],
[M,372,63,12392,372,88,12417],
[M,373,10,12454,373,38,12482],
[M,373,25,12469,373,37,12481],
[M,373,10,12454,373,24,12468],
[M,373,10,12454,373,20,12464],
[M,372,104,12433,372,113,12442],
[M,372,89,12418,372,102,12431],
[M,372,15,12344,373,39,12483],
[M,372,6,12335,374,21,12505],
[M,375,37,12543,375,57,12563],
[M,375,37,12543,375,55,12561],
[M,375,37,12543,375,46,12552],
[M,375,6,12512,375,17,12523],
[M,364,70,12029,364,81,12040],
[M,364,70,12029,364,76,12035],
[M,364,60,12019,364,82,12041],
[M,365,10,12078,365,38,12106],
[M,365,25,12093,365,37,12105],
[M,365,10,12078,365,24,12092],
[M,365,10,12078,365,20,12088],
[M,364,98,12057,364,107,12066],
[M,364,83,12042,364,96,12055],
[M,364,15,11974,365,39,12107],
[M,364,6,11965,366,21,12129],
[M,367,37,12167,367,57,12187],
[M,367,37,12167,367,55,12185],
[M,367,37,12167,367,46,12176],
[M,367,6,12136,367,17,12147],
[M,356,80,11663,356,91,11674],
[M,356,80,11663,356,86,11669],
[M,356,65,11648,356,92,11675],
[M,357,10,11712,357,38,11740],
[M,357,25,11727,357,37,11739],
[M,357,10,11712,357,24,11726],
[M,357,10,11712,357,20,11722],
[M,356,108,11691,356,117,11700],
[M,356,93,11676,356,106,11689],
[M,356,15,11598,357,39,11741],
[M,356,6,11589,358,21,11763],
[M,359,37,11801,359,57,11821],
[M,359,37,11801,359,55,11819],
[M,359,37,11801,359,46,11810],
[M,359,6,11770,359,17,11781],
[M,347,43,11079,347,59,11095],
[M,347,43,11079,347,49,11085],
[M,347,12,11048,347,20,11056],
[M,346,77,11029,351,85,11439],
[M,346,62,11014,346,75,11027],
[M,346,47,10999,346,60,11012],
[M,346,35,10987,346,46,10998],
[M,346,25,10977,346,34,10986],
[M,347,61,11097,347,83,11119],
[M,347,61,11097,347,81,11117],
[M,347,61,11097,347,72,11108],
[M,347,12,11048,347,84,11120],
[M,348,43,11165,348,61,11183],
[M,348,43,11165,348,49,11171],
[M,348,12,11134,348,20,11142],
[M,348,63,11185,348,87,11209],
[M,348,63,11185,348,85,11207],
[M,348,63,11185,348,76,11198],
[M,348,12,11134,348,88,11210],
[M,349,42,11254,349,57,11269],
[M,349,42,11254,349,48,11260],
[M,349,12,11224,349,20,11232],
[M,350,26,11298,350,78,11350],
[M,350,67,11339,350,77,11349],
[M,350,53,11325,350,65,11337],
[M,350,38,11310,350,51,11323],
[M,350,26,11298,350,37,11309],
[M,350,14,11286,350,25,11297],
[M,350,14,11286,350,79,11351],
[M,349,12,11224,350,80,11352],
[M,351,43,11397,351,59,11413],
[M,351,43,11397,351,49,11403],
[M,351,12,11366,351,20,11374],
[M,351,61,11415,351,83,11437],
[M,351,61,11415,351,81,11435],
[M,351,61,11415,351,72,11426],
[M,351,12,11366,351,84,11438],
[M,346,35,10987,351,86,11440],
[M,346,25,10977,351,87,11441],
[M,781,38,29306,781,77,29345],
[M,331,31,10536,333,46,10648],
[M,333,24,10626,333,45,10647],
[M,333,24,10626,333,43,10645],
[M,333,24,10626,333,34,10636],
[M,331,15,10520,333,46,10648],
[M,326,31,10300,326,103,10372],
[M,326,83,10352,326,102,10371],
[M,326,83,10352,326,100,10369],
[M,326,83,10352,326,91,10360],
[M,326,15,10284,326,103,10372],
[M,337,38,10729,337,77,10768],
[M,314,31,9929,314,102,10000],
[M,314,80,9978,314,101,9999],
[M,314,80,9978,314,99,9997],
[M,314,80,9978,314,90,9988],
[M,314,15,9913,314,102,10000],
[M,318,38,10081,318,77,10120],
[M,303,48,9593,303,65,9610],
[M,303,48,9593,303,63,9608],
[M,303,48,9593,303,54,9599],
[M,303,31,9576,303,119,9664],
[M,303,97,9642,303,118,9663],
[M,303,97,9642,303,116,9661],
[M,303,97,9642,303,107,9652],
[M,303,15,9560,303,119,9664],
[M,299,31,9387,299,102,9458],
[M,299,80,9436,299,101,9457],
[M,299,80,9436,299,99,9455],
[M,299,80,9436,299,90,9446],
[M,299,15,9371,299,102,9458],
[M,307,38,9745,307,77,9784],
[M,289,44,9108,289,68,9132],
[M,289,34,9098,289,69,9133],
[M,292,38,9209,292,77,9248],
[M,283,38,8967,283,77,9006],
[M,257,70,8084,257,79,8093],
[M,257,82,8096,257,91,8105],
[M,258,8,8115,258,50,8157],
[M,258,40,8147,258,49,8156],
[M,259,8,8192,259,34,8218],
[M,259,21,8205,259,33,8217],
[M,259,8,8192,259,20,8204],
[M,259,8,8192,259,16,8200],
[M,258,66,8173,258,75,8182],
[M,258,51,8158,258,64,8171],
[M,269,38,8550,269,77,8589],
[M,249,38,7823,249,77,7862],
[M,226,20,7165,226,40,7185],
[M,226,20,7165,226,38,7183],
[M,226,20,7165,226,29,7174],
[M,219,63,6845,219,83,6865],
[M,219,63,6845,219,81,6863],
[M,219,63,6845,219,72,6854],
[M,219,95,6877,219,116,6898],
[M,219,95,6877,219,114,6896],
[M,219,95,6877,219,105,6887],
[M,219,85,6867,219,93,6875],
[M,214,63,6608,214,83,6628],
[M,214,63,6608,214,81,6626],
[M,214,63,6608,214,72,6617],
[M,230,38,7267,230,77,7306],
[M,199,12,6147,199,42,6177],
[M,199,12,6147,199,40,6175],
[M,199,12,6147,199,31,6166],
[M,200,14,6193,200,44,6223],
[M,200,31,6210,200,43,6222],
[M,200,14,6193,200,30,6209],
[M,200,14,6193,200,26,6205],
[M,197,10,6090,201,43,6267],
[M,201,21,6245,201,42,6266],
[M,201,21,6245,201,40,6264],
[M,201,21,6245,201,31,6255],
[M,201,14,6238,201,43,6267],
[M,196,8,6071,202,11,6279],
[M,206,38,6360,206,77,6399],
[M,158,27,4790,158,36,4799],
[M,160,8,4898,160,32,4922],
[M,160,19,4909,160,31,4921],
[M,160,8,4898,160,18,4908],
[M,159,79,4879,159,88,4888],
[M,159,64,4864,159,77,4877],
[M,159,53,4853,159,62,4862],
[M,159,42,4842,159,51,4851],
[M,159,10,4810,159,30,4830],
[M,163,36,4997,163,58,5019],
[M,163,48,5009,163,57,5018],
[M,163,36,4997,163,45,5006],
[M,163,4,4965,163,24,4985],
[M,162,13,4945,162,20,4952],
[M,159,10,4810,160,33,4923],
[M,164,6,5063,164,40,5097],
[M,164,15,5072,164,39,5096],
[M,164,23,5080,164,33,5090],
[M,164,6,5063,164,14,5071],
[M,163,85,5046,163,94,5055],
[M,163,70,5031,163,83,5044],
[M,163,59,5020,163,68,5029],
[M,163,4,4965,164,41,5098],
[M,162,2,4934,164,42,5099],
[M,165,2,5102,165,28,5128],
[M,167,7,5146,167,23,5162],
[M,167,25,5164,167,30,5169],
[M,168,4,5174,168,45,5215],
[M,168,12,5182,168,24,5194],
[M,172,7,5277,172,17,5287],
[M,172,7,5277,172,42,5312],
[M,168,33,5203,168,45,5215],
[M,168,33,5203,168,39,5209],
[M,169,25,5241,169,36,5252],
[M,169,18,5234,169,24,5240],
[M,168,12,5182,168,31,5201],
[M,169,18,5234,169,36,5252],
[M,169,10,5226,169,36,5252],
[M,172,7,5277,172,22,5292],
[M,172,43,5313,172,52,5322],
[M,173,10,5333,173,53,5376],
[M,175,20,5405,175,56,5441],
[M,175,11,5396,175,19,5404],
[M,172,26,5296,172,41,5311],
[M,173,39,5362,173,53,5376],
[M,173,39,5362,173,51,5374],
[M,175,2,5387,175,56,5441],
[M,176,2,5444,179,5,5539],
[M,176,12,5454,179,5,5539],
[M,178,4,5504,178,33,5533],
[M,178,19,5519,178,31,5531],
[M,177,4,5480,177,23,5499],
[M,177,14,5490,177,23,5499],
[M,181,7,5558,181,28,5579],
[M,181,7,5558,181,19,5570],
[M,181,30,5581,181,37,5588],
[M,182,10,5599,182,61,5650],
[M,182,10,5599,182,21,5610],
[M,185,7,5677,185,38,5708],
[M,185,25,5695,185,37,5707],
[M,185,7,5677,185,22,5692],
[M,185,39,5709,185,48,5718],
[M,186,30,5749,186,41,5760],
[M,186,30,5749,186,36,5755],
[M,186,20,5739,186,29,5748],
[M,188,42,5826,188,57,5841],
[M,188,42,5826,188,55,5839],
[M,188,2,5786,188,13,5797],
[M,186,20,5739,186,42,5761],
[M,186,10,5729,186,56,5775],
[M,186,45,5764,186,56,5775],
[M,188,33,5817,188,58,5842],
[M,134,4,4159,136,7,4255],
[M,135,48,4234,135,60,4246],
[M,134,9,4164,134,29,4184],
[M,137,13,4269,137,22,4278],
[M,135,12,4198,135,61,4247],
[M,135,6,4192,135,61,4247],
[M,120,37,3707,120,58,3728],
[M,120,46,3716,120,57,3727],
[M,127,38,4038,127,79,4079],
[M,125,44,3959,125,55,3970],
[M,125,44,3959,125,53,3968],
[M,124,42,3898,124,53,3909],
[M,124,42,3898,124,51,3907],
[M,123,41,3839,123,52,3850],
[M,123,41,3839,123,50,3848],
[M,122,39,3781,122,50,3792],
[M,122,39,3781,122,48,3790],
[M,3,0,13,2497,1,79500],
[M,9,11,112,9,19,120],
[M,11,0,122,11,39,161],
[M,11,12,134,11,21,143]];
var _greaterequal51 = NAMESPACE.get("_greaterequal");
var _greaterthan52 = NAMESPACE.get("_greaterthan");
var _lessequal53 = NAMESPACE.get("_lessequal");
var _lessthan54 = NAMESPACE.get("_lessthan");
var _plus55 = NAMESPACE.get("_plus");
var _times56 = NAMESPACE.get("_times");
var builtins57 = NAMESPACE.get("builtins");
var is_DASH_nothing58 = NAMESPACE.get("is-nothing");
var is_DASH_string59 = NAMESPACE.get("is-string");
var not60 = NAMESPACE.get("not");
var nothing61 = NAMESPACE.get("nothing");
var raise62 = NAMESPACE.get("raise");
var string_DASH_length63 = NAMESPACE.get("string-length");
var string_DASH_substring64 = NAMESPACE.get("string-substring");
var torepr65 = NAMESPACE.get("torepr");
var tostring66 = NAMESPACE.get("tostring");
var $type$Boolean67 = NAMESPACE.get("$type$Boolean");
var $type$Number68 = NAMESPACE.get("$type$Number");
var $type$String69 = NAMESPACE.get("$type$String");
var $Hdummy_DASH_loc1150995 = function(dummy_DASH_loc11796,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var INDENT118169 = (2);
var anf_fun2167 = G(PP170,"sbreak",L[1]);
var $z159160 = D;
var $f165166 = function(_) {
return R.isFunction(anf_fun2167)?anf_fun2167.app((1)):R.ffi.throwNonFunApp(L[0],anf_fun2167,[(1)]);
};
try {
if(--R.GAS > 0) {
$z159160 = $f165166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f165166,
"from":L[0]});
}
} catch($e157158) {
if(R.isCont($e157158)) {
var $ss161162 = {"from":L[0],
"go":function(break_DASH_one119168) {
return $Hbreak_DASH_one11508170(break_DASH_one119168,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e157158.stack[R.EXN_STACKHEIGHT++] = $ss161162;
}
if(R.isPyretException($e157158)) {
$e157158.pyretStack.push(L[0]);
}
throw $e157158;
}
var $ret163164 = $Hbreak_DASH_one11508170($z159160,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret163164;
};
var $Hbreak_DASH_one11508170 = function(break_DASH_one119168,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun3181 = G(PP170,"str",L[3]);
var $z173174 = D;
var $f179180 = function(_) {
return R.isFunction(anf_fun3181)?anf_fun3181.app(("Any")):R.ffi.throwNonFunApp(L[2],anf_fun3181,[("Any")]);
};
try {
if(--R.GAS > 0) {
$z173174 = $f179180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f179180,
"from":L[2]});
}
} catch($e171172) {
if(R.isCont($e171172)) {
var $ss175176 = {"from":L[2],
"go":function(str_DASH_any120182) {
return $Hstr_DASH_any11507183(str_DASH_any120182,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e171172.stack[R.EXN_STACKHEIGHT++] = $ss175176;
}
if(R.isPyretException($e171172)) {
$e171172.pyretStack.push(L[2]);
}
throw $e171172;
}
var $ret177178 = $Hstr_DASH_any11507183($z173174,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret177178;
};
var $Hstr_DASH_any11507183 = function(str_DASH_any120182,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun4194 = G(PP170,"str",L[5]);
var $z186187 = D;
var $f192193 = function(_) {
return R.isFunction(anf_fun4194)?anf_fun4194.app(("->")):R.ffi.throwNonFunApp(L[4],anf_fun4194,[("->")]);
};
try {
if(--R.GAS > 0) {
$z186187 = $f192193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f192193,
"from":L[4]});
}
} catch($e184185) {
if(R.isCont($e184185)) {
var $ss188189 = {"from":L[4],
"go":function(str_DASH_arrow121195) {
return $Hstr_DASH_arrow11506196(str_DASH_arrow121195,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e184185.stack[R.EXN_STACKHEIGHT++] = $ss188189;
}
if(R.isPyretException($e184185)) {
$e184185.pyretStack.push(L[4]);
}
throw $e184185;
}
var $ret190191 = $Hstr_DASH_arrow11506196($z186187,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret190191;
};
var $Hstr_DASH_arrow11506196 = function(str_DASH_arrow121195,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun5207 = G(PP170,"str",L[7]);
var $z199200 = D;
var $f205206 = function(_) {
return R.isFunction(anf_fun5207)?anf_fun5207.app(("-> ")):R.ffi.throwNonFunApp(L[6],anf_fun5207,[("-> ")]);
};
try {
if(--R.GAS > 0) {
$z199200 = $f205206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f205206,
"from":L[6]});
}
} catch($e197198) {
if(R.isCont($e197198)) {
var $ss201202 = {"from":L[6],
"go":function(str_DASH_arrowspace122208) {
return $Hstr_DASH_arrowspace11505209(str_DASH_arrowspace122208,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e197198.stack[R.EXN_STACKHEIGHT++] = $ss201202;
}
if(R.isPyretException($e197198)) {
$e197198.pyretStack.push(L[6]);
}
throw $e197198;
}
var $ret203204 = $Hstr_DASH_arrowspace11505209($z199200,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret203204;
};
var $Hstr_DASH_arrowspace11505209 = function(str_DASH_arrowspace122208,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun6220 = G(PP170,"str",L[9]);
var $z212213 = D;
var $f218219 = function(_) {
return R.isFunction(anf_fun6220)?anf_fun6220.app(("as")):R.ffi.throwNonFunApp(L[8],anf_fun6220,[("as")]);
};
try {
if(--R.GAS > 0) {
$z212213 = $f218219();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f218219,
"from":L[8]});
}
} catch($e210211) {
if(R.isCont($e210211)) {
var $ss214215 = {"from":L[8],
"go":function(str_DASH_as123221) {
return $Hstr_DASH_as11504222(str_DASH_as123221,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e210211.stack[R.EXN_STACKHEIGHT++] = $ss214215;
}
if(R.isPyretException($e210211)) {
$e210211.pyretStack.push(L[8]);
}
throw $e210211;
}
var $ret216217 = $Hstr_DASH_as11504222($z212213,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret216217;
};
var $Hstr_DASH_as11504222 = function(str_DASH_as123221,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun7233 = G(PP170,"str",L[11]);
var $z225226 = D;
var $f231232 = function(_) {
return R.isFunction(anf_fun7233)?anf_fun7233.app(("")):R.ffi.throwNonFunApp(L[10],anf_fun7233,[("")]);
};
try {
if(--R.GAS > 0) {
$z225226 = $f231232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f231232,
"from":L[10]});
}
} catch($e223224) {
if(R.isCont($e223224)) {
var $ss227228 = {"from":L[10],
"go":function(str_DASH_blank124234) {
return $Hstr_DASH_blank11503235(str_DASH_blank124234,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e223224.stack[R.EXN_STACKHEIGHT++] = $ss227228;
}
if(R.isPyretException($e223224)) {
$e223224.pyretStack.push(L[10]);
}
throw $e223224;
}
var $ret229230 = $Hstr_DASH_blank11503235($z225226,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret229230;
};
var $Hstr_DASH_blank11503235 = function(str_DASH_blank124234,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun8246 = G(PP170,"str",L[13]);
var $z238239 = D;
var $f244245 = function(_) {
return R.isFunction(anf_fun8246)?anf_fun8246.app(("let")):R.ffi.throwNonFunApp(L[12],anf_fun8246,[("let")]);
};
try {
if(--R.GAS > 0) {
$z238239 = $f244245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f244245,
"from":L[12]});
}
} catch($e236237) {
if(R.isCont($e236237)) {
var $ss240241 = {"from":L[12],
"go":function(str_DASH_let125247) {
return $Hstr_DASH_let11502248(str_DASH_let125247,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e236237.stack[R.EXN_STACKHEIGHT++] = $ss240241;
}
if(R.isPyretException($e236237)) {
$e236237.pyretStack.push(L[12]);
}
throw $e236237;
}
var $ret242243 = $Hstr_DASH_let11502248($z238239,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret242243;
};
var $Hstr_DASH_let11502248 = function(str_DASH_let125247,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun9259 = G(PP170,"str",L[15]);
var $z251252 = D;
var $f257258 = function(_) {
return R.isFunction(anf_fun9259)?anf_fun9259.app(("type-let")):R.ffi.throwNonFunApp(L[14],anf_fun9259,[("type-let")]);
};
try {
if(--R.GAS > 0) {
$z251252 = $f257258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f257258,
"from":L[14]});
}
} catch($e249250) {
if(R.isCont($e249250)) {
var $ss253254 = {"from":L[14],
"go":function(str_DASH_type_DASH_let126260) {
return $Hstr_DASH_type_DASH_let11501261(str_DASH_type_DASH_let126260,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e249250.stack[R.EXN_STACKHEIGHT++] = $ss253254;
}
if(R.isPyretException($e249250)) {
$e249250.pyretStack.push(L[14]);
}
throw $e249250;
}
var $ret255256 = $Hstr_DASH_type_DASH_let11501261($z251252,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret255256;
};
var $Hstr_DASH_type_DASH_let11501261 = function(str_DASH_type_DASH_let126260,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun10272 = G(PP170,"str",L[17]);
var $z264265 = D;
var $f270271 = function(_) {
return R.isFunction(anf_fun10272)?anf_fun10272.app(("letrec")):R.ffi.throwNonFunApp(L[16],anf_fun10272,[("letrec")]);
};
try {
if(--R.GAS > 0) {
$z264265 = $f270271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f270271,
"from":L[16]});
}
} catch($e262263) {
if(R.isCont($e262263)) {
var $ss266267 = {"from":L[16],
"go":function(str_DASH_letrec127273) {
return $Hstr_DASH_letrec11500274(str_DASH_letrec127273,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e262263.stack[R.EXN_STACKHEIGHT++] = $ss266267;
}
if(R.isPyretException($e262263)) {
$e262263.pyretStack.push(L[16]);
}
throw $e262263;
}
var $ret268269 = $Hstr_DASH_letrec11500274($z264265,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret268269;
};
var $Hstr_DASH_letrec11500274 = function(str_DASH_letrec127273,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun11285 = G(PP170,"str",L[19]);
var $z277278 = D;
var $f283284 = function(_) {
return R.isFunction(anf_fun11285)?anf_fun11285.app(("block:")):R.ffi.throwNonFunApp(L[18],anf_fun11285,[("block:")]);
};
try {
if(--R.GAS > 0) {
$z277278 = $f283284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f283284,
"from":L[18]});
}
} catch($e275276) {
if(R.isCont($e275276)) {
var $ss279280 = {"from":L[18],
"go":function(str_DASH_block128286) {
return $Hstr_DASH_block11499287(str_DASH_block128286,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e275276.stack[R.EXN_STACKHEIGHT++] = $ss279280;
}
if(R.isPyretException($e275276)) {
$e275276.pyretStack.push(L[18]);
}
throw $e275276;
}
var $ret281282 = $Hstr_DASH_block11499287($z277278,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret281282;
};
var $Hstr_DASH_block11499287 = function(str_DASH_block128286,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun12298 = G(PP170,"str",L[21]);
var $z290291 = D;
var $f296297 = function(_) {
return R.isFunction(anf_fun12298)?anf_fun12298.app(("[list: ]")):R.ffi.throwNonFunApp(L[20],anf_fun12298,[("[list: ]")]);
};
try {
if(--R.GAS > 0) {
$z290291 = $f296297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f296297,
"from":L[20]});
}
} catch($e288289) {
if(R.isCont($e288289)) {
var $ss292293 = {"from":L[20],
"go":function(str_DASH_brackets129299) {
return $Hstr_DASH_brackets11498300(str_DASH_brackets129299,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e288289.stack[R.EXN_STACKHEIGHT++] = $ss292293;
}
if(R.isPyretException($e288289)) {
$e288289.pyretStack.push(L[20]);
}
throw $e288289;
}
var $ret294295 = $Hstr_DASH_brackets11498300($z290291,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret294295;
};
var $Hstr_DASH_brackets11498300 = function(str_DASH_brackets129299,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun13311 = G(PP170,"str",L[23]);
var $z303304 = D;
var $f309310 = function(_) {
return R.isFunction(anf_fun13311)?anf_fun13311.app(("cases")):R.ffi.throwNonFunApp(L[22],anf_fun13311,[("cases")]);
};
try {
if(--R.GAS > 0) {
$z303304 = $f309310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f309310,
"from":L[22]});
}
} catch($e301302) {
if(R.isCont($e301302)) {
var $ss305306 = {"from":L[22],
"go":function(str_DASH_cases130312) {
return $Hstr_DASH_cases11497313(str_DASH_cases130312,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e301302.stack[R.EXN_STACKHEIGHT++] = $ss305306;
}
if(R.isPyretException($e301302)) {
$e301302.pyretStack.push(L[22]);
}
throw $e301302;
}
var $ret307308 = $Hstr_DASH_cases11497313($z303304,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret307308;
};
var $Hstr_DASH_cases11497313 = function(str_DASH_cases130312,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun14324 = G(PP170,"str",L[25]);
var $z316317 = D;
var $f322323 = function(_) {
return R.isFunction(anf_fun14324)?anf_fun14324.app(("^")):R.ffi.throwNonFunApp(L[24],anf_fun14324,[("^")]);
};
try {
if(--R.GAS > 0) {
$z316317 = $f322323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f322323,
"from":L[24]});
}
} catch($e314315) {
if(R.isCont($e314315)) {
var $ss318319 = {"from":L[24],
"go":function(str_DASH_caret131325) {
return $Hstr_DASH_caret11496326(str_DASH_caret131325,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_cases130312,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e314315.stack[R.EXN_STACKHEIGHT++] = $ss318319;
}
if(R.isPyretException($e314315)) {
$e314315.pyretStack.push(L[24]);
}
throw $e314315;
}
var $ret320321 = $Hstr_DASH_caret11496326($z316317,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_cases130312,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret320321;
};
var $Hstr_DASH_caret11496326 = function(str_DASH_caret131325,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_cases130312,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun15337 = G(PP170,"str",L[27]);
var $z329330 = D;
var $f335336 = function(_) {
return R.isFunction(anf_fun15337)?anf_fun15337.app(("check:")):R.ffi.throwNonFunApp(L[26],anf_fun15337,[("check:")]);
};
try {
if(--R.GAS > 0) {
$z329330 = $f335336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f335336,
"from":L[26]});
}
} catch($e327328) {
if(R.isCont($e327328)) {
var $ss331332 = {"from":L[26],
"go":function(str_DASH_checkcolon132338) {
return $Hstr_DASH_checkcolon11495339(str_DASH_checkcolon132338,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e327328.stack[R.EXN_STACKHEIGHT++] = $ss331332;
}
if(R.isPyretException($e327328)) {
$e327328.pyretStack.push(L[26]);
}
throw $e327328;
}
var $ret333334 = $Hstr_DASH_checkcolon11495339($z329330,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret333334;
};
var $Hstr_DASH_checkcolon11495339 = function(str_DASH_checkcolon132338,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun16350 = G(PP170,"str",L[29]);
var $z342343 = D;
var $f348349 = function(_) {
return R.isFunction(anf_fun16350)?anf_fun16350.app(("examples:")):R.ffi.throwNonFunApp(L[28],anf_fun16350,[("examples:")]);
};
try {
if(--R.GAS > 0) {
$z342343 = $f348349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f348349,
"from":L[28]});
}
} catch($e340341) {
if(R.isCont($e340341)) {
var $ss344345 = {"from":L[28],
"go":function(str_DASH_examplescolon133351) {
return $Hstr_DASH_examplescolon11494352(str_DASH_examplescolon133351,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e340341.stack[R.EXN_STACKHEIGHT++] = $ss344345;
}
if(R.isPyretException($e340341)) {
$e340341.pyretStack.push(L[28]);
}
throw $e340341;
}
var $ret346347 = $Hstr_DASH_examplescolon11494352($z342343,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret346347;
};
var $Hstr_DASH_examplescolon11494352 = function(str_DASH_examplescolon133351,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun17363 = G(PP170,"str",L[31]);
var $z355356 = D;
var $f361362 = function(_) {
return R.isFunction(anf_fun17363)?anf_fun17363.app((":")):R.ffi.throwNonFunApp(L[30],anf_fun17363,[(":")]);
};
try {
if(--R.GAS > 0) {
$z355356 = $f361362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f361362,
"from":L[30]});
}
} catch($e353354) {
if(R.isCont($e353354)) {
var $ss357358 = {"from":L[30],
"go":function(str_DASH_colon134364) {
return $Hstr_DASH_colon11493365(str_DASH_colon134364,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e353354.stack[R.EXN_STACKHEIGHT++] = $ss357358;
}
if(R.isPyretException($e353354)) {
$e353354.pyretStack.push(L[30]);
}
throw $e353354;
}
var $ret359360 = $Hstr_DASH_colon11493365($z355356,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret359360;
};
var $Hstr_DASH_colon11493365 = function(str_DASH_colon134364,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun18376 = G(PP170,"str",L[33]);
var $z368369 = D;
var $f374375 = function(_) {
return R.isFunction(anf_fun18376)?anf_fun18376.app(("::")):R.ffi.throwNonFunApp(L[32],anf_fun18376,[("::")]);
};
try {
if(--R.GAS > 0) {
$z368369 = $f374375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f374375,
"from":L[32]});
}
} catch($e366367) {
if(R.isCont($e366367)) {
var $ss370371 = {"from":L[32],
"go":function(str_DASH_coloncolon135377) {
return $Hstr_DASH_coloncolon11492378(str_DASH_coloncolon135377,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e366367.stack[R.EXN_STACKHEIGHT++] = $ss370371;
}
if(R.isPyretException($e366367)) {
$e366367.pyretStack.push(L[32]);
}
throw $e366367;
}
var $ret372373 = $Hstr_DASH_coloncolon11492378($z368369,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret372373;
};
var $Hstr_DASH_coloncolon11492378 = function(str_DASH_coloncolon135377,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun19389 = G(PP170,"str",L[35]);
var $z381382 = D;
var $f387388 = function(_) {
return R.isFunction(anf_fun19389)?anf_fun19389.app((": ")):R.ffi.throwNonFunApp(L[34],anf_fun19389,[(": ")]);
};
try {
if(--R.GAS > 0) {
$z381382 = $f387388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f387388,
"from":L[34]});
}
} catch($e379380) {
if(R.isCont($e379380)) {
var $ss383384 = {"from":L[34],
"go":function(str_DASH_colonspace136390) {
return $Hstr_DASH_colonspace11491391(str_DASH_colonspace136390,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e379380.stack[R.EXN_STACKHEIGHT++] = $ss383384;
}
if(R.isPyretException($e379380)) {
$e379380.pyretStack.push(L[34]);
}
throw $e379380;
}
var $ret385386 = $Hstr_DASH_colonspace11491391($z381382,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret385386;
};
var $Hstr_DASH_colonspace11491391 = function(str_DASH_colonspace136390,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun20402 = G(PP170,"str",L[37]);
var $z394395 = D;
var $f400401 = function(_) {
return R.isFunction(anf_fun20402)?anf_fun20402.app(("# ")):R.ffi.throwNonFunApp(L[36],anf_fun20402,[("# ")]);
};
try {
if(--R.GAS > 0) {
$z394395 = $f400401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f400401,
"from":L[36]});
}
} catch($e392393) {
if(R.isCont($e392393)) {
var $ss396397 = {"from":L[36],
"go":function(str_DASH_comment137403) {
return $Hstr_DASH_comment11490404(str_DASH_comment137403,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e392393.stack[R.EXN_STACKHEIGHT++] = $ss396397;
}
if(R.isPyretException($e392393)) {
$e392393.pyretStack.push(L[36]);
}
throw $e392393;
}
var $ret398399 = $Hstr_DASH_comment11490404($z394395,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret398399;
};
var $Hstr_DASH_comment11490404 = function(str_DASH_comment137403,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun21415 = G(PP170,"str",L[39]);
var $z407408 = D;
var $f413414 = function(_) {
return R.isFunction(anf_fun21415)?anf_fun21415.app(("with constructor")):R.ffi.throwNonFunApp(L[38],anf_fun21415,[("with constructor")]);
};
try {
if(--R.GAS > 0) {
$z407408 = $f413414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f413414,
"from":L[38]});
}
} catch($e405406) {
if(R.isCont($e405406)) {
var $ss409410 = {"from":L[38],
"go":function(str_DASH_constructor138416) {
return $Hstr_DASH_constructor11489417(str_DASH_constructor138416,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e405406.stack[R.EXN_STACKHEIGHT++] = $ss409410;
}
if(R.isPyretException($e405406)) {
$e405406.pyretStack.push(L[38]);
}
throw $e405406;
}
var $ret411412 = $Hstr_DASH_constructor11489417($z407408,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret411412;
};
var $Hstr_DASH_constructor11489417 = function(str_DASH_constructor138416,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun22428 = G(PP170,"str",L[41]);
var $z420421 = D;
var $f426427 = function(_) {
return R.isFunction(anf_fun22428)?anf_fun22428.app(("data ")):R.ffi.throwNonFunApp(L[40],anf_fun22428,[("data ")]);
};
try {
if(--R.GAS > 0) {
$z420421 = $f426427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f426427,
"from":L[40]});
}
} catch($e418419) {
if(R.isCont($e418419)) {
var $ss422423 = {"from":L[40],
"go":function(str_DASH_data139429) {
return $Hstr_DASH_data11488430(str_DASH_data139429,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e418419.stack[R.EXN_STACKHEIGHT++] = $ss422423;
}
if(R.isPyretException($e418419)) {
$e418419.pyretStack.push(L[40]);
}
throw $e418419;
}
var $ret424425 = $Hstr_DASH_data11488430($z420421,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret424425;
};
var $Hstr_DASH_data11488430 = function(str_DASH_data139429,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun23441 = G(PP170,"str",L[43]);
var $z433434 = D;
var $f439440 = function(_) {
return R.isFunction(anf_fun23441)?anf_fun23441.app(("data-expr ")):R.ffi.throwNonFunApp(L[42],anf_fun23441,[("data-expr ")]);
};
try {
if(--R.GAS > 0) {
$z433434 = $f439440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f439440,
"from":L[42]});
}
} catch($e431432) {
if(R.isCont($e431432)) {
var $ss435436 = {"from":L[42],
"go":function(str_DASH_data_DASH_expr140442) {
return $Hstr_DASH_data_DASH_expr11487443(str_DASH_data_DASH_expr140442,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data139429,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e431432.stack[R.EXN_STACKHEIGHT++] = $ss435436;
}
if(R.isPyretException($e431432)) {
$e431432.pyretStack.push(L[42]);
}
throw $e431432;
}
var $ret437438 = $Hstr_DASH_data_DASH_expr11487443($z433434,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data139429,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret437438;
};
var $Hstr_DASH_data_DASH_expr11487443 = function(str_DASH_data_DASH_expr140442,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data139429,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun24454 = G(PP170,"str",L[45]);
var $z446447 = D;
var $f452453 = function(_) {
return R.isFunction(anf_fun24454)?anf_fun24454.app(("datatype ")):R.ffi.throwNonFunApp(L[44],anf_fun24454,[("datatype ")]);
};
try {
if(--R.GAS > 0) {
$z446447 = $f452453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f452453,
"from":L[44]});
}
} catch($e444445) {
if(R.isCont($e444445)) {
var $ss448449 = {"from":L[44],
"go":function(str_DASH_datatype141455) {
return $Hstr_DASH_datatype11486456(str_DASH_datatype141455,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e444445.stack[R.EXN_STACKHEIGHT++] = $ss448449;
}
if(R.isPyretException($e444445)) {
$e444445.pyretStack.push(L[44]);
}
throw $e444445;
}
var $ret450451 = $Hstr_DASH_datatype11486456($z446447,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret450451;
};
var $Hstr_DASH_datatype11486456 = function(str_DASH_datatype141455,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun25467 = G(PP170,"str",L[47]);
var $z459460 = D;
var $f465466 = function(_) {
return R.isFunction(anf_fun25467)?anf_fun25467.app(("deriving ")):R.ffi.throwNonFunApp(L[46],anf_fun25467,[("deriving ")]);
};
try {
if(--R.GAS > 0) {
$z459460 = $f465466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f465466,
"from":L[46]});
}
} catch($e457458) {
if(R.isCont($e457458)) {
var $ss461462 = {"from":L[46],
"go":function(str_DASH_deriving142468) {
return $Hstr_DASH_deriving11485469(str_DASH_deriving142468,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e457458.stack[R.EXN_STACKHEIGHT++] = $ss461462;
}
if(R.isPyretException($e457458)) {
$e457458.pyretStack.push(L[46]);
}
throw $e457458;
}
var $ret463464 = $Hstr_DASH_deriving11485469($z459460,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret463464;
};
var $Hstr_DASH_deriving11485469 = function(str_DASH_deriving142468,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun26480 = G(PP170,"str",L[49]);
var $z472473 = D;
var $f478479 = function(_) {
return R.isFunction(anf_fun26480)?anf_fun26480.app(("doc: ")):R.ffi.throwNonFunApp(L[48],anf_fun26480,[("doc: ")]);
};
try {
if(--R.GAS > 0) {
$z472473 = $f478479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f478479,
"from":L[48]});
}
} catch($e470471) {
if(R.isCont($e470471)) {
var $ss474475 = {"from":L[48],
"go":function(str_DASH_doc143481) {
return $Hstr_DASH_doc11484482(str_DASH_doc143481,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e470471.stack[R.EXN_STACKHEIGHT++] = $ss474475;
}
if(R.isPyretException($e470471)) {
$e470471.pyretStack.push(L[48]);
}
throw $e470471;
}
var $ret476477 = $Hstr_DASH_doc11484482($z472473,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret476477;
};
var $Hstr_DASH_doc11484482 = function(str_DASH_doc143481,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun27493 = G(PP170,"str",L[51]);
var $z485486 = D;
var $f491492 = function(_) {
return R.isFunction(anf_fun27493)?anf_fun27493.app(("| else =>")):R.ffi.throwNonFunApp(L[50],anf_fun27493,[("| else =>")]);
};
try {
if(--R.GAS > 0) {
$z485486 = $f491492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f491492,
"from":L[50]});
}
} catch($e483484) {
if(R.isCont($e483484)) {
var $ss487488 = {"from":L[50],
"go":function(str_DASH_elsebranch144494) {
return $Hstr_DASH_elsebranch11483495(str_DASH_elsebranch144494,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e483484.stack[R.EXN_STACKHEIGHT++] = $ss487488;
}
if(R.isPyretException($e483484)) {
$e483484.pyretStack.push(L[50]);
}
throw $e483484;
}
var $ret489490 = $Hstr_DASH_elsebranch11483495($z485486,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret489490;
};
var $Hstr_DASH_elsebranch11483495 = function(str_DASH_elsebranch144494,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun28506 = G(PP170,"str",L[53]);
var $z498499 = D;
var $f504505 = function(_) {
return R.isFunction(anf_fun28506)?anf_fun28506.app(("else:")):R.ffi.throwNonFunApp(L[52],anf_fun28506,[("else:")]);
};
try {
if(--R.GAS > 0) {
$z498499 = $f504505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f504505,
"from":L[52]});
}
} catch($e496497) {
if(R.isCont($e496497)) {
var $ss500501 = {"from":L[52],
"go":function(str_DASH_elsecolon145507) {
return $Hstr_DASH_elsecolon11482508(str_DASH_elsecolon145507,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e496497.stack[R.EXN_STACKHEIGHT++] = $ss500501;
}
if(R.isPyretException($e496497)) {
$e496497.pyretStack.push(L[52]);
}
throw $e496497;
}
var $ret502503 = $Hstr_DASH_elsecolon11482508($z498499,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret502503;
};
var $Hstr_DASH_elsecolon11482508 = function(str_DASH_elsecolon145507,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun29519 = G(PP170,"str",L[55]);
var $z511512 = D;
var $f517518 = function(_) {
return R.isFunction(anf_fun29519)?anf_fun29519.app(("otherwise:")):R.ffi.throwNonFunApp(L[54],anf_fun29519,[("otherwise:")]);
};
try {
if(--R.GAS > 0) {
$z511512 = $f517518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f517518,
"from":L[54]});
}
} catch($e509510) {
if(R.isCont($e509510)) {
var $ss513514 = {"from":L[54],
"go":function(str_DASH_otherwisecolon146520) {
return $Hstr_DASH_otherwisecolon11481521(str_DASH_otherwisecolon146520,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e509510.stack[R.EXN_STACKHEIGHT++] = $ss513514;
}
if(R.isPyretException($e509510)) {
$e509510.pyretStack.push(L[54]);
}
throw $e509510;
}
var $ret515516 = $Hstr_DASH_otherwisecolon11481521($z511512,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret515516;
};
var $Hstr_DASH_otherwisecolon11481521 = function(str_DASH_otherwisecolon146520,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun30532 = G(PP170,"str",L[57]);
var $z524525 = D;
var $f530531 = function(_) {
return R.isFunction(anf_fun30532)?anf_fun30532.app(("else ")):R.ffi.throwNonFunApp(L[56],anf_fun30532,[("else ")]);
};
try {
if(--R.GAS > 0) {
$z524525 = $f530531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f530531,
"from":L[56]});
}
} catch($e522523) {
if(R.isCont($e522523)) {
var $ss526527 = {"from":L[56],
"go":function(str_DASH_elsespace147533) {
return $Hstr_DASH_elsespace11480534(str_DASH_elsespace147533,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e522523.stack[R.EXN_STACKHEIGHT++] = $ss526527;
}
if(R.isPyretException($e522523)) {
$e522523.pyretStack.push(L[56]);
}
throw $e522523;
}
var $ret528529 = $Hstr_DASH_elsespace11480534($z524525,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret528529;
};
var $Hstr_DASH_elsespace11480534 = function(str_DASH_elsespace147533,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun31545 = G(PP170,"str",L[59]);
var $z537538 = D;
var $f543544 = function(_) {
return R.isFunction(anf_fun31545)?anf_fun31545.app(("end")):R.ffi.throwNonFunApp(L[58],anf_fun31545,[("end")]);
};
try {
if(--R.GAS > 0) {
$z537538 = $f543544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f543544,
"from":L[58]});
}
} catch($e535536) {
if(R.isCont($e535536)) {
var $ss539540 = {"from":L[58],
"go":function(str_DASH_end148546) {
return $Hstr_DASH_end11479547(str_DASH_end148546,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e535536.stack[R.EXN_STACKHEIGHT++] = $ss539540;
}
if(R.isPyretException($e535536)) {
$e535536.pyretStack.push(L[58]);
}
throw $e535536;
}
var $ret541542 = $Hstr_DASH_end11479547($z537538,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret541542;
};
var $Hstr_DASH_end11479547 = function(str_DASH_end148546,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun32558 = G(PP170,"str",L[61]);
var $z550551 = D;
var $f556557 = function(_) {
return R.isFunction(anf_fun32558)?anf_fun32558.app(("except")):R.ffi.throwNonFunApp(L[60],anf_fun32558,[("except")]);
};
try {
if(--R.GAS > 0) {
$z550551 = $f556557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f556557,
"from":L[60]});
}
} catch($e548549) {
if(R.isCont($e548549)) {
var $ss552553 = {"from":L[60],
"go":function(str_DASH_except149559) {
return $Hstr_DASH_except11478560(str_DASH_except149559,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e548549.stack[R.EXN_STACKHEIGHT++] = $ss552553;
}
if(R.isPyretException($e548549)) {
$e548549.pyretStack.push(L[60]);
}
throw $e548549;
}
var $ret554555 = $Hstr_DASH_except11478560($z550551,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret554555;
};
var $Hstr_DASH_except11478560 = function(str_DASH_except149559,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun33571 = G(PP170,"str",L[63]);
var $z563564 = D;
var $f569570 = function(_) {
return R.isFunction(anf_fun33571)?anf_fun33571.app(("for ")):R.ffi.throwNonFunApp(L[62],anf_fun33571,[("for ")]);
};
try {
if(--R.GAS > 0) {
$z563564 = $f569570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f569570,
"from":L[62]});
}
} catch($e561562) {
if(R.isCont($e561562)) {
var $ss565566 = {"from":L[62],
"go":function(str_DASH_for150572) {
return $Hstr_DASH_for11477573(str_DASH_for150572,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e561562.stack[R.EXN_STACKHEIGHT++] = $ss565566;
}
if(R.isPyretException($e561562)) {
$e561562.pyretStack.push(L[62]);
}
throw $e561562;
}
var $ret567568 = $Hstr_DASH_for11477573($z563564,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret567568;
};
var $Hstr_DASH_for11477573 = function(str_DASH_for150572,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun34584 = G(PP170,"str",L[65]);
var $z576577 = D;
var $f582583 = function(_) {
return R.isFunction(anf_fun34584)?anf_fun34584.app(("from")):R.ffi.throwNonFunApp(L[64],anf_fun34584,[("from")]);
};
try {
if(--R.GAS > 0) {
$z576577 = $f582583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f582583,
"from":L[64]});
}
} catch($e574575) {
if(R.isCont($e574575)) {
var $ss578579 = {"from":L[64],
"go":function(str_DASH_from151585) {
return $Hstr_DASH_from11476586(str_DASH_from151585,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e574575.stack[R.EXN_STACKHEIGHT++] = $ss578579;
}
if(R.isPyretException($e574575)) {
$e574575.pyretStack.push(L[64]);
}
throw $e574575;
}
var $ret580581 = $Hstr_DASH_from11476586($z576577,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret580581;
};
var $Hstr_DASH_from11476586 = function(str_DASH_from151585,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun35597 = G(PP170,"str",L[67]);
var $z589590 = D;
var $f595596 = function(_) {
return R.isFunction(anf_fun35597)?anf_fun35597.app(("fun")):R.ffi.throwNonFunApp(L[66],anf_fun35597,[("fun")]);
};
try {
if(--R.GAS > 0) {
$z589590 = $f595596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f595596,
"from":L[66]});
}
} catch($e587588) {
if(R.isCont($e587588)) {
var $ss591592 = {"from":L[66],
"go":function(str_DASH_fun152598) {
return $Hstr_DASH_fun11475599(str_DASH_fun152598,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e587588.stack[R.EXN_STACKHEIGHT++] = $ss591592;
}
if(R.isPyretException($e587588)) {
$e587588.pyretStack.push(L[66]);
}
throw $e587588;
}
var $ret593594 = $Hstr_DASH_fun11475599($z589590,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret593594;
};
var $Hstr_DASH_fun11475599 = function(str_DASH_fun152598,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun36610 = G(PP170,"str",L[69]);
var $z602603 = D;
var $f608609 = function(_) {
return R.isFunction(anf_fun36610)?anf_fun36610.app(("lam")):R.ffi.throwNonFunApp(L[68],anf_fun36610,[("lam")]);
};
try {
if(--R.GAS > 0) {
$z602603 = $f608609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f608609,
"from":L[68]});
}
} catch($e600601) {
if(R.isCont($e600601)) {
var $ss604605 = {"from":L[68],
"go":function(str_DASH_lam153611) {
return $Hstr_DASH_lam11474612(str_DASH_lam153611,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e600601.stack[R.EXN_STACKHEIGHT++] = $ss604605;
}
if(R.isPyretException($e600601)) {
$e600601.pyretStack.push(L[68]);
}
throw $e600601;
}
var $ret606607 = $Hstr_DASH_lam11474612($z602603,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret606607;
};
var $Hstr_DASH_lam11474612 = function(str_DASH_lam153611,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun37623 = G(PP170,"str",L[71]);
var $z615616 = D;
var $f621622 = function(_) {
return R.isFunction(anf_fun37623)?anf_fun37623.app(("graph:")):R.ffi.throwNonFunApp(L[70],anf_fun37623,[("graph:")]);
};
try {
if(--R.GAS > 0) {
$z615616 = $f621622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f621622,
"from":L[70]});
}
} catch($e613614) {
if(R.isCont($e613614)) {
var $ss617618 = {"from":L[70],
"go":function(str_DASH_graph154624) {
return $Hstr_DASH_graph11473625(str_DASH_graph154624,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e613614.stack[R.EXN_STACKHEIGHT++] = $ss617618;
}
if(R.isPyretException($e613614)) {
$e613614.pyretStack.push(L[70]);
}
throw $e613614;
}
var $ret619620 = $Hstr_DASH_graph11473625($z615616,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret619620;
};
var $Hstr_DASH_graph11473625 = function(str_DASH_graph154624,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun38636 = G(PP170,"str",L[73]);
var $z628629 = D;
var $f634635 = function(_) {
return R.isFunction(anf_fun38636)?anf_fun38636.app(("if ")):R.ffi.throwNonFunApp(L[72],anf_fun38636,[("if ")]);
};
try {
if(--R.GAS > 0) {
$z628629 = $f634635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f634635,
"from":L[72]});
}
} catch($e626627) {
if(R.isCont($e626627)) {
var $ss630631 = {"from":L[72],
"go":function(str_DASH_if155637) {
return $Hstr_DASH_if11472638(str_DASH_if155637,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e626627.stack[R.EXN_STACKHEIGHT++] = $ss630631;
}
if(R.isPyretException($e626627)) {
$e626627.pyretStack.push(L[72]);
}
throw $e626627;
}
var $ret632633 = $Hstr_DASH_if11472638($z628629,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret632633;
};
var $Hstr_DASH_if11472638 = function(str_DASH_if155637,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun39649 = G(PP170,"str",L[75]);
var $z641642 = D;
var $f647648 = function(_) {
return R.isFunction(anf_fun39649)?anf_fun39649.app(("ask:")):R.ffi.throwNonFunApp(L[74],anf_fun39649,[("ask:")]);
};
try {
if(--R.GAS > 0) {
$z641642 = $f647648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f647648,
"from":L[74]});
}
} catch($e639640) {
if(R.isCont($e639640)) {
var $ss643644 = {"from":L[74],
"go":function(str_DASH_askcolon156650) {
return $Hstr_DASH_askcolon11471651(str_DASH_askcolon156650,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e639640.stack[R.EXN_STACKHEIGHT++] = $ss643644;
}
if(R.isPyretException($e639640)) {
$e639640.pyretStack.push(L[74]);
}
throw $e639640;
}
var $ret645646 = $Hstr_DASH_askcolon11471651($z641642,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret645646;
};
var $Hstr_DASH_askcolon11471651 = function(str_DASH_askcolon156650,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun40662 = G(PP170,"str",L[77]);
var $z654655 = D;
var $f660661 = function(_) {
return R.isFunction(anf_fun40662)?anf_fun40662.app(("import")):R.ffi.throwNonFunApp(L[76],anf_fun40662,[("import")]);
};
try {
if(--R.GAS > 0) {
$z654655 = $f660661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f660661,
"from":L[76]});
}
} catch($e652653) {
if(R.isCont($e652653)) {
var $ss656657 = {"from":L[76],
"go":function(str_DASH_import157663) {
return $Hstr_DASH_import11470664(str_DASH_import157663,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e652653.stack[R.EXN_STACKHEIGHT++] = $ss656657;
}
if(R.isPyretException($e652653)) {
$e652653.pyretStack.push(L[76]);
}
throw $e652653;
}
var $ret658659 = $Hstr_DASH_import11470664($z654655,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret658659;
};
var $Hstr_DASH_import11470664 = function(str_DASH_import157663,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun41675 = G(PP170,"str",L[79]);
var $z667668 = D;
var $f673674 = function(_) {
return R.isFunction(anf_fun41675)?anf_fun41675.app(("method")):R.ffi.throwNonFunApp(L[78],anf_fun41675,[("method")]);
};
try {
if(--R.GAS > 0) {
$z667668 = $f673674();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f673674,
"from":L[78]});
}
} catch($e665666) {
if(R.isCont($e665666)) {
var $ss669670 = {"from":L[78],
"go":function(str_DASH_method158676) {
return $Hstr_DASH_method11469677(str_DASH_method158676,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e665666.stack[R.EXN_STACKHEIGHT++] = $ss669670;
}
if(R.isPyretException($e665666)) {
$e665666.pyretStack.push(L[78]);
}
throw $e665666;
}
var $ret671672 = $Hstr_DASH_method11469677($z667668,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret671672;
};
var $Hstr_DASH_method11469677 = function(str_DASH_method158676,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun42688 = G(PP170,"str",L[81]);
var $z680681 = D;
var $f686687 = function(_) {
return R.isFunction(anf_fun42688)?anf_fun42688.app(("mutable")):R.ffi.throwNonFunApp(L[80],anf_fun42688,[("mutable")]);
};
try {
if(--R.GAS > 0) {
$z680681 = $f686687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f686687,
"from":L[80]});
}
} catch($e678679) {
if(R.isCont($e678679)) {
var $ss682683 = {"from":L[80],
"go":function(str_DASH_mutable159689) {
return $Hstr_DASH_mutable11468690(str_DASH_mutable159689,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e678679.stack[R.EXN_STACKHEIGHT++] = $ss682683;
}
if(R.isPyretException($e678679)) {
$e678679.pyretStack.push(L[80]);
}
throw $e678679;
}
var $ret684685 = $Hstr_DASH_mutable11468690($z680681,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret684685;
};
var $Hstr_DASH_mutable11468690 = function(str_DASH_mutable159689,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun43701 = G(PP170,"str",L[83]);
var $z693694 = D;
var $f699700 = function(_) {
return R.isFunction(anf_fun43701)?anf_fun43701.app((".")):R.ffi.throwNonFunApp(L[82],anf_fun43701,[(".")]);
};
try {
if(--R.GAS > 0) {
$z693694 = $f699700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f699700,
"from":L[82]});
}
} catch($e691692) {
if(R.isCont($e691692)) {
var $ss695696 = {"from":L[82],
"go":function(str_DASH_period160702) {
return $Hstr_DASH_period11467703(str_DASH_period160702,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e691692.stack[R.EXN_STACKHEIGHT++] = $ss695696;
}
if(R.isPyretException($e691692)) {
$e691692.pyretStack.push(L[82]);
}
throw $e691692;
}
var $ret697698 = $Hstr_DASH_period11467703($z693694,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret697698;
};
var $Hstr_DASH_period11467703 = function(str_DASH_period160702,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun44714 = G(PP170,"str",L[85]);
var $z706707 = D;
var $f712713 = function(_) {
return R.isFunction(anf_fun44714)?anf_fun44714.app(("!")):R.ffi.throwNonFunApp(L[84],anf_fun44714,[("!")]);
};
try {
if(--R.GAS > 0) {
$z706707 = $f712713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f712713,
"from":L[84]});
}
} catch($e704705) {
if(R.isCont($e704705)) {
var $ss708709 = {"from":L[84],
"go":function(str_DASH_bang161715) {
return $Hstr_DASH_bang11466716(str_DASH_bang161715,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e704705.stack[R.EXN_STACKHEIGHT++] = $ss708709;
}
if(R.isPyretException($e704705)) {
$e704705.pyretStack.push(L[84]);
}
throw $e704705;
}
var $ret710711 = $Hstr_DASH_bang11466716($z706707,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret710711;
};
var $Hstr_DASH_bang11466716 = function(str_DASH_bang161715,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun45727 = G(PP170,"str",L[87]);
var $z719720 = D;
var $f725726 = function(_) {
return R.isFunction(anf_fun45727)?anf_fun45727.app(("| ")):R.ffi.throwNonFunApp(L[86],anf_fun45727,[("| ")]);
};
try {
if(--R.GAS > 0) {
$z719720 = $f725726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f725726,
"from":L[86]});
}
} catch($e717718) {
if(R.isCont($e717718)) {
var $ss721722 = {"from":L[86],
"go":function(str_DASH_pipespace162728) {
return $Hstr_DASH_pipespace11465729(str_DASH_pipespace162728,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e717718.stack[R.EXN_STACKHEIGHT++] = $ss721722;
}
if(R.isPyretException($e717718)) {
$e717718.pyretStack.push(L[86]);
}
throw $e717718;
}
var $ret723724 = $Hstr_DASH_pipespace11465729($z719720,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret723724;
};
var $Hstr_DASH_pipespace11465729 = function(str_DASH_pipespace162728,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun46740 = G(PP170,"str",L[89]);
var $z732733 = D;
var $f738739 = function(_) {
return R.isFunction(anf_fun46740)?anf_fun46740.app(("provide")):R.ffi.throwNonFunApp(L[88],anf_fun46740,[("provide")]);
};
try {
if(--R.GAS > 0) {
$z732733 = $f738739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f738739,
"from":L[88]});
}
} catch($e730731) {
if(R.isCont($e730731)) {
var $ss734735 = {"from":L[88],
"go":function(str_DASH_provide163741) {
return $Hstr_DASH_provide11464742(str_DASH_provide163741,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e730731.stack[R.EXN_STACKHEIGHT++] = $ss734735;
}
if(R.isPyretException($e730731)) {
$e730731.pyretStack.push(L[88]);
}
throw $e730731;
}
var $ret736737 = $Hstr_DASH_provide11464742($z732733,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret736737;
};
var $Hstr_DASH_provide11464742 = function(str_DASH_provide163741,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun47753 = G(PP170,"str",L[91]);
var $z745746 = D;
var $f751752 = function(_) {
return R.isFunction(anf_fun47753)?anf_fun47753.app(("provide-types")):R.ffi.throwNonFunApp(L[90],anf_fun47753,[("provide-types")]);
};
try {
if(--R.GAS > 0) {
$z745746 = $f751752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f751752,
"from":L[90]});
}
} catch($e743744) {
if(R.isCont($e743744)) {
var $ss747748 = {"from":L[90],
"go":function(str_DASH_provide_DASH_types164754) {
return $Hstr_DASH_provide_DASH_types11463755(str_DASH_provide_DASH_types164754,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e743744.stack[R.EXN_STACKHEIGHT++] = $ss747748;
}
if(R.isPyretException($e743744)) {
$e743744.pyretStack.push(L[90]);
}
throw $e743744;
}
var $ret749750 = $Hstr_DASH_provide_DASH_types11463755($z745746,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret749750;
};
var $Hstr_DASH_provide_DASH_types11463755 = function(str_DASH_provide_DASH_types164754,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun48766 = G(PP170,"str",L[93]);
var $z758759 = D;
var $f764765 = function(_) {
return R.isFunction(anf_fun48766)?anf_fun48766.app(("provide *")):R.ffi.throwNonFunApp(L[92],anf_fun48766,[("provide *")]);
};
try {
if(--R.GAS > 0) {
$z758759 = $f764765();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f764765,
"from":L[92]});
}
} catch($e756757) {
if(R.isCont($e756757)) {
var $ss760761 = {"from":L[92],
"go":function(str_DASH_provide_DASH_star165767) {
return $Hstr_DASH_provide_DASH_star11462768(str_DASH_provide_DASH_star165767,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e756757.stack[R.EXN_STACKHEIGHT++] = $ss760761;
}
if(R.isPyretException($e756757)) {
$e756757.pyretStack.push(L[92]);
}
throw $e756757;
}
var $ret762763 = $Hstr_DASH_provide_DASH_star11462768($z758759,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret762763;
};
var $Hstr_DASH_provide_DASH_star11462768 = function(str_DASH_provide_DASH_star165767,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun49779 = G(PP170,"str",L[95]);
var $z771772 = D;
var $f777778 = function(_) {
return R.isFunction(anf_fun49779)?anf_fun49779.app(("provide-types *")):R.ffi.throwNonFunApp(L[94],anf_fun49779,[("provide-types *")]);
};
try {
if(--R.GAS > 0) {
$z771772 = $f777778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f777778,
"from":L[94]});
}
} catch($e769770) {
if(R.isCont($e769770)) {
var $ss773774 = {"from":L[94],
"go":function(str_DASH_provide_DASH_types_DASH_star166780) {
return $Hstr_DASH_provide_DASH_types_DASH_star11461781(str_DASH_provide_DASH_types_DASH_star166780,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e769770.stack[R.EXN_STACKHEIGHT++] = $ss773774;
}
if(R.isPyretException($e769770)) {
$e769770.pyretStack.push(L[94]);
}
throw $e769770;
}
var $ret775776 = $Hstr_DASH_provide_DASH_types_DASH_star11461781($z771772,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret775776;
};
var $Hstr_DASH_provide_DASH_types_DASH_star11461781 = function(str_DASH_provide_DASH_types_DASH_star166780,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun50792 = G(PP170,"str",L[97]);
var $z784785 = D;
var $f790791 = function(_) {
return R.isFunction(anf_fun50792)?anf_fun50792.app(("sharing:")):R.ffi.throwNonFunApp(L[96],anf_fun50792,[("sharing:")]);
};
try {
if(--R.GAS > 0) {
$z784785 = $f790791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f790791,
"from":L[96]});
}
} catch($e782783) {
if(R.isCont($e782783)) {
var $ss786787 = {"from":L[96],
"go":function(str_DASH_sharing167793) {
return $Hstr_DASH_sharing11460794(str_DASH_sharing167793,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e782783.stack[R.EXN_STACKHEIGHT++] = $ss786787;
}
if(R.isPyretException($e782783)) {
$e782783.pyretStack.push(L[96]);
}
throw $e782783;
}
var $ret788789 = $Hstr_DASH_sharing11460794($z784785,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret788789;
};
var $Hstr_DASH_sharing11460794 = function(str_DASH_sharing167793,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun51805 = G(PP170,"str",L[99]);
var $z797798 = D;
var $f803804 = function(_) {
return R.isFunction(anf_fun51805)?anf_fun51805.app((" ")):R.ffi.throwNonFunApp(L[98],anf_fun51805,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z797798 = $f803804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f803804,
"from":L[98]});
}
} catch($e795796) {
if(R.isCont($e795796)) {
var $ss799800 = {"from":L[98],
"go":function(str_DASH_space168806) {
return $Hstr_DASH_space11459807(str_DASH_space168806,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e795796.stack[R.EXN_STACKHEIGHT++] = $ss799800;
}
if(R.isPyretException($e795796)) {
$e795796.pyretStack.push(L[98]);
}
throw $e795796;
}
var $ret801802 = $Hstr_DASH_space11459807($z797798,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret801802;
};
var $Hstr_DASH_space11459807 = function(str_DASH_space168806,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun52818 = G(PP170,"str",L[101]);
var $z810811 = D;
var $f816817 = function(_) {
return R.isFunction(anf_fun52818)?anf_fun52818.app((" :=")):R.ffi.throwNonFunApp(L[100],anf_fun52818,[(" :=")]);
};
try {
if(--R.GAS > 0) {
$z810811 = $f816817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f816817,
"from":L[100]});
}
} catch($e808809) {
if(R.isCont($e808809)) {
var $ss812813 = {"from":L[100],
"go":function(str_DASH_spacecolonequal169819) {
return $Hstr_DASH_spacecolonequal11458820(str_DASH_spacecolonequal169819,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e808809.stack[R.EXN_STACKHEIGHT++] = $ss812813;
}
if(R.isPyretException($e808809)) {
$e808809.pyretStack.push(L[100]);
}
throw $e808809;
}
var $ret814815 = $Hstr_DASH_spacecolonequal11458820($z810811,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret814815;
};
var $Hstr_DASH_spacecolonequal11458820 = function(str_DASH_spacecolonequal169819,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun53831 = G(PP170,"str",L[103]);
var $z823824 = D;
var $f829830 = function(_) {
return R.isFunction(anf_fun53831)?anf_fun53831.app((" =")):R.ffi.throwNonFunApp(L[102],anf_fun53831,[(" =")]);
};
try {
if(--R.GAS > 0) {
$z823824 = $f829830();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f829830,
"from":L[102]});
}
} catch($e821822) {
if(R.isCont($e821822)) {
var $ss825826 = {"from":L[102],
"go":function(str_DASH_spaceequal170832) {
return $Hstr_DASH_spaceequal11457833(str_DASH_spaceequal170832,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e821822.stack[R.EXN_STACKHEIGHT++] = $ss825826;
}
if(R.isPyretException($e821822)) {
$e821822.pyretStack.push(L[102]);
}
throw $e821822;
}
var $ret827828 = $Hstr_DASH_spaceequal11457833($z823824,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret827828;
};
var $Hstr_DASH_spaceequal11457833 = function(str_DASH_spaceequal170832,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun54844 = G(PP170,"str",L[105]);
var $z836837 = D;
var $f842843 = function(_) {
return R.isFunction(anf_fun54844)?anf_fun54844.app(("then:")):R.ffi.throwNonFunApp(L[104],anf_fun54844,[("then:")]);
};
try {
if(--R.GAS > 0) {
$z836837 = $f842843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f842843,
"from":L[104]});
}
} catch($e834835) {
if(R.isCont($e834835)) {
var $ss838839 = {"from":L[104],
"go":function(str_DASH_thencolon171845) {
return $Hstr_DASH_thencolon11456846(str_DASH_thencolon171845,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e834835.stack[R.EXN_STACKHEIGHT++] = $ss838839;
}
if(R.isPyretException($e834835)) {
$e834835.pyretStack.push(L[104]);
}
throw $e834835;
}
var $ret840841 = $Hstr_DASH_thencolon11456846($z836837,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret840841;
};
var $Hstr_DASH_thencolon11456846 = function(str_DASH_thencolon171845,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun55857 = G(PP170,"str",L[107]);
var $z849850 = D;
var $f855856 = function(_) {
return R.isFunction(anf_fun55857)?anf_fun55857.app(("=>")):R.ffi.throwNonFunApp(L[106],anf_fun55857,[("=>")]);
};
try {
if(--R.GAS > 0) {
$z849850 = $f855856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f855856,
"from":L[106]});
}
} catch($e847848) {
if(R.isCont($e847848)) {
var $ss851852 = {"from":L[106],
"go":function(str_DASH_thickarrow172858) {
return $Hstr_DASH_thickarrow11455859(str_DASH_thickarrow172858,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e847848.stack[R.EXN_STACKHEIGHT++] = $ss851852;
}
if(R.isPyretException($e847848)) {
$e847848.pyretStack.push(L[106]);
}
throw $e847848;
}
var $ret853854 = $Hstr_DASH_thickarrow11455859($z849850,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret853854;
};
var $Hstr_DASH_thickarrow11455859 = function(str_DASH_thickarrow172858,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun56870 = G(PP170,"str",L[109]);
var $z862863 = D;
var $f868869 = function(_) {
return R.isFunction(anf_fun56870)?anf_fun56870.app(("try:")):R.ffi.throwNonFunApp(L[108],anf_fun56870,[("try:")]);
};
try {
if(--R.GAS > 0) {
$z862863 = $f868869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f868869,
"from":L[108]});
}
} catch($e860861) {
if(R.isCont($e860861)) {
var $ss864865 = {"from":L[108],
"go":function(str_DASH_try173871) {
return $Hstr_DASH_try11454872(str_DASH_try173871,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e860861.stack[R.EXN_STACKHEIGHT++] = $ss864865;
}
if(R.isPyretException($e860861)) {
$e860861.pyretStack.push(L[108]);
}
throw $e860861;
}
var $ret866867 = $Hstr_DASH_try11454872($z862863,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret866867;
};
var $Hstr_DASH_try11454872 = function(str_DASH_try173871,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun57883 = G(PP170,"str",L[111]);
var $z875876 = D;
var $f881882 = function(_) {
return R.isFunction(anf_fun57883)?anf_fun57883.app(("UseLoc")):R.ffi.throwNonFunApp(L[110],anf_fun57883,[("UseLoc")]);
};
try {
if(--R.GAS > 0) {
$z875876 = $f881882();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f881882,
"from":L[110]});
}
} catch($e873874) {
if(R.isCont($e873874)) {
var $ss877878 = {"from":L[110],
"go":function(str_DASH_use_DASH_loc174884) {
return $Hstr_DASH_use_DASH_loc11453885(str_DASH_use_DASH_loc174884,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e873874.stack[R.EXN_STACKHEIGHT++] = $ss877878;
}
if(R.isPyretException($e873874)) {
$e873874.pyretStack.push(L[110]);
}
throw $e873874;
}
var $ret879880 = $Hstr_DASH_use_DASH_loc11453885($z875876,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret879880;
};
var $Hstr_DASH_use_DASH_loc11453885 = function(str_DASH_use_DASH_loc174884,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun58896 = G(PP170,"str",L[113]);
var $z888889 = D;
var $f894895 = function(_) {
return R.isFunction(anf_fun58896)?anf_fun58896.app(("var ")):R.ffi.throwNonFunApp(L[112],anf_fun58896,[("var ")]);
};
try {
if(--R.GAS > 0) {
$z888889 = $f894895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f894895,
"from":L[112]});
}
} catch($e886887) {
if(R.isCont($e886887)) {
var $ss890891 = {"from":L[112],
"go":function(str_DASH_var175897) {
return $Hstr_DASH_var11452898(str_DASH_var175897,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e886887.stack[R.EXN_STACKHEIGHT++] = $ss890891;
}
if(R.isPyretException($e886887)) {
$e886887.pyretStack.push(L[112]);
}
throw $e886887;
}
var $ret892893 = $Hstr_DASH_var11452898($z888889,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret892893;
};
var $Hstr_DASH_var11452898 = function(str_DASH_var175897,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun59909 = G(PP170,"str",L[115]);
var $z901902 = D;
var $f907908 = function(_) {
return R.isFunction(anf_fun59909)?anf_fun59909.app(("type ")):R.ffi.throwNonFunApp(L[114],anf_fun59909,[("type ")]);
};
try {
if(--R.GAS > 0) {
$z901902 = $f907908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f907908,
"from":L[114]});
}
} catch($e899900) {
if(R.isCont($e899900)) {
var $ss903904 = {"from":L[114],
"go":function(str_DASH_newtype176910) {
return $Hstr_DASH_newtype11451911(str_DASH_newtype176910,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e899900.stack[R.EXN_STACKHEIGHT++] = $ss903904;
}
if(R.isPyretException($e899900)) {
$e899900.pyretStack.push(L[114]);
}
throw $e899900;
}
var $ret905906 = $Hstr_DASH_newtype11451911($z901902,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret905906;
};
var $Hstr_DASH_newtype11451911 = function(str_DASH_newtype176910,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun60922 = G(PP170,"str",L[117]);
var $z914915 = D;
var $f920921 = function(_) {
return R.isFunction(anf_fun60922)?anf_fun60922.app(("type ")):R.ffi.throwNonFunApp(L[116],anf_fun60922,[("type ")]);
};
try {
if(--R.GAS > 0) {
$z914915 = $f920921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f920921,
"from":L[116]});
}
} catch($e912913) {
if(R.isCont($e912913)) {
var $ss916917 = {"from":L[116],
"go":function(str_DASH_type177923) {
return $Hstr_DASH_type11450924(str_DASH_type177923,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e912913.stack[R.EXN_STACKHEIGHT++] = $ss916917;
}
if(R.isPyretException($e912913)) {
$e912913.pyretStack.push(L[116]);
}
throw $e912913;
}
var $ret918919 = $Hstr_DASH_type11450924($z914915,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret918919;
};
var $Hstr_DASH_type11450924 = function(str_DASH_type177923,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun61935 = G(PP170,"str",L[119]);
var $z927928 = D;
var $f933934 = function(_) {
return R.isFunction(anf_fun61935)?anf_fun61935.app(("bless ")):R.ffi.throwNonFunApp(L[118],anf_fun61935,[("bless ")]);
};
try {
if(--R.GAS > 0) {
$z927928 = $f933934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f933934,
"from":L[118]});
}
} catch($e925926) {
if(R.isCont($e925926)) {
var $ss929930 = {"from":L[118],
"go":function(str_DASH_bless178936) {
return $Hstr_DASH_bless11449937(str_DASH_bless178936,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e925926.stack[R.EXN_STACKHEIGHT++] = $ss929930;
}
if(R.isPyretException($e925926)) {
$e925926.pyretStack.push(L[118]);
}
throw $e925926;
}
var $ret931932 = $Hstr_DASH_bless11449937($z927928,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret931932;
};
var $Hstr_DASH_bless11449937 = function(str_DASH_bless178936,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun62948 = G(PP170,"str",L[121]);
var $z940941 = D;
var $f946947 = function(_) {
return R.isFunction(anf_fun62948)?anf_fun62948.app(("confirm ")):R.ffi.throwNonFunApp(L[120],anf_fun62948,[("confirm ")]);
};
try {
if(--R.GAS > 0) {
$z940941 = $f946947();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f946947,
"from":L[120]});
}
} catch($e938939) {
if(R.isCont($e938939)) {
var $ss942943 = {"from":L[120],
"go":function(str_DASH_confirm179949) {
return $Hstr_DASH_confirm11448950(str_DASH_confirm179949,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e938939.stack[R.EXN_STACKHEIGHT++] = $ss942943;
}
if(R.isPyretException($e938939)) {
$e938939.pyretStack.push(L[120]);
}
throw $e938939;
}
var $ret944945 = $Hstr_DASH_confirm11448950($z940941,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret944945;
};
var $Hstr_DASH_confirm11448950 = function(str_DASH_confirm179949,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun63961 = G(PP170,"str",L[123]);
var $z953954 = D;
var $f959960 = function(_) {
return R.isFunction(anf_fun63961)?anf_fun63961.app(("val ")):R.ffi.throwNonFunApp(L[122],anf_fun63961,[("val ")]);
};
try {
if(--R.GAS > 0) {
$z953954 = $f959960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f959960,
"from":L[122]});
}
} catch($e951952) {
if(R.isCont($e951952)) {
var $ss955956 = {"from":L[122],
"go":function(str_DASH_val180962) {
return $Hstr_DASH_val11447963(str_DASH_val180962,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e951952.stack[R.EXN_STACKHEIGHT++] = $ss955956;
}
if(R.isPyretException($e951952)) {
$e951952.pyretStack.push(L[122]);
}
throw $e951952;
}
var $ret957958 = $Hstr_DASH_val11447963($z953954,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret957958;
};
var $Hstr_DASH_val11447963 = function(str_DASH_val180962,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun64974 = G(PP170,"str",L[125]);
var $z966967 = D;
var $f972973 = function(_) {
return R.isFunction(anf_fun64974)?anf_fun64974.app(("when")):R.ffi.throwNonFunApp(L[124],anf_fun64974,[("when")]);
};
try {
if(--R.GAS > 0) {
$z966967 = $f972973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f972973,
"from":L[124]});
}
} catch($e964965) {
if(R.isCont($e964965)) {
var $ss968969 = {"from":L[124],
"go":function(str_DASH_when181975) {
return $Hstr_DASH_when11446976(str_DASH_when181975,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e964965.stack[R.EXN_STACKHEIGHT++] = $ss968969;
}
if(R.isPyretException($e964965)) {
$e964965.pyretStack.push(L[124]);
}
throw $e964965;
}
var $ret970971 = $Hstr_DASH_when11446976($z966967,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret970971;
};
var $Hstr_DASH_when11446976 = function(str_DASH_when181975,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun65987 = G(PP170,"str",L[127]);
var $z979980 = D;
var $f985986 = function(_) {
return R.isFunction(anf_fun65987)?anf_fun65987.app(("where:")):R.ffi.throwNonFunApp(L[126],anf_fun65987,[("where:")]);
};
try {
if(--R.GAS > 0) {
$z979980 = $f985986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f985986,
"from":L[126]});
}
} catch($e977978) {
if(R.isCont($e977978)) {
var $ss981982 = {"from":L[126],
"go":function(str_DASH_where182988) {
return $Hstr_DASH_where11445989(str_DASH_where182988,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e977978.stack[R.EXN_STACKHEIGHT++] = $ss981982;
}
if(R.isPyretException($e977978)) {
$e977978.pyretStack.push(L[126]);
}
throw $e977978;
}
var $ret983984 = $Hstr_DASH_where11445989($z979980,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret983984;
};
var $Hstr_DASH_where11445989 = function(str_DASH_where182988,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var anf_fun661000 = G(PP170,"str",L[129]);
var $z992993 = D;
var $f998999 = function(_) {
return R.isFunction(anf_fun661000)?anf_fun661000.app(("with:")):R.ffi.throwNonFunApp(L[128],anf_fun661000,[("with:")]);
};
try {
if(--R.GAS > 0) {
$z992993 = $f998999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f998999,
"from":L[128]});
}
} catch($e990991) {
if(R.isCont($e990991)) {
var $ss994995 = {"from":L[128],
"go":function(str_DASH_with1831001) {
return $Hstr_DASH_with114441002(str_DASH_with1831001,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,str_DASH_where182988,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e990991.stack[R.EXN_STACKHEIGHT++] = $ss994995;
}
if(R.isPyretException($e990991)) {
$e990991.pyretStack.push(L[128]);
}
throw $e990991;
}
var $ret996997 = $Hstr_DASH_with114441002($z992993,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,str_DASH_where182988,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret996997;
};
var $Hstr_DASH_with114441002 = function(str_DASH_with1831001,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,str_DASH_where182988,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var Name261841003 = {"$var":D,
"$name":"Name26"};
var Name1851005 = {"$var":D,
"$name":"Name"};
var is_DASH_Name1861007 = {"$var":D,
"$name":"is-Name"};
var is_DASH_s_DASH_underscore1871009 = {"$var":D,
"$name":"is-s-underscore"};
var s_DASH_underscore1881011 = {"$var":D,
"$name":"s-underscore"};
var is_DASH_s_DASH_name1891013 = {"$var":D,
"$name":"is-s-name"};
var s_DASH_name1901015 = {"$var":D,
"$name":"s-name"};
var is_DASH_s_DASH_global1911017 = {"$var":D,
"$name":"is-s-global"};
var s_DASH_global1921019 = {"$var":D,
"$name":"s-global"};
var is_DASH_s_DASH_type_DASH_global1931021 = {"$var":D,
"$name":"is-s-type-global"};
var s_DASH_type_DASH_global1941023 = {"$var":D,
"$name":"s-type-global"};
var is_DASH_s_DASH_atom1951025 = {"$var":D,
"$name":"is-s-atom"};
var s_DASH_atom1961027 = {"$var":D,
"$name":"s-atom"};
var MakeName1971029 = {"$var":D,
"$name":"MakeName"};
var anf_shared721061 = R.makeMethod(function(self2351800) {
return function(other2361798) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[245],1,arguments);
}
var anf_fun681796 = G(self2351800,"key",L[244]);
var $z17881789 = D;
var $f17941795 = function(_) {
return R.isFunction(anf_fun681796)?anf_fun681796.app():R.ffi.throwNonFunApp(L[243],anf_fun681796,[]);
};
try {
if(--R.GAS > 0) {
$z17881789 = $f17941795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17941795,
"from":L[243]});
}
} catch($e17861787) {
if(R.isCont($e17861787)) {
var $ss17901791 = {"from":L[243],
"go":function(anf_arg691797) {
return $Hanf_arg82911799(anf_arg691797,other2361798,_lessthan54);
}};
$e17861787.stack[R.EXN_STACKHEIGHT++] = $ss17901791;
}
if(R.isPyretException($e17861787)) {
$e17861787.pyretStack.push(L[243]);
}
throw $e17861787;
}
var $ret17921793 = $Hanf_arg82911799($z17881789,other2361798,_lessthan54);
++R.GAS;
return $ret17921793;
};
},{"length":2});
var anf_shared781062 = R.makeMethod(function(self2371785) {
return function(other2381783) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[242],1,arguments);
}
var anf_fun741781 = G(self2371785,"key",L[241]);
var $z17731774 = D;
var $f17791780 = function(_) {
return R.isFunction(anf_fun741781)?anf_fun741781.app():R.ffi.throwNonFunApp(L[240],anf_fun741781,[]);
};
try {
if(--R.GAS > 0) {
$z17731774 = $f17791780();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17791780,
"from":L[240]});
}
} catch($e17711772) {
if(R.isCont($e17711772)) {
var $ss17751776 = {"from":L[240],
"go":function(anf_arg751782) {
return $Hanf_arg82941784(anf_arg751782,other2381783,_lessequal53);
}};
$e17711772.stack[R.EXN_STACKHEIGHT++] = $ss17751776;
}
if(R.isPyretException($e17711772)) {
$e17711772.pyretStack.push(L[240]);
}
throw $e17711772;
}
var $ret17771778 = $Hanf_arg82941784($z17731774,other2381783,_lessequal53);
++R.GAS;
return $ret17771778;
};
},{"length":2});
var anf_shared841063 = R.makeMethod(function(self2391770) {
return function(other2401768) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[239],1,arguments);
}
var anf_fun801766 = G(self2391770,"key",L[238]);
var $z17581759 = D;
var $f17641765 = function(_) {
return R.isFunction(anf_fun801766)?anf_fun801766.app():R.ffi.throwNonFunApp(L[237],anf_fun801766,[]);
};
try {
if(--R.GAS > 0) {
$z17581759 = $f17641765();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17641765,
"from":L[237]});
}
} catch($e17561757) {
if(R.isCont($e17561757)) {
var $ss17601761 = {"from":L[237],
"go":function(anf_arg811767) {
return $Hanf_arg82971769(anf_arg811767,other2401768,_greaterthan52);
}};
$e17561757.stack[R.EXN_STACKHEIGHT++] = $ss17601761;
}
if(R.isPyretException($e17561757)) {
$e17561757.pyretStack.push(L[237]);
}
throw $e17561757;
}
var $ret17621763 = $Hanf_arg82971769($z17581759,other2401768,_greaterthan52);
++R.GAS;
return $ret17621763;
};
},{"length":2});
var anf_shared901064 = R.makeMethod(function(self2411755) {
return function(other2421753) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[236],1,arguments);
}
var anf_fun861751 = G(self2411755,"key",L[235]);
var $z17431744 = D;
var $f17491750 = function(_) {
return R.isFunction(anf_fun861751)?anf_fun861751.app():R.ffi.throwNonFunApp(L[234],anf_fun861751,[]);
};
try {
if(--R.GAS > 0) {
$z17431744 = $f17491750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17491750,
"from":L[234]});
}
} catch($e17411742) {
if(R.isCont($e17411742)) {
var $ss17451746 = {"from":L[234],
"go":function(anf_arg871752) {
return $Hanf_arg83001754(anf_arg871752,other2421753,_greaterequal51);
}};
$e17411742.stack[R.EXN_STACKHEIGHT++] = $ss17451746;
}
if(R.isPyretException($e17411742)) {
$e17411742.pyretStack.push(L[234]);
}
throw $e17411742;
}
var $ret17471748 = $Hanf_arg83001754($z17431744,other2421753,_greaterequal51);
++R.GAS;
return $ret17471748;
};
},{"length":2});
var anf_shared971065 = R.makeMethod(function(self2431738) {
return function(visitor2441724) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[230],1,arguments);
}
var anf_fun921723 = G(self2431738,"_match",L[233]);
var anf_arg961725 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[231],0,arguments);
}
var $z17301731 = D;
var $f17361737 = function(_) {
return R.isFunction(tostring66)?tostring66.app(self2431738):R.ffi.throwNonFunApp(L[232],tostring66,[self2431738]);
};
try {
if(--R.GAS > 0) {
$z17301731 = $f17361737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17361737,
"from":L[232]});
}
} catch($e17281729) {
if(R.isCont($e17281729)) {
var $ss17321733 = {"from":L[232],
"go":function(anf_arg941739) {
return $Hanf_arg83031740(anf_arg941739,_plus55,raise62);
}};
$e17281729.stack[R.EXN_STACKHEIGHT++] = $ss17321733;
}
if(R.isPyretException($e17281729)) {
$e17281729.pyretStack.push(L[232]);
}
throw $e17281729;
}
var $ret17341735 = $Hanf_arg83031740($z17301731,_plus55,raise62);
++R.GAS;
return $ret17341735;
});
var $z17151716 = D;
var $f17211722 = function(_) {
return R.isFunction(anf_fun921723)?anf_fun921723.app(visitor2441724,anf_arg961725):R.ffi.throwNonFunApp(L[230],anf_fun921723,[visitor2441724,anf_arg961725]);
};
try {
if(--R.GAS > 0) {
$z17151716 = $f17211722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17211722,
"from":L[230]});
}
} catch($e17131714) {
if(R.isCont($e17131714)) {
var $ss17171718 = {"from":L[230],
"go":function(ann_DASH_check_DASH_temp911726) {
return $Hann_DASH_check_DASH_temp83041727(ann_DASH_check_DASH_temp911726);
}};
$e17131714.stack[R.EXN_STACKHEIGHT++] = $ss17171718;
}
if(R.isPyretException($e17131714)) {
$e17131714.pyretStack.push(L[230]);
}
throw $e17131714;
}
var $ret17191720 = $Hann_DASH_check_DASH_temp83041727($z17151716);
++R.GAS;
return $ret17191720;
};
},{"length":2});
var anf_variant_member1091071 = R.makeMethod(function(self21691) {
return function(cases_DASH_funs31692,else_DASH_clause41703) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[138],2,arguments);
}
var if_DASH_61706 = R.hasField(cases_DASH_funs31692,("s-underscore"));
var if_helper991689 = R.makeFunction(function(if_helper_arg1001711) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[138],1,arguments);
}
var ann_DASH_check_DASH_temp981712 = if_helper_arg1001711;
return ann_DASH_check_DASH_temp981712;
});
var anf_if1031710 = R.isBoolean(if_DASH_61706);
if(R.isPyretTrue(anf_if1031710)) {
if(R.isPyretTrue(if_DASH_61706)) {
var call_DASH_s_DASH_underscore11686 = G(cases_DASH_funs31692,"s-underscore",L[138]);
var anf_arg1061687 = G(self21691,"l",L[229]);
var $z16781679 = D;
var $f16841685 = function(_) {
return R.isFunction(call_DASH_s_DASH_underscore11686)?call_DASH_s_DASH_underscore11686.app(anf_arg1061687):R.ffi.throwNonFunApp(L[138],call_DASH_s_DASH_underscore11686,[anf_arg1061687]);
};
try {
if(--R.GAS > 0) {
$z16781679 = $f16841685();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16841685,
"from":L[138]});
}
} catch($e16761677) {
if(R.isCont($e16761677)) {
var $ss16801681 = {"from":L[138],
"go":function(cont_tail_arg1071688) {
return $Hcont_tail_arg83051690(cont_tail_arg1071688,if_helper991689);
}};
$e16761677.stack[R.EXN_STACKHEIGHT++] = $ss16801681;
}
if(R.isPyretException($e16761677)) {
$e16761677.pyretStack.push(L[138]);
}
throw $e16761677;
}
var $ret16821683 = $Hcont_tail_arg83051690($z16781679,if_helper991689);
++R.GAS;
return $ret16821683;
} else {
var $z16951696 = D;
var $f17011702 = function(_) {
return R.isFunction(else_DASH_clause41703)?else_DASH_clause41703.app():R.ffi.throwNonFunApp(L[138],else_DASH_clause41703,[]);
};
try {
if(--R.GAS > 0) {
$z16951696 = $f17011702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17011702,
"from":L[138]});
}
} catch($e16931694) {
if(R.isCont($e16931694)) {
var $ss16971698 = {"from":L[138],
"go":function(cont_tail_arg1041704) {
return $Hcont_tail_arg83061705(cont_tail_arg1041704,if_helper991689);
}};
$e16931694.stack[R.EXN_STACKHEIGHT++] = $ss16971698;
}
if(R.isPyretException($e16931694)) {
$e16931694.pyretStack.push(L[138]);
}
throw $e16931694;
}
var $ret16991700 = $Hcont_tail_arg83061705($z16951696,if_helper991689);
++R.GAS;
return $ret16991700;
}
} else {
var cont_tail_arg1011709 = R.throwNonBooleanCondition(L[138],("if"),if_DASH_61706);
if(--R.GAS > 0) {
$z17071708 = R.isFunction(if_helper991689)?if_helper991689.app(cont_tail_arg1011709):R.ffi.throwNonFunApp(L[138],if_helper991689,[cont_tail_arg1011709]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper991689)?if_helper991689.app(cont_tail_arg1011709):R.ffi.throwNonFunApp(L[138],if_helper991689,[cont_tail_arg1011709]);
},
"from":L[138]});
}
++R.GAS;
return $z17071708;
}
};
},{"length":3});
var anf_variant_member1151072 = R.makeMethod(function(self51675) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[138],0,arguments);
}
var anf_arg1111672 = G(self51675,"l",L[138]);
var $z16641665 = D;
var $f16701671 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg1111672):R.ffi.throwNonFunApp(L[138],torepr65,[anf_arg1111672]);
};
try {
if(--R.GAS > 0) {
$z16641665 = $f16701671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16701671,
"from":L[138]});
}
} catch($e16621663) {
if(R.isCont($e16621663)) {
var $ss16661667 = {"from":L[138],
"go":function(anf_arg1121673) {
return $Hanf_arg83101674(anf_arg1121673,_plus55);
}};
$e16621663.stack[R.EXN_STACKHEIGHT++] = $ss16661667;
}
if(R.isPyretException($e16621663)) {
$e16621663.pyretStack.push(L[138]);
}
throw $e16621663;
}
var $ret16681669 = $Hanf_arg83101674($z16641665,_plus55);
++R.GAS;
return $ret16681669;
};
},{"length":1});
var anf_variant_member1171073 = R.makeMethod(function(self1991661) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[228],0,arguments);
}
var $z16511652 = D;
var $f16571658 = function(_) {
return R.isFunction(raise62)?raise62.app(("Cannot compile underscores")):R.ffi.throwNonFunApp(L[228],raise62,[("Cannot compile underscores")]);
};
try {
if(--R.GAS > 0) {
$z16511652 = $f16571658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16571658,
"from":L[228]});
}
} catch($e16491650) {
if(R.isCont($e16491650)) {
var $ss16531654 = {"from":L[228],
"go":function(ann_DASH_check_DASH_temp1161659) {
return $Hann_DASH_check_DASH_temp83111660(ann_DASH_check_DASH_temp1161659);
}};
$e16491650.stack[R.EXN_STACKHEIGHT++] = $ss16531654;
}
if(R.isPyretException($e16491650)) {
$e16491650.pyretStack.push(L[228]);
}
throw $e16491650;
}
var $ret16551656 = $Hann_DASH_check_DASH_temp83111660($z16511652);
++R.GAS;
return $ret16551656;
};
},{"length":1});
var anf_variant_member1191074 = R.makeMethod(function(self2001648) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[227],0,arguments);
}
var $z16381639 = D;
var $f16441645 = function(_) {
return R.isFunction(raise62)?raise62.app(("Cannot compile underscores")):R.ffi.throwNonFunApp(L[227],raise62,[("Cannot compile underscores")]);
};
try {
if(--R.GAS > 0) {
$z16381639 = $f16441645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16441645,
"from":L[227]});
}
} catch($e16361637) {
if(R.isCont($e16361637)) {
var $ss16401641 = {"from":L[227],
"go":function(ann_DASH_check_DASH_temp1181646) {
return $Hann_DASH_check_DASH_temp83121647(ann_DASH_check_DASH_temp1181646);
}};
$e16361637.stack[R.EXN_STACKHEIGHT++] = $ss16401641;
}
if(R.isPyretException($e16361637)) {
$e16361637.pyretStack.push(L[227]);
}
throw $e16361637;
}
var $ret16421643 = $Hann_DASH_check_DASH_temp83121647($z16381639);
++R.GAS;
return $ret16421643;
};
},{"length":1});
var anf_variant_member1221075 = R.makeMethod(function(self2011635) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[225],0,arguments);
}
var anf_fun1211632 = G(PP170,"str",L[226]);
var $z16241625 = D;
var $f16301631 = function(_) {
return R.isFunction(anf_fun1211632)?anf_fun1211632.app(("_")):R.ffi.throwNonFunApp(L[225],anf_fun1211632,[("_")]);
};
try {
if(--R.GAS > 0) {
$z16241625 = $f16301631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16301631,
"from":L[225]});
}
} catch($e16221623) {
if(R.isCont($e16221623)) {
var $ss16261627 = {"from":L[225],
"go":function(ann_DASH_check_DASH_temp1201633) {
return $Hann_DASH_check_DASH_temp83131634(ann_DASH_check_DASH_temp1201633);
}};
$e16221623.stack[R.EXN_STACKHEIGHT++] = $ss16261627;
}
if(R.isPyretException($e16221623)) {
$e16221623.pyretStack.push(L[225]);
}
throw $e16221623;
}
var $ret16281629 = $Hann_DASH_check_DASH_temp83131634($z16241625);
++R.GAS;
return $ret16281629;
};
},{"length":1});
var anf_variant_member1241076 = R.makeMethod(function(self2021621) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[224],0,arguments);
}
var ann_DASH_check_DASH_temp1231620 = ("_");
return ann_DASH_check_DASH_temp1231620;
};
},{"length":1});
var anf_variant_member1261077 = R.makeMethod(function(self2031619) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[223],0,arguments);
}
var $z16091610 = D;
var $f16151616 = function(_) {
return R.isFunction(raise62)?raise62.app(("Cannot get name for underscore")):R.ffi.throwNonFunApp(L[223],raise62,[("Cannot get name for underscore")]);
};
try {
if(--R.GAS > 0) {
$z16091610 = $f16151616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16151616,
"from":L[223]});
}
} catch($e16071608) {
if(R.isCont($e16071608)) {
var $ss16111612 = {"from":L[223],
"go":function(ann_DASH_check_DASH_temp1251617) {
return $Hann_DASH_check_DASH_temp83141618(ann_DASH_check_DASH_temp1251617);
}};
$e16071608.stack[R.EXN_STACKHEIGHT++] = $ss16111612;
}
if(R.isPyretException($e16071608)) {
$e16071608.pyretStack.push(L[223]);
}
throw $e16071608;
}
var $ret16131614 = $Hann_DASH_check_DASH_temp83141618($z16091610);
++R.GAS;
return $ret16131614;
};
},{"length":1});
var anf_variant_member1281078 = R.makeMethod(function(self2041606) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[222],0,arguments);
}
var ann_DASH_check_DASH_temp1271605 = ("underscore#");
return ann_DASH_check_DASH_temp1271605;
};
},{"length":1});
var anf_variant_member1411085 = R.makeMethod(function(self81583) {
return function(cases_DASH_funs91584,else_DASH_clause101595) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[137],2,arguments);
}
var if_DASH_121598 = R.hasField(cases_DASH_funs91584,("s-name"));
var if_helper1301581 = R.makeFunction(function(if_helper_arg1311603) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[137],1,arguments);
}
var ann_DASH_check_DASH_temp1291604 = if_helper_arg1311603;
return ann_DASH_check_DASH_temp1291604;
});
var anf_if1341602 = R.isBoolean(if_DASH_121598);
if(R.isPyretTrue(anf_if1341602)) {
if(R.isPyretTrue(if_DASH_121598)) {
var call_DASH_s_DASH_name71577 = G(cases_DASH_funs91584,"s-name",L[137]);
var anf_arg1371578 = G(self81583,"l",L[221]);
var anf_arg1381579 = G(self81583,"s",L[220]);
var $z15691570 = D;
var $f15751576 = function(_) {
return R.isFunction(call_DASH_s_DASH_name71577)?call_DASH_s_DASH_name71577.app(anf_arg1371578,anf_arg1381579):R.ffi.throwNonFunApp(L[137],call_DASH_s_DASH_name71577,[anf_arg1371578,anf_arg1381579]);
};
try {
if(--R.GAS > 0) {
$z15691570 = $f15751576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15751576,
"from":L[137]});
}
} catch($e15671568) {
if(R.isCont($e15671568)) {
var $ss15711572 = {"from":L[137],
"go":function(cont_tail_arg1391580) {
return $Hcont_tail_arg83151582(cont_tail_arg1391580,if_helper1301581);
}};
$e15671568.stack[R.EXN_STACKHEIGHT++] = $ss15711572;
}
if(R.isPyretException($e15671568)) {
$e15671568.pyretStack.push(L[137]);
}
throw $e15671568;
}
var $ret15731574 = $Hcont_tail_arg83151582($z15691570,if_helper1301581);
++R.GAS;
return $ret15731574;
} else {
var $z15871588 = D;
var $f15931594 = function(_) {
return R.isFunction(else_DASH_clause101595)?else_DASH_clause101595.app():R.ffi.throwNonFunApp(L[137],else_DASH_clause101595,[]);
};
try {
if(--R.GAS > 0) {
$z15871588 = $f15931594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15931594,
"from":L[137]});
}
} catch($e15851586) {
if(R.isCont($e15851586)) {
var $ss15891590 = {"from":L[137],
"go":function(cont_tail_arg1351596) {
return $Hcont_tail_arg83161597(cont_tail_arg1351596,if_helper1301581);
}};
$e15851586.stack[R.EXN_STACKHEIGHT++] = $ss15891590;
}
if(R.isPyretException($e15851586)) {
$e15851586.pyretStack.push(L[137]);
}
throw $e15851586;
}
var $ret15911592 = $Hcont_tail_arg83161597($z15871588,if_helper1301581);
++R.GAS;
return $ret15911592;
}
} else {
var cont_tail_arg1321601 = R.throwNonBooleanCondition(L[137],("if"),if_DASH_121598);
if(--R.GAS > 0) {
$z15991600 = R.isFunction(if_helper1301581)?if_helper1301581.app(cont_tail_arg1321601):R.ffi.throwNonFunApp(L[137],if_helper1301581,[cont_tail_arg1321601]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper1301581)?if_helper1301581.app(cont_tail_arg1321601):R.ffi.throwNonFunApp(L[137],if_helper1301581,[cont_tail_arg1321601]);
},
"from":L[137]});
}
++R.GAS;
return $z15991600;
}
};
},{"length":3});
var anf_variant_member1511086 = R.makeMethod(function(self111565) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[137],0,arguments);
}
var anf_arg1431563 = G(self111565,"l",L[137]);
var $z15551556 = D;
var $f15611562 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg1431563):R.ffi.throwNonFunApp(L[137],torepr65,[anf_arg1431563]);
};
try {
if(--R.GAS > 0) {
$z15551556 = $f15611562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15611562,
"from":L[137]});
}
} catch($e15531554) {
if(R.isCont($e15531554)) {
var $ss15571558 = {"from":L[137],
"go":function(anf_arg1441564) {
return $Hanf_arg83231566(anf_arg1441564,self111565,_plus55,torepr65);
}};
$e15531554.stack[R.EXN_STACKHEIGHT++] = $ss15571558;
}
if(R.isPyretException($e15531554)) {
$e15531554.pyretStack.push(L[137]);
}
throw $e15531554;
}
var $ret15591560 = $Hanf_arg83231566($z15551556,self111565,_plus55,torepr65);
++R.GAS;
return $ret15591560;
};
},{"length":1});
var anf_variant_member1551087 = R.makeMethod(function(self2071552) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[219],0,arguments);
}
var anf_arg1531549 = G(self2071552,"s",L[218]);
var $z15411542 = D;
var $f15471548 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("Cannot compile local name "),anf_arg1531549):R.ffi.throwNonFunApp(L[217],_plus55,[("Cannot compile local name "),anf_arg1531549]);
};
try {
if(--R.GAS > 0) {
$z15411542 = $f15471548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15471548,
"from":L[217]});
}
} catch($e15391540) {
if(R.isCont($e15391540)) {
var $ss15431544 = {"from":L[217],
"go":function(anf_arg1541550) {
return $Hanf_arg83251551(anf_arg1541550,raise62);
}};
$e15391540.stack[R.EXN_STACKHEIGHT++] = $ss15431544;
}
if(R.isPyretException($e15391540)) {
$e15391540.pyretStack.push(L[217]);
}
throw $e15391540;
}
var $ret15451546 = $Hanf_arg83251551($z15411542,raise62);
++R.GAS;
return $ret15451546;
};
},{"length":1});
var anf_variant_member1591088 = R.makeMethod(function(self2081538) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[216],0,arguments);
}
var anf_arg1571535 = G(self2081538,"s",L[215]);
var $z15271528 = D;
var $f15331534 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("Cannot compile local name "),anf_arg1571535):R.ffi.throwNonFunApp(L[214],_plus55,[("Cannot compile local name "),anf_arg1571535]);
};
try {
if(--R.GAS > 0) {
$z15271528 = $f15331534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15331534,
"from":L[214]});
}
} catch($e15251526) {
if(R.isCont($e15251526)) {
var $ss15291530 = {"from":L[214],
"go":function(anf_arg1581536) {
return $Hanf_arg83271537(anf_arg1581536,raise62);
}};
$e15251526.stack[R.EXN_STACKHEIGHT++] = $ss15291530;
}
if(R.isPyretException($e15251526)) {
$e15251526.pyretStack.push(L[214]);
}
throw $e15251526;
}
var $ret15311532 = $Hanf_arg83271537($z15271528,raise62);
++R.GAS;
return $ret15311532;
};
},{"length":1});
var anf_variant_member1631089 = R.makeMethod(function(self2091524) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[211],0,arguments);
}
var anf_fun1611520 = G(PP170,"str",L[213]);
var anf_arg1621521 = G(self2091524,"s",L[212]);
var $z15121513 = D;
var $f15181519 = function(_) {
return R.isFunction(anf_fun1611520)?anf_fun1611520.app(anf_arg1621521):R.ffi.throwNonFunApp(L[211],anf_fun1611520,[anf_arg1621521]);
};
try {
if(--R.GAS > 0) {
$z15121513 = $f15181519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15181519,
"from":L[211]});
}
} catch($e15101511) {
if(R.isCont($e15101511)) {
var $ss15141515 = {"from":L[211],
"go":function(ann_DASH_check_DASH_temp1601522) {
return $Hann_DASH_check_DASH_temp83281523(ann_DASH_check_DASH_temp1601522);
}};
$e15101511.stack[R.EXN_STACKHEIGHT++] = $ss15141515;
}
if(R.isPyretException($e15101511)) {
$e15101511.pyretStack.push(L[211]);
}
throw $e15101511;
}
var $ret15161517 = $Hann_DASH_check_DASH_temp83281523($z15121513);
++R.GAS;
return $ret15161517;
};
},{"length":1});
var anf_variant_member1651090 = R.makeMethod(function(self2101509) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[210],0,arguments);
}
var ann_DASH_check_DASH_temp1641508 = G(self2101509,"s",L[209]);
return ann_DASH_check_DASH_temp1641508;
};
},{"length":1});
var anf_variant_member1671091 = R.makeMethod(function(self2111507) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[208],0,arguments);
}
var ann_DASH_check_DASH_temp1661506 = G(self2111507,"s",L[207]);
return ann_DASH_check_DASH_temp1661506;
};
},{"length":1});
var anf_variant_member1701092 = R.makeMethod(function(self2121505) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[205],0,arguments);
}
var anf_arg1691502 = G(self2121505,"s",L[206]);
var $z14941495 = D;
var $f15001501 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("name#"),anf_arg1691502):R.ffi.throwNonFunApp(L[205],_plus55,[("name#"),anf_arg1691502]);
};
try {
if(--R.GAS > 0) {
$z14941495 = $f15001501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15001501,
"from":L[205]});
}
} catch($e14921493) {
if(R.isCont($e14921493)) {
var $ss14961497 = {"from":L[205],
"go":function(ann_DASH_check_DASH_temp1681503) {
return $Hann_DASH_check_DASH_temp83291504(ann_DASH_check_DASH_temp1681503);
}};
$e14921493.stack[R.EXN_STACKHEIGHT++] = $ss14961497;
}
if(R.isPyretException($e14921493)) {
$e14921493.pyretStack.push(L[205]);
}
throw $e14921493;
}
var $ret14981499 = $Hann_DASH_check_DASH_temp83291504($z14941495);
++R.GAS;
return $ret14981499;
};
},{"length":1});
var anf_variant_member1821100 = R.makeMethod(function(self141470) {
return function(cases_DASH_funs151471,else_DASH_clause161482) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[136],2,arguments);
}
var if_DASH_181485 = R.hasField(cases_DASH_funs151471,("s-global"));
var if_helper1721468 = R.makeFunction(function(if_helper_arg1731490) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[136],1,arguments);
}
var ann_DASH_check_DASH_temp1711491 = if_helper_arg1731490;
return ann_DASH_check_DASH_temp1711491;
});
var anf_if1761489 = R.isBoolean(if_DASH_181485);
if(R.isPyretTrue(anf_if1761489)) {
if(R.isPyretTrue(if_DASH_181485)) {
var call_DASH_s_DASH_global131465 = G(cases_DASH_funs151471,"s-global",L[136]);
var anf_arg1791466 = G(self141470,"s",L[204]);
var $z14571458 = D;
var $f14631464 = function(_) {
return R.isFunction(call_DASH_s_DASH_global131465)?call_DASH_s_DASH_global131465.app(anf_arg1791466):R.ffi.throwNonFunApp(L[136],call_DASH_s_DASH_global131465,[anf_arg1791466]);
};
try {
if(--R.GAS > 0) {
$z14571458 = $f14631464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14631464,
"from":L[136]});
}
} catch($e14551456) {
if(R.isCont($e14551456)) {
var $ss14591460 = {"from":L[136],
"go":function(cont_tail_arg1801467) {
return $Hcont_tail_arg83301469(cont_tail_arg1801467,if_helper1721468);
}};
$e14551456.stack[R.EXN_STACKHEIGHT++] = $ss14591460;
}
if(R.isPyretException($e14551456)) {
$e14551456.pyretStack.push(L[136]);
}
throw $e14551456;
}
var $ret14611462 = $Hcont_tail_arg83301469($z14571458,if_helper1721468);
++R.GAS;
return $ret14611462;
} else {
var $z14741475 = D;
var $f14801481 = function(_) {
return R.isFunction(else_DASH_clause161482)?else_DASH_clause161482.app():R.ffi.throwNonFunApp(L[136],else_DASH_clause161482,[]);
};
try {
if(--R.GAS > 0) {
$z14741475 = $f14801481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14801481,
"from":L[136]});
}
} catch($e14721473) {
if(R.isCont($e14721473)) {
var $ss14761477 = {"from":L[136],
"go":function(cont_tail_arg1771483) {
return $Hcont_tail_arg83311484(cont_tail_arg1771483,if_helper1721468);
}};
$e14721473.stack[R.EXN_STACKHEIGHT++] = $ss14761477;
}
if(R.isPyretException($e14721473)) {
$e14721473.pyretStack.push(L[136]);
}
throw $e14721473;
}
var $ret14781479 = $Hcont_tail_arg83311484($z14741475,if_helper1721468);
++R.GAS;
return $ret14781479;
}
} else {
var cont_tail_arg1741488 = R.throwNonBooleanCondition(L[136],("if"),if_DASH_181485);
if(--R.GAS > 0) {
$z14861487 = R.isFunction(if_helper1721468)?if_helper1721468.app(cont_tail_arg1741488):R.ffi.throwNonFunApp(L[136],if_helper1721468,[cont_tail_arg1741488]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper1721468)?if_helper1721468.app(cont_tail_arg1741488):R.ffi.throwNonFunApp(L[136],if_helper1721468,[cont_tail_arg1741488]);
},
"from":L[136]});
}
++R.GAS;
return $z14861487;
}
};
},{"length":3});
var anf_variant_member1881101 = R.makeMethod(function(self171454) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[136],0,arguments);
}
var anf_arg1841451 = G(self171454,"s",L[136]);
var $z14431444 = D;
var $f14491450 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg1841451):R.ffi.throwNonFunApp(L[136],torepr65,[anf_arg1841451]);
};
try {
if(--R.GAS > 0) {
$z14431444 = $f14491450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14491450,
"from":L[136]});
}
} catch($e14411442) {
if(R.isCont($e14411442)) {
var $ss14451446 = {"from":L[136],
"go":function(anf_arg1851452) {
return $Hanf_arg83351453(anf_arg1851452,_plus55);
}};
$e14411442.stack[R.EXN_STACKHEIGHT++] = $ss14451446;
}
if(R.isPyretException($e14411442)) {
$e14411442.pyretStack.push(L[136]);
}
throw $e14411442;
}
var $ret14471448 = $Hanf_arg83351453($z14431444,_plus55);
++R.GAS;
return $ret14471448;
};
},{"length":1});
var anf_variant_member1931102 = R.makeMethod(function(self2141440) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[203],0,arguments);
}
var anf_fun1901438 = G(PP170,"str",L[202]);
var anf_fun1911436 = G(self2141440,"to-compiled",L[201]);
var $z14281429 = D;
var $f14341435 = function(_) {
return R.isFunction(anf_fun1911436)?anf_fun1911436.app():R.ffi.throwNonFunApp(L[200],anf_fun1911436,[]);
};
try {
if(--R.GAS > 0) {
$z14281429 = $f14341435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14341435,
"from":L[200]});
}
} catch($e14261427) {
if(R.isCont($e14261427)) {
var $ss14301431 = {"from":L[200],
"go":function(anf_arg1921437) {
return $Hanf_arg83371439(anf_arg1921437,anf_fun1901438);
}};
$e14261427.stack[R.EXN_STACKHEIGHT++] = $ss14301431;
}
if(R.isPyretException($e14261427)) {
$e14261427.pyretStack.push(L[200]);
}
throw $e14261427;
}
var $ret14321433 = $Hanf_arg83371439($z14281429,anf_fun1901438);
++R.GAS;
return $ret14321433;
};
},{"length":1});
var anf_variant_member1951103 = R.makeMethod(function(self2151425) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[199],0,arguments);
}
var ann_DASH_check_DASH_temp1941424 = G(self2151425,"s",L[198]);
return ann_DASH_check_DASH_temp1941424;
};
},{"length":1});
var anf_variant_member1991104 = R.makeMethod(function(self2161423) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[195],0,arguments);
}
var anf_fun1971419 = G(PP170,"str",L[197]);
var anf_arg1981420 = G(self2161423,"s",L[196]);
var $z14111412 = D;
var $f14171418 = function(_) {
return R.isFunction(anf_fun1971419)?anf_fun1971419.app(anf_arg1981420):R.ffi.throwNonFunApp(L[195],anf_fun1971419,[anf_arg1981420]);
};
try {
if(--R.GAS > 0) {
$z14111412 = $f14171418();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14171418,
"from":L[195]});
}
} catch($e14091410) {
if(R.isCont($e14091410)) {
var $ss14131414 = {"from":L[195],
"go":function(ann_DASH_check_DASH_temp1961421) {
return $Hann_DASH_check_DASH_temp83381422(ann_DASH_check_DASH_temp1961421);
}};
$e14091410.stack[R.EXN_STACKHEIGHT++] = $ss14131414;
}
if(R.isPyretException($e14091410)) {
$e14091410.pyretStack.push(L[195]);
}
throw $e14091410;
}
var $ret14151416 = $Hann_DASH_check_DASH_temp83381422($z14111412);
++R.GAS;
return $ret14151416;
};
},{"length":1});
var anf_variant_member2011105 = R.makeMethod(function(self2171408) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[194],0,arguments);
}
var ann_DASH_check_DASH_temp2001407 = G(self2171408,"s",L[193]);
return ann_DASH_check_DASH_temp2001407;
};
},{"length":1});
var anf_variant_member2031106 = R.makeMethod(function(self2181406) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[192],0,arguments);
}
var ann_DASH_check_DASH_temp2021405 = G(self2181406,"s",L[191]);
return ann_DASH_check_DASH_temp2021405;
};
},{"length":1});
var anf_variant_member2061107 = R.makeMethod(function(self2191404) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[189],0,arguments);
}
var anf_arg2051401 = G(self2191404,"s",L[190]);
var $z13931394 = D;
var $f13991400 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("global#"),anf_arg2051401):R.ffi.throwNonFunApp(L[189],_plus55,[("global#"),anf_arg2051401]);
};
try {
if(--R.GAS > 0) {
$z13931394 = $f13991400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13991400,
"from":L[189]});
}
} catch($e13911392) {
if(R.isCont($e13911392)) {
var $ss13951396 = {"from":L[189],
"go":function(ann_DASH_check_DASH_temp2041402) {
return $Hann_DASH_check_DASH_temp83391403(ann_DASH_check_DASH_temp2041402);
}};
$e13911392.stack[R.EXN_STACKHEIGHT++] = $ss13951396;
}
if(R.isPyretException($e13911392)) {
$e13911392.pyretStack.push(L[189]);
}
throw $e13911392;
}
var $ret13971398 = $Hann_DASH_check_DASH_temp83391403($z13931394);
++R.GAS;
return $ret13971398;
};
},{"length":1});
var anf_variant_member2181114 = R.makeMethod(function(self201369) {
return function(cases_DASH_funs211370,else_DASH_clause221381) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[135],2,arguments);
}
var if_DASH_241384 = R.hasField(cases_DASH_funs211370,("s-type-global"));
var if_helper2081367 = R.makeFunction(function(if_helper_arg2091389) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[135],1,arguments);
}
var ann_DASH_check_DASH_temp2071390 = if_helper_arg2091389;
return ann_DASH_check_DASH_temp2071390;
});
var anf_if2121388 = R.isBoolean(if_DASH_241384);
if(R.isPyretTrue(anf_if2121388)) {
if(R.isPyretTrue(if_DASH_241384)) {
var call_DASH_s_DASH_type_DASH_global191364 = G(cases_DASH_funs211370,"s-type-global",L[135]);
var anf_arg2151365 = G(self201369,"s",L[188]);
var $z13561357 = D;
var $f13621363 = function(_) {
return R.isFunction(call_DASH_s_DASH_type_DASH_global191364)?call_DASH_s_DASH_type_DASH_global191364.app(anf_arg2151365):R.ffi.throwNonFunApp(L[135],call_DASH_s_DASH_type_DASH_global191364,[anf_arg2151365]);
};
try {
if(--R.GAS > 0) {
$z13561357 = $f13621363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13621363,
"from":L[135]});
}
} catch($e13541355) {
if(R.isCont($e13541355)) {
var $ss13581359 = {"from":L[135],
"go":function(cont_tail_arg2161366) {
return $Hcont_tail_arg83401368(cont_tail_arg2161366,if_helper2081367);
}};
$e13541355.stack[R.EXN_STACKHEIGHT++] = $ss13581359;
}
if(R.isPyretException($e13541355)) {
$e13541355.pyretStack.push(L[135]);
}
throw $e13541355;
}
var $ret13601361 = $Hcont_tail_arg83401368($z13561357,if_helper2081367);
++R.GAS;
return $ret13601361;
} else {
var $z13731374 = D;
var $f13791380 = function(_) {
return R.isFunction(else_DASH_clause221381)?else_DASH_clause221381.app():R.ffi.throwNonFunApp(L[135],else_DASH_clause221381,[]);
};
try {
if(--R.GAS > 0) {
$z13731374 = $f13791380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13791380,
"from":L[135]});
}
} catch($e13711372) {
if(R.isCont($e13711372)) {
var $ss13751376 = {"from":L[135],
"go":function(cont_tail_arg2131382) {
return $Hcont_tail_arg83411383(cont_tail_arg2131382,if_helper2081367);
}};
$e13711372.stack[R.EXN_STACKHEIGHT++] = $ss13751376;
}
if(R.isPyretException($e13711372)) {
$e13711372.pyretStack.push(L[135]);
}
throw $e13711372;
}
var $ret13771378 = $Hcont_tail_arg83411383($z13731374,if_helper2081367);
++R.GAS;
return $ret13771378;
}
} else {
var cont_tail_arg2101387 = R.throwNonBooleanCondition(L[135],("if"),if_DASH_241384);
if(--R.GAS > 0) {
$z13851386 = R.isFunction(if_helper2081367)?if_helper2081367.app(cont_tail_arg2101387):R.ffi.throwNonFunApp(L[135],if_helper2081367,[cont_tail_arg2101387]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper2081367)?if_helper2081367.app(cont_tail_arg2101387):R.ffi.throwNonFunApp(L[135],if_helper2081367,[cont_tail_arg2101387]);
},
"from":L[135]});
}
++R.GAS;
return $z13851386;
}
};
},{"length":3});
var anf_variant_member2241115 = R.makeMethod(function(self231353) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[135],0,arguments);
}
var anf_arg2201350 = G(self231353,"s",L[135]);
var $z13421343 = D;
var $f13481349 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg2201350):R.ffi.throwNonFunApp(L[135],torepr65,[anf_arg2201350]);
};
try {
if(--R.GAS > 0) {
$z13421343 = $f13481349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13481349,
"from":L[135]});
}
} catch($e13401341) {
if(R.isCont($e13401341)) {
var $ss13441345 = {"from":L[135],
"go":function(anf_arg2211351) {
return $Hanf_arg83451352(anf_arg2211351,_plus55);
}};
$e13401341.stack[R.EXN_STACKHEIGHT++] = $ss13441345;
}
if(R.isPyretException($e13401341)) {
$e13401341.pyretStack.push(L[135]);
}
throw $e13401341;
}
var $ret13461347 = $Hanf_arg83451352($z13421343,_plus55);
++R.GAS;
return $ret13461347;
};
},{"length":1});
var anf_variant_member2291116 = R.makeMethod(function(self2211339) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[187],0,arguments);
}
var anf_fun2261337 = G(PP170,"str",L[186]);
var anf_fun2271335 = G(self2211339,"to-compiled",L[185]);
var $z13271328 = D;
var $f13331334 = function(_) {
return R.isFunction(anf_fun2271335)?anf_fun2271335.app():R.ffi.throwNonFunApp(L[184],anf_fun2271335,[]);
};
try {
if(--R.GAS > 0) {
$z13271328 = $f13331334();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13331334,
"from":L[184]});
}
} catch($e13251326) {
if(R.isCont($e13251326)) {
var $ss13291330 = {"from":L[184],
"go":function(anf_arg2281336) {
return $Hanf_arg83471338(anf_arg2281336,anf_fun2261337);
}};
$e13251326.stack[R.EXN_STACKHEIGHT++] = $ss13291330;
}
if(R.isPyretException($e13251326)) {
$e13251326.pyretStack.push(L[184]);
}
throw $e13251326;
}
var $ret13311332 = $Hanf_arg83471338($z13271328,anf_fun2261337);
++R.GAS;
return $ret13311332;
};
},{"length":1});
var anf_variant_member2321117 = R.makeMethod(function(self2221324) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[182],0,arguments);
}
var anf_arg2311321 = G(self2221324,"s",L[183]);
var $z13131314 = D;
var $f13191320 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("$type$"),anf_arg2311321):R.ffi.throwNonFunApp(L[182],_plus55,[("$type$"),anf_arg2311321]);
};
try {
if(--R.GAS > 0) {
$z13131314 = $f13191320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13191320,
"from":L[182]});
}
} catch($e13111312) {
if(R.isCont($e13111312)) {
var $ss13151316 = {"from":L[182],
"go":function(ann_DASH_check_DASH_temp2301322) {
return $Hann_DASH_check_DASH_temp83481323(ann_DASH_check_DASH_temp2301322);
}};
$e13111312.stack[R.EXN_STACKHEIGHT++] = $ss13151316;
}
if(R.isPyretException($e13111312)) {
$e13111312.pyretStack.push(L[182]);
}
throw $e13111312;
}
var $ret13171318 = $Hann_DASH_check_DASH_temp83481323($z13131314);
++R.GAS;
return $ret13171318;
};
},{"length":1});
var anf_variant_member2361118 = R.makeMethod(function(self2231310) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[179],0,arguments);
}
var anf_fun2341306 = G(PP170,"str",L[181]);
var anf_arg2351307 = G(self2231310,"s",L[180]);
var $z12981299 = D;
var $f13041305 = function(_) {
return R.isFunction(anf_fun2341306)?anf_fun2341306.app(anf_arg2351307):R.ffi.throwNonFunApp(L[179],anf_fun2341306,[anf_arg2351307]);
};
try {
if(--R.GAS > 0) {
$z12981299 = $f13041305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13041305,
"from":L[179]});
}
} catch($e12961297) {
if(R.isCont($e12961297)) {
var $ss13001301 = {"from":L[179],
"go":function(ann_DASH_check_DASH_temp2331308) {
return $Hann_DASH_check_DASH_temp83491309(ann_DASH_check_DASH_temp2331308);
}};
$e12961297.stack[R.EXN_STACKHEIGHT++] = $ss13001301;
}
if(R.isPyretException($e12961297)) {
$e12961297.pyretStack.push(L[179]);
}
throw $e12961297;
}
var $ret13021303 = $Hann_DASH_check_DASH_temp83491309($z12981299);
++R.GAS;
return $ret13021303;
};
},{"length":1});
var anf_variant_member2391119 = R.makeMethod(function(self2241295) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[177],0,arguments);
}
var anf_arg2381292 = G(self2241295,"s",L[178]);
var $z12841285 = D;
var $f12901291 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("$type$"),anf_arg2381292):R.ffi.throwNonFunApp(L[177],_plus55,[("$type$"),anf_arg2381292]);
};
try {
if(--R.GAS > 0) {
$z12841285 = $f12901291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12901291,
"from":L[177]});
}
} catch($e12821283) {
if(R.isCont($e12821283)) {
var $ss12861287 = {"from":L[177],
"go":function(ann_DASH_check_DASH_temp2371293) {
return $Hann_DASH_check_DASH_temp83501294(ann_DASH_check_DASH_temp2371293);
}};
$e12821283.stack[R.EXN_STACKHEIGHT++] = $ss12861287;
}
if(R.isPyretException($e12821283)) {
$e12821283.pyretStack.push(L[177]);
}
throw $e12821283;
}
var $ret12881289 = $Hann_DASH_check_DASH_temp83501294($z12841285);
++R.GAS;
return $ret12881289;
};
},{"length":1});
var anf_variant_member2411120 = R.makeMethod(function(self2251281) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[176],0,arguments);
}
var ann_DASH_check_DASH_temp2401280 = G(self2251281,"s",L[175]);
return ann_DASH_check_DASH_temp2401280;
};
},{"length":1});
var anf_variant_member2441121 = R.makeMethod(function(self2261279) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[173],0,arguments);
}
var anf_arg2431276 = G(self2261279,"s",L[174]);
var $z12681269 = D;
var $f12741275 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("tglobal#"),anf_arg2431276):R.ffi.throwNonFunApp(L[173],_plus55,[("tglobal#"),anf_arg2431276]);
};
try {
if(--R.GAS > 0) {
$z12681269 = $f12741275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12741275,
"from":L[173]});
}
} catch($e12661267) {
if(R.isCont($e12661267)) {
var $ss12701271 = {"from":L[173],
"go":function(ann_DASH_check_DASH_temp2421277) {
return $Hann_DASH_check_DASH_temp83511278(ann_DASH_check_DASH_temp2421277);
}};
$e12661267.stack[R.EXN_STACKHEIGHT++] = $ss12701271;
}
if(R.isPyretException($e12661267)) {
$e12661267.pyretStack.push(L[173]);
}
throw $e12661267;
}
var $ret12721273 = $Hann_DASH_check_DASH_temp83511278($z12681269);
++R.GAS;
return $ret12721273;
};
},{"length":1});
var anf_variant_member2571128 = R.makeMethod(function(self261243) {
return function(cases_DASH_funs271244,else_DASH_clause281255) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[134],2,arguments);
}
var if_DASH_301258 = R.hasField(cases_DASH_funs271244,("s-atom"));
var if_helper2461241 = R.makeFunction(function(if_helper_arg2471264) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[134],1,arguments);
}
var ann_DASH_check_DASH_temp2451265 = if_helper_arg2471264;
return ann_DASH_check_DASH_temp2451265;
});
var anf_if2501263 = R.isBoolean(if_DASH_301258);
if(R.isPyretTrue(anf_if2501263)) {
if(R.isPyretTrue(if_DASH_301258)) {
var call_DASH_s_DASH_atom251237 = G(cases_DASH_funs271244,"s-atom",L[134]);
var anf_arg2531238 = G(self261243,"base",L[172]);
var anf_arg2541239 = G(self261243,"serial",L[171]);
var $z12291230 = D;
var $f12351236 = function(_) {
return R.isFunction(call_DASH_s_DASH_atom251237)?call_DASH_s_DASH_atom251237.app(anf_arg2531238,anf_arg2541239):R.ffi.throwNonFunApp(L[134],call_DASH_s_DASH_atom251237,[anf_arg2531238,anf_arg2541239]);
};
try {
if(--R.GAS > 0) {
$z12291230 = $f12351236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12351236,
"from":L[134]});
}
} catch($e12271228) {
if(R.isCont($e12271228)) {
var $ss12311232 = {"from":L[134],
"go":function(cont_tail_arg2551240) {
return $Hcont_tail_arg83521242(cont_tail_arg2551240,if_helper2461241);
}};
$e12271228.stack[R.EXN_STACKHEIGHT++] = $ss12311232;
}
if(R.isPyretException($e12271228)) {
$e12271228.pyretStack.push(L[134]);
}
throw $e12271228;
}
var $ret12331234 = $Hcont_tail_arg83521242($z12291230,if_helper2461241);
++R.GAS;
return $ret12331234;
} else {
var $z12471248 = D;
var $f12531254 = function(_) {
return R.isFunction(else_DASH_clause281255)?else_DASH_clause281255.app():R.ffi.throwNonFunApp(L[134],else_DASH_clause281255,[]);
};
try {
if(--R.GAS > 0) {
$z12471248 = $f12531254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12531254,
"from":L[134]});
}
} catch($e12451246) {
if(R.isCont($e12451246)) {
var $ss12491250 = {"from":L[134],
"go":function(cont_tail_arg2511256) {
return $Hcont_tail_arg83531257(cont_tail_arg2511256,if_helper2461241);
}};
$e12451246.stack[R.EXN_STACKHEIGHT++] = $ss12491250;
}
if(R.isPyretException($e12451246)) {
$e12451246.pyretStack.push(L[134]);
}
throw $e12451246;
}
var $ret12511252 = $Hcont_tail_arg83531257($z12471248,if_helper2461241);
++R.GAS;
return $ret12511252;
}
} else {
var cont_tail_arg2481261 = R.throwNonBooleanCondition(L[134],("if"),if_DASH_301258);
if(--R.GAS > 0) {
$z12591260 = R.isFunction(if_helper2461241)?if_helper2461241.app(cont_tail_arg2481261):R.ffi.throwNonFunApp(L[134],if_helper2461241,[cont_tail_arg2481261]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper2461241)?if_helper2461241.app(cont_tail_arg2481261):R.ffi.throwNonFunApp(L[134],if_helper2461241,[cont_tail_arg2481261]);
},
"from":L[134]});
}
++R.GAS;
return $z12591260;
}
};
},{"length":3});
var anf_variant_member2671129 = R.makeMethod(function(self291225) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[134],0,arguments);
}
var anf_arg2591223 = G(self291225,"base",L[134]);
var $z12151216 = D;
var $f12211222 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg2591223):R.ffi.throwNonFunApp(L[134],torepr65,[anf_arg2591223]);
};
try {
if(--R.GAS > 0) {
$z12151216 = $f12211222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12211222,
"from":L[134]});
}
} catch($e12131214) {
if(R.isCont($e12131214)) {
var $ss12171218 = {"from":L[134],
"go":function(anf_arg2601224) {
return $Hanf_arg83601226(anf_arg2601224,self291225,_plus55,torepr65);
}};
$e12131214.stack[R.EXN_STACKHEIGHT++] = $ss12171218;
}
if(R.isPyretException($e12131214)) {
$e12131214.pyretStack.push(L[134]);
}
throw $e12131214;
}
var $ret12191220 = $Hanf_arg83601226($z12151216,self291225,_plus55,torepr65);
++R.GAS;
return $ret12191220;
};
},{"length":1});
var anf_variant_member2721130 = R.makeMethod(function(self2291212) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[170],0,arguments);
}
var anf_fun2691210 = G(PP170,"str",L[169]);
var anf_fun2701208 = G(self2291212,"to-compiled",L[168]);
var $z12001201 = D;
var $f12061207 = function(_) {
return R.isFunction(anf_fun2701208)?anf_fun2701208.app():R.ffi.throwNonFunApp(L[167],anf_fun2701208,[]);
};
try {
if(--R.GAS > 0) {
$z12001201 = $f12061207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12061207,
"from":L[167]});
}
} catch($e11981199) {
if(R.isCont($e11981199)) {
var $ss12021203 = {"from":L[167],
"go":function(anf_arg2711209) {
return $Hanf_arg83621211(anf_arg2711209,anf_fun2691210);
}};
$e11981199.stack[R.EXN_STACKHEIGHT++] = $ss12021203;
}
if(R.isPyretException($e11981199)) {
$e11981199.pyretStack.push(L[167]);
}
throw $e11981199;
}
var $ret12041205 = $Hanf_arg83621211($z12001201,anf_fun2691210);
++R.GAS;
return $ret12041205;
};
},{"length":1});
var anf_variant_member2771131 = R.makeMethod(function(self2301197) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[166],0,arguments);
}
var anf_arg2741195 = G(self2301197,"base",L[165]);
var anf_arg2751193 = G(self2301197,"serial",L[164]);
var $z11851186 = D;
var $f11911192 = function(_) {
return R.isFunction(tostring66)?tostring66.app(anf_arg2751193):R.ffi.throwNonFunApp(L[163],tostring66,[anf_arg2751193]);
};
try {
if(--R.GAS > 0) {
$z11851186 = $f11911192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11911192,
"from":L[163]});
}
} catch($e11831184) {
if(R.isCont($e11831184)) {
var $ss11871188 = {"from":L[163],
"go":function(anf_arg2761194) {
return $Hanf_arg83641196(anf_arg2761194,anf_arg2741195,_plus55);
}};
$e11831184.stack[R.EXN_STACKHEIGHT++] = $ss11871188;
}
if(R.isPyretException($e11831184)) {
$e11831184.pyretStack.push(L[163]);
}
throw $e11831184;
}
var $ret11891190 = $Hanf_arg83641196($z11851186,anf_arg2741195,_plus55);
++R.GAS;
return $ret11891190;
};
},{"length":1});
var anf_variant_member2821132 = R.makeMethod(function(self2311182) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[162],0,arguments);
}
var anf_fun2791180 = G(PP170,"str",L[161]);
var anf_fun2801178 = G(self2311182,"to-compiled",L[160]);
var $z11701171 = D;
var $f11761177 = function(_) {
return R.isFunction(anf_fun2801178)?anf_fun2801178.app():R.ffi.throwNonFunApp(L[159],anf_fun2801178,[]);
};
try {
if(--R.GAS > 0) {
$z11701171 = $f11761177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11761177,
"from":L[159]});
}
} catch($e11681169) {
if(R.isCont($e11681169)) {
var $ss11721173 = {"from":L[159],
"go":function(anf_arg2811179) {
return $Hanf_arg83661181(anf_arg2811179,anf_fun2791180);
}};
$e11681169.stack[R.EXN_STACKHEIGHT++] = $ss11721173;
}
if(R.isPyretException($e11681169)) {
$e11681169.pyretStack.push(L[159]);
}
throw $e11681169;
}
var $ret11741175 = $Hanf_arg83661181($z11701171,anf_fun2791180);
++R.GAS;
return $ret11741175;
};
},{"length":1});
var anf_variant_member2851133 = R.makeMethod(function(self2321167) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[157],0,arguments);
}
var anf_fun2841164 = G(self2321167,"to-compiled",L[158]);
var $z11561157 = D;
var $f11621163 = function(_) {
return R.isFunction(anf_fun2841164)?anf_fun2841164.app():R.ffi.throwNonFunApp(L[157],anf_fun2841164,[]);
};
try {
if(--R.GAS > 0) {
$z11561157 = $f11621163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11621163,
"from":L[157]});
}
} catch($e11541155) {
if(R.isCont($e11541155)) {
var $ss11581159 = {"from":L[157],
"go":function(ann_DASH_check_DASH_temp2831165) {
return $Hann_DASH_check_DASH_temp83671166(ann_DASH_check_DASH_temp2831165);
}};
$e11541155.stack[R.EXN_STACKHEIGHT++] = $ss11581159;
}
if(R.isPyretException($e11541155)) {
$e11541155.pyretStack.push(L[157]);
}
throw $e11541155;
}
var $ret11601161 = $Hann_DASH_check_DASH_temp83671166($z11561157);
++R.GAS;
return $ret11601161;
};
},{"length":1});
var anf_variant_member2871134 = R.makeMethod(function(self2331153) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[156],0,arguments);
}
var ann_DASH_check_DASH_temp2861152 = G(self2331153,"base",L[155]);
return ann_DASH_check_DASH_temp2861152;
};
},{"length":1});
var anf_variant_member2931135 = R.makeMethod(function(self2341150) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[154],0,arguments);
}
var anf_arg2891148 = G(self2341150,"base",L[153]);
var $z11401141 = D;
var $f11461147 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("atom#"),anf_arg2891148):R.ffi.throwNonFunApp(L[152],_plus55,[("atom#"),anf_arg2891148]);
};
try {
if(--R.GAS > 0) {
$z11401141 = $f11461147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11461147,
"from":L[152]});
}
} catch($e11381139) {
if(R.isCont($e11381139)) {
var $ss11421143 = {"from":L[152],
"go":function(anf_arg2901149) {
return $Hanf_arg83701151(anf_arg2901149,self2341150,_plus55,tostring66);
}};
$e11381139.stack[R.EXN_STACKHEIGHT++] = $ss11421143;
}
if(R.isPyretException($e11381139)) {
$e11381139.pyretStack.push(L[152]);
}
throw $e11381139;
}
var $ret11441145 = $Hanf_arg83701151($z11401141,self2341150,_plus55,tostring66);
++R.GAS;
return $ret11441145;
};
},{"length":1});
var anf_assign2941004 = (function() {
var $s_DASH_underscore_DASH_base10661067 = {"_lessthan":anf_shared721061,
"_lessequal":anf_shared781062,
"_greaterthan":anf_shared841063,
"_greaterequal":anf_shared901064,
"visit":anf_shared971065,
"_match":anf_variant_member1091071,
"_torepr":anf_variant_member1151072,
"to-compiled-source":anf_variant_member1171073,
"to-compiled":anf_variant_member1191074,
"tosource":anf_variant_member1221075,
"tostring":anf_variant_member1241076,
"toname":anf_variant_member1261077,
"key":anf_variant_member1281078};
var $s_DASH_underscore_DASH_brands10691070 = {"$brand-s-underscore1068":true};
$s_DASH_underscore_DASH_brands10691070[NameT167134._brand] = true
var $s_DASH_name_DASH_base10801081 = {"_lessthan":anf_shared721061,
"_lessequal":anf_shared781062,
"_greaterthan":anf_shared841063,
"_greaterequal":anf_shared901064,
"visit":anf_shared971065,
"_match":anf_variant_member1411085,
"_torepr":anf_variant_member1511086,
"to-compiled-source":anf_variant_member1551087,
"to-compiled":anf_variant_member1591088,
"tosource":anf_variant_member1631089,
"tostring":anf_variant_member1651090,
"toname":anf_variant_member1671091,
"key":anf_variant_member1701092};
var $s_DASH_name_DASH_brands10831084 = {"$brand-s-name1082":true};
$s_DASH_name_DASH_brands10831084[NameT167134._brand] = true
var $s_DASH_global_DASH_base10951096 = {"_lessthan":anf_shared721061,
"_lessequal":anf_shared781062,
"_greaterthan":anf_shared841063,
"_greaterequal":anf_shared901064,
"visit":anf_shared971065,
"_match":anf_variant_member1821100,
"_torepr":anf_variant_member1881101,
"to-compiled-source":anf_variant_member1931102,
"to-compiled":anf_variant_member1951103,
"tosource":anf_variant_member1991104,
"tostring":anf_variant_member2011105,
"toname":anf_variant_member2031106,
"key":anf_variant_member2061107};
var $s_DASH_global_DASH_brands10981099 = {"$brand-s-global1097":true};
$s_DASH_global_DASH_brands10981099[NameT167134._brand] = true
var $s_DASH_type_DASH_global_DASH_base11091110 = {"_lessthan":anf_shared721061,
"_lessequal":anf_shared781062,
"_greaterthan":anf_shared841063,
"_greaterequal":anf_shared901064,
"visit":anf_shared971065,
"_match":anf_variant_member2181114,
"_torepr":anf_variant_member2241115,
"to-compiled-source":anf_variant_member2291116,
"to-compiled":anf_variant_member2321117,
"tosource":anf_variant_member2361118,
"tostring":anf_variant_member2391119,
"toname":anf_variant_member2411120,
"key":anf_variant_member2441121};
var $s_DASH_type_DASH_global_DASH_brands11121113 = {"$brand-s-type-global1111":true};
$s_DASH_type_DASH_global_DASH_brands11121113[NameT167134._brand] = true
var $s_DASH_atom_DASH_base11231124 = {"_lessthan":anf_shared721061,
"_lessequal":anf_shared781062,
"_greaterthan":anf_shared841063,
"_greaterequal":anf_shared901064,
"visit":anf_shared971065,
"_match":anf_variant_member2571128,
"_torepr":anf_variant_member2671129,
"to-compiled-source":anf_variant_member2721130,
"to-compiled":anf_variant_member2771131,
"tosource":anf_variant_member2821132,
"tostring":anf_variant_member2851133,
"toname":anf_variant_member2871134,
"key":anf_variant_member2931135};
var $s_DASH_atom_DASH_brands11261127 = {"$brand-s-atom1125":true};
$s_DASH_atom_DASH_brands11261127[NameT167134._brand] = true
return R.makeObject({"Name":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[139],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,NameT167134._brand));
}),
"is-s-underscore":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[138],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-underscore1068"));
}),
"s-underscore":R.makeFunction(function(l1981079) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[140],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l1981079],[L[141]],function() {
var dict = R.create($s_DASH_underscore_DASH_base10661067);
dict["l"] = l1981079
return R.makeBrandedObject(dict,$s_DASH_underscore_DASH_brands10691070);
});
}),
"is-s-name":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[137],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-name1082"));
}),
"s-name":R.makeFunction(function(l2051093,s2061094) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[142],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l2051093,s2061094],[L[143],L[144]],function() {
var dict = R.create($s_DASH_name_DASH_base10801081);
dict["l"] = l2051093
dict["s"] = s2061094
return R.makeBrandedObject(dict,$s_DASH_name_DASH_brands10831084);
});
}),
"is-s-global":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[136],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-global1097"));
}),
"s-global":R.makeFunction(function(s2131108) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[145],1,arguments);
}
return R.checkAnnArgs([$type$String69],[s2131108],[L[146]],function() {
var dict = R.create($s_DASH_global_DASH_base10951096);
dict["s"] = s2131108
return R.makeBrandedObject(dict,$s_DASH_global_DASH_brands10981099);
});
}),
"is-s-type-global":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[135],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-type-global1111"));
}),
"s-type-global":R.makeFunction(function(s2201122) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[147],1,arguments);
}
return R.checkAnnArgs([$type$String69],[s2201122],[L[148]],function() {
var dict = R.create($s_DASH_type_DASH_global_DASH_base11091110);
dict["s"] = s2201122
return R.makeBrandedObject(dict,$s_DASH_type_DASH_global_DASH_brands11121113);
});
}),
"is-s-atom":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[134],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-atom1125"));
}),
"s-atom":R.makeFunction(function(base2271136,serial2281137) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[149],2,arguments);
}
return R.checkAnnArgs([$type$String69,$type$Number68],[base2271136,serial2281137],[L[150],L[151]],function() {
var dict = R.create($s_DASH_atom_DASH_base11231124);
dict["base"] = base2271136
dict["serial"] = serial2281137
return R.makeBrandedObject(dict,$s_DASH_atom_DASH_brands11261127);
});
})});
})();
Name261841003.$var = anf_assign2941004;
var anf_assign2951006 = G(Name261841003.$var,"Name",L[139]);
Name1851005.$var = anf_assign2951006;
var anf_assign2961008 = G(Name261841003.$var,"Name",L[139]);
is_DASH_Name1861007.$var = anf_assign2961008;
var anf_assign2971010 = G(Name261841003.$var,"is-s-underscore",L[138]);
is_DASH_s_DASH_underscore1871009.$var = anf_assign2971010;
var anf_assign2981012 = G(Name261841003.$var,"s-underscore",L[138]);
s_DASH_underscore1881011.$var = anf_assign2981012;
var anf_assign2991014 = G(Name261841003.$var,"is-s-name",L[137]);
is_DASH_s_DASH_name1891013.$var = anf_assign2991014;
var anf_assign3001016 = G(Name261841003.$var,"s-name",L[137]);
s_DASH_name1901015.$var = anf_assign3001016;
var anf_assign3011018 = G(Name261841003.$var,"is-s-global",L[136]);
is_DASH_s_DASH_global1911017.$var = anf_assign3011018;
var anf_assign3021020 = G(Name261841003.$var,"s-global",L[136]);
s_DASH_global1921019.$var = anf_assign3021020;
var anf_assign3031022 = G(Name261841003.$var,"is-s-type-global",L[135]);
is_DASH_s_DASH_type_DASH_global1931021.$var = anf_assign3031022;
var anf_assign3041024 = G(Name261841003.$var,"s-type-global",L[135]);
s_DASH_type_DASH_global1941023.$var = anf_assign3041024;
var anf_assign3051026 = G(Name261841003.$var,"is-s-atom",L[134]);
is_DASH_s_DASH_atom1951025.$var = anf_assign3051026;
var anf_assign3061028 = G(Name261841003.$var,"s-atom",L[134]);
s_DASH_atom1961027.$var = anf_assign3061028;
var anf_assign3211030 = R.makeFunction(function(start2451043) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[131],1,arguments);
}
var count2461059 = {"$var":start2451043,
"$name":"count"};
var atom2471044 = {"$var":D,
"$name":"atom"};
var anf_assign3201045 = R.makeFunction(function(base2481047) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[132],1,arguments);
}
var $z10501051 = D;
var $f10561057 = function(_) {
return R.isFunction(is_DASH_string59)?is_DASH_string59.app(base2481047):R.ffi.throwNonFunApp(L[133],is_DASH_string59,[base2481047]);
};
try {
if(--R.GAS > 0) {
$z10501051 = $f10561057();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10561057,
"from":L[133]});
}
} catch($e10481049) {
if(R.isCont($e10481049)) {
var $ss10521053 = {"from":L[133],
"go":function(anf_arg3091058) {
return $Hanf_arg83801060(anf_arg3091058,base2481047,count2461059,s_DASH_atom1961027,_plus55,not60,nothing61,raise62,torepr65);
}};
$e10481049.stack[R.EXN_STACKHEIGHT++] = $ss10521053;
}
if(R.isPyretException($e10481049)) {
$e10481049.pyretStack.push(L[133]);
}
throw $e10481049;
}
var $ret10541055 = $Hanf_arg83801060($z10501051,base2481047,count2461059,s_DASH_atom1961027,_plus55,not60,nothing61,raise62,torepr65);
++R.GAS;
return $ret10541055;
});
atom2471044.$var = anf_assign3201045;
var ann_DASH_check_DASH_temp3071046 = R.makeObject({"s-underscore":s_DASH_underscore1881011.$var,
"s-name":s_DASH_name1901015.$var,
"s-global":s_DASH_global1921019.$var,
"s-type-global":s_DASH_type_DASH_global1941023.$var,
"make-atom":atom2471044.$var,
"is-s-underscore":is_DASH_s_DASH_underscore1871009.$var,
"is-s-name":is_DASH_s_DASH_name1891013.$var,
"is-s-global":is_DASH_s_DASH_global1911017.$var,
"is-s-atom":is_DASH_s_DASH_atom1951025.$var});
return ann_DASH_check_DASH_temp3071046;
});
MakeName1971029.$var = anf_assign3211030;
var $z10331034 = D;
var $f10391040 = function(_) {
return R.isFunction(MakeName1971029.$var)?MakeName1971029.$var.app((0)):R.ffi.throwNonFunApp(L[130],MakeName1971029.$var,[(0)]);
};
try {
if(--R.GAS > 0) {
$z10331034 = $f10391040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10391040,
"from":L[130]});
}
} catch($e10311032) {
if(R.isCont($e10311032)) {
var $ss10351036 = {"from":L[130],
"go":function(global_DASH_names2491041) {
return $Hglobal_DASH_names114431042(global_DASH_names2491041,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,MakeName1971029,Member92131,MemberT1493132,Name1851005,Name66133,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_Name1861007,is_DASH_empty26152,is_DASH_s_DASH_atom1951025,is_DASH_s_DASH_global1911017,is_DASH_s_DASH_name1891013,is_DASH_s_DASH_type_DASH_global1931021,is_DASH_s_DASH_underscore1871009,link29153,list25154,lists974,none61155,s_DASH_atom1961027,s_DASH_global1921019,s_DASH_name1901015,s_DASH_type_DASH_global1941023,s_DASH_underscore1881011,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,str_DASH_where182988,str_DASH_with1831001,_plus55,_times56,builtins57,is_DASH_nothing58,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e10311032.stack[R.EXN_STACKHEIGHT++] = $ss10351036;
}
if(R.isPyretException($e10311032)) {
$e10311032.pyretStack.push(L[130]);
}
throw $e10311032;
}
var $ret10371038 = $Hglobal_DASH_names114431042($z10331034,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,MakeName1971029,Member92131,MemberT1493132,Name1851005,Name66133,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_Name1861007,is_DASH_empty26152,is_DASH_s_DASH_atom1951025,is_DASH_s_DASH_global1911017,is_DASH_s_DASH_name1891013,is_DASH_s_DASH_type_DASH_global1931021,is_DASH_s_DASH_underscore1871009,link29153,list25154,lists974,none61155,s_DASH_atom1961027,s_DASH_global1921019,s_DASH_name1901015,s_DASH_type_DASH_global1941023,s_DASH_underscore1881011,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,str_DASH_where182988,str_DASH_with1831001,_plus55,_times56,builtins57,is_DASH_nothing58,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret10371038;
};
var $Hglobal_DASH_names114431042 = function(global_DASH_names2491041,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,INDENT118169,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,MakeName1971029,Member92131,MemberT1493132,Name1851005,Name66133,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,break_DASH_one119168,dummy_DASH_loc11796,empty28150,fold53151,is_DASH_Name1861007,is_DASH_empty26152,is_DASH_s_DASH_atom1951025,is_DASH_s_DASH_global1911017,is_DASH_s_DASH_name1891013,is_DASH_s_DASH_type_DASH_global1931021,is_DASH_s_DASH_underscore1871009,link29153,list25154,lists974,none61155,s_DASH_atom1961027,s_DASH_global1921019,s_DASH_name1901015,s_DASH_type_DASH_global1941023,s_DASH_underscore1881011,some62156,str_DASH_any120182,str_DASH_arrow121195,str_DASH_arrowspace122208,str_DASH_as123221,str_DASH_askcolon156650,str_DASH_bang161715,str_DASH_blank124234,str_DASH_bless178936,str_DASH_block128286,str_DASH_brackets129299,str_DASH_caret131325,str_DASH_cases130312,str_DASH_checkcolon132338,str_DASH_colon134364,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_comment137403,str_DASH_confirm179949,str_DASH_constructor138416,str_DASH_data_DASH_expr140442,str_DASH_data139429,str_DASH_datatype141455,str_DASH_deriving142468,str_DASH_doc143481,str_DASH_elsebranch144494,str_DASH_elsecolon145507,str_DASH_elsespace147533,str_DASH_end148546,str_DASH_examplescolon133351,str_DASH_except149559,str_DASH_for150572,str_DASH_from151585,str_DASH_fun152598,str_DASH_graph154624,str_DASH_if155637,str_DASH_import157663,str_DASH_lam153611,str_DASH_let125247,str_DASH_letrec127273,str_DASH_method158676,str_DASH_mutable159689,str_DASH_newtype176910,str_DASH_otherwisecolon146520,str_DASH_period160702,str_DASH_pipespace162728,str_DASH_provide_DASH_star165767,str_DASH_provide_DASH_types_DASH_star166780,str_DASH_provide_DASH_types164754,str_DASH_provide163741,str_DASH_sharing167793,str_DASH_space168806,str_DASH_spacecolonequal169819,str_DASH_spaceequal170832,str_DASH_thencolon171845,str_DASH_thickarrow172858,str_DASH_try173871,str_DASH_type_DASH_let126260,str_DASH_type177923,str_DASH_use_DASH_loc174884,str_DASH_val180962,str_DASH_var175897,str_DASH_when181975,str_DASH_where182988,str_DASH_with1831001,_plus55,_times56,builtins57,is_DASH_nothing58,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69) {
var funlam_DASH_tosource2501801 = {"$var":D,
"$name":"funlam-tosource"};
var Program272511803 = {"$var":D,
"$name":"Program27"};
var Program2521805 = {"$var":D,
"$name":"Program"};
var is_DASH_Program2531807 = {"$var":D,
"$name":"is-Program"};
var is_DASH_s_DASH_program2541809 = {"$var":D,
"$name":"is-s-program"};
var s_DASH_program2551811 = {"$var":D,
"$name":"s-program"};
var Import282561813 = {"$var":D,
"$name":"Import28"};
var Import2571815 = {"$var":D,
"$name":"Import"};
var is_DASH_Import2581817 = {"$var":D,
"$name":"is-Import"};
var is_DASH_s_DASH_import2591819 = {"$var":D,
"$name":"is-s-import"};
var s_DASH_import2601821 = {"$var":D,
"$name":"s-import"};
var is_DASH_s_DASH_import_DASH_types2611823 = {"$var":D,
"$name":"is-s-import-types"};
var s_DASH_import_DASH_types2621825 = {"$var":D,
"$name":"s-import-types"};
var is_DASH_s_DASH_import_DASH_fields2631827 = {"$var":D,
"$name":"is-s-import-fields"};
var s_DASH_import_DASH_fields2641829 = {"$var":D,
"$name":"s-import-fields"};
var Provide292651831 = {"$var":D,
"$name":"Provide29"};
var Provide2661833 = {"$var":D,
"$name":"Provide"};
var is_DASH_Provide2671835 = {"$var":D,
"$name":"is-Provide"};
var is_DASH_s_DASH_provide2681837 = {"$var":D,
"$name":"is-s-provide"};
var s_DASH_provide2691839 = {"$var":D,
"$name":"s-provide"};
var is_DASH_s_DASH_provide_DASH_all2701841 = {"$var":D,
"$name":"is-s-provide-all"};
var s_DASH_provide_DASH_all2711843 = {"$var":D,
"$name":"s-provide-all"};
var is_DASH_s_DASH_provide_DASH_none2721845 = {"$var":D,
"$name":"is-s-provide-none"};
var s_DASH_provide_DASH_none2731847 = {"$var":D,
"$name":"s-provide-none"};
var ProvideTypes302741849 = {"$var":D,
"$name":"ProvideTypes30"};
var ProvideTypes2751851 = {"$var":D,
"$name":"ProvideTypes"};
var is_DASH_ProvideTypes2761853 = {"$var":D,
"$name":"is-ProvideTypes"};
var is_DASH_s_DASH_provide_DASH_types2771855 = {"$var":D,
"$name":"is-s-provide-types"};
var s_DASH_provide_DASH_types2781857 = {"$var":D,
"$name":"s-provide-types"};
var is_DASH_s_DASH_provide_DASH_types_DASH_all2791859 = {"$var":D,
"$name":"is-s-provide-types-all"};
var s_DASH_provide_DASH_types_DASH_all2801861 = {"$var":D,
"$name":"s-provide-types-all"};
var is_DASH_s_DASH_provide_DASH_types_DASH_none2811863 = {"$var":D,
"$name":"is-s-provide-types-none"};
var s_DASH_provide_DASH_types_DASH_none2821865 = {"$var":D,
"$name":"s-provide-types-none"};
var ImportType312831867 = {"$var":D,
"$name":"ImportType31"};
var ImportType2841869 = {"$var":D,
"$name":"ImportType"};
var is_DASH_ImportType2851871 = {"$var":D,
"$name":"is-ImportType"};
var is_DASH_s_DASH_file_DASH_import2861873 = {"$var":D,
"$name":"is-s-file-import"};
var s_DASH_file_DASH_import2871875 = {"$var":D,
"$name":"s-file-import"};
var is_DASH_s_DASH_const_DASH_import2881877 = {"$var":D,
"$name":"is-s-const-import"};
var s_DASH_const_DASH_import2891879 = {"$var":D,
"$name":"s-const-import"};
var Hint322901881 = {"$var":D,
"$name":"Hint32"};
var Hint2911883 = {"$var":D,
"$name":"Hint"};
var is_DASH_Hint2921885 = {"$var":D,
"$name":"is-Hint"};
var is_DASH_h_DASH_use_DASH_loc2931887 = {"$var":D,
"$name":"is-h-use-loc"};
var h_DASH_use_DASH_loc2941889 = {"$var":D,
"$name":"h-use-loc"};
var LetBind332951891 = {"$var":D,
"$name":"LetBind33"};
var LetBind2961893 = {"$var":D,
"$name":"LetBind"};
var is_DASH_LetBind2971895 = {"$var":D,
"$name":"is-LetBind"};
var is_DASH_s_DASH_let_DASH_bind2981897 = {"$var":D,
"$name":"is-s-let-bind"};
var s_DASH_let_DASH_bind2991899 = {"$var":D,
"$name":"s-let-bind"};
var is_DASH_s_DASH_var_DASH_bind3001901 = {"$var":D,
"$name":"is-s-var-bind"};
var s_DASH_var_DASH_bind3011903 = {"$var":D,
"$name":"s-var-bind"};
var LetrecBind343021905 = {"$var":D,
"$name":"LetrecBind34"};
var LetrecBind3031907 = {"$var":D,
"$name":"LetrecBind"};
var is_DASH_LetrecBind3041909 = {"$var":D,
"$name":"is-LetrecBind"};
var is_DASH_s_DASH_letrec_DASH_bind3051911 = {"$var":D,
"$name":"is-s-letrec-bind"};
var s_DASH_letrec_DASH_bind3061913 = {"$var":D,
"$name":"s-letrec-bind"};
var TypeLetBind353071915 = {"$var":D,
"$name":"TypeLetBind35"};
var TypeLetBind3081917 = {"$var":D,
"$name":"TypeLetBind"};
var is_DASH_TypeLetBind3091919 = {"$var":D,
"$name":"is-TypeLetBind"};
var is_DASH_s_DASH_type_DASH_bind3101921 = {"$var":D,
"$name":"is-s-type-bind"};
var s_DASH_type_DASH_bind3111923 = {"$var":D,
"$name":"s-type-bind"};
var is_DASH_s_DASH_newtype_DASH_bind3121925 = {"$var":D,
"$name":"is-s-newtype-bind"};
var s_DASH_newtype_DASH_bind3131927 = {"$var":D,
"$name":"s-newtype-bind"};
var Expr363141929 = {"$var":D,
"$name":"Expr36"};
var Expr3151931 = {"$var":D,
"$name":"Expr"};
var is_DASH_Expr3161933 = {"$var":D,
"$name":"is-Expr"};
var is_DASH_s_DASH_module3171935 = {"$var":D,
"$name":"is-s-module"};
var s_DASH_module3181937 = {"$var":D,
"$name":"s-module"};
var is_DASH_s_DASH_type_DASH_let_DASH_expr3191939 = {"$var":D,
"$name":"is-s-type-let-expr"};
var s_DASH_type_DASH_let_DASH_expr3201941 = {"$var":D,
"$name":"s-type-let-expr"};
var is_DASH_s_DASH_let_DASH_expr3211943 = {"$var":D,
"$name":"is-s-let-expr"};
var s_DASH_let_DASH_expr3221945 = {"$var":D,
"$name":"s-let-expr"};
var is_DASH_s_DASH_letrec3231947 = {"$var":D,
"$name":"is-s-letrec"};
var s_DASH_letrec3241949 = {"$var":D,
"$name":"s-letrec"};
var is_DASH_s_DASH_hint_DASH_exp3251951 = {"$var":D,
"$name":"is-s-hint-exp"};
var s_DASH_hint_DASH_exp3261953 = {"$var":D,
"$name":"s-hint-exp"};
var is_DASH_s_DASH_instantiate3271955 = {"$var":D,
"$name":"is-s-instantiate"};
var s_DASH_instantiate3281957 = {"$var":D,
"$name":"s-instantiate"};
var is_DASH_s_DASH_block3291959 = {"$var":D,
"$name":"is-s-block"};
var s_DASH_block3301961 = {"$var":D,
"$name":"s-block"};
var is_DASH_s_DASH_user_DASH_block3311963 = {"$var":D,
"$name":"is-s-user-block"};
var s_DASH_user_DASH_block3321965 = {"$var":D,
"$name":"s-user-block"};
var is_DASH_s_DASH_fun3331967 = {"$var":D,
"$name":"is-s-fun"};
var s_DASH_fun3341969 = {"$var":D,
"$name":"s-fun"};
var is_DASH_s_DASH_type3351971 = {"$var":D,
"$name":"is-s-type"};
var s_DASH_type3361973 = {"$var":D,
"$name":"s-type"};
var is_DASH_s_DASH_newtype3371975 = {"$var":D,
"$name":"is-s-newtype"};
var s_DASH_newtype3381977 = {"$var":D,
"$name":"s-newtype"};
var is_DASH_s_DASH_var3391979 = {"$var":D,
"$name":"is-s-var"};
var s_DASH_var3401981 = {"$var":D,
"$name":"s-var"};
var is_DASH_s_DASH_let3411983 = {"$var":D,
"$name":"is-s-let"};
var s_DASH_let3421985 = {"$var":D,
"$name":"s-let"};
var is_DASH_s_DASH_graph3431987 = {"$var":D,
"$name":"is-s-graph"};
var s_DASH_graph3441989 = {"$var":D,
"$name":"s-graph"};
var is_DASH_s_DASH_contract3451991 = {"$var":D,
"$name":"is-s-contract"};
var s_DASH_contract3461993 = {"$var":D,
"$name":"s-contract"};
var is_DASH_s_DASH_when3471995 = {"$var":D,
"$name":"is-s-when"};
var s_DASH_when3481997 = {"$var":D,
"$name":"s-when"};
var is_DASH_s_DASH_assign3491999 = {"$var":D,
"$name":"is-s-assign"};
var s_DASH_assign3502001 = {"$var":D,
"$name":"s-assign"};
var is_DASH_s_DASH_if_DASH_pipe3512003 = {"$var":D,
"$name":"is-s-if-pipe"};
var s_DASH_if_DASH_pipe3522005 = {"$var":D,
"$name":"s-if-pipe"};
var is_DASH_s_DASH_if_DASH_pipe_DASH_else3532007 = {"$var":D,
"$name":"is-s-if-pipe-else"};
var s_DASH_if_DASH_pipe_DASH_else3542009 = {"$var":D,
"$name":"s-if-pipe-else"};
var is_DASH_s_DASH_if3552011 = {"$var":D,
"$name":"is-s-if"};
var s_DASH_if3562013 = {"$var":D,
"$name":"s-if"};
var is_DASH_s_DASH_if_DASH_else3572015 = {"$var":D,
"$name":"is-s-if-else"};
var s_DASH_if_DASH_else3582017 = {"$var":D,
"$name":"s-if-else"};
var is_DASH_s_DASH_cases3592019 = {"$var":D,
"$name":"is-s-cases"};
var s_DASH_cases3602021 = {"$var":D,
"$name":"s-cases"};
var is_DASH_s_DASH_cases_DASH_else3612023 = {"$var":D,
"$name":"is-s-cases-else"};
var s_DASH_cases_DASH_else3622025 = {"$var":D,
"$name":"s-cases-else"};
var is_DASH_s_DASH_try3632027 = {"$var":D,
"$name":"is-s-try"};
var s_DASH_try3642029 = {"$var":D,
"$name":"s-try"};
var is_DASH_s_DASH_op3652031 = {"$var":D,
"$name":"is-s-op"};
var s_DASH_op3662033 = {"$var":D,
"$name":"s-op"};
var is_DASH_s_DASH_check_DASH_test3672035 = {"$var":D,
"$name":"is-s-check-test"};
var s_DASH_check_DASH_test3682037 = {"$var":D,
"$name":"s-check-test"};
var is_DASH_s_DASH_paren3692039 = {"$var":D,
"$name":"is-s-paren"};
var s_DASH_paren3702041 = {"$var":D,
"$name":"s-paren"};
var is_DASH_s_DASH_lam3712043 = {"$var":D,
"$name":"is-s-lam"};
var s_DASH_lam3722045 = {"$var":D,
"$name":"s-lam"};
var is_DASH_s_DASH_method3732047 = {"$var":D,
"$name":"is-s-method"};
var s_DASH_method3742049 = {"$var":D,
"$name":"s-method"};
var is_DASH_s_DASH_extend3752051 = {"$var":D,
"$name":"is-s-extend"};
var s_DASH_extend3762053 = {"$var":D,
"$name":"s-extend"};
var is_DASH_s_DASH_update3772055 = {"$var":D,
"$name":"is-s-update"};
var s_DASH_update3782057 = {"$var":D,
"$name":"s-update"};
var is_DASH_s_DASH_obj3792059 = {"$var":D,
"$name":"is-s-obj"};
var s_DASH_obj3802061 = {"$var":D,
"$name":"s-obj"};
var is_DASH_s_DASH_array3812063 = {"$var":D,
"$name":"is-s-array"};
var s_DASH_array3822065 = {"$var":D,
"$name":"s-array"};
var is_DASH_s_DASH_construct3832067 = {"$var":D,
"$name":"is-s-construct"};
var s_DASH_construct3842069 = {"$var":D,
"$name":"s-construct"};
var is_DASH_s_DASH_confirm3852071 = {"$var":D,
"$name":"is-s-confirm"};
var s_DASH_confirm3862073 = {"$var":D,
"$name":"s-confirm"};
var is_DASH_s_DASH_bless3872075 = {"$var":D,
"$name":"is-s-bless"};
var s_DASH_bless3882077 = {"$var":D,
"$name":"s-bless"};
var is_DASH_s_DASH_app3892079 = {"$var":D,
"$name":"is-s-app"};
var s_DASH_app3902081 = {"$var":D,
"$name":"s-app"};
var is_DASH_s_DASH_prim_DASH_app3912083 = {"$var":D,
"$name":"is-s-prim-app"};
var s_DASH_prim_DASH_app3922085 = {"$var":D,
"$name":"s-prim-app"};
var is_DASH_s_DASH_prim_DASH_val3932087 = {"$var":D,
"$name":"is-s-prim-val"};
var s_DASH_prim_DASH_val3942089 = {"$var":D,
"$name":"s-prim-val"};
var is_DASH_s_DASH_id3952091 = {"$var":D,
"$name":"is-s-id"};
var s_DASH_id3962093 = {"$var":D,
"$name":"s-id"};
var is_DASH_s_DASH_id_DASH_var3972095 = {"$var":D,
"$name":"is-s-id-var"};
var s_DASH_id_DASH_var3982097 = {"$var":D,
"$name":"s-id-var"};
var is_DASH_s_DASH_id_DASH_letrec3992099 = {"$var":D,
"$name":"is-s-id-letrec"};
var s_DASH_id_DASH_letrec4002101 = {"$var":D,
"$name":"s-id-letrec"};
var is_DASH_s_DASH_undefined4012103 = {"$var":D,
"$name":"is-s-undefined"};
var s_DASH_undefined4022105 = {"$var":D,
"$name":"s-undefined"};
var is_DASH_s_DASH_srcloc4032107 = {"$var":D,
"$name":"is-s-srcloc"};
var s_DASH_srcloc4042109 = {"$var":D,
"$name":"s-srcloc"};
var is_DASH_s_DASH_num4052111 = {"$var":D,
"$name":"is-s-num"};
var s_DASH_num4062113 = {"$var":D,
"$name":"s-num"};
var is_DASH_s_DASH_frac4072115 = {"$var":D,
"$name":"is-s-frac"};
var s_DASH_frac4082117 = {"$var":D,
"$name":"s-frac"};
var is_DASH_s_DASH_bool4092119 = {"$var":D,
"$name":"is-s-bool"};
var s_DASH_bool4102121 = {"$var":D,
"$name":"s-bool"};
var is_DASH_s_DASH_str4112123 = {"$var":D,
"$name":"is-s-str"};
var s_DASH_str4122125 = {"$var":D,
"$name":"s-str"};
var is_DASH_s_DASH_dot4132127 = {"$var":D,
"$name":"is-s-dot"};
var s_DASH_dot4142129 = {"$var":D,
"$name":"s-dot"};
var is_DASH_s_DASH_get_DASH_bang4152131 = {"$var":D,
"$name":"is-s-get-bang"};
var s_DASH_get_DASH_bang4162133 = {"$var":D,
"$name":"s-get-bang"};
var is_DASH_s_DASH_bracket4172135 = {"$var":D,
"$name":"is-s-bracket"};
var s_DASH_bracket4182137 = {"$var":D,
"$name":"s-bracket"};
var is_DASH_s_DASH_data4192139 = {"$var":D,
"$name":"is-s-data"};
var s_DASH_data4202141 = {"$var":D,
"$name":"s-data"};
var is_DASH_s_DASH_data_DASH_expr4212143 = {"$var":D,
"$name":"is-s-data-expr"};
var s_DASH_data_DASH_expr4222145 = {"$var":D,
"$name":"s-data-expr"};
var is_DASH_s_DASH_for4232147 = {"$var":D,
"$name":"is-s-for"};
var s_DASH_for4242149 = {"$var":D,
"$name":"s-for"};
var is_DASH_s_DASH_check4252151 = {"$var":D,
"$name":"is-s-check"};
var s_DASH_check4262153 = {"$var":D,
"$name":"s-check"};
var ConstructModifier374272155 = {"$var":D,
"$name":"ConstructModifier37"};
var ConstructModifier4282157 = {"$var":D,
"$name":"ConstructModifier"};
var is_DASH_ConstructModifier4292159 = {"$var":D,
"$name":"is-ConstructModifier"};
var is_DASH_s_DASH_construct_DASH_normal4302161 = {"$var":D,
"$name":"is-s-construct-normal"};
var s_DASH_construct_DASH_normal4312163 = {"$var":D,
"$name":"s-construct-normal"};
var is_DASH_s_DASH_construct_DASH_lazy4322165 = {"$var":D,
"$name":"is-s-construct-lazy"};
var s_DASH_construct_DASH_lazy4332167 = {"$var":D,
"$name":"s-construct-lazy"};
var Bind384342169 = {"$var":D,
"$name":"Bind38"};
var Bind4352171 = {"$var":D,
"$name":"Bind"};
var is_DASH_Bind4362173 = {"$var":D,
"$name":"is-Bind"};
var is_DASH_s_DASH_bind4372175 = {"$var":D,
"$name":"is-s-bind"};
var s_DASH_bind4382177 = {"$var":D,
"$name":"s-bind"};
var Member394392179 = {"$var":D,
"$name":"Member39"};
var Member4402181 = {"$var":D,
"$name":"Member"};
var is_DASH_Member4412183 = {"$var":D,
"$name":"is-Member"};
var is_DASH_s_DASH_data_DASH_field4422185 = {"$var":D,
"$name":"is-s-data-field"};
var s_DASH_data_DASH_field4432187 = {"$var":D,
"$name":"s-data-field"};
var is_DASH_s_DASH_mutable_DASH_field4442189 = {"$var":D,
"$name":"is-s-mutable-field"};
var s_DASH_mutable_DASH_field4452191 = {"$var":D,
"$name":"s-mutable-field"};
var is_DASH_s_DASH_once_DASH_field4462193 = {"$var":D,
"$name":"is-s-once-field"};
var s_DASH_once_DASH_field4472195 = {"$var":D,
"$name":"s-once-field"};
var is_DASH_s_DASH_method_DASH_field4482197 = {"$var":D,
"$name":"is-s-method-field"};
var s_DASH_method_DASH_field4492199 = {"$var":D,
"$name":"s-method-field"};
var ForBind404502201 = {"$var":D,
"$name":"ForBind40"};
var ForBind4512203 = {"$var":D,
"$name":"ForBind"};
var is_DASH_ForBind4522205 = {"$var":D,
"$name":"is-ForBind"};
var is_DASH_s_DASH_for_DASH_bind4532207 = {"$var":D,
"$name":"is-s-for-bind"};
var s_DASH_for_DASH_bind4542209 = {"$var":D,
"$name":"s-for-bind"};
var VariantMemberType414552211 = {"$var":D,
"$name":"VariantMemberType41"};
var VariantMemberType4562213 = {"$var":D,
"$name":"VariantMemberType"};
var is_DASH_VariantMemberType4572215 = {"$var":D,
"$name":"is-VariantMemberType"};
var is_DASH_s_DASH_normal4582217 = {"$var":D,
"$name":"is-s-normal"};
var s_DASH_normal4592219 = {"$var":D,
"$name":"s-normal"};
var is_DASH_s_DASH_cyclic4602221 = {"$var":D,
"$name":"is-s-cyclic"};
var s_DASH_cyclic4612223 = {"$var":D,
"$name":"s-cyclic"};
var is_DASH_s_DASH_mutable4622225 = {"$var":D,
"$name":"is-s-mutable"};
var s_DASH_mutable4632227 = {"$var":D,
"$name":"s-mutable"};
var VariantMember424642229 = {"$var":D,
"$name":"VariantMember42"};
var VariantMember4652231 = {"$var":D,
"$name":"VariantMember"};
var is_DASH_VariantMember4662233 = {"$var":D,
"$name":"is-VariantMember"};
var is_DASH_s_DASH_variant_DASH_member4672235 = {"$var":D,
"$name":"is-s-variant-member"};
var s_DASH_variant_DASH_member4682237 = {"$var":D,
"$name":"s-variant-member"};
var Variant434692239 = {"$var":D,
"$name":"Variant43"};
var Variant4702241 = {"$var":D,
"$name":"Variant"};
var is_DASH_Variant4712243 = {"$var":D,
"$name":"is-Variant"};
var is_DASH_s_DASH_variant4722245 = {"$var":D,
"$name":"is-s-variant"};
var s_DASH_variant4732247 = {"$var":D,
"$name":"s-variant"};
var is_DASH_s_DASH_singleton_DASH_variant4742249 = {"$var":D,
"$name":"is-s-singleton-variant"};
var s_DASH_singleton_DASH_variant4752251 = {"$var":D,
"$name":"s-singleton-variant"};
var DatatypeVariant444762253 = {"$var":D,
"$name":"DatatypeVariant44"};
var DatatypeVariant4772255 = {"$var":D,
"$name":"DatatypeVariant"};
var is_DASH_DatatypeVariant4782257 = {"$var":D,
"$name":"is-DatatypeVariant"};
var is_DASH_s_DASH_datatype_DASH_variant4792259 = {"$var":D,
"$name":"is-s-datatype-variant"};
var s_DASH_datatype_DASH_variant4802261 = {"$var":D,
"$name":"s-datatype-variant"};
var is_DASH_s_DASH_datatype_DASH_singleton_DASH_variant4812263 = {"$var":D,
"$name":"is-s-datatype-singleton-variant"};
var s_DASH_datatype_DASH_singleton_DASH_variant4822265 = {"$var":D,
"$name":"s-datatype-singleton-variant"};
var Constructor454832267 = {"$var":D,
"$name":"Constructor45"};
var Constructor4842269 = {"$var":D,
"$name":"Constructor"};
var is_DASH_Constructor4852271 = {"$var":D,
"$name":"is-Constructor"};
var is_DASH_s_DASH_datatype_DASH_constructor4862273 = {"$var":D,
"$name":"is-s-datatype-constructor"};
var s_DASH_datatype_DASH_constructor4872275 = {"$var":D,
"$name":"s-datatype-constructor"};
var IfBranch464882277 = {"$var":D,
"$name":"IfBranch46"};
var IfBranch4892279 = {"$var":D,
"$name":"IfBranch"};
var is_DASH_IfBranch4902281 = {"$var":D,
"$name":"is-IfBranch"};
var is_DASH_s_DASH_if_DASH_branch4912283 = {"$var":D,
"$name":"is-s-if-branch"};
var s_DASH_if_DASH_branch4922285 = {"$var":D,
"$name":"s-if-branch"};
var IfPipeBranch474932287 = {"$var":D,
"$name":"IfPipeBranch47"};
var IfPipeBranch4942289 = {"$var":D,
"$name":"IfPipeBranch"};
var is_DASH_IfPipeBranch4952291 = {"$var":D,
"$name":"is-IfPipeBranch"};
var is_DASH_s_DASH_if_DASH_pipe_DASH_branch4962293 = {"$var":D,
"$name":"is-s-if-pipe-branch"};
var s_DASH_if_DASH_pipe_DASH_branch4972295 = {"$var":D,
"$name":"s-if-pipe-branch"};
var CasesBranch484982297 = {"$var":D,
"$name":"CasesBranch48"};
var CasesBranch4992299 = {"$var":D,
"$name":"CasesBranch"};
var is_DASH_CasesBranch5002301 = {"$var":D,
"$name":"is-CasesBranch"};
var is_DASH_s_DASH_cases_DASH_branch5012303 = {"$var":D,
"$name":"is-s-cases-branch"};
var s_DASH_cases_DASH_branch5022305 = {"$var":D,
"$name":"s-cases-branch"};
var Ann495032307 = {"$var":D,
"$name":"Ann49"};
var Ann5042309 = {"$var":D,
"$name":"Ann"};
var is_DASH_Ann5052311 = {"$var":D,
"$name":"is-Ann"};
var is_DASH_a_DASH_blank5062313 = {"$var":D,
"$name":"is-a-blank"};
var a_DASH_blank5072315 = {"$var":D,
"$name":"a-blank"};
var is_DASH_a_DASH_any5082317 = {"$var":D,
"$name":"is-a-any"};
var a_DASH_any5092319 = {"$var":D,
"$name":"a-any"};
var is_DASH_a_DASH_name5102321 = {"$var":D,
"$name":"is-a-name"};
var a_DASH_name5112323 = {"$var":D,
"$name":"a-name"};
var is_DASH_a_DASH_arrow5122325 = {"$var":D,
"$name":"is-a-arrow"};
var a_DASH_arrow5132327 = {"$var":D,
"$name":"a-arrow"};
var is_DASH_a_DASH_method5142329 = {"$var":D,
"$name":"is-a-method"};
var a_DASH_method5152331 = {"$var":D,
"$name":"a-method"};
var is_DASH_a_DASH_record5162333 = {"$var":D,
"$name":"is-a-record"};
var a_DASH_record5172335 = {"$var":D,
"$name":"a-record"};
var is_DASH_a_DASH_app5182337 = {"$var":D,
"$name":"is-a-app"};
var a_DASH_app5192339 = {"$var":D,
"$name":"a-app"};
var is_DASH_a_DASH_pred5202341 = {"$var":D,
"$name":"is-a-pred"};
var a_DASH_pred5212343 = {"$var":D,
"$name":"a-pred"};
var is_DASH_a_DASH_dot5222345 = {"$var":D,
"$name":"is-a-dot"};
var a_DASH_dot5232347 = {"$var":D,
"$name":"a-dot"};
var AField505242349 = {"$var":D,
"$name":"AField50"};
var AField5252351 = {"$var":D,
"$name":"AField"};
var is_DASH_AField5262353 = {"$var":D,
"$name":"is-AField"};
var is_DASH_a_DASH_field5272355 = {"$var":D,
"$name":"is-a-field"};
var a_DASH_field5282357 = {"$var":D,
"$name":"a-field"};
var make_DASH_checker_DASH_name5292359 = {"$var":D,
"$name":"make-checker-name"};
var flatten5302361 = {"$var":D,
"$name":"flatten"};
var binding_DASH_type_DASH_ids5312363 = {"$var":D,
"$name":"binding-type-ids"};
var block_DASH_type_DASH_ids5322365 = {"$var":D,
"$name":"block-type-ids"};
var binding_DASH_ids5332367 = {"$var":D,
"$name":"binding-ids"};
var block_DASH_ids5342369 = {"$var":D,
"$name":"block-ids"};
var toplevel_DASH_ids5352371 = {"$var":D,
"$name":"toplevel-ids"};
var anf_assign4481802 = R.makeFunction(function(funtype53618529,name53718530,params53818531,args53918532,ann54018533,doc54118534,body54218535,_check54318536) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[3303],8,arguments);
}
return R.checkAnnArgs([List17129,Ann11299,$type$String69,Expr86111,Option18135],[args53918532,ann54018533,doc54118534,body54218535,_check54318536],[L[3305],L[3306],L[3307],L[3308],L[3309]],function() {
var $z1853918540 = D;
var $f1854518546 = function(_) {
return R.isFunction(is_DASH_nothing58)?is_DASH_nothing58.app(params53818531):R.ffi.throwNonFunApp(L[3304],is_DASH_nothing58,[params53818531]);
};
try {
if(--R.GAS > 0) {
$z1853918540 = $f1854518546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1854518546,
"from":L[3304]});
}
} catch($e1853718538) {
if(R.isCont($e1853718538)) {
var $ss1854118542 = {"from":L[3304],
"go":function(if_DASH_3318547) {
return $Hif_DASH_842318548(if_DASH_3318547,INDENT118169,PP170,PP278,_check54318536,ann54018533,args53918532,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,params53818531,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e1853718538.stack[R.EXN_STACKHEIGHT++] = $ss1854118542;
}
if(R.isPyretException($e1853718538)) {
$e1853718538.pyretStack.push(L[3304]);
}
throw $e1853718538;
}
var $ret1854318544 = $Hif_DASH_842318548($z1853918540,INDENT118169,PP170,PP278,_check54318536,ann54018533,args53918532,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,params53818531,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret1854318544;
});
});
funlam_DASH_tosource2501801.$var = anf_assign4481802;
var anf_shared45618410 = R.makeMethod(function(self56218528) {
return function(visitor56318511) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3298],1,arguments);
}
var anf_fun45018510 = G(self56218528,"_match",L[3302]);
var anf_arg45518512 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3299],0,arguments);
}
var anf_fun45218525 = G(self56218528,"label",L[3301]);
var $z1851718518 = D;
var $f1852318524 = function(_) {
return R.isFunction(anf_fun45218525)?anf_fun45218525.app():R.ffi.throwNonFunApp(L[3300],anf_fun45218525,[]);
};
try {
if(--R.GAS > 0) {
$z1851718518 = $f1852318524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1852318524,
"from":L[3300]});
}
} catch($e1851518516) {
if(R.isCont($e1851518516)) {
var $ss1851918520 = {"from":L[3300],
"go":function(anf_arg45318526) {
return $Hanf_arg842618527(anf_arg45318526,_plus55,raise62);
}};
$e1851518516.stack[R.EXN_STACKHEIGHT++] = $ss1851918520;
}
if(R.isPyretException($e1851518516)) {
$e1851518516.pyretStack.push(L[3300]);
}
throw $e1851518516;
}
var $ret1852118522 = $Hanf_arg842618527($z1851718518,_plus55,raise62);
++R.GAS;
return $ret1852118522;
});
var $z1850218503 = D;
var $f1850818509 = function(_) {
return R.isFunction(anf_fun45018510)?anf_fun45018510.app(visitor56318511,anf_arg45518512):R.ffi.throwNonFunApp(L[3298],anf_fun45018510,[visitor56318511,anf_arg45518512]);
};
try {
if(--R.GAS > 0) {
$z1850218503 = $f1850818509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1850818509,
"from":L[3298]});
}
} catch($e1850018501) {
if(R.isCont($e1850018501)) {
var $ss1850418505 = {"from":L[3298],
"go":function(ann_DASH_check_DASH_temp44918513) {
return $Hann_DASH_check_DASH_temp842718514(ann_DASH_check_DASH_temp44918513);
}};
$e1850018501.stack[R.EXN_STACKHEIGHT++] = $ss1850418505;
}
if(R.isPyretException($e1850018501)) {
$e1850018501.pyretStack.push(L[3298]);
}
throw $e1850018501;
}
var $ret1850618507 = $Hann_DASH_check_DASH_temp842718514($z1850218503);
++R.GAS;
return $ret1850618507;
};
},{"length":2});
var anf_variant_member47218416 = R.makeMethod(function(self4518478) {
return function(cases_DASH_funs4618479,else_DASH_clause4718490) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3277],2,arguments);
}
var if_DASH_4918493 = R.hasField(cases_DASH_funs4618479,("s-program"));
var if_helper45818476 = R.makeFunction(function(if_helper_arg45918498) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3277],1,arguments);
}
var ann_DASH_check_DASH_temp45718499 = if_helper_arg45918498;
return ann_DASH_check_DASH_temp45718499;
});
var anf_if46218497 = R.isBoolean(if_DASH_4918493);
if(R.isPyretTrue(anf_if46218497)) {
if(R.isPyretTrue(if_DASH_4918493)) {
var call_DASH_s_DASH_program4418469 = G(cases_DASH_funs4618479,"s-program",L[3277]);
var anf_arg46518470 = G(self4518478,"l",L[3297]);
var anf_arg46618471 = G(self4518478,"_provide",L[3296]);
var anf_arg46718472 = G(self4518478,"provided-types",L[3295]);
var anf_arg46818473 = G(self4518478,"imports",L[3294]);
var anf_arg46918474 = G(self4518478,"block",L[3293]);
var $z1846118462 = D;
var $f1846718468 = function(_) {
return R.isFunction(call_DASH_s_DASH_program4418469)?call_DASH_s_DASH_program4418469.app(anf_arg46518470,anf_arg46618471,anf_arg46718472,anf_arg46818473,anf_arg46918474):R.ffi.throwNonFunApp(L[3277],call_DASH_s_DASH_program4418469,[anf_arg46518470,anf_arg46618471,anf_arg46718472,anf_arg46818473,anf_arg46918474]);
};
try {
if(--R.GAS > 0) {
$z1846118462 = $f1846718468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1846718468,
"from":L[3277]});
}
} catch($e1845918460) {
if(R.isCont($e1845918460)) {
var $ss1846318464 = {"from":L[3277],
"go":function(cont_tail_arg47018475) {
return $Hcont_tail_arg842818477(cont_tail_arg47018475,if_helper45818476);
}};
$e1845918460.stack[R.EXN_STACKHEIGHT++] = $ss1846318464;
}
if(R.isPyretException($e1845918460)) {
$e1845918460.pyretStack.push(L[3277]);
}
throw $e1845918460;
}
var $ret1846518466 = $Hcont_tail_arg842818477($z1846118462,if_helper45818476);
++R.GAS;
return $ret1846518466;
} else {
var $z1848218483 = D;
var $f1848818489 = function(_) {
return R.isFunction(else_DASH_clause4718490)?else_DASH_clause4718490.app():R.ffi.throwNonFunApp(L[3277],else_DASH_clause4718490,[]);
};
try {
if(--R.GAS > 0) {
$z1848218483 = $f1848818489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1848818489,
"from":L[3277]});
}
} catch($e1848018481) {
if(R.isCont($e1848018481)) {
var $ss1848418485 = {"from":L[3277],
"go":function(cont_tail_arg46318491) {
return $Hcont_tail_arg842918492(cont_tail_arg46318491,if_helper45818476);
}};
$e1848018481.stack[R.EXN_STACKHEIGHT++] = $ss1848418485;
}
if(R.isPyretException($e1848018481)) {
$e1848018481.pyretStack.push(L[3277]);
}
throw $e1848018481;
}
var $ret1848618487 = $Hcont_tail_arg842918492($z1848218483,if_helper45818476);
++R.GAS;
return $ret1848618487;
}
} else {
var cont_tail_arg46018496 = R.throwNonBooleanCondition(L[3277],("if"),if_DASH_4918493);
if(--R.GAS > 0) {
$z1849418495 = R.isFunction(if_helper45818476)?if_helper45818476.app(cont_tail_arg46018496):R.ffi.throwNonFunApp(L[3277],if_helper45818476,[cont_tail_arg46018496]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper45818476)?if_helper45818476.app(cont_tail_arg46018496):R.ffi.throwNonFunApp(L[3277],if_helper45818476,[cont_tail_arg46018496]);
},
"from":L[3277]});
}
++R.GAS;
return $z1849418495;
}
};
},{"length":3});
var anf_variant_member49418417 = R.makeMethod(function(self4818457) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3277],0,arguments);
}
var anf_arg47418455 = G(self4818457,"l",L[3277]);
var $z1844718448 = D;
var $f1845318454 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg47418455):R.ffi.throwNonFunApp(L[3277],torepr65,[anf_arg47418455]);
};
try {
if(--R.GAS > 0) {
$z1844718448 = $f1845318454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1845318454,
"from":L[3277]});
}
} catch($e1844518446) {
if(R.isCont($e1844518446)) {
var $ss1844918450 = {"from":L[3277],
"go":function(anf_arg47518456) {
return $Hanf_arg844518458(anf_arg47518456,self4818457,_plus55,torepr65);
}};
$e1844518446.stack[R.EXN_STACKHEIGHT++] = $ss1844918450;
}
if(R.isPyretException($e1844518446)) {
$e1844518446.pyretStack.push(L[3277]);
}
throw $e1844518446;
}
var $ret1845118452 = $Hanf_arg844518458($z1844718448,self4818457,_plus55,torepr65);
++R.GAS;
return $ret1845118452;
};
},{"length":1});
var anf_variant_member49618418 = R.makeMethod(function(self56018444) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3292],0,arguments);
}
var ann_DASH_check_DASH_temp49518443 = ("s-program");
return ann_DASH_check_DASH_temp49518443;
};
},{"length":1});
var anf_variant_member52218419 = R.makeMethod(function(self56118440) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3291],0,arguments);
}
var anf_fun49818437 = G(PP170,"group",L[3290]);
var anf_fun49918438 = G(PP170,"vert",L[3289]);
var anf_fun50018439 = G(list25154,"make",L[3288]);
var anf_bracket50118442 = G(self56118440,"_provide",L[3287]);
var anf_fun50218435 = G(anf_bracket50118442,"tosource",L[3286]);
var $z1842718428 = D;
var $f1843318434 = function(_) {
return R.isFunction(anf_fun50218435)?anf_fun50218435.app():R.ffi.throwNonFunApp(L[3285],anf_fun50218435,[]);
};
try {
if(--R.GAS > 0) {
$z1842718428 = $f1843318434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1843318434,
"from":L[3285]});
}
} catch($e1842518426) {
if(R.isCont($e1842518426)) {
var $ss1842918430 = {"from":L[3285],
"go":function(anf_array_val50318436) {
return $Hanf_array_val845618441(anf_array_val50318436,anf_fun49818437,anf_fun49918438,anf_fun50018439,list25154,self56118440,_plus55);
}};
$e1842518426.stack[R.EXN_STACKHEIGHT++] = $ss1842918430;
}
if(R.isPyretException($e1842518426)) {
$e1842518426.pyretStack.push(L[3285]);
}
throw $e1842518426;
}
var $ret1843118432 = $Hanf_array_val845618441($z1842718428,anf_fun49818437,anf_fun49918438,anf_fun50018439,list25154,self56118440,_plus55);
++R.GAS;
return $ret1843118432;
};
},{"length":1});
var anf_assign5231804 = (function() {
var $s_DASH_program_DASH_base1841118412 = {"visit":anf_shared45618410,
"_match":anf_variant_member47218416,
"_torepr":anf_variant_member49418417,
"label":anf_variant_member49618418,
"tosource":anf_variant_member52218419};
var $s_DASH_program_DASH_brands1841418415 = {"$brand-s-program18413":true};
$s_DASH_program_DASH_brands1841418415[ProgramT269137._brand] = true
return R.makeObject({"Program":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3278],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ProgramT269137._brand));
}),
"is-s-program":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3277],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-program18413"));
}),
"s-program":R.makeFunction(function(l55518420,_provide55618421,provided_DASH_types55718422,imports55818423,block55918424) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[3279],5,arguments);
}
return R.checkAnnArgs([Loc116130,Provide72138,ProvideTypes74140,List17129,Expr86111],[l55518420,_provide55618421,provided_DASH_types55718422,imports55818423,block55918424],[L[3280],L[3281],L[3282],L[3283],L[3284]],function() {
var dict = R.create($s_DASH_program_DASH_base1841118412);
dict["l"] = l55518420
dict["_provide"] = _provide55618421
dict["provided-types"] = provided_DASH_types55718422
dict["imports"] = imports55818423
dict["block"] = block55918424
return R.makeBrandedObject(dict,$s_DASH_program_DASH_brands1841418415);
});
})});
})();
Program272511803.$var = anf_assign5231804;
var anf_assign5241806 = G(Program272511803.$var,"Program",L[3278]);
Program2521805.$var = anf_assign5241806;
var anf_assign5251808 = G(Program272511803.$var,"Program",L[3278]);
is_DASH_Program2531807.$var = anf_assign5251808;
var anf_assign5261810 = G(Program272511803.$var,"is-s-program",L[3277]);
is_DASH_s_DASH_program2541809.$var = anf_assign5261810;
var anf_assign5271812 = G(Program272511803.$var,"s-program",L[3277]);
s_DASH_program2551811.$var = anf_assign5271812;
var anf_shared53518111 = R.makeMethod(function(self58018409) {
return function(visitor58118392) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3272],1,arguments);
}
var anf_fun52918391 = G(self58018409,"_match",L[3276]);
var anf_arg53418393 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3273],0,arguments);
}
var anf_fun53118406 = G(self58018409,"label",L[3275]);
var $z1839818399 = D;
var $f1840418405 = function(_) {
return R.isFunction(anf_fun53118406)?anf_fun53118406.app():R.ffi.throwNonFunApp(L[3274],anf_fun53118406,[]);
};
try {
if(--R.GAS > 0) {
$z1839818399 = $f1840418405();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1840418405,
"from":L[3274]});
}
} catch($e1839618397) {
if(R.isCont($e1839618397)) {
var $ss1840018401 = {"from":L[3274],
"go":function(anf_arg53218407) {
return $Hanf_arg845918408(anf_arg53218407,_plus55,raise62);
}};
$e1839618397.stack[R.EXN_STACKHEIGHT++] = $ss1840018401;
}
if(R.isPyretException($e1839618397)) {
$e1839618397.pyretStack.push(L[3274]);
}
throw $e1839618397;
}
var $ret1840218403 = $Hanf_arg845918408($z1839818399,_plus55,raise62);
++R.GAS;
return $ret1840218403;
});
var $z1838318384 = D;
var $f1838918390 = function(_) {
return R.isFunction(anf_fun52918391)?anf_fun52918391.app(visitor58118392,anf_arg53418393):R.ffi.throwNonFunApp(L[3272],anf_fun52918391,[visitor58118392,anf_arg53418393]);
};
try {
if(--R.GAS > 0) {
$z1838318384 = $f1838918390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1838918390,
"from":L[3272]});
}
} catch($e1838118382) {
if(R.isCont($e1838118382)) {
var $ss1838518386 = {"from":L[3272],
"go":function(ann_DASH_check_DASH_temp52818394) {
return $Hann_DASH_check_DASH_temp846018395(ann_DASH_check_DASH_temp52818394);
}};
$e1838118382.stack[R.EXN_STACKHEIGHT++] = $ss1838518386;
}
if(R.isPyretException($e1838118382)) {
$e1838118382.pyretStack.push(L[3272]);
}
throw $e1838118382;
}
var $ret1838718388 = $Hann_DASH_check_DASH_temp846018395($z1838318384);
++R.GAS;
return $ret1838718388;
};
},{"length":2});
var anf_variant_member54918117 = R.makeMethod(function(self5218359) {
return function(cases_DASH_funs5318360,else_DASH_clause5418371) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3224],2,arguments);
}
var if_DASH_5618374 = R.hasField(cases_DASH_funs5318360,("s-import"));
var if_helper53718357 = R.makeFunction(function(if_helper_arg53818379) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3224],1,arguments);
}
var ann_DASH_check_DASH_temp53618380 = if_helper_arg53818379;
return ann_DASH_check_DASH_temp53618380;
});
var anf_if54118378 = R.isBoolean(if_DASH_5618374);
if(R.isPyretTrue(anf_if54118378)) {
if(R.isPyretTrue(if_DASH_5618374)) {
var call_DASH_s_DASH_import5118352 = G(cases_DASH_funs5318360,"s-import",L[3224]);
var anf_arg54418353 = G(self5218359,"l",L[3271]);
var anf_arg54518354 = G(self5218359,"file",L[3270]);
var anf_arg54618355 = G(self5218359,"name",L[3269]);
var $z1834418345 = D;
var $f1835018351 = function(_) {
return R.isFunction(call_DASH_s_DASH_import5118352)?call_DASH_s_DASH_import5118352.app(anf_arg54418353,anf_arg54518354,anf_arg54618355):R.ffi.throwNonFunApp(L[3224],call_DASH_s_DASH_import5118352,[anf_arg54418353,anf_arg54518354,anf_arg54618355]);
};
try {
if(--R.GAS > 0) {
$z1834418345 = $f1835018351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1835018351,
"from":L[3224]});
}
} catch($e1834218343) {
if(R.isCont($e1834218343)) {
var $ss1834618347 = {"from":L[3224],
"go":function(cont_tail_arg54718356) {
return $Hcont_tail_arg846118358(cont_tail_arg54718356,if_helper53718357);
}};
$e1834218343.stack[R.EXN_STACKHEIGHT++] = $ss1834618347;
}
if(R.isPyretException($e1834218343)) {
$e1834218343.pyretStack.push(L[3224]);
}
throw $e1834218343;
}
var $ret1834818349 = $Hcont_tail_arg846118358($z1834418345,if_helper53718357);
++R.GAS;
return $ret1834818349;
} else {
var $z1836318364 = D;
var $f1836918370 = function(_) {
return R.isFunction(else_DASH_clause5418371)?else_DASH_clause5418371.app():R.ffi.throwNonFunApp(L[3224],else_DASH_clause5418371,[]);
};
try {
if(--R.GAS > 0) {
$z1836318364 = $f1836918370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1836918370,
"from":L[3224]});
}
} catch($e1836118362) {
if(R.isCont($e1836118362)) {
var $ss1836518366 = {"from":L[3224],
"go":function(cont_tail_arg54218372) {
return $Hcont_tail_arg846218373(cont_tail_arg54218372,if_helper53718357);
}};
$e1836118362.stack[R.EXN_STACKHEIGHT++] = $ss1836518366;
}
if(R.isPyretException($e1836118362)) {
$e1836118362.pyretStack.push(L[3224]);
}
throw $e1836118362;
}
var $ret1836718368 = $Hcont_tail_arg846218373($z1836318364,if_helper53718357);
++R.GAS;
return $ret1836718368;
}
} else {
var cont_tail_arg53918377 = R.throwNonBooleanCondition(L[3224],("if"),if_DASH_5618374);
if(--R.GAS > 0) {
$z1837518376 = R.isFunction(if_helper53718357)?if_helper53718357.app(cont_tail_arg53918377):R.ffi.throwNonFunApp(L[3224],if_helper53718357,[cont_tail_arg53918377]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53718357)?if_helper53718357.app(cont_tail_arg53918377):R.ffi.throwNonFunApp(L[3224],if_helper53718357,[cont_tail_arg53918377]);
},
"from":L[3224]});
}
++R.GAS;
return $z1837518376;
}
};
},{"length":3});
var anf_variant_member56318118 = R.makeMethod(function(self5518340) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3224],0,arguments);
}
var anf_arg55118338 = G(self5518340,"l",L[3224]);
var $z1833018331 = D;
var $f1833618337 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg55118338):R.ffi.throwNonFunApp(L[3224],torepr65,[anf_arg55118338]);
};
try {
if(--R.GAS > 0) {
$z1833018331 = $f1833618337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1833618337,
"from":L[3224]});
}
} catch($e1832818329) {
if(R.isCont($e1832818329)) {
var $ss1833218333 = {"from":L[3224],
"go":function(anf_arg55218339) {
return $Hanf_arg847218341(anf_arg55218339,self5518340,_plus55,torepr65);
}};
$e1832818329.stack[R.EXN_STACKHEIGHT++] = $ss1833218333;
}
if(R.isPyretException($e1832818329)) {
$e1832818329.pyretStack.push(L[3224]);
}
throw $e1832818329;
}
var $ret1833418335 = $Hanf_arg847218341($z1833018331,self5518340,_plus55,torepr65);
++R.GAS;
return $ret1833418335;
};
},{"length":1});
var anf_variant_member56518119 = R.makeMethod(function(self56718327) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3268],0,arguments);
}
var ann_DASH_check_DASH_temp56418326 = ("s-import");
return ann_DASH_check_DASH_temp56418326;
};
},{"length":1});
var anf_variant_member57618120 = R.makeMethod(function(self56818323) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3267],0,arguments);
}
var anf_fun56718321 = G(PP170,"flow",L[3266]);
var anf_fun56818322 = G(list25154,"make",L[3265]);
var anf_bracket56918325 = G(self56818323,"file",L[3264]);
var anf_fun57018319 = G(anf_bracket56918325,"tosource",L[3263]);
var $z1831118312 = D;
var $f1831718318 = function(_) {
return R.isFunction(anf_fun57018319)?anf_fun57018319.app():R.ffi.throwNonFunApp(L[3262],anf_fun57018319,[]);
};
try {
if(--R.GAS > 0) {
$z1831118312 = $f1831718318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1831718318,
"from":L[3262]});
}
} catch($e1830918310) {
if(R.isCont($e1830918310)) {
var $ss1831318314 = {"from":L[3262],
"go":function(anf_array_val57118320) {
return $Hanf_array_val847618324(anf_array_val57118320,anf_fun56718321,anf_fun56818322,self56818323,str_DASH_as123221,str_DASH_import157663);
}};
$e1830918310.stack[R.EXN_STACKHEIGHT++] = $ss1831318314;
}
if(R.isPyretException($e1830918310)) {
$e1830918310.pyretStack.push(L[3262]);
}
throw $e1830918310;
}
var $ret1831518316 = $Hanf_array_val847618324($z1831118312,anf_fun56718321,anf_fun56818322,self56818323,str_DASH_as123221,str_DASH_import157663);
++R.GAS;
return $ret1831518316;
};
},{"length":1});
var anf_variant_member59118129 = R.makeMethod(function(self5818287) {
return function(cases_DASH_funs5918288,else_DASH_clause6018299) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3223],2,arguments);
}
var if_DASH_6218302 = R.hasField(cases_DASH_funs5918288,("s-import-types"));
var if_helper57818285 = R.makeFunction(function(if_helper_arg57918307) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3223],1,arguments);
}
var ann_DASH_check_DASH_temp57718308 = if_helper_arg57918307;
return ann_DASH_check_DASH_temp57718308;
});
var anf_if58218306 = R.isBoolean(if_DASH_6218302);
if(R.isPyretTrue(anf_if58218306)) {
if(R.isPyretTrue(if_DASH_6218302)) {
var call_DASH_s_DASH_import_DASH_types5718279 = G(cases_DASH_funs5918288,"s-import-types",L[3223]);
var anf_arg58518280 = G(self5818287,"l",L[3261]);
var anf_arg58618281 = G(self5818287,"file",L[3260]);
var anf_arg58718282 = G(self5818287,"name",L[3259]);
var anf_arg58818283 = G(self5818287,"types",L[3258]);
var $z1827118272 = D;
var $f1827718278 = function(_) {
return R.isFunction(call_DASH_s_DASH_import_DASH_types5718279)?call_DASH_s_DASH_import_DASH_types5718279.app(anf_arg58518280,anf_arg58618281,anf_arg58718282,anf_arg58818283):R.ffi.throwNonFunApp(L[3223],call_DASH_s_DASH_import_DASH_types5718279,[anf_arg58518280,anf_arg58618281,anf_arg58718282,anf_arg58818283]);
};
try {
if(--R.GAS > 0) {
$z1827118272 = $f1827718278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1827718278,
"from":L[3223]});
}
} catch($e1826918270) {
if(R.isCont($e1826918270)) {
var $ss1827318274 = {"from":L[3223],
"go":function(cont_tail_arg58918284) {
return $Hcont_tail_arg847718286(cont_tail_arg58918284,if_helper57818285);
}};
$e1826918270.stack[R.EXN_STACKHEIGHT++] = $ss1827318274;
}
if(R.isPyretException($e1826918270)) {
$e1826918270.pyretStack.push(L[3223]);
}
throw $e1826918270;
}
var $ret1827518276 = $Hcont_tail_arg847718286($z1827118272,if_helper57818285);
++R.GAS;
return $ret1827518276;
} else {
var $z1829118292 = D;
var $f1829718298 = function(_) {
return R.isFunction(else_DASH_clause6018299)?else_DASH_clause6018299.app():R.ffi.throwNonFunApp(L[3223],else_DASH_clause6018299,[]);
};
try {
if(--R.GAS > 0) {
$z1829118292 = $f1829718298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1829718298,
"from":L[3223]});
}
} catch($e1828918290) {
if(R.isCont($e1828918290)) {
var $ss1829318294 = {"from":L[3223],
"go":function(cont_tail_arg58318300) {
return $Hcont_tail_arg847818301(cont_tail_arg58318300,if_helper57818285);
}};
$e1828918290.stack[R.EXN_STACKHEIGHT++] = $ss1829318294;
}
if(R.isPyretException($e1828918290)) {
$e1828918290.pyretStack.push(L[3223]);
}
throw $e1828918290;
}
var $ret1829518296 = $Hcont_tail_arg847818301($z1829118292,if_helper57818285);
++R.GAS;
return $ret1829518296;
}
} else {
var cont_tail_arg58018305 = R.throwNonBooleanCondition(L[3223],("if"),if_DASH_6218302);
if(--R.GAS > 0) {
$z1830318304 = R.isFunction(if_helper57818285)?if_helper57818285.app(cont_tail_arg58018305):R.ffi.throwNonFunApp(L[3223],if_helper57818285,[cont_tail_arg58018305]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper57818285)?if_helper57818285.app(cont_tail_arg58018305):R.ffi.throwNonFunApp(L[3223],if_helper57818285,[cont_tail_arg58018305]);
},
"from":L[3223]});
}
++R.GAS;
return $z1830318304;
}
};
},{"length":3});
var anf_variant_member60918130 = R.makeMethod(function(self6118267) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3223],0,arguments);
}
var anf_arg59318265 = G(self6118267,"l",L[3223]);
var $z1825718258 = D;
var $f1826318264 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg59318265):R.ffi.throwNonFunApp(L[3223],torepr65,[anf_arg59318265]);
};
try {
if(--R.GAS > 0) {
$z1825718258 = $f1826318264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1826318264,
"from":L[3223]});
}
} catch($e1825518256) {
if(R.isCont($e1825518256)) {
var $ss1825918260 = {"from":L[3223],
"go":function(anf_arg59418266) {
return $Hanf_arg849118268(anf_arg59418266,self6118267,_plus55,torepr65);
}};
$e1825518256.stack[R.EXN_STACKHEIGHT++] = $ss1825918260;
}
if(R.isPyretException($e1825518256)) {
$e1825518256.pyretStack.push(L[3223]);
}
throw $e1825518256;
}
var $ret1826118262 = $Hanf_arg849118268($z1825718258,self6118267,_plus55,torepr65);
++R.GAS;
return $ret1826118262;
};
},{"length":1});
var anf_variant_member61118131 = R.makeMethod(function(self57318254) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3257],0,arguments);
}
var ann_DASH_check_DASH_temp61018253 = ("s-import-types");
return ann_DASH_check_DASH_temp61018253;
};
},{"length":1});
var anf_variant_member62618132 = R.makeMethod(function(self57418250) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3256],0,arguments);
}
var anf_fun61318248 = G(PP170,"flow",L[3255]);
var anf_fun61418249 = G(list25154,"make",L[3254]);
var anf_bracket61518252 = G(self57418250,"file",L[3253]);
var anf_fun61618246 = G(anf_bracket61518252,"tosource",L[3252]);
var $z1823818239 = D;
var $f1824418245 = function(_) {
return R.isFunction(anf_fun61618246)?anf_fun61618246.app():R.ffi.throwNonFunApp(L[3251],anf_fun61618246,[]);
};
try {
if(--R.GAS > 0) {
$z1823818239 = $f1824418245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1824418245,
"from":L[3251]});
}
} catch($e1823618237) {
if(R.isCont($e1823618237)) {
var $ss1824018241 = {"from":L[3251],
"go":function(anf_array_val61718247) {
return $Hanf_array_val849618251(anf_array_val61718247,PP170,anf_fun61318248,anf_fun61418249,self57418250,str_DASH_as123221,str_DASH_import157663);
}};
$e1823618237.stack[R.EXN_STACKHEIGHT++] = $ss1824018241;
}
if(R.isPyretException($e1823618237)) {
$e1823618237.pyretStack.push(L[3251]);
}
throw $e1823618237;
}
var $ret1824218243 = $Hanf_array_val849618251($z1823818239,PP170,anf_fun61318248,anf_fun61418249,self57418250,str_DASH_as123221,str_DASH_import157663);
++R.GAS;
return $ret1824218243;
};
},{"length":1});
var anf_variant_member64018142 = R.makeMethod(function(self6418214) {
return function(cases_DASH_funs6518215,else_DASH_clause6618226) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3222],2,arguments);
}
var if_DASH_6818229 = R.hasField(cases_DASH_funs6518215,("s-import-fields"));
var if_helper62818212 = R.makeFunction(function(if_helper_arg62918234) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3222],1,arguments);
}
var ann_DASH_check_DASH_temp62718235 = if_helper_arg62918234;
return ann_DASH_check_DASH_temp62718235;
});
var anf_if63218233 = R.isBoolean(if_DASH_6818229);
if(R.isPyretTrue(anf_if63218233)) {
if(R.isPyretTrue(if_DASH_6818229)) {
var call_DASH_s_DASH_import_DASH_fields6318207 = G(cases_DASH_funs6518215,"s-import-fields",L[3222]);
var anf_arg63518208 = G(self6418214,"l",L[3250]);
var anf_arg63618209 = G(self6418214,"fields",L[3249]);
var anf_arg63718210 = G(self6418214,"file",L[3248]);
var $z1819918200 = D;
var $f1820518206 = function(_) {
return R.isFunction(call_DASH_s_DASH_import_DASH_fields6318207)?call_DASH_s_DASH_import_DASH_fields6318207.app(anf_arg63518208,anf_arg63618209,anf_arg63718210):R.ffi.throwNonFunApp(L[3222],call_DASH_s_DASH_import_DASH_fields6318207,[anf_arg63518208,anf_arg63618209,anf_arg63718210]);
};
try {
if(--R.GAS > 0) {
$z1819918200 = $f1820518206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1820518206,
"from":L[3222]});
}
} catch($e1819718198) {
if(R.isCont($e1819718198)) {
var $ss1820118202 = {"from":L[3222],
"go":function(cont_tail_arg63818211) {
return $Hcont_tail_arg849718213(cont_tail_arg63818211,if_helper62818212);
}};
$e1819718198.stack[R.EXN_STACKHEIGHT++] = $ss1820118202;
}
if(R.isPyretException($e1819718198)) {
$e1819718198.pyretStack.push(L[3222]);
}
throw $e1819718198;
}
var $ret1820318204 = $Hcont_tail_arg849718213($z1819918200,if_helper62818212);
++R.GAS;
return $ret1820318204;
} else {
var $z1821818219 = D;
var $f1822418225 = function(_) {
return R.isFunction(else_DASH_clause6618226)?else_DASH_clause6618226.app():R.ffi.throwNonFunApp(L[3222],else_DASH_clause6618226,[]);
};
try {
if(--R.GAS > 0) {
$z1821818219 = $f1822418225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1822418225,
"from":L[3222]});
}
} catch($e1821618217) {
if(R.isCont($e1821618217)) {
var $ss1822018221 = {"from":L[3222],
"go":function(cont_tail_arg63318227) {
return $Hcont_tail_arg849818228(cont_tail_arg63318227,if_helper62818212);
}};
$e1821618217.stack[R.EXN_STACKHEIGHT++] = $ss1822018221;
}
if(R.isPyretException($e1821618217)) {
$e1821618217.pyretStack.push(L[3222]);
}
throw $e1821618217;
}
var $ret1822218223 = $Hcont_tail_arg849818228($z1821818219,if_helper62818212);
++R.GAS;
return $ret1822218223;
}
} else {
var cont_tail_arg63018232 = R.throwNonBooleanCondition(L[3222],("if"),if_DASH_6818229);
if(--R.GAS > 0) {
$z1823018231 = R.isFunction(if_helper62818212)?if_helper62818212.app(cont_tail_arg63018232):R.ffi.throwNonFunApp(L[3222],if_helper62818212,[cont_tail_arg63018232]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper62818212)?if_helper62818212.app(cont_tail_arg63018232):R.ffi.throwNonFunApp(L[3222],if_helper62818212,[cont_tail_arg63018232]);
},
"from":L[3222]});
}
++R.GAS;
return $z1823018231;
}
};
},{"length":3});
var anf_variant_member65418143 = R.makeMethod(function(self6718195) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3222],0,arguments);
}
var anf_arg64218193 = G(self6718195,"l",L[3222]);
var $z1818518186 = D;
var $f1819118192 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg64218193):R.ffi.throwNonFunApp(L[3222],torepr65,[anf_arg64218193]);
};
try {
if(--R.GAS > 0) {
$z1818518186 = $f1819118192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1819118192,
"from":L[3222]});
}
} catch($e1818318184) {
if(R.isCont($e1818318184)) {
var $ss1818718188 = {"from":L[3222],
"go":function(anf_arg64318194) {
return $Hanf_arg850818196(anf_arg64318194,self6718195,_plus55,torepr65);
}};
$e1818318184.stack[R.EXN_STACKHEIGHT++] = $ss1818718188;
}
if(R.isPyretException($e1818318184)) {
$e1818318184.pyretStack.push(L[3222]);
}
throw $e1818318184;
}
var $ret1818918190 = $Hanf_arg850818196($z1818518186,self6718195,_plus55,torepr65);
++R.GAS;
return $ret1818918190;
};
},{"length":1});
var anf_variant_member65618144 = R.makeMethod(function(self57811174) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3247],0,arguments);
}
var ann_DASH_check_DASH_temp65518182 = ("s-import-fields");
return ann_DASH_check_DASH_temp65518182;
};
},{"length":1});
var anf_variant_member67118145 = R.makeMethod(function(self57918166) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3246],0,arguments);
}
var anf_fun65818164 = G(PP170,"flow",L[3245]);
var anf_fun65918165 = G(list25154,"make",L[3244]);
var anf_fun66018159 = G(PP170,"flow-map",L[3243]);
var anf_arg66118160 = G(PP170,"commabreak",L[3242]);
var anf_arg66418161 = R.makeFunction(function(recv_DASH_6918168) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3241],1,arguments);
}
var anf_fun66318179 = G(recv_DASH_6918168,"tosource",L[3241]);
var $z1817118172 = D;
var $f1817718178 = function(_) {
return R.isFunction(anf_fun66318179)?anf_fun66318179.app():R.ffi.throwNonFunApp(L[3241],anf_fun66318179,[]);
};
try {
if(--R.GAS > 0) {
$z1817118172 = $f1817718178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1817718178,
"from":L[3241]});
}
} catch($e1816918170) {
if(R.isCont($e1816918170)) {
var $ss1817318174 = {"from":L[3241],
"go":function(ann_DASH_check_DASH_temp66218180) {
return $Hann_DASH_check_DASH_temp850918181(ann_DASH_check_DASH_temp66218180);
}};
$e1816918170.stack[R.EXN_STACKHEIGHT++] = $ss1817318174;
}
if(R.isPyretException($e1816918170)) {
$e1816918170.pyretStack.push(L[3241]);
}
throw $e1816918170;
}
var $ret1817518176 = $Hann_DASH_check_DASH_temp850918181($z1817118172);
++R.GAS;
return $ret1817518176;
});
var anf_arg66518162 = G(self57918166,"fields",L[3240]);
var $z1815118152 = D;
var $f1815718158 = function(_) {
return R.isFunction(anf_fun66018159)?anf_fun66018159.app(anf_arg66118160,anf_arg66418161,anf_arg66518162):R.ffi.throwNonFunApp(L[3239],anf_fun66018159,[anf_arg66118160,anf_arg66418161,anf_arg66518162]);
};
try {
if(--R.GAS > 0) {
$z1815118152 = $f1815718158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1815718158,
"from":L[3239]});
}
} catch($e1814918150) {
if(R.isCont($e1814918150)) {
var $ss1815318154 = {"from":L[3239],
"go":function(anf_array_val66618163) {
return $Hanf_array_val851318167(anf_array_val66618163,anf_fun65818164,anf_fun65918165,self57918166,str_DASH_from151585,str_DASH_import157663);
}};
$e1814918150.stack[R.EXN_STACKHEIGHT++] = $ss1815318154;
}
if(R.isPyretException($e1814918150)) {
$e1814918150.pyretStack.push(L[3239]);
}
throw $e1814918150;
}
var $ret1815518156 = $Hanf_array_val851318167($z1815118152,anf_fun65818164,anf_fun65918165,self57918166,str_DASH_from151585,str_DASH_import157663);
++R.GAS;
return $ret1815518156;
};
},{"length":1});
var anf_assign6721814 = (function() {
var $s_DASH_import_DASH_base1811218113 = {"visit":anf_shared53518111,
"_match":anf_variant_member54918117,
"_torepr":anf_variant_member56318118,
"label":anf_variant_member56518119,
"tosource":anf_variant_member57618120};
var $s_DASH_import_DASH_brands1811518116 = {"$brand-s-import18114":true};
$s_DASH_import_DASH_brands1811518116[ImportT371122._brand] = true
var $s_DASH_import_DASH_types_DASH_base1812418125 = {"visit":anf_shared53518111,
"_match":anf_variant_member59118129,
"_torepr":anf_variant_member60918130,
"label":anf_variant_member61118131,
"tosource":anf_variant_member62618132};
var $s_DASH_import_DASH_types_DASH_brands1812718128 = {"$brand-s-import-types18126":true};
$s_DASH_import_DASH_types_DASH_brands1812718128[ImportT371122._brand] = true
var $s_DASH_import_DASH_fields_DASH_base1813718138 = {"visit":anf_shared53518111,
"_match":anf_variant_member64018142,
"_torepr":anf_variant_member65418143,
"label":anf_variant_member65618144,
"tosource":anf_variant_member67118145};
var $s_DASH_import_DASH_fields_DASH_brands1814018141 = {"$brand-s-import-fields18139":true};
$s_DASH_import_DASH_fields_DASH_brands1814018141[ImportT371122._brand] = true
return R.makeObject({"Import":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3225],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ImportT371122._brand));
}),
"is-s-import":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3224],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-import18114"));
}),
"s-import":R.makeFunction(function(l56418121,file56518122,name56618123) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[3226],3,arguments);
}
return R.checkAnnArgs([Loc116130,ImportType76123,Name66133],[l56418121,file56518122,name56618123],[L[3227],L[3228],L[3229]],function() {
var dict = R.create($s_DASH_import_DASH_base1811218113);
dict["l"] = l56418121
dict["file"] = file56518122
dict["name"] = name56618123
return R.makeBrandedObject(dict,$s_DASH_import_DASH_brands1811518116);
});
}),
"is-s-import-types":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3223],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-import-types18126"));
}),
"s-import-types":R.makeFunction(function(l56918133,file57018134,name57118135,types57218136) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[3230],4,arguments);
}
return R.checkAnnArgs([Loc116130,ImportType76123,Name66133,Name66133],[l56918133,file57018134,name57118135,types57218136],[L[3231],L[3232],L[3233],L[3234]],function() {
var dict = R.create($s_DASH_import_DASH_types_DASH_base1812418125);
dict["l"] = l56918133
dict["file"] = file57018134
dict["name"] = name57118135
dict["types"] = types57218136
return R.makeBrandedObject(dict,$s_DASH_import_DASH_types_DASH_brands1812718128);
});
}),
"is-s-import-fields":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3222],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-import-fields18139"));
}),
"s-import-fields":R.makeFunction(function(l57518146,fields57618147,file57718148) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[3235],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,ImportType76123],[l57518146,fields57618147,file57718148],[L[3236],L[3237],L[3238]],function() {
var dict = R.create($s_DASH_import_DASH_fields_DASH_base1813718138);
dict["l"] = l57518146
dict["fields"] = fields57618147
dict["file"] = file57718148
return R.makeBrandedObject(dict,$s_DASH_import_DASH_fields_DASH_brands1814018141);
});
})});
})();
Import282561813.$var = anf_assign6721814;
var anf_assign6731816 = G(Import282561813.$var,"Import",L[3225]);
Import2571815.$var = anf_assign6731816;
var anf_assign6741818 = G(Import282561813.$var,"Import",L[3225]);
is_DASH_Import2581817.$var = anf_assign6741818;
var anf_assign6751820 = G(Import282561813.$var,"is-s-import",L[3224]);
is_DASH_s_DASH_import2591819.$var = anf_assign6751820;
var anf_assign6761822 = G(Import282561813.$var,"s-import",L[3224]);
s_DASH_import2601821.$var = anf_assign6761822;
var anf_assign6771824 = G(Import282561813.$var,"is-s-import-types",L[3223]);
is_DASH_s_DASH_import_DASH_types2611823.$var = anf_assign6771824;
var anf_assign6781826 = G(Import282561813.$var,"s-import-types",L[3223]);
s_DASH_import_DASH_types2621825.$var = anf_assign6781826;
var anf_assign6791828 = G(Import282561813.$var,"is-s-import-fields",L[3222]);
is_DASH_s_DASH_import_DASH_fields2631827.$var = anf_assign6791828;
var anf_assign6801830 = G(Import282561813.$var,"s-import-fields",L[3222]);
s_DASH_import_DASH_fields2641829.$var = anf_assign6801830;
var anf_shared68817873 = R.makeMethod(function(self59218110) {
return function(visitor59318093) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3217],1,arguments);
}
var anf_fun68218092 = G(self59218110,"_match",L[3221]);
var anf_arg68718094 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3218],0,arguments);
}
var anf_fun68418107 = G(self59218110,"label",L[3220]);
var $z1809918100 = D;
var $f1810518106 = function(_) {
return R.isFunction(anf_fun68418107)?anf_fun68418107.app():R.ffi.throwNonFunApp(L[3219],anf_fun68418107,[]);
};
try {
if(--R.GAS > 0) {
$z1809918100 = $f1810518106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1810518106,
"from":L[3219]});
}
} catch($e1809718098) {
if(R.isCont($e1809718098)) {
var $ss1810118102 = {"from":L[3219],
"go":function(anf_arg68518108) {
return $Hanf_arg851618109(anf_arg68518108,_plus55,raise62);
}};
$e1809718098.stack[R.EXN_STACKHEIGHT++] = $ss1810118102;
}
if(R.isPyretException($e1809718098)) {
$e1809718098.pyretStack.push(L[3219]);
}
throw $e1809718098;
}
var $ret1810318104 = $Hanf_arg851618109($z1809918100,_plus55,raise62);
++R.GAS;
return $ret1810318104;
});
var $z1808418085 = D;
var $f1809018091 = function(_) {
return R.isFunction(anf_fun68218092)?anf_fun68218092.app(visitor59318093,anf_arg68718094):R.ffi.throwNonFunApp(L[3217],anf_fun68218092,[visitor59318093,anf_arg68718094]);
};
try {
if(--R.GAS > 0) {
$z1808418085 = $f1809018091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1809018091,
"from":L[3217]});
}
} catch($e1808218083) {
if(R.isCont($e1808218083)) {
var $ss1808618087 = {"from":L[3217],
"go":function(ann_DASH_check_DASH_temp68118095) {
return $Hann_DASH_check_DASH_temp851718096(ann_DASH_check_DASH_temp68118095);
}};
$e1808218083.stack[R.EXN_STACKHEIGHT++] = $ss1808618087;
}
if(R.isPyretException($e1808218083)) {
$e1808218083.pyretStack.push(L[3217]);
}
throw $e1808218083;
}
var $ret1808818089 = $Hann_DASH_check_DASH_temp851718096($z1808418085);
++R.GAS;
return $ret1808818089;
};
},{"length":2});
var anf_variant_member70117879 = R.makeMethod(function(self7118060) {
return function(cases_DASH_funs7218061,else_DASH_clause7318072) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3193],2,arguments);
}
var if_DASH_7518075 = R.hasField(cases_DASH_funs7218061,("s-provide"));
var if_helper69018058 = R.makeFunction(function(if_helper_arg69118080) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3193],1,arguments);
}
var ann_DASH_check_DASH_temp68918081 = if_helper_arg69118080;
return ann_DASH_check_DASH_temp68918081;
});
var anf_if69418079 = R.isBoolean(if_DASH_7518075);
if(R.isPyretTrue(anf_if69418079)) {
if(R.isPyretTrue(if_DASH_7518075)) {
var call_DASH_s_DASH_provide7018054 = G(cases_DASH_funs7218061,"s-provide",L[3193]);
var anf_arg69718055 = G(self7118060,"l",L[3216]);
var anf_arg69818056 = G(self7118060,"block",L[3215]);
var $z1804618047 = D;
var $f1805218053 = function(_) {
return R.isFunction(call_DASH_s_DASH_provide7018054)?call_DASH_s_DASH_provide7018054.app(anf_arg69718055,anf_arg69818056):R.ffi.throwNonFunApp(L[3193],call_DASH_s_DASH_provide7018054,[anf_arg69718055,anf_arg69818056]);
};
try {
if(--R.GAS > 0) {
$z1804618047 = $f1805218053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1805218053,
"from":L[3193]});
}
} catch($e1804418045) {
if(R.isCont($e1804418045)) {
var $ss1804818049 = {"from":L[3193],
"go":function(cont_tail_arg69918057) {
return $Hcont_tail_arg851818059(cont_tail_arg69918057,if_helper69018058);
}};
$e1804418045.stack[R.EXN_STACKHEIGHT++] = $ss1804818049;
}
if(R.isPyretException($e1804418045)) {
$e1804418045.pyretStack.push(L[3193]);
}
throw $e1804418045;
}
var $ret1805018051 = $Hcont_tail_arg851818059($z1804618047,if_helper69018058);
++R.GAS;
return $ret1805018051;
} else {
var $z1806418065 = D;
var $f1807018071 = function(_) {
return R.isFunction(else_DASH_clause7318072)?else_DASH_clause7318072.app():R.ffi.throwNonFunApp(L[3193],else_DASH_clause7318072,[]);
};
try {
if(--R.GAS > 0) {
$z1806418065 = $f1807018071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1807018071,
"from":L[3193]});
}
} catch($e1806218063) {
if(R.isCont($e1806218063)) {
var $ss1806618067 = {"from":L[3193],
"go":function(cont_tail_arg69518073) {
return $Hcont_tail_arg851918074(cont_tail_arg69518073,if_helper69018058);
}};
$e1806218063.stack[R.EXN_STACKHEIGHT++] = $ss1806618067;
}
if(R.isPyretException($e1806218063)) {
$e1806218063.pyretStack.push(L[3193]);
}
throw $e1806218063;
}
var $ret1806818069 = $Hcont_tail_arg851918074($z1806418065,if_helper69018058);
++R.GAS;
return $ret1806818069;
}
} else {
var cont_tail_arg69218078 = R.throwNonBooleanCondition(L[3193],("if"),if_DASH_7518075);
if(--R.GAS > 0) {
$z1807618077 = R.isFunction(if_helper69018058)?if_helper69018058.app(cont_tail_arg69218078):R.ffi.throwNonFunApp(L[3193],if_helper69018058,[cont_tail_arg69218078]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper69018058)?if_helper69018058.app(cont_tail_arg69218078):R.ffi.throwNonFunApp(L[3193],if_helper69018058,[cont_tail_arg69218078]);
},
"from":L[3193]});
}
++R.GAS;
return $z1807618077;
}
};
},{"length":3});
var anf_variant_member71117880 = R.makeMethod(function(self7418042) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3193],0,arguments);
}
var anf_arg70318040 = G(self7418042,"l",L[3193]);
var $z1803218033 = D;
var $f1803818039 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg70318040):R.ffi.throwNonFunApp(L[3193],torepr65,[anf_arg70318040]);
};
try {
if(--R.GAS > 0) {
$z1803218033 = $f1803818039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1803818039,
"from":L[3193]});
}
} catch($e1803018031) {
if(R.isCont($e1803018031)) {
var $ss1803418035 = {"from":L[3193],
"go":function(anf_arg70418041) {
return $Hanf_arg852618043(anf_arg70418041,self7418042,_plus55,torepr65);
}};
$e1803018031.stack[R.EXN_STACKHEIGHT++] = $ss1803418035;
}
if(R.isPyretException($e1803018031)) {
$e1803018031.pyretStack.push(L[3193]);
}
throw $e1803018031;
}
var $ret1803618037 = $Hanf_arg852618043($z1803218033,self7418042,_plus55,torepr65);
++R.GAS;
return $ret1803618037;
};
},{"length":1});
var anf_variant_member71317881 = R.makeMethod(function(self58411120) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3214],0,arguments);
}
var ann_DASH_check_DASH_temp71218029 = ("s-provide");
return ann_DASH_check_DASH_temp71218029;
};
},{"length":1});
var anf_variant_member71917882 = R.makeMethod(function(self58518028) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3213],0,arguments);
}
var anf_fun71518025 = G(PP170,"soft-surround",L[3212]);
var anf_bracket71618027 = G(self58518028,"block",L[3211]);
var anf_fun71718023 = G(anf_bracket71618027,"tosource",L[3210]);
var $z1801518016 = D;
var $f1802118022 = function(_) {
return R.isFunction(anf_fun71718023)?anf_fun71718023.app():R.ffi.throwNonFunApp(L[3209],anf_fun71718023,[]);
};
try {
if(--R.GAS > 0) {
$z1801518016 = $f1802118022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1802118022,
"from":L[3209]});
}
} catch($e1801318014) {
if(R.isCont($e1801318014)) {
var $ss1801718018 = {"from":L[3209],
"go":function(anf_arg71818024) {
return $Hanf_arg852818026(anf_arg71818024,INDENT118169,anf_fun71518025,str_DASH_end148546,str_DASH_provide163741);
}};
$e1801318014.stack[R.EXN_STACKHEIGHT++] = $ss1801718018;
}
if(R.isPyretException($e1801318014)) {
$e1801318014.pyretStack.push(L[3209]);
}
throw $e1801318014;
}
var $ret1801918020 = $Hanf_arg852818026($z1801518016,INDENT118169,anf_fun71518025,str_DASH_end148546,str_DASH_provide163741);
++R.GAS;
return $ret1801918020;
};
},{"length":1});
var anf_variant_member73117890 = R.makeMethod(function(self7717991) {
return function(cases_DASH_funs7817992,else_DASH_clause7918003) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3192],2,arguments);
}
var if_DASH_8118006 = R.hasField(cases_DASH_funs7817992,("s-provide-all"));
var if_helper72117989 = R.makeFunction(function(if_helper_arg72218011) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3192],1,arguments);
}
var ann_DASH_check_DASH_temp72018012 = if_helper_arg72218011;
return ann_DASH_check_DASH_temp72018012;
});
var anf_if72518010 = R.isBoolean(if_DASH_8118006);
if(R.isPyretTrue(anf_if72518010)) {
if(R.isPyretTrue(if_DASH_8118006)) {
var call_DASH_s_DASH_provide_DASH_all7617986 = G(cases_DASH_funs7817992,"s-provide-all",L[3192]);
var anf_arg72817987 = G(self7717991,"l",L[3208]);
var $z1797817979 = D;
var $f1798417985 = function(_) {
return R.isFunction(call_DASH_s_DASH_provide_DASH_all7617986)?call_DASH_s_DASH_provide_DASH_all7617986.app(anf_arg72817987):R.ffi.throwNonFunApp(L[3192],call_DASH_s_DASH_provide_DASH_all7617986,[anf_arg72817987]);
};
try {
if(--R.GAS > 0) {
$z1797817979 = $f1798417985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1798417985,
"from":L[3192]});
}
} catch($e1797617977) {
if(R.isCont($e1797617977)) {
var $ss1798017981 = {"from":L[3192],
"go":function(cont_tail_arg72917988) {
return $Hcont_tail_arg852917990(cont_tail_arg72917988,if_helper72117989);
}};
$e1797617977.stack[R.EXN_STACKHEIGHT++] = $ss1798017981;
}
if(R.isPyretException($e1797617977)) {
$e1797617977.pyretStack.push(L[3192]);
}
throw $e1797617977;
}
var $ret1798217983 = $Hcont_tail_arg852917990($z1797817979,if_helper72117989);
++R.GAS;
return $ret1798217983;
} else {
var $z1799517996 = D;
var $f1800118002 = function(_) {
return R.isFunction(else_DASH_clause7918003)?else_DASH_clause7918003.app():R.ffi.throwNonFunApp(L[3192],else_DASH_clause7918003,[]);
};
try {
if(--R.GAS > 0) {
$z1799517996 = $f1800118002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1800118002,
"from":L[3192]});
}
} catch($e1799317994) {
if(R.isCont($e1799317994)) {
var $ss1799717998 = {"from":L[3192],
"go":function(cont_tail_arg72618004) {
return $Hcont_tail_arg853018005(cont_tail_arg72618004,if_helper72117989);
}};
$e1799317994.stack[R.EXN_STACKHEIGHT++] = $ss1799717998;
}
if(R.isPyretException($e1799317994)) {
$e1799317994.pyretStack.push(L[3192]);
}
throw $e1799317994;
}
var $ret1799918000 = $Hcont_tail_arg853018005($z1799517996,if_helper72117989);
++R.GAS;
return $ret1799918000;
}
} else {
var cont_tail_arg72318009 = R.throwNonBooleanCondition(L[3192],("if"),if_DASH_8118006);
if(--R.GAS > 0) {
$z1800718008 = R.isFunction(if_helper72117989)?if_helper72117989.app(cont_tail_arg72318009):R.ffi.throwNonFunApp(L[3192],if_helper72117989,[cont_tail_arg72318009]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper72117989)?if_helper72117989.app(cont_tail_arg72318009):R.ffi.throwNonFunApp(L[3192],if_helper72117989,[cont_tail_arg72318009]);
},
"from":L[3192]});
}
++R.GAS;
return $z1800718008;
}
};
},{"length":3});
var anf_variant_member73717891 = R.makeMethod(function(self8017975) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3192],0,arguments);
}
var anf_arg73317972 = G(self8017975,"l",L[3192]);
var $z1796417965 = D;
var $f1797017971 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg73317972):R.ffi.throwNonFunApp(L[3192],torepr65,[anf_arg73317972]);
};
try {
if(--R.GAS > 0) {
$z1796417965 = $f1797017971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1797017971,
"from":L[3192]});
}
} catch($e1796217963) {
if(R.isCont($e1796217963)) {
var $ss1796617967 = {"from":L[3192],
"go":function(anf_arg73417973) {
return $Hanf_arg853417974(anf_arg73417973,_plus55);
}};
$e1796217963.stack[R.EXN_STACKHEIGHT++] = $ss1796617967;
}
if(R.isPyretException($e1796217963)) {
$e1796217963.pyretStack.push(L[3192]);
}
throw $e1796217963;
}
var $ret1796817969 = $Hanf_arg853417974($z1796417965,_plus55);
++R.GAS;
return $ret1796817969;
};
},{"length":1});
var anf_variant_member73917892 = R.makeMethod(function(self58711024) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3207],0,arguments);
}
var ann_DASH_check_DASH_temp73817961 = ("s-provide-all");
return ann_DASH_check_DASH_temp73817961;
};
},{"length":1});
var anf_variant_member74117893 = R.makeMethod(function(self58817960) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3206],0,arguments);
}
var ann_DASH_check_DASH_temp74017959 = str_DASH_provide_DASH_star165767;
return ann_DASH_check_DASH_temp74017959;
};
},{"length":1});
var anf_variant_member75317900 = R.makeMethod(function(self8317937) {
return function(cases_DASH_funs8417938,else_DASH_clause8517949) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3191],2,arguments);
}
var if_DASH_8717952 = R.hasField(cases_DASH_funs8417938,("s-provide-none"));
var if_helper74317935 = R.makeFunction(function(if_helper_arg74417957) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3191],1,arguments);
}
var ann_DASH_check_DASH_temp74217958 = if_helper_arg74417957;
return ann_DASH_check_DASH_temp74217958;
});
var anf_if74717956 = R.isBoolean(if_DASH_8717952);
if(R.isPyretTrue(anf_if74717956)) {
if(R.isPyretTrue(if_DASH_8717952)) {
var call_DASH_s_DASH_provide_DASH_none8217932 = G(cases_DASH_funs8417938,"s-provide-none",L[3191]);
var anf_arg75017933 = G(self8317937,"l",L[3205]);
var $z1792417925 = D;
var $f1793017931 = function(_) {
return R.isFunction(call_DASH_s_DASH_provide_DASH_none8217932)?call_DASH_s_DASH_provide_DASH_none8217932.app(anf_arg75017933):R.ffi.throwNonFunApp(L[3191],call_DASH_s_DASH_provide_DASH_none8217932,[anf_arg75017933]);
};
try {
if(--R.GAS > 0) {
$z1792417925 = $f1793017931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1793017931,
"from":L[3191]});
}
} catch($e1792217923) {
if(R.isCont($e1792217923)) {
var $ss1792617927 = {"from":L[3191],
"go":function(cont_tail_arg75117934) {
return $Hcont_tail_arg853517936(cont_tail_arg75117934,if_helper74317935);
}};
$e1792217923.stack[R.EXN_STACKHEIGHT++] = $ss1792617927;
}
if(R.isPyretException($e1792217923)) {
$e1792217923.pyretStack.push(L[3191]);
}
throw $e1792217923;
}
var $ret1792817929 = $Hcont_tail_arg853517936($z1792417925,if_helper74317935);
++R.GAS;
return $ret1792817929;
} else {
var $z1794117942 = D;
var $f1794717948 = function(_) {
return R.isFunction(else_DASH_clause8517949)?else_DASH_clause8517949.app():R.ffi.throwNonFunApp(L[3191],else_DASH_clause8517949,[]);
};
try {
if(--R.GAS > 0) {
$z1794117942 = $f1794717948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1794717948,
"from":L[3191]});
}
} catch($e1793917940) {
if(R.isCont($e1793917940)) {
var $ss1794317944 = {"from":L[3191],
"go":function(cont_tail_arg74817950) {
return $Hcont_tail_arg853617951(cont_tail_arg74817950,if_helper74317935);
}};
$e1793917940.stack[R.EXN_STACKHEIGHT++] = $ss1794317944;
}
if(R.isPyretException($e1793917940)) {
$e1793917940.pyretStack.push(L[3191]);
}
throw $e1793917940;
}
var $ret1794517946 = $Hcont_tail_arg853617951($z1794117942,if_helper74317935);
++R.GAS;
return $ret1794517946;
}
} else {
var cont_tail_arg74517955 = R.throwNonBooleanCondition(L[3191],("if"),if_DASH_8717952);
if(--R.GAS > 0) {
$z1795317954 = R.isFunction(if_helper74317935)?if_helper74317935.app(cont_tail_arg74517955):R.ffi.throwNonFunApp(L[3191],if_helper74317935,[cont_tail_arg74517955]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper74317935)?if_helper74317935.app(cont_tail_arg74517955):R.ffi.throwNonFunApp(L[3191],if_helper74317935,[cont_tail_arg74517955]);
},
"from":L[3191]});
}
++R.GAS;
return $z1795317954;
}
};
},{"length":3});
var anf_variant_member75917901 = R.makeMethod(function(self8617921) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3191],0,arguments);
}
var anf_arg75517918 = G(self8617921,"l",L[3191]);
var $z1791017911 = D;
var $f1791617917 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg75517918):R.ffi.throwNonFunApp(L[3191],torepr65,[anf_arg75517918]);
};
try {
if(--R.GAS > 0) {
$z1791017911 = $f1791617917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1791617917,
"from":L[3191]});
}
} catch($e1790817909) {
if(R.isCont($e1790817909)) {
var $ss1791217913 = {"from":L[3191],
"go":function(anf_arg75617919) {
return $Hanf_arg854017920(anf_arg75617919,_plus55);
}};
$e1790817909.stack[R.EXN_STACKHEIGHT++] = $ss1791217913;
}
if(R.isPyretException($e1790817909)) {
$e1790817909.pyretStack.push(L[3191]);
}
throw $e1790817909;
}
var $ret1791417915 = $Hanf_arg854017920($z1791017911,_plus55);
++R.GAS;
return $ret1791417915;
};
},{"length":1});
var anf_variant_member76117902 = R.makeMethod(function(self59011005) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3204],0,arguments);
}
var ann_DASH_check_DASH_temp76017907 = ("s-provide-none");
return ann_DASH_check_DASH_temp76017907;
};
},{"length":1});
var anf_variant_member76317903 = R.makeMethod(function(self59117906) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3203],0,arguments);
}
var ann_DASH_check_DASH_temp76217905 = G(PP170,"mt-doc",L[3202]);
return ann_DASH_check_DASH_temp76217905;
};
},{"length":1});
var anf_assign7641832 = (function() {
var $s_DASH_provide_DASH_base1787417875 = {"visit":anf_shared68817873,
"_match":anf_variant_member70117879,
"_torepr":anf_variant_member71117880,
"label":anf_variant_member71317881,
"tosource":anf_variant_member71917882};
var $s_DASH_provide_DASH_brands1787717878 = {"$brand-s-provide17876":true};
$s_DASH_provide_DASH_brands1787717878[ProvideT473139._brand] = true
var $s_DASH_provide_DASH_all_DASH_base1788517886 = {"visit":anf_shared68817873,
"_match":anf_variant_member73117890,
"_torepr":anf_variant_member73717891,
"label":anf_variant_member73917892,
"tosource":anf_variant_member74117893};
var $s_DASH_provide_DASH_all_DASH_brands1788817889 = {"$brand-s-provide-all17887":true};
$s_DASH_provide_DASH_all_DASH_brands1788817889[ProvideT473139._brand] = true
var $s_DASH_provide_DASH_none_DASH_base1789517896 = {"visit":anf_shared68817873,
"_match":anf_variant_member75317900,
"_torepr":anf_variant_member75917901,
"label":anf_variant_member76117902,
"tosource":anf_variant_member76317903};
var $s_DASH_provide_DASH_none_DASH_brands1789817899 = {"$brand-s-provide-none17897":true};
$s_DASH_provide_DASH_none_DASH_brands1789817899[ProvideT473139._brand] = true
return R.makeObject({"Provide":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3194],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ProvideT473139._brand));
}),
"is-s-provide":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3193],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-provide17876"));
}),
"s-provide":R.makeFunction(function(l58217883,block58317884) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3195],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l58217883,block58317884],[L[3196],L[3197]],function() {
var dict = R.create($s_DASH_provide_DASH_base1787417875);
dict["l"] = l58217883
dict["block"] = block58317884
return R.makeBrandedObject(dict,$s_DASH_provide_DASH_brands1787717878);
});
}),
"is-s-provide-all":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3192],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-provide-all17887"));
}),
"s-provide-all":R.makeFunction(function(l58617894) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3198],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l58617894],[L[3199]],function() {
var dict = R.create($s_DASH_provide_DASH_all_DASH_base1788517886);
dict["l"] = l58617894
return R.makeBrandedObject(dict,$s_DASH_provide_DASH_all_DASH_brands1788817889);
});
}),
"is-s-provide-none":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3191],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-provide-none17897"));
}),
"s-provide-none":R.makeFunction(function(l58917904) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3200],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l58917904],[L[3201]],function() {
var dict = R.create($s_DASH_provide_DASH_none_DASH_base1789517896);
dict["l"] = l58917904
return R.makeBrandedObject(dict,$s_DASH_provide_DASH_none_DASH_brands1789817899);
});
})});
})();
Provide292651831.$var = anf_assign7641832;
var anf_assign7651834 = G(Provide292651831.$var,"Provide",L[3194]);
Provide2661833.$var = anf_assign7651834;
var anf_assign7661836 = G(Provide292651831.$var,"Provide",L[3194]);
is_DASH_Provide2671835.$var = anf_assign7661836;
var anf_assign7671838 = G(Provide292651831.$var,"is-s-provide",L[3193]);
is_DASH_s_DASH_provide2681837.$var = anf_assign7671838;
var anf_assign7681840 = G(Provide292651831.$var,"s-provide",L[3193]);
s_DASH_provide2691839.$var = anf_assign7681840;
var anf_assign7691842 = G(Provide292651831.$var,"is-s-provide-all",L[3192]);
is_DASH_s_DASH_provide_DASH_all2701841.$var = anf_assign7691842;
var anf_assign7701844 = G(Provide292651831.$var,"s-provide-all",L[3192]);
s_DASH_provide_DASH_all2711843.$var = anf_assign7701844;
var anf_assign7711846 = G(Provide292651831.$var,"is-s-provide-none",L[3191]);
is_DASH_s_DASH_provide_DASH_none2721845.$var = anf_assign7711846;
var anf_assign7721848 = G(Provide292651831.$var,"s-provide-none",L[3191]);
s_DASH_provide_DASH_none2731847.$var = anf_assign7721848;
var anf_shared78017637 = R.makeMethod(function(self60417872) {
return function(visitor60517855) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3186],1,arguments);
}
var anf_fun77417854 = G(self60417872,"_match",L[3190]);
var anf_arg77917856 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3187],0,arguments);
}
var anf_fun77617869 = G(self60417872,"label",L[3189]);
var $z1786117862 = D;
var $f1786717868 = function(_) {
return R.isFunction(anf_fun77617869)?anf_fun77617869.app():R.ffi.throwNonFunApp(L[3188],anf_fun77617869,[]);
};
try {
if(--R.GAS > 0) {
$z1786117862 = $f1786717868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1786717868,
"from":L[3188]});
}
} catch($e1785917860) {
if(R.isCont($e1785917860)) {
var $ss1786317864 = {"from":L[3188],
"go":function(anf_arg77717870) {
return $Hanf_arg854317871(anf_arg77717870,_plus55,raise62);
}};
$e1785917860.stack[R.EXN_STACKHEIGHT++] = $ss1786317864;
}
if(R.isPyretException($e1785917860)) {
$e1785917860.pyretStack.push(L[3188]);
}
throw $e1785917860;
}
var $ret1786517866 = $Hanf_arg854317871($z1786117862,_plus55,raise62);
++R.GAS;
return $ret1786517866;
});
var $z1784617847 = D;
var $f1785217853 = function(_) {
return R.isFunction(anf_fun77417854)?anf_fun77417854.app(visitor60517855,anf_arg77917856):R.ffi.throwNonFunApp(L[3186],anf_fun77417854,[visitor60517855,anf_arg77917856]);
};
try {
if(--R.GAS > 0) {
$z1784617847 = $f1785217853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1785217853,
"from":L[3186]});
}
} catch($e1784417845) {
if(R.isCont($e1784417845)) {
var $ss1784817849 = {"from":L[3186],
"go":function(ann_DASH_check_DASH_temp77317857) {
return $Hann_DASH_check_DASH_temp854417858(ann_DASH_check_DASH_temp77317857);
}};
$e1784417845.stack[R.EXN_STACKHEIGHT++] = $ss1784817849;
}
if(R.isPyretException($e1784417845)) {
$e1784417845.pyretStack.push(L[3186]);
}
throw $e1784417845;
}
var $ret1785017851 = $Hann_DASH_check_DASH_temp854417858($z1784617847);
++R.GAS;
return $ret1785017851;
};
},{"length":2});
var anf_variant_member79317643 = R.makeMethod(function(self8917822) {
return function(cases_DASH_funs9017823,else_DASH_clause9117834) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3164],2,arguments);
}
var if_DASH_9317837 = R.hasField(cases_DASH_funs9017823,("s-provide-types"));
var if_helper78217820 = R.makeFunction(function(if_helper_arg78317842) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3164],1,arguments);
}
var ann_DASH_check_DASH_temp78117843 = if_helper_arg78317842;
return ann_DASH_check_DASH_temp78117843;
});
var anf_if78617841 = R.isBoolean(if_DASH_9317837);
if(R.isPyretTrue(anf_if78617841)) {
if(R.isPyretTrue(if_DASH_9317837)) {
var call_DASH_s_DASH_provide_DASH_types8817816 = G(cases_DASH_funs9017823,"s-provide-types",L[3164]);
var anf_arg78917817 = G(self8917822,"l",L[3185]);
var anf_arg79017818 = G(self8917822,"ann",L[3184]);
var $z1780817809 = D;
var $f1781417815 = function(_) {
return R.isFunction(call_DASH_s_DASH_provide_DASH_types8817816)?call_DASH_s_DASH_provide_DASH_types8817816.app(anf_arg78917817,anf_arg79017818):R.ffi.throwNonFunApp(L[3164],call_DASH_s_DASH_provide_DASH_types8817816,[anf_arg78917817,anf_arg79017818]);
};
try {
if(--R.GAS > 0) {
$z1780817809 = $f1781417815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1781417815,
"from":L[3164]});
}
} catch($e1780617807) {
if(R.isCont($e1780617807)) {
var $ss1781017811 = {"from":L[3164],
"go":function(cont_tail_arg79117819) {
return $Hcont_tail_arg854517821(cont_tail_arg79117819,if_helper78217820);
}};
$e1780617807.stack[R.EXN_STACKHEIGHT++] = $ss1781017811;
}
if(R.isPyretException($e1780617807)) {
$e1780617807.pyretStack.push(L[3164]);
}
throw $e1780617807;
}
var $ret1781217813 = $Hcont_tail_arg854517821($z1780817809,if_helper78217820);
++R.GAS;
return $ret1781217813;
} else {
var $z1782617827 = D;
var $f1783217833 = function(_) {
return R.isFunction(else_DASH_clause9117834)?else_DASH_clause9117834.app():R.ffi.throwNonFunApp(L[3164],else_DASH_clause9117834,[]);
};
try {
if(--R.GAS > 0) {
$z1782617827 = $f1783217833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1783217833,
"from":L[3164]});
}
} catch($e1782417825) {
if(R.isCont($e1782417825)) {
var $ss1782817829 = {"from":L[3164],
"go":function(cont_tail_arg78717835) {
return $Hcont_tail_arg854617836(cont_tail_arg78717835,if_helper78217820);
}};
$e1782417825.stack[R.EXN_STACKHEIGHT++] = $ss1782817829;
}
if(R.isPyretException($e1782417825)) {
$e1782417825.pyretStack.push(L[3164]);
}
throw $e1782417825;
}
var $ret1783017831 = $Hcont_tail_arg854617836($z1782617827,if_helper78217820);
++R.GAS;
return $ret1783017831;
}
} else {
var cont_tail_arg78417840 = R.throwNonBooleanCondition(L[3164],("if"),if_DASH_9317837);
if(--R.GAS > 0) {
$z1783817839 = R.isFunction(if_helper78217820)?if_helper78217820.app(cont_tail_arg78417840):R.ffi.throwNonFunApp(L[3164],if_helper78217820,[cont_tail_arg78417840]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper78217820)?if_helper78217820.app(cont_tail_arg78417840):R.ffi.throwNonFunApp(L[3164],if_helper78217820,[cont_tail_arg78417840]);
},
"from":L[3164]});
}
++R.GAS;
return $z1783817839;
}
};
},{"length":3});
var anf_variant_member80317644 = R.makeMethod(function(self9217804) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3164],0,arguments);
}
var anf_arg79517802 = G(self9217804,"l",L[3164]);
var $z1779417795 = D;
var $f1780017801 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg79517802):R.ffi.throwNonFunApp(L[3164],torepr65,[anf_arg79517802]);
};
try {
if(--R.GAS > 0) {
$z1779417795 = $f1780017801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1780017801,
"from":L[3164]});
}
} catch($e1779217793) {
if(R.isCont($e1779217793)) {
var $ss1779617797 = {"from":L[3164],
"go":function(anf_arg79617803) {
return $Hanf_arg855317805(anf_arg79617803,self9217804,_plus55,torepr65);
}};
$e1779217793.stack[R.EXN_STACKHEIGHT++] = $ss1779617797;
}
if(R.isPyretException($e1779217793)) {
$e1779217793.pyretStack.push(L[3164]);
}
throw $e1779217793;
}
var $ret1779817799 = $Hanf_arg855317805($z1779417795,self9217804,_plus55,torepr65);
++R.GAS;
return $ret1779817799;
};
},{"length":1});
var anf_variant_member80517645 = R.makeMethod(function(self59610891) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3183],0,arguments);
}
var ann_DASH_check_DASH_temp80417791 = ("a-provide-type");
return ann_DASH_check_DASH_temp80417791;
};
},{"length":1});
var anf_variant_member82417646 = R.makeMethod(function(self59717789) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3182],0,arguments);
}
var anf_fun80717788 = G(PP170,"surround-separate",L[3181]);
var $z1777917780 = D;
var $f1778517786 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_provide_DASH_types164754,break_DASH_one119168):R.ffi.throwNonFunApp(L[3180],_plus55,[str_DASH_provide_DASH_types164754,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z1777917780 = $f1778517786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1778517786,
"from":L[3180]});
}
} catch($e1777717778) {
if(R.isCont($e1777717778)) {
var $ss1778117782 = {"from":L[3180],
"go":function(anf_arg80817787) {
return $Hanf_arg856117790(anf_arg80817787,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55);
}};
$e1777717778.stack[R.EXN_STACKHEIGHT++] = $ss1778117782;
}
if(R.isPyretException($e1777717778)) {
$e1777717778.pyretStack.push(L[3180]);
}
throw $e1777717778;
}
var $ret1778317784 = $Hanf_arg856117790($z1777917780,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55);
++R.GAS;
return $ret1778317784;
};
},{"length":1});
var anf_variant_member83617654 = R.makeMethod(function(self9617755) {
return function(cases_DASH_funs9717756,else_DASH_clause9817767) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3163],2,arguments);
}
var if_DASH_10017770 = R.hasField(cases_DASH_funs9717756,("s-provide-types-all"));
var if_helper82617753 = R.makeFunction(function(if_helper_arg82717775) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3163],1,arguments);
}
var ann_DASH_check_DASH_temp82517776 = if_helper_arg82717775;
return ann_DASH_check_DASH_temp82517776;
});
var anf_if83017774 = R.isBoolean(if_DASH_10017770);
if(R.isPyretTrue(anf_if83017774)) {
if(R.isPyretTrue(if_DASH_10017770)) {
var call_DASH_s_DASH_provide_DASH_types_DASH_all9517750 = G(cases_DASH_funs9717756,"s-provide-types-all",L[3163]);
var anf_arg83317751 = G(self9617755,"l",L[3179]);
var $z1774217743 = D;
var $f1774817749 = function(_) {
return R.isFunction(call_DASH_s_DASH_provide_DASH_types_DASH_all9517750)?call_DASH_s_DASH_provide_DASH_types_DASH_all9517750.app(anf_arg83317751):R.ffi.throwNonFunApp(L[3163],call_DASH_s_DASH_provide_DASH_types_DASH_all9517750,[anf_arg83317751]);
};
try {
if(--R.GAS > 0) {
$z1774217743 = $f1774817749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1774817749,
"from":L[3163]});
}
} catch($e1774017741) {
if(R.isCont($e1774017741)) {
var $ss1774417745 = {"from":L[3163],
"go":function(cont_tail_arg83417752) {
return $Hcont_tail_arg856217754(cont_tail_arg83417752,if_helper82617753);
}};
$e1774017741.stack[R.EXN_STACKHEIGHT++] = $ss1774417745;
}
if(R.isPyretException($e1774017741)) {
$e1774017741.pyretStack.push(L[3163]);
}
throw $e1774017741;
}
var $ret1774617747 = $Hcont_tail_arg856217754($z1774217743,if_helper82617753);
++R.GAS;
return $ret1774617747;
} else {
var $z1775917760 = D;
var $f1776517766 = function(_) {
return R.isFunction(else_DASH_clause9817767)?else_DASH_clause9817767.app():R.ffi.throwNonFunApp(L[3163],else_DASH_clause9817767,[]);
};
try {
if(--R.GAS > 0) {
$z1775917760 = $f1776517766();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1776517766,
"from":L[3163]});
}
} catch($e1775717758) {
if(R.isCont($e1775717758)) {
var $ss1776117762 = {"from":L[3163],
"go":function(cont_tail_arg83117768) {
return $Hcont_tail_arg856317769(cont_tail_arg83117768,if_helper82617753);
}};
$e1775717758.stack[R.EXN_STACKHEIGHT++] = $ss1776117762;
}
if(R.isPyretException($e1775717758)) {
$e1775717758.pyretStack.push(L[3163]);
}
throw $e1775717758;
}
var $ret1776317764 = $Hcont_tail_arg856317769($z1775917760,if_helper82617753);
++R.GAS;
return $ret1776317764;
}
} else {
var cont_tail_arg82817773 = R.throwNonBooleanCondition(L[3163],("if"),if_DASH_10017770);
if(--R.GAS > 0) {
$z1777117772 = R.isFunction(if_helper82617753)?if_helper82617753.app(cont_tail_arg82817773):R.ffi.throwNonFunApp(L[3163],if_helper82617753,[cont_tail_arg82817773]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper82617753)?if_helper82617753.app(cont_tail_arg82817773):R.ffi.throwNonFunApp(L[3163],if_helper82617753,[cont_tail_arg82817773]);
},
"from":L[3163]});
}
++R.GAS;
return $z1777117772;
}
};
},{"length":3});
var anf_variant_member84217655 = R.makeMethod(function(self9917739) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3163],0,arguments);
}
var anf_arg83817736 = G(self9917739,"l",L[3163]);
var $z1772817729 = D;
var $f1773417735 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg83817736):R.ffi.throwNonFunApp(L[3163],torepr65,[anf_arg83817736]);
};
try {
if(--R.GAS > 0) {
$z1772817729 = $f1773417735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1773417735,
"from":L[3163]});
}
} catch($e1772617727) {
if(R.isCont($e1772617727)) {
var $ss1773017731 = {"from":L[3163],
"go":function(anf_arg83917737) {
return $Hanf_arg856717738(anf_arg83917737,_plus55);
}};
$e1772617727.stack[R.EXN_STACKHEIGHT++] = $ss1773017731;
}
if(R.isPyretException($e1772617727)) {
$e1772617727.pyretStack.push(L[3163]);
}
throw $e1772617727;
}
var $ret1773217733 = $Hanf_arg856717738($z1772817729,_plus55);
++R.GAS;
return $ret1773217733;
};
},{"length":1});
var anf_variant_member84417656 = R.makeMethod(function(self59917725) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3178],0,arguments);
}
var ann_DASH_check_DASH_temp84317724 = ("s-provide-types-all");
return ann_DASH_check_DASH_temp84317724;
};
},{"length":1});
var anf_variant_member84617657 = R.makeMethod(function(self60010840) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3177],0,arguments);
}
var ann_DASH_check_DASH_temp84517723 = str_DASH_provide_DASH_types_DASH_star166780;
return ann_DASH_check_DASH_temp84517723;
};
},{"length":1});
var anf_variant_member85817664 = R.makeMethod(function(self10217701) {
return function(cases_DASH_funs10317702,else_DASH_clause10417713) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3162],2,arguments);
}
var if_DASH_10617716 = R.hasField(cases_DASH_funs10317702,("s-provide-types-none"));
var if_helper84817699 = R.makeFunction(function(if_helper_arg84917721) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3162],1,arguments);
}
var ann_DASH_check_DASH_temp84717722 = if_helper_arg84917721;
return ann_DASH_check_DASH_temp84717722;
});
var anf_if85217720 = R.isBoolean(if_DASH_10617716);
if(R.isPyretTrue(anf_if85217720)) {
if(R.isPyretTrue(if_DASH_10617716)) {
var call_DASH_s_DASH_provide_DASH_types_DASH_none10117696 = G(cases_DASH_funs10317702,"s-provide-types-none",L[3162]);
var anf_arg85517697 = G(self10217701,"l",L[3176]);
var $z1768817689 = D;
var $f1769417695 = function(_) {
return R.isFunction(call_DASH_s_DASH_provide_DASH_types_DASH_none10117696)?call_DASH_s_DASH_provide_DASH_types_DASH_none10117696.app(anf_arg85517697):R.ffi.throwNonFunApp(L[3162],call_DASH_s_DASH_provide_DASH_types_DASH_none10117696,[anf_arg85517697]);
};
try {
if(--R.GAS > 0) {
$z1768817689 = $f1769417695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1769417695,
"from":L[3162]});
}
} catch($e1768617687) {
if(R.isCont($e1768617687)) {
var $ss1769017691 = {"from":L[3162],
"go":function(cont_tail_arg85617698) {
return $Hcont_tail_arg856817700(cont_tail_arg85617698,if_helper84817699);
}};
$e1768617687.stack[R.EXN_STACKHEIGHT++] = $ss1769017691;
}
if(R.isPyretException($e1768617687)) {
$e1768617687.pyretStack.push(L[3162]);
}
throw $e1768617687;
}
var $ret1769217693 = $Hcont_tail_arg856817700($z1768817689,if_helper84817699);
++R.GAS;
return $ret1769217693;
} else {
var $z1770517706 = D;
var $f1771117712 = function(_) {
return R.isFunction(else_DASH_clause10417713)?else_DASH_clause10417713.app():R.ffi.throwNonFunApp(L[3162],else_DASH_clause10417713,[]);
};
try {
if(--R.GAS > 0) {
$z1770517706 = $f1771117712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1771117712,
"from":L[3162]});
}
} catch($e1770317704) {
if(R.isCont($e1770317704)) {
var $ss1770717708 = {"from":L[3162],
"go":function(cont_tail_arg85317714) {
return $Hcont_tail_arg856917715(cont_tail_arg85317714,if_helper84817699);
}};
$e1770317704.stack[R.EXN_STACKHEIGHT++] = $ss1770717708;
}
if(R.isPyretException($e1770317704)) {
$e1770317704.pyretStack.push(L[3162]);
}
throw $e1770317704;
}
var $ret1770917710 = $Hcont_tail_arg856917715($z1770517706,if_helper84817699);
++R.GAS;
return $ret1770917710;
}
} else {
var cont_tail_arg85017719 = R.throwNonBooleanCondition(L[3162],("if"),if_DASH_10617716);
if(--R.GAS > 0) {
$z1771717718 = R.isFunction(if_helper84817699)?if_helper84817699.app(cont_tail_arg85017719):R.ffi.throwNonFunApp(L[3162],if_helper84817699,[cont_tail_arg85017719]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper84817699)?if_helper84817699.app(cont_tail_arg85017719):R.ffi.throwNonFunApp(L[3162],if_helper84817699,[cont_tail_arg85017719]);
},
"from":L[3162]});
}
++R.GAS;
return $z1771717718;
}
};
},{"length":3});
var anf_variant_member86417665 = R.makeMethod(function(self10517685) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3162],0,arguments);
}
var anf_arg86017682 = G(self10517685,"l",L[3162]);
var $z1767417675 = D;
var $f1768017681 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg86017682):R.ffi.throwNonFunApp(L[3162],torepr65,[anf_arg86017682]);
};
try {
if(--R.GAS > 0) {
$z1767417675 = $f1768017681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1768017681,
"from":L[3162]});
}
} catch($e1767217673) {
if(R.isCont($e1767217673)) {
var $ss1767617677 = {"from":L[3162],
"go":function(anf_arg86117683) {
return $Hanf_arg857317684(anf_arg86117683,_plus55);
}};
$e1767217673.stack[R.EXN_STACKHEIGHT++] = $ss1767617677;
}
if(R.isPyretException($e1767217673)) {
$e1767217673.pyretStack.push(L[3162]);
}
throw $e1767217673;
}
var $ret1767817679 = $Hanf_arg857317684($z1767417675,_plus55);
++R.GAS;
return $ret1767817679;
};
},{"length":1});
var anf_variant_member86617666 = R.makeMethod(function(self60217671) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3175],0,arguments);
}
var ann_DASH_check_DASH_temp86517670 = ("s-provide-types-none");
return ann_DASH_check_DASH_temp86517670;
};
},{"length":1});
var anf_variant_member86817667 = R.makeMethod(function(self60310821) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3174],0,arguments);
}
var ann_DASH_check_DASH_temp86717669 = G(PP170,"mt-doc",L[3173]);
return ann_DASH_check_DASH_temp86717669;
};
},{"length":1});
var anf_assign8691850 = (function() {
var $s_DASH_provide_DASH_types_DASH_base1763817639 = {"visit":anf_shared78017637,
"_match":anf_variant_member79317643,
"_torepr":anf_variant_member80317644,
"label":anf_variant_member80517645,
"tosource":anf_variant_member82417646};
var $s_DASH_provide_DASH_types_DASH_brands1764117642 = {"$brand-s-provide-types17640":true};
$s_DASH_provide_DASH_types_DASH_brands1764117642[ProvideTypesT575141._brand] = true
var $s_DASH_provide_DASH_types_DASH_all_DASH_base1764917650 = {"visit":anf_shared78017637,
"_match":anf_variant_member83617654,
"_torepr":anf_variant_member84217655,
"label":anf_variant_member84417656,
"tosource":anf_variant_member84617657};
var $s_DASH_provide_DASH_types_DASH_all_DASH_brands1765217653 = {"$brand-s-provide-types-all17651":true};
$s_DASH_provide_DASH_types_DASH_all_DASH_brands1765217653[ProvideTypesT575141._brand] = true
var $s_DASH_provide_DASH_types_DASH_none_DASH_base1765917660 = {"visit":anf_shared78017637,
"_match":anf_variant_member85817664,
"_torepr":anf_variant_member86417665,
"label":anf_variant_member86617666,
"tosource":anf_variant_member86817667};
var $s_DASH_provide_DASH_types_DASH_none_DASH_brands1766217663 = {"$brand-s-provide-types-none17661":true};
$s_DASH_provide_DASH_types_DASH_none_DASH_brands1766217663[ProvideTypesT575141._brand] = true
return R.makeObject({"ProvideTypes":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3165],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ProvideTypesT575141._brand));
}),
"is-s-provide-types":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3164],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-provide-types17640"));
}),
"s-provide-types":R.makeFunction(function(l59417647,ann59517648) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3166],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l59417647,ann59517648],[L[3167],L[3168]],function() {
var dict = R.create($s_DASH_provide_DASH_types_DASH_base1763817639);
dict["l"] = l59417647
dict["ann"] = ann59517648
return R.makeBrandedObject(dict,$s_DASH_provide_DASH_types_DASH_brands1764117642);
});
}),
"is-s-provide-types-all":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3163],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-provide-types-all17651"));
}),
"s-provide-types-all":R.makeFunction(function(l59817658) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3169],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l59817658],[L[3170]],function() {
var dict = R.create($s_DASH_provide_DASH_types_DASH_all_DASH_base1764917650);
dict["l"] = l59817658
return R.makeBrandedObject(dict,$s_DASH_provide_DASH_types_DASH_all_DASH_brands1765217653);
});
}),
"is-s-provide-types-none":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3162],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-provide-types-none17661"));
}),
"s-provide-types-none":R.makeFunction(function(l60117668) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3171],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l60117668],[L[3172]],function() {
var dict = R.create($s_DASH_provide_DASH_types_DASH_none_DASH_base1765917660);
dict["l"] = l60117668
return R.makeBrandedObject(dict,$s_DASH_provide_DASH_types_DASH_none_DASH_brands1766217663);
});
})});
})();
ProvideTypes302741849.$var = anf_assign8691850;
var anf_assign8701852 = G(ProvideTypes302741849.$var,"ProvideTypes",L[3165]);
ProvideTypes2751851.$var = anf_assign8701852;
var anf_assign8711854 = G(ProvideTypes302741849.$var,"ProvideTypes",L[3165]);
is_DASH_ProvideTypes2761853.$var = anf_assign8711854;
var anf_assign8721856 = G(ProvideTypes302741849.$var,"is-s-provide-types",L[3164]);
is_DASH_s_DASH_provide_DASH_types2771855.$var = anf_assign8721856;
var anf_assign8731858 = G(ProvideTypes302741849.$var,"s-provide-types",L[3164]);
s_DASH_provide_DASH_types2781857.$var = anf_assign8731858;
var anf_assign8741860 = G(ProvideTypes302741849.$var,"is-s-provide-types-all",L[3163]);
is_DASH_s_DASH_provide_DASH_types_DASH_all2791859.$var = anf_assign8741860;
var anf_assign8751862 = G(ProvideTypes302741849.$var,"s-provide-types-all",L[3163]);
s_DASH_provide_DASH_types_DASH_all2801861.$var = anf_assign8751862;
var anf_assign8761864 = G(ProvideTypes302741849.$var,"is-s-provide-types-none",L[3162]);
is_DASH_s_DASH_provide_DASH_types_DASH_none2811863.$var = anf_assign8761864;
var anf_assign8771866 = G(ProvideTypes302741849.$var,"s-provide-types-none",L[3162]);
s_DASH_provide_DASH_types_DASH_none2821865.$var = anf_assign8771866;
var anf_shared88517448 = R.makeMethod(function(self61417636) {
return function(visitor61517619) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3157],1,arguments);
}
var anf_fun87917618 = G(self61417636,"_match",L[3161]);
var anf_arg88417620 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3158],0,arguments);
}
var anf_fun88117633 = G(self61417636,"label",L[3160]);
var $z1762517626 = D;
var $f1763117632 = function(_) {
return R.isFunction(anf_fun88117633)?anf_fun88117633.app():R.ffi.throwNonFunApp(L[3159],anf_fun88117633,[]);
};
try {
if(--R.GAS > 0) {
$z1762517626 = $f1763117632();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1763117632,
"from":L[3159]});
}
} catch($e1762317624) {
if(R.isCont($e1762317624)) {
var $ss1762717628 = {"from":L[3159],
"go":function(anf_arg88217634) {
return $Hanf_arg857617635(anf_arg88217634,_plus55,raise62);
}};
$e1762317624.stack[R.EXN_STACKHEIGHT++] = $ss1762717628;
}
if(R.isPyretException($e1762317624)) {
$e1762317624.pyretStack.push(L[3159]);
}
throw $e1762317624;
}
var $ret1762917630 = $Hanf_arg857617635($z1762517626,_plus55,raise62);
++R.GAS;
return $ret1762917630;
});
var $z1761017611 = D;
var $f1761617617 = function(_) {
return R.isFunction(anf_fun87917618)?anf_fun87917618.app(visitor61517619,anf_arg88417620):R.ffi.throwNonFunApp(L[3157],anf_fun87917618,[visitor61517619,anf_arg88417620]);
};
try {
if(--R.GAS > 0) {
$z1761017611 = $f1761617617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1761617617,
"from":L[3157]});
}
} catch($e1760817609) {
if(R.isCont($e1760817609)) {
var $ss1761217613 = {"from":L[3157],
"go":function(ann_DASH_check_DASH_temp87817621) {
return $Hann_DASH_check_DASH_temp857717622(ann_DASH_check_DASH_temp87817621);
}};
$e1760817609.stack[R.EXN_STACKHEIGHT++] = $ss1761217613;
}
if(R.isPyretException($e1760817609)) {
$e1760817609.pyretStack.push(L[3157]);
}
throw $e1760817609;
}
var $ret1761417615 = $Hann_DASH_check_DASH_temp857717622($z1761017611);
++R.GAS;
return $ret1761417615;
};
},{"length":2});
var anf_variant_member89817454 = R.makeMethod(function(self10817586) {
return function(cases_DASH_funs10917587,else_DASH_clause11017598) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3136],2,arguments);
}
var if_DASH_11217601 = R.hasField(cases_DASH_funs10917587,("s-file-import"));
var if_helper88717584 = R.makeFunction(function(if_helper_arg88817606) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3136],1,arguments);
}
var ann_DASH_check_DASH_temp88617607 = if_helper_arg88817606;
return ann_DASH_check_DASH_temp88617607;
});
var anf_if89117605 = R.isBoolean(if_DASH_11217601);
if(R.isPyretTrue(anf_if89117605)) {
if(R.isPyretTrue(if_DASH_11217601)) {
var call_DASH_s_DASH_file_DASH_import10717580 = G(cases_DASH_funs10917587,"s-file-import",L[3136]);
var anf_arg89417581 = G(self10817586,"l",L[3156]);
var anf_arg89517582 = G(self10817586,"file",L[3155]);
var $z1757217573 = D;
var $f1757817579 = function(_) {
return R.isFunction(call_DASH_s_DASH_file_DASH_import10717580)?call_DASH_s_DASH_file_DASH_import10717580.app(anf_arg89417581,anf_arg89517582):R.ffi.throwNonFunApp(L[3136],call_DASH_s_DASH_file_DASH_import10717580,[anf_arg89417581,anf_arg89517582]);
};
try {
if(--R.GAS > 0) {
$z1757217573 = $f1757817579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1757817579,
"from":L[3136]});
}
} catch($e1757017571) {
if(R.isCont($e1757017571)) {
var $ss1757417575 = {"from":L[3136],
"go":function(cont_tail_arg89617583) {
return $Hcont_tail_arg857817585(cont_tail_arg89617583,if_helper88717584);
}};
$e1757017571.stack[R.EXN_STACKHEIGHT++] = $ss1757417575;
}
if(R.isPyretException($e1757017571)) {
$e1757017571.pyretStack.push(L[3136]);
}
throw $e1757017571;
}
var $ret1757617577 = $Hcont_tail_arg857817585($z1757217573,if_helper88717584);
++R.GAS;
return $ret1757617577;
} else {
var $z1759017591 = D;
var $f1759617597 = function(_) {
return R.isFunction(else_DASH_clause11017598)?else_DASH_clause11017598.app():R.ffi.throwNonFunApp(L[3136],else_DASH_clause11017598,[]);
};
try {
if(--R.GAS > 0) {
$z1759017591 = $f1759617597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1759617597,
"from":L[3136]});
}
} catch($e1758817589) {
if(R.isCont($e1758817589)) {
var $ss1759217593 = {"from":L[3136],
"go":function(cont_tail_arg89217599) {
return $Hcont_tail_arg857917600(cont_tail_arg89217599,if_helper88717584);
}};
$e1758817589.stack[R.EXN_STACKHEIGHT++] = $ss1759217593;
}
if(R.isPyretException($e1758817589)) {
$e1758817589.pyretStack.push(L[3136]);
}
throw $e1758817589;
}
var $ret1759417595 = $Hcont_tail_arg857917600($z1759017591,if_helper88717584);
++R.GAS;
return $ret1759417595;
}
} else {
var cont_tail_arg88917604 = R.throwNonBooleanCondition(L[3136],("if"),if_DASH_11217601);
if(--R.GAS > 0) {
$z1760217603 = R.isFunction(if_helper88717584)?if_helper88717584.app(cont_tail_arg88917604):R.ffi.throwNonFunApp(L[3136],if_helper88717584,[cont_tail_arg88917604]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper88717584)?if_helper88717584.app(cont_tail_arg88917604):R.ffi.throwNonFunApp(L[3136],if_helper88717584,[cont_tail_arg88917604]);
},
"from":L[3136]});
}
++R.GAS;
return $z1760217603;
}
};
},{"length":3});
var anf_variant_member90817455 = R.makeMethod(function(self11117568) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3136],0,arguments);
}
var anf_arg90017566 = G(self11117568,"l",L[3136]);
var $z1755817559 = D;
var $f1756417565 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg90017566):R.ffi.throwNonFunApp(L[3136],torepr65,[anf_arg90017566]);
};
try {
if(--R.GAS > 0) {
$z1755817559 = $f1756417565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1756417565,
"from":L[3136]});
}
} catch($e1755617557) {
if(R.isCont($e1755617557)) {
var $ss1756017561 = {"from":L[3136],
"go":function(anf_arg90117567) {
return $Hanf_arg858617569(anf_arg90117567,self11117568,_plus55,torepr65);
}};
$e1755617557.stack[R.EXN_STACKHEIGHT++] = $ss1756017561;
}
if(R.isPyretException($e1755617557)) {
$e1755617557.pyretStack.push(L[3136]);
}
throw $e1755617557;
}
var $ret1756217563 = $Hanf_arg858617569($z1755817559,self11117568,_plus55,torepr65);
++R.GAS;
return $ret1756217563;
};
},{"length":1});
var anf_variant_member91017456 = R.makeMethod(function(self60817555) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3154],0,arguments);
}
var ann_DASH_check_DASH_temp90917554 = ("s-file-import");
return ann_DASH_check_DASH_temp90917554;
};
},{"length":1});
var anf_variant_member91517457 = R.makeMethod(function(self60917553) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3153],0,arguments);
}
var anf_fun91217551 = G(PP170,"str",L[3152]);
var anf_arg91317549 = G(self60917553,"file",L[3151]);
var $z1754117542 = D;
var $f1754717548 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg91317549):R.ffi.throwNonFunApp(L[3150],torepr65,[anf_arg91317549]);
};
try {
if(--R.GAS > 0) {
$z1754117542 = $f1754717548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1754717548,
"from":L[3150]});
}
} catch($e1753917540) {
if(R.isCont($e1753917540)) {
var $ss1754317544 = {"from":L[3150],
"go":function(anf_arg91417550) {
return $Hanf_arg858817552(anf_arg91417550,anf_fun91217551);
}};
$e1753917540.stack[R.EXN_STACKHEIGHT++] = $ss1754317544;
}
if(R.isPyretException($e1753917540)) {
$e1753917540.pyretStack.push(L[3150]);
}
throw $e1753917540;
}
var $ret1754517546 = $Hanf_arg858817552($z1754117542,anf_fun91217551);
++R.GAS;
return $ret1754517546;
};
},{"length":1});
var anf_variant_member92817465 = R.makeMethod(function(self11417517) {
return function(cases_DASH_funs11517518,else_DASH_clause11617529) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3135],2,arguments);
}
var if_DASH_11817532 = R.hasField(cases_DASH_funs11517518,("s-const-import"));
var if_helper91717515 = R.makeFunction(function(if_helper_arg91817537) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3135],1,arguments);
}
var ann_DASH_check_DASH_temp91617538 = if_helper_arg91817537;
return ann_DASH_check_DASH_temp91617538;
});
var anf_if92117536 = R.isBoolean(if_DASH_11817532);
if(R.isPyretTrue(anf_if92117536)) {
if(R.isPyretTrue(if_DASH_11817532)) {
var call_DASH_s_DASH_const_DASH_import11317511 = G(cases_DASH_funs11517518,"s-const-import",L[3135]);
var anf_arg92417512 = G(self11417517,"l",L[3149]);
var anf_arg92517513 = G(self11417517,"mod",L[3148]);
var $z1750317504 = D;
var $f1750917510 = function(_) {
return R.isFunction(call_DASH_s_DASH_const_DASH_import11317511)?call_DASH_s_DASH_const_DASH_import11317511.app(anf_arg92417512,anf_arg92517513):R.ffi.throwNonFunApp(L[3135],call_DASH_s_DASH_const_DASH_import11317511,[anf_arg92417512,anf_arg92517513]);
};
try {
if(--R.GAS > 0) {
$z1750317504 = $f1750917510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1750917510,
"from":L[3135]});
}
} catch($e1750117502) {
if(R.isCont($e1750117502)) {
var $ss1750517506 = {"from":L[3135],
"go":function(cont_tail_arg92617514) {
return $Hcont_tail_arg858917516(cont_tail_arg92617514,if_helper91717515);
}};
$e1750117502.stack[R.EXN_STACKHEIGHT++] = $ss1750517506;
}
if(R.isPyretException($e1750117502)) {
$e1750117502.pyretStack.push(L[3135]);
}
throw $e1750117502;
}
var $ret1750717508 = $Hcont_tail_arg858917516($z1750317504,if_helper91717515);
++R.GAS;
return $ret1750717508;
} else {
var $z1752117522 = D;
var $f1752717528 = function(_) {
return R.isFunction(else_DASH_clause11617529)?else_DASH_clause11617529.app():R.ffi.throwNonFunApp(L[3135],else_DASH_clause11617529,[]);
};
try {
if(--R.GAS > 0) {
$z1752117522 = $f1752717528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1752717528,
"from":L[3135]});
}
} catch($e1751917520) {
if(R.isCont($e1751917520)) {
var $ss1752317524 = {"from":L[3135],
"go":function(cont_tail_arg92217530) {
return $Hcont_tail_arg859017531(cont_tail_arg92217530,if_helper91717515);
}};
$e1751917520.stack[R.EXN_STACKHEIGHT++] = $ss1752317524;
}
if(R.isPyretException($e1751917520)) {
$e1751917520.pyretStack.push(L[3135]);
}
throw $e1751917520;
}
var $ret1752517526 = $Hcont_tail_arg859017531($z1752117522,if_helper91717515);
++R.GAS;
return $ret1752517526;
}
} else {
var cont_tail_arg91917535 = R.throwNonBooleanCondition(L[3135],("if"),if_DASH_11817532);
if(--R.GAS > 0) {
$z1753317534 = R.isFunction(if_helper91717515)?if_helper91717515.app(cont_tail_arg91917535):R.ffi.throwNonFunApp(L[3135],if_helper91717515,[cont_tail_arg91917535]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper91717515)?if_helper91717515.app(cont_tail_arg91917535):R.ffi.throwNonFunApp(L[3135],if_helper91717515,[cont_tail_arg91917535]);
},
"from":L[3135]});
}
++R.GAS;
return $z1753317534;
}
};
},{"length":3});
var anf_variant_member93817466 = R.makeMethod(function(self11717499) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3135],0,arguments);
}
var anf_arg93017497 = G(self11717499,"l",L[3135]);
var $z1748917490 = D;
var $f1749517496 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg93017497):R.ffi.throwNonFunApp(L[3135],torepr65,[anf_arg93017497]);
};
try {
if(--R.GAS > 0) {
$z1748917490 = $f1749517496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1749517496,
"from":L[3135]});
}
} catch($e1748717488) {
if(R.isCont($e1748717488)) {
var $ss1749117492 = {"from":L[3135],
"go":function(anf_arg93117498) {
return $Hanf_arg859717500(anf_arg93117498,self11717499,_plus55,torepr65);
}};
$e1748717488.stack[R.EXN_STACKHEIGHT++] = $ss1749117492;
}
if(R.isPyretException($e1748717488)) {
$e1748717488.pyretStack.push(L[3135]);
}
throw $e1748717488;
}
var $ret1749317494 = $Hanf_arg859717500($z1748917490,self11717499,_plus55,torepr65);
++R.GAS;
return $ret1749317494;
};
},{"length":1});
var anf_variant_member94017467 = R.makeMethod(function(self61217486) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3147],0,arguments);
}
var ann_DASH_check_DASH_temp93917485 = ("s-const-import");
return ann_DASH_check_DASH_temp93917485;
};
},{"length":1});
var anf_variant_member94417468 = R.makeMethod(function(self61310644) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3144],0,arguments);
}
var anf_fun94217481 = G(PP170,"str",L[3146]);
var anf_arg94317482 = G(self61310644,"mod",L[3145]);
var $z1747317474 = D;
var $f1747917480 = function(_) {
return R.isFunction(anf_fun94217481)?anf_fun94217481.app(anf_arg94317482):R.ffi.throwNonFunApp(L[3144],anf_fun94217481,[anf_arg94317482]);
};
try {
if(--R.GAS > 0) {
$z1747317474 = $f1747917480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1747917480,
"from":L[3144]});
}
} catch($e1747117472) {
if(R.isCont($e1747117472)) {
var $ss1747517476 = {"from":L[3144],
"go":function(ann_DASH_check_DASH_temp94117483) {
return $Hann_DASH_check_DASH_temp859817484(ann_DASH_check_DASH_temp94117483);
}};
$e1747117472.stack[R.EXN_STACKHEIGHT++] = $ss1747517476;
}
if(R.isPyretException($e1747117472)) {
$e1747117472.pyretStack.push(L[3144]);
}
throw $e1747117472;
}
var $ret1747717478 = $Hann_DASH_check_DASH_temp859817484($z1747317474);
++R.GAS;
return $ret1747717478;
};
},{"length":1});
var anf_assign9451868 = (function() {
var $s_DASH_file_DASH_import_DASH_base1744917450 = {"visit":anf_shared88517448,
"_match":anf_variant_member89817454,
"_torepr":anf_variant_member90817455,
"label":anf_variant_member91017456,
"tosource":anf_variant_member91517457};
var $s_DASH_file_DASH_import_DASH_brands1745217453 = {"$brand-s-file-import17451":true};
$s_DASH_file_DASH_import_DASH_brands1745217453[ImportTypeT677124._brand] = true
var $s_DASH_const_DASH_import_DASH_base1746017461 = {"visit":anf_shared88517448,
"_match":anf_variant_member92817465,
"_torepr":anf_variant_member93817466,
"label":anf_variant_member94017467,
"tosource":anf_variant_member94417468};
var $s_DASH_const_DASH_import_DASH_brands1746317464 = {"$brand-s-const-import17462":true};
$s_DASH_const_DASH_import_DASH_brands1746317464[ImportTypeT677124._brand] = true
return R.makeObject({"ImportType":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3137],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ImportTypeT677124._brand));
}),
"is-s-file-import":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3136],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-file-import17451"));
}),
"s-file-import":R.makeFunction(function(l60617458,file60717459) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3138],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l60617458,file60717459],[L[3139],L[3140]],function() {
var dict = R.create($s_DASH_file_DASH_import_DASH_base1744917450);
dict["l"] = l60617458
dict["file"] = file60717459
return R.makeBrandedObject(dict,$s_DASH_file_DASH_import_DASH_brands1745217453);
});
}),
"is-s-const-import":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3135],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-const-import17462"));
}),
"s-const-import":R.makeFunction(function(l61017469,mod61117470) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3141],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l61017469,mod61117470],[L[3142],L[3143]],function() {
var dict = R.create($s_DASH_const_DASH_import_DASH_base1746017461);
dict["l"] = l61017469
dict["mod"] = mod61117470
return R.makeBrandedObject(dict,$s_DASH_const_DASH_import_DASH_brands1746317464);
});
})});
})();
ImportType312831867.$var = anf_assign9451868;
var anf_assign9461870 = G(ImportType312831867.$var,"ImportType",L[3137]);
ImportType2841869.$var = anf_assign9461870;
var anf_assign9471872 = G(ImportType312831867.$var,"ImportType",L[3137]);
is_DASH_ImportType2851871.$var = anf_assign9471872;
var anf_assign9481874 = G(ImportType312831867.$var,"is-s-file-import",L[3136]);
is_DASH_s_DASH_file_DASH_import2861873.$var = anf_assign9481874;
var anf_assign9491876 = G(ImportType312831867.$var,"s-file-import",L[3136]);
s_DASH_file_DASH_import2871875.$var = anf_assign9491876;
var anf_assign9501878 = G(ImportType312831867.$var,"is-s-const-import",L[3135]);
is_DASH_s_DASH_const_DASH_import2881877.$var = anf_assign9501878;
var anf_assign9511880 = G(ImportType312831867.$var,"s-const-import",L[3135]);
s_DASH_const_DASH_import2891879.$var = anf_assign9511880;
var anf_shared95917342 = R.makeMethod(function(self61817447) {
return function(visitor61917430) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3130],1,arguments);
}
var anf_fun95317429 = G(self61817447,"_match",L[3134]);
var anf_arg95817431 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3131],0,arguments);
}
var anf_fun95517444 = G(self61817447,"label",L[3133]);
var $z1743617437 = D;
var $f1744217443 = function(_) {
return R.isFunction(anf_fun95517444)?anf_fun95517444.app():R.ffi.throwNonFunApp(L[3132],anf_fun95517444,[]);
};
try {
if(--R.GAS > 0) {
$z1743617437 = $f1744217443();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1744217443,
"from":L[3132]});
}
} catch($e1743417435) {
if(R.isCont($e1743417435)) {
var $ss1743817439 = {"from":L[3132],
"go":function(anf_arg95617445) {
return $Hanf_arg860117446(anf_arg95617445,_plus55,raise62);
}};
$e1743417435.stack[R.EXN_STACKHEIGHT++] = $ss1743817439;
}
if(R.isPyretException($e1743417435)) {
$e1743417435.pyretStack.push(L[3132]);
}
throw $e1743417435;
}
var $ret1744017441 = $Hanf_arg860117446($z1743617437,_plus55,raise62);
++R.GAS;
return $ret1744017441;
});
var $z1742117422 = D;
var $f1742717428 = function(_) {
return R.isFunction(anf_fun95317429)?anf_fun95317429.app(visitor61917430,anf_arg95817431):R.ffi.throwNonFunApp(L[3130],anf_fun95317429,[visitor61917430,anf_arg95817431]);
};
try {
if(--R.GAS > 0) {
$z1742117422 = $f1742717428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1742717428,
"from":L[3130]});
}
} catch($e1741917420) {
if(R.isCont($e1741917420)) {
var $ss1742317424 = {"from":L[3130],
"go":function(ann_DASH_check_DASH_temp95217432) {
return $Hann_DASH_check_DASH_temp860217433(ann_DASH_check_DASH_temp95217432);
}};
$e1741917420.stack[R.EXN_STACKHEIGHT++] = $ss1742317424;
}
if(R.isPyretException($e1741917420)) {
$e1741917420.pyretStack.push(L[3130]);
}
throw $e1741917420;
}
var $ret1742517426 = $Hann_DASH_check_DASH_temp860217433($z1742117422);
++R.GAS;
return $ret1742517426;
};
},{"length":2});
var anf_variant_member97117348 = R.makeMethod(function(self12017397) {
return function(cases_DASH_funs12117398,else_DASH_clause12217409) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3120],2,arguments);
}
var if_DASH_12417412 = R.hasField(cases_DASH_funs12117398,("h-use-loc"));
var if_helper96117395 = R.makeFunction(function(if_helper_arg96217417) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3120],1,arguments);
}
var ann_DASH_check_DASH_temp96017418 = if_helper_arg96217417;
return ann_DASH_check_DASH_temp96017418;
});
var anf_if96517416 = R.isBoolean(if_DASH_12417412);
if(R.isPyretTrue(anf_if96517416)) {
if(R.isPyretTrue(if_DASH_12417412)) {
var call_DASH_h_DASH_use_DASH_loc11917392 = G(cases_DASH_funs12117398,"h-use-loc",L[3120]);
var anf_arg96817393 = G(self12017397,"l",L[3129]);
var $z1738417385 = D;
var $f1739017391 = function(_) {
return R.isFunction(call_DASH_h_DASH_use_DASH_loc11917392)?call_DASH_h_DASH_use_DASH_loc11917392.app(anf_arg96817393):R.ffi.throwNonFunApp(L[3120],call_DASH_h_DASH_use_DASH_loc11917392,[anf_arg96817393]);
};
try {
if(--R.GAS > 0) {
$z1738417385 = $f1739017391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1739017391,
"from":L[3120]});
}
} catch($e1738217383) {
if(R.isCont($e1738217383)) {
var $ss1738617387 = {"from":L[3120],
"go":function(cont_tail_arg96917394) {
return $Hcont_tail_arg860317396(cont_tail_arg96917394,if_helper96117395);
}};
$e1738217383.stack[R.EXN_STACKHEIGHT++] = $ss1738617387;
}
if(R.isPyretException($e1738217383)) {
$e1738217383.pyretStack.push(L[3120]);
}
throw $e1738217383;
}
var $ret1738817389 = $Hcont_tail_arg860317396($z1738417385,if_helper96117395);
++R.GAS;
return $ret1738817389;
} else {
var $z1740117402 = D;
var $f1740717408 = function(_) {
return R.isFunction(else_DASH_clause12217409)?else_DASH_clause12217409.app():R.ffi.throwNonFunApp(L[3120],else_DASH_clause12217409,[]);
};
try {
if(--R.GAS > 0) {
$z1740117402 = $f1740717408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1740717408,
"from":L[3120]});
}
} catch($e1739917400) {
if(R.isCont($e1739917400)) {
var $ss1740317404 = {"from":L[3120],
"go":function(cont_tail_arg96617410) {
return $Hcont_tail_arg860417411(cont_tail_arg96617410,if_helper96117395);
}};
$e1739917400.stack[R.EXN_STACKHEIGHT++] = $ss1740317404;
}
if(R.isPyretException($e1739917400)) {
$e1739917400.pyretStack.push(L[3120]);
}
throw $e1739917400;
}
var $ret1740517406 = $Hcont_tail_arg860417411($z1740117402,if_helper96117395);
++R.GAS;
return $ret1740517406;
}
} else {
var cont_tail_arg96317415 = R.throwNonBooleanCondition(L[3120],("if"),if_DASH_12417412);
if(--R.GAS > 0) {
$z1741317414 = R.isFunction(if_helper96117395)?if_helper96117395.app(cont_tail_arg96317415):R.ffi.throwNonFunApp(L[3120],if_helper96117395,[cont_tail_arg96317415]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper96117395)?if_helper96117395.app(cont_tail_arg96317415):R.ffi.throwNonFunApp(L[3120],if_helper96117395,[cont_tail_arg96317415]);
},
"from":L[3120]});
}
++R.GAS;
return $z1741317414;
}
};
},{"length":3});
var anf_variant_member97717349 = R.makeMethod(function(self12317381) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3120],0,arguments);
}
var anf_arg97317378 = G(self12317381,"l",L[3120]);
var $z1737017371 = D;
var $f1737617377 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg97317378):R.ffi.throwNonFunApp(L[3120],torepr65,[anf_arg97317378]);
};
try {
if(--R.GAS > 0) {
$z1737017371 = $f1737617377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1737617377,
"from":L[3120]});
}
} catch($e1736817369) {
if(R.isCont($e1736817369)) {
var $ss1737217373 = {"from":L[3120],
"go":function(anf_arg97417379) {
return $Hanf_arg860817380(anf_arg97417379,_plus55);
}};
$e1736817369.stack[R.EXN_STACKHEIGHT++] = $ss1737217373;
}
if(R.isPyretException($e1736817369)) {
$e1736817369.pyretStack.push(L[3120]);
}
throw $e1736817369;
}
var $ret1737417375 = $Hanf_arg860817380($z1737017371,_plus55);
++R.GAS;
return $ret1737417375;
};
},{"length":1});
var anf_variant_member98517350 = R.makeMethod(function(self61717367) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3128],0,arguments);
}
var anf_fun97917364 = G(PP170,"parens",L[3127]);
var anf_fun98017365 = G(PP170,"str",L[3126]);
var anf_arg98117362 = G(self61717367,"l",L[3125]);
var $z1735417355 = D;
var $f1736017361 = function(_) {
return R.isFunction(tostring66)?tostring66.app(anf_arg98117362):R.ffi.throwNonFunApp(L[3124],tostring66,[anf_arg98117362]);
};
try {
if(--R.GAS > 0) {
$z1735417355 = $f1736017361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1736017361,
"from":L[3124]});
}
} catch($e1735217353) {
if(R.isCont($e1735217353)) {
var $ss1735617357 = {"from":L[3124],
"go":function(anf_arg98217363) {
return $Hanf_arg861217366(anf_arg98217363,anf_fun97917364,anf_fun98017365,str_DASH_use_DASH_loc174884,_plus55);
}};
$e1735217353.stack[R.EXN_STACKHEIGHT++] = $ss1735617357;
}
if(R.isPyretException($e1735217353)) {
$e1735217353.pyretStack.push(L[3124]);
}
throw $e1735217353;
}
var $ret1735817359 = $Hanf_arg861217366($z1735417355,anf_fun97917364,anf_fun98017365,str_DASH_use_DASH_loc174884,_plus55);
++R.GAS;
return $ret1735817359;
};
},{"length":1});
var anf_assign9861882 = (function() {
var $h_DASH_use_DASH_loc_DASH_base1734317344 = {"visit":anf_shared95917342,
"_match":anf_variant_member97117348,
"_torepr":anf_variant_member97717349,
"tosource":anf_variant_member98517350};
var $h_DASH_use_DASH_loc_DASH_brands1734617347 = {"$brand-h-use-loc17345":true};
$h_DASH_use_DASH_loc_DASH_brands1734617347[HintT779116._brand] = true
return R.makeObject({"Hint":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3121],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,HintT779116._brand));
}),
"is-h-use-loc":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3120],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-h-use-loc17345"));
}),
"h-use-loc":R.makeFunction(function(l61617351) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3122],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l61617351],[L[3123]],function() {
var dict = R.create($h_DASH_use_DASH_loc_DASH_base1734317344);
dict["l"] = l61617351
return R.makeBrandedObject(dict,$h_DASH_use_DASH_loc_DASH_brands1734617347);
});
})});
})();
Hint322901881.$var = anf_assign9861882;
var anf_assign9871884 = G(Hint322901881.$var,"Hint",L[3121]);
Hint2911883.$var = anf_assign9871884;
var anf_assign9881886 = G(Hint322901881.$var,"Hint",L[3121]);
is_DASH_Hint2921885.$var = anf_assign9881886;
var anf_assign9891888 = G(Hint322901881.$var,"is-h-use-loc",L[3120]);
is_DASH_h_DASH_use_DASH_loc2931887.$var = anf_assign9891888;
var anf_assign9901890 = G(Hint322901881.$var,"h-use-loc",L[3120]);
h_DASH_use_DASH_loc2941889.$var = anf_assign9901890;
var anf_shared99817152 = R.makeMethod(function(self62810390) {
return function(visitor62917325) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3115],1,arguments);
}
var anf_fun99217324 = G(self62810390,"_match",L[3119]);
var anf_arg99717326 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3116],0,arguments);
}
var anf_fun99417339 = G(self62810390,"label",L[3118]);
var $z1733117332 = D;
var $f1733717338 = function(_) {
return R.isFunction(anf_fun99417339)?anf_fun99417339.app():R.ffi.throwNonFunApp(L[3117],anf_fun99417339,[]);
};
try {
if(--R.GAS > 0) {
$z1733117332 = $f1733717338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1733717338,
"from":L[3117]});
}
} catch($e1732917330) {
if(R.isCont($e1732917330)) {
var $ss1733317334 = {"from":L[3117],
"go":function(anf_arg99517340) {
return $Hanf_arg861517341(anf_arg99517340,_plus55,raise62);
}};
$e1732917330.stack[R.EXN_STACKHEIGHT++] = $ss1733317334;
}
if(R.isPyretException($e1732917330)) {
$e1732917330.pyretStack.push(L[3117]);
}
throw $e1732917330;
}
var $ret1733517336 = $Hanf_arg861517341($z1733117332,_plus55,raise62);
++R.GAS;
return $ret1733517336;
});
var $z1731617317 = D;
var $f1732217323 = function(_) {
return R.isFunction(anf_fun99217324)?anf_fun99217324.app(visitor62917325,anf_arg99717326):R.ffi.throwNonFunApp(L[3115],anf_fun99217324,[visitor62917325,anf_arg99717326]);
};
try {
if(--R.GAS > 0) {
$z1731617317 = $f1732217323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1732217323,
"from":L[3115]});
}
} catch($e1731417315) {
if(R.isCont($e1731417315)) {
var $ss1731817319 = {"from":L[3115],
"go":function(ann_DASH_check_DASH_temp99117327) {
return $Hann_DASH_check_DASH_temp861617328(ann_DASH_check_DASH_temp99117327);
}};
$e1731417315.stack[R.EXN_STACKHEIGHT++] = $ss1731817319;
}
if(R.isPyretException($e1731417315)) {
$e1731417315.pyretStack.push(L[3115]);
}
throw $e1731417315;
}
var $ret1732017321 = $Hann_DASH_check_DASH_temp861617328($z1731617317);
++R.GAS;
return $ret1732017321;
};
},{"length":2});
var anf_variant_member101217158 = R.makeMethod(function(self12617292) {
return function(cases_DASH_funs12717293,else_DASH_clause12817304) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3088],2,arguments);
}
var if_DASH_13017307 = R.hasField(cases_DASH_funs12717293,("s-let-bind"));
var if_helper100017290 = R.makeFunction(function(if_helper_arg100117312) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3088],1,arguments);
}
var ann_DASH_check_DASH_temp99917313 = if_helper_arg100117312;
return ann_DASH_check_DASH_temp99917313;
});
var anf_if100417311 = R.isBoolean(if_DASH_13017307);
if(R.isPyretTrue(anf_if100417311)) {
if(R.isPyretTrue(if_DASH_13017307)) {
var call_DASH_s_DASH_let_DASH_bind12517285 = G(cases_DASH_funs12717293,"s-let-bind",L[3088]);
var anf_arg100717286 = G(self12617292,"l",L[3114]);
var anf_arg100817287 = G(self12617292,"b",L[3113]);
var anf_arg100917288 = G(self12617292,"value",L[3112]);
var $z1727717278 = D;
var $f1728317284 = function(_) {
return R.isFunction(call_DASH_s_DASH_let_DASH_bind12517285)?call_DASH_s_DASH_let_DASH_bind12517285.app(anf_arg100717286,anf_arg100817287,anf_arg100917288):R.ffi.throwNonFunApp(L[3088],call_DASH_s_DASH_let_DASH_bind12517285,[anf_arg100717286,anf_arg100817287,anf_arg100917288]);
};
try {
if(--R.GAS > 0) {
$z1727717278 = $f1728317284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1728317284,
"from":L[3088]});
}
} catch($e1727517276) {
if(R.isCont($e1727517276)) {
var $ss1727917280 = {"from":L[3088],
"go":function(cont_tail_arg101017289) {
return $Hcont_tail_arg861717291(cont_tail_arg101017289,if_helper100017290);
}};
$e1727517276.stack[R.EXN_STACKHEIGHT++] = $ss1727917280;
}
if(R.isPyretException($e1727517276)) {
$e1727517276.pyretStack.push(L[3088]);
}
throw $e1727517276;
}
var $ret1728117282 = $Hcont_tail_arg861717291($z1727717278,if_helper100017290);
++R.GAS;
return $ret1728117282;
} else {
var $z1729617297 = D;
var $f1730217303 = function(_) {
return R.isFunction(else_DASH_clause12817304)?else_DASH_clause12817304.app():R.ffi.throwNonFunApp(L[3088],else_DASH_clause12817304,[]);
};
try {
if(--R.GAS > 0) {
$z1729617297 = $f1730217303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1730217303,
"from":L[3088]});
}
} catch($e1729417295) {
if(R.isCont($e1729417295)) {
var $ss1729817299 = {"from":L[3088],
"go":function(cont_tail_arg100517305) {
return $Hcont_tail_arg861817306(cont_tail_arg100517305,if_helper100017290);
}};
$e1729417295.stack[R.EXN_STACKHEIGHT++] = $ss1729817299;
}
if(R.isPyretException($e1729417295)) {
$e1729417295.pyretStack.push(L[3088]);
}
throw $e1729417295;
}
var $ret1730017301 = $Hcont_tail_arg861817306($z1729617297,if_helper100017290);
++R.GAS;
return $ret1730017301;
}
} else {
var cont_tail_arg100217310 = R.throwNonBooleanCondition(L[3088],("if"),if_DASH_13017307);
if(--R.GAS > 0) {
$z1730817309 = R.isFunction(if_helper100017290)?if_helper100017290.app(cont_tail_arg100217310):R.ffi.throwNonFunApp(L[3088],if_helper100017290,[cont_tail_arg100217310]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper100017290)?if_helper100017290.app(cont_tail_arg100217310):R.ffi.throwNonFunApp(L[3088],if_helper100017290,[cont_tail_arg100217310]);
},
"from":L[3088]});
}
++R.GAS;
return $z1730817309;
}
};
},{"length":3});
var anf_variant_member102617159 = R.makeMethod(function(self12917273) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3088],0,arguments);
}
var anf_arg101417271 = G(self12917273,"l",L[3088]);
var $z1726317264 = D;
var $f1726917270 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg101417271):R.ffi.throwNonFunApp(L[3088],torepr65,[anf_arg101417271]);
};
try {
if(--R.GAS > 0) {
$z1726317264 = $f1726917270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1726917270,
"from":L[3088]});
}
} catch($e1726117262) {
if(R.isCont($e1726117262)) {
var $ss1726517266 = {"from":L[3088],
"go":function(anf_arg101517272) {
return $Hanf_arg862817274(anf_arg101517272,self12917273,_plus55,torepr65);
}};
$e1726117262.stack[R.EXN_STACKHEIGHT++] = $ss1726517266;
}
if(R.isPyretException($e1726117262)) {
$e1726117262.pyretStack.push(L[3088]);
}
throw $e1726117262;
}
var $ret1726717268 = $Hanf_arg862817274($z1726317264,self12917273,_plus55,torepr65);
++R.GAS;
return $ret1726717268;
};
},{"length":1});
var anf_variant_member104017160 = R.makeMethod(function(self62317258) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3111],0,arguments);
}
var anf_fun102817256 = G(PP170,"group",L[3110]);
var anf_fun102917257 = G(PP170,"nest",L[3109]);
var anf_bracket103017260 = G(self62317258,"b",L[3108]);
var anf_fun103117254 = G(anf_bracket103017260,"tosource",L[3107]);
var $z1724617247 = D;
var $f1725217253 = function(_) {
return R.isFunction(anf_fun103117254)?anf_fun103117254.app():R.ffi.throwNonFunApp(L[3106],anf_fun103117254,[]);
};
try {
if(--R.GAS > 0) {
$z1724617247 = $f1725217253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1725217253,
"from":L[3106]});
}
} catch($e1724417245) {
if(R.isCont($e1724417245)) {
var $ss1724817249 = {"from":L[3106],
"go":function(anf_arg103217255) {
return $Hanf_arg863517259(anf_arg103217255,INDENT118169,anf_fun102817256,anf_fun102917257,break_DASH_one119168,self62317258,str_DASH_spaceequal170832,_plus55);
}};
$e1724417245.stack[R.EXN_STACKHEIGHT++] = $ss1724817249;
}
if(R.isPyretException($e1724417245)) {
$e1724417245.pyretStack.push(L[3106]);
}
throw $e1724417245;
}
var $ret1725017251 = $Hanf_arg863517259($z1724617247,INDENT118169,anf_fun102817256,anf_fun102917257,break_DASH_one119168,self62317258,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret1725017251;
};
},{"length":1});
var anf_variant_member105417169 = R.makeMethod(function(self13217222) {
return function(cases_DASH_funs13317223,else_DASH_clause13417234) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3087],2,arguments);
}
var if_DASH_13617237 = R.hasField(cases_DASH_funs13317223,("s-var-bind"));
var if_helper104217220 = R.makeFunction(function(if_helper_arg104317242) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3087],1,arguments);
}
var ann_DASH_check_DASH_temp104117243 = if_helper_arg104317242;
return ann_DASH_check_DASH_temp104117243;
});
var anf_if104617241 = R.isBoolean(if_DASH_13617237);
if(R.isPyretTrue(anf_if104617241)) {
if(R.isPyretTrue(if_DASH_13617237)) {
var call_DASH_s_DASH_var_DASH_bind13117215 = G(cases_DASH_funs13317223,"s-var-bind",L[3087]);
var anf_arg104917216 = G(self13217222,"l",L[3105]);
var anf_arg105017217 = G(self13217222,"b",L[3104]);
var anf_arg105117218 = G(self13217222,"value",L[3103]);
var $z1720717208 = D;
var $f1721317214 = function(_) {
return R.isFunction(call_DASH_s_DASH_var_DASH_bind13117215)?call_DASH_s_DASH_var_DASH_bind13117215.app(anf_arg104917216,anf_arg105017217,anf_arg105117218):R.ffi.throwNonFunApp(L[3087],call_DASH_s_DASH_var_DASH_bind13117215,[anf_arg104917216,anf_arg105017217,anf_arg105117218]);
};
try {
if(--R.GAS > 0) {
$z1720717208 = $f1721317214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1721317214,
"from":L[3087]});
}
} catch($e1720517206) {
if(R.isCont($e1720517206)) {
var $ss1720917210 = {"from":L[3087],
"go":function(cont_tail_arg105217219) {
return $Hcont_tail_arg863617221(cont_tail_arg105217219,if_helper104217220);
}};
$e1720517206.stack[R.EXN_STACKHEIGHT++] = $ss1720917210;
}
if(R.isPyretException($e1720517206)) {
$e1720517206.pyretStack.push(L[3087]);
}
throw $e1720517206;
}
var $ret1721117212 = $Hcont_tail_arg863617221($z1720717208,if_helper104217220);
++R.GAS;
return $ret1721117212;
} else {
var $z1722617227 = D;
var $f1723217233 = function(_) {
return R.isFunction(else_DASH_clause13417234)?else_DASH_clause13417234.app():R.ffi.throwNonFunApp(L[3087],else_DASH_clause13417234,[]);
};
try {
if(--R.GAS > 0) {
$z1722617227 = $f1723217233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1723217233,
"from":L[3087]});
}
} catch($e1722417225) {
if(R.isCont($e1722417225)) {
var $ss1722817229 = {"from":L[3087],
"go":function(cont_tail_arg104717235) {
return $Hcont_tail_arg863717236(cont_tail_arg104717235,if_helper104217220);
}};
$e1722417225.stack[R.EXN_STACKHEIGHT++] = $ss1722817229;
}
if(R.isPyretException($e1722417225)) {
$e1722417225.pyretStack.push(L[3087]);
}
throw $e1722417225;
}
var $ret1723017231 = $Hcont_tail_arg863717236($z1722617227,if_helper104217220);
++R.GAS;
return $ret1723017231;
}
} else {
var cont_tail_arg104417240 = R.throwNonBooleanCondition(L[3087],("if"),if_DASH_13617237);
if(--R.GAS > 0) {
$z1723817239 = R.isFunction(if_helper104217220)?if_helper104217220.app(cont_tail_arg104417240):R.ffi.throwNonFunApp(L[3087],if_helper104217220,[cont_tail_arg104417240]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper104217220)?if_helper104217220.app(cont_tail_arg104417240):R.ffi.throwNonFunApp(L[3087],if_helper104217220,[cont_tail_arg104417240]);
},
"from":L[3087]});
}
++R.GAS;
return $z1723817239;
}
};
},{"length":3});
var anf_variant_member106817170 = R.makeMethod(function(self13517203) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3087],0,arguments);
}
var anf_arg105617201 = G(self13517203,"l",L[3087]);
var $z1719317194 = D;
var $f1719917200 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg105617201):R.ffi.throwNonFunApp(L[3087],torepr65,[anf_arg105617201]);
};
try {
if(--R.GAS > 0) {
$z1719317194 = $f1719917200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1719917200,
"from":L[3087]});
}
} catch($e1719117192) {
if(R.isCont($e1719117192)) {
var $ss1719517196 = {"from":L[3087],
"go":function(anf_arg105717202) {
return $Hanf_arg864717204(anf_arg105717202,self13517203,_plus55,torepr65);
}};
$e1719117192.stack[R.EXN_STACKHEIGHT++] = $ss1719517196;
}
if(R.isPyretException($e1719117192)) {
$e1719117192.pyretStack.push(L[3087]);
}
throw $e1719117192;
}
var $ret1719717198 = $Hanf_arg864717204($z1719317194,self13517203,_plus55,torepr65);
++R.GAS;
return $ret1719717198;
};
},{"length":1});
var anf_variant_member108517171 = R.makeMethod(function(self62717189) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3102],0,arguments);
}
var anf_fun107017187 = G(PP170,"group",L[3101]);
var anf_fun107117188 = G(PP170,"nest",L[3100]);
var anf_fun107217185 = G(PP170,"str",L[3099]);
var $z1717717178 = D;
var $f1718317184 = function(_) {
return R.isFunction(anf_fun107217185)?anf_fun107217185.app(("var ")):R.ffi.throwNonFunApp(L[3098],anf_fun107217185,[("var ")]);
};
try {
if(--R.GAS > 0) {
$z1717717178 = $f1718317184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1718317184,
"from":L[3098]});
}
} catch($e1717517176) {
if(R.isCont($e1717517176)) {
var $ss1717917180 = {"from":L[3098],
"go":function(anf_arg107317186) {
return $Hanf_arg865617190(anf_arg107317186,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55);
}};
$e1717517176.stack[R.EXN_STACKHEIGHT++] = $ss1717917180;
}
if(R.isPyretException($e1717517176)) {
$e1717517176.pyretStack.push(L[3098]);
}
throw $e1717517176;
}
var $ret1718117182 = $Hanf_arg865617190($z1717717178,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret1718117182;
};
},{"length":1});
var anf_assign10861892 = (function() {
var $s_DASH_let_DASH_bind_DASH_base1715317154 = {"visit":anf_shared99817152,
"_match":anf_variant_member101217158,
"_torepr":anf_variant_member102617159,
"tosource":anf_variant_member104017160};
var $s_DASH_let_DASH_bind_DASH_brands1715617157 = {"$brand-s-let-bind17155":true};
$s_DASH_let_DASH_bind_DASH_brands1715617157[LetBindT881126._brand] = true
var $s_DASH_var_DASH_bind_DASH_base1716417165 = {"visit":anf_shared99817152,
"_match":anf_variant_member105417169,
"_torepr":anf_variant_member106817170,
"tosource":anf_variant_member108517171};
var $s_DASH_var_DASH_bind_DASH_brands1716717168 = {"$brand-s-var-bind17166":true};
$s_DASH_var_DASH_bind_DASH_brands1716717168[LetBindT881126._brand] = true
return R.makeObject({"LetBind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3089],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,LetBindT881126._brand));
}),
"is-s-let-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3088],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-let-bind17155"));
}),
"s-let-bind":R.makeFunction(function(l62017161,b62117162,value62217163) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[3090],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l62017161,b62117162,value62217163],[L[3091],L[3092],L[3093]],function() {
var dict = R.create($s_DASH_let_DASH_bind_DASH_base1715317154);
dict["l"] = l62017161
dict["b"] = b62117162
dict["value"] = value62217163
return R.makeBrandedObject(dict,$s_DASH_let_DASH_bind_DASH_brands1715617157);
});
}),
"is-s-var-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3087],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-var-bind17166"));
}),
"s-var-bind":R.makeFunction(function(l62417172,b62517173,value62617174) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[3094],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l62417172,b62517173,value62617174],[L[3095],L[3096],L[3097]],function() {
var dict = R.create($s_DASH_var_DASH_bind_DASH_base1716417165);
dict["l"] = l62417172
dict["b"] = b62517173
dict["value"] = value62617174
return R.makeBrandedObject(dict,$s_DASH_var_DASH_bind_DASH_brands1716717168);
});
})});
})();
LetBind332951891.$var = anf_assign10861892;
var anf_assign10871894 = G(LetBind332951891.$var,"LetBind",L[3089]);
LetBind2961893.$var = anf_assign10871894;
var anf_assign10881896 = G(LetBind332951891.$var,"LetBind",L[3089]);
is_DASH_LetBind2971895.$var = anf_assign10881896;
var anf_assign10891898 = G(LetBind332951891.$var,"is-s-let-bind",L[3088]);
is_DASH_s_DASH_let_DASH_bind2981897.$var = anf_assign10891898;
var anf_assign10901900 = G(LetBind332951891.$var,"s-let-bind",L[3088]);
s_DASH_let_DASH_bind2991899.$var = anf_assign10901900;
var anf_assign10911902 = G(LetBind332951891.$var,"is-s-var-bind",L[3087]);
is_DASH_s_DASH_var_DASH_bind3001901.$var = anf_assign10911902;
var anf_assign10921904 = G(LetBind332951891.$var,"s-var-bind",L[3087]);
s_DASH_var_DASH_bind3011903.$var = anf_assign10921904;
var anf_shared110017042 = R.makeMethod(function(self63410279) {
return function(visitor63517135) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3082],1,arguments);
}
var anf_fun109417134 = G(self63410279,"_match",L[3086]);
var anf_arg109917136 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3083],0,arguments);
}
var anf_fun109617149 = G(self63410279,"label",L[3085]);
var $z1714117142 = D;
var $f1714717148 = function(_) {
return R.isFunction(anf_fun109617149)?anf_fun109617149.app():R.ffi.throwNonFunApp(L[3084],anf_fun109617149,[]);
};
try {
if(--R.GAS > 0) {
$z1714117142 = $f1714717148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1714717148,
"from":L[3084]});
}
} catch($e1713917140) {
if(R.isCont($e1713917140)) {
var $ss1714317144 = {"from":L[3084],
"go":function(anf_arg109717150) {
return $Hanf_arg865917151(anf_arg109717150,_plus55,raise62);
}};
$e1713917140.stack[R.EXN_STACKHEIGHT++] = $ss1714317144;
}
if(R.isPyretException($e1713917140)) {
$e1713917140.pyretStack.push(L[3084]);
}
throw $e1713917140;
}
var $ret1714517146 = $Hanf_arg865917151($z1714117142,_plus55,raise62);
++R.GAS;
return $ret1714517146;
});
var $z1712617127 = D;
var $f1713217133 = function(_) {
return R.isFunction(anf_fun109417134)?anf_fun109417134.app(visitor63517135,anf_arg109917136):R.ffi.throwNonFunApp(L[3082],anf_fun109417134,[visitor63517135,anf_arg109917136]);
};
try {
if(--R.GAS > 0) {
$z1712617127 = $f1713217133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1713217133,
"from":L[3082]});
}
} catch($e1712417125) {
if(R.isCont($e1712417125)) {
var $ss1712817129 = {"from":L[3082],
"go":function(ann_DASH_check_DASH_temp109317137) {
return $Hann_DASH_check_DASH_temp866017138(ann_DASH_check_DASH_temp109317137);
}};
$e1712417125.stack[R.EXN_STACKHEIGHT++] = $ss1712817129;
}
if(R.isPyretException($e1712417125)) {
$e1712417125.pyretStack.push(L[3082]);
}
throw $e1712417125;
}
var $ret1713017131 = $Hann_DASH_check_DASH_temp866017138($z1712617127);
++R.GAS;
return $ret1713017131;
};
},{"length":2});
var anf_variant_member111417048 = R.makeMethod(function(self13817102) {
return function(cases_DASH_funs13917103,else_DASH_clause14017114) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3067],2,arguments);
}
var if_DASH_14217117 = R.hasField(cases_DASH_funs13917103,("s-letrec-bind"));
var if_helper110217100 = R.makeFunction(function(if_helper_arg110317122) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3067],1,arguments);
}
var ann_DASH_check_DASH_temp110117123 = if_helper_arg110317122;
return ann_DASH_check_DASH_temp110117123;
});
var anf_if110617121 = R.isBoolean(if_DASH_14217117);
if(R.isPyretTrue(anf_if110617121)) {
if(R.isPyretTrue(if_DASH_14217117)) {
var call_DASH_s_DASH_letrec_DASH_bind13717095 = G(cases_DASH_funs13917103,"s-letrec-bind",L[3067]);
var anf_arg110917096 = G(self13817102,"l",L[3081]);
var anf_arg111017097 = G(self13817102,"b",L[3080]);
var anf_arg111117098 = G(self13817102,"value",L[3079]);
var $z1708717088 = D;
var $f1709317094 = function(_) {
return R.isFunction(call_DASH_s_DASH_letrec_DASH_bind13717095)?call_DASH_s_DASH_letrec_DASH_bind13717095.app(anf_arg110917096,anf_arg111017097,anf_arg111117098):R.ffi.throwNonFunApp(L[3067],call_DASH_s_DASH_letrec_DASH_bind13717095,[anf_arg110917096,anf_arg111017097,anf_arg111117098]);
};
try {
if(--R.GAS > 0) {
$z1708717088 = $f1709317094();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1709317094,
"from":L[3067]});
}
} catch($e1708517086) {
if(R.isCont($e1708517086)) {
var $ss1708917090 = {"from":L[3067],
"go":function(cont_tail_arg111217099) {
return $Hcont_tail_arg866117101(cont_tail_arg111217099,if_helper110217100);
}};
$e1708517086.stack[R.EXN_STACKHEIGHT++] = $ss1708917090;
}
if(R.isPyretException($e1708517086)) {
$e1708517086.pyretStack.push(L[3067]);
}
throw $e1708517086;
}
var $ret1709117092 = $Hcont_tail_arg866117101($z1708717088,if_helper110217100);
++R.GAS;
return $ret1709117092;
} else {
var $z1710617107 = D;
var $f1711217113 = function(_) {
return R.isFunction(else_DASH_clause14017114)?else_DASH_clause14017114.app():R.ffi.throwNonFunApp(L[3067],else_DASH_clause14017114,[]);
};
try {
if(--R.GAS > 0) {
$z1710617107 = $f1711217113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1711217113,
"from":L[3067]});
}
} catch($e1710417105) {
if(R.isCont($e1710417105)) {
var $ss1710817109 = {"from":L[3067],
"go":function(cont_tail_arg110717115) {
return $Hcont_tail_arg866217116(cont_tail_arg110717115,if_helper110217100);
}};
$e1710417105.stack[R.EXN_STACKHEIGHT++] = $ss1710817109;
}
if(R.isPyretException($e1710417105)) {
$e1710417105.pyretStack.push(L[3067]);
}
throw $e1710417105;
}
var $ret1711017111 = $Hcont_tail_arg866217116($z1710617107,if_helper110217100);
++R.GAS;
return $ret1711017111;
}
} else {
var cont_tail_arg110417120 = R.throwNonBooleanCondition(L[3067],("if"),if_DASH_14217117);
if(--R.GAS > 0) {
$z1711817119 = R.isFunction(if_helper110217100)?if_helper110217100.app(cont_tail_arg110417120):R.ffi.throwNonFunApp(L[3067],if_helper110217100,[cont_tail_arg110417120]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper110217100)?if_helper110217100.app(cont_tail_arg110417120):R.ffi.throwNonFunApp(L[3067],if_helper110217100,[cont_tail_arg110417120]);
},
"from":L[3067]});
}
++R.GAS;
return $z1711817119;
}
};
},{"length":3});
var anf_variant_member112817049 = R.makeMethod(function(self14117083) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3067],0,arguments);
}
var anf_arg111617081 = G(self14117083,"l",L[3067]);
var $z1707317074 = D;
var $f1707917080 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg111617081):R.ffi.throwNonFunApp(L[3067],torepr65,[anf_arg111617081]);
};
try {
if(--R.GAS > 0) {
$z1707317074 = $f1707917080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1707917080,
"from":L[3067]});
}
} catch($e1707117072) {
if(R.isCont($e1707117072)) {
var $ss1707517076 = {"from":L[3067],
"go":function(anf_arg111717082) {
return $Hanf_arg867217084(anf_arg111717082,self14117083,_plus55,torepr65);
}};
$e1707117072.stack[R.EXN_STACKHEIGHT++] = $ss1707517076;
}
if(R.isPyretException($e1707117072)) {
$e1707117072.pyretStack.push(L[3067]);
}
throw $e1707117072;
}
var $ret1707717078 = $Hanf_arg867217084($z1707317074,self14117083,_plus55,torepr65);
++R.GAS;
return $ret1707717078;
};
},{"length":1});
var anf_variant_member114217050 = R.makeMethod(function(self63317068) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3078],0,arguments);
}
var anf_fun113017066 = G(PP170,"group",L[3077]);
var anf_fun113117067 = G(PP170,"nest",L[3076]);
var anf_bracket113217070 = G(self63317068,"b",L[3075]);
var anf_fun113317064 = G(anf_bracket113217070,"tosource",L[3074]);
var $z1705617057 = D;
var $f1706217063 = function(_) {
return R.isFunction(anf_fun113317064)?anf_fun113317064.app():R.ffi.throwNonFunApp(L[3073],anf_fun113317064,[]);
};
try {
if(--R.GAS > 0) {
$z1705617057 = $f1706217063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1706217063,
"from":L[3073]});
}
} catch($e1705417055) {
if(R.isCont($e1705417055)) {
var $ss1705817059 = {"from":L[3073],
"go":function(anf_arg113417065) {
return $Hanf_arg867917069(anf_arg113417065,INDENT118169,anf_fun113017066,anf_fun113117067,break_DASH_one119168,self63317068,str_DASH_spaceequal170832,_plus55);
}};
$e1705417055.stack[R.EXN_STACKHEIGHT++] = $ss1705817059;
}
if(R.isPyretException($e1705417055)) {
$e1705417055.pyretStack.push(L[3073]);
}
throw $e1705417055;
}
var $ret1706017061 = $Hanf_arg867917069($z1705617057,INDENT118169,anf_fun113017066,anf_fun113117067,break_DASH_one119168,self63317068,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret1706017061;
};
},{"length":1});
var anf_assign11431906 = (function() {
var $s_DASH_letrec_DASH_bind_DASH_base1704317044 = {"visit":anf_shared110017042,
"_match":anf_variant_member111417048,
"_torepr":anf_variant_member112817049,
"tosource":anf_variant_member114217050};
var $s_DASH_letrec_DASH_bind_DASH_brands1704617047 = {"$brand-s-letrec-bind17045":true};
$s_DASH_letrec_DASH_bind_DASH_brands1704617047[LetrecBindT983128._brand] = true
return R.makeObject({"LetrecBind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3068],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,LetrecBindT983128._brand));
}),
"is-s-letrec-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3067],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-letrec-bind17045"));
}),
"s-letrec-bind":R.makeFunction(function(l63017051,b63117052,value63217053) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[3069],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l63017051,b63117052,value63217053],[L[3070],L[3071],L[3072]],function() {
var dict = R.create($s_DASH_letrec_DASH_bind_DASH_base1704317044);
dict["l"] = l63017051
dict["b"] = b63117052
dict["value"] = value63217053
return R.makeBrandedObject(dict,$s_DASH_letrec_DASH_bind_DASH_brands1704617047);
});
})});
})();
LetrecBind343021905.$var = anf_assign11431906;
var anf_assign11441908 = G(LetrecBind343021905.$var,"LetrecBind",L[3068]);
LetrecBind3031907.$var = anf_assign11441908;
var anf_assign11451910 = G(LetrecBind343021905.$var,"LetrecBind",L[3068]);
is_DASH_LetrecBind3041909.$var = anf_assign11451910;
var anf_assign11461912 = G(LetrecBind343021905.$var,"is-s-letrec-bind",L[3067]);
is_DASH_s_DASH_letrec_DASH_bind3051911.$var = anf_assign11461912;
var anf_assign11471914 = G(LetrecBind343021905.$var,"s-letrec-bind",L[3067]);
s_DASH_letrec_DASH_bind3061913.$var = anf_assign11471914;
var anf_shared115516846 = R.makeMethod(function(self64610056) {
return function(visitor64717025) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3062],1,arguments);
}
var anf_fun114917024 = G(self64610056,"_match",L[3066]);
var anf_arg115417026 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3063],0,arguments);
}
var anf_fun115117039 = G(self64610056,"label",L[3065]);
var $z1703117032 = D;
var $f1703717038 = function(_) {
return R.isFunction(anf_fun115117039)?anf_fun115117039.app():R.ffi.throwNonFunApp(L[3064],anf_fun115117039,[]);
};
try {
if(--R.GAS > 0) {
$z1703117032 = $f1703717038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1703717038,
"from":L[3064]});
}
} catch($e1702917030) {
if(R.isCont($e1702917030)) {
var $ss1703317034 = {"from":L[3064],
"go":function(anf_arg115217040) {
return $Hanf_arg868217041(anf_arg115217040,_plus55,raise62);
}};
$e1702917030.stack[R.EXN_STACKHEIGHT++] = $ss1703317034;
}
if(R.isPyretException($e1702917030)) {
$e1702917030.pyretStack.push(L[3064]);
}
throw $e1702917030;
}
var $ret1703517036 = $Hanf_arg868217041($z1703117032,_plus55,raise62);
++R.GAS;
return $ret1703517036;
});
var $z1701617017 = D;
var $f1702217023 = function(_) {
return R.isFunction(anf_fun114917024)?anf_fun114917024.app(visitor64717025,anf_arg115417026):R.ffi.throwNonFunApp(L[3062],anf_fun114917024,[visitor64717025,anf_arg115417026]);
};
try {
if(--R.GAS > 0) {
$z1701617017 = $f1702217023();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1702217023,
"from":L[3062]});
}
} catch($e1701417015) {
if(R.isCont($e1701417015)) {
var $ss1701817019 = {"from":L[3062],
"go":function(ann_DASH_check_DASH_temp114817027) {
return $Hann_DASH_check_DASH_temp868317028(ann_DASH_check_DASH_temp114817027);
}};
$e1701417015.stack[R.EXN_STACKHEIGHT++] = $ss1701817019;
}
if(R.isPyretException($e1701417015)) {
$e1701417015.pyretStack.push(L[3062]);
}
throw $e1701417015;
}
var $ret1702017021 = $Hann_DASH_check_DASH_temp868317028($z1701617017);
++R.GAS;
return $ret1702017021;
};
},{"length":2});
var anf_variant_member116916852 = R.makeMethod(function(self14416992) {
return function(cases_DASH_funs14516993,else_DASH_clause14617004) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3032],2,arguments);
}
var if_DASH_14817007 = R.hasField(cases_DASH_funs14516993,("s-type-bind"));
var if_helper115716990 = R.makeFunction(function(if_helper_arg115817012) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3032],1,arguments);
}
var ann_DASH_check_DASH_temp115617013 = if_helper_arg115817012;
return ann_DASH_check_DASH_temp115617013;
});
var anf_if116117011 = R.isBoolean(if_DASH_14817007);
if(R.isPyretTrue(anf_if116117011)) {
if(R.isPyretTrue(if_DASH_14817007)) {
var call_DASH_s_DASH_type_DASH_bind14316985 = G(cases_DASH_funs14516993,"s-type-bind",L[3032]);
var anf_arg116416986 = G(self14416992,"l",L[3061]);
var anf_arg116516987 = G(self14416992,"name",L[3060]);
var anf_arg116616988 = G(self14416992,"ann",L[3059]);
var $z1697716978 = D;
var $f1698316984 = function(_) {
return R.isFunction(call_DASH_s_DASH_type_DASH_bind14316985)?call_DASH_s_DASH_type_DASH_bind14316985.app(anf_arg116416986,anf_arg116516987,anf_arg116616988):R.ffi.throwNonFunApp(L[3032],call_DASH_s_DASH_type_DASH_bind14316985,[anf_arg116416986,anf_arg116516987,anf_arg116616988]);
};
try {
if(--R.GAS > 0) {
$z1697716978 = $f1698316984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1698316984,
"from":L[3032]});
}
} catch($e1697516976) {
if(R.isCont($e1697516976)) {
var $ss1697916980 = {"from":L[3032],
"go":function(cont_tail_arg116716989) {
return $Hcont_tail_arg868416991(cont_tail_arg116716989,if_helper115716990);
}};
$e1697516976.stack[R.EXN_STACKHEIGHT++] = $ss1697916980;
}
if(R.isPyretException($e1697516976)) {
$e1697516976.pyretStack.push(L[3032]);
}
throw $e1697516976;
}
var $ret1698116982 = $Hcont_tail_arg868416991($z1697716978,if_helper115716990);
++R.GAS;
return $ret1698116982;
} else {
var $z1699616997 = D;
var $f1700217003 = function(_) {
return R.isFunction(else_DASH_clause14617004)?else_DASH_clause14617004.app():R.ffi.throwNonFunApp(L[3032],else_DASH_clause14617004,[]);
};
try {
if(--R.GAS > 0) {
$z1699616997 = $f1700217003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1700217003,
"from":L[3032]});
}
} catch($e1699416995) {
if(R.isCont($e1699416995)) {
var $ss1699816999 = {"from":L[3032],
"go":function(cont_tail_arg116217005) {
return $Hcont_tail_arg868517006(cont_tail_arg116217005,if_helper115716990);
}};
$e1699416995.stack[R.EXN_STACKHEIGHT++] = $ss1699816999;
}
if(R.isPyretException($e1699416995)) {
$e1699416995.pyretStack.push(L[3032]);
}
throw $e1699416995;
}
var $ret1700017001 = $Hcont_tail_arg868517006($z1699616997,if_helper115716990);
++R.GAS;
return $ret1700017001;
}
} else {
var cont_tail_arg115917010 = R.throwNonBooleanCondition(L[3032],("if"),if_DASH_14817007);
if(--R.GAS > 0) {
$z1700817009 = R.isFunction(if_helper115716990)?if_helper115716990.app(cont_tail_arg115917010):R.ffi.throwNonFunApp(L[3032],if_helper115716990,[cont_tail_arg115917010]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper115716990)?if_helper115716990.app(cont_tail_arg115917010):R.ffi.throwNonFunApp(L[3032],if_helper115716990,[cont_tail_arg115917010]);
},
"from":L[3032]});
}
++R.GAS;
return $z1700817009;
}
};
},{"length":3});
var anf_variant_member118316853 = R.makeMethod(function(self14716973) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3032],0,arguments);
}
var anf_arg117116971 = G(self14716973,"l",L[3032]);
var $z1696316964 = D;
var $f1696916970 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg117116971):R.ffi.throwNonFunApp(L[3032],torepr65,[anf_arg117116971]);
};
try {
if(--R.GAS > 0) {
$z1696316964 = $f1696916970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1696916970,
"from":L[3032]});
}
} catch($e1696116962) {
if(R.isCont($e1696116962)) {
var $ss1696516966 = {"from":L[3032],
"go":function(anf_arg117216972) {
return $Hanf_arg869516974(anf_arg117216972,self14716973,_plus55,torepr65);
}};
$e1696116962.stack[R.EXN_STACKHEIGHT++] = $ss1696516966;
}
if(R.isPyretException($e1696116962)) {
$e1696116962.pyretStack.push(L[3032]);
}
throw $e1696116962;
}
var $ret1696716968 = $Hanf_arg869516974($z1696316964,self14716973,_plus55,torepr65);
++R.GAS;
return $ret1696716968;
};
},{"length":1});
var anf_variant_member118516854 = R.makeMethod(function(self63916960) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3058],0,arguments);
}
var ann_DASH_check_DASH_temp118416959 = ("s-type-bind");
return ann_DASH_check_DASH_temp118416959;
};
},{"length":1});
var anf_variant_member119916855 = R.makeMethod(function(self64010167) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3057],0,arguments);
}
var anf_fun118716955 = G(PP170,"group",L[3056]);
var anf_fun118816956 = G(PP170,"nest",L[3055]);
var anf_bracket118916958 = G(self64010167,"name",L[3054]);
var anf_fun119016953 = G(anf_bracket118916958,"tosource",L[3053]);
var $z1694516946 = D;
var $f1695116952 = function(_) {
return R.isFunction(anf_fun119016953)?anf_fun119016953.app():R.ffi.throwNonFunApp(L[3052],anf_fun119016953,[]);
};
try {
if(--R.GAS > 0) {
$z1694516946 = $f1695116952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1695116952,
"from":L[3052]});
}
} catch($e1694316944) {
if(R.isCont($e1694316944)) {
var $ss1694716948 = {"from":L[3052],
"go":function(anf_arg119116954) {
return $Hanf_arg870216957(anf_arg119116954,INDENT118169,anf_fun118716955,anf_fun118816956,break_DASH_one119168,self64010167,str_DASH_spaceequal170832,_plus55);
}};
$e1694316944.stack[R.EXN_STACKHEIGHT++] = $ss1694716948;
}
if(R.isPyretException($e1694316944)) {
$e1694316944.pyretStack.push(L[3052]);
}
throw $e1694316944;
}
var $ret1694916950 = $Hanf_arg870216957($z1694516946,INDENT118169,anf_fun118716955,anf_fun118816956,break_DASH_one119168,self64010167,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret1694916950;
};
},{"length":1});
var anf_variant_member121316864 = R.makeMethod(function(self15016921) {
return function(cases_DASH_funs15116922,else_DASH_clause15216933) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3031],2,arguments);
}
var if_DASH_15416936 = R.hasField(cases_DASH_funs15116922,("s-newtype-bind"));
var if_helper120116919 = R.makeFunction(function(if_helper_arg120216941) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3031],1,arguments);
}
var ann_DASH_check_DASH_temp120016942 = if_helper_arg120216941;
return ann_DASH_check_DASH_temp120016942;
});
var anf_if120516940 = R.isBoolean(if_DASH_15416936);
if(R.isPyretTrue(anf_if120516940)) {
if(R.isPyretTrue(if_DASH_15416936)) {
var call_DASH_s_DASH_newtype_DASH_bind14916914 = G(cases_DASH_funs15116922,"s-newtype-bind",L[3031]);
var anf_arg120816915 = G(self15016921,"l",L[3051]);
var anf_arg120916916 = G(self15016921,"name",L[3050]);
var anf_arg121016917 = G(self15016921,"namet",L[3049]);
var $z1690616907 = D;
var $f1691216913 = function(_) {
return R.isFunction(call_DASH_s_DASH_newtype_DASH_bind14916914)?call_DASH_s_DASH_newtype_DASH_bind14916914.app(anf_arg120816915,anf_arg120916916,anf_arg121016917):R.ffi.throwNonFunApp(L[3031],call_DASH_s_DASH_newtype_DASH_bind14916914,[anf_arg120816915,anf_arg120916916,anf_arg121016917]);
};
try {
if(--R.GAS > 0) {
$z1690616907 = $f1691216913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1691216913,
"from":L[3031]});
}
} catch($e1690416905) {
if(R.isCont($e1690416905)) {
var $ss1690816909 = {"from":L[3031],
"go":function(cont_tail_arg121116918) {
return $Hcont_tail_arg870316920(cont_tail_arg121116918,if_helper120116919);
}};
$e1690416905.stack[R.EXN_STACKHEIGHT++] = $ss1690816909;
}
if(R.isPyretException($e1690416905)) {
$e1690416905.pyretStack.push(L[3031]);
}
throw $e1690416905;
}
var $ret1691016911 = $Hcont_tail_arg870316920($z1690616907,if_helper120116919);
++R.GAS;
return $ret1691016911;
} else {
var $z1692516926 = D;
var $f1693116932 = function(_) {
return R.isFunction(else_DASH_clause15216933)?else_DASH_clause15216933.app():R.ffi.throwNonFunApp(L[3031],else_DASH_clause15216933,[]);
};
try {
if(--R.GAS > 0) {
$z1692516926 = $f1693116932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1693116932,
"from":L[3031]});
}
} catch($e1692316924) {
if(R.isCont($e1692316924)) {
var $ss1692716928 = {"from":L[3031],
"go":function(cont_tail_arg120616934) {
return $Hcont_tail_arg870416935(cont_tail_arg120616934,if_helper120116919);
}};
$e1692316924.stack[R.EXN_STACKHEIGHT++] = $ss1692716928;
}
if(R.isPyretException($e1692316924)) {
$e1692316924.pyretStack.push(L[3031]);
}
throw $e1692316924;
}
var $ret1692916930 = $Hcont_tail_arg870416935($z1692516926,if_helper120116919);
++R.GAS;
return $ret1692916930;
}
} else {
var cont_tail_arg120316939 = R.throwNonBooleanCondition(L[3031],("if"),if_DASH_15416936);
if(--R.GAS > 0) {
$z1693716938 = R.isFunction(if_helper120116919)?if_helper120116919.app(cont_tail_arg120316939):R.ffi.throwNonFunApp(L[3031],if_helper120116919,[cont_tail_arg120316939]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper120116919)?if_helper120116919.app(cont_tail_arg120316939):R.ffi.throwNonFunApp(L[3031],if_helper120116919,[cont_tail_arg120316939]);
},
"from":L[3031]});
}
++R.GAS;
return $z1693716938;
}
};
},{"length":3});
var anf_variant_member122716865 = R.makeMethod(function(self15316902) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3031],0,arguments);
}
var anf_arg121516900 = G(self15316902,"l",L[3031]);
var $z1689216893 = D;
var $f1689816899 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg121516900):R.ffi.throwNonFunApp(L[3031],torepr65,[anf_arg121516900]);
};
try {
if(--R.GAS > 0) {
$z1689216893 = $f1689816899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1689816899,
"from":L[3031]});
}
} catch($e1689016891) {
if(R.isCont($e1689016891)) {
var $ss1689416895 = {"from":L[3031],
"go":function(anf_arg121616901) {
return $Hanf_arg871416903(anf_arg121616901,self15316902,_plus55,torepr65);
}};
$e1689016891.stack[R.EXN_STACKHEIGHT++] = $ss1689416895;
}
if(R.isPyretException($e1689016891)) {
$e1689016891.pyretStack.push(L[3031]);
}
throw $e1689016891;
}
var $ret1689616897 = $Hanf_arg871416903($z1689216893,self15316902,_plus55,torepr65);
++R.GAS;
return $ret1689616897;
};
},{"length":1});
var anf_variant_member122916866 = R.makeMethod(function(self64416889) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3048],0,arguments);
}
var ann_DASH_check_DASH_temp122816888 = ("s-newtype-bind");
return ann_DASH_check_DASH_temp122816888;
};
},{"length":1});
var anf_variant_member124516867 = R.makeMethod(function(self64516885) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3047],0,arguments);
}
var anf_fun123116883 = G(PP170,"group",L[3046]);
var anf_fun123216884 = G(PP170,"nest",L[3045]);
var anf_bracket123316887 = G(self64516885,"name",L[3044]);
var anf_fun123416881 = G(anf_bracket123316887,"tosource",L[3043]);
var $z1687316874 = D;
var $f1687916880 = function(_) {
return R.isFunction(anf_fun123416881)?anf_fun123416881.app():R.ffi.throwNonFunApp(L[3042],anf_fun123416881,[]);
};
try {
if(--R.GAS > 0) {
$z1687316874 = $f1687916880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1687916880,
"from":L[3042]});
}
} catch($e1687116872) {
if(R.isCont($e1687116872)) {
var $ss1687516876 = {"from":L[3042],
"go":function(anf_arg123516882) {
return $Hanf_arg872316886(anf_arg123516882,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,str_DASH_newtype176910,_plus55);
}};
$e1687116872.stack[R.EXN_STACKHEIGHT++] = $ss1687516876;
}
if(R.isPyretException($e1687116872)) {
$e1687116872.pyretStack.push(L[3042]);
}
throw $e1687116872;
}
var $ret1687716878 = $Hanf_arg872316886($z1687316874,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,str_DASH_newtype176910,_plus55);
++R.GAS;
return $ret1687716878;
};
},{"length":1});
var anf_assign12461916 = (function() {
var $s_DASH_type_DASH_bind_DASH_base1684716848 = {"visit":anf_shared115516846,
"_match":anf_variant_member116916852,
"_torepr":anf_variant_member118316853,
"label":anf_variant_member118516854,
"tosource":anf_variant_member119916855};
var $s_DASH_type_DASH_bind_DASH_brands1685016851 = {"$brand-s-type-bind16849":true};
$s_DASH_type_DASH_bind_DASH_brands1685016851[TypeLetBindT1085143._brand] = true
var $s_DASH_newtype_DASH_bind_DASH_base1685916860 = {"visit":anf_shared115516846,
"_match":anf_variant_member121316864,
"_torepr":anf_variant_member122716865,
"label":anf_variant_member122916866,
"tosource":anf_variant_member124516867};
var $s_DASH_newtype_DASH_bind_DASH_brands1686216863 = {"$brand-s-newtype-bind16861":true};
$s_DASH_newtype_DASH_bind_DASH_brands1686216863[TypeLetBindT1085143._brand] = true
return R.makeObject({"TypeLetBind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3033],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,TypeLetBindT1085143._brand));
}),
"is-s-type-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3032],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-type-bind16849"));
}),
"s-type-bind":R.makeFunction(function(l63616856,name63716857,ann63816858) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[3034],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Ann11299],[l63616856,name63716857,ann63816858],[L[3035],L[3036],L[3037]],function() {
var dict = R.create($s_DASH_type_DASH_bind_DASH_base1684716848);
dict["l"] = l63616856
dict["name"] = name63716857
dict["ann"] = ann63816858
return R.makeBrandedObject(dict,$s_DASH_type_DASH_bind_DASH_brands1685016851);
});
}),
"is-s-newtype-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3031],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-newtype-bind16861"));
}),
"s-newtype-bind":R.makeFunction(function(l64116868,name64216869,namet64316870) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[3038],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Name66133],[l64116868,name64216869,namet64316870],[L[3039],L[3040],L[3041]],function() {
var dict = R.create($s_DASH_newtype_DASH_bind_DASH_base1685916860);
dict["l"] = l64116868
dict["name"] = name64216869
dict["namet"] = namet64316870
return R.makeBrandedObject(dict,$s_DASH_newtype_DASH_bind_DASH_brands1686216863);
});
})});
})();
TypeLetBind353071915.$var = anf_assign12461916;
var anf_assign12471918 = G(TypeLetBind353071915.$var,"TypeLetBind",L[3033]);
TypeLetBind3081917.$var = anf_assign12471918;
var anf_assign12481920 = G(TypeLetBind353071915.$var,"TypeLetBind",L[3033]);
is_DASH_TypeLetBind3091919.$var = anf_assign12481920;
var anf_assign12491922 = G(TypeLetBind353071915.$var,"is-s-type-bind",L[3032]);
is_DASH_s_DASH_type_DASH_bind3101921.$var = anf_assign12491922;
var anf_assign12501924 = G(TypeLetBind353071915.$var,"s-type-bind",L[3032]);
s_DASH_type_DASH_bind3111923.$var = anf_assign12501924;
var anf_assign12511926 = G(TypeLetBind353071915.$var,"is-s-newtype-bind",L[3031]);
is_DASH_s_DASH_newtype_DASH_bind3121925.$var = anf_assign12511926;
var anf_assign12521928 = G(TypeLetBind353071915.$var,"s-newtype-bind",L[3031]);
s_DASH_newtype_DASH_bind3131927.$var = anf_assign12521928;
var anf_shared126012040 = R.makeMethod(function(self100116845) {
return function(visitor100216828) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3026],1,arguments);
}
var anf_fun125416827 = G(self100116845,"_match",L[3030]);
var anf_arg125916829 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3027],0,arguments);
}
var anf_fun125616842 = G(self100116845,"label",L[3029]);
var $z1683416835 = D;
var $f1684016841 = function(_) {
return R.isFunction(anf_fun125616842)?anf_fun125616842.app():R.ffi.throwNonFunApp(L[3028],anf_fun125616842,[]);
};
try {
if(--R.GAS > 0) {
$z1683416835 = $f1684016841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1684016841,
"from":L[3028]});
}
} catch($e1683216833) {
if(R.isCont($e1683216833)) {
var $ss1683616837 = {"from":L[3028],
"go":function(anf_arg125716843) {
return $Hanf_arg872616844(anf_arg125716843,_plus55,raise62);
}};
$e1683216833.stack[R.EXN_STACKHEIGHT++] = $ss1683616837;
}
if(R.isPyretException($e1683216833)) {
$e1683216833.pyretStack.push(L[3028]);
}
throw $e1683216833;
}
var $ret1683816839 = $Hanf_arg872616844($z1683416835,_plus55,raise62);
++R.GAS;
return $ret1683816839;
});
var $z1681916820 = D;
var $f1682516826 = function(_) {
return R.isFunction(anf_fun125416827)?anf_fun125416827.app(visitor100216828,anf_arg125916829):R.ffi.throwNonFunApp(L[3026],anf_fun125416827,[visitor100216828,anf_arg125916829]);
};
try {
if(--R.GAS > 0) {
$z1681916820 = $f1682516826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1682516826,
"from":L[3026]});
}
} catch($e1681716818) {
if(R.isCont($e1681716818)) {
var $ss1682116822 = {"from":L[3026],
"go":function(ann_DASH_check_DASH_temp125316830) {
return $Hann_DASH_check_DASH_temp872716831(ann_DASH_check_DASH_temp125316830);
}};
$e1681716818.stack[R.EXN_STACKHEIGHT++] = $ss1682116822;
}
if(R.isPyretException($e1681716818)) {
$e1681716818.pyretStack.push(L[3026]);
}
throw $e1681716818;
}
var $ret1682316824 = $Hann_DASH_check_DASH_temp872716831($z1681916820);
++R.GAS;
return $ret1682316824;
};
},{"length":2});
var anf_variant_member127612046 = R.makeMethod(function(self15616795) {
return function(cases_DASH_funs15716796,else_DASH_clause15816807) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2270],2,arguments);
}
var if_DASH_16016810 = R.hasField(cases_DASH_funs15716796,("s-module"));
var if_helper126216793 = R.makeFunction(function(if_helper_arg126316815) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2270],1,arguments);
}
var ann_DASH_check_DASH_temp126116816 = if_helper_arg126316815;
return ann_DASH_check_DASH_temp126116816;
});
var anf_if126616814 = R.isBoolean(if_DASH_16016810);
if(R.isPyretTrue(anf_if126616814)) {
if(R.isPyretTrue(if_DASH_16016810)) {
var call_DASH_s_DASH_module15516786 = G(cases_DASH_funs15716796,"s-module",L[2270]);
var anf_arg126916787 = G(self15616795,"l",L[3025]);
var anf_arg127016788 = G(self15616795,"answer",L[3024]);
var anf_arg127116789 = G(self15616795,"provides",L[3023]);
var anf_arg127216790 = G(self15616795,"types",L[3022]);
var anf_arg127316791 = G(self15616795,"checks",L[3021]);
var $z1677816779 = D;
var $f1678416785 = function(_) {
return R.isFunction(call_DASH_s_DASH_module15516786)?call_DASH_s_DASH_module15516786.app(anf_arg126916787,anf_arg127016788,anf_arg127116789,anf_arg127216790,anf_arg127316791):R.ffi.throwNonFunApp(L[2270],call_DASH_s_DASH_module15516786,[anf_arg126916787,anf_arg127016788,anf_arg127116789,anf_arg127216790,anf_arg127316791]);
};
try {
if(--R.GAS > 0) {
$z1677816779 = $f1678416785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1678416785,
"from":L[2270]});
}
} catch($e1677616777) {
if(R.isCont($e1677616777)) {
var $ss1678016781 = {"from":L[2270],
"go":function(cont_tail_arg127416792) {
return $Hcont_tail_arg872816794(cont_tail_arg127416792,if_helper126216793);
}};
$e1677616777.stack[R.EXN_STACKHEIGHT++] = $ss1678016781;
}
if(R.isPyretException($e1677616777)) {
$e1677616777.pyretStack.push(L[2270]);
}
throw $e1677616777;
}
var $ret1678216783 = $Hcont_tail_arg872816794($z1677816779,if_helper126216793);
++R.GAS;
return $ret1678216783;
} else {
var $z1679916800 = D;
var $f1680516806 = function(_) {
return R.isFunction(else_DASH_clause15816807)?else_DASH_clause15816807.app():R.ffi.throwNonFunApp(L[2270],else_DASH_clause15816807,[]);
};
try {
if(--R.GAS > 0) {
$z1679916800 = $f1680516806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1680516806,
"from":L[2270]});
}
} catch($e1679716798) {
if(R.isCont($e1679716798)) {
var $ss1680116802 = {"from":L[2270],
"go":function(cont_tail_arg126716808) {
return $Hcont_tail_arg872916809(cont_tail_arg126716808,if_helper126216793);
}};
$e1679716798.stack[R.EXN_STACKHEIGHT++] = $ss1680116802;
}
if(R.isPyretException($e1679716798)) {
$e1679716798.pyretStack.push(L[2270]);
}
throw $e1679716798;
}
var $ret1680316804 = $Hcont_tail_arg872916809($z1679916800,if_helper126216793);
++R.GAS;
return $ret1680316804;
}
} else {
var cont_tail_arg126416813 = R.throwNonBooleanCondition(L[2270],("if"),if_DASH_16016810);
if(--R.GAS > 0) {
$z1681116812 = R.isFunction(if_helper126216793)?if_helper126216793.app(cont_tail_arg126416813):R.ffi.throwNonFunApp(L[2270],if_helper126216793,[cont_tail_arg126416813]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper126216793)?if_helper126216793.app(cont_tail_arg126416813):R.ffi.throwNonFunApp(L[2270],if_helper126216793,[cont_tail_arg126416813]);
},
"from":L[2270]});
}
++R.GAS;
return $z1681116812;
}
};
},{"length":3});
var anf_variant_member129812047 = R.makeMethod(function(self15916774) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2270],0,arguments);
}
var anf_arg127816772 = G(self15916774,"l",L[2270]);
var $z1676416765 = D;
var $f1677016771 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg127816772):R.ffi.throwNonFunApp(L[2270],torepr65,[anf_arg127816772]);
};
try {
if(--R.GAS > 0) {
$z1676416765 = $f1677016771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1677016771,
"from":L[2270]});
}
} catch($e1676216763) {
if(R.isCont($e1676216763)) {
var $ss1676616767 = {"from":L[2270],
"go":function(anf_arg127916773) {
return $Hanf_arg874516775(anf_arg127916773,self15916774,_plus55,torepr65);
}};
$e1676216763.stack[R.EXN_STACKHEIGHT++] = $ss1676616767;
}
if(R.isPyretException($e1676216763)) {
$e1676216763.pyretStack.push(L[2270]);
}
throw $e1676216763;
}
var $ret1676816769 = $Hanf_arg874516775($z1676416765,self15916774,_plus55,torepr65);
++R.GAS;
return $ret1676816769;
};
},{"length":1});
var anf_variant_member130012048 = R.makeMethod(function(self65316761) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3020],0,arguments);
}
var ann_DASH_check_DASH_temp129916760 = ("s-module");
return ann_DASH_check_DASH_temp129916760;
};
},{"length":1});
var anf_variant_member134712049 = R.makeMethod(function(self65416758) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3019],0,arguments);
}
var anf_fun130216756 = G(PP170,"str",L[3018]);
var $z1674816749 = D;
var $f1675416755 = function(_) {
return R.isFunction(anf_fun130216756)?anf_fun130216756.app(("Module")):R.ffi.throwNonFunApp(L[3017],anf_fun130216756,[("Module")]);
};
try {
if(--R.GAS > 0) {
$z1674816749 = $f1675416755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1675416755,
"from":L[3017]});
}
} catch($e1674616747) {
if(R.isCont($e1674616747)) {
var $ss1675016751 = {"from":L[3017],
"go":function(anf_arg130316757) {
return $Hanf_arg876416759(anf_arg130316757,INDENT118169,PP170,list25154,self65416758,str_DASH_colon134364,_plus55);
}};
$e1674616747.stack[R.EXN_STACKHEIGHT++] = $ss1675016751;
}
if(R.isPyretException($e1674616747)) {
$e1674616747.pyretStack.push(L[3017]);
}
throw $e1674616747;
}
var $ret1675216753 = $Hanf_arg876416759($z1674816749,INDENT118169,PP170,list25154,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret1675216753;
};
},{"length":1});
var anf_variant_member136112060 = R.makeMethod(function(self16316724) {
return function(cases_DASH_funs16416725,else_DASH_clause16516736) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2269],2,arguments);
}
var if_DASH_16716739 = R.hasField(cases_DASH_funs16416725,("s-type-let-expr"));
var if_helper134916722 = R.makeFunction(function(if_helper_arg135016744) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2269],1,arguments);
}
var ann_DASH_check_DASH_temp134816745 = if_helper_arg135016744;
return ann_DASH_check_DASH_temp134816745;
});
var anf_if135316743 = R.isBoolean(if_DASH_16716739);
if(R.isPyretTrue(anf_if135316743)) {
if(R.isPyretTrue(if_DASH_16716739)) {
var call_DASH_s_DASH_type_DASH_let_DASH_expr16216717 = G(cases_DASH_funs16416725,"s-type-let-expr",L[2269]);
var anf_arg135616718 = G(self16316724,"l",L[3016]);
var anf_arg135716719 = G(self16316724,"binds",L[3015]);
var anf_arg135816720 = G(self16316724,"body",L[3014]);
var $z1670916710 = D;
var $f1671516716 = function(_) {
return R.isFunction(call_DASH_s_DASH_type_DASH_let_DASH_expr16216717)?call_DASH_s_DASH_type_DASH_let_DASH_expr16216717.app(anf_arg135616718,anf_arg135716719,anf_arg135816720):R.ffi.throwNonFunApp(L[2269],call_DASH_s_DASH_type_DASH_let_DASH_expr16216717,[anf_arg135616718,anf_arg135716719,anf_arg135816720]);
};
try {
if(--R.GAS > 0) {
$z1670916710 = $f1671516716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1671516716,
"from":L[2269]});
}
} catch($e1670716708) {
if(R.isCont($e1670716708)) {
var $ss1671116712 = {"from":L[2269],
"go":function(cont_tail_arg135916721) {
return $Hcont_tail_arg876516723(cont_tail_arg135916721,if_helper134916722);
}};
$e1670716708.stack[R.EXN_STACKHEIGHT++] = $ss1671116712;
}
if(R.isPyretException($e1670716708)) {
$e1670716708.pyretStack.push(L[2269]);
}
throw $e1670716708;
}
var $ret1671316714 = $Hcont_tail_arg876516723($z1670916710,if_helper134916722);
++R.GAS;
return $ret1671316714;
} else {
var $z1672816729 = D;
var $f1673416735 = function(_) {
return R.isFunction(else_DASH_clause16516736)?else_DASH_clause16516736.app():R.ffi.throwNonFunApp(L[2269],else_DASH_clause16516736,[]);
};
try {
if(--R.GAS > 0) {
$z1672816729 = $f1673416735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1673416735,
"from":L[2269]});
}
} catch($e1672616727) {
if(R.isCont($e1672616727)) {
var $ss1673016731 = {"from":L[2269],
"go":function(cont_tail_arg135416737) {
return $Hcont_tail_arg876616738(cont_tail_arg135416737,if_helper134916722);
}};
$e1672616727.stack[R.EXN_STACKHEIGHT++] = $ss1673016731;
}
if(R.isPyretException($e1672616727)) {
$e1672616727.pyretStack.push(L[2269]);
}
throw $e1672616727;
}
var $ret1673216733 = $Hcont_tail_arg876616738($z1672816729,if_helper134916722);
++R.GAS;
return $ret1673216733;
}
} else {
var cont_tail_arg135116742 = R.throwNonBooleanCondition(L[2269],("if"),if_DASH_16716739);
if(--R.GAS > 0) {
$z1674016741 = R.isFunction(if_helper134916722)?if_helper134916722.app(cont_tail_arg135116742):R.ffi.throwNonFunApp(L[2269],if_helper134916722,[cont_tail_arg135116742]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper134916722)?if_helper134916722.app(cont_tail_arg135116742):R.ffi.throwNonFunApp(L[2269],if_helper134916722,[cont_tail_arg135116742]);
},
"from":L[2269]});
}
++R.GAS;
return $z1674016741;
}
};
},{"length":3});
var anf_variant_member137512061 = R.makeMethod(function(self16616705) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2269],0,arguments);
}
var anf_arg136316703 = G(self16616705,"l",L[2269]);
var $z1669516696 = D;
var $f1670116702 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg136316703):R.ffi.throwNonFunApp(L[2269],torepr65,[anf_arg136316703]);
};
try {
if(--R.GAS > 0) {
$z1669516696 = $f1670116702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1670116702,
"from":L[2269]});
}
} catch($e1669316694) {
if(R.isCont($e1669316694)) {
var $ss1669716698 = {"from":L[2269],
"go":function(anf_arg136416704) {
return $Hanf_arg877616706(anf_arg136416704,self16616705,_plus55,torepr65);
}};
$e1669316694.stack[R.EXN_STACKHEIGHT++] = $ss1669716698;
}
if(R.isPyretException($e1669316694)) {
$e1669316694.pyretStack.push(L[2269]);
}
throw $e1669316694;
}
var $ret1669916700 = $Hanf_arg877616706($z1669516696,self16616705,_plus55,torepr65);
++R.GAS;
return $ret1669916700;
};
},{"length":1});
var anf_variant_member137712062 = R.makeMethod(function(self65916692) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3013],0,arguments);
}
var ann_DASH_check_DASH_temp137616691 = ("s-type-let");
return ann_DASH_check_DASH_temp137616691;
};
},{"length":1});
var anf_variant_member139712063 = R.makeMethod(function(self66016689) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3012],0,arguments);
}
var anf_fun137916688 = G(PP170,"surround-separate",L[3011]);
var $z1667916680 = D;
var $f1668516686 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[3010],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z1667916680 = $f1668516686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1668516686,
"from":L[3010]});
}
} catch($e1667716678) {
if(R.isCont($e1667716678)) {
var $ss1668116682 = {"from":L[3010],
"go":function(anf_arg138016687) {
return $Hanf_arg878516690(anf_arg138016687,INDENT118169,PP170,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55);
}};
$e1667716678.stack[R.EXN_STACKHEIGHT++] = $ss1668116682;
}
if(R.isPyretException($e1667716678)) {
$e1667716678.pyretStack.push(L[3010]);
}
throw $e1667716678;
}
var $ret1668316684 = $Hanf_arg878516690($z1667916680,INDENT118169,PP170,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55);
++R.GAS;
return $ret1668316684;
};
},{"length":1});
var anf_variant_member141112072 = R.makeMethod(function(self17016655) {
return function(cases_DASH_funs17116656,else_DASH_clause17216667) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2268],2,arguments);
}
var if_DASH_17416670 = R.hasField(cases_DASH_funs17116656,("s-let-expr"));
var if_helper139916653 = R.makeFunction(function(if_helper_arg140016675) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2268],1,arguments);
}
var ann_DASH_check_DASH_temp139816676 = if_helper_arg140016675;
return ann_DASH_check_DASH_temp139816676;
});
var anf_if140316674 = R.isBoolean(if_DASH_17416670);
if(R.isPyretTrue(anf_if140316674)) {
if(R.isPyretTrue(if_DASH_17416670)) {
var call_DASH_s_DASH_let_DASH_expr16916648 = G(cases_DASH_funs17116656,"s-let-expr",L[2268]);
var anf_arg140616649 = G(self17016655,"l",L[3009]);
var anf_arg140716650 = G(self17016655,"binds",L[3008]);
var anf_arg140816651 = G(self17016655,"body",L[3007]);
var $z1664016641 = D;
var $f1664616647 = function(_) {
return R.isFunction(call_DASH_s_DASH_let_DASH_expr16916648)?call_DASH_s_DASH_let_DASH_expr16916648.app(anf_arg140616649,anf_arg140716650,anf_arg140816651):R.ffi.throwNonFunApp(L[2268],call_DASH_s_DASH_let_DASH_expr16916648,[anf_arg140616649,anf_arg140716650,anf_arg140816651]);
};
try {
if(--R.GAS > 0) {
$z1664016641 = $f1664616647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1664616647,
"from":L[2268]});
}
} catch($e1663816639) {
if(R.isCont($e1663816639)) {
var $ss1664216643 = {"from":L[2268],
"go":function(cont_tail_arg140916652) {
return $Hcont_tail_arg878616654(cont_tail_arg140916652,if_helper139916653);
}};
$e1663816639.stack[R.EXN_STACKHEIGHT++] = $ss1664216643;
}
if(R.isPyretException($e1663816639)) {
$e1663816639.pyretStack.push(L[2268]);
}
throw $e1663816639;
}
var $ret1664416645 = $Hcont_tail_arg878616654($z1664016641,if_helper139916653);
++R.GAS;
return $ret1664416645;
} else {
var $z1665916660 = D;
var $f1666516666 = function(_) {
return R.isFunction(else_DASH_clause17216667)?else_DASH_clause17216667.app():R.ffi.throwNonFunApp(L[2268],else_DASH_clause17216667,[]);
};
try {
if(--R.GAS > 0) {
$z1665916660 = $f1666516666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1666516666,
"from":L[2268]});
}
} catch($e1665716658) {
if(R.isCont($e1665716658)) {
var $ss1666116662 = {"from":L[2268],
"go":function(cont_tail_arg140416668) {
return $Hcont_tail_arg878716669(cont_tail_arg140416668,if_helper139916653);
}};
$e1665716658.stack[R.EXN_STACKHEIGHT++] = $ss1666116662;
}
if(R.isPyretException($e1665716658)) {
$e1665716658.pyretStack.push(L[2268]);
}
throw $e1665716658;
}
var $ret1666316664 = $Hcont_tail_arg878716669($z1665916660,if_helper139916653);
++R.GAS;
return $ret1666316664;
}
} else {
var cont_tail_arg140116673 = R.throwNonBooleanCondition(L[2268],("if"),if_DASH_17416670);
if(--R.GAS > 0) {
$z1667116672 = R.isFunction(if_helper139916653)?if_helper139916653.app(cont_tail_arg140116673):R.ffi.throwNonFunApp(L[2268],if_helper139916653,[cont_tail_arg140116673]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper139916653)?if_helper139916653.app(cont_tail_arg140116673):R.ffi.throwNonFunApp(L[2268],if_helper139916653,[cont_tail_arg140116673]);
},
"from":L[2268]});
}
++R.GAS;
return $z1667116672;
}
};
},{"length":3});
var anf_variant_member142512073 = R.makeMethod(function(self17316636) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2268],0,arguments);
}
var anf_arg141316634 = G(self17316636,"l",L[2268]);
var $z1662616627 = D;
var $f1663216633 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg141316634):R.ffi.throwNonFunApp(L[2268],torepr65,[anf_arg141316634]);
};
try {
if(--R.GAS > 0) {
$z1662616627 = $f1663216633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1663216633,
"from":L[2268]});
}
} catch($e1662416625) {
if(R.isCont($e1662416625)) {
var $ss1662816629 = {"from":L[2268],
"go":function(anf_arg141416635) {
return $Hanf_arg879716637(anf_arg141416635,self17316636,_plus55,torepr65);
}};
$e1662416625.stack[R.EXN_STACKHEIGHT++] = $ss1662816629;
}
if(R.isPyretException($e1662416625)) {
$e1662416625.pyretStack.push(L[2268]);
}
throw $e1662416625;
}
var $ret1663016631 = $Hanf_arg879716637($z1662616627,self17316636,_plus55,torepr65);
++R.GAS;
return $ret1663016631;
};
},{"length":1});
var anf_variant_member142712074 = R.makeMethod(function(self66516623) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3006],0,arguments);
}
var ann_DASH_check_DASH_temp142616622 = ("s-let");
return ann_DASH_check_DASH_temp142616622;
};
},{"length":1});
var anf_variant_member144712075 = R.makeMethod(function(self66616620) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3005],0,arguments);
}
var anf_fun142916619 = G(PP170,"surround-separate",L[3004]);
var $z1661016611 = D;
var $f1661616617 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[3003],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z1661016611 = $f1661616617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1661616617,
"from":L[3003]});
}
} catch($e1660816609) {
if(R.isCont($e1660816609)) {
var $ss1661216613 = {"from":L[3003],
"go":function(anf_arg143016618) {
return $Hanf_arg880616621(anf_arg143016618,INDENT118169,PP170,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55);
}};
$e1660816609.stack[R.EXN_STACKHEIGHT++] = $ss1661216613;
}
if(R.isPyretException($e1660816609)) {
$e1660816609.pyretStack.push(L[3003]);
}
throw $e1660816609;
}
var $ret1661416615 = $Hanf_arg880616621($z1661016611,INDENT118169,PP170,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55);
++R.GAS;
return $ret1661416615;
};
},{"length":1});
var anf_variant_member146112084 = R.makeMethod(function(self17716586) {
return function(cases_DASH_funs17816587,else_DASH_clause17916598) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2267],2,arguments);
}
var if_DASH_18116601 = R.hasField(cases_DASH_funs17816587,("s-letrec"));
var if_helper144916584 = R.makeFunction(function(if_helper_arg145016606) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2267],1,arguments);
}
var ann_DASH_check_DASH_temp144816607 = if_helper_arg145016606;
return ann_DASH_check_DASH_temp144816607;
});
var anf_if145316605 = R.isBoolean(if_DASH_18116601);
if(R.isPyretTrue(anf_if145316605)) {
if(R.isPyretTrue(if_DASH_18116601)) {
var call_DASH_s_DASH_letrec17616579 = G(cases_DASH_funs17816587,"s-letrec",L[2267]);
var anf_arg145616580 = G(self17716586,"l",L[3002]);
var anf_arg145716581 = G(self17716586,"binds",L[3001]);
var anf_arg145816582 = G(self17716586,"body",L[3000]);
var $z1657116572 = D;
var $f1657716578 = function(_) {
return R.isFunction(call_DASH_s_DASH_letrec17616579)?call_DASH_s_DASH_letrec17616579.app(anf_arg145616580,anf_arg145716581,anf_arg145816582):R.ffi.throwNonFunApp(L[2267],call_DASH_s_DASH_letrec17616579,[anf_arg145616580,anf_arg145716581,anf_arg145816582]);
};
try {
if(--R.GAS > 0) {
$z1657116572 = $f1657716578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1657716578,
"from":L[2267]});
}
} catch($e1656916570) {
if(R.isCont($e1656916570)) {
var $ss1657316574 = {"from":L[2267],
"go":function(cont_tail_arg145916583) {
return $Hcont_tail_arg880716585(cont_tail_arg145916583,if_helper144916584);
}};
$e1656916570.stack[R.EXN_STACKHEIGHT++] = $ss1657316574;
}
if(R.isPyretException($e1656916570)) {
$e1656916570.pyretStack.push(L[2267]);
}
throw $e1656916570;
}
var $ret1657516576 = $Hcont_tail_arg880716585($z1657116572,if_helper144916584);
++R.GAS;
return $ret1657516576;
} else {
var $z1659016591 = D;
var $f1659616597 = function(_) {
return R.isFunction(else_DASH_clause17916598)?else_DASH_clause17916598.app():R.ffi.throwNonFunApp(L[2267],else_DASH_clause17916598,[]);
};
try {
if(--R.GAS > 0) {
$z1659016591 = $f1659616597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1659616597,
"from":L[2267]});
}
} catch($e1658816589) {
if(R.isCont($e1658816589)) {
var $ss1659216593 = {"from":L[2267],
"go":function(cont_tail_arg145416599) {
return $Hcont_tail_arg880816600(cont_tail_arg145416599,if_helper144916584);
}};
$e1658816589.stack[R.EXN_STACKHEIGHT++] = $ss1659216593;
}
if(R.isPyretException($e1658816589)) {
$e1658816589.pyretStack.push(L[2267]);
}
throw $e1658816589;
}
var $ret1659416595 = $Hcont_tail_arg880816600($z1659016591,if_helper144916584);
++R.GAS;
return $ret1659416595;
}
} else {
var cont_tail_arg145116604 = R.throwNonBooleanCondition(L[2267],("if"),if_DASH_18116601);
if(--R.GAS > 0) {
$z1660216603 = R.isFunction(if_helper144916584)?if_helper144916584.app(cont_tail_arg145116604):R.ffi.throwNonFunApp(L[2267],if_helper144916584,[cont_tail_arg145116604]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper144916584)?if_helper144916584.app(cont_tail_arg145116604):R.ffi.throwNonFunApp(L[2267],if_helper144916584,[cont_tail_arg145116604]);
},
"from":L[2267]});
}
++R.GAS;
return $z1660216603;
}
};
},{"length":3});
var anf_variant_member147512085 = R.makeMethod(function(self18016567) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2267],0,arguments);
}
var anf_arg146316565 = G(self18016567,"l",L[2267]);
var $z1655716558 = D;
var $f1656316564 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg146316565):R.ffi.throwNonFunApp(L[2267],torepr65,[anf_arg146316565]);
};
try {
if(--R.GAS > 0) {
$z1655716558 = $f1656316564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1656316564,
"from":L[2267]});
}
} catch($e1655516556) {
if(R.isCont($e1655516556)) {
var $ss1655916560 = {"from":L[2267],
"go":function(anf_arg146416566) {
return $Hanf_arg881816568(anf_arg146416566,self18016567,_plus55,torepr65);
}};
$e1655516556.stack[R.EXN_STACKHEIGHT++] = $ss1655916560;
}
if(R.isPyretException($e1655516556)) {
$e1655516556.pyretStack.push(L[2267]);
}
throw $e1655516556;
}
var $ret1656116562 = $Hanf_arg881816568($z1655716558,self18016567,_plus55,torepr65);
++R.GAS;
return $ret1656116562;
};
},{"length":1});
var anf_variant_member147712086 = R.makeMethod(function(self67116554) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2999],0,arguments);
}
var ann_DASH_check_DASH_temp147616553 = ("s-letrec");
return ann_DASH_check_DASH_temp147616553;
};
},{"length":1});
var anf_variant_member149712087 = R.makeMethod(function(self6729809) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2998],0,arguments);
}
var anf_fun147916551 = G(PP170,"surround-separate",L[2997]);
var $z1654216543 = D;
var $f1654816549 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[2996],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z1654216543 = $f1654816549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1654816549,
"from":L[2996]});
}
} catch($e1654016541) {
if(R.isCont($e1654016541)) {
var $ss1654416545 = {"from":L[2996],
"go":function(anf_arg148016550) {
return $Hanf_arg882716552(anf_arg148016550,INDENT118169,PP170,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55);
}};
$e1654016541.stack[R.EXN_STACKHEIGHT++] = $ss1654416545;
}
if(R.isPyretException($e1654016541)) {
$e1654016541.pyretStack.push(L[2996]);
}
throw $e1654016541;
}
var $ret1654616547 = $Hanf_arg882716552($z1654216543,INDENT118169,PP170,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55);
++R.GAS;
return $ret1654616547;
};
},{"length":1});
var anf_variant_member151112096 = R.makeMethod(function(self18416518) {
return function(cases_DASH_funs18516519,else_DASH_clause18616530) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2266],2,arguments);
}
var if_DASH_18816533 = R.hasField(cases_DASH_funs18516519,("s-hint-exp"));
var if_helper149916516 = R.makeFunction(function(if_helper_arg150016538) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2266],1,arguments);
}
var ann_DASH_check_DASH_temp149816539 = if_helper_arg150016538;
return ann_DASH_check_DASH_temp149816539;
});
var anf_if150316537 = R.isBoolean(if_DASH_18816533);
if(R.isPyretTrue(anf_if150316537)) {
if(R.isPyretTrue(if_DASH_18816533)) {
var call_DASH_s_DASH_hint_DASH_exp18316511 = G(cases_DASH_funs18516519,"s-hint-exp",L[2266]);
var anf_arg150616512 = G(self18416518,"l",L[2995]);
var anf_arg150716513 = G(self18416518,"hints",L[2994]);
var anf_arg150816514 = G(self18416518,"exp",L[2993]);
var $z1650316504 = D;
var $f1650916510 = function(_) {
return R.isFunction(call_DASH_s_DASH_hint_DASH_exp18316511)?call_DASH_s_DASH_hint_DASH_exp18316511.app(anf_arg150616512,anf_arg150716513,anf_arg150816514):R.ffi.throwNonFunApp(L[2266],call_DASH_s_DASH_hint_DASH_exp18316511,[anf_arg150616512,anf_arg150716513,anf_arg150816514]);
};
try {
if(--R.GAS > 0) {
$z1650316504 = $f1650916510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1650916510,
"from":L[2266]});
}
} catch($e1650116502) {
if(R.isCont($e1650116502)) {
var $ss1650516506 = {"from":L[2266],
"go":function(cont_tail_arg150916515) {
return $Hcont_tail_arg882816517(cont_tail_arg150916515,if_helper149916516);
}};
$e1650116502.stack[R.EXN_STACKHEIGHT++] = $ss1650516506;
}
if(R.isPyretException($e1650116502)) {
$e1650116502.pyretStack.push(L[2266]);
}
throw $e1650116502;
}
var $ret1650716508 = $Hcont_tail_arg882816517($z1650316504,if_helper149916516);
++R.GAS;
return $ret1650716508;
} else {
var $z1652216523 = D;
var $f1652816529 = function(_) {
return R.isFunction(else_DASH_clause18616530)?else_DASH_clause18616530.app():R.ffi.throwNonFunApp(L[2266],else_DASH_clause18616530,[]);
};
try {
if(--R.GAS > 0) {
$z1652216523 = $f1652816529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1652816529,
"from":L[2266]});
}
} catch($e1652016521) {
if(R.isCont($e1652016521)) {
var $ss1652416525 = {"from":L[2266],
"go":function(cont_tail_arg150416531) {
return $Hcont_tail_arg882916532(cont_tail_arg150416531,if_helper149916516);
}};
$e1652016521.stack[R.EXN_STACKHEIGHT++] = $ss1652416525;
}
if(R.isPyretException($e1652016521)) {
$e1652016521.pyretStack.push(L[2266]);
}
throw $e1652016521;
}
var $ret1652616527 = $Hcont_tail_arg882916532($z1652216523,if_helper149916516);
++R.GAS;
return $ret1652616527;
}
} else {
var cont_tail_arg150116536 = R.throwNonBooleanCondition(L[2266],("if"),if_DASH_18816533);
if(--R.GAS > 0) {
$z1653416535 = R.isFunction(if_helper149916516)?if_helper149916516.app(cont_tail_arg150116536):R.ffi.throwNonFunApp(L[2266],if_helper149916516,[cont_tail_arg150116536]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper149916516)?if_helper149916516.app(cont_tail_arg150116536):R.ffi.throwNonFunApp(L[2266],if_helper149916516,[cont_tail_arg150116536]);
},
"from":L[2266]});
}
++R.GAS;
return $z1653416535;
}
};
},{"length":3});
var anf_variant_member152512097 = R.makeMethod(function(self18716499) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2266],0,arguments);
}
var anf_arg151316497 = G(self18716499,"l",L[2266]);
var $z1648916490 = D;
var $f1649516496 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg151316497):R.ffi.throwNonFunApp(L[2266],torepr65,[anf_arg151316497]);
};
try {
if(--R.GAS > 0) {
$z1648916490 = $f1649516496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1649516496,
"from":L[2266]});
}
} catch($e1648716488) {
if(R.isCont($e1648716488)) {
var $ss1649116492 = {"from":L[2266],
"go":function(anf_arg151416498) {
return $Hanf_arg883916500(anf_arg151416498,self18716499,_plus55,torepr65);
}};
$e1648716488.stack[R.EXN_STACKHEIGHT++] = $ss1649116492;
}
if(R.isPyretException($e1648716488)) {
$e1648716488.pyretStack.push(L[2266]);
}
throw $e1648716488;
}
var $ret1649316494 = $Hanf_arg883916500($z1648916490,self18716499,_plus55,torepr65);
++R.GAS;
return $ret1649316494;
};
},{"length":1});
var anf_variant_member152712098 = R.makeMethod(function(self67716486) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2992],0,arguments);
}
var ann_DASH_check_DASH_temp152616485 = ("s-hint-exp");
return ann_DASH_check_DASH_temp152616485;
};
},{"length":1});
var anf_variant_member154212099 = R.makeMethod(function(self6789741) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2991],0,arguments);
}
var anf_fun152916465 = G(PP170,"flow-map",L[2990]);
var anf_arg153016466 = G(PP170,"hardline",L[2989]);
var anf_arg153416467 = R.makeFunction(function(h67916471) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2986],1,arguments);
}
var anf_fun153216482 = G(h67916471,"tosource",L[2988]);
var $z1647416475 = D;
var $f1648016481 = function(_) {
return R.isFunction(anf_fun153216482)?anf_fun153216482.app():R.ffi.throwNonFunApp(L[2987],anf_fun153216482,[]);
};
try {
if(--R.GAS > 0) {
$z1647416475 = $f1648016481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1648016481,
"from":L[2987]});
}
} catch($e1647216473) {
if(R.isCont($e1647216473)) {
var $ss1647616477 = {"from":L[2987],
"go":function(anf_arg153316483) {
return $Hanf_arg884116484(anf_arg153316483,str_DASH_comment137403,_plus55);
}};
$e1647216473.stack[R.EXN_STACKHEIGHT++] = $ss1647616477;
}
if(R.isPyretException($e1647216473)) {
$e1647216473.pyretStack.push(L[2987]);
}
throw $e1647216473;
}
var $ret1647816479 = $Hanf_arg884116484($z1647416475,str_DASH_comment137403,_plus55);
++R.GAS;
return $ret1647816479;
});
var anf_arg153516468 = G(self6789741,"hints",L[2985]);
var $z1645716458 = D;
var $f1646316464 = function(_) {
return R.isFunction(anf_fun152916465)?anf_fun152916465.app(anf_arg153016466,anf_arg153416467,anf_arg153516468):R.ffi.throwNonFunApp(L[2984],anf_fun152916465,[anf_arg153016466,anf_arg153416467,anf_arg153516468]);
};
try {
if(--R.GAS > 0) {
$z1645716458 = $f1646316464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1646316464,
"from":L[2984]});
}
} catch($e1645516456) {
if(R.isCont($e1645516456)) {
var $ss1645916460 = {"from":L[2984],
"go":function(anf_arg153616469) {
return $Hanf_arg884516470(anf_arg153616469,PP170,self6789741,_plus55);
}};
$e1645516456.stack[R.EXN_STACKHEIGHT++] = $ss1645916460;
}
if(R.isPyretException($e1645516456)) {
$e1645516456.pyretStack.push(L[2984]);
}
throw $e1645516456;
}
var $ret1646116462 = $Hanf_arg884516470($z1645716458,PP170,self6789741,_plus55);
++R.GAS;
return $ret1646116462;
};
},{"length":1});
var anf_variant_member155612108 = R.makeMethod(function(self19016433) {
return function(cases_DASH_funs19116434,else_DASH_clause19216445) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2265],2,arguments);
}
var if_DASH_19416448 = R.hasField(cases_DASH_funs19116434,("s-instantiate"));
var if_helper154416431 = R.makeFunction(function(if_helper_arg154516453) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2265],1,arguments);
}
var ann_DASH_check_DASH_temp154316454 = if_helper_arg154516453;
return ann_DASH_check_DASH_temp154316454;
});
var anf_if154816452 = R.isBoolean(if_DASH_19416448);
if(R.isPyretTrue(anf_if154816452)) {
if(R.isPyretTrue(if_DASH_19416448)) {
var call_DASH_s_DASH_instantiate18916426 = G(cases_DASH_funs19116434,"s-instantiate",L[2265]);
var anf_arg155116427 = G(self19016433,"l",L[2983]);
var anf_arg155216428 = G(self19016433,"expr",L[2982]);
var anf_arg155316429 = G(self19016433,"params",L[2981]);
var $z1641816419 = D;
var $f1642416425 = function(_) {
return R.isFunction(call_DASH_s_DASH_instantiate18916426)?call_DASH_s_DASH_instantiate18916426.app(anf_arg155116427,anf_arg155216428,anf_arg155316429):R.ffi.throwNonFunApp(L[2265],call_DASH_s_DASH_instantiate18916426,[anf_arg155116427,anf_arg155216428,anf_arg155316429]);
};
try {
if(--R.GAS > 0) {
$z1641816419 = $f1642416425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1642416425,
"from":L[2265]});
}
} catch($e1641616417) {
if(R.isCont($e1641616417)) {
var $ss1642016421 = {"from":L[2265],
"go":function(cont_tail_arg155416430) {
return $Hcont_tail_arg884616432(cont_tail_arg155416430,if_helper154416431);
}};
$e1641616417.stack[R.EXN_STACKHEIGHT++] = $ss1642016421;
}
if(R.isPyretException($e1641616417)) {
$e1641616417.pyretStack.push(L[2265]);
}
throw $e1641616417;
}
var $ret1642216423 = $Hcont_tail_arg884616432($z1641816419,if_helper154416431);
++R.GAS;
return $ret1642216423;
} else {
var $z1643716438 = D;
var $f1644316444 = function(_) {
return R.isFunction(else_DASH_clause19216445)?else_DASH_clause19216445.app():R.ffi.throwNonFunApp(L[2265],else_DASH_clause19216445,[]);
};
try {
if(--R.GAS > 0) {
$z1643716438 = $f1644316444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1644316444,
"from":L[2265]});
}
} catch($e1643516436) {
if(R.isCont($e1643516436)) {
var $ss1643916440 = {"from":L[2265],
"go":function(cont_tail_arg154916446) {
return $Hcont_tail_arg884716447(cont_tail_arg154916446,if_helper154416431);
}};
$e1643516436.stack[R.EXN_STACKHEIGHT++] = $ss1643916440;
}
if(R.isPyretException($e1643516436)) {
$e1643516436.pyretStack.push(L[2265]);
}
throw $e1643516436;
}
var $ret1644116442 = $Hcont_tail_arg884716447($z1643716438,if_helper154416431);
++R.GAS;
return $ret1644116442;
}
} else {
var cont_tail_arg154616451 = R.throwNonBooleanCondition(L[2265],("if"),if_DASH_19416448);
if(--R.GAS > 0) {
$z1644916450 = R.isFunction(if_helper154416431)?if_helper154416431.app(cont_tail_arg154616451):R.ffi.throwNonFunApp(L[2265],if_helper154416431,[cont_tail_arg154616451]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper154416431)?if_helper154416431.app(cont_tail_arg154616451):R.ffi.throwNonFunApp(L[2265],if_helper154416431,[cont_tail_arg154616451]);
},
"from":L[2265]});
}
++R.GAS;
return $z1644916450;
}
};
},{"length":3});
var anf_variant_member157012109 = R.makeMethod(function(self19316414) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2265],0,arguments);
}
var anf_arg155816412 = G(self19316414,"l",L[2265]);
var $z1640416405 = D;
var $f1641016411 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg155816412):R.ffi.throwNonFunApp(L[2265],torepr65,[anf_arg155816412]);
};
try {
if(--R.GAS > 0) {
$z1640416405 = $f1641016411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1641016411,
"from":L[2265]});
}
} catch($e1640216403) {
if(R.isCont($e1640216403)) {
var $ss1640616407 = {"from":L[2265],
"go":function(anf_arg155916413) {
return $Hanf_arg885716415(anf_arg155916413,self19316414,_plus55,torepr65);
}};
$e1640216403.stack[R.EXN_STACKHEIGHT++] = $ss1640616407;
}
if(R.isPyretException($e1640216403)) {
$e1640216403.pyretStack.push(L[2265]);
}
throw $e1640216403;
}
var $ret1640816409 = $Hanf_arg885716415($z1640416405,self19316414,_plus55,torepr65);
++R.GAS;
return $ret1640816409;
};
},{"length":1});
var anf_variant_member157212110 = R.makeMethod(function(self68316401) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2980],0,arguments);
}
var ann_DASH_check_DASH_temp157116400 = ("s-instantiate");
return ann_DASH_check_DASH_temp157116400;
};
},{"length":1});
var anf_variant_member159012111 = R.makeMethod(function(self68416397) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2979],0,arguments);
}
var anf_fun157416396 = G(PP170,"group",L[2978]);
var anf_bracket157516399 = G(self68416397,"expr",L[2977]);
var anf_fun157616394 = G(anf_bracket157516399,"tosource",L[2976]);
var $z1638616387 = D;
var $f1639216393 = function(_) {
return R.isFunction(anf_fun157616394)?anf_fun157616394.app():R.ffi.throwNonFunApp(L[2975],anf_fun157616394,[]);
};
try {
if(--R.GAS > 0) {
$z1638616387 = $f1639216393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1639216393,
"from":L[2975]});
}
} catch($e1638416385) {
if(R.isCont($e1638416385)) {
var $ss1638816389 = {"from":L[2975],
"go":function(anf_arg157716395) {
return $Hanf_arg886216398(anf_arg157716395,INDENT118169,PP170,anf_fun157416396,self68416397,_plus55);
}};
$e1638416385.stack[R.EXN_STACKHEIGHT++] = $ss1638816389;
}
if(R.isPyretException($e1638416385)) {
$e1638416385.pyretStack.push(L[2975]);
}
throw $e1638416385;
}
var $ret1639016391 = $Hanf_arg886216398($z1638616387,INDENT118169,PP170,anf_fun157416396,self68416397,_plus55);
++R.GAS;
return $ret1639016391;
};
},{"length":1});
var anf_variant_member160312120 = R.makeMethod(function(self19716362) {
return function(cases_DASH_funs19816363,else_DASH_clause19916374) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2264],2,arguments);
}
var if_DASH_20116377 = R.hasField(cases_DASH_funs19816363,("s-block"));
var if_helper159216360 = R.makeFunction(function(if_helper_arg159316382) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2264],1,arguments);
}
var ann_DASH_check_DASH_temp159116383 = if_helper_arg159316382;
return ann_DASH_check_DASH_temp159116383;
});
var anf_if159616381 = R.isBoolean(if_DASH_20116377);
if(R.isPyretTrue(anf_if159616381)) {
if(R.isPyretTrue(if_DASH_20116377)) {
var call_DASH_s_DASH_block19616356 = G(cases_DASH_funs19816363,"s-block",L[2264]);
var anf_arg159916357 = G(self19716362,"l",L[2974]);
var anf_arg160016358 = G(self19716362,"stmts",L[2973]);
var $z1634816349 = D;
var $f1635416355 = function(_) {
return R.isFunction(call_DASH_s_DASH_block19616356)?call_DASH_s_DASH_block19616356.app(anf_arg159916357,anf_arg160016358):R.ffi.throwNonFunApp(L[2264],call_DASH_s_DASH_block19616356,[anf_arg159916357,anf_arg160016358]);
};
try {
if(--R.GAS > 0) {
$z1634816349 = $f1635416355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1635416355,
"from":L[2264]});
}
} catch($e1634616347) {
if(R.isCont($e1634616347)) {
var $ss1635016351 = {"from":L[2264],
"go":function(cont_tail_arg160116359) {
return $Hcont_tail_arg886316361(cont_tail_arg160116359,if_helper159216360);
}};
$e1634616347.stack[R.EXN_STACKHEIGHT++] = $ss1635016351;
}
if(R.isPyretException($e1634616347)) {
$e1634616347.pyretStack.push(L[2264]);
}
throw $e1634616347;
}
var $ret1635216353 = $Hcont_tail_arg886316361($z1634816349,if_helper159216360);
++R.GAS;
return $ret1635216353;
} else {
var $z1636616367 = D;
var $f1637216373 = function(_) {
return R.isFunction(else_DASH_clause19916374)?else_DASH_clause19916374.app():R.ffi.throwNonFunApp(L[2264],else_DASH_clause19916374,[]);
};
try {
if(--R.GAS > 0) {
$z1636616367 = $f1637216373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1637216373,
"from":L[2264]});
}
} catch($e1636416365) {
if(R.isCont($e1636416365)) {
var $ss1636816369 = {"from":L[2264],
"go":function(cont_tail_arg159716375) {
return $Hcont_tail_arg886416376(cont_tail_arg159716375,if_helper159216360);
}};
$e1636416365.stack[R.EXN_STACKHEIGHT++] = $ss1636816369;
}
if(R.isPyretException($e1636416365)) {
$e1636416365.pyretStack.push(L[2264]);
}
throw $e1636416365;
}
var $ret1637016371 = $Hcont_tail_arg886416376($z1636616367,if_helper159216360);
++R.GAS;
return $ret1637016371;
}
} else {
var cont_tail_arg159416380 = R.throwNonBooleanCondition(L[2264],("if"),if_DASH_20116377);
if(--R.GAS > 0) {
$z1637816379 = R.isFunction(if_helper159216360)?if_helper159216360.app(cont_tail_arg159416380):R.ffi.throwNonFunApp(L[2264],if_helper159216360,[cont_tail_arg159416380]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper159216360)?if_helper159216360.app(cont_tail_arg159416380):R.ffi.throwNonFunApp(L[2264],if_helper159216360,[cont_tail_arg159416380]);
},
"from":L[2264]});
}
++R.GAS;
return $z1637816379;
}
};
},{"length":3});
var anf_variant_member161312121 = R.makeMethod(function(self2001648) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2264],0,arguments);
}
var anf_arg160516343 = G(self2001648,"l",L[2264]);
var $z1633516336 = D;
var $f1634116342 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg160516343):R.ffi.throwNonFunApp(L[2264],torepr65,[anf_arg160516343]);
};
try {
if(--R.GAS > 0) {
$z1633516336 = $f1634116342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1634116342,
"from":L[2264]});
}
} catch($e1633316334) {
if(R.isCont($e1633316334)) {
var $ss1633716338 = {"from":L[2264],
"go":function(anf_arg160616344) {
return $Hanf_arg887116345(anf_arg160616344,self2001648,_plus55,torepr65);
}};
$e1633316334.stack[R.EXN_STACKHEIGHT++] = $ss1633716338;
}
if(R.isPyretException($e1633316334)) {
$e1633316334.pyretStack.push(L[2264]);
}
throw $e1633316334;
}
var $ret1633916340 = $Hanf_arg887116345($z1633516336,self2001648,_plus55,torepr65);
++R.GAS;
return $ret1633916340;
};
},{"length":1});
var anf_variant_member161512122 = R.makeMethod(function(self68716332) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2972],0,arguments);
}
var ann_DASH_check_DASH_temp161416331 = ("s-block");
return ann_DASH_check_DASH_temp161416331;
};
},{"length":1});
var anf_variant_member162312123 = R.makeMethod(function(self68816316) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2967],0,arguments);
}
var anf_fun161716310 = G(PP170,"flow-map",L[2971]);
var anf_arg161816311 = G(PP170,"hardline",L[2970]);
var anf_arg162116312 = R.makeFunction(function(recv_DASH_20216317) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2969],1,arguments);
}
var anf_fun162016328 = G(recv_DASH_20216317,"tosource",L[2969]);
var $z1632016321 = D;
var $f1632616327 = function(_) {
return R.isFunction(anf_fun162016328)?anf_fun162016328.app():R.ffi.throwNonFunApp(L[2969],anf_fun162016328,[]);
};
try {
if(--R.GAS > 0) {
$z1632016321 = $f1632616327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1632616327,
"from":L[2969]});
}
} catch($e1631816319) {
if(R.isCont($e1631816319)) {
var $ss1632216323 = {"from":L[2969],
"go":function(ann_DASH_check_DASH_temp161916329) {
return $Hann_DASH_check_DASH_temp887216330(ann_DASH_check_DASH_temp161916329);
}};
$e1631816319.stack[R.EXN_STACKHEIGHT++] = $ss1632216323;
}
if(R.isPyretException($e1631816319)) {
$e1631816319.pyretStack.push(L[2969]);
}
throw $e1631816319;
}
var $ret1632416325 = $Hann_DASH_check_DASH_temp887216330($z1632016321);
++R.GAS;
return $ret1632416325;
});
var anf_arg162216313 = G(self68816316,"stmts",L[2968]);
var $z1630216303 = D;
var $f1630816309 = function(_) {
return R.isFunction(anf_fun161716310)?anf_fun161716310.app(anf_arg161816311,anf_arg162116312,anf_arg162216313):R.ffi.throwNonFunApp(L[2967],anf_fun161716310,[anf_arg161816311,anf_arg162116312,anf_arg162216313]);
};
try {
if(--R.GAS > 0) {
$z1630216303 = $f1630816309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1630816309,
"from":L[2967]});
}
} catch($e1630016301) {
if(R.isCont($e1630016301)) {
var $ss1630416305 = {"from":L[2967],
"go":function(ann_DASH_check_DASH_temp161616314) {
return $Hann_DASH_check_DASH_temp887316315(ann_DASH_check_DASH_temp161616314);
}};
$e1630016301.stack[R.EXN_STACKHEIGHT++] = $ss1630416305;
}
if(R.isPyretException($e1630016301)) {
$e1630016301.pyretStack.push(L[2967]);
}
throw $e1630016301;
}
var $ret1630616307 = $Hann_DASH_check_DASH_temp887316315($z1630216303);
++R.GAS;
return $ret1630616307;
};
},{"length":1});
var anf_variant_member163612131 = R.makeMethod(function(self2041606) {
return function(cases_DASH_funs20516279,else_DASH_clause20616290) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2263],2,arguments);
}
var if_DASH_20816293 = R.hasField(cases_DASH_funs20516279,("s-user-block"));
var if_helper162516277 = R.makeFunction(function(if_helper_arg162616298) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2263],1,arguments);
}
var ann_DASH_check_DASH_temp162416299 = if_helper_arg162616298;
return ann_DASH_check_DASH_temp162416299;
});
var anf_if162916297 = R.isBoolean(if_DASH_20816293);
if(R.isPyretTrue(anf_if162916297)) {
if(R.isPyretTrue(if_DASH_20816293)) {
var call_DASH_s_DASH_user_DASH_block20316273 = G(cases_DASH_funs20516279,"s-user-block",L[2263]);
var anf_arg163216274 = G(self2041606,"l",L[2966]);
var anf_arg163316275 = G(self2041606,"body",L[2965]);
var $z1626516266 = D;
var $f1627116272 = function(_) {
return R.isFunction(call_DASH_s_DASH_user_DASH_block20316273)?call_DASH_s_DASH_user_DASH_block20316273.app(anf_arg163216274,anf_arg163316275):R.ffi.throwNonFunApp(L[2263],call_DASH_s_DASH_user_DASH_block20316273,[anf_arg163216274,anf_arg163316275]);
};
try {
if(--R.GAS > 0) {
$z1626516266 = $f1627116272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1627116272,
"from":L[2263]});
}
} catch($e1626316264) {
if(R.isCont($e1626316264)) {
var $ss1626716268 = {"from":L[2263],
"go":function(cont_tail_arg163416276) {
return $Hcont_tail_arg887416278(cont_tail_arg163416276,if_helper162516277);
}};
$e1626316264.stack[R.EXN_STACKHEIGHT++] = $ss1626716268;
}
if(R.isPyretException($e1626316264)) {
$e1626316264.pyretStack.push(L[2263]);
}
throw $e1626316264;
}
var $ret1626916270 = $Hcont_tail_arg887416278($z1626516266,if_helper162516277);
++R.GAS;
return $ret1626916270;
} else {
var $z1628216283 = D;
var $f1628816289 = function(_) {
return R.isFunction(else_DASH_clause20616290)?else_DASH_clause20616290.app():R.ffi.throwNonFunApp(L[2263],else_DASH_clause20616290,[]);
};
try {
if(--R.GAS > 0) {
$z1628216283 = $f1628816289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1628816289,
"from":L[2263]});
}
} catch($e1628016281) {
if(R.isCont($e1628016281)) {
var $ss1628416285 = {"from":L[2263],
"go":function(cont_tail_arg163016291) {
return $Hcont_tail_arg887516292(cont_tail_arg163016291,if_helper162516277);
}};
$e1628016281.stack[R.EXN_STACKHEIGHT++] = $ss1628416285;
}
if(R.isPyretException($e1628016281)) {
$e1628016281.pyretStack.push(L[2263]);
}
throw $e1628016281;
}
var $ret1628616287 = $Hcont_tail_arg887516292($z1628216283,if_helper162516277);
++R.GAS;
return $ret1628616287;
}
} else {
var cont_tail_arg162716296 = R.throwNonBooleanCondition(L[2263],("if"),if_DASH_20816293);
if(--R.GAS > 0) {
$z1629416295 = R.isFunction(if_helper162516277)?if_helper162516277.app(cont_tail_arg162716296):R.ffi.throwNonFunApp(L[2263],if_helper162516277,[cont_tail_arg162716296]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper162516277)?if_helper162516277.app(cont_tail_arg162716296):R.ffi.throwNonFunApp(L[2263],if_helper162516277,[cont_tail_arg162716296]);
},
"from":L[2263]});
}
++R.GAS;
return $z1629416295;
}
};
},{"length":3});
var anf_variant_member164612132 = R.makeMethod(function(self2071552) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2263],0,arguments);
}
var anf_arg163816260 = G(self2071552,"l",L[2263]);
var $z1625216253 = D;
var $f1625816259 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg163816260):R.ffi.throwNonFunApp(L[2263],torepr65,[anf_arg163816260]);
};
try {
if(--R.GAS > 0) {
$z1625216253 = $f1625816259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1625816259,
"from":L[2263]});
}
} catch($e1625016251) {
if(R.isCont($e1625016251)) {
var $ss1625416255 = {"from":L[2263],
"go":function(anf_arg163916261) {
return $Hanf_arg888216262(anf_arg163916261,self2071552,_plus55,torepr65);
}};
$e1625016251.stack[R.EXN_STACKHEIGHT++] = $ss1625416255;
}
if(R.isPyretException($e1625016251)) {
$e1625016251.pyretStack.push(L[2263]);
}
throw $e1625016251;
}
var $ret1625616257 = $Hanf_arg888216262($z1625216253,self2071552,_plus55,torepr65);
++R.GAS;
return $ret1625616257;
};
},{"length":1});
var anf_variant_member164812133 = R.makeMethod(function(self69116249) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2964],0,arguments);
}
var ann_DASH_check_DASH_temp164716248 = ("s-user-block");
return ann_DASH_check_DASH_temp164716248;
};
},{"length":1});
var anf_variant_member165412134 = R.makeMethod(function(self6929599) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2963],0,arguments);
}
var anf_fun165016245 = G(PP170,"surround",L[2962]);
var anf_bracket165116247 = G(self6929599,"body",L[2961]);
var anf_fun165216243 = G(anf_bracket165116247,"tosource",L[2960]);
var $z1623516236 = D;
var $f1624116242 = function(_) {
return R.isFunction(anf_fun165216243)?anf_fun165216243.app():R.ffi.throwNonFunApp(L[2959],anf_fun165216243,[]);
};
try {
if(--R.GAS > 0) {
$z1623516236 = $f1624116242();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1624116242,
"from":L[2959]});
}
} catch($e1623316234) {
if(R.isCont($e1623316234)) {
var $ss1623716238 = {"from":L[2959],
"go":function(anf_arg165316244) {
return $Hanf_arg888416246(anf_arg165316244,INDENT118169,anf_fun165016245,str_DASH_block128286,str_DASH_end148546);
}};
$e1623316234.stack[R.EXN_STACKHEIGHT++] = $ss1623716238;
}
if(R.isPyretException($e1623316234)) {
$e1623316234.pyretStack.push(L[2959]);
}
throw $e1623316234;
}
var $ret1623916240 = $Hanf_arg888416246($z1623516236,INDENT118169,anf_fun165016245,str_DASH_block128286,str_DASH_end148546);
++R.GAS;
return $ret1623916240;
};
},{"length":1});
var anf_variant_member167312142 = R.makeMethod(function(self2101509) {
return function(cases_DASH_funs21116212,else_DASH_clause21216223) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2262],2,arguments);
}
var if_DASH_21416226 = R.hasField(cases_DASH_funs21116212,("s-fun"));
var if_helper165616210 = R.makeFunction(function(if_helper_arg165716231) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2262],1,arguments);
}
var ann_DASH_check_DASH_temp165516232 = if_helper_arg165716231;
return ann_DASH_check_DASH_temp165516232;
});
var anf_if166016230 = R.isBoolean(if_DASH_21416226);
if(R.isPyretTrue(anf_if166016230)) {
if(R.isPyretTrue(if_DASH_21416226)) {
var call_DASH_s_DASH_fun20916200 = G(cases_DASH_funs21116212,"s-fun",L[2262]);
var anf_arg166316201 = G(self2101509,"l",L[2958]);
var anf_arg166416202 = G(self2101509,"name",L[2957]);
var anf_arg166516203 = G(self2101509,"params",L[2956]);
var anf_arg166616204 = G(self2101509,"args",L[2955]);
var anf_arg166716205 = G(self2101509,"ann",L[2954]);
var anf_arg166816206 = G(self2101509,"doc",L[2953]);
var anf_arg166916207 = G(self2101509,"body",L[2952]);
var anf_arg167016208 = G(self2101509,"_check",L[2951]);
var $z1619216193 = D;
var $f1619816199 = function(_) {
return R.isFunction(call_DASH_s_DASH_fun20916200)?call_DASH_s_DASH_fun20916200.app(anf_arg166316201,anf_arg166416202,anf_arg166516203,anf_arg166616204,anf_arg166716205,anf_arg166816206,anf_arg166916207,anf_arg167016208):R.ffi.throwNonFunApp(L[2262],call_DASH_s_DASH_fun20916200,[anf_arg166316201,anf_arg166416202,anf_arg166516203,anf_arg166616204,anf_arg166716205,anf_arg166816206,anf_arg166916207,anf_arg167016208]);
};
try {
if(--R.GAS > 0) {
$z1619216193 = $f1619816199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1619816199,
"from":L[2262]});
}
} catch($e1619016191) {
if(R.isCont($e1619016191)) {
var $ss1619416195 = {"from":L[2262],
"go":function(cont_tail_arg167116209) {
return $Hcont_tail_arg888516211(cont_tail_arg167116209,if_helper165616210);
}};
$e1619016191.stack[R.EXN_STACKHEIGHT++] = $ss1619416195;
}
if(R.isPyretException($e1619016191)) {
$e1619016191.pyretStack.push(L[2262]);
}
throw $e1619016191;
}
var $ret1619616197 = $Hcont_tail_arg888516211($z1619216193,if_helper165616210);
++R.GAS;
return $ret1619616197;
} else {
var $z1621516216 = D;
var $f1622116222 = function(_) {
return R.isFunction(else_DASH_clause21216223)?else_DASH_clause21216223.app():R.ffi.throwNonFunApp(L[2262],else_DASH_clause21216223,[]);
};
try {
if(--R.GAS > 0) {
$z1621516216 = $f1622116222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1622116222,
"from":L[2262]});
}
} catch($e1621316214) {
if(R.isCont($e1621316214)) {
var $ss1621716218 = {"from":L[2262],
"go":function(cont_tail_arg166116224) {
return $Hcont_tail_arg888616225(cont_tail_arg166116224,if_helper165616210);
}};
$e1621316214.stack[R.EXN_STACKHEIGHT++] = $ss1621716218;
}
if(R.isPyretException($e1621316214)) {
$e1621316214.pyretStack.push(L[2262]);
}
throw $e1621316214;
}
var $ret1621916220 = $Hcont_tail_arg888616225($z1621516216,if_helper165616210);
++R.GAS;
return $ret1621916220;
}
} else {
var cont_tail_arg165816229 = R.throwNonBooleanCondition(L[2262],("if"),if_DASH_21416226);
if(--R.GAS > 0) {
$z1622716228 = R.isFunction(if_helper165616210)?if_helper165616210.app(cont_tail_arg165816229):R.ffi.throwNonFunApp(L[2262],if_helper165616210,[cont_tail_arg165816229]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper165616210)?if_helper165616210.app(cont_tail_arg165816229):R.ffi.throwNonFunApp(L[2262],if_helper165616210,[cont_tail_arg165816229]);
},
"from":L[2262]});
}
++R.GAS;
return $z1622716228;
}
};
},{"length":3});
var anf_variant_member170712143 = R.makeMethod(function(self21316188) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2262],0,arguments);
}
var anf_arg167516186 = G(self21316188,"l",L[2262]);
var $z1617816179 = D;
var $f1618416185 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg167516186):R.ffi.throwNonFunApp(L[2262],torepr65,[anf_arg167516186]);
};
try {
if(--R.GAS > 0) {
$z1617816179 = $f1618416185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1618416185,
"from":L[2262]});
}
} catch($e1617616177) {
if(R.isCont($e1617616177)) {
var $ss1618016181 = {"from":L[2262],
"go":function(anf_arg167616187) {
return $Hanf_arg891116189(anf_arg167616187,self21316188,_plus55,torepr65);
}};
$e1617616177.stack[R.EXN_STACKHEIGHT++] = $ss1618016181;
}
if(R.isPyretException($e1617616177)) {
$e1617616177.pyretStack.push(L[2262]);
}
throw $e1617616177;
}
var $ret1618216183 = $Hanf_arg891116189($z1617816179,self21316188,_plus55,torepr65);
++R.GAS;
return $ret1618216183;
};
},{"length":1});
var anf_variant_member170912144 = R.makeMethod(function(self7019347) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2950],0,arguments);
}
var ann_DASH_check_DASH_temp170816175 = ("s-fun");
return ann_DASH_check_DASH_temp170816175;
};
},{"length":1});
var anf_variant_member171812145 = R.makeMethod(function(self70216174) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2942],0,arguments);
}
var anf_arg171116165 = G(self70216174,"name",L[2949]);
var anf_arg171216166 = G(self70216174,"params",L[2948]);
var anf_arg171316167 = G(self70216174,"args",L[2947]);
var anf_arg171416168 = G(self70216174,"ann",L[2946]);
var anf_arg171516169 = G(self70216174,"doc",L[2945]);
var anf_arg171616170 = G(self70216174,"body",L[2944]);
var anf_arg171716171 = G(self70216174,"_check",L[2943]);
var $z1615716158 = D;
var $f1616316164 = function(_) {
return R.isFunction(funlam_DASH_tosource2501801.$var)?funlam_DASH_tosource2501801.$var.app(str_DASH_fun152598,anf_arg171116165,anf_arg171216166,anf_arg171316167,anf_arg171416168,anf_arg171516169,anf_arg171616170,anf_arg171716171):R.ffi.throwNonFunApp(L[2942],funlam_DASH_tosource2501801.$var,[str_DASH_fun152598,anf_arg171116165,anf_arg171216166,anf_arg171316167,anf_arg171416168,anf_arg171516169,anf_arg171616170,anf_arg171716171]);
};
try {
if(--R.GAS > 0) {
$z1615716158 = $f1616316164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1616316164,
"from":L[2942]});
}
} catch($e1615516156) {
if(R.isCont($e1615516156)) {
var $ss1615916160 = {"from":L[2942],
"go":function(ann_DASH_check_DASH_temp171016172) {
return $Hann_DASH_check_DASH_temp891216173(ann_DASH_check_DASH_temp171016172);
}};
$e1615516156.stack[R.EXN_STACKHEIGHT++] = $ss1615916160;
}
if(R.isPyretException($e1615516156)) {
$e1615516156.pyretStack.push(L[2942]);
}
throw $e1615516156;
}
var $ret1616116162 = $Hann_DASH_check_DASH_temp891216173($z1615716158);
++R.GAS;
return $ret1616116162;
};
},{"length":1});
var anf_variant_member173212159 = R.makeMethod(function(self2161423) {
return function(cases_DASH_funs21716134,else_DASH_clause21816145) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2261],2,arguments);
}
var if_DASH_22016148 = R.hasField(cases_DASH_funs21716134,("s-type"));
var if_helper172016132 = R.makeFunction(function(if_helper_arg172116153) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2261],1,arguments);
}
var ann_DASH_check_DASH_temp171916154 = if_helper_arg172116153;
return ann_DASH_check_DASH_temp171916154;
});
var anf_if172416152 = R.isBoolean(if_DASH_22016148);
if(R.isPyretTrue(anf_if172416152)) {
if(R.isPyretTrue(if_DASH_22016148)) {
var call_DASH_s_DASH_type21516127 = G(cases_DASH_funs21716134,"s-type",L[2261]);
var anf_arg172716128 = G(self2161423,"l",L[2941]);
var anf_arg172816129 = G(self2161423,"name",L[2940]);
var anf_arg172916130 = G(self2161423,"ann",L[2939]);
var $z1611916120 = D;
var $f1612516126 = function(_) {
return R.isFunction(call_DASH_s_DASH_type21516127)?call_DASH_s_DASH_type21516127.app(anf_arg172716128,anf_arg172816129,anf_arg172916130):R.ffi.throwNonFunApp(L[2261],call_DASH_s_DASH_type21516127,[anf_arg172716128,anf_arg172816129,anf_arg172916130]);
};
try {
if(--R.GAS > 0) {
$z1611916120 = $f1612516126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1612516126,
"from":L[2261]});
}
} catch($e1611716118) {
if(R.isCont($e1611716118)) {
var $ss1612116122 = {"from":L[2261],
"go":function(cont_tail_arg173016131) {
return $Hcont_tail_arg891316133(cont_tail_arg173016131,if_helper172016132);
}};
$e1611716118.stack[R.EXN_STACKHEIGHT++] = $ss1612116122;
}
if(R.isPyretException($e1611716118)) {
$e1611716118.pyretStack.push(L[2261]);
}
throw $e1611716118;
}
var $ret1612316124 = $Hcont_tail_arg891316133($z1611916120,if_helper172016132);
++R.GAS;
return $ret1612316124;
} else {
var $z1613716138 = D;
var $f1614316144 = function(_) {
return R.isFunction(else_DASH_clause21816145)?else_DASH_clause21816145.app():R.ffi.throwNonFunApp(L[2261],else_DASH_clause21816145,[]);
};
try {
if(--R.GAS > 0) {
$z1613716138 = $f1614316144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1614316144,
"from":L[2261]});
}
} catch($e1613516136) {
if(R.isCont($e1613516136)) {
var $ss1613916140 = {"from":L[2261],
"go":function(cont_tail_arg172516146) {
return $Hcont_tail_arg891416147(cont_tail_arg172516146,if_helper172016132);
}};
$e1613516136.stack[R.EXN_STACKHEIGHT++] = $ss1613916140;
}
if(R.isPyretException($e1613516136)) {
$e1613516136.pyretStack.push(L[2261]);
}
throw $e1613516136;
}
var $ret1614116142 = $Hcont_tail_arg891416147($z1613716138,if_helper172016132);
++R.GAS;
return $ret1614116142;
}
} else {
var cont_tail_arg172216151 = R.throwNonBooleanCondition(L[2261],("if"),if_DASH_22016148);
if(--R.GAS > 0) {
$z1614916150 = R.isFunction(if_helper172016132)?if_helper172016132.app(cont_tail_arg172216151):R.ffi.throwNonFunApp(L[2261],if_helper172016132,[cont_tail_arg172216151]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper172016132)?if_helper172016132.app(cont_tail_arg172216151):R.ffi.throwNonFunApp(L[2261],if_helper172016132,[cont_tail_arg172216151]);
},
"from":L[2261]});
}
++R.GAS;
return $z1614916150;
}
};
},{"length":3});
var anf_variant_member174612160 = R.makeMethod(function(self2191404) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2261],0,arguments);
}
var anf_arg173416114 = G(self2191404,"l",L[2261]);
var $z1610616107 = D;
var $f1611216113 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg173416114):R.ffi.throwNonFunApp(L[2261],torepr65,[anf_arg173416114]);
};
try {
if(--R.GAS > 0) {
$z1610616107 = $f1611216113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1611216113,
"from":L[2261]});
}
} catch($e1610416105) {
if(R.isCont($e1610416105)) {
var $ss1610816109 = {"from":L[2261],
"go":function(anf_arg173516115) {
return $Hanf_arg892416116(anf_arg173516115,self2191404,_plus55,torepr65);
}};
$e1610416105.stack[R.EXN_STACKHEIGHT++] = $ss1610816109;
}
if(R.isPyretException($e1610416105)) {
$e1610416105.pyretStack.push(L[2261]);
}
throw $e1610416105;
}
var $ret1611016111 = $Hanf_arg892416116($z1610616107,self2191404,_plus55,torepr65);
++R.GAS;
return $ret1611016111;
};
},{"length":1});
var anf_variant_member174812161 = R.makeMethod(function(self70616103) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2938],0,arguments);
}
var ann_DASH_check_DASH_temp174716102 = ("s-type");
return ann_DASH_check_DASH_temp174716102;
};
},{"length":1});
var anf_variant_member176312162 = R.makeMethod(function(self70716099) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2937],0,arguments);
}
var anf_fun175016097 = G(PP170,"group",L[2936]);
var anf_fun175116098 = G(PP170,"nest",L[2935]);
var anf_bracket175216101 = G(self70716099,"name",L[2934]);
var anf_fun175316095 = G(anf_bracket175216101,"tosource",L[2933]);
var $z1608716088 = D;
var $f1609316094 = function(_) {
return R.isFunction(anf_fun175316095)?anf_fun175316095.app():R.ffi.throwNonFunApp(L[2932],anf_fun175316095,[]);
};
try {
if(--R.GAS > 0) {
$z1608716088 = $f1609316094();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1609316094,
"from":L[2932]});
}
} catch($e1608516086) {
if(R.isCont($e1608516086)) {
var $ss1608916090 = {"from":L[2932],
"go":function(anf_arg175416096) {
return $Hanf_arg893216100(anf_arg175416096,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,str_DASH_spaceequal170832,str_DASH_type177923,_plus55);
}};
$e1608516086.stack[R.EXN_STACKHEIGHT++] = $ss1608916090;
}
if(R.isPyretException($e1608516086)) {
$e1608516086.pyretStack.push(L[2932]);
}
throw $e1608516086;
}
var $ret1609116092 = $Hanf_arg893216100($z1608716088,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,str_DASH_spaceequal170832,str_DASH_type177923,_plus55);
++R.GAS;
return $ret1609116092;
};
},{"length":1});
var anf_variant_member177712171 = R.makeMethod(function(self2221324) {
return function(cases_DASH_funs22316064,else_DASH_clause22416075) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2260],2,arguments);
}
var if_DASH_22616078 = R.hasField(cases_DASH_funs22316064,("s-newtype"));
var if_helper176516062 = R.makeFunction(function(if_helper_arg176616083) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2260],1,arguments);
}
var ann_DASH_check_DASH_temp176416084 = if_helper_arg176616083;
return ann_DASH_check_DASH_temp176416084;
});
var anf_if176916082 = R.isBoolean(if_DASH_22616078);
if(R.isPyretTrue(anf_if176916082)) {
if(R.isPyretTrue(if_DASH_22616078)) {
var call_DASH_s_DASH_newtype22116057 = G(cases_DASH_funs22316064,"s-newtype",L[2260]);
var anf_arg177216058 = G(self2221324,"l",L[2931]);
var anf_arg177316059 = G(self2221324,"name",L[2930]);
var anf_arg177416060 = G(self2221324,"namet",L[2929]);
var $z1604916050 = D;
var $f1605516056 = function(_) {
return R.isFunction(call_DASH_s_DASH_newtype22116057)?call_DASH_s_DASH_newtype22116057.app(anf_arg177216058,anf_arg177316059,anf_arg177416060):R.ffi.throwNonFunApp(L[2260],call_DASH_s_DASH_newtype22116057,[anf_arg177216058,anf_arg177316059,anf_arg177416060]);
};
try {
if(--R.GAS > 0) {
$z1604916050 = $f1605516056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1605516056,
"from":L[2260]});
}
} catch($e1604716048) {
if(R.isCont($e1604716048)) {
var $ss1605116052 = {"from":L[2260],
"go":function(cont_tail_arg177516061) {
return $Hcont_tail_arg893316063(cont_tail_arg177516061,if_helper176516062);
}};
$e1604716048.stack[R.EXN_STACKHEIGHT++] = $ss1605116052;
}
if(R.isPyretException($e1604716048)) {
$e1604716048.pyretStack.push(L[2260]);
}
throw $e1604716048;
}
var $ret1605316054 = $Hcont_tail_arg893316063($z1604916050,if_helper176516062);
++R.GAS;
return $ret1605316054;
} else {
var $z1606716068 = D;
var $f1607316074 = function(_) {
return R.isFunction(else_DASH_clause22416075)?else_DASH_clause22416075.app():R.ffi.throwNonFunApp(L[2260],else_DASH_clause22416075,[]);
};
try {
if(--R.GAS > 0) {
$z1606716068 = $f1607316074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1607316074,
"from":L[2260]});
}
} catch($e1606516066) {
if(R.isCont($e1606516066)) {
var $ss1606916070 = {"from":L[2260],
"go":function(cont_tail_arg177016076) {
return $Hcont_tail_arg893416077(cont_tail_arg177016076,if_helper176516062);
}};
$e1606516066.stack[R.EXN_STACKHEIGHT++] = $ss1606916070;
}
if(R.isPyretException($e1606516066)) {
$e1606516066.pyretStack.push(L[2260]);
}
throw $e1606516066;
}
var $ret1607116072 = $Hcont_tail_arg893416077($z1606716068,if_helper176516062);
++R.GAS;
return $ret1607116072;
}
} else {
var cont_tail_arg176716081 = R.throwNonBooleanCondition(L[2260],("if"),if_DASH_22616078);
if(--R.GAS > 0) {
$z1607916080 = R.isFunction(if_helper176516062)?if_helper176516062.app(cont_tail_arg176716081):R.ffi.throwNonFunApp(L[2260],if_helper176516062,[cont_tail_arg176716081]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper176516062)?if_helper176516062.app(cont_tail_arg176716081):R.ffi.throwNonFunApp(L[2260],if_helper176516062,[cont_tail_arg176716081]);
},
"from":L[2260]});
}
++R.GAS;
return $z1607916080;
}
};
},{"length":3});
var anf_variant_member179112172 = R.makeMethod(function(self2251281) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2260],0,arguments);
}
var anf_arg177916044 = G(self2251281,"l",L[2260]);
var $z1603616037 = D;
var $f1604216043 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg177916044):R.ffi.throwNonFunApp(L[2260],torepr65,[anf_arg177916044]);
};
try {
if(--R.GAS > 0) {
$z1603616037 = $f1604216043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1604216043,
"from":L[2260]});
}
} catch($e1603416035) {
if(R.isCont($e1603416035)) {
var $ss1603816039 = {"from":L[2260],
"go":function(anf_arg178016045) {
return $Hanf_arg894416046(anf_arg178016045,self2251281,_plus55,torepr65);
}};
$e1603416035.stack[R.EXN_STACKHEIGHT++] = $ss1603816039;
}
if(R.isPyretException($e1603416035)) {
$e1603416035.pyretStack.push(L[2260]);
}
throw $e1603416035;
}
var $ret1604016041 = $Hanf_arg894416046($z1603616037,self2251281,_plus55,torepr65);
++R.GAS;
return $ret1604016041;
};
},{"length":1});
var anf_variant_member179312173 = R.makeMethod(function(self71116033) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2928],0,arguments);
}
var ann_DASH_check_DASH_temp179216032 = ("s-newtype");
return ann_DASH_check_DASH_temp179216032;
};
},{"length":1});
var anf_variant_member180912174 = R.makeMethod(function(self71216029) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2927],0,arguments);
}
var anf_fun179516027 = G(PP170,"group",L[2926]);
var anf_fun179616028 = G(PP170,"nest",L[2925]);
var anf_bracket179716031 = G(self71216029,"name",L[2924]);
var anf_fun179816025 = G(anf_bracket179716031,"tosource",L[2923]);
var $z1601716018 = D;
var $f1602316024 = function(_) {
return R.isFunction(anf_fun179816025)?anf_fun179816025.app():R.ffi.throwNonFunApp(L[2922],anf_fun179816025,[]);
};
try {
if(--R.GAS > 0) {
$z1601716018 = $f1602316024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1602316024,
"from":L[2922]});
}
} catch($e1601516016) {
if(R.isCont($e1601516016)) {
var $ss1601916020 = {"from":L[2922],
"go":function(anf_arg179916026) {
return $Hanf_arg895316030(anf_arg179916026,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,str_DASH_newtype176910,_plus55);
}};
$e1601516016.stack[R.EXN_STACKHEIGHT++] = $ss1601916020;
}
if(R.isPyretException($e1601516016)) {
$e1601516016.pyretStack.push(L[2922]);
}
throw $e1601516016;
}
var $ret1602116022 = $Hanf_arg895316030($z1601716018,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,str_DASH_newtype176910,_plus55);
++R.GAS;
return $ret1602116022;
};
},{"length":1});
var anf_variant_member182312183 = R.makeMethod(function(self22815993) {
return function(cases_DASH_funs22915994,else_DASH_clause23016005) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2259],2,arguments);
}
var if_DASH_23216008 = R.hasField(cases_DASH_funs22915994,("s-var"));
var if_helper181115991 = R.makeFunction(function(if_helper_arg181216013) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2259],1,arguments);
}
var ann_DASH_check_DASH_temp181016014 = if_helper_arg181216013;
return ann_DASH_check_DASH_temp181016014;
});
var anf_if181516012 = R.isBoolean(if_DASH_23216008);
if(R.isPyretTrue(anf_if181516012)) {
if(R.isPyretTrue(if_DASH_23216008)) {
var call_DASH_s_DASH_var22715986 = G(cases_DASH_funs22915994,"s-var",L[2259]);
var anf_arg181815987 = G(self22815993,"l",L[2921]);
var anf_arg181915988 = G(self22815993,"name",L[2920]);
var anf_arg182015989 = G(self22815993,"value",L[2919]);
var $z1597815979 = D;
var $f1598415985 = function(_) {
return R.isFunction(call_DASH_s_DASH_var22715986)?call_DASH_s_DASH_var22715986.app(anf_arg181815987,anf_arg181915988,anf_arg182015989):R.ffi.throwNonFunApp(L[2259],call_DASH_s_DASH_var22715986,[anf_arg181815987,anf_arg181915988,anf_arg182015989]);
};
try {
if(--R.GAS > 0) {
$z1597815979 = $f1598415985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1598415985,
"from":L[2259]});
}
} catch($e1597615977) {
if(R.isCont($e1597615977)) {
var $ss1598015981 = {"from":L[2259],
"go":function(cont_tail_arg182115990) {
return $Hcont_tail_arg895415992(cont_tail_arg182115990,if_helper181115991);
}};
$e1597615977.stack[R.EXN_STACKHEIGHT++] = $ss1598015981;
}
if(R.isPyretException($e1597615977)) {
$e1597615977.pyretStack.push(L[2259]);
}
throw $e1597615977;
}
var $ret1598215983 = $Hcont_tail_arg895415992($z1597815979,if_helper181115991);
++R.GAS;
return $ret1598215983;
} else {
var $z1599715998 = D;
var $f1600316004 = function(_) {
return R.isFunction(else_DASH_clause23016005)?else_DASH_clause23016005.app():R.ffi.throwNonFunApp(L[2259],else_DASH_clause23016005,[]);
};
try {
if(--R.GAS > 0) {
$z1599715998 = $f1600316004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1600316004,
"from":L[2259]});
}
} catch($e1599515996) {
if(R.isCont($e1599515996)) {
var $ss1599916000 = {"from":L[2259],
"go":function(cont_tail_arg181616006) {
return $Hcont_tail_arg895516007(cont_tail_arg181616006,if_helper181115991);
}};
$e1599515996.stack[R.EXN_STACKHEIGHT++] = $ss1599916000;
}
if(R.isPyretException($e1599515996)) {
$e1599515996.pyretStack.push(L[2259]);
}
throw $e1599515996;
}
var $ret1600116002 = $Hcont_tail_arg895516007($z1599715998,if_helper181115991);
++R.GAS;
return $ret1600116002;
}
} else {
var cont_tail_arg181316011 = R.throwNonBooleanCondition(L[2259],("if"),if_DASH_23216008);
if(--R.GAS > 0) {
$z1600916010 = R.isFunction(if_helper181115991)?if_helper181115991.app(cont_tail_arg181316011):R.ffi.throwNonFunApp(L[2259],if_helper181115991,[cont_tail_arg181316011]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper181115991)?if_helper181115991.app(cont_tail_arg181316011):R.ffi.throwNonFunApp(L[2259],if_helper181115991,[cont_tail_arg181316011]);
},
"from":L[2259]});
}
++R.GAS;
return $z1600916010;
}
};
},{"length":3});
var anf_variant_member183712184 = R.makeMethod(function(self2311182) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2259],0,arguments);
}
var anf_arg182515973 = G(self2311182,"l",L[2259]);
var $z1596515966 = D;
var $f1597115972 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg182515973):R.ffi.throwNonFunApp(L[2259],torepr65,[anf_arg182515973]);
};
try {
if(--R.GAS > 0) {
$z1596515966 = $f1597115972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1597115972,
"from":L[2259]});
}
} catch($e1596315964) {
if(R.isCont($e1596315964)) {
var $ss1596715968 = {"from":L[2259],
"go":function(anf_arg182615974) {
return $Hanf_arg896515975(anf_arg182615974,self2311182,_plus55,torepr65);
}};
$e1596315964.stack[R.EXN_STACKHEIGHT++] = $ss1596715968;
}
if(R.isPyretException($e1596315964)) {
$e1596315964.pyretStack.push(L[2259]);
}
throw $e1596315964;
}
var $ret1596915970 = $Hanf_arg896515975($z1596515966,self2311182,_plus55,torepr65);
++R.GAS;
return $ret1596915970;
};
},{"length":1});
var anf_variant_member183912185 = R.makeMethod(function(self71615962) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2918],0,arguments);
}
var ann_DASH_check_DASH_temp183815961 = ("s-var");
return ann_DASH_check_DASH_temp183815961;
};
},{"length":1});
var anf_variant_member185412186 = R.makeMethod(function(self71715958) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2917],0,arguments);
}
var anf_fun184115956 = G(PP170,"group",L[2916]);
var anf_fun184215957 = G(PP170,"nest",L[2915]);
var anf_bracket184315960 = G(self71715958,"name",L[2914]);
var anf_fun184415954 = G(anf_bracket184315960,"tosource",L[2913]);
var $z1594615947 = D;
var $f1595215953 = function(_) {
return R.isFunction(anf_fun184415954)?anf_fun184415954.app():R.ffi.throwNonFunApp(L[2912],anf_fun184415954,[]);
};
try {
if(--R.GAS > 0) {
$z1594615947 = $f1595215953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1595215953,
"from":L[2912]});
}
} catch($e1594415945) {
if(R.isCont($e1594415945)) {
var $ss1594815949 = {"from":L[2912],
"go":function(anf_arg184515955) {
return $Hanf_arg897315959(anf_arg184515955,INDENT118169,anf_fun184115956,anf_fun184215957,break_DASH_one119168,self71715958,str_DASH_spaceequal170832,str_DASH_var175897,_plus55);
}};
$e1594415945.stack[R.EXN_STACKHEIGHT++] = $ss1594815949;
}
if(R.isPyretException($e1594415945)) {
$e1594415945.pyretStack.push(L[2912]);
}
throw $e1594415945;
}
var $ret1595015951 = $Hanf_arg897315959($z1594615947,INDENT118169,anf_fun184115956,anf_fun184215957,break_DASH_one119168,self71715958,str_DASH_spaceequal170832,str_DASH_var175897,_plus55);
++R.GAS;
return $ret1595015951;
};
},{"length":1});
var anf_variant_member186912195 = R.makeMethod(function(self2341150) {
return function(cases_DASH_funs23515923,else_DASH_clause23615934) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2258],2,arguments);
}
var if_DASH_23815937 = R.hasField(cases_DASH_funs23515923,("s-let"));
var if_helper185615921 = R.makeFunction(function(if_helper_arg185715942) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2258],1,arguments);
}
var ann_DASH_check_DASH_temp185515943 = if_helper_arg185715942;
return ann_DASH_check_DASH_temp185515943;
});
var anf_if186015941 = R.isBoolean(if_DASH_23815937);
if(R.isPyretTrue(anf_if186015941)) {
if(R.isPyretTrue(if_DASH_23815937)) {
var call_DASH_s_DASH_let23315915 = G(cases_DASH_funs23515923,"s-let",L[2258]);
var anf_arg186315916 = G(self2341150,"l",L[2911]);
var anf_arg186415917 = G(self2341150,"name",L[2910]);
var anf_arg186515918 = G(self2341150,"value",L[2909]);
var anf_arg186615919 = G(self2341150,"keyword-val",L[2908]);
var $z1590715908 = D;
var $f1591315914 = function(_) {
return R.isFunction(call_DASH_s_DASH_let23315915)?call_DASH_s_DASH_let23315915.app(anf_arg186315916,anf_arg186415917,anf_arg186515918,anf_arg186615919):R.ffi.throwNonFunApp(L[2258],call_DASH_s_DASH_let23315915,[anf_arg186315916,anf_arg186415917,anf_arg186515918,anf_arg186615919]);
};
try {
if(--R.GAS > 0) {
$z1590715908 = $f1591315914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1591315914,
"from":L[2258]});
}
} catch($e1590515906) {
if(R.isCont($e1590515906)) {
var $ss1590915910 = {"from":L[2258],
"go":function(cont_tail_arg186715920) {
return $Hcont_tail_arg897415922(cont_tail_arg186715920,if_helper185615921);
}};
$e1590515906.stack[R.EXN_STACKHEIGHT++] = $ss1590915910;
}
if(R.isPyretException($e1590515906)) {
$e1590515906.pyretStack.push(L[2258]);
}
throw $e1590515906;
}
var $ret1591115912 = $Hcont_tail_arg897415922($z1590715908,if_helper185615921);
++R.GAS;
return $ret1591115912;
} else {
var $z1592615927 = D;
var $f1593215933 = function(_) {
return R.isFunction(else_DASH_clause23615934)?else_DASH_clause23615934.app():R.ffi.throwNonFunApp(L[2258],else_DASH_clause23615934,[]);
};
try {
if(--R.GAS > 0) {
$z1592615927 = $f1593215933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1593215933,
"from":L[2258]});
}
} catch($e1592415925) {
if(R.isCont($e1592415925)) {
var $ss1592815929 = {"from":L[2258],
"go":function(cont_tail_arg186115935) {
return $Hcont_tail_arg897515936(cont_tail_arg186115935,if_helper185615921);
}};
$e1592415925.stack[R.EXN_STACKHEIGHT++] = $ss1592815929;
}
if(R.isPyretException($e1592415925)) {
$e1592415925.pyretStack.push(L[2258]);
}
throw $e1592415925;
}
var $ret1593015931 = $Hcont_tail_arg897515936($z1592615927,if_helper185615921);
++R.GAS;
return $ret1593015931;
}
} else {
var cont_tail_arg185815940 = R.throwNonBooleanCondition(L[2258],("if"),if_DASH_23815937);
if(--R.GAS > 0) {
$z1593815939 = R.isFunction(if_helper185615921)?if_helper185615921.app(cont_tail_arg185815940):R.ffi.throwNonFunApp(L[2258],if_helper185615921,[cont_tail_arg185815940]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper185615921)?if_helper185615921.app(cont_tail_arg185815940):R.ffi.throwNonFunApp(L[2258],if_helper185615921,[cont_tail_arg185815940]);
},
"from":L[2258]});
}
++R.GAS;
return $z1593815939;
}
};
},{"length":3});
var anf_variant_member188712196 = R.makeMethod(function(self2371785) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2258],0,arguments);
}
var anf_arg187115902 = G(self2371785,"l",L[2258]);
var $z1589415895 = D;
var $f1590015901 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg187115902):R.ffi.throwNonFunApp(L[2258],torepr65,[anf_arg187115902]);
};
try {
if(--R.GAS > 0) {
$z1589415895 = $f1590015901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1590015901,
"from":L[2258]});
}
} catch($e1589215893) {
if(R.isCont($e1589215893)) {
var $ss1589615897 = {"from":L[2258],
"go":function(anf_arg187215903) {
return $Hanf_arg898815904(anf_arg187215903,self2371785,_plus55,torepr65);
}};
$e1589215893.stack[R.EXN_STACKHEIGHT++] = $ss1589615897;
}
if(R.isPyretException($e1589215893)) {
$e1589215893.pyretStack.push(L[2258]);
}
throw $e1589215893;
}
var $ret1589815899 = $Hanf_arg898815904($z1589415895,self2371785,_plus55,torepr65);
++R.GAS;
return $ret1589815899;
};
},{"length":1});
var anf_variant_member188912197 = R.makeMethod(function(self72215891) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2907],0,arguments);
}
var ann_DASH_check_DASH_temp188815890 = ("s-let");
return ann_DASH_check_DASH_temp188815890;
};
},{"length":1});
var anf_variant_member191212198 = R.makeMethod(function(self72315887) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2906],0,arguments);
}
var anf_fun189115885 = G(PP170,"group",L[2905]);
var anf_fun189215886 = G(PP170,"nest",L[2904]);
var if_DASH_23915867 = G(self72315887,"keyword-val",L[2900]);
var if_helper189315861 = R.makeFunction(function(if_helper_arg189415872) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2900],1,arguments);
}
var anf_bracket189515889 = G(self72315887,"name",L[2903]);
var anf_fun189615883 = G(anf_bracket189515889,"tosource",L[2902]);
var $z1587515876 = D;
var $f1588115882 = function(_) {
return R.isFunction(anf_fun189615883)?anf_fun189615883.app():R.ffi.throwNonFunApp(L[2901],anf_fun189615883,[]);
};
try {
if(--R.GAS > 0) {
$z1587515876 = $f1588115882();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1588115882,
"from":L[2901]});
}
} catch($e1587315874) {
if(R.isCont($e1587315874)) {
var $ss1587715878 = {"from":L[2901],
"go":function(anf_arg189715884) {
return $Hanf_arg899615888(anf_arg189715884,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,if_helper_arg189415872,self72315887,str_DASH_spaceequal170832,_plus55);
}};
$e1587315874.stack[R.EXN_STACKHEIGHT++] = $ss1587715878;
}
if(R.isPyretException($e1587315874)) {
$e1587315874.pyretStack.push(L[2901]);
}
throw $e1587315874;
}
var $ret1587915880 = $Hanf_arg899615888($z1587515876,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,if_helper_arg189415872,self72315887,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret1587915880;
});
var anf_if190815871 = R.isBoolean(if_DASH_23915867);
if(R.isPyretTrue(anf_if190815871)) {
if(R.isPyretTrue(if_DASH_23915867)) {
var $z1585315854 = D;
var $f1585915860 = function(_) {
return R.isFunction(if_helper189315861)?if_helper189315861.app(str_DASH_val180962):R.ffi.throwNonFunApp(L[2898],if_helper189315861,[str_DASH_val180962]);
};
try {
if(--R.GAS > 0) {
$z1585315854 = $f1585915860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1585915860,
"from":L[2898]});
}
} catch($e1585115852) {
if(R.isCont($e1585115852)) {
var $ss1585515856 = {"from":L[2898],
"go":function(cont_tail_app191115862) {
return $Hcont_tail_app899715863(cont_tail_app191115862);
}};
$e1585115852.stack[R.EXN_STACKHEIGHT++] = $ss1585515856;
}
if(R.isPyretException($e1585115852)) {
$e1585115852.pyretStack.push(L[2898]);
}
throw $e1585115852;
}
var $ret1585715858 = $Hcont_tail_app899715863($z1585315854);
++R.GAS;
return $ret1585715858;
} else {
var cont_tail_arg190915866 = G(PP170,"mt-doc",L[2899]);
if(--R.GAS > 0) {
$z1586415865 = R.isFunction(if_helper189315861)?if_helper189315861.app(cont_tail_arg190915866):R.ffi.throwNonFunApp(L[2899],if_helper189315861,[cont_tail_arg190915866]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper189315861)?if_helper189315861.app(cont_tail_arg190915866):R.ffi.throwNonFunApp(L[2899],if_helper189315861,[cont_tail_arg190915866]);
},
"from":L[2899]});
}
++R.GAS;
return $z1586415865;
}
} else {
var cont_tail_arg190615870 = R.throwNonBooleanCondition(L[2900],("if"),if_DASH_23915867);
if(--R.GAS > 0) {
$z1586815869 = R.isFunction(if_helper189315861)?if_helper189315861.app(cont_tail_arg190615870):R.ffi.throwNonFunApp(L[2900],if_helper189315861,[cont_tail_arg190615870]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper189315861)?if_helper189315861.app(cont_tail_arg190615870):R.ffi.throwNonFunApp(L[2900],if_helper189315861,[cont_tail_arg190615870]);
},
"from":L[2900]});
}
++R.GAS;
return $z1586815869;
}
};
},{"length":1});
var anf_variant_member192512208 = R.makeMethod(function(self2411755) {
return function(cases_DASH_funs24215830,else_DASH_clause24315841) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2257],2,arguments);
}
var if_DASH_24515844 = R.hasField(cases_DASH_funs24215830,("s-graph"));
var if_helper191415828 = R.makeFunction(function(if_helper_arg191515849) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2257],1,arguments);
}
var ann_DASH_check_DASH_temp191315850 = if_helper_arg191515849;
return ann_DASH_check_DASH_temp191315850;
});
var anf_if191815848 = R.isBoolean(if_DASH_24515844);
if(R.isPyretTrue(anf_if191815848)) {
if(R.isPyretTrue(if_DASH_24515844)) {
var call_DASH_s_DASH_graph24015824 = G(cases_DASH_funs24215830,"s-graph",L[2257]);
var anf_arg192115825 = G(self2411755,"l",L[2897]);
var anf_arg192215826 = G(self2411755,"bindings",L[2896]);
var $z1581615817 = D;
var $f1582215823 = function(_) {
return R.isFunction(call_DASH_s_DASH_graph24015824)?call_DASH_s_DASH_graph24015824.app(anf_arg192115825,anf_arg192215826):R.ffi.throwNonFunApp(L[2257],call_DASH_s_DASH_graph24015824,[anf_arg192115825,anf_arg192215826]);
};
try {
if(--R.GAS > 0) {
$z1581615817 = $f1582215823();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1582215823,
"from":L[2257]});
}
} catch($e1581415815) {
if(R.isCont($e1581415815)) {
var $ss1581815819 = {"from":L[2257],
"go":function(cont_tail_arg192315827) {
return $Hcont_tail_arg899815829(cont_tail_arg192315827,if_helper191415828);
}};
$e1581415815.stack[R.EXN_STACKHEIGHT++] = $ss1581815819;
}
if(R.isPyretException($e1581415815)) {
$e1581415815.pyretStack.push(L[2257]);
}
throw $e1581415815;
}
var $ret1582015821 = $Hcont_tail_arg899815829($z1581615817,if_helper191415828);
++R.GAS;
return $ret1582015821;
} else {
var $z1583315834 = D;
var $f1583915840 = function(_) {
return R.isFunction(else_DASH_clause24315841)?else_DASH_clause24315841.app():R.ffi.throwNonFunApp(L[2257],else_DASH_clause24315841,[]);
};
try {
if(--R.GAS > 0) {
$z1583315834 = $f1583915840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1583915840,
"from":L[2257]});
}
} catch($e1583115832) {
if(R.isCont($e1583115832)) {
var $ss1583515836 = {"from":L[2257],
"go":function(cont_tail_arg191915842) {
return $Hcont_tail_arg899915843(cont_tail_arg191915842,if_helper191415828);
}};
$e1583115832.stack[R.EXN_STACKHEIGHT++] = $ss1583515836;
}
if(R.isPyretException($e1583115832)) {
$e1583115832.pyretStack.push(L[2257]);
}
throw $e1583115832;
}
var $ret1583715838 = $Hcont_tail_arg899915843($z1583315834,if_helper191415828);
++R.GAS;
return $ret1583715838;
}
} else {
var cont_tail_arg191615847 = R.throwNonBooleanCondition(L[2257],("if"),if_DASH_24515844);
if(--R.GAS > 0) {
$z1584515846 = R.isFunction(if_helper191415828)?if_helper191415828.app(cont_tail_arg191615847):R.ffi.throwNonFunApp(L[2257],if_helper191415828,[cont_tail_arg191615847]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper191415828)?if_helper191415828.app(cont_tail_arg191615847):R.ffi.throwNonFunApp(L[2257],if_helper191415828,[cont_tail_arg191615847]);
},
"from":L[2257]});
}
++R.GAS;
return $z1584515846;
}
};
},{"length":3});
var anf_variant_member193512209 = R.makeMethod(function(self24415812) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2257],0,arguments);
}
var anf_arg192715810 = G(self24415812,"l",L[2257]);
var $z1580215803 = D;
var $f1580815809 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg192715810):R.ffi.throwNonFunApp(L[2257],torepr65,[anf_arg192715810]);
};
try {
if(--R.GAS > 0) {
$z1580215803 = $f1580815809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1580815809,
"from":L[2257]});
}
} catch($e1580015801) {
if(R.isCont($e1580015801)) {
var $ss1580415805 = {"from":L[2257],
"go":function(anf_arg192815811) {
return $Hanf_arg900615813(anf_arg192815811,self24415812,_plus55,torepr65);
}};
$e1580015801.stack[R.EXN_STACKHEIGHT++] = $ss1580415805;
}
if(R.isPyretException($e1580015801)) {
$e1580015801.pyretStack.push(L[2257]);
}
throw $e1580015801;
}
var $ret1580615807 = $Hanf_arg900615813($z1580215803,self24415812,_plus55,torepr65);
++R.GAS;
return $ret1580615807;
};
},{"length":1});
var anf_variant_member193712210 = R.makeMethod(function(self72615799) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2895],0,arguments);
}
var ann_DASH_check_DASH_temp193615798 = ("s-graph");
return ann_DASH_check_DASH_temp193615798;
};
},{"length":1});
var anf_variant_member194712211 = R.makeMethod(function(self72715783) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2894],0,arguments);
}
var anf_fun193915781 = G(PP170,"soft-surround",L[2893]);
var anf_fun194015776 = G(PP170,"flow-map",L[2892]);
var anf_arg194115777 = G(PP170,"hardline",L[2891]);
var anf_arg194415778 = R.makeFunction(function(recv_DASH_24615784) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2890],1,arguments);
}
var anf_fun194315795 = G(recv_DASH_24615784,"tosource",L[2890]);
var $z1578715788 = D;
var $f1579315794 = function(_) {
return R.isFunction(anf_fun194315795)?anf_fun194315795.app():R.ffi.throwNonFunApp(L[2890],anf_fun194315795,[]);
};
try {
if(--R.GAS > 0) {
$z1578715788 = $f1579315794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1579315794,
"from":L[2890]});
}
} catch($e1578515786) {
if(R.isCont($e1578515786)) {
var $ss1578915790 = {"from":L[2890],
"go":function(ann_DASH_check_DASH_temp194215796) {
return $Hann_DASH_check_DASH_temp900715797(ann_DASH_check_DASH_temp194215796);
}};
$e1578515786.stack[R.EXN_STACKHEIGHT++] = $ss1578915790;
}
if(R.isPyretException($e1578515786)) {
$e1578515786.pyretStack.push(L[2890]);
}
throw $e1578515786;
}
var $ret1579115792 = $Hann_DASH_check_DASH_temp900715797($z1578715788);
++R.GAS;
return $ret1579115792;
});
var anf_arg194515779 = G(self72715783,"bindings",L[2889]);
var $z1576815769 = D;
var $f1577415775 = function(_) {
return R.isFunction(anf_fun194015776)?anf_fun194015776.app(anf_arg194115777,anf_arg194415778,anf_arg194515779):R.ffi.throwNonFunApp(L[2888],anf_fun194015776,[anf_arg194115777,anf_arg194415778,anf_arg194515779]);
};
try {
if(--R.GAS > 0) {
$z1576815769 = $f1577415775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1577415775,
"from":L[2888]});
}
} catch($e1576615767) {
if(R.isCont($e1576615767)) {
var $ss1577015771 = {"from":L[2888],
"go":function(anf_arg194615780) {
return $Hanf_arg900915782(anf_arg194615780,anf_fun193915781,str_DASH_end148546,str_DASH_graph154624);
}};
$e1576615767.stack[R.EXN_STACKHEIGHT++] = $ss1577015771;
}
if(R.isPyretException($e1576615767)) {
$e1576615767.pyretStack.push(L[2888]);
}
throw $e1576615767;
}
var $ret1577215773 = $Hanf_arg900915782($z1576815769,anf_fun193915781,str_DASH_end148546,str_DASH_graph154624);
++R.GAS;
return $ret1577215773;
};
},{"length":1});
var anf_variant_member196112219 = R.makeMethod(function(self24815744) {
return function(cases_DASH_funs24915745,else_DASH_clause25015756) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2256],2,arguments);
}
var if_DASH_25215759 = R.hasField(cases_DASH_funs24915745,("s-contract"));
var if_helper194915742 = R.makeFunction(function(if_helper_arg195015764) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2256],1,arguments);
}
var ann_DASH_check_DASH_temp194815765 = if_helper_arg195015764;
return ann_DASH_check_DASH_temp194815765;
});
var anf_if195315763 = R.isBoolean(if_DASH_25215759);
if(R.isPyretTrue(anf_if195315763)) {
if(R.isPyretTrue(if_DASH_25215759)) {
var call_DASH_s_DASH_contract24715737 = G(cases_DASH_funs24915745,"s-contract",L[2256]);
var anf_arg195615738 = G(self24815744,"l",L[2887]);
var anf_arg195715739 = G(self24815744,"name",L[2886]);
var anf_arg195815740 = G(self24815744,"ann",L[2885]);
var $z1572915730 = D;
var $f1573515736 = function(_) {
return R.isFunction(call_DASH_s_DASH_contract24715737)?call_DASH_s_DASH_contract24715737.app(anf_arg195615738,anf_arg195715739,anf_arg195815740):R.ffi.throwNonFunApp(L[2256],call_DASH_s_DASH_contract24715737,[anf_arg195615738,anf_arg195715739,anf_arg195815740]);
};
try {
if(--R.GAS > 0) {
$z1572915730 = $f1573515736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1573515736,
"from":L[2256]});
}
} catch($e1572715728) {
if(R.isCont($e1572715728)) {
var $ss1573115732 = {"from":L[2256],
"go":function(cont_tail_arg195915741) {
return $Hcont_tail_arg901015743(cont_tail_arg195915741,if_helper194915742);
}};
$e1572715728.stack[R.EXN_STACKHEIGHT++] = $ss1573115732;
}
if(R.isPyretException($e1572715728)) {
$e1572715728.pyretStack.push(L[2256]);
}
throw $e1572715728;
}
var $ret1573315734 = $Hcont_tail_arg901015743($z1572915730,if_helper194915742);
++R.GAS;
return $ret1573315734;
} else {
var $z1574815749 = D;
var $f1575415755 = function(_) {
return R.isFunction(else_DASH_clause25015756)?else_DASH_clause25015756.app():R.ffi.throwNonFunApp(L[2256],else_DASH_clause25015756,[]);
};
try {
if(--R.GAS > 0) {
$z1574815749 = $f1575415755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1575415755,
"from":L[2256]});
}
} catch($e1574615747) {
if(R.isCont($e1574615747)) {
var $ss1575015751 = {"from":L[2256],
"go":function(cont_tail_arg195415757) {
return $Hcont_tail_arg901115758(cont_tail_arg195415757,if_helper194915742);
}};
$e1574615747.stack[R.EXN_STACKHEIGHT++] = $ss1575015751;
}
if(R.isPyretException($e1574615747)) {
$e1574615747.pyretStack.push(L[2256]);
}
throw $e1574615747;
}
var $ret1575215753 = $Hcont_tail_arg901115758($z1574815749,if_helper194915742);
++R.GAS;
return $ret1575215753;
}
} else {
var cont_tail_arg195115762 = R.throwNonBooleanCondition(L[2256],("if"),if_DASH_25215759);
if(--R.GAS > 0) {
$z1576015761 = R.isFunction(if_helper194915742)?if_helper194915742.app(cont_tail_arg195115762):R.ffi.throwNonFunApp(L[2256],if_helper194915742,[cont_tail_arg195115762]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper194915742)?if_helper194915742.app(cont_tail_arg195115762):R.ffi.throwNonFunApp(L[2256],if_helper194915742,[cont_tail_arg195115762]);
},
"from":L[2256]});
}
++R.GAS;
return $z1576015761;
}
};
},{"length":3});
var anf_variant_member197512220 = R.makeMethod(function(self25115725) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2256],0,arguments);
}
var anf_arg196315723 = G(self25115725,"l",L[2256]);
var $z1571515716 = D;
var $f1572115722 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg196315723):R.ffi.throwNonFunApp(L[2256],torepr65,[anf_arg196315723]);
};
try {
if(--R.GAS > 0) {
$z1571515716 = $f1572115722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1572115722,
"from":L[2256]});
}
} catch($e1571315714) {
if(R.isCont($e1571315714)) {
var $ss1571715718 = {"from":L[2256],
"go":function(anf_arg196415724) {
return $Hanf_arg902115726(anf_arg196415724,self25115725,_plus55,torepr65);
}};
$e1571315714.stack[R.EXN_STACKHEIGHT++] = $ss1571715718;
}
if(R.isPyretException($e1571315714)) {
$e1571315714.pyretStack.push(L[2256]);
}
throw $e1571315714;
}
var $ret1571915720 = $Hanf_arg902115726($z1571515716,self25115725,_plus55,torepr65);
++R.GAS;
return $ret1571915720;
};
},{"length":1});
var anf_variant_member197712221 = R.makeMethod(function(self73115712) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2884],0,arguments);
}
var ann_DASH_check_DASH_temp197615711 = ("s-contract");
return ann_DASH_check_DASH_temp197615711;
};
},{"length":1});
var anf_variant_member198612222 = R.makeMethod(function(self73215708) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2883],0,arguments);
}
var anf_fun197915707 = G(PP170,"infix",L[2882]);
var anf_bracket198015710 = G(self73215708,"name",L[2881]);
var anf_fun198115705 = G(anf_bracket198015710,"tosource",L[2880]);
var $z1569715698 = D;
var $f1570315704 = function(_) {
return R.isFunction(anf_fun198115705)?anf_fun198115705.app():R.ffi.throwNonFunApp(L[2879],anf_fun198115705,[]);
};
try {
if(--R.GAS > 0) {
$z1569715698 = $f1570315704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1570315704,
"from":L[2879]});
}
} catch($e1569515696) {
if(R.isCont($e1569515696)) {
var $ss1569915700 = {"from":L[2879],
"go":function(anf_arg198215706) {
return $Hanf_arg902415709(anf_arg198215706,INDENT118169,anf_fun197915707,self73215708,str_DASH_coloncolon135377);
}};
$e1569515696.stack[R.EXN_STACKHEIGHT++] = $ss1569915700;
}
if(R.isPyretException($e1569515696)) {
$e1569515696.pyretStack.push(L[2879]);
}
throw $e1569515696;
}
var $ret1570115702 = $Hanf_arg902415709($z1569715698,INDENT118169,anf_fun197915707,self73215708,str_DASH_coloncolon135377);
++R.GAS;
return $ret1570115702;
};
},{"length":1});
var anf_variant_member200012231 = R.makeMethod(function(self25415673) {
return function(cases_DASH_funs25515674,else_DASH_clause25615685) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2255],2,arguments);
}
var if_DASH_25815688 = R.hasField(cases_DASH_funs25515674,("s-when"));
var if_helper198815671 = R.makeFunction(function(if_helper_arg198915693) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2255],1,arguments);
}
var ann_DASH_check_DASH_temp198715694 = if_helper_arg198915693;
return ann_DASH_check_DASH_temp198715694;
});
var anf_if199215692 = R.isBoolean(if_DASH_25815688);
if(R.isPyretTrue(anf_if199215692)) {
if(R.isPyretTrue(if_DASH_25815688)) {
var call_DASH_s_DASH_when25315666 = G(cases_DASH_funs25515674,"s-when",L[2255]);
var anf_arg199515667 = G(self25415673,"l",L[2878]);
var anf_arg199615668 = G(self25415673,"test",L[2877]);
var anf_arg199715669 = G(self25415673,"block",L[2876]);
var $z1565815659 = D;
var $f1566415665 = function(_) {
return R.isFunction(call_DASH_s_DASH_when25315666)?call_DASH_s_DASH_when25315666.app(anf_arg199515667,anf_arg199615668,anf_arg199715669):R.ffi.throwNonFunApp(L[2255],call_DASH_s_DASH_when25315666,[anf_arg199515667,anf_arg199615668,anf_arg199715669]);
};
try {
if(--R.GAS > 0) {
$z1565815659 = $f1566415665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1566415665,
"from":L[2255]});
}
} catch($e1565615657) {
if(R.isCont($e1565615657)) {
var $ss1566015661 = {"from":L[2255],
"go":function(cont_tail_arg199815670) {
return $Hcont_tail_arg902515672(cont_tail_arg199815670,if_helper198815671);
}};
$e1565615657.stack[R.EXN_STACKHEIGHT++] = $ss1566015661;
}
if(R.isPyretException($e1565615657)) {
$e1565615657.pyretStack.push(L[2255]);
}
throw $e1565615657;
}
var $ret1566215663 = $Hcont_tail_arg902515672($z1565815659,if_helper198815671);
++R.GAS;
return $ret1566215663;
} else {
var $z1567715678 = D;
var $f1568315684 = function(_) {
return R.isFunction(else_DASH_clause25615685)?else_DASH_clause25615685.app():R.ffi.throwNonFunApp(L[2255],else_DASH_clause25615685,[]);
};
try {
if(--R.GAS > 0) {
$z1567715678 = $f1568315684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1568315684,
"from":L[2255]});
}
} catch($e1567515676) {
if(R.isCont($e1567515676)) {
var $ss1567915680 = {"from":L[2255],
"go":function(cont_tail_arg199315686) {
return $Hcont_tail_arg902615687(cont_tail_arg199315686,if_helper198815671);
}};
$e1567515676.stack[R.EXN_STACKHEIGHT++] = $ss1567915680;
}
if(R.isPyretException($e1567515676)) {
$e1567515676.pyretStack.push(L[2255]);
}
throw $e1567515676;
}
var $ret1568115682 = $Hcont_tail_arg902615687($z1567715678,if_helper198815671);
++R.GAS;
return $ret1568115682;
}
} else {
var cont_tail_arg199015691 = R.throwNonBooleanCondition(L[2255],("if"),if_DASH_25815688);
if(--R.GAS > 0) {
$z1568915690 = R.isFunction(if_helper198815671)?if_helper198815671.app(cont_tail_arg199015691):R.ffi.throwNonFunApp(L[2255],if_helper198815671,[cont_tail_arg199015691]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper198815671)?if_helper198815671.app(cont_tail_arg199015691):R.ffi.throwNonFunApp(L[2255],if_helper198815671,[cont_tail_arg199015691]);
},
"from":L[2255]});
}
++R.GAS;
return $z1568915690;
}
};
},{"length":3});
var anf_variant_member201412232 = R.makeMethod(function(self25715654) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2255],0,arguments);
}
var anf_arg200215652 = G(self25715654,"l",L[2255]);
var $z1564415645 = D;
var $f1565015651 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg200215652):R.ffi.throwNonFunApp(L[2255],torepr65,[anf_arg200215652]);
};
try {
if(--R.GAS > 0) {
$z1564415645 = $f1565015651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1565015651,
"from":L[2255]});
}
} catch($e1564215643) {
if(R.isCont($e1564215643)) {
var $ss1564615647 = {"from":L[2255],
"go":function(anf_arg200315653) {
return $Hanf_arg903615655(anf_arg200315653,self25715654,_plus55,torepr65);
}};
$e1564215643.stack[R.EXN_STACKHEIGHT++] = $ss1564615647;
}
if(R.isPyretException($e1564215643)) {
$e1564215643.pyretStack.push(L[2255]);
}
throw $e1564215643;
}
var $ret1564815649 = $Hanf_arg903615655($z1564415645,self25715654,_plus55,torepr65);
++R.GAS;
return $ret1564815649;
};
},{"length":1});
var anf_variant_member201612233 = R.makeMethod(function(self73615641) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2875],0,arguments);
}
var ann_DASH_check_DASH_temp201515640 = ("s-when");
return ann_DASH_check_DASH_temp201515640;
};
},{"length":1});
var anf_variant_member202912234 = R.makeMethod(function(self73715637) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2874],0,arguments);
}
var anf_fun201815635 = G(PP170,"soft-surround",L[2873]);
var anf_fun201915636 = G(PP170,"parens",L[2872]);
var anf_bracket202015639 = G(self73715637,"test",L[2871]);
var anf_fun202115633 = G(anf_bracket202015639,"tosource",L[2870]);
var $z1562515626 = D;
var $f1563115632 = function(_) {
return R.isFunction(anf_fun202115633)?anf_fun202115633.app():R.ffi.throwNonFunApp(L[2869],anf_fun202115633,[]);
};
try {
if(--R.GAS > 0) {
$z1562515626 = $f1563115632();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1563115632,
"from":L[2869]});
}
} catch($e1562315624) {
if(R.isCont($e1562315624)) {
var $ss1562715628 = {"from":L[2869],
"go":function(anf_arg202215634) {
return $Hanf_arg904215638(anf_arg202215634,INDENT118169,anf_fun201815635,anf_fun201915636,self73715637,str_DASH_colon134364,str_DASH_end148546,str_DASH_when181975,_plus55);
}};
$e1562315624.stack[R.EXN_STACKHEIGHT++] = $ss1562715628;
}
if(R.isPyretException($e1562315624)) {
$e1562315624.pyretStack.push(L[2869]);
}
throw $e1562315624;
}
var $ret1562915630 = $Hanf_arg904215638($z1562515626,INDENT118169,anf_fun201815635,anf_fun201915636,self73715637,str_DASH_colon134364,str_DASH_end148546,str_DASH_when181975,_plus55);
++R.GAS;
return $ret1562915630;
};
},{"length":1});
var anf_variant_member204312243 = R.makeMethod(function(self26015601) {
return function(cases_DASH_funs26115602,else_DASH_clause26215613) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2254],2,arguments);
}
var if_DASH_26415616 = R.hasField(cases_DASH_funs26115602,("s-assign"));
var if_helper203115599 = R.makeFunction(function(if_helper_arg203215621) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2254],1,arguments);
}
var ann_DASH_check_DASH_temp203015622 = if_helper_arg203215621;
return ann_DASH_check_DASH_temp203015622;
});
var anf_if203515620 = R.isBoolean(if_DASH_26415616);
if(R.isPyretTrue(anf_if203515620)) {
if(R.isPyretTrue(if_DASH_26415616)) {
var call_DASH_s_DASH_assign25915594 = G(cases_DASH_funs26115602,"s-assign",L[2254]);
var anf_arg203815595 = G(self26015601,"l",L[2868]);
var anf_arg203915596 = G(self26015601,"id",L[2867]);
var anf_arg204015597 = G(self26015601,"value",L[2866]);
var $z1558615587 = D;
var $f1559215593 = function(_) {
return R.isFunction(call_DASH_s_DASH_assign25915594)?call_DASH_s_DASH_assign25915594.app(anf_arg203815595,anf_arg203915596,anf_arg204015597):R.ffi.throwNonFunApp(L[2254],call_DASH_s_DASH_assign25915594,[anf_arg203815595,anf_arg203915596,anf_arg204015597]);
};
try {
if(--R.GAS > 0) {
$z1558615587 = $f1559215593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1559215593,
"from":L[2254]});
}
} catch($e1558415585) {
if(R.isCont($e1558415585)) {
var $ss1558815589 = {"from":L[2254],
"go":function(cont_tail_arg204115598) {
return $Hcont_tail_arg904315600(cont_tail_arg204115598,if_helper203115599);
}};
$e1558415585.stack[R.EXN_STACKHEIGHT++] = $ss1558815589;
}
if(R.isPyretException($e1558415585)) {
$e1558415585.pyretStack.push(L[2254]);
}
throw $e1558415585;
}
var $ret1559015591 = $Hcont_tail_arg904315600($z1558615587,if_helper203115599);
++R.GAS;
return $ret1559015591;
} else {
var $z1560515606 = D;
var $f1561115612 = function(_) {
return R.isFunction(else_DASH_clause26215613)?else_DASH_clause26215613.app():R.ffi.throwNonFunApp(L[2254],else_DASH_clause26215613,[]);
};
try {
if(--R.GAS > 0) {
$z1560515606 = $f1561115612();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1561115612,
"from":L[2254]});
}
} catch($e1560315604) {
if(R.isCont($e1560315604)) {
var $ss1560715608 = {"from":L[2254],
"go":function(cont_tail_arg203615614) {
return $Hcont_tail_arg904415615(cont_tail_arg203615614,if_helper203115599);
}};
$e1560315604.stack[R.EXN_STACKHEIGHT++] = $ss1560715608;
}
if(R.isPyretException($e1560315604)) {
$e1560315604.pyretStack.push(L[2254]);
}
throw $e1560315604;
}
var $ret1560915610 = $Hcont_tail_arg904415615($z1560515606,if_helper203115599);
++R.GAS;
return $ret1560915610;
}
} else {
var cont_tail_arg203315619 = R.throwNonBooleanCondition(L[2254],("if"),if_DASH_26415616);
if(--R.GAS > 0) {
$z1561715618 = R.isFunction(if_helper203115599)?if_helper203115599.app(cont_tail_arg203315619):R.ffi.throwNonFunApp(L[2254],if_helper203115599,[cont_tail_arg203315619]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper203115599)?if_helper203115599.app(cont_tail_arg203315619):R.ffi.throwNonFunApp(L[2254],if_helper203115599,[cont_tail_arg203315619]);
},
"from":L[2254]});
}
++R.GAS;
return $z1561715618;
}
};
},{"length":3});
var anf_variant_member205712244 = R.makeMethod(function(self26315582) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2254],0,arguments);
}
var anf_arg204515580 = G(self26315582,"l",L[2254]);
var $z1557215573 = D;
var $f1557815579 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg204515580):R.ffi.throwNonFunApp(L[2254],torepr65,[anf_arg204515580]);
};
try {
if(--R.GAS > 0) {
$z1557215573 = $f1557815579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1557815579,
"from":L[2254]});
}
} catch($e1557015571) {
if(R.isCont($e1557015571)) {
var $ss1557415575 = {"from":L[2254],
"go":function(anf_arg204615581) {
return $Hanf_arg905415583(anf_arg204615581,self26315582,_plus55,torepr65);
}};
$e1557015571.stack[R.EXN_STACKHEIGHT++] = $ss1557415575;
}
if(R.isPyretException($e1557015571)) {
$e1557015571.pyretStack.push(L[2254]);
}
throw $e1557015571;
}
var $ret1557615577 = $Hanf_arg905415583($z1557215573,self26315582,_plus55,torepr65);
++R.GAS;
return $ret1557615577;
};
},{"length":1});
var anf_variant_member205912245 = R.makeMethod(function(self74115569) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2865],0,arguments);
}
var ann_DASH_check_DASH_temp205815568 = ("s-assign");
return ann_DASH_check_DASH_temp205815568;
};
},{"length":1});
var anf_variant_member207312246 = R.makeMethod(function(self74215565) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2864],0,arguments);
}
var anf_fun206115563 = G(PP170,"group",L[2863]);
var anf_fun206215564 = G(PP170,"nest",L[2862]);
var anf_bracket206315567 = G(self74215565,"id",L[2861]);
var anf_fun206415561 = G(anf_bracket206315567,"tosource",L[2860]);
var $z1555315554 = D;
var $f1555915560 = function(_) {
return R.isFunction(anf_fun206415561)?anf_fun206415561.app():R.ffi.throwNonFunApp(L[2859],anf_fun206415561,[]);
};
try {
if(--R.GAS > 0) {
$z1555315554 = $f1555915560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1555915560,
"from":L[2859]});
}
} catch($e1555115552) {
if(R.isCont($e1555115552)) {
var $ss1555515556 = {"from":L[2859],
"go":function(anf_arg206515562) {
return $Hanf_arg906115566(anf_arg206515562,INDENT118169,anf_fun206115563,anf_fun206215564,break_DASH_one119168,self74215565,str_DASH_spacecolonequal169819,_plus55);
}};
$e1555115552.stack[R.EXN_STACKHEIGHT++] = $ss1555515556;
}
if(R.isPyretException($e1555115552)) {
$e1555115552.pyretStack.push(L[2859]);
}
throw $e1555115552;
}
var $ret1555715558 = $Hanf_arg906115566($z1555315554,INDENT118169,anf_fun206115563,anf_fun206215564,break_DASH_one119168,self74215565,str_DASH_spacecolonequal169819,_plus55);
++R.GAS;
return $ret1555715558;
};
},{"length":1});
var anf_variant_member208612255 = R.makeMethod(function(self26615529) {
return function(cases_DASH_funs26715530,else_DASH_clause26815541) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2253],2,arguments);
}
var if_DASH_27015544 = R.hasField(cases_DASH_funs26715530,("s-if-pipe"));
var if_helper207515527 = R.makeFunction(function(if_helper_arg207615549) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2253],1,arguments);
}
var ann_DASH_check_DASH_temp207415550 = if_helper_arg207615549;
return ann_DASH_check_DASH_temp207415550;
});
var anf_if207915548 = R.isBoolean(if_DASH_27015544);
if(R.isPyretTrue(anf_if207915548)) {
if(R.isPyretTrue(if_DASH_27015544)) {
var call_DASH_s_DASH_if_DASH_pipe26515523 = G(cases_DASH_funs26715530,"s-if-pipe",L[2253]);
var anf_arg208215524 = G(self26615529,"l",L[2858]);
var anf_arg208315525 = G(self26615529,"branches",L[2857]);
var $z1551515516 = D;
var $f1552115522 = function(_) {
return R.isFunction(call_DASH_s_DASH_if_DASH_pipe26515523)?call_DASH_s_DASH_if_DASH_pipe26515523.app(anf_arg208215524,anf_arg208315525):R.ffi.throwNonFunApp(L[2253],call_DASH_s_DASH_if_DASH_pipe26515523,[anf_arg208215524,anf_arg208315525]);
};
try {
if(--R.GAS > 0) {
$z1551515516 = $f1552115522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1552115522,
"from":L[2253]});
}
} catch($e1551315514) {
if(R.isCont($e1551315514)) {
var $ss1551715518 = {"from":L[2253],
"go":function(cont_tail_arg208415526) {
return $Hcont_tail_arg906215528(cont_tail_arg208415526,if_helper207515527);
}};
$e1551315514.stack[R.EXN_STACKHEIGHT++] = $ss1551715518;
}
if(R.isPyretException($e1551315514)) {
$e1551315514.pyretStack.push(L[2253]);
}
throw $e1551315514;
}
var $ret1551915520 = $Hcont_tail_arg906215528($z1551515516,if_helper207515527);
++R.GAS;
return $ret1551915520;
} else {
var $z1553315534 = D;
var $f1553915540 = function(_) {
return R.isFunction(else_DASH_clause26815541)?else_DASH_clause26815541.app():R.ffi.throwNonFunApp(L[2253],else_DASH_clause26815541,[]);
};
try {
if(--R.GAS > 0) {
$z1553315534 = $f1553915540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1553915540,
"from":L[2253]});
}
} catch($e1553115532) {
if(R.isCont($e1553115532)) {
var $ss1553515536 = {"from":L[2253],
"go":function(cont_tail_arg208015542) {
return $Hcont_tail_arg906315543(cont_tail_arg208015542,if_helper207515527);
}};
$e1553115532.stack[R.EXN_STACKHEIGHT++] = $ss1553515536;
}
if(R.isPyretException($e1553115532)) {
$e1553115532.pyretStack.push(L[2253]);
}
throw $e1553115532;
}
var $ret1553715538 = $Hcont_tail_arg906315543($z1553315534,if_helper207515527);
++R.GAS;
return $ret1553715538;
}
} else {
var cont_tail_arg207715547 = R.throwNonBooleanCondition(L[2253],("if"),if_DASH_27015544);
if(--R.GAS > 0) {
$z1554515546 = R.isFunction(if_helper207515527)?if_helper207515527.app(cont_tail_arg207715547):R.ffi.throwNonFunApp(L[2253],if_helper207515527,[cont_tail_arg207715547]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper207515527)?if_helper207515527.app(cont_tail_arg207715547):R.ffi.throwNonFunApp(L[2253],if_helper207515527,[cont_tail_arg207715547]);
},
"from":L[2253]});
}
++R.GAS;
return $z1554515546;
}
};
},{"length":3});
var anf_variant_member209612256 = R.makeMethod(function(self26915511) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2253],0,arguments);
}
var anf_arg208815509 = G(self26915511,"l",L[2253]);
var $z1550115502 = D;
var $f1550715508 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg208815509):R.ffi.throwNonFunApp(L[2253],torepr65,[anf_arg208815509]);
};
try {
if(--R.GAS > 0) {
$z1550115502 = $f1550715508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1550715508,
"from":L[2253]});
}
} catch($e1549915500) {
if(R.isCont($e1549915500)) {
var $ss1550315504 = {"from":L[2253],
"go":function(anf_arg208915510) {
return $Hanf_arg907015512(anf_arg208915510,self26915511,_plus55,torepr65);
}};
$e1549915500.stack[R.EXN_STACKHEIGHT++] = $ss1550315504;
}
if(R.isPyretException($e1549915500)) {
$e1549915500.pyretStack.push(L[2253]);
}
throw $e1549915500;
}
var $ret1550515506 = $Hanf_arg907015512($z1550115502,self26915511,_plus55,torepr65);
++R.GAS;
return $ret1550515506;
};
},{"length":1});
var anf_variant_member209812257 = R.makeMethod(function(self74515498) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2856],0,arguments);
}
var ann_DASH_check_DASH_temp209715497 = ("s-if-pipe");
return ann_DASH_check_DASH_temp209715497;
};
},{"length":1});
var anf_variant_member211312258 = R.makeMethod(function(self74615495) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2855],0,arguments);
}
var anf_fun210015494 = G(PP170,"surround-separate",L[2854]);
var $z1548515486 = D;
var $f1549115492 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_askcolon156650,str_DASH_space168806):R.ffi.throwNonFunApp(L[2853],_plus55,[str_DASH_askcolon156650,str_DASH_space168806]);
};
try {
if(--R.GAS > 0) {
$z1548515486 = $f1549115492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1549115492,
"from":L[2853]});
}
} catch($e1548315484) {
if(R.isCont($e1548315484)) {
var $ss1548715488 = {"from":L[2853],
"go":function(anf_arg210115493) {
return $Hanf_arg907715496(anf_arg210115493,INDENT118169,PP170,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
}};
$e1548315484.stack[R.EXN_STACKHEIGHT++] = $ss1548715488;
}
if(R.isPyretException($e1548315484)) {
$e1548315484.pyretStack.push(L[2853]);
}
throw $e1548315484;
}
var $ret1548915490 = $Hanf_arg907715496($z1548515486,INDENT118169,PP170,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
++R.GAS;
return $ret1548915490;
};
},{"length":1});
var anf_variant_member212712266 = R.makeMethod(function(self27215461) {
return function(cases_DASH_funs27315462,else_DASH_clause27415473) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2252],2,arguments);
}
var if_DASH_27615476 = R.hasField(cases_DASH_funs27315462,("s-if-pipe-else"));
var if_helper211515459 = R.makeFunction(function(if_helper_arg211615481) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2252],1,arguments);
}
var ann_DASH_check_DASH_temp211415482 = if_helper_arg211615481;
return ann_DASH_check_DASH_temp211415482;
});
var anf_if211915480 = R.isBoolean(if_DASH_27615476);
if(R.isPyretTrue(anf_if211915480)) {
if(R.isPyretTrue(if_DASH_27615476)) {
var call_DASH_s_DASH_if_DASH_pipe_DASH_else27115454 = G(cases_DASH_funs27315462,"s-if-pipe-else",L[2252]);
var anf_arg212215455 = G(self27215461,"l",L[2852]);
var anf_arg212315456 = G(self27215461,"branches",L[2851]);
var anf_arg212415457 = G(self27215461,"_else",L[2850]);
var $z1544615447 = D;
var $f1545215453 = function(_) {
return R.isFunction(call_DASH_s_DASH_if_DASH_pipe_DASH_else27115454)?call_DASH_s_DASH_if_DASH_pipe_DASH_else27115454.app(anf_arg212215455,anf_arg212315456,anf_arg212415457):R.ffi.throwNonFunApp(L[2252],call_DASH_s_DASH_if_DASH_pipe_DASH_else27115454,[anf_arg212215455,anf_arg212315456,anf_arg212415457]);
};
try {
if(--R.GAS > 0) {
$z1544615447 = $f1545215453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1545215453,
"from":L[2252]});
}
} catch($e1544415445) {
if(R.isCont($e1544415445)) {
var $ss1544815449 = {"from":L[2252],
"go":function(cont_tail_arg212515458) {
return $Hcont_tail_arg907815460(cont_tail_arg212515458,if_helper211515459);
}};
$e1544415445.stack[R.EXN_STACKHEIGHT++] = $ss1544815449;
}
if(R.isPyretException($e1544415445)) {
$e1544415445.pyretStack.push(L[2252]);
}
throw $e1544415445;
}
var $ret1545015451 = $Hcont_tail_arg907815460($z1544615447,if_helper211515459);
++R.GAS;
return $ret1545015451;
} else {
var $z1546515466 = D;
var $f1547115472 = function(_) {
return R.isFunction(else_DASH_clause27415473)?else_DASH_clause27415473.app():R.ffi.throwNonFunApp(L[2252],else_DASH_clause27415473,[]);
};
try {
if(--R.GAS > 0) {
$z1546515466 = $f1547115472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1547115472,
"from":L[2252]});
}
} catch($e1546315464) {
if(R.isCont($e1546315464)) {
var $ss1546715468 = {"from":L[2252],
"go":function(cont_tail_arg212015474) {
return $Hcont_tail_arg907915475(cont_tail_arg212015474,if_helper211515459);
}};
$e1546315464.stack[R.EXN_STACKHEIGHT++] = $ss1546715468;
}
if(R.isPyretException($e1546315464)) {
$e1546315464.pyretStack.push(L[2252]);
}
throw $e1546315464;
}
var $ret1546915470 = $Hcont_tail_arg907915475($z1546515466,if_helper211515459);
++R.GAS;
return $ret1546915470;
}
} else {
var cont_tail_arg211715479 = R.throwNonBooleanCondition(L[2252],("if"),if_DASH_27615476);
if(--R.GAS > 0) {
$z1547715478 = R.isFunction(if_helper211515459)?if_helper211515459.app(cont_tail_arg211715479):R.ffi.throwNonFunApp(L[2252],if_helper211515459,[cont_tail_arg211715479]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper211515459)?if_helper211515459.app(cont_tail_arg211715479):R.ffi.throwNonFunApp(L[2252],if_helper211515459,[cont_tail_arg211715479]);
},
"from":L[2252]});
}
++R.GAS;
return $z1547715478;
}
};
},{"length":3});
var anf_variant_member214112267 = R.makeMethod(function(self27515442) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2252],0,arguments);
}
var anf_arg212915440 = G(self27515442,"l",L[2252]);
var $z1543215433 = D;
var $f1543815439 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg212915440):R.ffi.throwNonFunApp(L[2252],torepr65,[anf_arg212915440]);
};
try {
if(--R.GAS > 0) {
$z1543215433 = $f1543815439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1543815439,
"from":L[2252]});
}
} catch($e1543015431) {
if(R.isCont($e1543015431)) {
var $ss1543415435 = {"from":L[2252],
"go":function(anf_arg213015441) {
return $Hanf_arg908915443(anf_arg213015441,self27515442,_plus55,torepr65);
}};
$e1543015431.stack[R.EXN_STACKHEIGHT++] = $ss1543415435;
}
if(R.isPyretException($e1543015431)) {
$e1543015431.pyretStack.push(L[2252]);
}
throw $e1543015431;
}
var $ret1543615437 = $Hanf_arg908915443($z1543215433,self27515442,_plus55,torepr65);
++R.GAS;
return $ret1543615437;
};
},{"length":1});
var anf_variant_member214312268 = R.makeMethod(function(self75115429) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2849],0,arguments);
}
var ann_DASH_check_DASH_temp214215428 = ("s-if-pipe-else");
return ann_DASH_check_DASH_temp214215428;
};
},{"length":1});
var anf_variant_member216712269 = R.makeMethod(function(self75215410) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2848],0,arguments);
}
var anf_fun214515409 = G(PP170,"separate",L[2847]);
var anf_bracket214615427 = G(self75215410,"branches",L[2846]);
var anf_fun214715406 = G(anf_bracket214615427,"map",L[2845]);
var anf_arg215215407 = R.makeFunction(function(b75415412) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2841],1,arguments);
}
var anf_fun214915425 = G(PP170,"group",L[2844]);
var anf_fun215015423 = G(b75415412,"tosource",L[2843]);
var $z1541515416 = D;
var $f1542115422 = function(_) {
return R.isFunction(anf_fun215015423)?anf_fun215015423.app():R.ffi.throwNonFunApp(L[2842],anf_fun215015423,[]);
};
try {
if(--R.GAS > 0) {
$z1541515416 = $f1542115422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1542115422,
"from":L[2842]});
}
} catch($e1541315414) {
if(R.isCont($e1541315414)) {
var $ss1541715418 = {"from":L[2842],
"go":function(anf_arg215115424) {
return $Hanf_arg909115426(anf_arg215115424,anf_fun214915425);
}};
$e1541315414.stack[R.EXN_STACKHEIGHT++] = $ss1541715418;
}
if(R.isPyretException($e1541315414)) {
$e1541315414.pyretStack.push(L[2842]);
}
throw $e1541315414;
}
var $ret1541915420 = $Hanf_arg909115426($z1541515416,anf_fun214915425);
++R.GAS;
return $ret1541915420;
});
var $z1539815399 = D;
var $f1540415405 = function(_) {
return R.isFunction(anf_fun214715406)?anf_fun214715406.app(anf_arg215215407):R.ffi.throwNonFunApp(L[2840],anf_fun214715406,[anf_arg215215407]);
};
try {
if(--R.GAS > 0) {
$z1539815399 = $f1540415405();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1540415405,
"from":L[2840]});
}
} catch($e1539615397) {
if(R.isCont($e1539615397)) {
var $ss1540015401 = {"from":L[2840],
"go":function(anf_arg215315408) {
return $Hanf_arg910215411(anf_arg215315408,INDENT118169,PP170,anf_fun214515409,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55);
}};
$e1539615397.stack[R.EXN_STACKHEIGHT++] = $ss1540015401;
}
if(R.isPyretException($e1539615397)) {
$e1539615397.pyretStack.push(L[2840]);
}
throw $e1539615397;
}
var $ret1540215403 = $Hanf_arg910215411($z1539815399,INDENT118169,PP170,anf_fun214515409,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55);
++R.GAS;
return $ret1540215403;
};
},{"length":1});
var anf_variant_member218012278 = R.makeMethod(function(self27815374) {
return function(cases_DASH_funs27915375,else_DASH_clause28015386) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2251],2,arguments);
}
var if_DASH_28215389 = R.hasField(cases_DASH_funs27915375,("s-if"));
var if_helper216915372 = R.makeFunction(function(if_helper_arg217015394) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2251],1,arguments);
}
var ann_DASH_check_DASH_temp216815395 = if_helper_arg217015394;
return ann_DASH_check_DASH_temp216815395;
});
var anf_if217315393 = R.isBoolean(if_DASH_28215389);
if(R.isPyretTrue(anf_if217315393)) {
if(R.isPyretTrue(if_DASH_28215389)) {
var call_DASH_s_DASH_if27715368 = G(cases_DASH_funs27915375,"s-if",L[2251]);
var anf_arg217615369 = G(self27815374,"l",L[2839]);
var anf_arg217715370 = G(self27815374,"branches",L[2838]);
var $z1536015361 = D;
var $f1536615367 = function(_) {
return R.isFunction(call_DASH_s_DASH_if27715368)?call_DASH_s_DASH_if27715368.app(anf_arg217615369,anf_arg217715370):R.ffi.throwNonFunApp(L[2251],call_DASH_s_DASH_if27715368,[anf_arg217615369,anf_arg217715370]);
};
try {
if(--R.GAS > 0) {
$z1536015361 = $f1536615367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1536615367,
"from":L[2251]});
}
} catch($e1535815359) {
if(R.isCont($e1535815359)) {
var $ss1536215363 = {"from":L[2251],
"go":function(cont_tail_arg217815371) {
return $Hcont_tail_arg910315373(cont_tail_arg217815371,if_helper216915372);
}};
$e1535815359.stack[R.EXN_STACKHEIGHT++] = $ss1536215363;
}
if(R.isPyretException($e1535815359)) {
$e1535815359.pyretStack.push(L[2251]);
}
throw $e1535815359;
}
var $ret1536415365 = $Hcont_tail_arg910315373($z1536015361,if_helper216915372);
++R.GAS;
return $ret1536415365;
} else {
var $z1537815379 = D;
var $f1538415385 = function(_) {
return R.isFunction(else_DASH_clause28015386)?else_DASH_clause28015386.app():R.ffi.throwNonFunApp(L[2251],else_DASH_clause28015386,[]);
};
try {
if(--R.GAS > 0) {
$z1537815379 = $f1538415385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1538415385,
"from":L[2251]});
}
} catch($e1537615377) {
if(R.isCont($e1537615377)) {
var $ss1538015381 = {"from":L[2251],
"go":function(cont_tail_arg217415387) {
return $Hcont_tail_arg910415388(cont_tail_arg217415387,if_helper216915372);
}};
$e1537615377.stack[R.EXN_STACKHEIGHT++] = $ss1538015381;
}
if(R.isPyretException($e1537615377)) {
$e1537615377.pyretStack.push(L[2251]);
}
throw $e1537615377;
}
var $ret1538215383 = $Hcont_tail_arg910415388($z1537815379,if_helper216915372);
++R.GAS;
return $ret1538215383;
}
} else {
var cont_tail_arg217115392 = R.throwNonBooleanCondition(L[2251],("if"),if_DASH_28215389);
if(--R.GAS > 0) {
$z1539015391 = R.isFunction(if_helper216915372)?if_helper216915372.app(cont_tail_arg217115392):R.ffi.throwNonFunApp(L[2251],if_helper216915372,[cont_tail_arg217115392]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper216915372)?if_helper216915372.app(cont_tail_arg217115392):R.ffi.throwNonFunApp(L[2251],if_helper216915372,[cont_tail_arg217115392]);
},
"from":L[2251]});
}
++R.GAS;
return $z1539015391;
}
};
},{"length":3});
var anf_variant_member219012279 = R.makeMethod(function(self28115356) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2251],0,arguments);
}
var anf_arg218215354 = G(self28115356,"l",L[2251]);
var $z1534615347 = D;
var $f1535215353 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg218215354):R.ffi.throwNonFunApp(L[2251],torepr65,[anf_arg218215354]);
};
try {
if(--R.GAS > 0) {
$z1534615347 = $f1535215353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1535215353,
"from":L[2251]});
}
} catch($e1534415345) {
if(R.isCont($e1534415345)) {
var $ss1534815349 = {"from":L[2251],
"go":function(anf_arg218315355) {
return $Hanf_arg911115357(anf_arg218315355,self28115356,_plus55,torepr65);
}};
$e1534415345.stack[R.EXN_STACKHEIGHT++] = $ss1534815349;
}
if(R.isPyretException($e1534415345)) {
$e1534415345.pyretStack.push(L[2251]);
}
throw $e1534415345;
}
var $ret1535015351 = $Hanf_arg911115357($z1534615347,self28115356,_plus55,torepr65);
++R.GAS;
return $ret1535015351;
};
},{"length":1});
var anf_variant_member219212280 = R.makeMethod(function(self75715343) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2837],0,arguments);
}
var ann_DASH_check_DASH_temp219115342 = ("s-if");
return ann_DASH_check_DASH_temp219115342;
};
},{"length":1});
var anf_variant_member220512281 = R.makeMethod(function(self75815340) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2836],0,arguments);
}
var anf_fun219415339 = G(PP170,"separate",L[2835]);
var $z1533015331 = D;
var $f1533615337 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_elsespace147533):R.ffi.throwNonFunApp(L[2834],_plus55,[break_DASH_one119168,str_DASH_elsespace147533]);
};
try {
if(--R.GAS > 0) {
$z1533015331 = $f1533615337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1533615337,
"from":L[2834]});
}
} catch($e1532815329) {
if(R.isCont($e1532815329)) {
var $ss1533215333 = {"from":L[2834],
"go":function(anf_arg219515338) {
return $Hanf_arg911815341(anf_arg219515338,PP170,anf_fun219415339,break_DASH_one119168,self75815340,str_DASH_end148546,_plus55);
}};
$e1532815329.stack[R.EXN_STACKHEIGHT++] = $ss1533215333;
}
if(R.isPyretException($e1532815329)) {
$e1532815329.pyretStack.push(L[2834]);
}
throw $e1532815329;
}
var $ret1533415335 = $Hanf_arg911815341($z1533015331,PP170,anf_fun219415339,break_DASH_one119168,self75815340,str_DASH_end148546,_plus55);
++R.GAS;
return $ret1533415335;
};
},{"length":1});
var anf_variant_member221912289 = R.makeMethod(function(self28415306) {
return function(cases_DASH_funs28515307,else_DASH_clause28615318) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2250],2,arguments);
}
var if_DASH_28815321 = R.hasField(cases_DASH_funs28515307,("s-if-else"));
var if_helper220715304 = R.makeFunction(function(if_helper_arg220815326) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2250],1,arguments);
}
var ann_DASH_check_DASH_temp220615327 = if_helper_arg220815326;
return ann_DASH_check_DASH_temp220615327;
});
var anf_if221115325 = R.isBoolean(if_DASH_28815321);
if(R.isPyretTrue(anf_if221115325)) {
if(R.isPyretTrue(if_DASH_28815321)) {
var call_DASH_s_DASH_if_DASH_else28315299 = G(cases_DASH_funs28515307,"s-if-else",L[2250]);
var anf_arg221415300 = G(self28415306,"l",L[2833]);
var anf_arg221515301 = G(self28415306,"branches",L[2832]);
var anf_arg221615302 = G(self28415306,"_else",L[2831]);
var $z1529115292 = D;
var $f1529715298 = function(_) {
return R.isFunction(call_DASH_s_DASH_if_DASH_else28315299)?call_DASH_s_DASH_if_DASH_else28315299.app(anf_arg221415300,anf_arg221515301,anf_arg221615302):R.ffi.throwNonFunApp(L[2250],call_DASH_s_DASH_if_DASH_else28315299,[anf_arg221415300,anf_arg221515301,anf_arg221615302]);
};
try {
if(--R.GAS > 0) {
$z1529115292 = $f1529715298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1529715298,
"from":L[2250]});
}
} catch($e1528915290) {
if(R.isCont($e1528915290)) {
var $ss1529315294 = {"from":L[2250],
"go":function(cont_tail_arg221715303) {
return $Hcont_tail_arg911915305(cont_tail_arg221715303,if_helper220715304);
}};
$e1528915290.stack[R.EXN_STACKHEIGHT++] = $ss1529315294;
}
if(R.isPyretException($e1528915290)) {
$e1528915290.pyretStack.push(L[2250]);
}
throw $e1528915290;
}
var $ret1529515296 = $Hcont_tail_arg911915305($z1529115292,if_helper220715304);
++R.GAS;
return $ret1529515296;
} else {
var $z1531015311 = D;
var $f1531615317 = function(_) {
return R.isFunction(else_DASH_clause28615318)?else_DASH_clause28615318.app():R.ffi.throwNonFunApp(L[2250],else_DASH_clause28615318,[]);
};
try {
if(--R.GAS > 0) {
$z1531015311 = $f1531615317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1531615317,
"from":L[2250]});
}
} catch($e1530815309) {
if(R.isCont($e1530815309)) {
var $ss1531215313 = {"from":L[2250],
"go":function(cont_tail_arg221215319) {
return $Hcont_tail_arg912015320(cont_tail_arg221215319,if_helper220715304);
}};
$e1530815309.stack[R.EXN_STACKHEIGHT++] = $ss1531215313;
}
if(R.isPyretException($e1530815309)) {
$e1530815309.pyretStack.push(L[2250]);
}
throw $e1530815309;
}
var $ret1531415315 = $Hcont_tail_arg912015320($z1531015311,if_helper220715304);
++R.GAS;
return $ret1531415315;
}
} else {
var cont_tail_arg220915324 = R.throwNonBooleanCondition(L[2250],("if"),if_DASH_28815321);
if(--R.GAS > 0) {
$z1532215323 = R.isFunction(if_helper220715304)?if_helper220715304.app(cont_tail_arg220915324):R.ffi.throwNonFunApp(L[2250],if_helper220715304,[cont_tail_arg220915324]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper220715304)?if_helper220715304.app(cont_tail_arg220915324):R.ffi.throwNonFunApp(L[2250],if_helper220715304,[cont_tail_arg220915324]);
},
"from":L[2250]});
}
++R.GAS;
return $z1532215323;
}
};
},{"length":3});
var anf_variant_member223312290 = R.makeMethod(function(self28715287) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2250],0,arguments);
}
var anf_arg222115285 = G(self28715287,"l",L[2250]);
var $z1527715278 = D;
var $f1528315284 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg222115285):R.ffi.throwNonFunApp(L[2250],torepr65,[anf_arg222115285]);
};
try {
if(--R.GAS > 0) {
$z1527715278 = $f1528315284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1528315284,
"from":L[2250]});
}
} catch($e1527515276) {
if(R.isCont($e1527515276)) {
var $ss1527915280 = {"from":L[2250],
"go":function(anf_arg222215286) {
return $Hanf_arg913015288(anf_arg222215286,self28715287,_plus55,torepr65);
}};
$e1527515276.stack[R.EXN_STACKHEIGHT++] = $ss1527915280;
}
if(R.isPyretException($e1527515276)) {
$e1527515276.pyretStack.push(L[2250]);
}
throw $e1527515276;
}
var $ret1528115282 = $Hanf_arg913015288($z1527715278,self28715287,_plus55,torepr65);
++R.GAS;
return $ret1528115282;
};
},{"length":1});
var anf_variant_member223512291 = R.makeMethod(function(self76415274) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2830],0,arguments);
}
var ann_DASH_check_DASH_temp223415273 = ("s-if-else");
return ann_DASH_check_DASH_temp223415273;
};
},{"length":1});
var anf_variant_member225612292 = R.makeMethod(function(self76515271) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2829],0,arguments);
}
var anf_fun223715270 = G(PP170,"separate",L[2828]);
var $z1526115262 = D;
var $f1526715268 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_elsespace147533):R.ffi.throwNonFunApp(L[2827],_plus55,[break_DASH_one119168,str_DASH_elsespace147533]);
};
try {
if(--R.GAS > 0) {
$z1526115262 = $f1526715268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1526715268,
"from":L[2827]});
}
} catch($e1525915260) {
if(R.isCont($e1525915260)) {
var $ss1526315264 = {"from":L[2827],
"go":function(anf_arg223815269) {
return $Hanf_arg914315272(anf_arg223815269,INDENT118169,PP170,anf_fun223715270,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
}};
$e1525915260.stack[R.EXN_STACKHEIGHT++] = $ss1526315264;
}
if(R.isPyretException($e1525915260)) {
$e1525915260.pyretStack.push(L[2827]);
}
throw $e1525915260;
}
var $ret1526515266 = $Hanf_arg914315272($z1526115262,INDENT118169,PP170,anf_fun223715270,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
++R.GAS;
return $ret1526515266;
};
},{"length":1});
var anf_variant_member227112301 = R.makeMethod(function(self29015237) {
return function(cases_DASH_funs29115238,else_DASH_clause29215249) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2249],2,arguments);
}
var if_DASH_29415252 = R.hasField(cases_DASH_funs29115238,("s-cases"));
var if_helper225815235 = R.makeFunction(function(if_helper_arg225915257) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2249],1,arguments);
}
var ann_DASH_check_DASH_temp225715258 = if_helper_arg225915257;
return ann_DASH_check_DASH_temp225715258;
});
var anf_if226215256 = R.isBoolean(if_DASH_29415252);
if(R.isPyretTrue(anf_if226215256)) {
if(R.isPyretTrue(if_DASH_29415252)) {
var call_DASH_s_DASH_cases28915229 = G(cases_DASH_funs29115238,"s-cases",L[2249]);
var anf_arg226515230 = G(self29015237,"l",L[2826]);
var anf_arg226615231 = G(self29015237,"typ",L[2825]);
var anf_arg226715232 = G(self29015237,"val",L[2824]);
var anf_arg226815233 = G(self29015237,"branches",L[2823]);
var $z1522115222 = D;
var $f1522715228 = function(_) {
return R.isFunction(call_DASH_s_DASH_cases28915229)?call_DASH_s_DASH_cases28915229.app(anf_arg226515230,anf_arg226615231,anf_arg226715232,anf_arg226815233):R.ffi.throwNonFunApp(L[2249],call_DASH_s_DASH_cases28915229,[anf_arg226515230,anf_arg226615231,anf_arg226715232,anf_arg226815233]);
};
try {
if(--R.GAS > 0) {
$z1522115222 = $f1522715228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1522715228,
"from":L[2249]});
}
} catch($e1521915220) {
if(R.isCont($e1521915220)) {
var $ss1522315224 = {"from":L[2249],
"go":function(cont_tail_arg226915234) {
return $Hcont_tail_arg914415236(cont_tail_arg226915234,if_helper225815235);
}};
$e1521915220.stack[R.EXN_STACKHEIGHT++] = $ss1522315224;
}
if(R.isPyretException($e1521915220)) {
$e1521915220.pyretStack.push(L[2249]);
}
throw $e1521915220;
}
var $ret1522515226 = $Hcont_tail_arg914415236($z1522115222,if_helper225815235);
++R.GAS;
return $ret1522515226;
} else {
var $z1524115242 = D;
var $f1524715248 = function(_) {
return R.isFunction(else_DASH_clause29215249)?else_DASH_clause29215249.app():R.ffi.throwNonFunApp(L[2249],else_DASH_clause29215249,[]);
};
try {
if(--R.GAS > 0) {
$z1524115242 = $f1524715248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1524715248,
"from":L[2249]});
}
} catch($e1523915240) {
if(R.isCont($e1523915240)) {
var $ss1524315244 = {"from":L[2249],
"go":function(cont_tail_arg226315250) {
return $Hcont_tail_arg914515251(cont_tail_arg226315250,if_helper225815235);
}};
$e1523915240.stack[R.EXN_STACKHEIGHT++] = $ss1524315244;
}
if(R.isPyretException($e1523915240)) {
$e1523915240.pyretStack.push(L[2249]);
}
throw $e1523915240;
}
var $ret1524515246 = $Hcont_tail_arg914515251($z1524115242,if_helper225815235);
++R.GAS;
return $ret1524515246;
}
} else {
var cont_tail_arg226015255 = R.throwNonBooleanCondition(L[2249],("if"),if_DASH_29415252);
if(--R.GAS > 0) {
$z1525315254 = R.isFunction(if_helper225815235)?if_helper225815235.app(cont_tail_arg226015255):R.ffi.throwNonFunApp(L[2249],if_helper225815235,[cont_tail_arg226015255]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper225815235)?if_helper225815235.app(cont_tail_arg226015255):R.ffi.throwNonFunApp(L[2249],if_helper225815235,[cont_tail_arg226015255]);
},
"from":L[2249]});
}
++R.GAS;
return $z1525315254;
}
};
},{"length":3});
var anf_variant_member228912302 = R.makeMethod(function(self29315217) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2249],0,arguments);
}
var anf_arg227315215 = G(self29315217,"l",L[2249]);
var $z1520715208 = D;
var $f1521315214 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg227315215):R.ffi.throwNonFunApp(L[2249],torepr65,[anf_arg227315215]);
};
try {
if(--R.GAS > 0) {
$z1520715208 = $f1521315214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1521315214,
"from":L[2249]});
}
} catch($e1520515206) {
if(R.isCont($e1520515206)) {
var $ss1520915210 = {"from":L[2249],
"go":function(anf_arg227415216) {
return $Hanf_arg915815218(anf_arg227415216,self29315217,_plus55,torepr65);
}};
$e1520515206.stack[R.EXN_STACKHEIGHT++] = $ss1520915210;
}
if(R.isPyretException($e1520515206)) {
$e1520515206.pyretStack.push(L[2249]);
}
throw $e1520515206;
}
var $ret1521115212 = $Hanf_arg915815218($z1520715208,self29315217,_plus55,torepr65);
++R.GAS;
return $ret1521115212;
};
},{"length":1});
var anf_variant_member229112303 = R.makeMethod(function(self77315204) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2822],0,arguments);
}
var ann_DASH_check_DASH_temp229015203 = ("s-cases");
return ann_DASH_check_DASH_temp229015203;
};
},{"length":1});
var anf_variant_member231712304 = R.makeMethod(function(self77415200) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2821],0,arguments);
}
var anf_fun229315199 = G(PP170,"parens",L[2820]);
var anf_bracket229415202 = G(self77415200,"typ",L[2819]);
var anf_fun229515197 = G(anf_bracket229415202,"tosource",L[2818]);
var $z1518915190 = D;
var $f1519515196 = function(_) {
return R.isFunction(anf_fun229515197)?anf_fun229515197.app():R.ffi.throwNonFunApp(L[2817],anf_fun229515197,[]);
};
try {
if(--R.GAS > 0) {
$z1518915190 = $f1519515196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1519515196,
"from":L[2817]});
}
} catch($e1518715188) {
if(R.isCont($e1518715188)) {
var $ss1519115192 = {"from":L[2817],
"go":function(anf_arg229615198) {
return $Hanf_arg917215201(anf_arg229615198,INDENT118169,PP170,anf_fun229315199,break_DASH_one119168,self77415200,str_DASH_cases130312,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
}};
$e1518715188.stack[R.EXN_STACKHEIGHT++] = $ss1519115192;
}
if(R.isPyretException($e1518715188)) {
$e1518715188.pyretStack.push(L[2817]);
}
throw $e1518715188;
}
var $ret1519315194 = $Hanf_arg917215201($z1518915190,INDENT118169,PP170,anf_fun229315199,break_DASH_one119168,self77415200,str_DASH_cases130312,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
++R.GAS;
return $ret1519315194;
};
},{"length":1});
var anf_variant_member233312314 = R.makeMethod(function(self29615165) {
return function(cases_DASH_funs29715166,else_DASH_clause29815177) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2248],2,arguments);
}
var if_DASH_30015180 = R.hasField(cases_DASH_funs29715166,("s-cases-else"));
var if_helper231915163 = R.makeFunction(function(if_helper_arg232015185) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2248],1,arguments);
}
var ann_DASH_check_DASH_temp231815186 = if_helper_arg232015185;
return ann_DASH_check_DASH_temp231815186;
});
var anf_if232315184 = R.isBoolean(if_DASH_30015180);
if(R.isPyretTrue(anf_if232315184)) {
if(R.isPyretTrue(if_DASH_30015180)) {
var call_DASH_s_DASH_cases_DASH_else29515156 = G(cases_DASH_funs29715166,"s-cases-else",L[2248]);
var anf_arg232615157 = G(self29615165,"l",L[2816]);
var anf_arg232715158 = G(self29615165,"typ",L[2815]);
var anf_arg232815159 = G(self29615165,"val",L[2814]);
var anf_arg232915160 = G(self29615165,"branches",L[2813]);
var anf_arg233015161 = G(self29615165,"_else",L[2812]);
var $z1514815149 = D;
var $f1515415155 = function(_) {
return R.isFunction(call_DASH_s_DASH_cases_DASH_else29515156)?call_DASH_s_DASH_cases_DASH_else29515156.app(anf_arg232615157,anf_arg232715158,anf_arg232815159,anf_arg232915160,anf_arg233015161):R.ffi.throwNonFunApp(L[2248],call_DASH_s_DASH_cases_DASH_else29515156,[anf_arg232615157,anf_arg232715158,anf_arg232815159,anf_arg232915160,anf_arg233015161]);
};
try {
if(--R.GAS > 0) {
$z1514815149 = $f1515415155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1515415155,
"from":L[2248]});
}
} catch($e1514615147) {
if(R.isCont($e1514615147)) {
var $ss1515015151 = {"from":L[2248],
"go":function(cont_tail_arg233115162) {
return $Hcont_tail_arg917315164(cont_tail_arg233115162,if_helper231915163);
}};
$e1514615147.stack[R.EXN_STACKHEIGHT++] = $ss1515015151;
}
if(R.isPyretException($e1514615147)) {
$e1514615147.pyretStack.push(L[2248]);
}
throw $e1514615147;
}
var $ret1515215153 = $Hcont_tail_arg917315164($z1514815149,if_helper231915163);
++R.GAS;
return $ret1515215153;
} else {
var $z1516915170 = D;
var $f1517515176 = function(_) {
return R.isFunction(else_DASH_clause29815177)?else_DASH_clause29815177.app():R.ffi.throwNonFunApp(L[2248],else_DASH_clause29815177,[]);
};
try {
if(--R.GAS > 0) {
$z1516915170 = $f1517515176();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1517515176,
"from":L[2248]});
}
} catch($e1516715168) {
if(R.isCont($e1516715168)) {
var $ss1517115172 = {"from":L[2248],
"go":function(cont_tail_arg232415178) {
return $Hcont_tail_arg917415179(cont_tail_arg232415178,if_helper231915163);
}};
$e1516715168.stack[R.EXN_STACKHEIGHT++] = $ss1517115172;
}
if(R.isPyretException($e1516715168)) {
$e1516715168.pyretStack.push(L[2248]);
}
throw $e1516715168;
}
var $ret1517315174 = $Hcont_tail_arg917415179($z1516915170,if_helper231915163);
++R.GAS;
return $ret1517315174;
}
} else {
var cont_tail_arg232115183 = R.throwNonBooleanCondition(L[2248],("if"),if_DASH_30015180);
if(--R.GAS > 0) {
$z1518115182 = R.isFunction(if_helper231915163)?if_helper231915163.app(cont_tail_arg232115183):R.ffi.throwNonFunApp(L[2248],if_helper231915163,[cont_tail_arg232115183]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper231915163)?if_helper231915163.app(cont_tail_arg232115183):R.ffi.throwNonFunApp(L[2248],if_helper231915163,[cont_tail_arg232115183]);
},
"from":L[2248]});
}
++R.GAS;
return $z1518115182;
}
};
},{"length":3});
var anf_variant_member235512315 = R.makeMethod(function(self29915144) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2248],0,arguments);
}
var anf_arg233515142 = G(self29915144,"l",L[2248]);
var $z1513415135 = D;
var $f1514015141 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg233515142):R.ffi.throwNonFunApp(L[2248],torepr65,[anf_arg233515142]);
};
try {
if(--R.GAS > 0) {
$z1513415135 = $f1514015141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1514015141,
"from":L[2248]});
}
} catch($e1513215133) {
if(R.isCont($e1513215133)) {
var $ss1513615137 = {"from":L[2248],
"go":function(anf_arg233615143) {
return $Hanf_arg919015145(anf_arg233615143,self29915144,_plus55,torepr65);
}};
$e1513215133.stack[R.EXN_STACKHEIGHT++] = $ss1513615137;
}
if(R.isPyretException($e1513215133)) {
$e1513215133.pyretStack.push(L[2248]);
}
throw $e1513215133;
}
var $ret1513815139 = $Hanf_arg919015145($z1513415135,self29915144,_plus55,torepr65);
++R.GAS;
return $ret1513815139;
};
},{"length":1});
var anf_variant_member235712316 = R.makeMethod(function(self78215131) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2811],0,arguments);
}
var ann_DASH_check_DASH_temp235615130 = ("s-cases-else");
return ann_DASH_check_DASH_temp235615130;
};
},{"length":1});
var anf_variant_member239112317 = R.makeMethod(function(self78315127) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2810],0,arguments);
}
var anf_fun235915126 = G(PP170,"parens",L[2809]);
var anf_bracket236015129 = G(self78315127,"typ",L[2808]);
var anf_fun236115124 = G(anf_bracket236015129,"tosource",L[2807]);
var $z1511615117 = D;
var $f1512215123 = function(_) {
return R.isFunction(anf_fun236115124)?anf_fun236115124.app():R.ffi.throwNonFunApp(L[2806],anf_fun236115124,[]);
};
try {
if(--R.GAS > 0) {
$z1511615117 = $f1512215123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1512215123,
"from":L[2806]});
}
} catch($e1511415115) {
if(R.isCont($e1511415115)) {
var $ss1511815119 = {"from":L[2806],
"go":function(anf_arg236215125) {
return $Hanf_arg920915128(anf_arg236215125,INDENT118169,PP170,anf_fun235915126,break_DASH_one119168,self78315127,str_DASH_cases130312,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e1511415115.stack[R.EXN_STACKHEIGHT++] = $ss1511815119;
}
if(R.isPyretException($e1511415115)) {
$e1511415115.pyretStack.push(L[2806]);
}
throw $e1511415115;
}
var $ret1512015121 = $Hanf_arg920915128($z1511615117,INDENT118169,PP170,anf_fun235915126,break_DASH_one119168,self78315127,str_DASH_cases130312,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret1512015121;
};
},{"length":1});
var anf_variant_member240612328 = R.makeMethod(function(self30215092) {
return function(cases_DASH_funs30315093,else_DASH_clause30415104) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2247],2,arguments);
}
var if_DASH_30615107 = R.hasField(cases_DASH_funs30315093,("s-try"));
var if_helper239315090 = R.makeFunction(function(if_helper_arg239415112) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2247],1,arguments);
}
var ann_DASH_check_DASH_temp239215113 = if_helper_arg239415112;
return ann_DASH_check_DASH_temp239215113;
});
var anf_if239715111 = R.isBoolean(if_DASH_30615107);
if(R.isPyretTrue(anf_if239715111)) {
if(R.isPyretTrue(if_DASH_30615107)) {
var call_DASH_s_DASH_try30115084 = G(cases_DASH_funs30315093,"s-try",L[2247]);
var anf_arg240015085 = G(self30215092,"l",L[2805]);
var anf_arg240115086 = G(self30215092,"body",L[2804]);
var anf_arg240215087 = G(self30215092,"id",L[2803]);
var anf_arg240315088 = G(self30215092,"_except",L[2802]);
var $z1507615077 = D;
var $f1508215083 = function(_) {
return R.isFunction(call_DASH_s_DASH_try30115084)?call_DASH_s_DASH_try30115084.app(anf_arg240015085,anf_arg240115086,anf_arg240215087,anf_arg240315088):R.ffi.throwNonFunApp(L[2247],call_DASH_s_DASH_try30115084,[anf_arg240015085,anf_arg240115086,anf_arg240215087,anf_arg240315088]);
};
try {
if(--R.GAS > 0) {
$z1507615077 = $f1508215083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1508215083,
"from":L[2247]});
}
} catch($e1507415075) {
if(R.isCont($e1507415075)) {
var $ss1507815079 = {"from":L[2247],
"go":function(cont_tail_arg240415089) {
return $Hcont_tail_arg921015091(cont_tail_arg240415089,if_helper239315090);
}};
$e1507415075.stack[R.EXN_STACKHEIGHT++] = $ss1507815079;
}
if(R.isPyretException($e1507415075)) {
$e1507415075.pyretStack.push(L[2247]);
}
throw $e1507415075;
}
var $ret1508015081 = $Hcont_tail_arg921015091($z1507615077,if_helper239315090);
++R.GAS;
return $ret1508015081;
} else {
var $z1509615097 = D;
var $f1510215103 = function(_) {
return R.isFunction(else_DASH_clause30415104)?else_DASH_clause30415104.app():R.ffi.throwNonFunApp(L[2247],else_DASH_clause30415104,[]);
};
try {
if(--R.GAS > 0) {
$z1509615097 = $f1510215103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1510215103,
"from":L[2247]});
}
} catch($e1509415095) {
if(R.isCont($e1509415095)) {
var $ss1509815099 = {"from":L[2247],
"go":function(cont_tail_arg239815105) {
return $Hcont_tail_arg921115106(cont_tail_arg239815105,if_helper239315090);
}};
$e1509415095.stack[R.EXN_STACKHEIGHT++] = $ss1509815099;
}
if(R.isPyretException($e1509415095)) {
$e1509415095.pyretStack.push(L[2247]);
}
throw $e1509415095;
}
var $ret1510015101 = $Hcont_tail_arg921115106($z1509615097,if_helper239315090);
++R.GAS;
return $ret1510015101;
}
} else {
var cont_tail_arg239515110 = R.throwNonBooleanCondition(L[2247],("if"),if_DASH_30615107);
if(--R.GAS > 0) {
$z1510815109 = R.isFunction(if_helper239315090)?if_helper239315090.app(cont_tail_arg239515110):R.ffi.throwNonFunApp(L[2247],if_helper239315090,[cont_tail_arg239515110]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper239315090)?if_helper239315090.app(cont_tail_arg239515110):R.ffi.throwNonFunApp(L[2247],if_helper239315090,[cont_tail_arg239515110]);
},
"from":L[2247]});
}
++R.GAS;
return $z1510815109;
}
};
},{"length":3});
var anf_variant_member242412329 = R.makeMethod(function(self30515072) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2247],0,arguments);
}
var anf_arg240815070 = G(self30515072,"l",L[2247]);
var $z1506215063 = D;
var $f1506815069 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg240815070):R.ffi.throwNonFunApp(L[2247],torepr65,[anf_arg240815070]);
};
try {
if(--R.GAS > 0) {
$z1506215063 = $f1506815069();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1506815069,
"from":L[2247]});
}
} catch($e1506015061) {
if(R.isCont($e1506015061)) {
var $ss1506415065 = {"from":L[2247],
"go":function(anf_arg240915071) {
return $Hanf_arg922415073(anf_arg240915071,self30515072,_plus55,torepr65);
}};
$e1506015061.stack[R.EXN_STACKHEIGHT++] = $ss1506415065;
}
if(R.isPyretException($e1506015061)) {
$e1506015061.pyretStack.push(L[2247]);
}
throw $e1506015061;
}
var $ret1506615067 = $Hanf_arg922415073($z1506215063,self30515072,_plus55,torepr65);
++R.GAS;
return $ret1506615067;
};
},{"length":1});
var anf_variant_member242612330 = R.makeMethod(function(self79115059) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2801],0,arguments);
}
var ann_DASH_check_DASH_temp242515058 = ("s-try");
return ann_DASH_check_DASH_temp242515058;
};
},{"length":1});
var anf_variant_member245212331 = R.makeMethod(function(self79215056) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2800],0,arguments);
}
var $z1504715048 = D;
var $f1505315054 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_try173871,break_DASH_one119168):R.ffi.throwNonFunApp(L[2799],_plus55,[str_DASH_try173871,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z1504715048 = $f1505315054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1505315054,
"from":L[2799]});
}
} catch($e1504515046) {
if(R.isCont($e1504515046)) {
var $ss1504915050 = {"from":L[2799],
"go":function(anf_arg242815055) {
return $Hanf_arg924115057(anf_arg242815055,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
}};
$e1504515046.stack[R.EXN_STACKHEIGHT++] = $ss1504915050;
}
if(R.isPyretException($e1504515046)) {
$e1504515046.pyretStack.push(L[2799]);
}
throw $e1504515046;
}
var $ret1505115052 = $Hanf_arg924115057($z1504715048,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
++R.GAS;
return $ret1505115052;
};
},{"length":1});
var anf_variant_member246712341 = R.makeMethod(function(self30815023) {
return function(cases_DASH_funs30915024,else_DASH_clause31015035) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2246],2,arguments);
}
var if_DASH_31215038 = R.hasField(cases_DASH_funs30915024,("s-op"));
var if_helper245415021 = R.makeFunction(function(if_helper_arg245515043) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2246],1,arguments);
}
var ann_DASH_check_DASH_temp245315044 = if_helper_arg245515043;
return ann_DASH_check_DASH_temp245315044;
});
var anf_if245815042 = R.isBoolean(if_DASH_31215038);
if(R.isPyretTrue(anf_if245815042)) {
if(R.isPyretTrue(if_DASH_31215038)) {
var call_DASH_s_DASH_op30715015 = G(cases_DASH_funs30915024,"s-op",L[2246]);
var anf_arg246115016 = G(self30815023,"l",L[2798]);
var anf_arg246215017 = G(self30815023,"op",L[2797]);
var anf_arg246315018 = G(self30815023,"left",L[2796]);
var anf_arg246415019 = G(self30815023,"right",L[2795]);
var $z1500715008 = D;
var $f1501315014 = function(_) {
return R.isFunction(call_DASH_s_DASH_op30715015)?call_DASH_s_DASH_op30715015.app(anf_arg246115016,anf_arg246215017,anf_arg246315018,anf_arg246415019):R.ffi.throwNonFunApp(L[2246],call_DASH_s_DASH_op30715015,[anf_arg246115016,anf_arg246215017,anf_arg246315018,anf_arg246415019]);
};
try {
if(--R.GAS > 0) {
$z1500715008 = $f1501315014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1501315014,
"from":L[2246]});
}
} catch($e1500515006) {
if(R.isCont($e1500515006)) {
var $ss1500915010 = {"from":L[2246],
"go":function(cont_tail_arg246515020) {
return $Hcont_tail_arg924215022(cont_tail_arg246515020,if_helper245415021);
}};
$e1500515006.stack[R.EXN_STACKHEIGHT++] = $ss1500915010;
}
if(R.isPyretException($e1500515006)) {
$e1500515006.pyretStack.push(L[2246]);
}
throw $e1500515006;
}
var $ret1501115012 = $Hcont_tail_arg924215022($z1500715008,if_helper245415021);
++R.GAS;
return $ret1501115012;
} else {
var $z1502715028 = D;
var $f1503315034 = function(_) {
return R.isFunction(else_DASH_clause31015035)?else_DASH_clause31015035.app():R.ffi.throwNonFunApp(L[2246],else_DASH_clause31015035,[]);
};
try {
if(--R.GAS > 0) {
$z1502715028 = $f1503315034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1503315034,
"from":L[2246]});
}
} catch($e1502515026) {
if(R.isCont($e1502515026)) {
var $ss1502915030 = {"from":L[2246],
"go":function(cont_tail_arg245915036) {
return $Hcont_tail_arg924315037(cont_tail_arg245915036,if_helper245415021);
}};
$e1502515026.stack[R.EXN_STACKHEIGHT++] = $ss1502915030;
}
if(R.isPyretException($e1502515026)) {
$e1502515026.pyretStack.push(L[2246]);
}
throw $e1502515026;
}
var $ret1503115032 = $Hcont_tail_arg924315037($z1502715028,if_helper245415021);
++R.GAS;
return $ret1503115032;
}
} else {
var cont_tail_arg245615041 = R.throwNonBooleanCondition(L[2246],("if"),if_DASH_31215038);
if(--R.GAS > 0) {
$z1503915040 = R.isFunction(if_helper245415021)?if_helper245415021.app(cont_tail_arg245615041):R.ffi.throwNonFunApp(L[2246],if_helper245415021,[cont_tail_arg245615041]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper245415021)?if_helper245415021.app(cont_tail_arg245615041):R.ffi.throwNonFunApp(L[2246],if_helper245415021,[cont_tail_arg245615041]);
},
"from":L[2246]});
}
++R.GAS;
return $z1503915040;
}
};
},{"length":3});
var anf_variant_member248512342 = R.makeMethod(function(self31115003) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2246],0,arguments);
}
var anf_arg246915001 = G(self31115003,"l",L[2246]);
var $z1499314994 = D;
var $f1499915000 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg246915001):R.ffi.throwNonFunApp(L[2246],torepr65,[anf_arg246915001]);
};
try {
if(--R.GAS > 0) {
$z1499314994 = $f1499915000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1499915000,
"from":L[2246]});
}
} catch($e1499114992) {
if(R.isCont($e1499114992)) {
var $ss1499514996 = {"from":L[2246],
"go":function(anf_arg247015002) {
return $Hanf_arg925615004(anf_arg247015002,self31115003,_plus55,torepr65);
}};
$e1499114992.stack[R.EXN_STACKHEIGHT++] = $ss1499514996;
}
if(R.isPyretException($e1499114992)) {
$e1499114992.pyretStack.push(L[2246]);
}
throw $e1499114992;
}
var $ret1499714998 = $Hanf_arg925615004($z1499314994,self31115003,_plus55,torepr65);
++R.GAS;
return $ret1499714998;
};
},{"length":1});
var anf_variant_member248712343 = R.makeMethod(function(self79914990) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2794],0,arguments);
}
var ann_DASH_check_DASH_temp248614989 = ("s-op");
return ann_DASH_check_DASH_temp248614989;
};
},{"length":1});
var anf_variant_member256212344 = R.makeMethod(function(self80014974) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2793],0,arguments);
}
var collect_DASH_same_DASH_operands80114960 = {"$var":D,
"$name":"collect-same-operands"};
var anf_assign251614961 = R.makeFunction(function(exp80214976) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2790],1,arguments);
}
var $z1497914980 = D;
var $f1498514986 = function(_) {
return R.isFunction(is_DASH_s_DASH_op3652031.$var === D?U(L[2791],"is-s-op"):is_DASH_s_DASH_op3652031.$var)?is_DASH_s_DASH_op3652031.$var === D?U(L[2791],"is-s-op"):is_DASH_s_DASH_op3652031.$var.app(exp80214976):R.ffi.throwNonFunApp(L[2792],is_DASH_s_DASH_op3652031.$var === D?U(L[2791],"is-s-op"):is_DASH_s_DASH_op3652031.$var,[exp80214976]);
};
try {
if(--R.GAS > 0) {
$z1497914980 = $f1498514986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1498514986,
"from":L[2792]});
}
} catch($e1497714978) {
if(R.isCont($e1497714978)) {
var $ss1498114982 = {"from":L[2792],
"go":function(and_DASH_oper_DASH_31414987) {
return $Hand_DASH_oper_DASH_926314988(and_DASH_oper_DASH_31414987,collect_DASH_same_DASH_operands80114960,exp80214976,list25154,self80014974,_plus55);
}};
$e1497714978.stack[R.EXN_STACKHEIGHT++] = $ss1498114982;
}
if(R.isPyretException($e1497714978)) {
$e1497714978.pyretStack.push(L[2792]);
}
throw $e1497714978;
}
var $ret1498314984 = $Hand_DASH_oper_DASH_926314988($z1497914980,collect_DASH_same_DASH_operands80114960,exp80214976,list25154,self80014974,_plus55);
++R.GAS;
return $ret1498314984;
});
collect_DASH_same_DASH_operands80114960.$var = anf_assign251614961;
var anf_arg251714972 = G(self80014974,"left",L[2789]);
var $z1496414965 = D;
var $f1497014971 = function(_) {
return R.isFunction(collect_DASH_same_DASH_operands80114960.$var)?collect_DASH_same_DASH_operands80114960.$var.app(anf_arg251714972):R.ffi.throwNonFunApp(L[2788],collect_DASH_same_DASH_operands80114960.$var,[anf_arg251714972]);
};
try {
if(--R.GAS > 0) {
$z1496414965 = $f1497014971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1497014971,
"from":L[2788]});
}
} catch($e1496214963) {
if(R.isCont($e1496214963)) {
var $ss1496614967 = {"from":L[2788],
"go":function(anf_arg251814973) {
return $Hanf_arg928514975(anf_arg251814973,INDENT118169,PP170,break_DASH_one119168,collect_DASH_same_DASH_operands80114960,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64);
}};
$e1496214963.stack[R.EXN_STACKHEIGHT++] = $ss1496614967;
}
if(R.isPyretException($e1496214963)) {
$e1496214963.pyretStack.push(L[2788]);
}
throw $e1496214963;
}
var $ret1496814969 = $Hanf_arg928514975($z1496414965,INDENT118169,PP170,break_DASH_one119168,collect_DASH_same_DASH_operands80114960,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64);
++R.GAS;
return $ret1496814969;
};
},{"length":1});
var anf_variant_member257712354 = R.makeMethod(function(self31914938) {
return function(cases_DASH_funs32014939,else_DASH_clause32114950) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2245],2,arguments);
}
var if_DASH_32314953 = R.hasField(cases_DASH_funs32014939,("s-check-test"));
var if_helper256414936 = R.makeFunction(function(if_helper_arg256514958) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2245],1,arguments);
}
var ann_DASH_check_DASH_temp256314959 = if_helper_arg256514958;
return ann_DASH_check_DASH_temp256314959;
});
var anf_if256814957 = R.isBoolean(if_DASH_32314953);
if(R.isPyretTrue(anf_if256814957)) {
if(R.isPyretTrue(if_DASH_32314953)) {
var call_DASH_s_DASH_check_DASH_test31814930 = G(cases_DASH_funs32014939,"s-check-test",L[2245]);
var anf_arg257114931 = G(self31914938,"l",L[2787]);
var anf_arg257214932 = G(self31914938,"op",L[2786]);
var anf_arg257314933 = G(self31914938,"left",L[2785]);
var anf_arg257414934 = G(self31914938,"right",L[2784]);
var $z1492214923 = D;
var $f1492814929 = function(_) {
return R.isFunction(call_DASH_s_DASH_check_DASH_test31814930)?call_DASH_s_DASH_check_DASH_test31814930.app(anf_arg257114931,anf_arg257214932,anf_arg257314933,anf_arg257414934):R.ffi.throwNonFunApp(L[2245],call_DASH_s_DASH_check_DASH_test31814930,[anf_arg257114931,anf_arg257214932,anf_arg257314933,anf_arg257414934]);
};
try {
if(--R.GAS > 0) {
$z1492214923 = $f1492814929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1492814929,
"from":L[2245]});
}
} catch($e1492014921) {
if(R.isCont($e1492014921)) {
var $ss1492414925 = {"from":L[2245],
"go":function(cont_tail_arg257514935) {
return $Hcont_tail_arg928614937(cont_tail_arg257514935,if_helper256414936);
}};
$e1492014921.stack[R.EXN_STACKHEIGHT++] = $ss1492414925;
}
if(R.isPyretException($e1492014921)) {
$e1492014921.pyretStack.push(L[2245]);
}
throw $e1492014921;
}
var $ret1492614927 = $Hcont_tail_arg928614937($z1492214923,if_helper256414936);
++R.GAS;
return $ret1492614927;
} else {
var $z1494214943 = D;
var $f1494814949 = function(_) {
return R.isFunction(else_DASH_clause32114950)?else_DASH_clause32114950.app():R.ffi.throwNonFunApp(L[2245],else_DASH_clause32114950,[]);
};
try {
if(--R.GAS > 0) {
$z1494214943 = $f1494814949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1494814949,
"from":L[2245]});
}
} catch($e1494014941) {
if(R.isCont($e1494014941)) {
var $ss1494414945 = {"from":L[2245],
"go":function(cont_tail_arg256914951) {
return $Hcont_tail_arg928714952(cont_tail_arg256914951,if_helper256414936);
}};
$e1494014941.stack[R.EXN_STACKHEIGHT++] = $ss1494414945;
}
if(R.isPyretException($e1494014941)) {
$e1494014941.pyretStack.push(L[2245]);
}
throw $e1494014941;
}
var $ret1494614947 = $Hcont_tail_arg928714952($z1494214943,if_helper256414936);
++R.GAS;
return $ret1494614947;
}
} else {
var cont_tail_arg256614956 = R.throwNonBooleanCondition(L[2245],("if"),if_DASH_32314953);
if(--R.GAS > 0) {
$z1495414955 = R.isFunction(if_helper256414936)?if_helper256414936.app(cont_tail_arg256614956):R.ffi.throwNonFunApp(L[2245],if_helper256414936,[cont_tail_arg256614956]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper256414936)?if_helper256414936.app(cont_tail_arg256614956):R.ffi.throwNonFunApp(L[2245],if_helper256414936,[cont_tail_arg256614956]);
},
"from":L[2245]});
}
++R.GAS;
return $z1495414955;
}
};
},{"length":3});
var anf_variant_member259512355 = R.makeMethod(function(self32214918) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2245],0,arguments);
}
var anf_arg257914916 = G(self32214918,"l",L[2245]);
var $z1490814909 = D;
var $f1491414915 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg257914916):R.ffi.throwNonFunApp(L[2245],torepr65,[anf_arg257914916]);
};
try {
if(--R.GAS > 0) {
$z1490814909 = $f1491414915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1491414915,
"from":L[2245]});
}
} catch($e1490614907) {
if(R.isCont($e1490614907)) {
var $ss1491014911 = {"from":L[2245],
"go":function(anf_arg258014917) {
return $Hanf_arg930014919(anf_arg258014917,self32214918,_plus55,torepr65);
}};
$e1490614907.stack[R.EXN_STACKHEIGHT++] = $ss1491014911;
}
if(R.isPyretException($e1490614907)) {
$e1490614907.pyretStack.push(L[2245]);
}
throw $e1490614907;
}
var $ret1491214913 = $Hanf_arg930014919($z1490814909,self32214918,_plus55,torepr65);
++R.GAS;
return $ret1491214913;
};
},{"length":1});
var anf_variant_member261012356 = R.makeMethod(function(self81614904) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2783],0,arguments);
}
var anf_fun259714902 = G(PP170,"infix",L[2782]);
var anf_fun259814903 = G(PP170,"str",L[2781]);
var anf_arg259914901 = G(self81614904,"op",L[2780]);
var anf_arg260014899 = G(self81614904,"op",L[2779]);
var $z1489114892 = D;
var $f1489714898 = function(_) {
return R.isFunction(string_DASH_length63)?string_DASH_length63.app(anf_arg260014899):R.ffi.throwNonFunApp(L[2778],string_DASH_length63,[anf_arg260014899]);
};
try {
if(--R.GAS > 0) {
$z1489114892 = $f1489714898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1489714898,
"from":L[2778]});
}
} catch($e1488914890) {
if(R.isCont($e1488914890)) {
var $ss1489314894 = {"from":L[2778],
"go":function(anf_arg260114900) {
return $Hanf_arg930614905(anf_arg260114900,INDENT118169,anf_arg259914901,anf_fun259714902,anf_fun259814903,self81614904,string_DASH_substring64);
}};
$e1488914890.stack[R.EXN_STACKHEIGHT++] = $ss1489314894;
}
if(R.isPyretException($e1488914890)) {
$e1488914890.pyretStack.push(L[2778]);
}
throw $e1488914890;
}
var $ret1489514896 = $Hanf_arg930614905($z1489114892,INDENT118169,anf_arg259914901,anf_fun259714902,anf_fun259814903,self81614904,string_DASH_substring64);
++R.GAS;
return $ret1489514896;
};
},{"length":1});
var anf_variant_member262312366 = R.makeMethod(function(self32514867) {
return function(cases_DASH_funs32614868,else_DASH_clause32714879) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2244],2,arguments);
}
var if_DASH_32914882 = R.hasField(cases_DASH_funs32614868,("s-paren"));
var if_helper261214865 = R.makeFunction(function(if_helper_arg261314887) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2244],1,arguments);
}
var ann_DASH_check_DASH_temp261114888 = if_helper_arg261314887;
return ann_DASH_check_DASH_temp261114888;
});
var anf_if261614886 = R.isBoolean(if_DASH_32914882);
if(R.isPyretTrue(anf_if261614886)) {
if(R.isPyretTrue(if_DASH_32914882)) {
var call_DASH_s_DASH_paren32414861 = G(cases_DASH_funs32614868,"s-paren",L[2244]);
var anf_arg261914862 = G(self32514867,"l",L[2777]);
var anf_arg262014863 = G(self32514867,"expr",L[2776]);
var $z1485314854 = D;
var $f1485914860 = function(_) {
return R.isFunction(call_DASH_s_DASH_paren32414861)?call_DASH_s_DASH_paren32414861.app(anf_arg261914862,anf_arg262014863):R.ffi.throwNonFunApp(L[2244],call_DASH_s_DASH_paren32414861,[anf_arg261914862,anf_arg262014863]);
};
try {
if(--R.GAS > 0) {
$z1485314854 = $f1485914860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1485914860,
"from":L[2244]});
}
} catch($e1485114852) {
if(R.isCont($e1485114852)) {
var $ss1485514856 = {"from":L[2244],
"go":function(cont_tail_arg262114864) {
return $Hcont_tail_arg930714866(cont_tail_arg262114864,if_helper261214865);
}};
$e1485114852.stack[R.EXN_STACKHEIGHT++] = $ss1485514856;
}
if(R.isPyretException($e1485114852)) {
$e1485114852.pyretStack.push(L[2244]);
}
throw $e1485114852;
}
var $ret1485714858 = $Hcont_tail_arg930714866($z1485314854,if_helper261214865);
++R.GAS;
return $ret1485714858;
} else {
var $z1487114872 = D;
var $f1487714878 = function(_) {
return R.isFunction(else_DASH_clause32714879)?else_DASH_clause32714879.app():R.ffi.throwNonFunApp(L[2244],else_DASH_clause32714879,[]);
};
try {
if(--R.GAS > 0) {
$z1487114872 = $f1487714878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1487714878,
"from":L[2244]});
}
} catch($e1486914870) {
if(R.isCont($e1486914870)) {
var $ss1487314874 = {"from":L[2244],
"go":function(cont_tail_arg261714880) {
return $Hcont_tail_arg930814881(cont_tail_arg261714880,if_helper261214865);
}};
$e1486914870.stack[R.EXN_STACKHEIGHT++] = $ss1487314874;
}
if(R.isPyretException($e1486914870)) {
$e1486914870.pyretStack.push(L[2244]);
}
throw $e1486914870;
}
var $ret1487514876 = $Hcont_tail_arg930814881($z1487114872,if_helper261214865);
++R.GAS;
return $ret1487514876;
}
} else {
var cont_tail_arg261414885 = R.throwNonBooleanCondition(L[2244],("if"),if_DASH_32914882);
if(--R.GAS > 0) {
$z1488314884 = R.isFunction(if_helper261214865)?if_helper261214865.app(cont_tail_arg261414885):R.ffi.throwNonFunApp(L[2244],if_helper261214865,[cont_tail_arg261414885]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper261214865)?if_helper261214865.app(cont_tail_arg261414885):R.ffi.throwNonFunApp(L[2244],if_helper261214865,[cont_tail_arg261414885]);
},
"from":L[2244]});
}
++R.GAS;
return $z1488314884;
}
};
},{"length":3});
var anf_variant_member263312367 = R.makeMethod(function(self32814849) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2244],0,arguments);
}
var anf_arg262514847 = G(self32814849,"l",L[2244]);
var $z1483914840 = D;
var $f1484514846 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg262514847):R.ffi.throwNonFunApp(L[2244],torepr65,[anf_arg262514847]);
};
try {
if(--R.GAS > 0) {
$z1483914840 = $f1484514846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1484514846,
"from":L[2244]});
}
} catch($e1483714838) {
if(R.isCont($e1483714838)) {
var $ss1484114842 = {"from":L[2244],
"go":function(anf_arg262614848) {
return $Hanf_arg931514850(anf_arg262614848,self32814849,_plus55,torepr65);
}};
$e1483714838.stack[R.EXN_STACKHEIGHT++] = $ss1484114842;
}
if(R.isPyretException($e1483714838)) {
$e1483714838.pyretStack.push(L[2244]);
}
throw $e1483714838;
}
var $ret1484314844 = $Hanf_arg931514850($z1483914840,self32814849,_plus55,torepr65);
++R.GAS;
return $ret1484314844;
};
},{"length":1});
var anf_variant_member263512368 = R.makeMethod(function(self81914836) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2775],0,arguments);
}
var ann_DASH_check_DASH_temp263414835 = ("s-paren");
return ann_DASH_check_DASH_temp263414835;
};
},{"length":1});
var anf_variant_member264112369 = R.makeMethod(function(self82014834) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2774],0,arguments);
}
var anf_fun263714831 = G(PP170,"parens",L[2773]);
var anf_bracket263814833 = G(self82014834,"expr",L[2772]);
var anf_fun263914829 = G(anf_bracket263814833,"tosource",L[2771]);
var $z1482114822 = D;
var $f1482714828 = function(_) {
return R.isFunction(anf_fun263914829)?anf_fun263914829.app():R.ffi.throwNonFunApp(L[2770],anf_fun263914829,[]);
};
try {
if(--R.GAS > 0) {
$z1482114822 = $f1482714828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1482714828,
"from":L[2770]});
}
} catch($e1481914820) {
if(R.isCont($e1481914820)) {
var $ss1482314824 = {"from":L[2770],
"go":function(anf_arg264014830) {
return $Hanf_arg931714832(anf_arg264014830,anf_fun263714831);
}};
$e1481914820.stack[R.EXN_STACKHEIGHT++] = $ss1482314824;
}
if(R.isPyretException($e1481914820)) {
$e1481914820.pyretStack.push(L[2770]);
}
throw $e1481914820;
}
var $ret1482514826 = $Hanf_arg931714832($z1482114822,anf_fun263714831);
++R.GAS;
return $ret1482514826;
};
},{"length":1});
var anf_variant_member265912377 = R.makeMethod(function(self33114797) {
return function(cases_DASH_funs33214798,else_DASH_clause33314809) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2243],2,arguments);
}
var if_DASH_33514812 = R.hasField(cases_DASH_funs33214798,("s-lam"));
var if_helper264314795 = R.makeFunction(function(if_helper_arg264414817) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2243],1,arguments);
}
var ann_DASH_check_DASH_temp264214818 = if_helper_arg264414817;
return ann_DASH_check_DASH_temp264214818;
});
var anf_if264714816 = R.isBoolean(if_DASH_33514812);
if(R.isPyretTrue(anf_if264714816)) {
if(R.isPyretTrue(if_DASH_33514812)) {
var call_DASH_s_DASH_lam33014786 = G(cases_DASH_funs33214798,"s-lam",L[2243]);
var anf_arg265014787 = G(self33114797,"l",L[2769]);
var anf_arg265114788 = G(self33114797,"params",L[2768]);
var anf_arg265214789 = G(self33114797,"args",L[2767]);
var anf_arg265314790 = G(self33114797,"ann",L[2766]);
var anf_arg265414791 = G(self33114797,"doc",L[2765]);
var anf_arg265514792 = G(self33114797,"body",L[2764]);
var anf_arg265614793 = G(self33114797,"_check",L[2763]);
var $z1477814779 = D;
var $f1478414785 = function(_) {
return R.isFunction(call_DASH_s_DASH_lam33014786)?call_DASH_s_DASH_lam33014786.app(anf_arg265014787,anf_arg265114788,anf_arg265214789,anf_arg265314790,anf_arg265414791,anf_arg265514792,anf_arg265614793):R.ffi.throwNonFunApp(L[2243],call_DASH_s_DASH_lam33014786,[anf_arg265014787,anf_arg265114788,anf_arg265214789,anf_arg265314790,anf_arg265414791,anf_arg265514792,anf_arg265614793]);
};
try {
if(--R.GAS > 0) {
$z1477814779 = $f1478414785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1478414785,
"from":L[2243]});
}
} catch($e1477614777) {
if(R.isCont($e1477614777)) {
var $ss1478014781 = {"from":L[2243],
"go":function(cont_tail_arg265714794) {
return $Hcont_tail_arg931814796(cont_tail_arg265714794,if_helper264314795);
}};
$e1477614777.stack[R.EXN_STACKHEIGHT++] = $ss1478014781;
}
if(R.isPyretException($e1477614777)) {
$e1477614777.pyretStack.push(L[2243]);
}
throw $e1477614777;
}
var $ret1478214783 = $Hcont_tail_arg931814796($z1477814779,if_helper264314795);
++R.GAS;
return $ret1478214783;
} else {
var $z1480114802 = D;
var $f1480714808 = function(_) {
return R.isFunction(else_DASH_clause33314809)?else_DASH_clause33314809.app():R.ffi.throwNonFunApp(L[2243],else_DASH_clause33314809,[]);
};
try {
if(--R.GAS > 0) {
$z1480114802 = $f1480714808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1480714808,
"from":L[2243]});
}
} catch($e1479914800) {
if(R.isCont($e1479914800)) {
var $ss1480314804 = {"from":L[2243],
"go":function(cont_tail_arg264814810) {
return $Hcont_tail_arg931914811(cont_tail_arg264814810,if_helper264314795);
}};
$e1479914800.stack[R.EXN_STACKHEIGHT++] = $ss1480314804;
}
if(R.isPyretException($e1479914800)) {
$e1479914800.pyretStack.push(L[2243]);
}
throw $e1479914800;
}
var $ret1480514806 = $Hcont_tail_arg931914811($z1480114802,if_helper264314795);
++R.GAS;
return $ret1480514806;
}
} else {
var cont_tail_arg264514815 = R.throwNonBooleanCondition(L[2243],("if"),if_DASH_33514812);
if(--R.GAS > 0) {
$z1481314814 = R.isFunction(if_helper264314795)?if_helper264314795.app(cont_tail_arg264514815):R.ffi.throwNonFunApp(L[2243],if_helper264314795,[cont_tail_arg264514815]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper264314795)?if_helper264314795.app(cont_tail_arg264514815):R.ffi.throwNonFunApp(L[2243],if_helper264314795,[cont_tail_arg264514815]);
},
"from":L[2243]});
}
++R.GAS;
return $z1481314814;
}
};
},{"length":3});
var anf_variant_member268912378 = R.makeMethod(function(self33414774) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2243],0,arguments);
}
var anf_arg266114772 = G(self33414774,"l",L[2243]);
var $z1476414765 = D;
var $f1477014771 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg266114772):R.ffi.throwNonFunApp(L[2243],torepr65,[anf_arg266114772]);
};
try {
if(--R.GAS > 0) {
$z1476414765 = $f1477014771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1477014771,
"from":L[2243]});
}
} catch($e1476214763) {
if(R.isCont($e1476214763)) {
var $ss1476614767 = {"from":L[2243],
"go":function(anf_arg266214773) {
return $Hanf_arg934114775(anf_arg266214773,self33414774,_plus55,torepr65);
}};
$e1476214763.stack[R.EXN_STACKHEIGHT++] = $ss1476614767;
}
if(R.isPyretException($e1476214763)) {
$e1476214763.pyretStack.push(L[2243]);
}
throw $e1476214763;
}
var $ret1476814769 = $Hanf_arg934114775($z1476414765,self33414774,_plus55,torepr65);
++R.GAS;
return $ret1476814769;
};
},{"length":1});
var anf_variant_member269112379 = R.makeMethod(function(self82814761) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2762],0,arguments);
}
var ann_DASH_check_DASH_temp269014760 = ("s-lam");
return ann_DASH_check_DASH_temp269014760;
};
},{"length":1});
var anf_variant_member269912380 = R.makeMethod(function(self82914759) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2755],0,arguments);
}
var anf_arg269314751 = G(self82914759,"params",L[2761]);
var anf_arg269414752 = G(self82914759,"args",L[2760]);
var anf_arg269514753 = G(self82914759,"ann",L[2759]);
var anf_arg269614754 = G(self82914759,"doc",L[2758]);
var anf_arg269714755 = G(self82914759,"body",L[2757]);
var anf_arg269814756 = G(self82914759,"_check",L[2756]);
var $z1474314744 = D;
var $f1474914750 = function(_) {
return R.isFunction(funlam_DASH_tosource2501801.$var)?funlam_DASH_tosource2501801.$var.app(str_DASH_lam153611,nothing61,anf_arg269314751,anf_arg269414752,anf_arg269514753,anf_arg269614754,anf_arg269714755,anf_arg269814756):R.ffi.throwNonFunApp(L[2755],funlam_DASH_tosource2501801.$var,[str_DASH_lam153611,nothing61,anf_arg269314751,anf_arg269414752,anf_arg269514753,anf_arg269614754,anf_arg269714755,anf_arg269814756]);
};
try {
if(--R.GAS > 0) {
$z1474314744 = $f1474914750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1474914750,
"from":L[2755]});
}
} catch($e1474114742) {
if(R.isCont($e1474114742)) {
var $ss1474514746 = {"from":L[2755],
"go":function(ann_DASH_check_DASH_temp269214757) {
return $Hann_DASH_check_DASH_temp934214758(ann_DASH_check_DASH_temp269214757);
}};
$e1474114742.stack[R.EXN_STACKHEIGHT++] = $ss1474514746;
}
if(R.isPyretException($e1474114742)) {
$e1474114742.pyretStack.push(L[2755]);
}
throw $e1474114742;
}
var $ret1474714748 = $Hann_DASH_check_DASH_temp934214758($z1474314744);
++R.GAS;
return $ret1474714748;
};
},{"length":1});
var anf_variant_member271612393 = R.makeMethod(function(self33714719) {
return function(cases_DASH_funs33814720,else_DASH_clause33914731) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2242],2,arguments);
}
var if_DASH_34114734 = R.hasField(cases_DASH_funs33814720,("s-method"));
var if_helper270114717 = R.makeFunction(function(if_helper_arg270214739) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2242],1,arguments);
}
var ann_DASH_check_DASH_temp270014740 = if_helper_arg270214739;
return ann_DASH_check_DASH_temp270014740;
});
var anf_if270514738 = R.isBoolean(if_DASH_34114734);
if(R.isPyretTrue(anf_if270514738)) {
if(R.isPyretTrue(if_DASH_34114734)) {
var call_DASH_s_DASH_method33614709 = G(cases_DASH_funs33814720,"s-method",L[2242]);
var anf_arg270814710 = G(self33714719,"l",L[2754]);
var anf_arg270914711 = G(self33714719,"args",L[2753]);
var anf_arg271014712 = G(self33714719,"ann",L[2752]);
var anf_arg271114713 = G(self33714719,"doc",L[2751]);
var anf_arg271214714 = G(self33714719,"body",L[2750]);
var anf_arg271314715 = G(self33714719,"_check",L[2749]);
var $z1470114702 = D;
var $f1470714708 = function(_) {
return R.isFunction(call_DASH_s_DASH_method33614709)?call_DASH_s_DASH_method33614709.app(anf_arg270814710,anf_arg270914711,anf_arg271014712,anf_arg271114713,anf_arg271214714,anf_arg271314715):R.ffi.throwNonFunApp(L[2242],call_DASH_s_DASH_method33614709,[anf_arg270814710,anf_arg270914711,anf_arg271014712,anf_arg271114713,anf_arg271214714,anf_arg271314715]);
};
try {
if(--R.GAS > 0) {
$z1470114702 = $f1470714708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1470714708,
"from":L[2242]});
}
} catch($e1469914700) {
if(R.isCont($e1469914700)) {
var $ss1470314704 = {"from":L[2242],
"go":function(cont_tail_arg271414716) {
return $Hcont_tail_arg934314718(cont_tail_arg271414716,if_helper270114717);
}};
$e1469914700.stack[R.EXN_STACKHEIGHT++] = $ss1470314704;
}
if(R.isPyretException($e1469914700)) {
$e1469914700.pyretStack.push(L[2242]);
}
throw $e1469914700;
}
var $ret1470514706 = $Hcont_tail_arg934314718($z1470114702,if_helper270114717);
++R.GAS;
return $ret1470514706;
} else {
var $z1472314724 = D;
var $f1472914730 = function(_) {
return R.isFunction(else_DASH_clause33914731)?else_DASH_clause33914731.app():R.ffi.throwNonFunApp(L[2242],else_DASH_clause33914731,[]);
};
try {
if(--R.GAS > 0) {
$z1472314724 = $f1472914730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1472914730,
"from":L[2242]});
}
} catch($e1472114722) {
if(R.isCont($e1472114722)) {
var $ss1472514726 = {"from":L[2242],
"go":function(cont_tail_arg270614732) {
return $Hcont_tail_arg934414733(cont_tail_arg270614732,if_helper270114717);
}};
$e1472114722.stack[R.EXN_STACKHEIGHT++] = $ss1472514726;
}
if(R.isPyretException($e1472114722)) {
$e1472114722.pyretStack.push(L[2242]);
}
throw $e1472114722;
}
var $ret1472714728 = $Hcont_tail_arg934414733($z1472314724,if_helper270114717);
++R.GAS;
return $ret1472714728;
}
} else {
var cont_tail_arg270314737 = R.throwNonBooleanCondition(L[2242],("if"),if_DASH_34114734);
if(--R.GAS > 0) {
$z1473514736 = R.isFunction(if_helper270114717)?if_helper270114717.app(cont_tail_arg270314737):R.ffi.throwNonFunApp(L[2242],if_helper270114717,[cont_tail_arg270314737]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper270114717)?if_helper270114717.app(cont_tail_arg270314737):R.ffi.throwNonFunApp(L[2242],if_helper270114717,[cont_tail_arg270314737]);
},
"from":L[2242]});
}
++R.GAS;
return $z1473514736;
}
};
},{"length":3});
var anf_variant_member274212394 = R.makeMethod(function(self34014697) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2242],0,arguments);
}
var anf_arg271814695 = G(self34014697,"l",L[2242]);
var $z1468714688 = D;
var $f1469314694 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg271814695):R.ffi.throwNonFunApp(L[2242],torepr65,[anf_arg271814695]);
};
try {
if(--R.GAS > 0) {
$z1468714688 = $f1469314694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1469314694,
"from":L[2242]});
}
} catch($e1468514686) {
if(R.isCont($e1468514686)) {
var $ss1468914690 = {"from":L[2242],
"go":function(anf_arg271914696) {
return $Hanf_arg936314698(anf_arg271914696,self34014697,_plus55,torepr65);
}};
$e1468514686.stack[R.EXN_STACKHEIGHT++] = $ss1468914690;
}
if(R.isPyretException($e1468514686)) {
$e1468514686.pyretStack.push(L[2242]);
}
throw $e1468514686;
}
var $ret1469114692 = $Hanf_arg936314698($z1468714688,self34014697,_plus55,torepr65);
++R.GAS;
return $ret1469114692;
};
},{"length":1});
var anf_variant_member274412395 = R.makeMethod(function(self83614684) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2748],0,arguments);
}
var ann_DASH_check_DASH_temp274314683 = ("s-method");
return ann_DASH_check_DASH_temp274314683;
};
},{"length":1});
var anf_variant_member275112396 = R.makeMethod(function(self83714682) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2742],0,arguments);
}
var anf_arg274614675 = G(self83714682,"args",L[2747]);
var anf_arg274714676 = G(self83714682,"ann",L[2746]);
var anf_arg274814677 = G(self83714682,"doc",L[2745]);
var anf_arg274914678 = G(self83714682,"body",L[2744]);
var anf_arg275014679 = G(self83714682,"_check",L[2743]);
var $z1466714668 = D;
var $f1467314674 = function(_) {
return R.isFunction(funlam_DASH_tosource2501801.$var)?funlam_DASH_tosource2501801.$var.app(str_DASH_method158676,nothing61,nothing61,anf_arg274614675,anf_arg274714676,anf_arg274814677,anf_arg274914678,anf_arg275014679):R.ffi.throwNonFunApp(L[2742],funlam_DASH_tosource2501801.$var,[str_DASH_method158676,nothing61,nothing61,anf_arg274614675,anf_arg274714676,anf_arg274814677,anf_arg274914678,anf_arg275014679]);
};
try {
if(--R.GAS > 0) {
$z1466714668 = $f1467314674();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1467314674,
"from":L[2742]});
}
} catch($e1466514666) {
if(R.isCont($e1466514666)) {
var $ss1466914670 = {"from":L[2742],
"go":function(ann_DASH_check_DASH_temp274514680) {
return $Hann_DASH_check_DASH_temp936414681(ann_DASH_check_DASH_temp274514680);
}};
$e1466514666.stack[R.EXN_STACKHEIGHT++] = $ss1466914670;
}
if(R.isPyretException($e1466514666)) {
$e1466514666.pyretStack.push(L[2742]);
}
throw $e1466514666;
}
var $ret1467114672 = $Hann_DASH_check_DASH_temp936414681($z1466714668);
++R.GAS;
return $ret1467114672;
};
},{"length":1});
var anf_variant_member276512408 = R.makeMethod(function(self34314643) {
return function(cases_DASH_funs34414644,else_DASH_clause34514655) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2241],2,arguments);
}
var if_DASH_34714658 = R.hasField(cases_DASH_funs34414644,("s-extend"));
var if_helper275314641 = R.makeFunction(function(if_helper_arg275414663) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2241],1,arguments);
}
var ann_DASH_check_DASH_temp275214664 = if_helper_arg275414663;
return ann_DASH_check_DASH_temp275214664;
});
var anf_if275714662 = R.isBoolean(if_DASH_34714658);
if(R.isPyretTrue(anf_if275714662)) {
if(R.isPyretTrue(if_DASH_34714658)) {
var call_DASH_s_DASH_extend34214636 = G(cases_DASH_funs34414644,"s-extend",L[2241]);
var anf_arg276014637 = G(self34314643,"l",L[2741]);
var anf_arg276114638 = G(self34314643,"supe",L[2740]);
var anf_arg276214639 = G(self34314643,"fields",L[2739]);
var $z1462814629 = D;
var $f1463414635 = function(_) {
return R.isFunction(call_DASH_s_DASH_extend34214636)?call_DASH_s_DASH_extend34214636.app(anf_arg276014637,anf_arg276114638,anf_arg276214639):R.ffi.throwNonFunApp(L[2241],call_DASH_s_DASH_extend34214636,[anf_arg276014637,anf_arg276114638,anf_arg276214639]);
};
try {
if(--R.GAS > 0) {
$z1462814629 = $f1463414635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1463414635,
"from":L[2241]});
}
} catch($e1462614627) {
if(R.isCont($e1462614627)) {
var $ss1463014631 = {"from":L[2241],
"go":function(cont_tail_arg276314640) {
return $Hcont_tail_arg936514642(cont_tail_arg276314640,if_helper275314641);
}};
$e1462614627.stack[R.EXN_STACKHEIGHT++] = $ss1463014631;
}
if(R.isPyretException($e1462614627)) {
$e1462614627.pyretStack.push(L[2241]);
}
throw $e1462614627;
}
var $ret1463214633 = $Hcont_tail_arg936514642($z1462814629,if_helper275314641);
++R.GAS;
return $ret1463214633;
} else {
var $z1464714648 = D;
var $f1465314654 = function(_) {
return R.isFunction(else_DASH_clause34514655)?else_DASH_clause34514655.app():R.ffi.throwNonFunApp(L[2241],else_DASH_clause34514655,[]);
};
try {
if(--R.GAS > 0) {
$z1464714648 = $f1465314654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1465314654,
"from":L[2241]});
}
} catch($e1464514646) {
if(R.isCont($e1464514646)) {
var $ss1464914650 = {"from":L[2241],
"go":function(cont_tail_arg275814656) {
return $Hcont_tail_arg936614657(cont_tail_arg275814656,if_helper275314641);
}};
$e1464514646.stack[R.EXN_STACKHEIGHT++] = $ss1464914650;
}
if(R.isPyretException($e1464514646)) {
$e1464514646.pyretStack.push(L[2241]);
}
throw $e1464514646;
}
var $ret1465114652 = $Hcont_tail_arg936614657($z1464714648,if_helper275314641);
++R.GAS;
return $ret1465114652;
}
} else {
var cont_tail_arg275514661 = R.throwNonBooleanCondition(L[2241],("if"),if_DASH_34714658);
if(--R.GAS > 0) {
$z1465914660 = R.isFunction(if_helper275314641)?if_helper275314641.app(cont_tail_arg275514661):R.ffi.throwNonFunApp(L[2241],if_helper275314641,[cont_tail_arg275514661]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper275314641)?if_helper275314641.app(cont_tail_arg275514661):R.ffi.throwNonFunApp(L[2241],if_helper275314641,[cont_tail_arg275514661]);
},
"from":L[2241]});
}
++R.GAS;
return $z1465914660;
}
};
},{"length":3});
var anf_variant_member277912409 = R.makeMethod(function(self34614624) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2241],0,arguments);
}
var anf_arg276714622 = G(self34614624,"l",L[2241]);
var $z1461414615 = D;
var $f1462014621 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg276714622):R.ffi.throwNonFunApp(L[2241],torepr65,[anf_arg276714622]);
};
try {
if(--R.GAS > 0) {
$z1461414615 = $f1462014621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1462014621,
"from":L[2241]});
}
} catch($e1461214613) {
if(R.isCont($e1461214613)) {
var $ss1461614617 = {"from":L[2241],
"go":function(anf_arg276814623) {
return $Hanf_arg937614625(anf_arg276814623,self34614624,_plus55,torepr65);
}};
$e1461214613.stack[R.EXN_STACKHEIGHT++] = $ss1461614617;
}
if(R.isPyretException($e1461214613)) {
$e1461214613.pyretStack.push(L[2241]);
}
throw $e1461214613;
}
var $ret1461814619 = $Hanf_arg937614625($z1461414615,self34614624,_plus55,torepr65);
++R.GAS;
return $ret1461814619;
};
},{"length":1});
var anf_variant_member278112410 = R.makeMethod(function(self84114611) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2738],0,arguments);
}
var ann_DASH_check_DASH_temp278014610 = ("s-extend");
return ann_DASH_check_DASH_temp278014610;
};
},{"length":1});
var anf_variant_member280312411 = R.makeMethod(function(self84214607) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2737],0,arguments);
}
var anf_fun278314606 = G(PP170,"group",L[2736]);
var anf_bracket278414609 = G(self84214607,"supe",L[2735]);
var anf_fun278514604 = G(anf_bracket278414609,"tosource",L[2734]);
var $z1459614597 = D;
var $f1460214603 = function(_) {
return R.isFunction(anf_fun278514604)?anf_fun278514604.app():R.ffi.throwNonFunApp(L[2733],anf_fun278514604,[]);
};
try {
if(--R.GAS > 0) {
$z1459614597 = $f1460214603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1460214603,
"from":L[2733]});
}
} catch($e1459414595) {
if(R.isCont($e1459414595)) {
var $ss1459814599 = {"from":L[2733],
"go":function(anf_arg278614605) {
return $Hanf_arg938414608(anf_arg278614605,INDENT118169,PP170,anf_fun278314606,self84214607,str_DASH_period160702,_plus55);
}};
$e1459414595.stack[R.EXN_STACKHEIGHT++] = $ss1459814599;
}
if(R.isPyretException($e1459414595)) {
$e1459414595.pyretStack.push(L[2733]);
}
throw $e1459414595;
}
var $ret1460014601 = $Hanf_arg938414608($z1459614597,INDENT118169,PP170,anf_fun278314606,self84214607,str_DASH_period160702,_plus55);
++R.GAS;
return $ret1460014601;
};
},{"length":1});
var anf_variant_member281712420 = R.makeMethod(function(self35014572) {
return function(cases_DASH_funs35114573,else_DASH_clause35214584) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2240],2,arguments);
}
var if_DASH_35414587 = R.hasField(cases_DASH_funs35114573,("s-update"));
var if_helper280514570 = R.makeFunction(function(if_helper_arg280614592) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2240],1,arguments);
}
var ann_DASH_check_DASH_temp280414593 = if_helper_arg280614592;
return ann_DASH_check_DASH_temp280414593;
});
var anf_if280914591 = R.isBoolean(if_DASH_35414587);
if(R.isPyretTrue(anf_if280914591)) {
if(R.isPyretTrue(if_DASH_35414587)) {
var call_DASH_s_DASH_update34914565 = G(cases_DASH_funs35114573,"s-update",L[2240]);
var anf_arg281214566 = G(self35014572,"l",L[2732]);
var anf_arg281314567 = G(self35014572,"supe",L[2731]);
var anf_arg281414568 = G(self35014572,"fields",L[2730]);
var $z1455714558 = D;
var $f1456314564 = function(_) {
return R.isFunction(call_DASH_s_DASH_update34914565)?call_DASH_s_DASH_update34914565.app(anf_arg281214566,anf_arg281314567,anf_arg281414568):R.ffi.throwNonFunApp(L[2240],call_DASH_s_DASH_update34914565,[anf_arg281214566,anf_arg281314567,anf_arg281414568]);
};
try {
if(--R.GAS > 0) {
$z1455714558 = $f1456314564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1456314564,
"from":L[2240]});
}
} catch($e1455514556) {
if(R.isCont($e1455514556)) {
var $ss1455914560 = {"from":L[2240],
"go":function(cont_tail_arg281514569) {
return $Hcont_tail_arg938514571(cont_tail_arg281514569,if_helper280514570);
}};
$e1455514556.stack[R.EXN_STACKHEIGHT++] = $ss1455914560;
}
if(R.isPyretException($e1455514556)) {
$e1455514556.pyretStack.push(L[2240]);
}
throw $e1455514556;
}
var $ret1456114562 = $Hcont_tail_arg938514571($z1455714558,if_helper280514570);
++R.GAS;
return $ret1456114562;
} else {
var $z1457614577 = D;
var $f1458214583 = function(_) {
return R.isFunction(else_DASH_clause35214584)?else_DASH_clause35214584.app():R.ffi.throwNonFunApp(L[2240],else_DASH_clause35214584,[]);
};
try {
if(--R.GAS > 0) {
$z1457614577 = $f1458214583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1458214583,
"from":L[2240]});
}
} catch($e1457414575) {
if(R.isCont($e1457414575)) {
var $ss1457814579 = {"from":L[2240],
"go":function(cont_tail_arg281014585) {
return $Hcont_tail_arg938614586(cont_tail_arg281014585,if_helper280514570);
}};
$e1457414575.stack[R.EXN_STACKHEIGHT++] = $ss1457814579;
}
if(R.isPyretException($e1457414575)) {
$e1457414575.pyretStack.push(L[2240]);
}
throw $e1457414575;
}
var $ret1458014581 = $Hcont_tail_arg938614586($z1457614577,if_helper280514570);
++R.GAS;
return $ret1458014581;
}
} else {
var cont_tail_arg280714590 = R.throwNonBooleanCondition(L[2240],("if"),if_DASH_35414587);
if(--R.GAS > 0) {
$z1458814589 = R.isFunction(if_helper280514570)?if_helper280514570.app(cont_tail_arg280714590):R.ffi.throwNonFunApp(L[2240],if_helper280514570,[cont_tail_arg280714590]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper280514570)?if_helper280514570.app(cont_tail_arg280714590):R.ffi.throwNonFunApp(L[2240],if_helper280514570,[cont_tail_arg280714590]);
},
"from":L[2240]});
}
++R.GAS;
return $z1458814589;
}
};
},{"length":3});
var anf_variant_member283112421 = R.makeMethod(function(self35314553) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2240],0,arguments);
}
var anf_arg281914551 = G(self35314553,"l",L[2240]);
var $z1454314544 = D;
var $f1454914550 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg281914551):R.ffi.throwNonFunApp(L[2240],torepr65,[anf_arg281914551]);
};
try {
if(--R.GAS > 0) {
$z1454314544 = $f1454914550();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1454914550,
"from":L[2240]});
}
} catch($e1454114542) {
if(R.isCont($e1454114542)) {
var $ss1454514546 = {"from":L[2240],
"go":function(anf_arg282014552) {
return $Hanf_arg939614554(anf_arg282014552,self35314553,_plus55,torepr65);
}};
$e1454114542.stack[R.EXN_STACKHEIGHT++] = $ss1454514546;
}
if(R.isPyretException($e1454114542)) {
$e1454114542.pyretStack.push(L[2240]);
}
throw $e1454114542;
}
var $ret1454714548 = $Hanf_arg939614554($z1454314544,self35314553,_plus55,torepr65);
++R.GAS;
return $ret1454714548;
};
},{"length":1});
var anf_variant_member283312422 = R.makeMethod(function(self84614540) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2729],0,arguments);
}
var ann_DASH_check_DASH_temp283214539 = ("s-update");
return ann_DASH_check_DASH_temp283214539;
};
},{"length":1});
var anf_variant_member284612431 = R.makeMethod(function(self35614517) {
return function(cases_DASH_funs35714518,else_DASH_clause35814529) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2239],2,arguments);
}
var if_DASH_36014532 = R.hasField(cases_DASH_funs35714518,("s-obj"));
var if_helper283514515 = R.makeFunction(function(if_helper_arg283614537) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2239],1,arguments);
}
var ann_DASH_check_DASH_temp283414538 = if_helper_arg283614537;
return ann_DASH_check_DASH_temp283414538;
});
var anf_if283914536 = R.isBoolean(if_DASH_36014532);
if(R.isPyretTrue(anf_if283914536)) {
if(R.isPyretTrue(if_DASH_36014532)) {
var call_DASH_s_DASH_obj35514511 = G(cases_DASH_funs35714518,"s-obj",L[2239]);
var anf_arg284214512 = G(self35614517,"l",L[2728]);
var anf_arg284314513 = G(self35614517,"fields",L[2727]);
var $z1450314504 = D;
var $f1450914510 = function(_) {
return R.isFunction(call_DASH_s_DASH_obj35514511)?call_DASH_s_DASH_obj35514511.app(anf_arg284214512,anf_arg284314513):R.ffi.throwNonFunApp(L[2239],call_DASH_s_DASH_obj35514511,[anf_arg284214512,anf_arg284314513]);
};
try {
if(--R.GAS > 0) {
$z1450314504 = $f1450914510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1450914510,
"from":L[2239]});
}
} catch($e1450114502) {
if(R.isCont($e1450114502)) {
var $ss1450514506 = {"from":L[2239],
"go":function(cont_tail_arg284414514) {
return $Hcont_tail_arg939714516(cont_tail_arg284414514,if_helper283514515);
}};
$e1450114502.stack[R.EXN_STACKHEIGHT++] = $ss1450514506;
}
if(R.isPyretException($e1450114502)) {
$e1450114502.pyretStack.push(L[2239]);
}
throw $e1450114502;
}
var $ret1450714508 = $Hcont_tail_arg939714516($z1450314504,if_helper283514515);
++R.GAS;
return $ret1450714508;
} else {
var $z1452114522 = D;
var $f1452714528 = function(_) {
return R.isFunction(else_DASH_clause35814529)?else_DASH_clause35814529.app():R.ffi.throwNonFunApp(L[2239],else_DASH_clause35814529,[]);
};
try {
if(--R.GAS > 0) {
$z1452114522 = $f1452714528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1452714528,
"from":L[2239]});
}
} catch($e1451914520) {
if(R.isCont($e1451914520)) {
var $ss1452314524 = {"from":L[2239],
"go":function(cont_tail_arg284014530) {
return $Hcont_tail_arg939814531(cont_tail_arg284014530,if_helper283514515);
}};
$e1451914520.stack[R.EXN_STACKHEIGHT++] = $ss1452314524;
}
if(R.isPyretException($e1451914520)) {
$e1451914520.pyretStack.push(L[2239]);
}
throw $e1451914520;
}
var $ret1452514526 = $Hcont_tail_arg939814531($z1452114522,if_helper283514515);
++R.GAS;
return $ret1452514526;
}
} else {
var cont_tail_arg283714535 = R.throwNonBooleanCondition(L[2239],("if"),if_DASH_36014532);
if(--R.GAS > 0) {
$z1453314534 = R.isFunction(if_helper283514515)?if_helper283514515.app(cont_tail_arg283714535):R.ffi.throwNonFunApp(L[2239],if_helper283514515,[cont_tail_arg283714535]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper283514515)?if_helper283514515.app(cont_tail_arg283714535):R.ffi.throwNonFunApp(L[2239],if_helper283514515,[cont_tail_arg283714535]);
},
"from":L[2239]});
}
++R.GAS;
return $z1453314534;
}
};
},{"length":3});
var anf_variant_member285612432 = R.makeMethod(function(self35914499) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2239],0,arguments);
}
var anf_arg284814497 = G(self35914499,"l",L[2239]);
var $z1448914490 = D;
var $f1449514496 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg284814497):R.ffi.throwNonFunApp(L[2239],torepr65,[anf_arg284814497]);
};
try {
if(--R.GAS > 0) {
$z1448914490 = $f1449514496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1449514496,
"from":L[2239]});
}
} catch($e1448714488) {
if(R.isCont($e1448714488)) {
var $ss1449114492 = {"from":L[2239],
"go":function(anf_arg284914498) {
return $Hanf_arg940514500(anf_arg284914498,self35914499,_plus55,torepr65);
}};
$e1448714488.stack[R.EXN_STACKHEIGHT++] = $ss1449114492;
}
if(R.isPyretException($e1448714488)) {
$e1448714488.pyretStack.push(L[2239]);
}
throw $e1448714488;
}
var $ret1449314494 = $Hanf_arg940514500($z1448914490,self35914499,_plus55,torepr65);
++R.GAS;
return $ret1449314494;
};
},{"length":1});
var anf_variant_member285812433 = R.makeMethod(function(self84914486) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2726],0,arguments);
}
var ann_DASH_check_DASH_temp285714485 = ("s-obj");
return ann_DASH_check_DASH_temp285714485;
};
},{"length":1});
var anf_variant_member287312434 = R.makeMethod(function(self85014483) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2725],0,arguments);
}
var anf_fun286014482 = G(PP170,"surround-separate",L[2724]);
var anf_arg286114479 = G(PP170,"lbrace",L[2723]);
var anf_arg286214480 = G(PP170,"rbrace",L[2722]);
var $z1447114472 = D;
var $f1447714478 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg286114479,anf_arg286214480):R.ffi.throwNonFunApp(L[2721],_plus55,[anf_arg286114479,anf_arg286214480]);
};
try {
if(--R.GAS > 0) {
$z1447114472 = $f1447714478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1447714478,
"from":L[2721]});
}
} catch($e1446914470) {
if(R.isCont($e1446914470)) {
var $ss1447314474 = {"from":L[2721],
"go":function(anf_arg286314481) {
return $Hanf_arg940914484(anf_arg286314481,INDENT118169,PP170,anf_fun286014482,self85014483);
}};
$e1446914470.stack[R.EXN_STACKHEIGHT++] = $ss1447314474;
}
if(R.isPyretException($e1446914470)) {
$e1446914470.pyretStack.push(L[2721]);
}
throw $e1446914470;
}
var $ret1447514476 = $Hanf_arg940914484($z1447114472,INDENT118169,PP170,anf_fun286014482,self85014483);
++R.GAS;
return $ret1447514476;
};
},{"length":1});
var anf_variant_member288612442 = R.makeMethod(function(self36314447) {
return function(cases_DASH_funs36414448,else_DASH_clause36514459) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2238],2,arguments);
}
var if_DASH_36714462 = R.hasField(cases_DASH_funs36414448,("s-array"));
var if_helper287514445 = R.makeFunction(function(if_helper_arg287614467) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2238],1,arguments);
}
var ann_DASH_check_DASH_temp287414468 = if_helper_arg287614467;
return ann_DASH_check_DASH_temp287414468;
});
var anf_if287914466 = R.isBoolean(if_DASH_36714462);
if(R.isPyretTrue(anf_if287914466)) {
if(R.isPyretTrue(if_DASH_36714462)) {
var call_DASH_s_DASH_array36214441 = G(cases_DASH_funs36414448,"s-array",L[2238]);
var anf_arg288214442 = G(self36314447,"l",L[2720]);
var anf_arg288314443 = G(self36314447,"values",L[2719]);
var $z1443314434 = D;
var $f1443914440 = function(_) {
return R.isFunction(call_DASH_s_DASH_array36214441)?call_DASH_s_DASH_array36214441.app(anf_arg288214442,anf_arg288314443):R.ffi.throwNonFunApp(L[2238],call_DASH_s_DASH_array36214441,[anf_arg288214442,anf_arg288314443]);
};
try {
if(--R.GAS > 0) {
$z1443314434 = $f1443914440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1443914440,
"from":L[2238]});
}
} catch($e1443114432) {
if(R.isCont($e1443114432)) {
var $ss1443514436 = {"from":L[2238],
"go":function(cont_tail_arg288414444) {
return $Hcont_tail_arg941014446(cont_tail_arg288414444,if_helper287514445);
}};
$e1443114432.stack[R.EXN_STACKHEIGHT++] = $ss1443514436;
}
if(R.isPyretException($e1443114432)) {
$e1443114432.pyretStack.push(L[2238]);
}
throw $e1443114432;
}
var $ret1443714438 = $Hcont_tail_arg941014446($z1443314434,if_helper287514445);
++R.GAS;
return $ret1443714438;
} else {
var $z1445114452 = D;
var $f1445714458 = function(_) {
return R.isFunction(else_DASH_clause36514459)?else_DASH_clause36514459.app():R.ffi.throwNonFunApp(L[2238],else_DASH_clause36514459,[]);
};
try {
if(--R.GAS > 0) {
$z1445114452 = $f1445714458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1445714458,
"from":L[2238]});
}
} catch($e1444914450) {
if(R.isCont($e1444914450)) {
var $ss1445314454 = {"from":L[2238],
"go":function(cont_tail_arg288014460) {
return $Hcont_tail_arg941114461(cont_tail_arg288014460,if_helper287514445);
}};
$e1444914450.stack[R.EXN_STACKHEIGHT++] = $ss1445314454;
}
if(R.isPyretException($e1444914450)) {
$e1444914450.pyretStack.push(L[2238]);
}
throw $e1444914450;
}
var $ret1445514456 = $Hcont_tail_arg941114461($z1445114452,if_helper287514445);
++R.GAS;
return $ret1445514456;
}
} else {
var cont_tail_arg287714465 = R.throwNonBooleanCondition(L[2238],("if"),if_DASH_36714462);
if(--R.GAS > 0) {
$z1446314464 = R.isFunction(if_helper287514445)?if_helper287514445.app(cont_tail_arg287714465):R.ffi.throwNonFunApp(L[2238],if_helper287514445,[cont_tail_arg287714465]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper287514445)?if_helper287514445.app(cont_tail_arg287714465):R.ffi.throwNonFunApp(L[2238],if_helper287514445,[cont_tail_arg287714465]);
},
"from":L[2238]});
}
++R.GAS;
return $z1446314464;
}
};
},{"length":3});
var anf_variant_member289612443 = R.makeMethod(function(self36614429) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2238],0,arguments);
}
var anf_arg288814427 = G(self36614429,"l",L[2238]);
var $z1441914420 = D;
var $f1442514426 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg288814427):R.ffi.throwNonFunApp(L[2238],torepr65,[anf_arg288814427]);
};
try {
if(--R.GAS > 0) {
$z1441914420 = $f1442514426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1442514426,
"from":L[2238]});
}
} catch($e1441714418) {
if(R.isCont($e1441714418)) {
var $ss1442114422 = {"from":L[2238],
"go":function(anf_arg288914428) {
return $Hanf_arg941814430(anf_arg288914428,self36614429,_plus55,torepr65);
}};
$e1441714418.stack[R.EXN_STACKHEIGHT++] = $ss1442114422;
}
if(R.isPyretException($e1441714418)) {
$e1441714418.pyretStack.push(L[2238]);
}
throw $e1441714418;
}
var $ret1442314424 = $Hanf_arg941814430($z1441914420,self36614429,_plus55,torepr65);
++R.GAS;
return $ret1442314424;
};
},{"length":1});
var anf_variant_member289812444 = R.makeMethod(function(self85314416) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2718],0,arguments);
}
var ann_DASH_check_DASH_temp289714415 = ("s-array");
return ann_DASH_check_DASH_temp289714415;
};
},{"length":1});
var anf_variant_member291312445 = R.makeMethod(function(self85414413) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2717],0,arguments);
}
var anf_fun290014412 = G(PP170,"surround-separate",L[2716]);
var anf_fun290114410 = G(PP170,"str",L[2715]);
var $z1440214403 = D;
var $f1440814409 = function(_) {
return R.isFunction(anf_fun290114410)?anf_fun290114410.app(("[raw-array: ]")):R.ffi.throwNonFunApp(L[2714],anf_fun290114410,[("[raw-array: ]")]);
};
try {
if(--R.GAS > 0) {
$z1440214403 = $f1440814409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1440814409,
"from":L[2714]});
}
} catch($e1440014401) {
if(R.isCont($e1440014401)) {
var $ss1440414405 = {"from":L[2714],
"go":function(anf_arg290214411) {
return $Hanf_arg942314414(anf_arg290214411,INDENT118169,PP170,anf_fun290014412,self85414413);
}};
$e1440014401.stack[R.EXN_STACKHEIGHT++] = $ss1440414405;
}
if(R.isPyretException($e1440014401)) {
$e1440014401.pyretStack.push(L[2714]);
}
throw $e1440014401;
}
var $ret1440614407 = $Hanf_arg942314414($z1440214403,INDENT118169,PP170,anf_fun290014412,self85414413);
++R.GAS;
return $ret1440614407;
};
},{"length":1});
var anf_variant_member292812453 = R.makeMethod(function(self37014378) {
return function(cases_DASH_funs37114379,else_DASH_clause37214390) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2237],2,arguments);
}
var if_DASH_37414393 = R.hasField(cases_DASH_funs37114379,("s-construct"));
var if_helper291514376 = R.makeFunction(function(if_helper_arg291614398) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2237],1,arguments);
}
var ann_DASH_check_DASH_temp291414399 = if_helper_arg291614398;
return ann_DASH_check_DASH_temp291414399;
});
var anf_if291914397 = R.isBoolean(if_DASH_37414393);
if(R.isPyretTrue(anf_if291914397)) {
if(R.isPyretTrue(if_DASH_37414393)) {
var call_DASH_s_DASH_construct36914370 = G(cases_DASH_funs37114379,"s-construct",L[2237]);
var anf_arg292214371 = G(self37014378,"l",L[2713]);
var anf_arg292314372 = G(self37014378,"modifier",L[2712]);
var anf_arg292414373 = G(self37014378,"constructor",L[2711]);
var anf_arg292514374 = G(self37014378,"values",L[2710]);
var $z1436214363 = D;
var $f1436814369 = function(_) {
return R.isFunction(call_DASH_s_DASH_construct36914370)?call_DASH_s_DASH_construct36914370.app(anf_arg292214371,anf_arg292314372,anf_arg292414373,anf_arg292514374):R.ffi.throwNonFunApp(L[2237],call_DASH_s_DASH_construct36914370,[anf_arg292214371,anf_arg292314372,anf_arg292414373,anf_arg292514374]);
};
try {
if(--R.GAS > 0) {
$z1436214363 = $f1436814369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1436814369,
"from":L[2237]});
}
} catch($e1436014361) {
if(R.isCont($e1436014361)) {
var $ss1436414365 = {"from":L[2237],
"go":function(cont_tail_arg292614375) {
return $Hcont_tail_arg942414377(cont_tail_arg292614375,if_helper291514376);
}};
$e1436014361.stack[R.EXN_STACKHEIGHT++] = $ss1436414365;
}
if(R.isPyretException($e1436014361)) {
$e1436014361.pyretStack.push(L[2237]);
}
throw $e1436014361;
}
var $ret1436614367 = $Hcont_tail_arg942414377($z1436214363,if_helper291514376);
++R.GAS;
return $ret1436614367;
} else {
var $z1438214383 = D;
var $f1438814389 = function(_) {
return R.isFunction(else_DASH_clause37214390)?else_DASH_clause37214390.app():R.ffi.throwNonFunApp(L[2237],else_DASH_clause37214390,[]);
};
try {
if(--R.GAS > 0) {
$z1438214383 = $f1438814389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1438814389,
"from":L[2237]});
}
} catch($e1438014381) {
if(R.isCont($e1438014381)) {
var $ss1438414385 = {"from":L[2237],
"go":function(cont_tail_arg292014391) {
return $Hcont_tail_arg942514392(cont_tail_arg292014391,if_helper291514376);
}};
$e1438014381.stack[R.EXN_STACKHEIGHT++] = $ss1438414385;
}
if(R.isPyretException($e1438014381)) {
$e1438014381.pyretStack.push(L[2237]);
}
throw $e1438014381;
}
var $ret1438614387 = $Hcont_tail_arg942514392($z1438214383,if_helper291514376);
++R.GAS;
return $ret1438614387;
}
} else {
var cont_tail_arg291714396 = R.throwNonBooleanCondition(L[2237],("if"),if_DASH_37414393);
if(--R.GAS > 0) {
$z1439414395 = R.isFunction(if_helper291514376)?if_helper291514376.app(cont_tail_arg291714396):R.ffi.throwNonFunApp(L[2237],if_helper291514376,[cont_tail_arg291714396]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper291514376)?if_helper291514376.app(cont_tail_arg291714396):R.ffi.throwNonFunApp(L[2237],if_helper291514376,[cont_tail_arg291714396]);
},
"from":L[2237]});
}
++R.GAS;
return $z1439414395;
}
};
},{"length":3});
var anf_variant_member294612454 = R.makeMethod(function(self37314358) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2237],0,arguments);
}
var anf_arg293014356 = G(self37314358,"l",L[2237]);
var $z1434814349 = D;
var $f1435414355 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg293014356):R.ffi.throwNonFunApp(L[2237],torepr65,[anf_arg293014356]);
};
try {
if(--R.GAS > 0) {
$z1434814349 = $f1435414355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1435414355,
"from":L[2237]});
}
} catch($e1434614347) {
if(R.isCont($e1434614347)) {
var $ss1435014351 = {"from":L[2237],
"go":function(anf_arg293114357) {
return $Hanf_arg943814359(anf_arg293114357,self37314358,_plus55,torepr65);
}};
$e1434614347.stack[R.EXN_STACKHEIGHT++] = $ss1435014351;
}
if(R.isPyretException($e1434614347)) {
$e1434614347.pyretStack.push(L[2237]);
}
throw $e1434614347;
}
var $ret1435214353 = $Hanf_arg943814359($z1434814349,self37314358,_plus55,torepr65);
++R.GAS;
return $ret1435214353;
};
},{"length":1});
var anf_variant_member294812455 = R.makeMethod(function(self85914345) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2709],0,arguments);
}
var ann_DASH_check_DASH_temp294714344 = ("s-construct");
return ann_DASH_check_DASH_temp294714344;
};
},{"length":1});
var anf_variant_member298812456 = R.makeMethod(function(self86014342) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2708],0,arguments);
}
var anf_arg295014339 = G(PP170,"lbrack",L[2707]);
var anf_fun295114340 = G(PP170,"group",L[2706]);
var anf_fun295214341 = G(PP170,"separate",L[2705]);
var anf_fun295314337 = G(PP170,"sbreak",L[2704]);
var $z1432914330 = D;
var $f1433514336 = function(_) {
return R.isFunction(anf_fun295314337)?anf_fun295314337.app((1)):R.ffi.throwNonFunApp(L[2703],anf_fun295314337,[(1)]);
};
try {
if(--R.GAS > 0) {
$z1432914330 = $f1433514336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1433514336,
"from":L[2703]});
}
} catch($e1432714328) {
if(R.isCont($e1432714328)) {
var $ss1433114332 = {"from":L[2703],
"go":function(anf_arg295414338) {
return $Hanf_arg945214343(anf_arg295414338,INDENT118169,PP170,anf_arg295014339,anf_fun295114340,anf_fun295214341,is_DASH_empty26152,list25154,self86014342,str_DASH_colonspace136390,_plus55);
}};
$e1432714328.stack[R.EXN_STACKHEIGHT++] = $ss1433114332;
}
if(R.isPyretException($e1432714328)) {
$e1432714328.pyretStack.push(L[2703]);
}
throw $e1432714328;
}
var $ret1433314334 = $Hanf_arg945214343($z1432914330,INDENT118169,PP170,anf_arg295014339,anf_fun295114340,anf_fun295214341,is_DASH_empty26152,list25154,self86014342,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret1433314334;
};
},{"length":1});
var anf_variant_member300212466 = R.makeMethod(function(self37814305) {
return function(cases_DASH_funs37914306,else_DASH_clause38014317) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2236],2,arguments);
}
var if_DASH_38214320 = R.hasField(cases_DASH_funs37914306,("s-confirm"));
var if_helper299014303 = R.makeFunction(function(if_helper_arg299114325) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2236],1,arguments);
}
var ann_DASH_check_DASH_temp298914326 = if_helper_arg299114325;
return ann_DASH_check_DASH_temp298914326;
});
var anf_if299414324 = R.isBoolean(if_DASH_38214320);
if(R.isPyretTrue(anf_if299414324)) {
if(R.isPyretTrue(if_DASH_38214320)) {
var call_DASH_s_DASH_confirm37714298 = G(cases_DASH_funs37914306,"s-confirm",L[2236]);
var anf_arg299714299 = G(self37814305,"l",L[2702]);
var anf_arg299814300 = G(self37814305,"expr",L[2701]);
var anf_arg299914301 = G(self37814305,"typ",L[2700]);
var $z1429014291 = D;
var $f1429614297 = function(_) {
return R.isFunction(call_DASH_s_DASH_confirm37714298)?call_DASH_s_DASH_confirm37714298.app(anf_arg299714299,anf_arg299814300,anf_arg299914301):R.ffi.throwNonFunApp(L[2236],call_DASH_s_DASH_confirm37714298,[anf_arg299714299,anf_arg299814300,anf_arg299914301]);
};
try {
if(--R.GAS > 0) {
$z1429014291 = $f1429614297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1429614297,
"from":L[2236]});
}
} catch($e1428814289) {
if(R.isCont($e1428814289)) {
var $ss1429214293 = {"from":L[2236],
"go":function(cont_tail_arg300014302) {
return $Hcont_tail_arg945314304(cont_tail_arg300014302,if_helper299014303);
}};
$e1428814289.stack[R.EXN_STACKHEIGHT++] = $ss1429214293;
}
if(R.isPyretException($e1428814289)) {
$e1428814289.pyretStack.push(L[2236]);
}
throw $e1428814289;
}
var $ret1429414295 = $Hcont_tail_arg945314304($z1429014291,if_helper299014303);
++R.GAS;
return $ret1429414295;
} else {
var $z1430914310 = D;
var $f1431514316 = function(_) {
return R.isFunction(else_DASH_clause38014317)?else_DASH_clause38014317.app():R.ffi.throwNonFunApp(L[2236],else_DASH_clause38014317,[]);
};
try {
if(--R.GAS > 0) {
$z1430914310 = $f1431514316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1431514316,
"from":L[2236]});
}
} catch($e1430714308) {
if(R.isCont($e1430714308)) {
var $ss1431114312 = {"from":L[2236],
"go":function(cont_tail_arg299514318) {
return $Hcont_tail_arg945414319(cont_tail_arg299514318,if_helper299014303);
}};
$e1430714308.stack[R.EXN_STACKHEIGHT++] = $ss1431114312;
}
if(R.isPyretException($e1430714308)) {
$e1430714308.pyretStack.push(L[2236]);
}
throw $e1430714308;
}
var $ret1431314314 = $Hcont_tail_arg945414319($z1430914310,if_helper299014303);
++R.GAS;
return $ret1431314314;
}
} else {
var cont_tail_arg299214323 = R.throwNonBooleanCondition(L[2236],("if"),if_DASH_38214320);
if(--R.GAS > 0) {
$z1432114322 = R.isFunction(if_helper299014303)?if_helper299014303.app(cont_tail_arg299214323):R.ffi.throwNonFunApp(L[2236],if_helper299014303,[cont_tail_arg299214323]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper299014303)?if_helper299014303.app(cont_tail_arg299214323):R.ffi.throwNonFunApp(L[2236],if_helper299014303,[cont_tail_arg299214323]);
},
"from":L[2236]});
}
++R.GAS;
return $z1432114322;
}
};
},{"length":3});
var anf_variant_member301612467 = R.makeMethod(function(self38114286) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2236],0,arguments);
}
var anf_arg300414284 = G(self38114286,"l",L[2236]);
var $z1427614277 = D;
var $f1428214283 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg300414284):R.ffi.throwNonFunApp(L[2236],torepr65,[anf_arg300414284]);
};
try {
if(--R.GAS > 0) {
$z1427614277 = $f1428214283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1428214283,
"from":L[2236]});
}
} catch($e1427414275) {
if(R.isCont($e1427414275)) {
var $ss1427814279 = {"from":L[2236],
"go":function(anf_arg300514285) {
return $Hanf_arg946414287(anf_arg300514285,self38114286,_plus55,torepr65);
}};
$e1427414275.stack[R.EXN_STACKHEIGHT++] = $ss1427814279;
}
if(R.isPyretException($e1427414275)) {
$e1427414275.pyretStack.push(L[2236]);
}
throw $e1427414275;
}
var $ret1428014281 = $Hanf_arg946414287($z1427614277,self38114286,_plus55,torepr65);
++R.GAS;
return $ret1428014281;
};
},{"length":1});
var anf_variant_member301812468 = R.makeMethod(function(self86514273) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2699],0,arguments);
}
var ann_DASH_check_DASH_temp301714272 = ("s-confirm");
return ann_DASH_check_DASH_temp301714272;
};
},{"length":1});
var anf_variant_member302912469 = R.makeMethod(function(self86614269) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2698],0,arguments);
}
var anf_fun302014267 = G(PP170,"flow",L[2697]);
var anf_fun302114268 = G(list25154,"make",L[2696]);
var anf_bracket302214271 = G(self86614269,"expr",L[2695]);
var anf_fun302314265 = G(anf_bracket302214271,"tosource",L[2694]);
var $z1425714258 = D;
var $f1426314264 = function(_) {
return R.isFunction(anf_fun302314265)?anf_fun302314265.app():R.ffi.throwNonFunApp(L[2693],anf_fun302314265,[]);
};
try {
if(--R.GAS > 0) {
$z1425714258 = $f1426314264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1426314264,
"from":L[2693]});
}
} catch($e1425514256) {
if(R.isCont($e1425514256)) {
var $ss1425914260 = {"from":L[2693],
"go":function(anf_array_val302414266) {
return $Hanf_array_val946814270(anf_array_val302414266,anf_fun302014267,anf_fun302114268,self86614269,str_DASH_as123221,str_DASH_confirm179949);
}};
$e1425514256.stack[R.EXN_STACKHEIGHT++] = $ss1425914260;
}
if(R.isPyretException($e1425514256)) {
$e1425514256.pyretStack.push(L[2693]);
}
throw $e1425514256;
}
var $ret1426114262 = $Hanf_array_val946814270($z1425714258,anf_fun302014267,anf_fun302114268,self86614269,str_DASH_as123221,str_DASH_confirm179949);
++R.GAS;
return $ret1426114262;
};
},{"length":1});
var anf_variant_member304312478 = R.makeMethod(function(self38414233) {
return function(cases_DASH_funs38514234,else_DASH_clause38614245) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2235],2,arguments);
}
var if_DASH_38814248 = R.hasField(cases_DASH_funs38514234,("s-bless"));
var if_helper303114231 = R.makeFunction(function(if_helper_arg303214253) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2235],1,arguments);
}
var ann_DASH_check_DASH_temp303014254 = if_helper_arg303214253;
return ann_DASH_check_DASH_temp303014254;
});
var anf_if303514252 = R.isBoolean(if_DASH_38814248);
if(R.isPyretTrue(anf_if303514252)) {
if(R.isPyretTrue(if_DASH_38814248)) {
var call_DASH_s_DASH_bless38314226 = G(cases_DASH_funs38514234,"s-bless",L[2235]);
var anf_arg303814227 = G(self38414233,"l",L[2692]);
var anf_arg303914228 = G(self38414233,"expr",L[2691]);
var anf_arg304014229 = G(self38414233,"typ",L[2690]);
var $z1421814219 = D;
var $f1422414225 = function(_) {
return R.isFunction(call_DASH_s_DASH_bless38314226)?call_DASH_s_DASH_bless38314226.app(anf_arg303814227,anf_arg303914228,anf_arg304014229):R.ffi.throwNonFunApp(L[2235],call_DASH_s_DASH_bless38314226,[anf_arg303814227,anf_arg303914228,anf_arg304014229]);
};
try {
if(--R.GAS > 0) {
$z1421814219 = $f1422414225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1422414225,
"from":L[2235]});
}
} catch($e1421614217) {
if(R.isCont($e1421614217)) {
var $ss1422014221 = {"from":L[2235],
"go":function(cont_tail_arg304114230) {
return $Hcont_tail_arg946914232(cont_tail_arg304114230,if_helper303114231);
}};
$e1421614217.stack[R.EXN_STACKHEIGHT++] = $ss1422014221;
}
if(R.isPyretException($e1421614217)) {
$e1421614217.pyretStack.push(L[2235]);
}
throw $e1421614217;
}
var $ret1422214223 = $Hcont_tail_arg946914232($z1421814219,if_helper303114231);
++R.GAS;
return $ret1422214223;
} else {
var $z1423714238 = D;
var $f1424314244 = function(_) {
return R.isFunction(else_DASH_clause38614245)?else_DASH_clause38614245.app():R.ffi.throwNonFunApp(L[2235],else_DASH_clause38614245,[]);
};
try {
if(--R.GAS > 0) {
$z1423714238 = $f1424314244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1424314244,
"from":L[2235]});
}
} catch($e1423514236) {
if(R.isCont($e1423514236)) {
var $ss1423914240 = {"from":L[2235],
"go":function(cont_tail_arg303614246) {
return $Hcont_tail_arg947014247(cont_tail_arg303614246,if_helper303114231);
}};
$e1423514236.stack[R.EXN_STACKHEIGHT++] = $ss1423914240;
}
if(R.isPyretException($e1423514236)) {
$e1423514236.pyretStack.push(L[2235]);
}
throw $e1423514236;
}
var $ret1424114242 = $Hcont_tail_arg947014247($z1423714238,if_helper303114231);
++R.GAS;
return $ret1424114242;
}
} else {
var cont_tail_arg303314251 = R.throwNonBooleanCondition(L[2235],("if"),if_DASH_38814248);
if(--R.GAS > 0) {
$z1424914250 = R.isFunction(if_helper303114231)?if_helper303114231.app(cont_tail_arg303314251):R.ffi.throwNonFunApp(L[2235],if_helper303114231,[cont_tail_arg303314251]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper303114231)?if_helper303114231.app(cont_tail_arg303314251):R.ffi.throwNonFunApp(L[2235],if_helper303114231,[cont_tail_arg303314251]);
},
"from":L[2235]});
}
++R.GAS;
return $z1424914250;
}
};
},{"length":3});
var anf_variant_member305712479 = R.makeMethod(function(self38714214) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2235],0,arguments);
}
var anf_arg304514212 = G(self38714214,"l",L[2235]);
var $z1420414205 = D;
var $f1421014211 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg304514212):R.ffi.throwNonFunApp(L[2235],torepr65,[anf_arg304514212]);
};
try {
if(--R.GAS > 0) {
$z1420414205 = $f1421014211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1421014211,
"from":L[2235]});
}
} catch($e1420214203) {
if(R.isCont($e1420214203)) {
var $ss1420614207 = {"from":L[2235],
"go":function(anf_arg304614213) {
return $Hanf_arg948014215(anf_arg304614213,self38714214,_plus55,torepr65);
}};
$e1420214203.stack[R.EXN_STACKHEIGHT++] = $ss1420614207;
}
if(R.isPyretException($e1420214203)) {
$e1420214203.pyretStack.push(L[2235]);
}
throw $e1420214203;
}
var $ret1420814209 = $Hanf_arg948014215($z1420414205,self38714214,_plus55,torepr65);
++R.GAS;
return $ret1420814209;
};
},{"length":1});
var anf_variant_member305912480 = R.makeMethod(function(self87014201) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2689],0,arguments);
}
var ann_DASH_check_DASH_temp305814200 = ("s-bless");
return ann_DASH_check_DASH_temp305814200;
};
},{"length":1});
var anf_variant_member307012481 = R.makeMethod(function(self87114197) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2688],0,arguments);
}
var anf_fun306114195 = G(PP170,"flow",L[2687]);
var anf_fun306214196 = G(list25154,"make",L[2686]);
var anf_bracket306314199 = G(self87114197,"expr",L[2685]);
var anf_fun306414193 = G(anf_bracket306314199,"tosource",L[2684]);
var $z1418514186 = D;
var $f1419114192 = function(_) {
return R.isFunction(anf_fun306414193)?anf_fun306414193.app():R.ffi.throwNonFunApp(L[2683],anf_fun306414193,[]);
};
try {
if(--R.GAS > 0) {
$z1418514186 = $f1419114192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1419114192,
"from":L[2683]});
}
} catch($e1418314184) {
if(R.isCont($e1418314184)) {
var $ss1418714188 = {"from":L[2683],
"go":function(anf_array_val306514194) {
return $Hanf_array_val948414198(anf_array_val306514194,anf_fun306114195,anf_fun306214196,self87114197,str_DASH_as123221,str_DASH_bless178936);
}};
$e1418314184.stack[R.EXN_STACKHEIGHT++] = $ss1418714188;
}
if(R.isPyretException($e1418314184)) {
$e1418314184.pyretStack.push(L[2683]);
}
throw $e1418314184;
}
var $ret1418914190 = $Hanf_array_val948414198($z1418514186,anf_fun306114195,anf_fun306214196,self87114197,str_DASH_as123221,str_DASH_bless178936);
++R.GAS;
return $ret1418914190;
};
},{"length":1});
var anf_variant_member308412490 = R.makeMethod(function(self39014161) {
return function(cases_DASH_funs39114162,else_DASH_clause39214173) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2234],2,arguments);
}
var if_DASH_39414176 = R.hasField(cases_DASH_funs39114162,("s-app"));
var if_helper307214159 = R.makeFunction(function(if_helper_arg307314181) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2234],1,arguments);
}
var ann_DASH_check_DASH_temp307114182 = if_helper_arg307314181;
return ann_DASH_check_DASH_temp307114182;
});
var anf_if307614180 = R.isBoolean(if_DASH_39414176);
if(R.isPyretTrue(anf_if307614180)) {
if(R.isPyretTrue(if_DASH_39414176)) {
var call_DASH_s_DASH_app38914154 = G(cases_DASH_funs39114162,"s-app",L[2234]);
var anf_arg307914155 = G(self39014161,"l",L[2682]);
var anf_arg308014156 = G(self39014161,"_fun",L[2681]);
var anf_arg308114157 = G(self39014161,"args",L[2680]);
var $z1414614147 = D;
var $f1415214153 = function(_) {
return R.isFunction(call_DASH_s_DASH_app38914154)?call_DASH_s_DASH_app38914154.app(anf_arg307914155,anf_arg308014156,anf_arg308114157):R.ffi.throwNonFunApp(L[2234],call_DASH_s_DASH_app38914154,[anf_arg307914155,anf_arg308014156,anf_arg308114157]);
};
try {
if(--R.GAS > 0) {
$z1414614147 = $f1415214153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1415214153,
"from":L[2234]});
}
} catch($e1414414145) {
if(R.isCont($e1414414145)) {
var $ss1414814149 = {"from":L[2234],
"go":function(cont_tail_arg308214158) {
return $Hcont_tail_arg948514160(cont_tail_arg308214158,if_helper307214159);
}};
$e1414414145.stack[R.EXN_STACKHEIGHT++] = $ss1414814149;
}
if(R.isPyretException($e1414414145)) {
$e1414414145.pyretStack.push(L[2234]);
}
throw $e1414414145;
}
var $ret1415014151 = $Hcont_tail_arg948514160($z1414614147,if_helper307214159);
++R.GAS;
return $ret1415014151;
} else {
var $z1416514166 = D;
var $f1417114172 = function(_) {
return R.isFunction(else_DASH_clause39214173)?else_DASH_clause39214173.app():R.ffi.throwNonFunApp(L[2234],else_DASH_clause39214173,[]);
};
try {
if(--R.GAS > 0) {
$z1416514166 = $f1417114172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1417114172,
"from":L[2234]});
}
} catch($e1416314164) {
if(R.isCont($e1416314164)) {
var $ss1416714168 = {"from":L[2234],
"go":function(cont_tail_arg307714174) {
return $Hcont_tail_arg948614175(cont_tail_arg307714174,if_helper307214159);
}};
$e1416314164.stack[R.EXN_STACKHEIGHT++] = $ss1416714168;
}
if(R.isPyretException($e1416314164)) {
$e1416314164.pyretStack.push(L[2234]);
}
throw $e1416314164;
}
var $ret1416914170 = $Hcont_tail_arg948614175($z1416514166,if_helper307214159);
++R.GAS;
return $ret1416914170;
}
} else {
var cont_tail_arg307414179 = R.throwNonBooleanCondition(L[2234],("if"),if_DASH_39414176);
if(--R.GAS > 0) {
$z1417714178 = R.isFunction(if_helper307214159)?if_helper307214159.app(cont_tail_arg307414179):R.ffi.throwNonFunApp(L[2234],if_helper307214159,[cont_tail_arg307414179]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper307214159)?if_helper307214159.app(cont_tail_arg307414179):R.ffi.throwNonFunApp(L[2234],if_helper307214159,[cont_tail_arg307414179]);
},
"from":L[2234]});
}
++R.GAS;
return $z1417714178;
}
};
},{"length":3});
var anf_variant_member309812491 = R.makeMethod(function(self39314142) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2234],0,arguments);
}
var anf_arg308614140 = G(self39314142,"l",L[2234]);
var $z1413214133 = D;
var $f1413814139 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg308614140):R.ffi.throwNonFunApp(L[2234],torepr65,[anf_arg308614140]);
};
try {
if(--R.GAS > 0) {
$z1413214133 = $f1413814139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1413814139,
"from":L[2234]});
}
} catch($e1413014131) {
if(R.isCont($e1413014131)) {
var $ss1413414135 = {"from":L[2234],
"go":function(anf_arg308714141) {
return $Hanf_arg949614143(anf_arg308714141,self39314142,_plus55,torepr65);
}};
$e1413014131.stack[R.EXN_STACKHEIGHT++] = $ss1413414135;
}
if(R.isPyretException($e1413014131)) {
$e1413014131.pyretStack.push(L[2234]);
}
throw $e1413014131;
}
var $ret1413614137 = $Hanf_arg949614143($z1413214133,self39314142,_plus55,torepr65);
++R.GAS;
return $ret1413614137;
};
},{"length":1});
var anf_variant_member310012492 = R.makeMethod(function(self87514129) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2679],0,arguments);
}
var ann_DASH_check_DASH_temp309914128 = ("s-app");
return ann_DASH_check_DASH_temp309914128;
};
},{"length":1});
var anf_variant_member312012493 = R.makeMethod(function(self87614125) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2678],0,arguments);
}
var anf_fun310214124 = G(PP170,"group",L[2677]);
var anf_bracket310314127 = G(self87614125,"_fun",L[2676]);
var anf_fun310414122 = G(anf_bracket310314127,"tosource",L[2675]);
var $z1411414115 = D;
var $f1412014121 = function(_) {
return R.isFunction(anf_fun310414122)?anf_fun310414122.app():R.ffi.throwNonFunApp(L[2674],anf_fun310414122,[]);
};
try {
if(--R.GAS > 0) {
$z1411414115 = $f1412014121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1412014121,
"from":L[2674]});
}
} catch($e1411214113) {
if(R.isCont($e1411214113)) {
var $ss1411614117 = {"from":L[2674],
"go":function(anf_arg310514123) {
return $Hanf_arg950414126(anf_arg310514123,INDENT118169,PP170,anf_fun310214124,self87614125,_plus55);
}};
$e1411214113.stack[R.EXN_STACKHEIGHT++] = $ss1411614117;
}
if(R.isPyretException($e1411214113)) {
$e1411214113.pyretStack.push(L[2674]);
}
throw $e1411214113;
}
var $ret1411814119 = $Hanf_arg950414126($z1411414115,INDENT118169,PP170,anf_fun310214124,self87614125,_plus55);
++R.GAS;
return $ret1411814119;
};
},{"length":1});
var anf_variant_member313412502 = R.makeMethod(function(self39714090) {
return function(cases_DASH_funs39814091,else_DASH_clause39914102) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2233],2,arguments);
}
var if_DASH_40114105 = R.hasField(cases_DASH_funs39814091,("s-prim-app"));
var if_helper312214088 = R.makeFunction(function(if_helper_arg312314110) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2233],1,arguments);
}
var ann_DASH_check_DASH_temp312114111 = if_helper_arg312314110;
return ann_DASH_check_DASH_temp312114111;
});
var anf_if312614109 = R.isBoolean(if_DASH_40114105);
if(R.isPyretTrue(anf_if312614109)) {
if(R.isPyretTrue(if_DASH_40114105)) {
var call_DASH_s_DASH_prim_DASH_app39614083 = G(cases_DASH_funs39814091,"s-prim-app",L[2233]);
var anf_arg312914084 = G(self39714090,"l",L[2673]);
var anf_arg313014085 = G(self39714090,"_fun",L[2672]);
var anf_arg313114086 = G(self39714090,"args",L[2671]);
var $z1407514076 = D;
var $f1408114082 = function(_) {
return R.isFunction(call_DASH_s_DASH_prim_DASH_app39614083)?call_DASH_s_DASH_prim_DASH_app39614083.app(anf_arg312914084,anf_arg313014085,anf_arg313114086):R.ffi.throwNonFunApp(L[2233],call_DASH_s_DASH_prim_DASH_app39614083,[anf_arg312914084,anf_arg313014085,anf_arg313114086]);
};
try {
if(--R.GAS > 0) {
$z1407514076 = $f1408114082();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1408114082,
"from":L[2233]});
}
} catch($e1407314074) {
if(R.isCont($e1407314074)) {
var $ss1407714078 = {"from":L[2233],
"go":function(cont_tail_arg313214087) {
return $Hcont_tail_arg950514089(cont_tail_arg313214087,if_helper312214088);
}};
$e1407314074.stack[R.EXN_STACKHEIGHT++] = $ss1407714078;
}
if(R.isPyretException($e1407314074)) {
$e1407314074.pyretStack.push(L[2233]);
}
throw $e1407314074;
}
var $ret1407914080 = $Hcont_tail_arg950514089($z1407514076,if_helper312214088);
++R.GAS;
return $ret1407914080;
} else {
var $z1409414095 = D;
var $f1410014101 = function(_) {
return R.isFunction(else_DASH_clause39914102)?else_DASH_clause39914102.app():R.ffi.throwNonFunApp(L[2233],else_DASH_clause39914102,[]);
};
try {
if(--R.GAS > 0) {
$z1409414095 = $f1410014101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1410014101,
"from":L[2233]});
}
} catch($e1409214093) {
if(R.isCont($e1409214093)) {
var $ss1409614097 = {"from":L[2233],
"go":function(cont_tail_arg312714103) {
return $Hcont_tail_arg950614104(cont_tail_arg312714103,if_helper312214088);
}};
$e1409214093.stack[R.EXN_STACKHEIGHT++] = $ss1409614097;
}
if(R.isPyretException($e1409214093)) {
$e1409214093.pyretStack.push(L[2233]);
}
throw $e1409214093;
}
var $ret1409814099 = $Hcont_tail_arg950614104($z1409414095,if_helper312214088);
++R.GAS;
return $ret1409814099;
}
} else {
var cont_tail_arg312414108 = R.throwNonBooleanCondition(L[2233],("if"),if_DASH_40114105);
if(--R.GAS > 0) {
$z1410614107 = R.isFunction(if_helper312214088)?if_helper312214088.app(cont_tail_arg312414108):R.ffi.throwNonFunApp(L[2233],if_helper312214088,[cont_tail_arg312414108]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper312214088)?if_helper312214088.app(cont_tail_arg312414108):R.ffi.throwNonFunApp(L[2233],if_helper312214088,[cont_tail_arg312414108]);
},
"from":L[2233]});
}
++R.GAS;
return $z1410614107;
}
};
},{"length":3});
var anf_variant_member314812503 = R.makeMethod(function(self40014071) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2233],0,arguments);
}
var anf_arg313614069 = G(self40014071,"l",L[2233]);
var $z1406114062 = D;
var $f1406714068 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg313614069):R.ffi.throwNonFunApp(L[2233],torepr65,[anf_arg313614069]);
};
try {
if(--R.GAS > 0) {
$z1406114062 = $f1406714068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1406714068,
"from":L[2233]});
}
} catch($e1405914060) {
if(R.isCont($e1405914060)) {
var $ss1406314064 = {"from":L[2233],
"go":function(anf_arg313714070) {
return $Hanf_arg951614072(anf_arg313714070,self40014071,_plus55,torepr65);
}};
$e1405914060.stack[R.EXN_STACKHEIGHT++] = $ss1406314064;
}
if(R.isPyretException($e1405914060)) {
$e1405914060.pyretStack.push(L[2233]);
}
throw $e1405914060;
}
var $ret1406514066 = $Hanf_arg951614072($z1406114062,self40014071,_plus55,torepr65);
++R.GAS;
return $ret1406514066;
};
},{"length":1});
var anf_variant_member315012504 = R.makeMethod(function(self88014058) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2670],0,arguments);
}
var ann_DASH_check_DASH_temp314914057 = ("s-prim-app");
return ann_DASH_check_DASH_temp314914057;
};
},{"length":1});
var anf_variant_member317012505 = R.makeMethod(function(self88114055) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2669],0,arguments);
}
var anf_fun315214054 = G(PP170,"group",L[2668]);
var anf_fun315314051 = G(PP170,"str",L[2667]);
var anf_arg315414052 = G(self88114055,"_fun",L[2666]);
var $z1404314044 = D;
var $f1404914050 = function(_) {
return R.isFunction(anf_fun315314051)?anf_fun315314051.app(anf_arg315414052):R.ffi.throwNonFunApp(L[2665],anf_fun315314051,[anf_arg315414052]);
};
try {
if(--R.GAS > 0) {
$z1404314044 = $f1404914050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1404914050,
"from":L[2665]});
}
} catch($e1404114042) {
if(R.isCont($e1404114042)) {
var $ss1404514046 = {"from":L[2665],
"go":function(anf_arg315514053) {
return $Hanf_arg952414056(anf_arg315514053,INDENT118169,PP170,anf_fun315214054,self88114055,_plus55);
}};
$e1404114042.stack[R.EXN_STACKHEIGHT++] = $ss1404514046;
}
if(R.isPyretException($e1404114042)) {
$e1404114042.pyretStack.push(L[2665]);
}
throw $e1404114042;
}
var $ret1404714048 = $Hanf_arg952414056($z1404314044,INDENT118169,PP170,anf_fun315214054,self88114055,_plus55);
++R.GAS;
return $ret1404714048;
};
},{"length":1});
var anf_variant_member318312514 = R.makeMethod(function(self40414019) {
return function(cases_DASH_funs40514020,else_DASH_clause40614031) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2232],2,arguments);
}
var if_DASH_40814034 = R.hasField(cases_DASH_funs40514020,("s-prim-val"));
var if_helper317214017 = R.makeFunction(function(if_helper_arg317314039) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2232],1,arguments);
}
var ann_DASH_check_DASH_temp317114040 = if_helper_arg317314039;
return ann_DASH_check_DASH_temp317114040;
});
var anf_if317614038 = R.isBoolean(if_DASH_40814034);
if(R.isPyretTrue(anf_if317614038)) {
if(R.isPyretTrue(if_DASH_40814034)) {
var call_DASH_s_DASH_prim_DASH_val40314013 = G(cases_DASH_funs40514020,"s-prim-val",L[2232]);
var anf_arg317914014 = G(self40414019,"l",L[2664]);
var anf_arg318014015 = G(self40414019,"name",L[2663]);
var $z1400514006 = D;
var $f1401114012 = function(_) {
return R.isFunction(call_DASH_s_DASH_prim_DASH_val40314013)?call_DASH_s_DASH_prim_DASH_val40314013.app(anf_arg317914014,anf_arg318014015):R.ffi.throwNonFunApp(L[2232],call_DASH_s_DASH_prim_DASH_val40314013,[anf_arg317914014,anf_arg318014015]);
};
try {
if(--R.GAS > 0) {
$z1400514006 = $f1401114012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1401114012,
"from":L[2232]});
}
} catch($e1400314004) {
if(R.isCont($e1400314004)) {
var $ss1400714008 = {"from":L[2232],
"go":function(cont_tail_arg318114016) {
return $Hcont_tail_arg952514018(cont_tail_arg318114016,if_helper317214017);
}};
$e1400314004.stack[R.EXN_STACKHEIGHT++] = $ss1400714008;
}
if(R.isPyretException($e1400314004)) {
$e1400314004.pyretStack.push(L[2232]);
}
throw $e1400314004;
}
var $ret1400914010 = $Hcont_tail_arg952514018($z1400514006,if_helper317214017);
++R.GAS;
return $ret1400914010;
} else {
var $z1402314024 = D;
var $f1402914030 = function(_) {
return R.isFunction(else_DASH_clause40614031)?else_DASH_clause40614031.app():R.ffi.throwNonFunApp(L[2232],else_DASH_clause40614031,[]);
};
try {
if(--R.GAS > 0) {
$z1402314024 = $f1402914030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1402914030,
"from":L[2232]});
}
} catch($e1402114022) {
if(R.isCont($e1402114022)) {
var $ss1402514026 = {"from":L[2232],
"go":function(cont_tail_arg317714032) {
return $Hcont_tail_arg952614033(cont_tail_arg317714032,if_helper317214017);
}};
$e1402114022.stack[R.EXN_STACKHEIGHT++] = $ss1402514026;
}
if(R.isPyretException($e1402114022)) {
$e1402114022.pyretStack.push(L[2232]);
}
throw $e1402114022;
}
var $ret1402714028 = $Hcont_tail_arg952614033($z1402314024,if_helper317214017);
++R.GAS;
return $ret1402714028;
}
} else {
var cont_tail_arg317414037 = R.throwNonBooleanCondition(L[2232],("if"),if_DASH_40814034);
if(--R.GAS > 0) {
$z1403514036 = R.isFunction(if_helper317214017)?if_helper317214017.app(cont_tail_arg317414037):R.ffi.throwNonFunApp(L[2232],if_helper317214017,[cont_tail_arg317414037]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper317214017)?if_helper317214017.app(cont_tail_arg317414037):R.ffi.throwNonFunApp(L[2232],if_helper317214017,[cont_tail_arg317414037]);
},
"from":L[2232]});
}
++R.GAS;
return $z1403514036;
}
};
},{"length":3});
var anf_variant_member319312515 = R.makeMethod(function(self40714001) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2232],0,arguments);
}
var anf_arg318513999 = G(self40714001,"l",L[2232]);
var $z1399113992 = D;
var $f1399713998 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg318513999):R.ffi.throwNonFunApp(L[2232],torepr65,[anf_arg318513999]);
};
try {
if(--R.GAS > 0) {
$z1399113992 = $f1399713998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1399713998,
"from":L[2232]});
}
} catch($e1398913990) {
if(R.isCont($e1398913990)) {
var $ss1399313994 = {"from":L[2232],
"go":function(anf_arg318614000) {
return $Hanf_arg953314002(anf_arg318614000,self40714001,_plus55,torepr65);
}};
$e1398913990.stack[R.EXN_STACKHEIGHT++] = $ss1399313994;
}
if(R.isPyretException($e1398913990)) {
$e1398913990.pyretStack.push(L[2232]);
}
throw $e1398913990;
}
var $ret1399513996 = $Hanf_arg953314002($z1399113992,self40714001,_plus55,torepr65);
++R.GAS;
return $ret1399513996;
};
},{"length":1});
var anf_variant_member319512516 = R.makeMethod(function(self88413988) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2662],0,arguments);
}
var ann_DASH_check_DASH_temp319413987 = ("s-prim-val");
return ann_DASH_check_DASH_temp319413987;
};
},{"length":1});
var anf_variant_member319912517 = R.makeMethod(function(self88513986) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2659],0,arguments);
}
var anf_fun319713982 = G(PP170,"str",L[2661]);
var anf_arg319813983 = G(self88513986,"name",L[2660]);
var $z1397413975 = D;
var $f1398013981 = function(_) {
return R.isFunction(anf_fun319713982)?anf_fun319713982.app(anf_arg319813983):R.ffi.throwNonFunApp(L[2659],anf_fun319713982,[anf_arg319813983]);
};
try {
if(--R.GAS > 0) {
$z1397413975 = $f1398013981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1398013981,
"from":L[2659]});
}
} catch($e1397213973) {
if(R.isCont($e1397213973)) {
var $ss1397613977 = {"from":L[2659],
"go":function(ann_DASH_check_DASH_temp319613984) {
return $Hann_DASH_check_DASH_temp953413985(ann_DASH_check_DASH_temp319613984);
}};
$e1397213973.stack[R.EXN_STACKHEIGHT++] = $ss1397613977;
}
if(R.isPyretException($e1397213973)) {
$e1397213973.pyretStack.push(L[2659]);
}
throw $e1397213973;
}
var $ret1397813979 = $Hann_DASH_check_DASH_temp953413985($z1397413975);
++R.GAS;
return $ret1397813979;
};
},{"length":1});
var anf_variant_member321212525 = R.makeMethod(function(self41013950) {
return function(cases_DASH_funs41113951,else_DASH_clause41213962) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2231],2,arguments);
}
var if_DASH_41413965 = R.hasField(cases_DASH_funs41113951,("s-id"));
var if_helper320113948 = R.makeFunction(function(if_helper_arg320213970) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2231],1,arguments);
}
var ann_DASH_check_DASH_temp320013971 = if_helper_arg320213970;
return ann_DASH_check_DASH_temp320013971;
});
var anf_if320513969 = R.isBoolean(if_DASH_41413965);
if(R.isPyretTrue(anf_if320513969)) {
if(R.isPyretTrue(if_DASH_41413965)) {
var call_DASH_s_DASH_id40913944 = G(cases_DASH_funs41113951,"s-id",L[2231]);
var anf_arg320813945 = G(self41013950,"l",L[2658]);
var anf_arg320913946 = G(self41013950,"id",L[2657]);
var $z1393613937 = D;
var $f1394213943 = function(_) {
return R.isFunction(call_DASH_s_DASH_id40913944)?call_DASH_s_DASH_id40913944.app(anf_arg320813945,anf_arg320913946):R.ffi.throwNonFunApp(L[2231],call_DASH_s_DASH_id40913944,[anf_arg320813945,anf_arg320913946]);
};
try {
if(--R.GAS > 0) {
$z1393613937 = $f1394213943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1394213943,
"from":L[2231]});
}
} catch($e1393413935) {
if(R.isCont($e1393413935)) {
var $ss1393813939 = {"from":L[2231],
"go":function(cont_tail_arg321013947) {
return $Hcont_tail_arg953513949(cont_tail_arg321013947,if_helper320113948);
}};
$e1393413935.stack[R.EXN_STACKHEIGHT++] = $ss1393813939;
}
if(R.isPyretException($e1393413935)) {
$e1393413935.pyretStack.push(L[2231]);
}
throw $e1393413935;
}
var $ret1394013941 = $Hcont_tail_arg953513949($z1393613937,if_helper320113948);
++R.GAS;
return $ret1394013941;
} else {
var $z1395413955 = D;
var $f1396013961 = function(_) {
return R.isFunction(else_DASH_clause41213962)?else_DASH_clause41213962.app():R.ffi.throwNonFunApp(L[2231],else_DASH_clause41213962,[]);
};
try {
if(--R.GAS > 0) {
$z1395413955 = $f1396013961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1396013961,
"from":L[2231]});
}
} catch($e1395213953) {
if(R.isCont($e1395213953)) {
var $ss1395613957 = {"from":L[2231],
"go":function(cont_tail_arg320613963) {
return $Hcont_tail_arg953613964(cont_tail_arg320613963,if_helper320113948);
}};
$e1395213953.stack[R.EXN_STACKHEIGHT++] = $ss1395613957;
}
if(R.isPyretException($e1395213953)) {
$e1395213953.pyretStack.push(L[2231]);
}
throw $e1395213953;
}
var $ret1395813959 = $Hcont_tail_arg953613964($z1395413955,if_helper320113948);
++R.GAS;
return $ret1395813959;
}
} else {
var cont_tail_arg320313968 = R.throwNonBooleanCondition(L[2231],("if"),if_DASH_41413965);
if(--R.GAS > 0) {
$z1396613967 = R.isFunction(if_helper320113948)?if_helper320113948.app(cont_tail_arg320313968):R.ffi.throwNonFunApp(L[2231],if_helper320113948,[cont_tail_arg320313968]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper320113948)?if_helper320113948.app(cont_tail_arg320313968):R.ffi.throwNonFunApp(L[2231],if_helper320113948,[cont_tail_arg320313968]);
},
"from":L[2231]});
}
++R.GAS;
return $z1396613967;
}
};
},{"length":3});
var anf_variant_member322212526 = R.makeMethod(function(self41313932) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2231],0,arguments);
}
var anf_arg321413930 = G(self41313932,"l",L[2231]);
var $z1392213923 = D;
var $f1392813929 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg321413930):R.ffi.throwNonFunApp(L[2231],torepr65,[anf_arg321413930]);
};
try {
if(--R.GAS > 0) {
$z1392213923 = $f1392813929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1392813929,
"from":L[2231]});
}
} catch($e1392013921) {
if(R.isCont($e1392013921)) {
var $ss1392413925 = {"from":L[2231],
"go":function(anf_arg321513931) {
return $Hanf_arg954313933(anf_arg321513931,self41313932,_plus55,torepr65);
}};
$e1392013921.stack[R.EXN_STACKHEIGHT++] = $ss1392413925;
}
if(R.isPyretException($e1392013921)) {
$e1392013921.pyretStack.push(L[2231]);
}
throw $e1392013921;
}
var $ret1392613927 = $Hanf_arg954313933($z1392213923,self41313932,_plus55,torepr65);
++R.GAS;
return $ret1392613927;
};
},{"length":1});
var anf_variant_member322412527 = R.makeMethod(function(self88813919) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2656],0,arguments);
}
var ann_DASH_check_DASH_temp322313918 = ("s-id");
return ann_DASH_check_DASH_temp322313918;
};
},{"length":1});
var anf_variant_member322812528 = R.makeMethod(function(self88913917) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2653],0,arguments);
}
var anf_bracket322613916 = G(self88913917,"id",L[2655]);
var anf_fun322713913 = G(anf_bracket322613916,"tosource",L[2654]);
var $z1390513906 = D;
var $f1391113912 = function(_) {
return R.isFunction(anf_fun322713913)?anf_fun322713913.app():R.ffi.throwNonFunApp(L[2653],anf_fun322713913,[]);
};
try {
if(--R.GAS > 0) {
$z1390513906 = $f1391113912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1391113912,
"from":L[2653]});
}
} catch($e1390313904) {
if(R.isCont($e1390313904)) {
var $ss1390713908 = {"from":L[2653],
"go":function(ann_DASH_check_DASH_temp322513914) {
return $Hann_DASH_check_DASH_temp954413915(ann_DASH_check_DASH_temp322513914);
}};
$e1390313904.stack[R.EXN_STACKHEIGHT++] = $ss1390713908;
}
if(R.isPyretException($e1390313904)) {
$e1390313904.pyretStack.push(L[2653]);
}
throw $e1390313904;
}
var $ret1390913910 = $Hann_DASH_check_DASH_temp954413915($z1390513906);
++R.GAS;
return $ret1390913910;
};
},{"length":1});
var anf_variant_member324112536 = R.makeMethod(function(self41613881) {
return function(cases_DASH_funs41713882,else_DASH_clause41813893) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2230],2,arguments);
}
var if_DASH_42013896 = R.hasField(cases_DASH_funs41713882,("s-id-var"));
var if_helper323013879 = R.makeFunction(function(if_helper_arg323113901) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2230],1,arguments);
}
var ann_DASH_check_DASH_temp322913902 = if_helper_arg323113901;
return ann_DASH_check_DASH_temp322913902;
});
var anf_if323413900 = R.isBoolean(if_DASH_42013896);
if(R.isPyretTrue(anf_if323413900)) {
if(R.isPyretTrue(if_DASH_42013896)) {
var call_DASH_s_DASH_id_DASH_var41513875 = G(cases_DASH_funs41713882,"s-id-var",L[2230]);
var anf_arg323713876 = G(self41613881,"l",L[2652]);
var anf_arg323813877 = G(self41613881,"id",L[2651]);
var $z1386713868 = D;
var $f1387313874 = function(_) {
return R.isFunction(call_DASH_s_DASH_id_DASH_var41513875)?call_DASH_s_DASH_id_DASH_var41513875.app(anf_arg323713876,anf_arg323813877):R.ffi.throwNonFunApp(L[2230],call_DASH_s_DASH_id_DASH_var41513875,[anf_arg323713876,anf_arg323813877]);
};
try {
if(--R.GAS > 0) {
$z1386713868 = $f1387313874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1387313874,
"from":L[2230]});
}
} catch($e1386513866) {
if(R.isCont($e1386513866)) {
var $ss1386913870 = {"from":L[2230],
"go":function(cont_tail_arg323913878) {
return $Hcont_tail_arg954513880(cont_tail_arg323913878,if_helper323013879);
}};
$e1386513866.stack[R.EXN_STACKHEIGHT++] = $ss1386913870;
}
if(R.isPyretException($e1386513866)) {
$e1386513866.pyretStack.push(L[2230]);
}
throw $e1386513866;
}
var $ret1387113872 = $Hcont_tail_arg954513880($z1386713868,if_helper323013879);
++R.GAS;
return $ret1387113872;
} else {
var $z1388513886 = D;
var $f1389113892 = function(_) {
return R.isFunction(else_DASH_clause41813893)?else_DASH_clause41813893.app():R.ffi.throwNonFunApp(L[2230],else_DASH_clause41813893,[]);
};
try {
if(--R.GAS > 0) {
$z1388513886 = $f1389113892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1389113892,
"from":L[2230]});
}
} catch($e1388313884) {
if(R.isCont($e1388313884)) {
var $ss1388713888 = {"from":L[2230],
"go":function(cont_tail_arg323513894) {
return $Hcont_tail_arg954613895(cont_tail_arg323513894,if_helper323013879);
}};
$e1388313884.stack[R.EXN_STACKHEIGHT++] = $ss1388713888;
}
if(R.isPyretException($e1388313884)) {
$e1388313884.pyretStack.push(L[2230]);
}
throw $e1388313884;
}
var $ret1388913890 = $Hcont_tail_arg954613895($z1388513886,if_helper323013879);
++R.GAS;
return $ret1388913890;
}
} else {
var cont_tail_arg323213899 = R.throwNonBooleanCondition(L[2230],("if"),if_DASH_42013896);
if(--R.GAS > 0) {
$z1389713898 = R.isFunction(if_helper323013879)?if_helper323013879.app(cont_tail_arg323213899):R.ffi.throwNonFunApp(L[2230],if_helper323013879,[cont_tail_arg323213899]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper323013879)?if_helper323013879.app(cont_tail_arg323213899):R.ffi.throwNonFunApp(L[2230],if_helper323013879,[cont_tail_arg323213899]);
},
"from":L[2230]});
}
++R.GAS;
return $z1389713898;
}
};
},{"length":3});
var anf_variant_member325112537 = R.makeMethod(function(self41913863) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2230],0,arguments);
}
var anf_arg324313861 = G(self41913863,"l",L[2230]);
var $z1385313854 = D;
var $f1385913860 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg324313861):R.ffi.throwNonFunApp(L[2230],torepr65,[anf_arg324313861]);
};
try {
if(--R.GAS > 0) {
$z1385313854 = $f1385913860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1385913860,
"from":L[2230]});
}
} catch($e1385113852) {
if(R.isCont($e1385113852)) {
var $ss1385513856 = {"from":L[2230],
"go":function(anf_arg324413862) {
return $Hanf_arg955313864(anf_arg324413862,self41913863,_plus55,torepr65);
}};
$e1385113852.stack[R.EXN_STACKHEIGHT++] = $ss1385513856;
}
if(R.isPyretException($e1385113852)) {
$e1385113852.pyretStack.push(L[2230]);
}
throw $e1385113852;
}
var $ret1385713858 = $Hanf_arg955313864($z1385313854,self41913863,_plus55,torepr65);
++R.GAS;
return $ret1385713858;
};
},{"length":1});
var anf_variant_member325312538 = R.makeMethod(function(self89213850) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2650],0,arguments);
}
var ann_DASH_check_DASH_temp325213849 = ("s-id-var");
return ann_DASH_check_DASH_temp325213849;
};
},{"length":1});
var anf_variant_member326012539 = R.makeMethod(function(self89313847) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2649],0,arguments);
}
var anf_fun325513845 = G(PP170,"str",L[2648]);
var $z1383713838 = D;
var $f1384313844 = function(_) {
return R.isFunction(anf_fun325513845)?anf_fun325513845.app(("!")):R.ffi.throwNonFunApp(L[2647],anf_fun325513845,[("!")]);
};
try {
if(--R.GAS > 0) {
$z1383713838 = $f1384313844();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1384313844,
"from":L[2647]});
}
} catch($e1383513836) {
if(R.isCont($e1383513836)) {
var $ss1383913840 = {"from":L[2647],
"go":function(anf_arg325613846) {
return $Hanf_arg955613848(anf_arg325613846,self89313847,_plus55);
}};
$e1383513836.stack[R.EXN_STACKHEIGHT++] = $ss1383913840;
}
if(R.isPyretException($e1383513836)) {
$e1383513836.pyretStack.push(L[2647]);
}
throw $e1383513836;
}
var $ret1384113842 = $Hanf_arg955613848($z1383713838,self89313847,_plus55);
++R.GAS;
return $ret1384113842;
};
},{"length":1});
var anf_variant_member327412547 = R.makeMethod(function(self42213813) {
return function(cases_DASH_funs42313814,else_DASH_clause42413825) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2229],2,arguments);
}
var if_DASH_42613828 = R.hasField(cases_DASH_funs42313814,("s-id-letrec"));
var if_helper326213811 = R.makeFunction(function(if_helper_arg326313833) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2229],1,arguments);
}
var ann_DASH_check_DASH_temp326113834 = if_helper_arg326313833;
return ann_DASH_check_DASH_temp326113834;
});
var anf_if326613832 = R.isBoolean(if_DASH_42613828);
if(R.isPyretTrue(anf_if326613832)) {
if(R.isPyretTrue(if_DASH_42613828)) {
var call_DASH_s_DASH_id_DASH_letrec42113806 = G(cases_DASH_funs42313814,"s-id-letrec",L[2229]);
var anf_arg326913807 = G(self42213813,"l",L[2646]);
var anf_arg327013808 = G(self42213813,"id",L[2645]);
var anf_arg327113809 = G(self42213813,"safe",L[2644]);
var $z1379813799 = D;
var $f1380413805 = function(_) {
return R.isFunction(call_DASH_s_DASH_id_DASH_letrec42113806)?call_DASH_s_DASH_id_DASH_letrec42113806.app(anf_arg326913807,anf_arg327013808,anf_arg327113809):R.ffi.throwNonFunApp(L[2229],call_DASH_s_DASH_id_DASH_letrec42113806,[anf_arg326913807,anf_arg327013808,anf_arg327113809]);
};
try {
if(--R.GAS > 0) {
$z1379813799 = $f1380413805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1380413805,
"from":L[2229]});
}
} catch($e1379613797) {
if(R.isCont($e1379613797)) {
var $ss1380013801 = {"from":L[2229],
"go":function(cont_tail_arg327213810) {
return $Hcont_tail_arg955713812(cont_tail_arg327213810,if_helper326213811);
}};
$e1379613797.stack[R.EXN_STACKHEIGHT++] = $ss1380013801;
}
if(R.isPyretException($e1379613797)) {
$e1379613797.pyretStack.push(L[2229]);
}
throw $e1379613797;
}
var $ret1380213803 = $Hcont_tail_arg955713812($z1379813799,if_helper326213811);
++R.GAS;
return $ret1380213803;
} else {
var $z1381713818 = D;
var $f1382313824 = function(_) {
return R.isFunction(else_DASH_clause42413825)?else_DASH_clause42413825.app():R.ffi.throwNonFunApp(L[2229],else_DASH_clause42413825,[]);
};
try {
if(--R.GAS > 0) {
$z1381713818 = $f1382313824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1382313824,
"from":L[2229]});
}
} catch($e1381513816) {
if(R.isCont($e1381513816)) {
var $ss1381913820 = {"from":L[2229],
"go":function(cont_tail_arg326713826) {
return $Hcont_tail_arg955813827(cont_tail_arg326713826,if_helper326213811);
}};
$e1381513816.stack[R.EXN_STACKHEIGHT++] = $ss1381913820;
}
if(R.isPyretException($e1381513816)) {
$e1381513816.pyretStack.push(L[2229]);
}
throw $e1381513816;
}
var $ret1382113822 = $Hcont_tail_arg955813827($z1381713818,if_helper326213811);
++R.GAS;
return $ret1382113822;
}
} else {
var cont_tail_arg326413831 = R.throwNonBooleanCondition(L[2229],("if"),if_DASH_42613828);
if(--R.GAS > 0) {
$z1382913830 = R.isFunction(if_helper326213811)?if_helper326213811.app(cont_tail_arg326413831):R.ffi.throwNonFunApp(L[2229],if_helper326213811,[cont_tail_arg326413831]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper326213811)?if_helper326213811.app(cont_tail_arg326413831):R.ffi.throwNonFunApp(L[2229],if_helper326213811,[cont_tail_arg326413831]);
},
"from":L[2229]});
}
++R.GAS;
return $z1382913830;
}
};
},{"length":3});
var anf_variant_member328812548 = R.makeMethod(function(self42513794) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2229],0,arguments);
}
var anf_arg327613792 = G(self42513794,"l",L[2229]);
var $z1378413785 = D;
var $f1379013791 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg327613792):R.ffi.throwNonFunApp(L[2229],torepr65,[anf_arg327613792]);
};
try {
if(--R.GAS > 0) {
$z1378413785 = $f1379013791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1379013791,
"from":L[2229]});
}
} catch($e1378213783) {
if(R.isCont($e1378213783)) {
var $ss1378613787 = {"from":L[2229],
"go":function(anf_arg327713793) {
return $Hanf_arg956813795(anf_arg327713793,self42513794,_plus55,torepr65);
}};
$e1378213783.stack[R.EXN_STACKHEIGHT++] = $ss1378613787;
}
if(R.isPyretException($e1378213783)) {
$e1378213783.pyretStack.push(L[2229]);
}
throw $e1378213783;
}
var $ret1378813789 = $Hanf_arg956813795($z1378413785,self42513794,_plus55,torepr65);
++R.GAS;
return $ret1378813789;
};
},{"length":1});
var anf_variant_member329012549 = R.makeMethod(function(self89713781) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2643],0,arguments);
}
var ann_DASH_check_DASH_temp328913780 = ("s-id-letrec");
return ann_DASH_check_DASH_temp328913780;
};
},{"length":1});
var anf_variant_member329712550 = R.makeMethod(function(self89813778) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2642],0,arguments);
}
var anf_fun329213776 = G(PP170,"str",L[2641]);
var $z1376813769 = D;
var $f1377413775 = function(_) {
return R.isFunction(anf_fun329213776)?anf_fun329213776.app(("~")):R.ffi.throwNonFunApp(L[2640],anf_fun329213776,[("~")]);
};
try {
if(--R.GAS > 0) {
$z1376813769 = $f1377413775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1377413775,
"from":L[2640]});
}
} catch($e1376613767) {
if(R.isCont($e1376613767)) {
var $ss1377013771 = {"from":L[2640],
"go":function(anf_arg329313777) {
return $Hanf_arg957113779(anf_arg329313777,self89813778,_plus55);
}};
$e1376613767.stack[R.EXN_STACKHEIGHT++] = $ss1377013771;
}
if(R.isPyretException($e1376613767)) {
$e1376613767.pyretStack.push(L[2640]);
}
throw $e1376613767;
}
var $ret1377213773 = $Hanf_arg957113779($z1376813769,self89813778,_plus55);
++R.GAS;
return $ret1377213773;
};
},{"length":1});
var anf_variant_member330912559 = R.makeMethod(function(self42813744) {
return function(cases_DASH_funs42913745,else_DASH_clause43013756) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2228],2,arguments);
}
var if_DASH_43213759 = R.hasField(cases_DASH_funs42913745,("s-undefined"));
var if_helper329913742 = R.makeFunction(function(if_helper_arg330013764) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2228],1,arguments);
}
var ann_DASH_check_DASH_temp329813765 = if_helper_arg330013764;
return ann_DASH_check_DASH_temp329813765;
});
var anf_if330313763 = R.isBoolean(if_DASH_43213759);
if(R.isPyretTrue(anf_if330313763)) {
if(R.isPyretTrue(if_DASH_43213759)) {
var call_DASH_s_DASH_undefined42713739 = G(cases_DASH_funs42913745,"s-undefined",L[2228]);
var anf_arg330613740 = G(self42813744,"l",L[2639]);
var $z1373113732 = D;
var $f1373713738 = function(_) {
return R.isFunction(call_DASH_s_DASH_undefined42713739)?call_DASH_s_DASH_undefined42713739.app(anf_arg330613740):R.ffi.throwNonFunApp(L[2228],call_DASH_s_DASH_undefined42713739,[anf_arg330613740]);
};
try {
if(--R.GAS > 0) {
$z1373113732 = $f1373713738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1373713738,
"from":L[2228]});
}
} catch($e1372913730) {
if(R.isCont($e1372913730)) {
var $ss1373313734 = {"from":L[2228],
"go":function(cont_tail_arg330713741) {
return $Hcont_tail_arg957213743(cont_tail_arg330713741,if_helper329913742);
}};
$e1372913730.stack[R.EXN_STACKHEIGHT++] = $ss1373313734;
}
if(R.isPyretException($e1372913730)) {
$e1372913730.pyretStack.push(L[2228]);
}
throw $e1372913730;
}
var $ret1373513736 = $Hcont_tail_arg957213743($z1373113732,if_helper329913742);
++R.GAS;
return $ret1373513736;
} else {
var $z1374813749 = D;
var $f1375413755 = function(_) {
return R.isFunction(else_DASH_clause43013756)?else_DASH_clause43013756.app():R.ffi.throwNonFunApp(L[2228],else_DASH_clause43013756,[]);
};
try {
if(--R.GAS > 0) {
$z1374813749 = $f1375413755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1375413755,
"from":L[2228]});
}
} catch($e1374613747) {
if(R.isCont($e1374613747)) {
var $ss1375013751 = {"from":L[2228],
"go":function(cont_tail_arg330413757) {
return $Hcont_tail_arg957313758(cont_tail_arg330413757,if_helper329913742);
}};
$e1374613747.stack[R.EXN_STACKHEIGHT++] = $ss1375013751;
}
if(R.isPyretException($e1374613747)) {
$e1374613747.pyretStack.push(L[2228]);
}
throw $e1374613747;
}
var $ret1375213753 = $Hcont_tail_arg957313758($z1374813749,if_helper329913742);
++R.GAS;
return $ret1375213753;
}
} else {
var cont_tail_arg330113762 = R.throwNonBooleanCondition(L[2228],("if"),if_DASH_43213759);
if(--R.GAS > 0) {
$z1376013761 = R.isFunction(if_helper329913742)?if_helper329913742.app(cont_tail_arg330113762):R.ffi.throwNonFunApp(L[2228],if_helper329913742,[cont_tail_arg330113762]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper329913742)?if_helper329913742.app(cont_tail_arg330113762):R.ffi.throwNonFunApp(L[2228],if_helper329913742,[cont_tail_arg330113762]);
},
"from":L[2228]});
}
++R.GAS;
return $z1376013761;
}
};
},{"length":3});
var anf_variant_member331512560 = R.makeMethod(function(self43113728) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2228],0,arguments);
}
var anf_arg331113725 = G(self43113728,"l",L[2228]);
var $z1371713718 = D;
var $f1372313724 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg331113725):R.ffi.throwNonFunApp(L[2228],torepr65,[anf_arg331113725]);
};
try {
if(--R.GAS > 0) {
$z1371713718 = $f1372313724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1372313724,
"from":L[2228]});
}
} catch($e1371513716) {
if(R.isCont($e1371513716)) {
var $ss1371913720 = {"from":L[2228],
"go":function(anf_arg331213726) {
return $Hanf_arg957713727(anf_arg331213726,_plus55);
}};
$e1371513716.stack[R.EXN_STACKHEIGHT++] = $ss1371913720;
}
if(R.isPyretException($e1371513716)) {
$e1371513716.pyretStack.push(L[2228]);
}
throw $e1371513716;
}
var $ret1372113722 = $Hanf_arg957713727($z1371713718,_plus55);
++R.GAS;
return $ret1372113722;
};
},{"length":1});
var anf_variant_member331712561 = R.makeMethod(function(self90013714) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2638],0,arguments);
}
var ann_DASH_check_DASH_temp331613713 = ("s-undefined");
return ann_DASH_check_DASH_temp331613713;
};
},{"length":1});
var anf_variant_member332012562 = R.makeMethod(function(self90113712) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2636],0,arguments);
}
var anf_fun331913709 = G(PP170,"str",L[2637]);
var $z1370113702 = D;
var $f1370713708 = function(_) {
return R.isFunction(anf_fun331913709)?anf_fun331913709.app(("undefined")):R.ffi.throwNonFunApp(L[2636],anf_fun331913709,[("undefined")]);
};
try {
if(--R.GAS > 0) {
$z1370113702 = $f1370713708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1370713708,
"from":L[2636]});
}
} catch($e1369913700) {
if(R.isCont($e1369913700)) {
var $ss1370313704 = {"from":L[2636],
"go":function(ann_DASH_check_DASH_temp331813710) {
return $Hann_DASH_check_DASH_temp957813711(ann_DASH_check_DASH_temp331813710);
}};
$e1369913700.stack[R.EXN_STACKHEIGHT++] = $ss1370313704;
}
if(R.isPyretException($e1369913700)) {
$e1369913700.pyretStack.push(L[2636]);
}
throw $e1369913700;
}
var $ret1370513706 = $Hann_DASH_check_DASH_temp957813711($z1370113702);
++R.GAS;
return $ret1370513706;
};
},{"length":1});
var anf_variant_member333312569 = R.makeMethod(function(self43413677) {
return function(cases_DASH_funs43513678,else_DASH_clause43613689) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2227],2,arguments);
}
var if_DASH_43813692 = R.hasField(cases_DASH_funs43513678,("s-srcloc"));
var if_helper332213675 = R.makeFunction(function(if_helper_arg332313697) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2227],1,arguments);
}
var ann_DASH_check_DASH_temp332113698 = if_helper_arg332313697;
return ann_DASH_check_DASH_temp332113698;
});
var anf_if332613696 = R.isBoolean(if_DASH_43813692);
if(R.isPyretTrue(anf_if332613696)) {
if(R.isPyretTrue(if_DASH_43813692)) {
var call_DASH_s_DASH_srcloc43313671 = G(cases_DASH_funs43513678,"s-srcloc",L[2227]);
var anf_arg332913672 = G(self43413677,"l",L[2635]);
var anf_arg333013673 = G(self43413677,"loc",L[2634]);
var $z1366313664 = D;
var $f1366913670 = function(_) {
return R.isFunction(call_DASH_s_DASH_srcloc43313671)?call_DASH_s_DASH_srcloc43313671.app(anf_arg332913672,anf_arg333013673):R.ffi.throwNonFunApp(L[2227],call_DASH_s_DASH_srcloc43313671,[anf_arg332913672,anf_arg333013673]);
};
try {
if(--R.GAS > 0) {
$z1366313664 = $f1366913670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1366913670,
"from":L[2227]});
}
} catch($e1366113662) {
if(R.isCont($e1366113662)) {
var $ss1366513666 = {"from":L[2227],
"go":function(cont_tail_arg333113674) {
return $Hcont_tail_arg957913676(cont_tail_arg333113674,if_helper332213675);
}};
$e1366113662.stack[R.EXN_STACKHEIGHT++] = $ss1366513666;
}
if(R.isPyretException($e1366113662)) {
$e1366113662.pyretStack.push(L[2227]);
}
throw $e1366113662;
}
var $ret1366713668 = $Hcont_tail_arg957913676($z1366313664,if_helper332213675);
++R.GAS;
return $ret1366713668;
} else {
var $z1368113682 = D;
var $f1368713688 = function(_) {
return R.isFunction(else_DASH_clause43613689)?else_DASH_clause43613689.app():R.ffi.throwNonFunApp(L[2227],else_DASH_clause43613689,[]);
};
try {
if(--R.GAS > 0) {
$z1368113682 = $f1368713688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1368713688,
"from":L[2227]});
}
} catch($e1367913680) {
if(R.isCont($e1367913680)) {
var $ss1368313684 = {"from":L[2227],
"go":function(cont_tail_arg332713690) {
return $Hcont_tail_arg958013691(cont_tail_arg332713690,if_helper332213675);
}};
$e1367913680.stack[R.EXN_STACKHEIGHT++] = $ss1368313684;
}
if(R.isPyretException($e1367913680)) {
$e1367913680.pyretStack.push(L[2227]);
}
throw $e1367913680;
}
var $ret1368513686 = $Hcont_tail_arg958013691($z1368113682,if_helper332213675);
++R.GAS;
return $ret1368513686;
}
} else {
var cont_tail_arg332413695 = R.throwNonBooleanCondition(L[2227],("if"),if_DASH_43813692);
if(--R.GAS > 0) {
$z1369313694 = R.isFunction(if_helper332213675)?if_helper332213675.app(cont_tail_arg332413695):R.ffi.throwNonFunApp(L[2227],if_helper332213675,[cont_tail_arg332413695]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper332213675)?if_helper332213675.app(cont_tail_arg332413695):R.ffi.throwNonFunApp(L[2227],if_helper332213675,[cont_tail_arg332413695]);
},
"from":L[2227]});
}
++R.GAS;
return $z1369313694;
}
};
},{"length":3});
var anf_variant_member334312570 = R.makeMethod(function(self43713659) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2227],0,arguments);
}
var anf_arg333513657 = G(self43713659,"l",L[2227]);
var $z1364913650 = D;
var $f1365513656 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg333513657):R.ffi.throwNonFunApp(L[2227],torepr65,[anf_arg333513657]);
};
try {
if(--R.GAS > 0) {
$z1364913650 = $f1365513656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1365513656,
"from":L[2227]});
}
} catch($e1364713648) {
if(R.isCont($e1364713648)) {
var $ss1365113652 = {"from":L[2227],
"go":function(anf_arg333613658) {
return $Hanf_arg958713660(anf_arg333613658,self43713659,_plus55,torepr65);
}};
$e1364713648.stack[R.EXN_STACKHEIGHT++] = $ss1365113652;
}
if(R.isPyretException($e1364713648)) {
$e1364713648.pyretStack.push(L[2227]);
}
throw $e1364713648;
}
var $ret1365313654 = $Hanf_arg958713660($z1364913650,self43713659,_plus55,torepr65);
++R.GAS;
return $ret1365313654;
};
},{"length":1});
var anf_variant_member334512571 = R.makeMethod(function(self90413646) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2633],0,arguments);
}
var ann_DASH_check_DASH_temp334413645 = ("s-srcloc");
return ann_DASH_check_DASH_temp334413645;
};
},{"length":1});
var anf_variant_member335012572 = R.makeMethod(function(self90513644) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2632],0,arguments);
}
var anf_fun334713642 = G(PP170,"str",L[2631]);
var anf_arg334813640 = G(self90513644,"loc",L[2630]);
var $z1363213633 = D;
var $f1363813639 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg334813640):R.ffi.throwNonFunApp(L[2629],torepr65,[anf_arg334813640]);
};
try {
if(--R.GAS > 0) {
$z1363213633 = $f1363813639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1363813639,
"from":L[2629]});
}
} catch($e1363013631) {
if(R.isCont($e1363013631)) {
var $ss1363413635 = {"from":L[2629],
"go":function(anf_arg334913641) {
return $Hanf_arg958913643(anf_arg334913641,anf_fun334713642);
}};
$e1363013631.stack[R.EXN_STACKHEIGHT++] = $ss1363413635;
}
if(R.isPyretException($e1363013631)) {
$e1363013631.pyretStack.push(L[2629]);
}
throw $e1363013631;
}
var $ret1363613637 = $Hanf_arg958913643($z1363213633,anf_fun334713642);
++R.GAS;
return $ret1363613637;
};
},{"length":1});
var anf_variant_member336312580 = R.makeMethod(function(self44013608) {
return function(cases_DASH_funs44113609,else_DASH_clause44213620) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2226],2,arguments);
}
var if_DASH_44413623 = R.hasField(cases_DASH_funs44113609,("s-num"));
var if_helper335213606 = R.makeFunction(function(if_helper_arg335313628) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2226],1,arguments);
}
var ann_DASH_check_DASH_temp335113629 = if_helper_arg335313628;
return ann_DASH_check_DASH_temp335113629;
});
var anf_if335613627 = R.isBoolean(if_DASH_44413623);
if(R.isPyretTrue(anf_if335613627)) {
if(R.isPyretTrue(if_DASH_44413623)) {
var call_DASH_s_DASH_num43913602 = G(cases_DASH_funs44113609,"s-num",L[2226]);
var anf_arg335913603 = G(self44013608,"l",L[2628]);
var anf_arg336013604 = G(self44013608,"n",L[2627]);
var $z1359413595 = D;
var $f1360013601 = function(_) {
return R.isFunction(call_DASH_s_DASH_num43913602)?call_DASH_s_DASH_num43913602.app(anf_arg335913603,anf_arg336013604):R.ffi.throwNonFunApp(L[2226],call_DASH_s_DASH_num43913602,[anf_arg335913603,anf_arg336013604]);
};
try {
if(--R.GAS > 0) {
$z1359413595 = $f1360013601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1360013601,
"from":L[2226]});
}
} catch($e1359213593) {
if(R.isCont($e1359213593)) {
var $ss1359613597 = {"from":L[2226],
"go":function(cont_tail_arg336113605) {
return $Hcont_tail_arg959013607(cont_tail_arg336113605,if_helper335213606);
}};
$e1359213593.stack[R.EXN_STACKHEIGHT++] = $ss1359613597;
}
if(R.isPyretException($e1359213593)) {
$e1359213593.pyretStack.push(L[2226]);
}
throw $e1359213593;
}
var $ret1359813599 = $Hcont_tail_arg959013607($z1359413595,if_helper335213606);
++R.GAS;
return $ret1359813599;
} else {
var $z1361213613 = D;
var $f1361813619 = function(_) {
return R.isFunction(else_DASH_clause44213620)?else_DASH_clause44213620.app():R.ffi.throwNonFunApp(L[2226],else_DASH_clause44213620,[]);
};
try {
if(--R.GAS > 0) {
$z1361213613 = $f1361813619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1361813619,
"from":L[2226]});
}
} catch($e1361013611) {
if(R.isCont($e1361013611)) {
var $ss1361413615 = {"from":L[2226],
"go":function(cont_tail_arg335713621) {
return $Hcont_tail_arg959113622(cont_tail_arg335713621,if_helper335213606);
}};
$e1361013611.stack[R.EXN_STACKHEIGHT++] = $ss1361413615;
}
if(R.isPyretException($e1361013611)) {
$e1361013611.pyretStack.push(L[2226]);
}
throw $e1361013611;
}
var $ret1361613617 = $Hcont_tail_arg959113622($z1361213613,if_helper335213606);
++R.GAS;
return $ret1361613617;
}
} else {
var cont_tail_arg335413626 = R.throwNonBooleanCondition(L[2226],("if"),if_DASH_44413623);
if(--R.GAS > 0) {
$z1362413625 = R.isFunction(if_helper335213606)?if_helper335213606.app(cont_tail_arg335413626):R.ffi.throwNonFunApp(L[2226],if_helper335213606,[cont_tail_arg335413626]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper335213606)?if_helper335213606.app(cont_tail_arg335413626):R.ffi.throwNonFunApp(L[2226],if_helper335213606,[cont_tail_arg335413626]);
},
"from":L[2226]});
}
++R.GAS;
return $z1362413625;
}
};
},{"length":3});
var anf_variant_member337312581 = R.makeMethod(function(self44313590) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2226],0,arguments);
}
var anf_arg336513588 = G(self44313590,"l",L[2226]);
var $z1358013581 = D;
var $f1358613587 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg336513588):R.ffi.throwNonFunApp(L[2226],torepr65,[anf_arg336513588]);
};
try {
if(--R.GAS > 0) {
$z1358013581 = $f1358613587();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1358613587,
"from":L[2226]});
}
} catch($e1357813579) {
if(R.isCont($e1357813579)) {
var $ss1358213583 = {"from":L[2226],
"go":function(anf_arg336613589) {
return $Hanf_arg959813591(anf_arg336613589,self44313590,_plus55,torepr65);
}};
$e1357813579.stack[R.EXN_STACKHEIGHT++] = $ss1358213583;
}
if(R.isPyretException($e1357813579)) {
$e1357813579.pyretStack.push(L[2226]);
}
throw $e1357813579;
}
var $ret1358413585 = $Hanf_arg959813591($z1358013581,self44313590,_plus55,torepr65);
++R.GAS;
return $ret1358413585;
};
},{"length":1});
var anf_variant_member337512582 = R.makeMethod(function(self90813577) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2626],0,arguments);
}
var ann_DASH_check_DASH_temp337413576 = ("s-num");
return ann_DASH_check_DASH_temp337413576;
};
},{"length":1});
var anf_variant_member337912583 = R.makeMethod(function(self90913575) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2623],0,arguments);
}
var anf_fun337713571 = G(PP170,"number",L[2625]);
var anf_arg337813572 = G(self90913575,"n",L[2624]);
var $z1356313564 = D;
var $f1356913570 = function(_) {
return R.isFunction(anf_fun337713571)?anf_fun337713571.app(anf_arg337813572):R.ffi.throwNonFunApp(L[2623],anf_fun337713571,[anf_arg337813572]);
};
try {
if(--R.GAS > 0) {
$z1356313564 = $f1356913570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1356913570,
"from":L[2623]});
}
} catch($e1356113562) {
if(R.isCont($e1356113562)) {
var $ss1356513566 = {"from":L[2623],
"go":function(ann_DASH_check_DASH_temp337613573) {
return $Hann_DASH_check_DASH_temp959913574(ann_DASH_check_DASH_temp337613573);
}};
$e1356113562.stack[R.EXN_STACKHEIGHT++] = $ss1356513566;
}
if(R.isPyretException($e1356113562)) {
$e1356113562.pyretStack.push(L[2623]);
}
throw $e1356113562;
}
var $ret1356713568 = $Hann_DASH_check_DASH_temp959913574($z1356313564);
++R.GAS;
return $ret1356713568;
};
},{"length":1});
var anf_variant_member339312591 = R.makeMethod(function(self44613539) {
return function(cases_DASH_funs44713540,else_DASH_clause44813551) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2225],2,arguments);
}
var if_DASH_45013554 = R.hasField(cases_DASH_funs44713540,("s-frac"));
var if_helper338113537 = R.makeFunction(function(if_helper_arg338213559) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2225],1,arguments);
}
var ann_DASH_check_DASH_temp338013560 = if_helper_arg338213559;
return ann_DASH_check_DASH_temp338013560;
});
var anf_if338513558 = R.isBoolean(if_DASH_45013554);
if(R.isPyretTrue(anf_if338513558)) {
if(R.isPyretTrue(if_DASH_45013554)) {
var call_DASH_s_DASH_frac44513532 = G(cases_DASH_funs44713540,"s-frac",L[2225]);
var anf_arg338813533 = G(self44613539,"l",L[2622]);
var anf_arg338913534 = G(self44613539,"num",L[2621]);
var anf_arg339013535 = G(self44613539,"den",L[2620]);
var $z1352413525 = D;
var $f1353013531 = function(_) {
return R.isFunction(call_DASH_s_DASH_frac44513532)?call_DASH_s_DASH_frac44513532.app(anf_arg338813533,anf_arg338913534,anf_arg339013535):R.ffi.throwNonFunApp(L[2225],call_DASH_s_DASH_frac44513532,[anf_arg338813533,anf_arg338913534,anf_arg339013535]);
};
try {
if(--R.GAS > 0) {
$z1352413525 = $f1353013531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1353013531,
"from":L[2225]});
}
} catch($e1352213523) {
if(R.isCont($e1352213523)) {
var $ss1352613527 = {"from":L[2225],
"go":function(cont_tail_arg339113536) {
return $Hcont_tail_arg960013538(cont_tail_arg339113536,if_helper338113537);
}};
$e1352213523.stack[R.EXN_STACKHEIGHT++] = $ss1352613527;
}
if(R.isPyretException($e1352213523)) {
$e1352213523.pyretStack.push(L[2225]);
}
throw $e1352213523;
}
var $ret1352813529 = $Hcont_tail_arg960013538($z1352413525,if_helper338113537);
++R.GAS;
return $ret1352813529;
} else {
var $z1354313544 = D;
var $f1354913550 = function(_) {
return R.isFunction(else_DASH_clause44813551)?else_DASH_clause44813551.app():R.ffi.throwNonFunApp(L[2225],else_DASH_clause44813551,[]);
};
try {
if(--R.GAS > 0) {
$z1354313544 = $f1354913550();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1354913550,
"from":L[2225]});
}
} catch($e1354113542) {
if(R.isCont($e1354113542)) {
var $ss1354513546 = {"from":L[2225],
"go":function(cont_tail_arg338613552) {
return $Hcont_tail_arg960113553(cont_tail_arg338613552,if_helper338113537);
}};
$e1354113542.stack[R.EXN_STACKHEIGHT++] = $ss1354513546;
}
if(R.isPyretException($e1354113542)) {
$e1354113542.pyretStack.push(L[2225]);
}
throw $e1354113542;
}
var $ret1354713548 = $Hcont_tail_arg960113553($z1354313544,if_helper338113537);
++R.GAS;
return $ret1354713548;
}
} else {
var cont_tail_arg338313557 = R.throwNonBooleanCondition(L[2225],("if"),if_DASH_45013554);
if(--R.GAS > 0) {
$z1355513556 = R.isFunction(if_helper338113537)?if_helper338113537.app(cont_tail_arg338313557):R.ffi.throwNonFunApp(L[2225],if_helper338113537,[cont_tail_arg338313557]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper338113537)?if_helper338113537.app(cont_tail_arg338313557):R.ffi.throwNonFunApp(L[2225],if_helper338113537,[cont_tail_arg338313557]);
},
"from":L[2225]});
}
++R.GAS;
return $z1355513556;
}
};
},{"length":3});
var anf_variant_member340712592 = R.makeMethod(function(self44913520) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2225],0,arguments);
}
var anf_arg339513518 = G(self44913520,"l",L[2225]);
var $z1351013511 = D;
var $f1351613517 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg339513518):R.ffi.throwNonFunApp(L[2225],torepr65,[anf_arg339513518]);
};
try {
if(--R.GAS > 0) {
$z1351013511 = $f1351613517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1351613517,
"from":L[2225]});
}
} catch($e1350813509) {
if(R.isCont($e1350813509)) {
var $ss1351213513 = {"from":L[2225],
"go":function(anf_arg339613519) {
return $Hanf_arg961113521(anf_arg339613519,self44913520,_plus55,torepr65);
}};
$e1350813509.stack[R.EXN_STACKHEIGHT++] = $ss1351213513;
}
if(R.isPyretException($e1350813509)) {
$e1350813509.pyretStack.push(L[2225]);
}
throw $e1350813509;
}
var $ret1351413515 = $Hanf_arg961113521($z1351013511,self44913520,_plus55,torepr65);
++R.GAS;
return $ret1351413515;
};
},{"length":1});
var anf_variant_member340912593 = R.makeMethod(function(self91313507) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2619],0,arguments);
}
var ann_DASH_check_DASH_temp340813506 = ("s-frac");
return ann_DASH_check_DASH_temp340813506;
};
},{"length":1});
var anf_variant_member342012594 = R.makeMethod(function(self91413504) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2618],0,arguments);
}
var anf_fun341113501 = G(PP170,"number",L[2617]);
var anf_arg341213502 = G(self91413504,"num",L[2616]);
var $z1349313494 = D;
var $f1349913500 = function(_) {
return R.isFunction(anf_fun341113501)?anf_fun341113501.app(anf_arg341213502):R.ffi.throwNonFunApp(L[2615],anf_fun341113501,[anf_arg341213502]);
};
try {
if(--R.GAS > 0) {
$z1349313494 = $f1349913500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1349913500,
"from":L[2615]});
}
} catch($e1349113492) {
if(R.isCont($e1349113492)) {
var $ss1349513496 = {"from":L[2615],
"go":function(anf_arg341313503) {
return $Hanf_arg961613505(anf_arg341313503,PP170,self91413504,_plus55);
}};
$e1349113492.stack[R.EXN_STACKHEIGHT++] = $ss1349513496;
}
if(R.isPyretException($e1349113492)) {
$e1349113492.pyretStack.push(L[2615]);
}
throw $e1349113492;
}
var $ret1349713498 = $Hanf_arg961613505($z1349313494,PP170,self91413504,_plus55);
++R.GAS;
return $ret1349713498;
};
},{"length":1});
var anf_variant_member343312603 = R.makeMethod(function(self45213469) {
return function(cases_DASH_funs45313470,else_DASH_clause45413481) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2224],2,arguments);
}
var if_DASH_45613484 = R.hasField(cases_DASH_funs45313470,("s-bool"));
var if_helper342213467 = R.makeFunction(function(if_helper_arg342313489) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2224],1,arguments);
}
var ann_DASH_check_DASH_temp342113490 = if_helper_arg342313489;
return ann_DASH_check_DASH_temp342113490;
});
var anf_if342613488 = R.isBoolean(if_DASH_45613484);
if(R.isPyretTrue(anf_if342613488)) {
if(R.isPyretTrue(if_DASH_45613484)) {
var call_DASH_s_DASH_bool45113463 = G(cases_DASH_funs45313470,"s-bool",L[2224]);
var anf_arg342913464 = G(self45213469,"l",L[2614]);
var anf_arg343013465 = G(self45213469,"b",L[2613]);
var $z1345513456 = D;
var $f1346113462 = function(_) {
return R.isFunction(call_DASH_s_DASH_bool45113463)?call_DASH_s_DASH_bool45113463.app(anf_arg342913464,anf_arg343013465):R.ffi.throwNonFunApp(L[2224],call_DASH_s_DASH_bool45113463,[anf_arg342913464,anf_arg343013465]);
};
try {
if(--R.GAS > 0) {
$z1345513456 = $f1346113462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1346113462,
"from":L[2224]});
}
} catch($e1345313454) {
if(R.isCont($e1345313454)) {
var $ss1345713458 = {"from":L[2224],
"go":function(cont_tail_arg343113466) {
return $Hcont_tail_arg961713468(cont_tail_arg343113466,if_helper342213467);
}};
$e1345313454.stack[R.EXN_STACKHEIGHT++] = $ss1345713458;
}
if(R.isPyretException($e1345313454)) {
$e1345313454.pyretStack.push(L[2224]);
}
throw $e1345313454;
}
var $ret1345913460 = $Hcont_tail_arg961713468($z1345513456,if_helper342213467);
++R.GAS;
return $ret1345913460;
} else {
var $z1347313474 = D;
var $f1347913480 = function(_) {
return R.isFunction(else_DASH_clause45413481)?else_DASH_clause45413481.app():R.ffi.throwNonFunApp(L[2224],else_DASH_clause45413481,[]);
};
try {
if(--R.GAS > 0) {
$z1347313474 = $f1347913480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1347913480,
"from":L[2224]});
}
} catch($e1347113472) {
if(R.isCont($e1347113472)) {
var $ss1347513476 = {"from":L[2224],
"go":function(cont_tail_arg342713482) {
return $Hcont_tail_arg961813483(cont_tail_arg342713482,if_helper342213467);
}};
$e1347113472.stack[R.EXN_STACKHEIGHT++] = $ss1347513476;
}
if(R.isPyretException($e1347113472)) {
$e1347113472.pyretStack.push(L[2224]);
}
throw $e1347113472;
}
var $ret1347713478 = $Hcont_tail_arg961813483($z1347313474,if_helper342213467);
++R.GAS;
return $ret1347713478;
}
} else {
var cont_tail_arg342413487 = R.throwNonBooleanCondition(L[2224],("if"),if_DASH_45613484);
if(--R.GAS > 0) {
$z1348513486 = R.isFunction(if_helper342213467)?if_helper342213467.app(cont_tail_arg342413487):R.ffi.throwNonFunApp(L[2224],if_helper342213467,[cont_tail_arg342413487]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper342213467)?if_helper342213467.app(cont_tail_arg342413487):R.ffi.throwNonFunApp(L[2224],if_helper342213467,[cont_tail_arg342413487]);
},
"from":L[2224]});
}
++R.GAS;
return $z1348513486;
}
};
},{"length":3});
var anf_variant_member344312604 = R.makeMethod(function(self45513451) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2224],0,arguments);
}
var anf_arg343513449 = G(self45513451,"l",L[2224]);
var $z1344113442 = D;
var $f1344713448 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg343513449):R.ffi.throwNonFunApp(L[2224],torepr65,[anf_arg343513449]);
};
try {
if(--R.GAS > 0) {
$z1344113442 = $f1344713448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1344713448,
"from":L[2224]});
}
} catch($e1343913440) {
if(R.isCont($e1343913440)) {
var $ss1344313444 = {"from":L[2224],
"go":function(anf_arg343613450) {
return $Hanf_arg962513452(anf_arg343613450,self45513451,_plus55,torepr65);
}};
$e1343913440.stack[R.EXN_STACKHEIGHT++] = $ss1344313444;
}
if(R.isPyretException($e1343913440)) {
$e1343913440.pyretStack.push(L[2224]);
}
throw $e1343913440;
}
var $ret1344513446 = $Hanf_arg962513452($z1344113442,self45513451,_plus55,torepr65);
++R.GAS;
return $ret1344513446;
};
},{"length":1});
var anf_variant_member344512605 = R.makeMethod(function(self91713438) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2612],0,arguments);
}
var ann_DASH_check_DASH_temp344413437 = ("s-bool");
return ann_DASH_check_DASH_temp344413437;
};
},{"length":1});
var anf_variant_member345012606 = R.makeMethod(function(self91813436) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2611],0,arguments);
}
var anf_fun344713434 = G(PP170,"str",L[2610]);
var anf_arg344813432 = G(self91813436,"b",L[2609]);
var $z1342413425 = D;
var $f1343013431 = function(_) {
return R.isFunction(tostring66)?tostring66.app(anf_arg344813432):R.ffi.throwNonFunApp(L[2608],tostring66,[anf_arg344813432]);
};
try {
if(--R.GAS > 0) {
$z1342413425 = $f1343013431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1343013431,
"from":L[2608]});
}
} catch($e1342213423) {
if(R.isCont($e1342213423)) {
var $ss1342613427 = {"from":L[2608],
"go":function(anf_arg344913433) {
return $Hanf_arg962713435(anf_arg344913433,anf_fun344713434);
}};
$e1342213423.stack[R.EXN_STACKHEIGHT++] = $ss1342613427;
}
if(R.isPyretException($e1342213423)) {
$e1342213423.pyretStack.push(L[2608]);
}
throw $e1342213423;
}
var $ret1342813429 = $Hanf_arg962713435($z1342413425,anf_fun344713434);
++R.GAS;
return $ret1342813429;
};
},{"length":1});
var anf_variant_member346312614 = R.makeMethod(function(self45813400) {
return function(cases_DASH_funs45913401,else_DASH_clause46013412) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2223],2,arguments);
}
var if_DASH_46213415 = R.hasField(cases_DASH_funs45913401,("s-str"));
var if_helper345213398 = R.makeFunction(function(if_helper_arg345313420) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2223],1,arguments);
}
var ann_DASH_check_DASH_temp345113421 = if_helper_arg345313420;
return ann_DASH_check_DASH_temp345113421;
});
var anf_if345613419 = R.isBoolean(if_DASH_46213415);
if(R.isPyretTrue(anf_if345613419)) {
if(R.isPyretTrue(if_DASH_46213415)) {
var call_DASH_s_DASH_str45713394 = G(cases_DASH_funs45913401,"s-str",L[2223]);
var anf_arg345913395 = G(self45813400,"l",L[2607]);
var anf_arg346013396 = G(self45813400,"s",L[2606]);
var $z1338613387 = D;
var $f1339213393 = function(_) {
return R.isFunction(call_DASH_s_DASH_str45713394)?call_DASH_s_DASH_str45713394.app(anf_arg345913395,anf_arg346013396):R.ffi.throwNonFunApp(L[2223],call_DASH_s_DASH_str45713394,[anf_arg345913395,anf_arg346013396]);
};
try {
if(--R.GAS > 0) {
$z1338613387 = $f1339213393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1339213393,
"from":L[2223]});
}
} catch($e1338413385) {
if(R.isCont($e1338413385)) {
var $ss1338813389 = {"from":L[2223],
"go":function(cont_tail_arg346113397) {
return $Hcont_tail_arg962813399(cont_tail_arg346113397,if_helper345213398);
}};
$e1338413385.stack[R.EXN_STACKHEIGHT++] = $ss1338813389;
}
if(R.isPyretException($e1338413385)) {
$e1338413385.pyretStack.push(L[2223]);
}
throw $e1338413385;
}
var $ret1339013391 = $Hcont_tail_arg962813399($z1338613387,if_helper345213398);
++R.GAS;
return $ret1339013391;
} else {
var $z1340413405 = D;
var $f1341013411 = function(_) {
return R.isFunction(else_DASH_clause46013412)?else_DASH_clause46013412.app():R.ffi.throwNonFunApp(L[2223],else_DASH_clause46013412,[]);
};
try {
if(--R.GAS > 0) {
$z1340413405 = $f1341013411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1341013411,
"from":L[2223]});
}
} catch($e1340213403) {
if(R.isCont($e1340213403)) {
var $ss1340613407 = {"from":L[2223],
"go":function(cont_tail_arg345713413) {
return $Hcont_tail_arg962913414(cont_tail_arg345713413,if_helper345213398);
}};
$e1340213403.stack[R.EXN_STACKHEIGHT++] = $ss1340613407;
}
if(R.isPyretException($e1340213403)) {
$e1340213403.pyretStack.push(L[2223]);
}
throw $e1340213403;
}
var $ret1340813409 = $Hcont_tail_arg962913414($z1340413405,if_helper345213398);
++R.GAS;
return $ret1340813409;
}
} else {
var cont_tail_arg345413418 = R.throwNonBooleanCondition(L[2223],("if"),if_DASH_46213415);
if(--R.GAS > 0) {
$z1341613417 = R.isFunction(if_helper345213398)?if_helper345213398.app(cont_tail_arg345413418):R.ffi.throwNonFunApp(L[2223],if_helper345213398,[cont_tail_arg345413418]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper345213398)?if_helper345213398.app(cont_tail_arg345413418):R.ffi.throwNonFunApp(L[2223],if_helper345213398,[cont_tail_arg345413418]);
},
"from":L[2223]});
}
++R.GAS;
return $z1341613417;
}
};
},{"length":3});
var anf_variant_member347312615 = R.makeMethod(function(self46113382) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2223],0,arguments);
}
var anf_arg346513380 = G(self46113382,"l",L[2223]);
var $z1337213373 = D;
var $f1337813379 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg346513380):R.ffi.throwNonFunApp(L[2223],torepr65,[anf_arg346513380]);
};
try {
if(--R.GAS > 0) {
$z1337213373 = $f1337813379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1337813379,
"from":L[2223]});
}
} catch($e1337013371) {
if(R.isCont($e1337013371)) {
var $ss1337413375 = {"from":L[2223],
"go":function(anf_arg346613381) {
return $Hanf_arg963613383(anf_arg346613381,self46113382,_plus55,torepr65);
}};
$e1337013371.stack[R.EXN_STACKHEIGHT++] = $ss1337413375;
}
if(R.isPyretException($e1337013371)) {
$e1337013371.pyretStack.push(L[2223]);
}
throw $e1337013371;
}
var $ret1337613377 = $Hanf_arg963613383($z1337213373,self46113382,_plus55,torepr65);
++R.GAS;
return $ret1337613377;
};
},{"length":1});
var anf_variant_member347512616 = R.makeMethod(function(self92113369) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2605],0,arguments);
}
var ann_DASH_check_DASH_temp347413368 = ("s-str");
return ann_DASH_check_DASH_temp347413368;
};
},{"length":1});
var anf_variant_member348012617 = R.makeMethod(function(self92213367) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2604],0,arguments);
}
var anf_fun347713365 = G(PP170,"str",L[2603]);
var anf_arg347813363 = G(self92213367,"s",L[2602]);
var $z1335513356 = D;
var $f1336113362 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg347813363):R.ffi.throwNonFunApp(L[2601],torepr65,[anf_arg347813363]);
};
try {
if(--R.GAS > 0) {
$z1335513356 = $f1336113362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1336113362,
"from":L[2601]});
}
} catch($e1335313354) {
if(R.isCont($e1335313354)) {
var $ss1335713358 = {"from":L[2601],
"go":function(anf_arg347913364) {
return $Hanf_arg963813366(anf_arg347913364,anf_fun347713365);
}};
$e1335313354.stack[R.EXN_STACKHEIGHT++] = $ss1335713358;
}
if(R.isPyretException($e1335313354)) {
$e1335313354.pyretStack.push(L[2601]);
}
throw $e1335313354;
}
var $ret1335913360 = $Hanf_arg963813366($z1335513356,anf_fun347713365);
++R.GAS;
return $ret1335913360;
};
},{"length":1});
var anf_variant_member349412625 = R.makeMethod(function(self46413331) {
return function(cases_DASH_funs46513332,else_DASH_clause46613343) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2222],2,arguments);
}
var if_DASH_46813346 = R.hasField(cases_DASH_funs46513332,("s-dot"));
var if_helper348213329 = R.makeFunction(function(if_helper_arg348313351) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2222],1,arguments);
}
var ann_DASH_check_DASH_temp348113352 = if_helper_arg348313351;
return ann_DASH_check_DASH_temp348113352;
});
var anf_if348613350 = R.isBoolean(if_DASH_46813346);
if(R.isPyretTrue(anf_if348613350)) {
if(R.isPyretTrue(if_DASH_46813346)) {
var call_DASH_s_DASH_dot46313324 = G(cases_DASH_funs46513332,"s-dot",L[2222]);
var anf_arg348913325 = G(self46413331,"l",L[2600]);
var anf_arg349013326 = G(self46413331,"obj",L[2599]);
var anf_arg349113327 = G(self46413331,"field",L[2598]);
var $z1331613317 = D;
var $f1332213323 = function(_) {
return R.isFunction(call_DASH_s_DASH_dot46313324)?call_DASH_s_DASH_dot46313324.app(anf_arg348913325,anf_arg349013326,anf_arg349113327):R.ffi.throwNonFunApp(L[2222],call_DASH_s_DASH_dot46313324,[anf_arg348913325,anf_arg349013326,anf_arg349113327]);
};
try {
if(--R.GAS > 0) {
$z1331613317 = $f1332213323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1332213323,
"from":L[2222]});
}
} catch($e1331413315) {
if(R.isCont($e1331413315)) {
var $ss1331813319 = {"from":L[2222],
"go":function(cont_tail_arg349213328) {
return $Hcont_tail_arg963913330(cont_tail_arg349213328,if_helper348213329);
}};
$e1331413315.stack[R.EXN_STACKHEIGHT++] = $ss1331813319;
}
if(R.isPyretException($e1331413315)) {
$e1331413315.pyretStack.push(L[2222]);
}
throw $e1331413315;
}
var $ret1332013321 = $Hcont_tail_arg963913330($z1331613317,if_helper348213329);
++R.GAS;
return $ret1332013321;
} else {
var $z1333513336 = D;
var $f1334113342 = function(_) {
return R.isFunction(else_DASH_clause46613343)?else_DASH_clause46613343.app():R.ffi.throwNonFunApp(L[2222],else_DASH_clause46613343,[]);
};
try {
if(--R.GAS > 0) {
$z1333513336 = $f1334113342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1334113342,
"from":L[2222]});
}
} catch($e1333313334) {
if(R.isCont($e1333313334)) {
var $ss1333713338 = {"from":L[2222],
"go":function(cont_tail_arg348713344) {
return $Hcont_tail_arg964013345(cont_tail_arg348713344,if_helper348213329);
}};
$e1333313334.stack[R.EXN_STACKHEIGHT++] = $ss1333713338;
}
if(R.isPyretException($e1333313334)) {
$e1333313334.pyretStack.push(L[2222]);
}
throw $e1333313334;
}
var $ret1333913340 = $Hcont_tail_arg964013345($z1333513336,if_helper348213329);
++R.GAS;
return $ret1333913340;
}
} else {
var cont_tail_arg348413349 = R.throwNonBooleanCondition(L[2222],("if"),if_DASH_46813346);
if(--R.GAS > 0) {
$z1334713348 = R.isFunction(if_helper348213329)?if_helper348213329.app(cont_tail_arg348413349):R.ffi.throwNonFunApp(L[2222],if_helper348213329,[cont_tail_arg348413349]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper348213329)?if_helper348213329.app(cont_tail_arg348413349):R.ffi.throwNonFunApp(L[2222],if_helper348213329,[cont_tail_arg348413349]);
},
"from":L[2222]});
}
++R.GAS;
return $z1334713348;
}
};
},{"length":3});
var anf_variant_member350812626 = R.makeMethod(function(self46713312) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2222],0,arguments);
}
var anf_arg349613310 = G(self46713312,"l",L[2222]);
var $z1330213303 = D;
var $f1330813309 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg349613310):R.ffi.throwNonFunApp(L[2222],torepr65,[anf_arg349613310]);
};
try {
if(--R.GAS > 0) {
$z1330213303 = $f1330813309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1330813309,
"from":L[2222]});
}
} catch($e1330013301) {
if(R.isCont($e1330013301)) {
var $ss1330413305 = {"from":L[2222],
"go":function(anf_arg349713311) {
return $Hanf_arg965013313(anf_arg349713311,self46713312,_plus55,torepr65);
}};
$e1330013301.stack[R.EXN_STACKHEIGHT++] = $ss1330413305;
}
if(R.isPyretException($e1330013301)) {
$e1330013301.pyretStack.push(L[2222]);
}
throw $e1330013301;
}
var $ret1330613307 = $Hanf_arg965013313($z1330213303,self46713312,_plus55,torepr65);
++R.GAS;
return $ret1330613307;
};
},{"length":1});
var anf_variant_member351012627 = R.makeMethod(function(self92613299) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2597],0,arguments);
}
var ann_DASH_check_DASH_temp350913298 = ("s-dot");
return ann_DASH_check_DASH_temp350913298;
};
},{"length":1});
var anf_variant_member351912628 = R.makeMethod(function(self92713295) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2596],0,arguments);
}
var anf_fun351213294 = G(PP170,"infix-break",L[2595]);
var anf_bracket351313297 = G(self92713295,"obj",L[2594]);
var anf_fun351413292 = G(anf_bracket351313297,"tosource",L[2593]);
var $z1328413285 = D;
var $f1329013291 = function(_) {
return R.isFunction(anf_fun351413292)?anf_fun351413292.app():R.ffi.throwNonFunApp(L[2592],anf_fun351413292,[]);
};
try {
if(--R.GAS > 0) {
$z1328413285 = $f1329013291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1329013291,
"from":L[2592]});
}
} catch($e1328213283) {
if(R.isCont($e1328213283)) {
var $ss1328613287 = {"from":L[2592],
"go":function(anf_arg351513293) {
return $Hanf_arg965313296(anf_arg351513293,INDENT118169,PP170,anf_fun351213294,self92713295,str_DASH_period160702);
}};
$e1328213283.stack[R.EXN_STACKHEIGHT++] = $ss1328613287;
}
if(R.isPyretException($e1328213283)) {
$e1328213283.pyretStack.push(L[2592]);
}
throw $e1328213283;
}
var $ret1328813289 = $Hanf_arg965313296($z1328413285,INDENT118169,PP170,anf_fun351213294,self92713295,str_DASH_period160702);
++R.GAS;
return $ret1328813289;
};
},{"length":1});
var anf_variant_member353312637 = R.makeMethod(function(self47013260) {
return function(cases_DASH_funs47113261,else_DASH_clause47213272) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2221],2,arguments);
}
var if_DASH_47413275 = R.hasField(cases_DASH_funs47113261,("s-get-bang"));
var if_helper352113258 = R.makeFunction(function(if_helper_arg352213280) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2221],1,arguments);
}
var ann_DASH_check_DASH_temp352013281 = if_helper_arg352213280;
return ann_DASH_check_DASH_temp352013281;
});
var anf_if352513279 = R.isBoolean(if_DASH_47413275);
if(R.isPyretTrue(anf_if352513279)) {
if(R.isPyretTrue(if_DASH_47413275)) {
var call_DASH_s_DASH_get_DASH_bang46913253 = G(cases_DASH_funs47113261,"s-get-bang",L[2221]);
var anf_arg352813254 = G(self47013260,"l",L[2591]);
var anf_arg352913255 = G(self47013260,"obj",L[2590]);
var anf_arg353013256 = G(self47013260,"field",L[2589]);
var $z1324513246 = D;
var $f1325113252 = function(_) {
return R.isFunction(call_DASH_s_DASH_get_DASH_bang46913253)?call_DASH_s_DASH_get_DASH_bang46913253.app(anf_arg352813254,anf_arg352913255,anf_arg353013256):R.ffi.throwNonFunApp(L[2221],call_DASH_s_DASH_get_DASH_bang46913253,[anf_arg352813254,anf_arg352913255,anf_arg353013256]);
};
try {
if(--R.GAS > 0) {
$z1324513246 = $f1325113252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1325113252,
"from":L[2221]});
}
} catch($e1324313244) {
if(R.isCont($e1324313244)) {
var $ss1324713248 = {"from":L[2221],
"go":function(cont_tail_arg353113257) {
return $Hcont_tail_arg965413259(cont_tail_arg353113257,if_helper352113258);
}};
$e1324313244.stack[R.EXN_STACKHEIGHT++] = $ss1324713248;
}
if(R.isPyretException($e1324313244)) {
$e1324313244.pyretStack.push(L[2221]);
}
throw $e1324313244;
}
var $ret1324913250 = $Hcont_tail_arg965413259($z1324513246,if_helper352113258);
++R.GAS;
return $ret1324913250;
} else {
var $z1326413265 = D;
var $f1327013271 = function(_) {
return R.isFunction(else_DASH_clause47213272)?else_DASH_clause47213272.app():R.ffi.throwNonFunApp(L[2221],else_DASH_clause47213272,[]);
};
try {
if(--R.GAS > 0) {
$z1326413265 = $f1327013271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1327013271,
"from":L[2221]});
}
} catch($e1326213263) {
if(R.isCont($e1326213263)) {
var $ss1326613267 = {"from":L[2221],
"go":function(cont_tail_arg352613273) {
return $Hcont_tail_arg965513274(cont_tail_arg352613273,if_helper352113258);
}};
$e1326213263.stack[R.EXN_STACKHEIGHT++] = $ss1326613267;
}
if(R.isPyretException($e1326213263)) {
$e1326213263.pyretStack.push(L[2221]);
}
throw $e1326213263;
}
var $ret1326813269 = $Hcont_tail_arg965513274($z1326413265,if_helper352113258);
++R.GAS;
return $ret1326813269;
}
} else {
var cont_tail_arg352313278 = R.throwNonBooleanCondition(L[2221],("if"),if_DASH_47413275);
if(--R.GAS > 0) {
$z1327613277 = R.isFunction(if_helper352113258)?if_helper352113258.app(cont_tail_arg352313278):R.ffi.throwNonFunApp(L[2221],if_helper352113258,[cont_tail_arg352313278]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper352113258)?if_helper352113258.app(cont_tail_arg352313278):R.ffi.throwNonFunApp(L[2221],if_helper352113258,[cont_tail_arg352313278]);
},
"from":L[2221]});
}
++R.GAS;
return $z1327613277;
}
};
},{"length":3});
var anf_variant_member354712638 = R.makeMethod(function(self47313241) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2221],0,arguments);
}
var anf_arg353513239 = G(self47313241,"l",L[2221]);
var $z1323113232 = D;
var $f1323713238 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg353513239):R.ffi.throwNonFunApp(L[2221],torepr65,[anf_arg353513239]);
};
try {
if(--R.GAS > 0) {
$z1323113232 = $f1323713238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1323713238,
"from":L[2221]});
}
} catch($e1322913230) {
if(R.isCont($e1322913230)) {
var $ss1323313234 = {"from":L[2221],
"go":function(anf_arg353613240) {
return $Hanf_arg966513242(anf_arg353613240,self47313241,_plus55,torepr65);
}};
$e1322913230.stack[R.EXN_STACKHEIGHT++] = $ss1323313234;
}
if(R.isPyretException($e1322913230)) {
$e1322913230.pyretStack.push(L[2221]);
}
throw $e1322913230;
}
var $ret1323513236 = $Hanf_arg966513242($z1323113232,self47313241,_plus55,torepr65);
++R.GAS;
return $ret1323513236;
};
},{"length":1});
var anf_variant_member354912639 = R.makeMethod(function(self93113228) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2588],0,arguments);
}
var ann_DASH_check_DASH_temp354813227 = ("s-get-bang");
return ann_DASH_check_DASH_temp354813227;
};
},{"length":1});
var anf_variant_member355812640 = R.makeMethod(function(self93213224) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2587],0,arguments);
}
var anf_fun355113223 = G(PP170,"infix-break",L[2586]);
var anf_bracket355213226 = G(self93213224,"obj",L[2585]);
var anf_fun355313221 = G(anf_bracket355213226,"tosource",L[2584]);
var $z1321313214 = D;
var $f1321913220 = function(_) {
return R.isFunction(anf_fun355313221)?anf_fun355313221.app():R.ffi.throwNonFunApp(L[2583],anf_fun355313221,[]);
};
try {
if(--R.GAS > 0) {
$z1321313214 = $f1321913220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1321913220,
"from":L[2583]});
}
} catch($e1321113212) {
if(R.isCont($e1321113212)) {
var $ss1321513216 = {"from":L[2583],
"go":function(anf_arg355413222) {
return $Hanf_arg966813225(anf_arg355413222,INDENT118169,PP170,anf_fun355113223,self93213224,str_DASH_bang161715);
}};
$e1321113212.stack[R.EXN_STACKHEIGHT++] = $ss1321513216;
}
if(R.isPyretException($e1321113212)) {
$e1321113212.pyretStack.push(L[2583]);
}
throw $e1321113212;
}
var $ret1321713218 = $Hanf_arg966813225($z1321313214,INDENT118169,PP170,anf_fun355113223,self93213224,str_DASH_bang161715);
++R.GAS;
return $ret1321713218;
};
},{"length":1});
var anf_variant_member357212649 = R.makeMethod(function(self47613189) {
return function(cases_DASH_funs47713190,else_DASH_clause47813201) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2220],2,arguments);
}
var if_DASH_48013204 = R.hasField(cases_DASH_funs47713190,("s-bracket"));
var if_helper356013187 = R.makeFunction(function(if_helper_arg356113209) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2220],1,arguments);
}
var ann_DASH_check_DASH_temp355913210 = if_helper_arg356113209;
return ann_DASH_check_DASH_temp355913210;
});
var anf_if356413208 = R.isBoolean(if_DASH_48013204);
if(R.isPyretTrue(anf_if356413208)) {
if(R.isPyretTrue(if_DASH_48013204)) {
var call_DASH_s_DASH_bracket47513182 = G(cases_DASH_funs47713190,"s-bracket",L[2220]);
var anf_arg356713183 = G(self47613189,"l",L[2582]);
var anf_arg356813184 = G(self47613189,"obj",L[2581]);
var anf_arg356913185 = G(self47613189,"field",L[2580]);
var $z1317413175 = D;
var $f1318013181 = function(_) {
return R.isFunction(call_DASH_s_DASH_bracket47513182)?call_DASH_s_DASH_bracket47513182.app(anf_arg356713183,anf_arg356813184,anf_arg356913185):R.ffi.throwNonFunApp(L[2220],call_DASH_s_DASH_bracket47513182,[anf_arg356713183,anf_arg356813184,anf_arg356913185]);
};
try {
if(--R.GAS > 0) {
$z1317413175 = $f1318013181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1318013181,
"from":L[2220]});
}
} catch($e1317213173) {
if(R.isCont($e1317213173)) {
var $ss1317613177 = {"from":L[2220],
"go":function(cont_tail_arg357013186) {
return $Hcont_tail_arg966913188(cont_tail_arg357013186,if_helper356013187);
}};
$e1317213173.stack[R.EXN_STACKHEIGHT++] = $ss1317613177;
}
if(R.isPyretException($e1317213173)) {
$e1317213173.pyretStack.push(L[2220]);
}
throw $e1317213173;
}
var $ret1317813179 = $Hcont_tail_arg966913188($z1317413175,if_helper356013187);
++R.GAS;
return $ret1317813179;
} else {
var $z1319313194 = D;
var $f1319913200 = function(_) {
return R.isFunction(else_DASH_clause47813201)?else_DASH_clause47813201.app():R.ffi.throwNonFunApp(L[2220],else_DASH_clause47813201,[]);
};
try {
if(--R.GAS > 0) {
$z1319313194 = $f1319913200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1319913200,
"from":L[2220]});
}
} catch($e1319113192) {
if(R.isCont($e1319113192)) {
var $ss1319513196 = {"from":L[2220],
"go":function(cont_tail_arg356513202) {
return $Hcont_tail_arg967013203(cont_tail_arg356513202,if_helper356013187);
}};
$e1319113192.stack[R.EXN_STACKHEIGHT++] = $ss1319513196;
}
if(R.isPyretException($e1319113192)) {
$e1319113192.pyretStack.push(L[2220]);
}
throw $e1319113192;
}
var $ret1319713198 = $Hcont_tail_arg967013203($z1319313194,if_helper356013187);
++R.GAS;
return $ret1319713198;
}
} else {
var cont_tail_arg356213207 = R.throwNonBooleanCondition(L[2220],("if"),if_DASH_48013204);
if(--R.GAS > 0) {
$z1320513206 = R.isFunction(if_helper356013187)?if_helper356013187.app(cont_tail_arg356213207):R.ffi.throwNonFunApp(L[2220],if_helper356013187,[cont_tail_arg356213207]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper356013187)?if_helper356013187.app(cont_tail_arg356213207):R.ffi.throwNonFunApp(L[2220],if_helper356013187,[cont_tail_arg356213207]);
},
"from":L[2220]});
}
++R.GAS;
return $z1320513206;
}
};
},{"length":3});
var anf_variant_member358612650 = R.makeMethod(function(self47913170) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2220],0,arguments);
}
var anf_arg357413168 = G(self47913170,"l",L[2220]);
var $z1316013161 = D;
var $f1316613167 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg357413168):R.ffi.throwNonFunApp(L[2220],torepr65,[anf_arg357413168]);
};
try {
if(--R.GAS > 0) {
$z1316013161 = $f1316613167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1316613167,
"from":L[2220]});
}
} catch($e1315813159) {
if(R.isCont($e1315813159)) {
var $ss1316213163 = {"from":L[2220],
"go":function(anf_arg357513169) {
return $Hanf_arg968013171(anf_arg357513169,self47913170,_plus55,torepr65);
}};
$e1315813159.stack[R.EXN_STACKHEIGHT++] = $ss1316213163;
}
if(R.isPyretException($e1315813159)) {
$e1315813159.pyretStack.push(L[2220]);
}
throw $e1315813159;
}
var $ret1316413165 = $Hanf_arg968013171($z1316013161,self47913170,_plus55,torepr65);
++R.GAS;
return $ret1316413165;
};
},{"length":1});
var anf_variant_member358812651 = R.makeMethod(function(self93613157) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2579],0,arguments);
}
var ann_DASH_check_DASH_temp358713156 = ("s-bracket");
return ann_DASH_check_DASH_temp358713156;
};
},{"length":1});
var anf_variant_member360112652 = R.makeMethod(function(self93713153) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2578],0,arguments);
}
var anf_fun359013152 = G(PP170,"infix-break",L[2577]);
var anf_bracket359113155 = G(self93713153,"obj",L[2576]);
var anf_fun359213150 = G(anf_bracket359113155,"tosource",L[2575]);
var $z1314213143 = D;
var $f1314813149 = function(_) {
return R.isFunction(anf_fun359213150)?anf_fun359213150.app():R.ffi.throwNonFunApp(L[2574],anf_fun359213150,[]);
};
try {
if(--R.GAS > 0) {
$z1314213143 = $f1314813149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1314813149,
"from":L[2574]});
}
} catch($e1314013141) {
if(R.isCont($e1314013141)) {
var $ss1314413145 = {"from":L[2574],
"go":function(anf_arg359313151) {
return $Hanf_arg968413154(anf_arg359313151,INDENT118169,PP170,anf_fun359013152,self93713153,str_DASH_period160702);
}};
$e1314013141.stack[R.EXN_STACKHEIGHT++] = $ss1314413145;
}
if(R.isPyretException($e1314013141)) {
$e1314013141.pyretStack.push(L[2574]);
}
throw $e1314013141;
}
var $ret1314613147 = $Hanf_arg968413154($z1314213143,INDENT118169,PP170,anf_fun359013152,self93713153,str_DASH_period160702);
++R.GAS;
return $ret1314613147;
};
},{"length":1});
var anf_variant_member361912661 = R.makeMethod(function(self48213118) {
return function(cases_DASH_funs48313119,else_DASH_clause48413130) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2219],2,arguments);
}
var if_DASH_48613133 = R.hasField(cases_DASH_funs48313119,("s-data"));
var if_helper360313116 = R.makeFunction(function(if_helper_arg360413138) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2219],1,arguments);
}
var ann_DASH_check_DASH_temp360213139 = if_helper_arg360413138;
return ann_DASH_check_DASH_temp360213139;
});
var anf_if360713137 = R.isBoolean(if_DASH_48613133);
if(R.isPyretTrue(anf_if360713137)) {
if(R.isPyretTrue(if_DASH_48613133)) {
var call_DASH_s_DASH_data48113107 = G(cases_DASH_funs48313119,"s-data",L[2219]);
var anf_arg361013108 = G(self48213118,"l",L[2573]);
var anf_arg361113109 = G(self48213118,"name",L[2572]);
var anf_arg361213110 = G(self48213118,"params",L[2571]);
var anf_arg361313111 = G(self48213118,"mixins",L[2570]);
var anf_arg361413112 = G(self48213118,"variants",L[2569]);
var anf_arg361513113 = G(self48213118,"shared-members",L[2568]);
var anf_arg361613114 = G(self48213118,"_check",L[2567]);
var $z1309913100 = D;
var $f1310513106 = function(_) {
return R.isFunction(call_DASH_s_DASH_data48113107)?call_DASH_s_DASH_data48113107.app(anf_arg361013108,anf_arg361113109,anf_arg361213110,anf_arg361313111,anf_arg361413112,anf_arg361513113,anf_arg361613114):R.ffi.throwNonFunApp(L[2219],call_DASH_s_DASH_data48113107,[anf_arg361013108,anf_arg361113109,anf_arg361213110,anf_arg361313111,anf_arg361413112,anf_arg361513113,anf_arg361613114]);
};
try {
if(--R.GAS > 0) {
$z1309913100 = $f1310513106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1310513106,
"from":L[2219]});
}
} catch($e1309713098) {
if(R.isCont($e1309713098)) {
var $ss1310113102 = {"from":L[2219],
"go":function(cont_tail_arg361713115) {
return $Hcont_tail_arg968513117(cont_tail_arg361713115,if_helper360313116);
}};
$e1309713098.stack[R.EXN_STACKHEIGHT++] = $ss1310113102;
}
if(R.isPyretException($e1309713098)) {
$e1309713098.pyretStack.push(L[2219]);
}
throw $e1309713098;
}
var $ret1310313104 = $Hcont_tail_arg968513117($z1309913100,if_helper360313116);
++R.GAS;
return $ret1310313104;
} else {
var $z1312213123 = D;
var $f1312813129 = function(_) {
return R.isFunction(else_DASH_clause48413130)?else_DASH_clause48413130.app():R.ffi.throwNonFunApp(L[2219],else_DASH_clause48413130,[]);
};
try {
if(--R.GAS > 0) {
$z1312213123 = $f1312813129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1312813129,
"from":L[2219]});
}
} catch($e1312013121) {
if(R.isCont($e1312013121)) {
var $ss1312413125 = {"from":L[2219],
"go":function(cont_tail_arg360813131) {
return $Hcont_tail_arg968613132(cont_tail_arg360813131,if_helper360313116);
}};
$e1312013121.stack[R.EXN_STACKHEIGHT++] = $ss1312413125;
}
if(R.isPyretException($e1312013121)) {
$e1312013121.pyretStack.push(L[2219]);
}
throw $e1312013121;
}
var $ret1312613127 = $Hcont_tail_arg968613132($z1312213123,if_helper360313116);
++R.GAS;
return $ret1312613127;
}
} else {
var cont_tail_arg360513136 = R.throwNonBooleanCondition(L[2219],("if"),if_DASH_48613133);
if(--R.GAS > 0) {
$z1313413135 = R.isFunction(if_helper360313116)?if_helper360313116.app(cont_tail_arg360513136):R.ffi.throwNonFunApp(L[2219],if_helper360313116,[cont_tail_arg360513136]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper360313116)?if_helper360313116.app(cont_tail_arg360513136):R.ffi.throwNonFunApp(L[2219],if_helper360313116,[cont_tail_arg360513136]);
},
"from":L[2219]});
}
++R.GAS;
return $z1313413135;
}
};
},{"length":3});
var anf_variant_member364912662 = R.makeMethod(function(self48513095) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2219],0,arguments);
}
var anf_arg362113093 = G(self48513095,"l",L[2219]);
var $z1308513086 = D;
var $f1309113092 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg362113093):R.ffi.throwNonFunApp(L[2219],torepr65,[anf_arg362113093]);
};
try {
if(--R.GAS > 0) {
$z1308513086 = $f1309113092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1309113092,
"from":L[2219]});
}
} catch($e1308313084) {
if(R.isCont($e1308313084)) {
var $ss1308713088 = {"from":L[2219],
"go":function(anf_arg362213094) {
return $Hanf_arg970813096(anf_arg362213094,self48513095,_plus55,torepr65);
}};
$e1308313084.stack[R.EXN_STACKHEIGHT++] = $ss1308713088;
}
if(R.isPyretException($e1308313084)) {
$e1308313084.pyretStack.push(L[2219]);
}
throw $e1308313084;
}
var $ret1308913090 = $Hanf_arg970813096($z1308513086,self48513095,_plus55,torepr65);
++R.GAS;
return $ret1308913090;
};
},{"length":1});
var anf_variant_member365112663 = R.makeMethod(function(self94513082) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2566],0,arguments);
}
var ann_DASH_check_DASH_temp365013081 = ("s-data");
return ann_DASH_check_DASH_temp365013081;
};
},{"length":1});
var anf_variant_member374012664 = R.makeMethod(function(self94613064) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2565],0,arguments);
}
var optional_DASH_section94713050 = {"$var":D,
"$name":"optional-section"};
var anf_assign367013051 = R.makeFunction(function(lbl94813066,section94913067) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2562],2,arguments);
}
var anf_fun365413078 = G(PP170,"is-mt-doc",L[2564]);
var $z1307013071 = D;
var $f1307613077 = function(_) {
return R.isFunction(anf_fun365413078)?anf_fun365413078.app(section94913067):R.ffi.throwNonFunApp(L[2563],anf_fun365413078,[section94913067]);
};
try {
if(--R.GAS > 0) {
$z1307013071 = $f1307613077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1307613077,
"from":L[2563]});
}
} catch($e1306813069) {
if(R.isCont($e1306813069)) {
var $ss1307213073 = {"from":L[2563],
"go":function(if_DASH_48713079) {
return $Hif_DASH_971413080(if_DASH_48713079,INDENT118169,PP170,break_DASH_one119168,lbl94813066,section94913067,_plus55);
}};
$e1306813069.stack[R.EXN_STACKHEIGHT++] = $ss1307213073;
}
if(R.isPyretException($e1306813069)) {
$e1306813069.pyretStack.push(L[2563]);
}
throw $e1306813069;
}
var $ret1307413075 = $Hif_DASH_971413080($z1307013071,INDENT118169,PP170,break_DASH_one119168,lbl94813066,section94913067,_plus55);
++R.GAS;
return $ret1307413075;
});
optional_DASH_section94713050.$var = anf_assign367013051;
var anf_fun367113063 = G(PP170,"surround-separate",L[2561]);
var $z1305413055 = D;
var $f1306013061 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[2560],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z1305413055 = $f1306013061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1306013061,
"from":L[2560]});
}
} catch($e1305213053) {
if(R.isCont($e1305213053)) {
var $ss1305613057 = {"from":L[2560],
"go":function(anf_arg367213062) {
return $Hanf_arg974813065(anf_arg367213062,INDENT118169,PP170,anf_fun367113063,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e1305213053.stack[R.EXN_STACKHEIGHT++] = $ss1305613057;
}
if(R.isPyretException($e1305213053)) {
$e1305213053.pyretStack.push(L[2560]);
}
throw $e1305213053;
}
var $ret1305813059 = $Hanf_arg974813065($z1305413055,INDENT118169,PP170,anf_fun367113063,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret1305813059;
};
},{"length":1});
var anf_variant_member375912677 = R.makeMethod(function(self49213028) {
return function(cases_DASH_funs49313029,else_DASH_clause49413040) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2218],2,arguments);
}
var if_DASH_49613043 = R.hasField(cases_DASH_funs49313029,("s-data-expr"));
var if_helper374213026 = R.makeFunction(function(if_helper_arg374313048) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2218],1,arguments);
}
var ann_DASH_check_DASH_temp374113049 = if_helper_arg374313048;
return ann_DASH_check_DASH_temp374113049;
});
var anf_if374613047 = R.isBoolean(if_DASH_49613043);
if(R.isPyretTrue(anf_if374613047)) {
if(R.isPyretTrue(if_DASH_49613043)) {
var call_DASH_s_DASH_data_DASH_expr49113016 = G(cases_DASH_funs49313029,"s-data-expr",L[2218]);
var anf_arg374913017 = G(self49213028,"l",L[2559]);
var anf_arg375013018 = G(self49213028,"name",L[2558]);
var anf_arg375113019 = G(self49213028,"namet",L[2557]);
var anf_arg375213020 = G(self49213028,"params",L[2556]);
var anf_arg375313021 = G(self49213028,"mixins",L[2555]);
var anf_arg375413022 = G(self49213028,"variants",L[2554]);
var anf_arg375513023 = G(self49213028,"shared-members",L[2553]);
var anf_arg375613024 = G(self49213028,"_check",L[2552]);
var $z1300813009 = D;
var $f1301413015 = function(_) {
return R.isFunction(call_DASH_s_DASH_data_DASH_expr49113016)?call_DASH_s_DASH_data_DASH_expr49113016.app(anf_arg374913017,anf_arg375013018,anf_arg375113019,anf_arg375213020,anf_arg375313021,anf_arg375413022,anf_arg375513023,anf_arg375613024):R.ffi.throwNonFunApp(L[2218],call_DASH_s_DASH_data_DASH_expr49113016,[anf_arg374913017,anf_arg375013018,anf_arg375113019,anf_arg375213020,anf_arg375313021,anf_arg375413022,anf_arg375513023,anf_arg375613024]);
};
try {
if(--R.GAS > 0) {
$z1300813009 = $f1301413015();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1301413015,
"from":L[2218]});
}
} catch($e1300613007) {
if(R.isCont($e1300613007)) {
var $ss1301013011 = {"from":L[2218],
"go":function(cont_tail_arg375713025) {
return $Hcont_tail_arg974913027(cont_tail_arg375713025,if_helper374213026);
}};
$e1300613007.stack[R.EXN_STACKHEIGHT++] = $ss1301013011;
}
if(R.isPyretException($e1300613007)) {
$e1300613007.pyretStack.push(L[2218]);
}
throw $e1300613007;
}
var $ret1301213013 = $Hcont_tail_arg974913027($z1300813009,if_helper374213026);
++R.GAS;
return $ret1301213013;
} else {
var $z1303213033 = D;
var $f1303813039 = function(_) {
return R.isFunction(else_DASH_clause49413040)?else_DASH_clause49413040.app():R.ffi.throwNonFunApp(L[2218],else_DASH_clause49413040,[]);
};
try {
if(--R.GAS > 0) {
$z1303213033 = $f1303813039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1303813039,
"from":L[2218]});
}
} catch($e1303013031) {
if(R.isCont($e1303013031)) {
var $ss1303413035 = {"from":L[2218],
"go":function(cont_tail_arg374713041) {
return $Hcont_tail_arg975013042(cont_tail_arg374713041,if_helper374213026);
}};
$e1303013031.stack[R.EXN_STACKHEIGHT++] = $ss1303413035;
}
if(R.isPyretException($e1303013031)) {
$e1303013031.pyretStack.push(L[2218]);
}
throw $e1303013031;
}
var $ret1303613037 = $Hcont_tail_arg975013042($z1303213033,if_helper374213026);
++R.GAS;
return $ret1303613037;
}
} else {
var cont_tail_arg374413046 = R.throwNonBooleanCondition(L[2218],("if"),if_DASH_49613043);
if(--R.GAS > 0) {
$z1304413045 = R.isFunction(if_helper374213026)?if_helper374213026.app(cont_tail_arg374413046):R.ffi.throwNonFunApp(L[2218],if_helper374213026,[cont_tail_arg374413046]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper374213026)?if_helper374213026.app(cont_tail_arg374413046):R.ffi.throwNonFunApp(L[2218],if_helper374213026,[cont_tail_arg374413046]);
},
"from":L[2218]});
}
++R.GAS;
return $z1304413045;
}
};
},{"length":3});
var anf_variant_member379312678 = R.makeMethod(function(self49513004) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2218],0,arguments);
}
var anf_arg376113002 = G(self49513004,"l",L[2218]);
var $z1299412995 = D;
var $f1300013001 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg376113002):R.ffi.throwNonFunApp(L[2218],torepr65,[anf_arg376113002]);
};
try {
if(--R.GAS > 0) {
$z1299412995 = $f1300013001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1300013001,
"from":L[2218]});
}
} catch($e1299212993) {
if(R.isCont($e1299212993)) {
var $ss1299612997 = {"from":L[2218],
"go":function(anf_arg376213003) {
return $Hanf_arg977513005(anf_arg376213003,self49513004,_plus55,torepr65);
}};
$e1299212993.stack[R.EXN_STACKHEIGHT++] = $ss1299612997;
}
if(R.isPyretException($e1299212993)) {
$e1299212993.pyretStack.push(L[2218]);
}
throw $e1299212993;
}
var $ret1299812999 = $Hanf_arg977513005($z1299412995,self49513004,_plus55,torepr65);
++R.GAS;
return $ret1299812999;
};
},{"length":1});
var anf_variant_member379512679 = R.makeMethod(function(self96912991) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2551],0,arguments);
}
var ann_DASH_check_DASH_temp379412990 = ("s-data-expr");
return ann_DASH_check_DASH_temp379412990;
};
},{"length":1});
var anf_variant_member389012680 = R.makeMethod(function(self97012973) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2550],0,arguments);
}
var optional_DASH_section97112959 = {"$var":D,
"$name":"optional-section"};
var anf_assign381412960 = R.makeFunction(function(lbl97212975,section97312976) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2547],2,arguments);
}
var anf_fun379812987 = G(PP170,"is-mt-doc",L[2549]);
var $z1297912980 = D;
var $f1298512986 = function(_) {
return R.isFunction(anf_fun379812987)?anf_fun379812987.app(section97312976):R.ffi.throwNonFunApp(L[2548],anf_fun379812987,[section97312976]);
};
try {
if(--R.GAS > 0) {
$z1297912980 = $f1298512986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1298512986,
"from":L[2548]});
}
} catch($e1297712978) {
if(R.isCont($e1297712978)) {
var $ss1298112982 = {"from":L[2548],
"go":function(if_DASH_49712988) {
return $Hif_DASH_978112989(if_DASH_49712988,INDENT118169,PP170,break_DASH_one119168,lbl97212975,section97312976,_plus55);
}};
$e1297712978.stack[R.EXN_STACKHEIGHT++] = $ss1298112982;
}
if(R.isPyretException($e1297712978)) {
$e1297712978.pyretStack.push(L[2548]);
}
throw $e1297712978;
}
var $ret1298312984 = $Hif_DASH_978112989($z1297912980,INDENT118169,PP170,break_DASH_one119168,lbl97212975,section97312976,_plus55);
++R.GAS;
return $ret1298312984;
});
optional_DASH_section97112959.$var = anf_assign381412960;
var anf_fun381512972 = G(PP170,"surround-separate",L[2546]);
var $z1296312964 = D;
var $f1296912970 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[2545],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z1296312964 = $f1296912970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1296912970,
"from":L[2545]});
}
} catch($e1296112962) {
if(R.isCont($e1296112962)) {
var $ss1296512966 = {"from":L[2545],
"go":function(anf_arg381612971) {
return $Hanf_arg981812974(anf_arg381612971,INDENT118169,PP170,anf_fun381512972,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e1296112962.stack[R.EXN_STACKHEIGHT++] = $ss1296512966;
}
if(R.isPyretException($e1296112962)) {
$e1296112962.pyretStack.push(L[2545]);
}
throw $e1296112962;
}
var $ret1296712968 = $Hanf_arg981812974($z1296312964,INDENT118169,PP170,anf_fun381512972,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret1296712968;
};
},{"length":1});
var anf_variant_member390612694 = R.makeMethod(function(self50212937) {
return function(cases_DASH_funs50312938,else_DASH_clause50412949) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2217],2,arguments);
}
var if_DASH_50612952 = R.hasField(cases_DASH_funs50312938,("s-for"));
var if_helper389212935 = R.makeFunction(function(if_helper_arg389312957) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2217],1,arguments);
}
var ann_DASH_check_DASH_temp389112958 = if_helper_arg389312957;
return ann_DASH_check_DASH_temp389112958;
});
var anf_if389612956 = R.isBoolean(if_DASH_50612952);
if(R.isPyretTrue(anf_if389612956)) {
if(R.isPyretTrue(if_DASH_50612952)) {
var call_DASH_s_DASH_for50112928 = G(cases_DASH_funs50312938,"s-for",L[2217]);
var anf_arg389912929 = G(self50212937,"l",L[2544]);
var anf_arg390012930 = G(self50212937,"iterator",L[2543]);
var anf_arg390112931 = G(self50212937,"bindings",L[2542]);
var anf_arg390212932 = G(self50212937,"ann",L[2541]);
var anf_arg390312933 = G(self50212937,"body",L[2540]);
var $z1292012921 = D;
var $f1292612927 = function(_) {
return R.isFunction(call_DASH_s_DASH_for50112928)?call_DASH_s_DASH_for50112928.app(anf_arg389912929,anf_arg390012930,anf_arg390112931,anf_arg390212932,anf_arg390312933):R.ffi.throwNonFunApp(L[2217],call_DASH_s_DASH_for50112928,[anf_arg389912929,anf_arg390012930,anf_arg390112931,anf_arg390212932,anf_arg390312933]);
};
try {
if(--R.GAS > 0) {
$z1292012921 = $f1292612927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1292612927,
"from":L[2217]});
}
} catch($e1291812919) {
if(R.isCont($e1291812919)) {
var $ss1292212923 = {"from":L[2217],
"go":function(cont_tail_arg390412934) {
return $Hcont_tail_arg981912936(cont_tail_arg390412934,if_helper389212935);
}};
$e1291812919.stack[R.EXN_STACKHEIGHT++] = $ss1292212923;
}
if(R.isPyretException($e1291812919)) {
$e1291812919.pyretStack.push(L[2217]);
}
throw $e1291812919;
}
var $ret1292412925 = $Hcont_tail_arg981912936($z1292012921,if_helper389212935);
++R.GAS;
return $ret1292412925;
} else {
var $z1294112942 = D;
var $f1294712948 = function(_) {
return R.isFunction(else_DASH_clause50412949)?else_DASH_clause50412949.app():R.ffi.throwNonFunApp(L[2217],else_DASH_clause50412949,[]);
};
try {
if(--R.GAS > 0) {
$z1294112942 = $f1294712948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1294712948,
"from":L[2217]});
}
} catch($e1293912940) {
if(R.isCont($e1293912940)) {
var $ss1294312944 = {"from":L[2217],
"go":function(cont_tail_arg389712950) {
return $Hcont_tail_arg982012951(cont_tail_arg389712950,if_helper389212935);
}};
$e1293912940.stack[R.EXN_STACKHEIGHT++] = $ss1294312944;
}
if(R.isPyretException($e1293912940)) {
$e1293912940.pyretStack.push(L[2217]);
}
throw $e1293912940;
}
var $ret1294512946 = $Hcont_tail_arg982012951($z1294112942,if_helper389212935);
++R.GAS;
return $ret1294512946;
}
} else {
var cont_tail_arg389412955 = R.throwNonBooleanCondition(L[2217],("if"),if_DASH_50612952);
if(--R.GAS > 0) {
$z1295312954 = R.isFunction(if_helper389212935)?if_helper389212935.app(cont_tail_arg389412955):R.ffi.throwNonFunApp(L[2217],if_helper389212935,[cont_tail_arg389412955]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper389212935)?if_helper389212935.app(cont_tail_arg389412955):R.ffi.throwNonFunApp(L[2217],if_helper389212935,[cont_tail_arg389412955]);
},
"from":L[2217]});
}
++R.GAS;
return $z1295312954;
}
};
},{"length":3});
var anf_variant_member392812695 = R.makeMethod(function(self50512916) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2217],0,arguments);
}
var anf_arg390812914 = G(self50512916,"l",L[2217]);
var $z1290612907 = D;
var $f1291212913 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg390812914):R.ffi.throwNonFunApp(L[2217],torepr65,[anf_arg390812914]);
};
try {
if(--R.GAS > 0) {
$z1290612907 = $f1291212913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1291212913,
"from":L[2217]});
}
} catch($e1290412905) {
if(R.isCont($e1290412905)) {
var $ss1290812909 = {"from":L[2217],
"go":function(anf_arg390912915) {
return $Hanf_arg983612917(anf_arg390912915,self50512916,_plus55,torepr65);
}};
$e1290412905.stack[R.EXN_STACKHEIGHT++] = $ss1290812909;
}
if(R.isPyretException($e1290412905)) {
$e1290412905.pyretStack.push(L[2217]);
}
throw $e1290412905;
}
var $ret1291012911 = $Hanf_arg983612917($z1290612907,self50512916,_plus55,torepr65);
++R.GAS;
return $ret1291012911;
};
},{"length":1});
var anf_variant_member393012696 = R.makeMethod(function(self99012903) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2539],0,arguments);
}
var ann_DASH_check_DASH_temp392912902 = ("s-for");
return ann_DASH_check_DASH_temp392912902;
};
},{"length":1});
var anf_variant_member397012697 = R.makeMethod(function(self99112899) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2538],0,arguments);
}
var anf_fun393212898 = G(PP170,"group",L[2537]);
var anf_bracket393312901 = G(self99112899,"iterator",L[2536]);
var anf_fun393412896 = G(anf_bracket393312901,"tosource",L[2535]);
var $z1288812889 = D;
var $f1289412895 = function(_) {
return R.isFunction(anf_fun393412896)?anf_fun393412896.app():R.ffi.throwNonFunApp(L[2534],anf_fun393412896,[]);
};
try {
if(--R.GAS > 0) {
$z1288812889 = $f1289412895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1289412895,
"from":L[2534]});
}
} catch($e1288612887) {
if(R.isCont($e1288612887)) {
var $ss1289012891 = {"from":L[2534],
"go":function(anf_arg393512897) {
return $Hanf_arg985612900(anf_arg393512897,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,str_DASH_for150572,_plus55,_times56);
}};
$e1288612887.stack[R.EXN_STACKHEIGHT++] = $ss1289012891;
}
if(R.isPyretException($e1288612887)) {
$e1288612887.pyretStack.push(L[2534]);
}
throw $e1288612887;
}
var $ret1289212893 = $Hanf_arg985612900($z1288812889,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,str_DASH_for150572,_plus55,_times56);
++R.GAS;
return $ret1289212893;
};
},{"length":1});
var anf_variant_member398512708 = R.makeMethod(function(self50812864) {
return function(cases_DASH_funs50912865,else_DASH_clause51012876) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2216],2,arguments);
}
var if_DASH_51212879 = R.hasField(cases_DASH_funs50912865,("s-check"));
var if_helper397212862 = R.makeFunction(function(if_helper_arg397312884) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2216],1,arguments);
}
var ann_DASH_check_DASH_temp397112885 = if_helper_arg397312884;
return ann_DASH_check_DASH_temp397112885;
});
var anf_if397612883 = R.isBoolean(if_DASH_51212879);
if(R.isPyretTrue(anf_if397612883)) {
if(R.isPyretTrue(if_DASH_51212879)) {
var call_DASH_s_DASH_check50712856 = G(cases_DASH_funs50912865,"s-check",L[2216]);
var anf_arg397912857 = G(self50812864,"l",L[2533]);
var anf_arg398012858 = G(self50812864,"name",L[2532]);
var anf_arg398112859 = G(self50812864,"body",L[2531]);
var anf_arg398212860 = G(self50812864,"keyword-check",L[2530]);
var $z1284812849 = D;
var $f1285412855 = function(_) {
return R.isFunction(call_DASH_s_DASH_check50712856)?call_DASH_s_DASH_check50712856.app(anf_arg397912857,anf_arg398012858,anf_arg398112859,anf_arg398212860):R.ffi.throwNonFunApp(L[2216],call_DASH_s_DASH_check50712856,[anf_arg397912857,anf_arg398012858,anf_arg398112859,anf_arg398212860]);
};
try {
if(--R.GAS > 0) {
$z1284812849 = $f1285412855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1285412855,
"from":L[2216]});
}
} catch($e1284612847) {
if(R.isCont($e1284612847)) {
var $ss1285012851 = {"from":L[2216],
"go":function(cont_tail_arg398312861) {
return $Hcont_tail_arg985712863(cont_tail_arg398312861,if_helper397212862);
}};
$e1284612847.stack[R.EXN_STACKHEIGHT++] = $ss1285012851;
}
if(R.isPyretException($e1284612847)) {
$e1284612847.pyretStack.push(L[2216]);
}
throw $e1284612847;
}
var $ret1285212853 = $Hcont_tail_arg985712863($z1284812849,if_helper397212862);
++R.GAS;
return $ret1285212853;
} else {
var $z1286812869 = D;
var $f1287412875 = function(_) {
return R.isFunction(else_DASH_clause51012876)?else_DASH_clause51012876.app():R.ffi.throwNonFunApp(L[2216],else_DASH_clause51012876,[]);
};
try {
if(--R.GAS > 0) {
$z1286812869 = $f1287412875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1287412875,
"from":L[2216]});
}
} catch($e1286612867) {
if(R.isCont($e1286612867)) {
var $ss1287012871 = {"from":L[2216],
"go":function(cont_tail_arg397712877) {
return $Hcont_tail_arg985812878(cont_tail_arg397712877,if_helper397212862);
}};
$e1286612867.stack[R.EXN_STACKHEIGHT++] = $ss1287012871;
}
if(R.isPyretException($e1286612867)) {
$e1286612867.pyretStack.push(L[2216]);
}
throw $e1286612867;
}
var $ret1287212873 = $Hcont_tail_arg985812878($z1286812869,if_helper397212862);
++R.GAS;
return $ret1287212873;
}
} else {
var cont_tail_arg397412882 = R.throwNonBooleanCondition(L[2216],("if"),if_DASH_51212879);
if(--R.GAS > 0) {
$z1288012881 = R.isFunction(if_helper397212862)?if_helper397212862.app(cont_tail_arg397412882):R.ffi.throwNonFunApp(L[2216],if_helper397212862,[cont_tail_arg397412882]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper397212862)?if_helper397212862.app(cont_tail_arg397412882):R.ffi.throwNonFunApp(L[2216],if_helper397212862,[cont_tail_arg397412882]);
},
"from":L[2216]});
}
++R.GAS;
return $z1288012881;
}
};
},{"length":3});
var anf_variant_member400312709 = R.makeMethod(function(self51112844) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2216],0,arguments);
}
var anf_arg398712842 = G(self51112844,"l",L[2216]);
var $z1283412835 = D;
var $f1284012841 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg398712842):R.ffi.throwNonFunApp(L[2216],torepr65,[anf_arg398712842]);
};
try {
if(--R.GAS > 0) {
$z1283412835 = $f1284012841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1284012841,
"from":L[2216]});
}
} catch($e1283212833) {
if(R.isCont($e1283212833)) {
var $ss1283612837 = {"from":L[2216],
"go":function(anf_arg398812843) {
return $Hanf_arg987112845(anf_arg398812843,self51112844,_plus55,torepr65);
}};
$e1283212833.stack[R.EXN_STACKHEIGHT++] = $ss1283612837;
}
if(R.isPyretException($e1283212833)) {
$e1283212833.pyretStack.push(L[2216]);
}
throw $e1283212833;
}
var $ret1283812839 = $Hanf_arg987112845($z1283412835,self51112844,_plus55,torepr65);
++R.GAS;
return $ret1283812839;
};
},{"length":1});
var anf_variant_member400512710 = R.makeMethod(function(self99812831) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2529],0,arguments);
}
var ann_DASH_check_DASH_temp400412830 = ("s-check");
return ann_DASH_check_DASH_temp400412830;
};
},{"length":1});
var anf_variant_member404512711 = R.makeMethod(function(self99912781) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2509],0,arguments);
}
var cases_DASH_val51512829 = G(self99912781,"name",L[2528]);
var anf_fun400712726 = G(cases_DASH_val51512829,"_match",L[2510]);
var anf_obj402012732 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2520],0,arguments);
}
var anf_fun400912826 = G(PP170,"surround",L[2527]);
var if_DASH_51312808 = G(self99912781,"keyword-check",L[2523]);
var if_helper401012793 = R.makeFunction(function(if_helper_arg401112813) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2523],1,arguments);
}
var anf_bracket401212828 = G(self99912781,"body",L[2526]);
var anf_fun401312824 = G(anf_bracket401212828,"tosource",L[2525]);
var $z1281612817 = D;
var $f1282212823 = function(_) {
return R.isFunction(anf_fun401312824)?anf_fun401312824.app():R.ffi.throwNonFunApp(L[2524],anf_fun401312824,[]);
};
try {
if(--R.GAS > 0) {
$z1281612817 = $f1282212823();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1282212823,
"from":L[2524]});
}
} catch($e1281412815) {
if(R.isCont($e1281412815)) {
var $ss1281812819 = {"from":L[2524],
"go":function(anf_arg401412825) {
return $Hanf_arg987312827(anf_arg401412825,INDENT118169,anf_fun400912826,if_helper_arg401112813,str_DASH_end148546);
}};
$e1281412815.stack[R.EXN_STACKHEIGHT++] = $ss1281812819;
}
if(R.isPyretException($e1281412815)) {
$e1281412815.pyretStack.push(L[2524]);
}
throw $e1281412815;
}
var $ret1282012821 = $Hanf_arg987312827($z1281612817,INDENT118169,anf_fun400912826,if_helper_arg401112813,str_DASH_end148546);
++R.GAS;
return $ret1282012821;
});
var anf_if401712812 = R.isBoolean(if_DASH_51312808);
if(R.isPyretTrue(anf_if401712812)) {
if(R.isPyretTrue(if_DASH_51312808)) {
var $z1278512786 = D;
var $f1279112792 = function(_) {
return R.isFunction(if_helper401012793)?if_helper401012793.app(str_DASH_checkcolon132338):R.ffi.throwNonFunApp(L[2521],if_helper401012793,[str_DASH_checkcolon132338]);
};
try {
if(--R.GAS > 0) {
$z1278512786 = $f1279112792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1279112792,
"from":L[2521]});
}
} catch($e1278312784) {
if(R.isCont($e1278312784)) {
var $ss1278712788 = {"from":L[2521],
"go":function(cont_tail_app401912794) {
return $Hcont_tail_app987412795(cont_tail_app401912794);
}};
$e1278312784.stack[R.EXN_STACKHEIGHT++] = $ss1278712788;
}
if(R.isPyretException($e1278312784)) {
$e1278312784.pyretStack.push(L[2521]);
}
throw $e1278312784;
}
var $ret1278912790 = $Hcont_tail_app987412795($z1278512786);
++R.GAS;
return $ret1278912790;
} else {
var $z1279812799 = D;
var $f1280412805 = function(_) {
return R.isFunction(if_helper401012793)?if_helper401012793.app(str_DASH_examplescolon133351):R.ffi.throwNonFunApp(L[2522],if_helper401012793,[str_DASH_examplescolon133351]);
};
try {
if(--R.GAS > 0) {
$z1279812799 = $f1280412805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1280412805,
"from":L[2522]});
}
} catch($e1279612797) {
if(R.isCont($e1279612797)) {
var $ss1280012801 = {"from":L[2522],
"go":function(cont_tail_app401812806) {
return $Hcont_tail_app987512807(cont_tail_app401812806);
}};
$e1279612797.stack[R.EXN_STACKHEIGHT++] = $ss1280012801;
}
if(R.isPyretException($e1279612797)) {
$e1279612797.pyretStack.push(L[2522]);
}
throw $e1279612797;
}
var $ret1280212803 = $Hcont_tail_app987512807($z1279812799);
++R.GAS;
return $ret1280212803;
}
} else {
var cont_tail_arg401512811 = R.throwNonBooleanCondition(L[2523],("if"),if_DASH_51312808);
if(--R.GAS > 0) {
$z1280912810 = R.isFunction(if_helper401012793)?if_helper401012793.app(cont_tail_arg401512811):R.ffi.throwNonFunApp(L[2523],if_helper401012793,[cont_tail_arg401512811]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper401012793)?if_helper401012793.app(cont_tail_arg401512811):R.ffi.throwNonFunApp(L[2523],if_helper401012793,[cont_tail_arg401512811]);
},
"from":L[2523]});
}
++R.GAS;
return $z1280912810;
}
});
var anf_obj404112733 = R.makeFunction(function(name100012734) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2511],1,arguments);
}
var anf_fun402212780 = G(PP170,"surround",L[2519]);
var if_DASH_51412762 = G(self99912781,"keyword-check",L[2516]);
var if_helper402312747 = R.makeFunction(function(if_helper_arg402412767) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2516],1,arguments);
}
var anf_fun402512778 = G(PP170,"dquote",L[2518]);
var $z1277012771 = D;
var $f1277612777 = function(_) {
return R.isFunction(anf_fun402512778)?anf_fun402512778.app(name100012734):R.ffi.throwNonFunApp(L[2517],anf_fun402512778,[name100012734]);
};
try {
if(--R.GAS > 0) {
$z1277012771 = $f1277612777();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1277612777,
"from":L[2517]});
}
} catch($e1276812769) {
if(R.isCont($e1276812769)) {
var $ss1277212773 = {"from":L[2517],
"go":function(anf_arg402612779) {
return $Hanf_arg988012782(anf_arg402612779,INDENT118169,anf_fun402212780,if_helper_arg402412767,self99912781,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e1276812769.stack[R.EXN_STACKHEIGHT++] = $ss1277212773;
}
if(R.isPyretException($e1276812769)) {
$e1276812769.pyretStack.push(L[2517]);
}
throw $e1276812769;
}
var $ret1277412775 = $Hanf_arg988012782($z1277012771,INDENT118169,anf_fun402212780,if_helper_arg402412767,self99912781,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret1277412775;
});
var anf_if403412766 = R.isBoolean(if_DASH_51412762);
if(R.isPyretTrue(anf_if403412766)) {
if(R.isPyretTrue(if_DASH_51412762)) {
var anf_fun403812745 = G(PP170,"str",L[2513]);
var $z1273712738 = D;
var $f1274312744 = function(_) {
return R.isFunction(anf_fun403812745)?anf_fun403812745.app(("check ")):R.ffi.throwNonFunApp(L[2512],anf_fun403812745,[("check ")]);
};
try {
if(--R.GAS > 0) {
$z1273712738 = $f1274312744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1274312744,
"from":L[2512]});
}
} catch($e1273512736) {
if(R.isCont($e1273512736)) {
var $ss1273912740 = {"from":L[2512],
"go":function(cont_tail_arg403912746) {
return $Hcont_tail_arg988112748(cont_tail_arg403912746,if_helper402312747);
}};
$e1273512736.stack[R.EXN_STACKHEIGHT++] = $ss1273912740;
}
if(R.isPyretException($e1273512736)) {
$e1273512736.pyretStack.push(L[2512]);
}
throw $e1273512736;
}
var $ret1274112742 = $Hcont_tail_arg988112748($z1273712738,if_helper402312747);
++R.GAS;
return $ret1274112742;
} else {
var anf_fun403512759 = G(PP170,"str",L[2515]);
var $z1275112752 = D;
var $f1275712758 = function(_) {
return R.isFunction(anf_fun403512759)?anf_fun403512759.app(("examples ")):R.ffi.throwNonFunApp(L[2514],anf_fun403512759,[("examples ")]);
};
try {
if(--R.GAS > 0) {
$z1275112752 = $f1275712758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1275712758,
"from":L[2514]});
}
} catch($e1274912750) {
if(R.isCont($e1274912750)) {
var $ss1275312754 = {"from":L[2514],
"go":function(cont_tail_arg403612760) {
return $Hcont_tail_arg988212761(cont_tail_arg403612760,if_helper402312747);
}};
$e1274912750.stack[R.EXN_STACKHEIGHT++] = $ss1275312754;
}
if(R.isPyretException($e1274912750)) {
$e1274912750.pyretStack.push(L[2514]);
}
throw $e1274912750;
}
var $ret1275512756 = $Hcont_tail_arg988212761($z1275112752,if_helper402312747);
++R.GAS;
return $ret1275512756;
}
} else {
var cont_tail_arg403212765 = R.throwNonBooleanCondition(L[2516],("if"),if_DASH_51412762);
if(--R.GAS > 0) {
$z1276312764 = R.isFunction(if_helper402312747)?if_helper402312747.app(cont_tail_arg403212765):R.ffi.throwNonFunApp(L[2516],if_helper402312747,[cont_tail_arg403212765]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper402312747)?if_helper402312747.app(cont_tail_arg403212765):R.ffi.throwNonFunApp(L[2516],if_helper402312747,[cont_tail_arg403212765]);
},
"from":L[2516]});
}
++R.GAS;
return $z1276312764;
}
});
var anf_arg404212727 = R.makeObject({"none":anf_obj402012732,
"some":anf_obj404112733});
var anf_arg404412728 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2510],0,arguments);
}
var ann_DASH_check_DASH_temp404312731 = R.throwNoBranchesMatched(L[2510],("cases"));
return ann_DASH_check_DASH_temp404312731;
});
var $z1271812719 = D;
var $f1272412725 = function(_) {
return R.isFunction(anf_fun400712726)?anf_fun400712726.app(anf_arg404212727,anf_arg404412728):R.ffi.throwNonFunApp(L[2509],anf_fun400712726,[anf_arg404212727,anf_arg404412728]);
};
try {
if(--R.GAS > 0) {
$z1271812719 = $f1272412725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1272412725,
"from":L[2509]});
}
} catch($e1271612717) {
if(R.isCont($e1271612717)) {
var $ss1272012721 = {"from":L[2509],
"go":function(ann_DASH_check_DASH_temp400612729) {
return $Hann_DASH_check_DASH_temp988312730(ann_DASH_check_DASH_temp400612729);
}};
$e1271612717.stack[R.EXN_STACKHEIGHT++] = $ss1272012721;
}
if(R.isPyretException($e1271612717)) {
$e1271612717.pyretStack.push(L[2509]);
}
throw $e1271612717;
}
var $ret1272212723 = $Hann_DASH_check_DASH_temp988312730($z1271812719);
++R.GAS;
return $ret1272212723;
};
},{"length":1});
var anf_assign40461930 = (function() {
var $s_DASH_module_DASH_base1204112042 = {"visit":anf_shared126012040,
"_match":anf_variant_member127612046,
"_torepr":anf_variant_member129812047,
"label":anf_variant_member130012048,
"tosource":anf_variant_member134712049};
var $s_DASH_module_DASH_brands1204412045 = {"$brand-s-module12043":true};
$s_DASH_module_DASH_brands1204412045[ExprT1187112._brand] = true
var $s_DASH_type_DASH_let_DASH_expr_DASH_base1205512056 = {"visit":anf_shared126012040,
"_match":anf_variant_member136112060,
"_torepr":anf_variant_member137512061,
"label":anf_variant_member137712062,
"tosource":anf_variant_member139712063};
var $s_DASH_type_DASH_let_DASH_expr_DASH_brands1205812059 = {"$brand-s-type-let-expr12057":true};
$s_DASH_type_DASH_let_DASH_expr_DASH_brands1205812059[ExprT1187112._brand] = true
var $s_DASH_let_DASH_expr_DASH_base1206712068 = {"visit":anf_shared126012040,
"_match":anf_variant_member141112072,
"_torepr":anf_variant_member142512073,
"label":anf_variant_member142712074,
"tosource":anf_variant_member144712075};
var $s_DASH_let_DASH_expr_DASH_brands1207012071 = {"$brand-s-let-expr12069":true};
$s_DASH_let_DASH_expr_DASH_brands1207012071[ExprT1187112._brand] = true
var $s_DASH_letrec_DASH_base1207912080 = {"visit":anf_shared126012040,
"_match":anf_variant_member146112084,
"_torepr":anf_variant_member147512085,
"label":anf_variant_member147712086,
"tosource":anf_variant_member149712087};
var $s_DASH_letrec_DASH_brands1208212083 = {"$brand-s-letrec12081":true};
$s_DASH_letrec_DASH_brands1208212083[ExprT1187112._brand] = true
var $s_DASH_hint_DASH_exp_DASH_base1209112092 = {"visit":anf_shared126012040,
"_match":anf_variant_member151112096,
"_torepr":anf_variant_member152512097,
"label":anf_variant_member152712098,
"tosource":anf_variant_member154212099};
var $s_DASH_hint_DASH_exp_DASH_brands1209412095 = {"$brand-s-hint-exp12093":true};
$s_DASH_hint_DASH_exp_DASH_brands1209412095[ExprT1187112._brand] = true
var $s_DASH_instantiate_DASH_base1210312104 = {"visit":anf_shared126012040,
"_match":anf_variant_member155612108,
"_torepr":anf_variant_member157012109,
"label":anf_variant_member157212110,
"tosource":anf_variant_member159012111};
var $s_DASH_instantiate_DASH_brands1210612107 = {"$brand-s-instantiate12105":true};
$s_DASH_instantiate_DASH_brands1210612107[ExprT1187112._brand] = true
var $s_DASH_block_DASH_base1211512116 = {"visit":anf_shared126012040,
"_match":anf_variant_member160312120,
"_torepr":anf_variant_member161312121,
"label":anf_variant_member161512122,
"tosource":anf_variant_member162312123};
var $s_DASH_block_DASH_brands1211812119 = {"$brand-s-block12117":true};
$s_DASH_block_DASH_brands1211812119[ExprT1187112._brand] = true
var $s_DASH_user_DASH_block_DASH_base1212612127 = {"visit":anf_shared126012040,
"_match":anf_variant_member163612131,
"_torepr":anf_variant_member164612132,
"label":anf_variant_member164812133,
"tosource":anf_variant_member165412134};
var $s_DASH_user_DASH_block_DASH_brands1212912130 = {"$brand-s-user-block12128":true};
$s_DASH_user_DASH_block_DASH_brands1212912130[ExprT1187112._brand] = true
var $s_DASH_fun_DASH_base1213712138 = {"visit":anf_shared126012040,
"_match":anf_variant_member167312142,
"_torepr":anf_variant_member170712143,
"label":anf_variant_member170912144,
"tosource":anf_variant_member171812145};
var $s_DASH_fun_DASH_brands1214012141 = {"$brand-s-fun12139":true};
$s_DASH_fun_DASH_brands1214012141[ExprT1187112._brand] = true
var $s_DASH_type_DASH_base1215412155 = {"visit":anf_shared126012040,
"_match":anf_variant_member173212159,
"_torepr":anf_variant_member174612160,
"label":anf_variant_member174812161,
"tosource":anf_variant_member176312162};
var $s_DASH_type_DASH_brands1215712158 = {"$brand-s-type12156":true};
$s_DASH_type_DASH_brands1215712158[ExprT1187112._brand] = true
var $s_DASH_newtype_DASH_base1216612167 = {"visit":anf_shared126012040,
"_match":anf_variant_member177712171,
"_torepr":anf_variant_member179112172,
"label":anf_variant_member179312173,
"tosource":anf_variant_member180912174};
var $s_DASH_newtype_DASH_brands1216912170 = {"$brand-s-newtype12168":true};
$s_DASH_newtype_DASH_brands1216912170[ExprT1187112._brand] = true
var $s_DASH_var_DASH_base1217812179 = {"visit":anf_shared126012040,
"_match":anf_variant_member182312183,
"_torepr":anf_variant_member183712184,
"label":anf_variant_member183912185,
"tosource":anf_variant_member185412186};
var $s_DASH_var_DASH_brands1218112182 = {"$brand-s-var12180":true};
$s_DASH_var_DASH_brands1218112182[ExprT1187112._brand] = true
var $s_DASH_let_DASH_base1219012191 = {"visit":anf_shared126012040,
"_match":anf_variant_member186912195,
"_torepr":anf_variant_member188712196,
"label":anf_variant_member188912197,
"tosource":anf_variant_member191212198};
var $s_DASH_let_DASH_brands1219312194 = {"$brand-s-let12192":true};
$s_DASH_let_DASH_brands1219312194[ExprT1187112._brand] = true
var $s_DASH_graph_DASH_base1220312204 = {"visit":anf_shared126012040,
"_match":anf_variant_member192512208,
"_torepr":anf_variant_member193512209,
"label":anf_variant_member193712210,
"tosource":anf_variant_member194712211};
var $s_DASH_graph_DASH_brands1220612207 = {"$brand-s-graph12205":true};
$s_DASH_graph_DASH_brands1220612207[ExprT1187112._brand] = true
var $s_DASH_contract_DASH_base1221412215 = {"visit":anf_shared126012040,
"_match":anf_variant_member196112219,
"_torepr":anf_variant_member197512220,
"label":anf_variant_member197712221,
"tosource":anf_variant_member198612222};
var $s_DASH_contract_DASH_brands1221712218 = {"$brand-s-contract12216":true};
$s_DASH_contract_DASH_brands1221712218[ExprT1187112._brand] = true
var $s_DASH_when_DASH_base1222612227 = {"visit":anf_shared126012040,
"_match":anf_variant_member200012231,
"_torepr":anf_variant_member201412232,
"label":anf_variant_member201612233,
"tosource":anf_variant_member202912234};
var $s_DASH_when_DASH_brands1222912230 = {"$brand-s-when12228":true};
$s_DASH_when_DASH_brands1222912230[ExprT1187112._brand] = true
var $s_DASH_assign_DASH_base1223812239 = {"visit":anf_shared126012040,
"_match":anf_variant_member204312243,
"_torepr":anf_variant_member205712244,
"label":anf_variant_member205912245,
"tosource":anf_variant_member207312246};
var $s_DASH_assign_DASH_brands1224112242 = {"$brand-s-assign12240":true};
$s_DASH_assign_DASH_brands1224112242[ExprT1187112._brand] = true
var $s_DASH_if_DASH_pipe_DASH_base1225012251 = {"visit":anf_shared126012040,
"_match":anf_variant_member208612255,
"_torepr":anf_variant_member209612256,
"label":anf_variant_member209812257,
"tosource":anf_variant_member211312258};
var $s_DASH_if_DASH_pipe_DASH_brands1225312254 = {"$brand-s-if-pipe12252":true};
$s_DASH_if_DASH_pipe_DASH_brands1225312254[ExprT1187112._brand] = true
var $s_DASH_if_DASH_pipe_DASH_else_DASH_base1226112262 = {"visit":anf_shared126012040,
"_match":anf_variant_member212712266,
"_torepr":anf_variant_member214112267,
"label":anf_variant_member214312268,
"tosource":anf_variant_member216712269};
var $s_DASH_if_DASH_pipe_DASH_else_DASH_brands1226412265 = {"$brand-s-if-pipe-else12263":true};
$s_DASH_if_DASH_pipe_DASH_else_DASH_brands1226412265[ExprT1187112._brand] = true
var $s_DASH_if_DASH_base1227312274 = {"visit":anf_shared126012040,
"_match":anf_variant_member218012278,
"_torepr":anf_variant_member219012279,
"label":anf_variant_member219212280,
"tosource":anf_variant_member220512281};
var $s_DASH_if_DASH_brands1227612277 = {"$brand-s-if12275":true};
$s_DASH_if_DASH_brands1227612277[ExprT1187112._brand] = true
var $s_DASH_if_DASH_else_DASH_base1228412285 = {"visit":anf_shared126012040,
"_match":anf_variant_member221912289,
"_torepr":anf_variant_member223312290,
"label":anf_variant_member223512291,
"tosource":anf_variant_member225612292};
var $s_DASH_if_DASH_else_DASH_brands1228712288 = {"$brand-s-if-else12286":true};
$s_DASH_if_DASH_else_DASH_brands1228712288[ExprT1187112._brand] = true
var $s_DASH_cases_DASH_base1229612297 = {"visit":anf_shared126012040,
"_match":anf_variant_member227112301,
"_torepr":anf_variant_member228912302,
"label":anf_variant_member229112303,
"tosource":anf_variant_member231712304};
var $s_DASH_cases_DASH_brands1229912300 = {"$brand-s-cases12298":true};
$s_DASH_cases_DASH_brands1229912300[ExprT1187112._brand] = true
var $s_DASH_cases_DASH_else_DASH_base1230912310 = {"visit":anf_shared126012040,
"_match":anf_variant_member233312314,
"_torepr":anf_variant_member235512315,
"label":anf_variant_member235712316,
"tosource":anf_variant_member239112317};
var $s_DASH_cases_DASH_else_DASH_brands1231212313 = {"$brand-s-cases-else12311":true};
$s_DASH_cases_DASH_else_DASH_brands1231212313[ExprT1187112._brand] = true
var $s_DASH_try_DASH_base1232312324 = {"visit":anf_shared126012040,
"_match":anf_variant_member240612328,
"_torepr":anf_variant_member242412329,
"label":anf_variant_member242612330,
"tosource":anf_variant_member245212331};
var $s_DASH_try_DASH_brands1232612327 = {"$brand-s-try12325":true};
$s_DASH_try_DASH_brands1232612327[ExprT1187112._brand] = true
var $s_DASH_op_DASH_base1233612337 = {"visit":anf_shared126012040,
"_match":anf_variant_member246712341,
"_torepr":anf_variant_member248512342,
"label":anf_variant_member248712343,
"tosource":anf_variant_member256212344};
var $s_DASH_op_DASH_brands1233912340 = {"$brand-s-op12338":true};
$s_DASH_op_DASH_brands1233912340[ExprT1187112._brand] = true
var $s_DASH_check_DASH_test_DASH_base1234912350 = {"visit":anf_shared126012040,
"_match":anf_variant_member257712354,
"_torepr":anf_variant_member259512355,
"tosource":anf_variant_member261012356};
var $s_DASH_check_DASH_test_DASH_brands1235212353 = {"$brand-s-check-test12351":true};
$s_DASH_check_DASH_test_DASH_brands1235212353[ExprT1187112._brand] = true
var $s_DASH_paren_DASH_base1236112362 = {"visit":anf_shared126012040,
"_match":anf_variant_member262312366,
"_torepr":anf_variant_member263312367,
"label":anf_variant_member263512368,
"tosource":anf_variant_member264112369};
var $s_DASH_paren_DASH_brands1236412365 = {"$brand-s-paren12363":true};
$s_DASH_paren_DASH_brands1236412365[ExprT1187112._brand] = true
var $s_DASH_lam_DASH_base1237212373 = {"visit":anf_shared126012040,
"_match":anf_variant_member265912377,
"_torepr":anf_variant_member268912378,
"label":anf_variant_member269112379,
"tosource":anf_variant_member269912380};
var $s_DASH_lam_DASH_brands1237512376 = {"$brand-s-lam12374":true};
$s_DASH_lam_DASH_brands1237512376[ExprT1187112._brand] = true
var $s_DASH_method_DASH_base1238812389 = {"visit":anf_shared126012040,
"_match":anf_variant_member271612393,
"_torepr":anf_variant_member274212394,
"label":anf_variant_member274412395,
"tosource":anf_variant_member275112396};
var $s_DASH_method_DASH_brands1239112392 = {"$brand-s-method12390":true};
$s_DASH_method_DASH_brands1239112392[ExprT1187112._brand] = true
var $s_DASH_extend_DASH_base1240312404 = {"visit":anf_shared126012040,
"_match":anf_variant_member276512408,
"_torepr":anf_variant_member277912409,
"label":anf_variant_member278112410,
"tosource":anf_variant_member280312411};
var $s_DASH_extend_DASH_brands1240612407 = {"$brand-s-extend12405":true};
$s_DASH_extend_DASH_brands1240612407[ExprT1187112._brand] = true
var $s_DASH_update_DASH_base1241512416 = {"visit":anf_shared126012040,
"_match":anf_variant_member281712420,
"_torepr":anf_variant_member283112421,
"label":anf_variant_member283312422};
var $s_DASH_update_DASH_brands1241812419 = {"$brand-s-update12417":true};
$s_DASH_update_DASH_brands1241812419[ExprT1187112._brand] = true
var $s_DASH_obj_DASH_base1242612427 = {"visit":anf_shared126012040,
"_match":anf_variant_member284612431,
"_torepr":anf_variant_member285612432,
"label":anf_variant_member285812433,
"tosource":anf_variant_member287312434};
var $s_DASH_obj_DASH_brands1242912430 = {"$brand-s-obj12428":true};
$s_DASH_obj_DASH_brands1242912430[ExprT1187112._brand] = true
var $s_DASH_array_DASH_base1243712438 = {"visit":anf_shared126012040,
"_match":anf_variant_member288612442,
"_torepr":anf_variant_member289612443,
"label":anf_variant_member289812444,
"tosource":anf_variant_member291312445};
var $s_DASH_array_DASH_brands1244012441 = {"$brand-s-array12439":true};
$s_DASH_array_DASH_brands1244012441[ExprT1187112._brand] = true
var $s_DASH_construct_DASH_base1244812449 = {"visit":anf_shared126012040,
"_match":anf_variant_member292812453,
"_torepr":anf_variant_member294612454,
"label":anf_variant_member294812455,
"tosource":anf_variant_member298812456};
var $s_DASH_construct_DASH_brands1245112452 = {"$brand-s-construct12450":true};
$s_DASH_construct_DASH_brands1245112452[ExprT1187112._brand] = true
var $s_DASH_confirm_DASH_base1246112462 = {"visit":anf_shared126012040,
"_match":anf_variant_member300212466,
"_torepr":anf_variant_member301612467,
"label":anf_variant_member301812468,
"tosource":anf_variant_member302912469};
var $s_DASH_confirm_DASH_brands1246412465 = {"$brand-s-confirm12463":true};
$s_DASH_confirm_DASH_brands1246412465[ExprT1187112._brand] = true
var $s_DASH_bless_DASH_base1247312474 = {"visit":anf_shared126012040,
"_match":anf_variant_member304312478,
"_torepr":anf_variant_member305712479,
"label":anf_variant_member305912480,
"tosource":anf_variant_member307012481};
var $s_DASH_bless_DASH_brands1247612477 = {"$brand-s-bless12475":true};
$s_DASH_bless_DASH_brands1247612477[ExprT1187112._brand] = true
var $s_DASH_app_DASH_base1248512486 = {"visit":anf_shared126012040,
"_match":anf_variant_member308412490,
"_torepr":anf_variant_member309812491,
"label":anf_variant_member310012492,
"tosource":anf_variant_member312012493};
var $s_DASH_app_DASH_brands1248812489 = {"$brand-s-app12487":true};
$s_DASH_app_DASH_brands1248812489[ExprT1187112._brand] = true
var $s_DASH_prim_DASH_app_DASH_base1249712498 = {"visit":anf_shared126012040,
"_match":anf_variant_member313412502,
"_torepr":anf_variant_member314812503,
"label":anf_variant_member315012504,
"tosource":anf_variant_member317012505};
var $s_DASH_prim_DASH_app_DASH_brands1250012501 = {"$brand-s-prim-app12499":true};
$s_DASH_prim_DASH_app_DASH_brands1250012501[ExprT1187112._brand] = true
var $s_DASH_prim_DASH_val_DASH_base1250912510 = {"visit":anf_shared126012040,
"_match":anf_variant_member318312514,
"_torepr":anf_variant_member319312515,
"label":anf_variant_member319512516,
"tosource":anf_variant_member319912517};
var $s_DASH_prim_DASH_val_DASH_brands1251212513 = {"$brand-s-prim-val12511":true};
$s_DASH_prim_DASH_val_DASH_brands1251212513[ExprT1187112._brand] = true
var $s_DASH_id_DASH_base1252012521 = {"visit":anf_shared126012040,
"_match":anf_variant_member321212525,
"_torepr":anf_variant_member322212526,
"label":anf_variant_member322412527,
"tosource":anf_variant_member322812528};
var $s_DASH_id_DASH_brands1252312524 = {"$brand-s-id12522":true};
$s_DASH_id_DASH_brands1252312524[ExprT1187112._brand] = true
var $s_DASH_id_DASH_var_DASH_base1253112532 = {"visit":anf_shared126012040,
"_match":anf_variant_member324112536,
"_torepr":anf_variant_member325112537,
"label":anf_variant_member325312538,
"tosource":anf_variant_member326012539};
var $s_DASH_id_DASH_var_DASH_brands1253412535 = {"$brand-s-id-var12533":true};
$s_DASH_id_DASH_var_DASH_brands1253412535[ExprT1187112._brand] = true
var $s_DASH_id_DASH_letrec_DASH_base1254212543 = {"visit":anf_shared126012040,
"_match":anf_variant_member327412547,
"_torepr":anf_variant_member328812548,
"label":anf_variant_member329012549,
"tosource":anf_variant_member329712550};
var $s_DASH_id_DASH_letrec_DASH_brands1254512546 = {"$brand-s-id-letrec12544":true};
$s_DASH_id_DASH_letrec_DASH_brands1254512546[ExprT1187112._brand] = true
var $s_DASH_undefined_DASH_base1255412555 = {"visit":anf_shared126012040,
"_match":anf_variant_member330912559,
"_torepr":anf_variant_member331512560,
"label":anf_variant_member331712561,
"tosource":anf_variant_member332012562};
var $s_DASH_undefined_DASH_brands1255712558 = {"$brand-s-undefined12556":true};
$s_DASH_undefined_DASH_brands1255712558[ExprT1187112._brand] = true
var $s_DASH_srcloc_DASH_base1256412565 = {"visit":anf_shared126012040,
"_match":anf_variant_member333312569,
"_torepr":anf_variant_member334312570,
"label":anf_variant_member334512571,
"tosource":anf_variant_member335012572};
var $s_DASH_srcloc_DASH_brands1256712568 = {"$brand-s-srcloc12566":true};
$s_DASH_srcloc_DASH_brands1256712568[ExprT1187112._brand] = true
var $s_DASH_num_DASH_base1257512576 = {"visit":anf_shared126012040,
"_match":anf_variant_member336312580,
"_torepr":anf_variant_member337312581,
"label":anf_variant_member337512582,
"tosource":anf_variant_member337912583};
var $s_DASH_num_DASH_brands1257812579 = {"$brand-s-num12577":true};
$s_DASH_num_DASH_brands1257812579[ExprT1187112._brand] = true
var $s_DASH_frac_DASH_base1258612587 = {"visit":anf_shared126012040,
"_match":anf_variant_member339312591,
"_torepr":anf_variant_member340712592,
"label":anf_variant_member340912593,
"tosource":anf_variant_member342012594};
var $s_DASH_frac_DASH_brands1258912590 = {"$brand-s-frac12588":true};
$s_DASH_frac_DASH_brands1258912590[ExprT1187112._brand] = true
var $s_DASH_bool_DASH_base1259812599 = {"visit":anf_shared126012040,
"_match":anf_variant_member343312603,
"_torepr":anf_variant_member344312604,
"label":anf_variant_member344512605,
"tosource":anf_variant_member345012606};
var $s_DASH_bool_DASH_brands1260112602 = {"$brand-s-bool12600":true};
$s_DASH_bool_DASH_brands1260112602[ExprT1187112._brand] = true
var $s_DASH_str_DASH_base1260912610 = {"visit":anf_shared126012040,
"_match":anf_variant_member346312614,
"_torepr":anf_variant_member347312615,
"label":anf_variant_member347512616,
"tosource":anf_variant_member348012617};
var $s_DASH_str_DASH_brands1261212613 = {"$brand-s-str12611":true};
$s_DASH_str_DASH_brands1261212613[ExprT1187112._brand] = true
var $s_DASH_dot_DASH_base1262012621 = {"visit":anf_shared126012040,
"_match":anf_variant_member349412625,
"_torepr":anf_variant_member350812626,
"label":anf_variant_member351012627,
"tosource":anf_variant_member351912628};
var $s_DASH_dot_DASH_brands1262312624 = {"$brand-s-dot12622":true};
$s_DASH_dot_DASH_brands1262312624[ExprT1187112._brand] = true
var $s_DASH_get_DASH_bang_DASH_base1263212633 = {"visit":anf_shared126012040,
"_match":anf_variant_member353312637,
"_torepr":anf_variant_member354712638,
"label":anf_variant_member354912639,
"tosource":anf_variant_member355812640};
var $s_DASH_get_DASH_bang_DASH_brands1263512636 = {"$brand-s-get-bang12634":true};
$s_DASH_get_DASH_bang_DASH_brands1263512636[ExprT1187112._brand] = true
var $s_DASH_bracket_DASH_base1264412645 = {"visit":anf_shared126012040,
"_match":anf_variant_member357212649,
"_torepr":anf_variant_member358612650,
"label":anf_variant_member358812651,
"tosource":anf_variant_member360112652};
var $s_DASH_bracket_DASH_brands1264712648 = {"$brand-s-bracket12646":true};
$s_DASH_bracket_DASH_brands1264712648[ExprT1187112._brand] = true
var $s_DASH_data_DASH_base1265612657 = {"visit":anf_shared126012040,
"_match":anf_variant_member361912661,
"_torepr":anf_variant_member364912662,
"label":anf_variant_member365112663,
"tosource":anf_variant_member374012664};
var $s_DASH_data_DASH_brands1265912660 = {"$brand-s-data12658":true};
$s_DASH_data_DASH_brands1265912660[ExprT1187112._brand] = true
var $s_DASH_data_DASH_expr_DASH_base1267212673 = {"visit":anf_shared126012040,
"_match":anf_variant_member375912677,
"_torepr":anf_variant_member379312678,
"label":anf_variant_member379512679,
"tosource":anf_variant_member389012680};
var $s_DASH_data_DASH_expr_DASH_brands1267512676 = {"$brand-s-data-expr12674":true};
$s_DASH_data_DASH_expr_DASH_brands1267512676[ExprT1187112._brand] = true
var $s_DASH_for_DASH_base1268912690 = {"visit":anf_shared126012040,
"_match":anf_variant_member390612694,
"_torepr":anf_variant_member392812695,
"label":anf_variant_member393012696,
"tosource":anf_variant_member397012697};
var $s_DASH_for_DASH_brands1269212693 = {"$brand-s-for12691":true};
$s_DASH_for_DASH_brands1269212693[ExprT1187112._brand] = true
var $s_DASH_check_DASH_base1270312704 = {"visit":anf_shared126012040,
"_match":anf_variant_member398512708,
"_torepr":anf_variant_member400312709,
"label":anf_variant_member400512710,
"tosource":anf_variant_member404512711};
var $s_DASH_check_DASH_brands1270612707 = {"$brand-s-check12705":true};
$s_DASH_check_DASH_brands1270612707[ExprT1187112._brand] = true
return R.makeObject({"Expr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2271],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ExprT1187112._brand));
}),
"is-s-module":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2270],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-module12043"));
}),
"s-module":R.makeFunction(function(l64812050,answer64912051,provides65012052,types65112053,checks65212054) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[2272],5,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111,List17129,Expr86111],[l64812050,answer64912051,provides65012052,types65112053,checks65212054],[L[2273],L[2274],L[2275],L[2276],L[2277]],function() {
var dict = R.create($s_DASH_module_DASH_base1204112042);
dict["l"] = l64812050
dict["answer"] = answer64912051
dict["provides"] = provides65012052
dict["types"] = types65112053
dict["checks"] = checks65212054
return R.makeBrandedObject(dict,$s_DASH_module_DASH_brands1204412045);
});
}),
"is-s-type-let-expr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2269],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-type-let-expr12057"));
}),
"s-type-let-expr":R.makeFunction(function(l65612064,binds65712065,body65812066) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2278],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l65612064,binds65712065,body65812066],[L[2279],L[2280],L[2281]],function() {
var dict = R.create($s_DASH_type_DASH_let_DASH_expr_DASH_base1205512056);
dict["l"] = l65612064
dict["binds"] = binds65712065
dict["body"] = body65812066
return R.makeBrandedObject(dict,$s_DASH_type_DASH_let_DASH_expr_DASH_brands1205812059);
});
}),
"is-s-let-expr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2268],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-let-expr12069"));
}),
"s-let-expr":R.makeFunction(function(l66212076,binds66312077,body66412078) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2282],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l66212076,binds66312077,body66412078],[L[2283],L[2284],L[2285]],function() {
var dict = R.create($s_DASH_let_DASH_expr_DASH_base1206712068);
dict["l"] = l66212076
dict["binds"] = binds66312077
dict["body"] = body66412078
return R.makeBrandedObject(dict,$s_DASH_let_DASH_expr_DASH_brands1207012071);
});
}),
"is-s-letrec":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2267],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-letrec12081"));
}),
"s-letrec":R.makeFunction(function(l66812088,binds66912089,body67012090) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2286],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l66812088,binds66912089,body67012090],[L[2287],L[2288],L[2289]],function() {
var dict = R.create($s_DASH_letrec_DASH_base1207912080);
dict["l"] = l66812088
dict["binds"] = binds66912089
dict["body"] = body67012090
return R.makeBrandedObject(dict,$s_DASH_letrec_DASH_brands1208212083);
});
}),
"is-s-hint-exp":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2266],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-hint-exp12093"));
}),
"s-hint-exp":R.makeFunction(function(l67412100,hints67512101,exp67612102) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2290],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l67412100,hints67512101,exp67612102],[L[2291],L[2292],L[2293]],function() {
var dict = R.create($s_DASH_hint_DASH_exp_DASH_base1209112092);
dict["l"] = l67412100
dict["hints"] = hints67512101
dict["exp"] = exp67612102
return R.makeBrandedObject(dict,$s_DASH_hint_DASH_exp_DASH_brands1209412095);
});
}),
"is-s-instantiate":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2265],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-instantiate12105"));
}),
"s-instantiate":R.makeFunction(function(l68012112,expr68112113,params68212114) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2294],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l68012112,expr68112113,params68212114],[L[2295],L[2296],L[2297]],function() {
var dict = R.create($s_DASH_instantiate_DASH_base1210312104);
dict["l"] = l68012112
dict["expr"] = expr68112113
dict["params"] = params68212114
return R.makeBrandedObject(dict,$s_DASH_instantiate_DASH_brands1210612107);
});
}),
"is-s-block":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2264],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-block12117"));
}),
"s-block":R.makeFunction(function(l68512124,stmts68612125) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2298],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l68512124,stmts68612125],[L[2299],L[2300]],function() {
var dict = R.create($s_DASH_block_DASH_base1211512116);
dict["l"] = l68512124
dict["stmts"] = stmts68612125
return R.makeBrandedObject(dict,$s_DASH_block_DASH_brands1211812119);
});
}),
"is-s-user-block":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2263],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-user-block12128"));
}),
"s-user-block":R.makeFunction(function(l68912135,body69012136) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2301],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l68912135,body69012136],[L[2302],L[2303]],function() {
var dict = R.create($s_DASH_user_DASH_block_DASH_base1212612127);
dict["l"] = l68912135
dict["body"] = body69012136
return R.makeBrandedObject(dict,$s_DASH_user_DASH_block_DASH_brands1212912130);
});
}),
"is-s-fun":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2262],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-fun12139"));
}),
"s-fun":R.makeFunction(function(l69312146,name69412147,params69512148,args69612149,ann69712150,doc69812151,body69912152,_check70012153) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[2304],8,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l69312146,name69412147,params69512148,args69612149,ann69712150,doc69812151,body69912152,_check70012153],[L[2305],L[2306],L[2307],L[2308],L[2309],L[2310],L[2311],L[2312]],function() {
var dict = R.create($s_DASH_fun_DASH_base1213712138);
dict["l"] = l69312146
dict["name"] = name69412147
dict["params"] = params69512148
dict["args"] = args69612149
dict["ann"] = ann69712150
dict["doc"] = doc69812151
dict["body"] = body69912152
dict["_check"] = _check70012153
return R.makeBrandedObject(dict,$s_DASH_fun_DASH_brands1214012141);
});
}),
"is-s-type":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2261],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-type12156"));
}),
"s-type":R.makeFunction(function(l70312163,name70412164,ann70512165) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2313],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Ann11299],[l70312163,name70412164,ann70512165],[L[2314],L[2315],L[2316]],function() {
var dict = R.create($s_DASH_type_DASH_base1215412155);
dict["l"] = l70312163
dict["name"] = name70412164
dict["ann"] = ann70512165
return R.makeBrandedObject(dict,$s_DASH_type_DASH_brands1215712158);
});
}),
"is-s-newtype":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2260],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-newtype12168"));
}),
"s-newtype":R.makeFunction(function(l70812175,name70912176,namet71012177) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2317],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Name66133],[l70812175,name70912176,namet71012177],[L[2318],L[2319],L[2320]],function() {
var dict = R.create($s_DASH_newtype_DASH_base1216612167);
dict["l"] = l70812175
dict["name"] = name70912176
dict["namet"] = namet71012177
return R.makeBrandedObject(dict,$s_DASH_newtype_DASH_brands1216912170);
});
}),
"is-s-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2259],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-var12180"));
}),
"s-var":R.makeFunction(function(l71312187,name71412188,value71512189) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2321],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l71312187,name71412188,value71512189],[L[2322],L[2323],L[2324]],function() {
var dict = R.create($s_DASH_var_DASH_base1217812179);
dict["l"] = l71312187
dict["name"] = name71412188
dict["value"] = value71512189
return R.makeBrandedObject(dict,$s_DASH_var_DASH_brands1218112182);
});
}),
"is-s-let":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2258],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-let12192"));
}),
"s-let":R.makeFunction(function(l71812199,name71912200,value72012201,keyword_DASH_val72112202) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2325],4,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111,$type$Boolean67],[l71812199,name71912200,value72012201,keyword_DASH_val72112202],[L[2326],L[2327],L[2328],L[2329]],function() {
var dict = R.create($s_DASH_let_DASH_base1219012191);
dict["l"] = l71812199
dict["name"] = name71912200
dict["value"] = value72012201
dict["keyword-val"] = keyword_DASH_val72112202
return R.makeBrandedObject(dict,$s_DASH_let_DASH_brands1219312194);
});
}),
"is-s-graph":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2257],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-graph12205"));
}),
"s-graph":R.makeFunction(function(l72412212,bindings72512213) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2330],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l72412212,bindings72512213],[L[2331],L[2332]],function() {
var dict = R.create($s_DASH_graph_DASH_base1220312204);
dict["l"] = l72412212
dict["bindings"] = bindings72512213
return R.makeBrandedObject(dict,$s_DASH_graph_DASH_brands1220612207);
});
}),
"is-s-contract":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2256],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-contract12216"));
}),
"s-contract":R.makeFunction(function(l72812223,name72912224,ann73012225) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2333],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Ann11299],[l72812223,name72912224,ann73012225],[L[2334],L[2335],L[2336]],function() {
var dict = R.create($s_DASH_contract_DASH_base1221412215);
dict["l"] = l72812223
dict["name"] = name72912224
dict["ann"] = ann73012225
return R.makeBrandedObject(dict,$s_DASH_contract_DASH_brands1221712218);
});
}),
"is-s-when":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2255],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-when12228"));
}),
"s-when":R.makeFunction(function(l73312235,test73412236,block73512237) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2337],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l73312235,test73412236,block73512237],[L[2338],L[2339],L[2340]],function() {
var dict = R.create($s_DASH_when_DASH_base1222612227);
dict["l"] = l73312235
dict["test"] = test73412236
dict["block"] = block73512237
return R.makeBrandedObject(dict,$s_DASH_when_DASH_brands1222912230);
});
}),
"is-s-assign":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2254],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-assign12240"));
}),
"s-assign":R.makeFunction(function(l73812247,id73912248,value74012249) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2341],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Expr86111],[l73812247,id73912248,value74012249],[L[2342],L[2343],L[2344]],function() {
var dict = R.create($s_DASH_assign_DASH_base1223812239);
dict["l"] = l73812247
dict["id"] = id73912248
dict["value"] = value74012249
return R.makeBrandedObject(dict,$s_DASH_assign_DASH_brands1224112242);
});
}),
"is-s-if-pipe":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2253],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-if-pipe12252"));
}),
"s-if-pipe":R.makeFunction(function(l74312259,branches74412260) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2345],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l74312259,branches74412260],[L[2346],L[2347]],function() {
var dict = R.create($s_DASH_if_DASH_pipe_DASH_base1225012251);
dict["l"] = l74312259
dict["branches"] = branches74412260
return R.makeBrandedObject(dict,$s_DASH_if_DASH_pipe_DASH_brands1225312254);
});
}),
"is-s-if-pipe-else":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2252],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-if-pipe-else12263"));
}),
"s-if-pipe-else":R.makeFunction(function(l74812270,branches74912271,_else75012272) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2348],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l74812270,branches74912271,_else75012272],[L[2349],L[2350],L[2351]],function() {
var dict = R.create($s_DASH_if_DASH_pipe_DASH_else_DASH_base1226112262);
dict["l"] = l74812270
dict["branches"] = branches74912271
dict["_else"] = _else75012272
return R.makeBrandedObject(dict,$s_DASH_if_DASH_pipe_DASH_else_DASH_brands1226412265);
});
}),
"is-s-if":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2251],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-if12275"));
}),
"s-if":R.makeFunction(function(l75512282,branches75612283) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2352],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l75512282,branches75612283],[L[2353],L[2354]],function() {
var dict = R.create($s_DASH_if_DASH_base1227312274);
dict["l"] = l75512282
dict["branches"] = branches75612283
return R.makeBrandedObject(dict,$s_DASH_if_DASH_brands1227612277);
});
}),
"is-s-if-else":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2250],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-if-else12286"));
}),
"s-if-else":R.makeFunction(function(l76112293,branches76212294,_else76312295) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2355],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l76112293,branches76212294,_else76312295],[L[2356],L[2357],L[2358]],function() {
var dict = R.create($s_DASH_if_DASH_else_DASH_base1228412285);
dict["l"] = l76112293
dict["branches"] = branches76212294
dict["_else"] = _else76312295
return R.makeBrandedObject(dict,$s_DASH_if_DASH_else_DASH_brands1228712288);
});
}),
"is-s-cases":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2249],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-cases12298"));
}),
"s-cases":R.makeFunction(function(l76912305,typ77012306,val77112307,branches77212308) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2359],4,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111,List17129],[l76912305,typ77012306,val77112307,branches77212308],[L[2360],L[2361],L[2362],L[2363]],function() {
var dict = R.create($s_DASH_cases_DASH_base1229612297);
dict["l"] = l76912305
dict["typ"] = typ77012306
dict["val"] = val77112307
dict["branches"] = branches77212308
return R.makeBrandedObject(dict,$s_DASH_cases_DASH_brands1229912300);
});
}),
"is-s-cases-else":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2248],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-cases-else12311"));
}),
"s-cases-else":R.makeFunction(function(l77712318,typ77812319,val77912320,branches78012321,_else78112322) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[2364],5,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111,List17129,Expr86111],[l77712318,typ77812319,val77912320,branches78012321,_else78112322],[L[2365],L[2366],L[2367],L[2368],L[2369]],function() {
var dict = R.create($s_DASH_cases_DASH_else_DASH_base1230912310);
dict["l"] = l77712318
dict["typ"] = typ77812319
dict["val"] = val77912320
dict["branches"] = branches78012321
dict["_else"] = _else78112322
return R.makeBrandedObject(dict,$s_DASH_cases_DASH_else_DASH_brands1231212313);
});
}),
"is-s-try":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2247],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-try12325"));
}),
"s-try":R.makeFunction(function(l78712332,body78812333,id78912334,_except79012335) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2370],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Bind90101,Expr86111],[l78712332,body78812333,id78912334,_except79012335],[L[2371],L[2372],L[2373],L[2374]],function() {
var dict = R.create($s_DASH_try_DASH_base1232312324);
dict["l"] = l78712332
dict["body"] = body78812333
dict["id"] = id78912334
dict["_except"] = _except79012335
return R.makeBrandedObject(dict,$s_DASH_try_DASH_brands1232612327);
});
}),
"is-s-op":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2246],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-op12338"));
}),
"s-op":R.makeFunction(function(l79512345,op79612346,left79712347,right79812348) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2375],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111,Expr86111],[l79512345,op79612346,left79712347,right79812348],[L[2376],L[2377],L[2378],L[2379]],function() {
var dict = R.create($s_DASH_op_DASH_base1233612337);
dict["l"] = l79512345
dict["op"] = op79612346
dict["left"] = left79712347
dict["right"] = right79812348
return R.makeBrandedObject(dict,$s_DASH_op_DASH_brands1233912340);
});
}),
"is-s-check-test":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2245],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-check-test12351"));
}),
"s-check-test":R.makeFunction(function(l81212357,op81312358,left81412359,right81512360) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2380],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111,Expr86111],[l81212357,op81312358,left81412359,right81512360],[L[2381],L[2382],L[2383],L[2384]],function() {
var dict = R.create($s_DASH_check_DASH_test_DASH_base1234912350);
dict["l"] = l81212357
dict["op"] = op81312358
dict["left"] = left81412359
dict["right"] = right81512360
return R.makeBrandedObject(dict,$s_DASH_check_DASH_test_DASH_brands1235212353);
});
}),
"is-s-paren":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2244],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-paren12363"));
}),
"s-paren":R.makeFunction(function(l81712370,expr81812371) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2385],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l81712370,expr81812371],[L[2386],L[2387]],function() {
var dict = R.create($s_DASH_paren_DASH_base1236112362);
dict["l"] = l81712370
dict["expr"] = expr81812371
return R.makeBrandedObject(dict,$s_DASH_paren_DASH_brands1236412365);
});
}),
"is-s-lam":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2243],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-lam12374"));
}),
"s-lam":R.makeFunction(function(l82112381,params82212382,args82312383,ann82412384,doc82512385,body82612386,_check82712387) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[2388],7,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l82112381,params82212382,args82312383,ann82412384,doc82512385,body82612386,_check82712387],[L[2389],L[2390],L[2391],L[2392],L[2393],L[2394],L[2395]],function() {
var dict = R.create($s_DASH_lam_DASH_base1237212373);
dict["l"] = l82112381
dict["params"] = params82212382
dict["args"] = args82312383
dict["ann"] = ann82412384
dict["doc"] = doc82512385
dict["body"] = body82612386
dict["_check"] = _check82712387
return R.makeBrandedObject(dict,$s_DASH_lam_DASH_brands1237512376);
});
}),
"is-s-method":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2242],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-method12390"));
}),
"s-method":R.makeFunction(function(l83012397,args83112398,ann83212399,doc83312400,body83412401,_check83512402) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[2396],6,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l83012397,args83112398,ann83212399,doc83312400,body83412401,_check83512402],[L[2397],L[2398],L[2399],L[2400],L[2401],L[2402]],function() {
var dict = R.create($s_DASH_method_DASH_base1238812389);
dict["l"] = l83012397
dict["args"] = args83112398
dict["ann"] = ann83212399
dict["doc"] = doc83312400
dict["body"] = body83412401
dict["_check"] = _check83512402
return R.makeBrandedObject(dict,$s_DASH_method_DASH_brands1239112392);
});
}),
"is-s-extend":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2241],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-extend12405"));
}),
"s-extend":R.makeFunction(function(l83812412,supe83912413,fields84012414) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2403],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l83812412,supe83912413,fields84012414],[L[2404],L[2405],L[2406]],function() {
var dict = R.create($s_DASH_extend_DASH_base1240312404);
dict["l"] = l83812412
dict["supe"] = supe83912413
dict["fields"] = fields84012414
return R.makeBrandedObject(dict,$s_DASH_extend_DASH_brands1240612407);
});
}),
"is-s-update":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2240],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-update12417"));
}),
"s-update":R.makeFunction(function(l84312423,supe84412424,fields84512425) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2407],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l84312423,supe84412424,fields84512425],[L[2408],L[2409],L[2410]],function() {
var dict = R.create($s_DASH_update_DASH_base1241512416);
dict["l"] = l84312423
dict["supe"] = supe84412424
dict["fields"] = fields84512425
return R.makeBrandedObject(dict,$s_DASH_update_DASH_brands1241812419);
});
}),
"is-s-obj":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2239],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-obj12428"));
}),
"s-obj":R.makeFunction(function(l84712435,fields84812436) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2411],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l84712435,fields84812436],[L[2412],L[2413]],function() {
var dict = R.create($s_DASH_obj_DASH_base1242612427);
dict["l"] = l84712435
dict["fields"] = fields84812436
return R.makeBrandedObject(dict,$s_DASH_obj_DASH_brands1242912430);
});
}),
"is-s-array":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2238],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-array12439"));
}),
"s-array":R.makeFunction(function(l85112446,values85212447) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2414],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l85112446,values85212447],[L[2415],L[2416]],function() {
var dict = R.create($s_DASH_array_DASH_base1243712438);
dict["l"] = l85112446
dict["values"] = values85212447
return R.makeBrandedObject(dict,$s_DASH_array_DASH_brands1244012441);
});
}),
"is-s-construct":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2237],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-construct12450"));
}),
"s-construct":R.makeFunction(function(l85512457,modifier85612458,constructor85712459,values85812460) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2417],4,arguments);
}
return R.checkAnnArgs([Loc116130,ConstructModifier88105,Expr86111,List17129],[l85512457,modifier85612458,constructor85712459,values85812460],[L[2418],L[2419],L[2420],L[2421]],function() {
var dict = R.create($s_DASH_construct_DASH_base1244812449);
dict["l"] = l85512457
dict["modifier"] = modifier85612458
dict["constructor"] = constructor85712459
dict["values"] = values85812460
return R.makeBrandedObject(dict,$s_DASH_construct_DASH_brands1245112452);
});
}),
"is-s-confirm":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2236],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-confirm12463"));
}),
"s-confirm":R.makeFunction(function(l86212470,expr86312471,typ86412472) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2422],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Name66133],[l86212470,expr86312471,typ86412472],[L[2423],L[2424],L[2425]],function() {
var dict = R.create($s_DASH_confirm_DASH_base1246112462);
dict["l"] = l86212470
dict["expr"] = expr86312471
dict["typ"] = typ86412472
return R.makeBrandedObject(dict,$s_DASH_confirm_DASH_brands1246412465);
});
}),
"is-s-bless":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2235],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-bless12475"));
}),
"s-bless":R.makeFunction(function(l86712482,expr86812483,typ86912484) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2426],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Name66133],[l86712482,expr86812483,typ86912484],[L[2427],L[2428],L[2429]],function() {
var dict = R.create($s_DASH_bless_DASH_base1247312474);
dict["l"] = l86712482
dict["expr"] = expr86812483
dict["typ"] = typ86912484
return R.makeBrandedObject(dict,$s_DASH_bless_DASH_brands1247612477);
});
}),
"is-s-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2234],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-app12487"));
}),
"s-app":R.makeFunction(function(l87212494,_fun87312495,args87412496) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2430],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l87212494,_fun87312495,args87412496],[L[2431],L[2432],L[2433]],function() {
var dict = R.create($s_DASH_app_DASH_base1248512486);
dict["l"] = l87212494
dict["_fun"] = _fun87312495
dict["args"] = args87412496
return R.makeBrandedObject(dict,$s_DASH_app_DASH_brands1248812489);
});
}),
"is-s-prim-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2233],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-prim-app12499"));
}),
"s-prim-app":R.makeFunction(function(l87712506,_fun87812507,args87912508) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2434],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129],[l87712506,_fun87812507,args87912508],[L[2435],L[2436],L[2437]],function() {
var dict = R.create($s_DASH_prim_DASH_app_DASH_base1249712498);
dict["l"] = l87712506
dict["_fun"] = _fun87812507
dict["args"] = args87912508
return R.makeBrandedObject(dict,$s_DASH_prim_DASH_app_DASH_brands1250012501);
});
}),
"is-s-prim-val":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2232],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-prim-val12511"));
}),
"s-prim-val":R.makeFunction(function(l88212518,name88312519) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2438],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l88212518,name88312519],[L[2439],L[2440]],function() {
var dict = R.create($s_DASH_prim_DASH_val_DASH_base1250912510);
dict["l"] = l88212518
dict["name"] = name88312519
return R.makeBrandedObject(dict,$s_DASH_prim_DASH_val_DASH_brands1251212513);
});
}),
"is-s-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2231],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-id12522"));
}),
"s-id":R.makeFunction(function(l88612529,id88712530) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2441],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l88612529,id88712530],[L[2442],L[2443]],function() {
var dict = R.create($s_DASH_id_DASH_base1252012521);
dict["l"] = l88612529
dict["id"] = id88712530
return R.makeBrandedObject(dict,$s_DASH_id_DASH_brands1252312524);
});
}),
"is-s-id-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2230],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-id-var12533"));
}),
"s-id-var":R.makeFunction(function(l89012540,id89112541) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2444],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l89012540,id89112541],[L[2445],L[2446]],function() {
var dict = R.create($s_DASH_id_DASH_var_DASH_base1253112532);
dict["l"] = l89012540
dict["id"] = id89112541
return R.makeBrandedObject(dict,$s_DASH_id_DASH_var_DASH_brands1253412535);
});
}),
"is-s-id-letrec":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2229],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-id-letrec12544"));
}),
"s-id-letrec":R.makeFunction(function(l89412551,id89512552,safe89612553) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2447],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,$type$Boolean67],[l89412551,id89512552,safe89612553],[L[2448],L[2449],L[2450]],function() {
var dict = R.create($s_DASH_id_DASH_letrec_DASH_base1254212543);
dict["l"] = l89412551
dict["id"] = id89512552
dict["safe"] = safe89612553
return R.makeBrandedObject(dict,$s_DASH_id_DASH_letrec_DASH_brands1254512546);
});
}),
"is-s-undefined":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2228],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-undefined12556"));
}),
"s-undefined":R.makeFunction(function(l89912563) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2451],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l89912563],[L[2452]],function() {
var dict = R.create($s_DASH_undefined_DASH_base1255412555);
dict["l"] = l89912563
return R.makeBrandedObject(dict,$s_DASH_undefined_DASH_brands1255712558);
});
}),
"is-s-srcloc":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2227],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-srcloc12566"));
}),
"s-srcloc":R.makeFunction(function(l90212573,loc90312574) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2453],2,arguments);
}
return R.checkAnnArgs([Loc116130,Loc116130],[l90212573,loc90312574],[L[2454],L[2455]],function() {
var dict = R.create($s_DASH_srcloc_DASH_base1256412565);
dict["l"] = l90212573
dict["loc"] = loc90312574
return R.makeBrandedObject(dict,$s_DASH_srcloc_DASH_brands1256712568);
});
}),
"is-s-num":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2226],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-num12577"));
}),
"s-num":R.makeFunction(function(l90612584,n90712585) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2456],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Number68],[l90612584,n90712585],[L[2457],L[2458]],function() {
var dict = R.create($s_DASH_num_DASH_base1257512576);
dict["l"] = l90612584
dict["n"] = n90712585
return R.makeBrandedObject(dict,$s_DASH_num_DASH_brands1257812579);
});
}),
"is-s-frac":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2225],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-frac12588"));
}),
"s-frac":R.makeFunction(function(l91012595,num91112596,den91212597) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2459],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Number68,$type$Number68],[l91012595,num91112596,den91212597],[L[2460],L[2461],L[2462]],function() {
var dict = R.create($s_DASH_frac_DASH_base1258612587);
dict["l"] = l91012595
dict["num"] = num91112596
dict["den"] = den91212597
return R.makeBrandedObject(dict,$s_DASH_frac_DASH_brands1258912590);
});
}),
"is-s-bool":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2224],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-bool12600"));
}),
"s-bool":R.makeFunction(function(l91512607,b91612608) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2463],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Boolean67],[l91512607,b91612608],[L[2464],L[2465]],function() {
var dict = R.create($s_DASH_bool_DASH_base1259812599);
dict["l"] = l91512607
dict["b"] = b91612608
return R.makeBrandedObject(dict,$s_DASH_bool_DASH_brands1260112602);
});
}),
"is-s-str":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2223],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-str12611"));
}),
"s-str":R.makeFunction(function(l91912618,s92012619) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2466],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l91912618,s92012619],[L[2467],L[2468]],function() {
var dict = R.create($s_DASH_str_DASH_base1260912610);
dict["l"] = l91912618
dict["s"] = s92012619
return R.makeBrandedObject(dict,$s_DASH_str_DASH_brands1261212613);
});
}),
"is-s-dot":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2222],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-dot12622"));
}),
"s-dot":R.makeFunction(function(l92312629,obj92412630,field92512631) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2469],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,$type$String69],[l92312629,obj92412630,field92512631],[L[2470],L[2471],L[2472]],function() {
var dict = R.create($s_DASH_dot_DASH_base1262012621);
dict["l"] = l92312629
dict["obj"] = obj92412630
dict["field"] = field92512631
return R.makeBrandedObject(dict,$s_DASH_dot_DASH_brands1262312624);
});
}),
"is-s-get-bang":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2221],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-get-bang12634"));
}),
"s-get-bang":R.makeFunction(function(l92812641,obj92912642,field93012643) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2473],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,$type$String69],[l92812641,obj92912642,field93012643],[L[2474],L[2475],L[2476]],function() {
var dict = R.create($s_DASH_get_DASH_bang_DASH_base1263212633);
dict["l"] = l92812641
dict["obj"] = obj92912642
dict["field"] = field93012643
return R.makeBrandedObject(dict,$s_DASH_get_DASH_bang_DASH_brands1263512636);
});
}),
"is-s-bracket":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2220],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-bracket12646"));
}),
"s-bracket":R.makeFunction(function(l93312653,obj93412654,field93512655) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2477],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l93312653,obj93412654,field93512655],[L[2478],L[2479],L[2480]],function() {
var dict = R.create($s_DASH_bracket_DASH_base1264412645);
dict["l"] = l93312653
dict["obj"] = obj93412654
dict["field"] = field93512655
return R.makeBrandedObject(dict,$s_DASH_bracket_DASH_brands1264712648);
});
}),
"is-s-data":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2219],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-data12658"));
}),
"s-data":R.makeFunction(function(l93812665,name93912666,params94012667,mixins94112668,variants94212669,shared_DASH_members94312670,_check94412671) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[2481],7,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,List17129,List17129,List17129,Option18135],[l93812665,name93912666,params94012667,mixins94112668,variants94212669,shared_DASH_members94312670,_check94412671],[L[2482],L[2483],L[2484],L[2485],L[2486],L[2487],L[2488]],function() {
var dict = R.create($s_DASH_data_DASH_base1265612657);
dict["l"] = l93812665
dict["name"] = name93912666
dict["params"] = params94012667
dict["mixins"] = mixins94112668
dict["variants"] = variants94212669
dict["shared-members"] = shared_DASH_members94312670
dict["_check"] = _check94412671
return R.makeBrandedObject(dict,$s_DASH_data_DASH_brands1265912660);
});
}),
"is-s-data-expr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2218],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-data-expr12674"));
}),
"s-data-expr":R.makeFunction(function(l96112681,name96212682,namet96312683,params96412684,mixins96512685,variants96612686,shared_DASH_members96712687,_check96812688) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[2489],8,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Name66133,List17129,List17129,List17129,List17129,Option18135],[l96112681,name96212682,namet96312683,params96412684,mixins96512685,variants96612686,shared_DASH_members96712687,_check96812688],[L[2490],L[2491],L[2492],L[2493],L[2494],L[2495],L[2496],L[2497]],function() {
var dict = R.create($s_DASH_data_DASH_expr_DASH_base1267212673);
dict["l"] = l96112681
dict["name"] = name96212682
dict["namet"] = namet96312683
dict["params"] = params96412684
dict["mixins"] = mixins96512685
dict["variants"] = variants96612686
dict["shared-members"] = shared_DASH_members96712687
dict["_check"] = _check96812688
return R.makeBrandedObject(dict,$s_DASH_data_DASH_expr_DASH_brands1267512676);
});
}),
"is-s-for":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2217],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-for12691"));
}),
"s-for":R.makeFunction(function(l98512698,iterator98612699,bindings98712700,ann98812701,body98912702) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[2498],5,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129,Ann11299,Expr86111],[l98512698,iterator98612699,bindings98712700,ann98812701,body98912702],[L[2499],L[2500],L[2501],L[2502],L[2503]],function() {
var dict = R.create($s_DASH_for_DASH_base1268912690);
dict["l"] = l98512698
dict["iterator"] = iterator98612699
dict["bindings"] = bindings98712700
dict["ann"] = ann98812701
dict["body"] = body98912702
return R.makeBrandedObject(dict,$s_DASH_for_DASH_brands1269212693);
});
}),
"is-s-check":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2216],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-check12705"));
}),
"s-check":R.makeFunction(function(l99412712,name99512713,body99612714,keyword_DASH_check99712715) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2504],4,arguments);
}
return R.checkAnnArgs([Loc116130,Option18135,Expr86111,$type$Boolean67],[l99412712,name99512713,body99612714,keyword_DASH_check99712715],[L[2505],L[2506],L[2507],L[2508]],function() {
var dict = R.create($s_DASH_check_DASH_base1270312704);
dict["l"] = l99412712
dict["name"] = name99512713
dict["body"] = body99612714
dict["keyword-check"] = keyword_DASH_check99712715
return R.makeBrandedObject(dict,$s_DASH_check_DASH_brands1270612707);
});
})});
})();
Expr363141929.$var = anf_assign40461930;
var anf_assign40471932 = G(Expr363141929.$var,"Expr",L[2271]);
Expr3151931.$var = anf_assign40471932;
var anf_assign40481934 = G(Expr363141929.$var,"Expr",L[2271]);
is_DASH_Expr3161933.$var = anf_assign40481934;
var anf_assign40491936 = G(Expr363141929.$var,"is-s-module",L[2270]);
is_DASH_s_DASH_module3171935.$var = anf_assign40491936;
var anf_assign40501938 = G(Expr363141929.$var,"s-module",L[2270]);
s_DASH_module3181937.$var = anf_assign40501938;
var anf_assign40511940 = G(Expr363141929.$var,"is-s-type-let-expr",L[2269]);
is_DASH_s_DASH_type_DASH_let_DASH_expr3191939.$var = anf_assign40511940;
var anf_assign40521942 = G(Expr363141929.$var,"s-type-let-expr",L[2269]);
s_DASH_type_DASH_let_DASH_expr3201941.$var = anf_assign40521942;
var anf_assign40531944 = G(Expr363141929.$var,"is-s-let-expr",L[2268]);
is_DASH_s_DASH_let_DASH_expr3211943.$var = anf_assign40531944;
var anf_assign40541946 = G(Expr363141929.$var,"s-let-expr",L[2268]);
s_DASH_let_DASH_expr3221945.$var = anf_assign40541946;
var anf_assign40551948 = G(Expr363141929.$var,"is-s-letrec",L[2267]);
is_DASH_s_DASH_letrec3231947.$var = anf_assign40551948;
var anf_assign40561950 = G(Expr363141929.$var,"s-letrec",L[2267]);
s_DASH_letrec3241949.$var = anf_assign40561950;
var anf_assign40571952 = G(Expr363141929.$var,"is-s-hint-exp",L[2266]);
is_DASH_s_DASH_hint_DASH_exp3251951.$var = anf_assign40571952;
var anf_assign40581954 = G(Expr363141929.$var,"s-hint-exp",L[2266]);
s_DASH_hint_DASH_exp3261953.$var = anf_assign40581954;
var anf_assign40591956 = G(Expr363141929.$var,"is-s-instantiate",L[2265]);
is_DASH_s_DASH_instantiate3271955.$var = anf_assign40591956;
var anf_assign40601958 = G(Expr363141929.$var,"s-instantiate",L[2265]);
s_DASH_instantiate3281957.$var = anf_assign40601958;
var anf_assign40611960 = G(Expr363141929.$var,"is-s-block",L[2264]);
is_DASH_s_DASH_block3291959.$var = anf_assign40611960;
var anf_assign40621962 = G(Expr363141929.$var,"s-block",L[2264]);
s_DASH_block3301961.$var = anf_assign40621962;
var anf_assign40631964 = G(Expr363141929.$var,"is-s-user-block",L[2263]);
is_DASH_s_DASH_user_DASH_block3311963.$var = anf_assign40631964;
var anf_assign40641966 = G(Expr363141929.$var,"s-user-block",L[2263]);
s_DASH_user_DASH_block3321965.$var = anf_assign40641966;
var anf_assign40651968 = G(Expr363141929.$var,"is-s-fun",L[2262]);
is_DASH_s_DASH_fun3331967.$var = anf_assign40651968;
var anf_assign40661970 = G(Expr363141929.$var,"s-fun",L[2262]);
s_DASH_fun3341969.$var = anf_assign40661970;
var anf_assign40671972 = G(Expr363141929.$var,"is-s-type",L[2261]);
is_DASH_s_DASH_type3351971.$var = anf_assign40671972;
var anf_assign40681974 = G(Expr363141929.$var,"s-type",L[2261]);
s_DASH_type3361973.$var = anf_assign40681974;
var anf_assign40691976 = G(Expr363141929.$var,"is-s-newtype",L[2260]);
is_DASH_s_DASH_newtype3371975.$var = anf_assign40691976;
var anf_assign40701978 = G(Expr363141929.$var,"s-newtype",L[2260]);
s_DASH_newtype3381977.$var = anf_assign40701978;
var anf_assign40711980 = G(Expr363141929.$var,"is-s-var",L[2259]);
is_DASH_s_DASH_var3391979.$var = anf_assign40711980;
var anf_assign40721982 = G(Expr363141929.$var,"s-var",L[2259]);
s_DASH_var3401981.$var = anf_assign40721982;
var anf_assign40731984 = G(Expr363141929.$var,"is-s-let",L[2258]);
is_DASH_s_DASH_let3411983.$var = anf_assign40731984;
var anf_assign40741986 = G(Expr363141929.$var,"s-let",L[2258]);
s_DASH_let3421985.$var = anf_assign40741986;
var anf_assign40751988 = G(Expr363141929.$var,"is-s-graph",L[2257]);
is_DASH_s_DASH_graph3431987.$var = anf_assign40751988;
var anf_assign40761990 = G(Expr363141929.$var,"s-graph",L[2257]);
s_DASH_graph3441989.$var = anf_assign40761990;
var anf_assign40771992 = G(Expr363141929.$var,"is-s-contract",L[2256]);
is_DASH_s_DASH_contract3451991.$var = anf_assign40771992;
var anf_assign40781994 = G(Expr363141929.$var,"s-contract",L[2256]);
s_DASH_contract3461993.$var = anf_assign40781994;
var anf_assign40791996 = G(Expr363141929.$var,"is-s-when",L[2255]);
is_DASH_s_DASH_when3471995.$var = anf_assign40791996;
var anf_assign40801998 = G(Expr363141929.$var,"s-when",L[2255]);
s_DASH_when3481997.$var = anf_assign40801998;
var anf_assign40812000 = G(Expr363141929.$var,"is-s-assign",L[2254]);
is_DASH_s_DASH_assign3491999.$var = anf_assign40812000;
var anf_assign40822002 = G(Expr363141929.$var,"s-assign",L[2254]);
s_DASH_assign3502001.$var = anf_assign40822002;
var anf_assign40832004 = G(Expr363141929.$var,"is-s-if-pipe",L[2253]);
is_DASH_s_DASH_if_DASH_pipe3512003.$var = anf_assign40832004;
var anf_assign40842006 = G(Expr363141929.$var,"s-if-pipe",L[2253]);
s_DASH_if_DASH_pipe3522005.$var = anf_assign40842006;
var anf_assign40852008 = G(Expr363141929.$var,"is-s-if-pipe-else",L[2252]);
is_DASH_s_DASH_if_DASH_pipe_DASH_else3532007.$var = anf_assign40852008;
var anf_assign40862010 = G(Expr363141929.$var,"s-if-pipe-else",L[2252]);
s_DASH_if_DASH_pipe_DASH_else3542009.$var = anf_assign40862010;
var anf_assign40872012 = G(Expr363141929.$var,"is-s-if",L[2251]);
is_DASH_s_DASH_if3552011.$var = anf_assign40872012;
var anf_assign40882014 = G(Expr363141929.$var,"s-if",L[2251]);
s_DASH_if3562013.$var = anf_assign40882014;
var anf_assign40892016 = G(Expr363141929.$var,"is-s-if-else",L[2250]);
is_DASH_s_DASH_if_DASH_else3572015.$var = anf_assign40892016;
var anf_assign40902018 = G(Expr363141929.$var,"s-if-else",L[2250]);
s_DASH_if_DASH_else3582017.$var = anf_assign40902018;
var anf_assign40912020 = G(Expr363141929.$var,"is-s-cases",L[2249]);
is_DASH_s_DASH_cases3592019.$var = anf_assign40912020;
var anf_assign40922022 = G(Expr363141929.$var,"s-cases",L[2249]);
s_DASH_cases3602021.$var = anf_assign40922022;
var anf_assign40932024 = G(Expr363141929.$var,"is-s-cases-else",L[2248]);
is_DASH_s_DASH_cases_DASH_else3612023.$var = anf_assign40932024;
var anf_assign40942026 = G(Expr363141929.$var,"s-cases-else",L[2248]);
s_DASH_cases_DASH_else3622025.$var = anf_assign40942026;
var anf_assign40952028 = G(Expr363141929.$var,"is-s-try",L[2247]);
is_DASH_s_DASH_try3632027.$var = anf_assign40952028;
var anf_assign40962030 = G(Expr363141929.$var,"s-try",L[2247]);
s_DASH_try3642029.$var = anf_assign40962030;
var anf_assign40972032 = G(Expr363141929.$var,"is-s-op",L[2246]);
is_DASH_s_DASH_op3652031.$var = anf_assign40972032;
var anf_assign40982034 = G(Expr363141929.$var,"s-op",L[2246]);
s_DASH_op3662033.$var = anf_assign40982034;
var anf_assign40992036 = G(Expr363141929.$var,"is-s-check-test",L[2245]);
is_DASH_s_DASH_check_DASH_test3672035.$var = anf_assign40992036;
var anf_assign41002038 = G(Expr363141929.$var,"s-check-test",L[2245]);
s_DASH_check_DASH_test3682037.$var = anf_assign41002038;
var anf_assign41012040 = G(Expr363141929.$var,"is-s-paren",L[2244]);
is_DASH_s_DASH_paren3692039.$var = anf_assign41012040;
var anf_assign41022042 = G(Expr363141929.$var,"s-paren",L[2244]);
s_DASH_paren3702041.$var = anf_assign41022042;
var anf_assign41032044 = G(Expr363141929.$var,"is-s-lam",L[2243]);
is_DASH_s_DASH_lam3712043.$var = anf_assign41032044;
var anf_assign41042046 = G(Expr363141929.$var,"s-lam",L[2243]);
s_DASH_lam3722045.$var = anf_assign41042046;
var anf_assign41052048 = G(Expr363141929.$var,"is-s-method",L[2242]);
is_DASH_s_DASH_method3732047.$var = anf_assign41052048;
var anf_assign41062050 = G(Expr363141929.$var,"s-method",L[2242]);
s_DASH_method3742049.$var = anf_assign41062050;
var anf_assign41072052 = G(Expr363141929.$var,"is-s-extend",L[2241]);
is_DASH_s_DASH_extend3752051.$var = anf_assign41072052;
var anf_assign41082054 = G(Expr363141929.$var,"s-extend",L[2241]);
s_DASH_extend3762053.$var = anf_assign41082054;
var anf_assign41092056 = G(Expr363141929.$var,"is-s-update",L[2240]);
is_DASH_s_DASH_update3772055.$var = anf_assign41092056;
var anf_assign41102058 = G(Expr363141929.$var,"s-update",L[2240]);
s_DASH_update3782057.$var = anf_assign41102058;
var anf_assign41112060 = G(Expr363141929.$var,"is-s-obj",L[2239]);
is_DASH_s_DASH_obj3792059.$var = anf_assign41112060;
var anf_assign41122062 = G(Expr363141929.$var,"s-obj",L[2239]);
s_DASH_obj3802061.$var = anf_assign41122062;
var anf_assign41132064 = G(Expr363141929.$var,"is-s-array",L[2238]);
is_DASH_s_DASH_array3812063.$var = anf_assign41132064;
var anf_assign41142066 = G(Expr363141929.$var,"s-array",L[2238]);
s_DASH_array3822065.$var = anf_assign41142066;
var anf_assign41152068 = G(Expr363141929.$var,"is-s-construct",L[2237]);
is_DASH_s_DASH_construct3832067.$var = anf_assign41152068;
var anf_assign41162070 = G(Expr363141929.$var,"s-construct",L[2237]);
s_DASH_construct3842069.$var = anf_assign41162070;
var anf_assign41172072 = G(Expr363141929.$var,"is-s-confirm",L[2236]);
is_DASH_s_DASH_confirm3852071.$var = anf_assign41172072;
var anf_assign41182074 = G(Expr363141929.$var,"s-confirm",L[2236]);
s_DASH_confirm3862073.$var = anf_assign41182074;
var anf_assign41192076 = G(Expr363141929.$var,"is-s-bless",L[2235]);
is_DASH_s_DASH_bless3872075.$var = anf_assign41192076;
var anf_assign41202078 = G(Expr363141929.$var,"s-bless",L[2235]);
s_DASH_bless3882077.$var = anf_assign41202078;
var anf_assign41212080 = G(Expr363141929.$var,"is-s-app",L[2234]);
is_DASH_s_DASH_app3892079.$var = anf_assign41212080;
var anf_assign41222082 = G(Expr363141929.$var,"s-app",L[2234]);
s_DASH_app3902081.$var = anf_assign41222082;
var anf_assign41232084 = G(Expr363141929.$var,"is-s-prim-app",L[2233]);
is_DASH_s_DASH_prim_DASH_app3912083.$var = anf_assign41232084;
var anf_assign41242086 = G(Expr363141929.$var,"s-prim-app",L[2233]);
s_DASH_prim_DASH_app3922085.$var = anf_assign41242086;
var anf_assign41252088 = G(Expr363141929.$var,"is-s-prim-val",L[2232]);
is_DASH_s_DASH_prim_DASH_val3932087.$var = anf_assign41252088;
var anf_assign41262090 = G(Expr363141929.$var,"s-prim-val",L[2232]);
s_DASH_prim_DASH_val3942089.$var = anf_assign41262090;
var anf_assign41272092 = G(Expr363141929.$var,"is-s-id",L[2231]);
is_DASH_s_DASH_id3952091.$var = anf_assign41272092;
var anf_assign41282094 = G(Expr363141929.$var,"s-id",L[2231]);
s_DASH_id3962093.$var = anf_assign41282094;
var anf_assign41292096 = G(Expr363141929.$var,"is-s-id-var",L[2230]);
is_DASH_s_DASH_id_DASH_var3972095.$var = anf_assign41292096;
var anf_assign41302098 = G(Expr363141929.$var,"s-id-var",L[2230]);
s_DASH_id_DASH_var3982097.$var = anf_assign41302098;
var anf_assign41312100 = G(Expr363141929.$var,"is-s-id-letrec",L[2229]);
is_DASH_s_DASH_id_DASH_letrec3992099.$var = anf_assign41312100;
var anf_assign41322102 = G(Expr363141929.$var,"s-id-letrec",L[2229]);
s_DASH_id_DASH_letrec4002101.$var = anf_assign41322102;
var anf_assign41332104 = G(Expr363141929.$var,"is-s-undefined",L[2228]);
is_DASH_s_DASH_undefined4012103.$var = anf_assign41332104;
var anf_assign41342106 = G(Expr363141929.$var,"s-undefined",L[2228]);
s_DASH_undefined4022105.$var = anf_assign41342106;
var anf_assign41352108 = G(Expr363141929.$var,"is-s-srcloc",L[2227]);
is_DASH_s_DASH_srcloc4032107.$var = anf_assign41352108;
var anf_assign41362110 = G(Expr363141929.$var,"s-srcloc",L[2227]);
s_DASH_srcloc4042109.$var = anf_assign41362110;
var anf_assign41372112 = G(Expr363141929.$var,"is-s-num",L[2226]);
is_DASH_s_DASH_num4052111.$var = anf_assign41372112;
var anf_assign41382114 = G(Expr363141929.$var,"s-num",L[2226]);
s_DASH_num4062113.$var = anf_assign41382114;
var anf_assign41392116 = G(Expr363141929.$var,"is-s-frac",L[2225]);
is_DASH_s_DASH_frac4072115.$var = anf_assign41392116;
var anf_assign41402118 = G(Expr363141929.$var,"s-frac",L[2225]);
s_DASH_frac4082117.$var = anf_assign41402118;
var anf_assign41412120 = G(Expr363141929.$var,"is-s-bool",L[2224]);
is_DASH_s_DASH_bool4092119.$var = anf_assign41412120;
var anf_assign41422122 = G(Expr363141929.$var,"s-bool",L[2224]);
s_DASH_bool4102121.$var = anf_assign41422122;
var anf_assign41432124 = G(Expr363141929.$var,"is-s-str",L[2223]);
is_DASH_s_DASH_str4112123.$var = anf_assign41432124;
var anf_assign41442126 = G(Expr363141929.$var,"s-str",L[2223]);
s_DASH_str4122125.$var = anf_assign41442126;
var anf_assign41452128 = G(Expr363141929.$var,"is-s-dot",L[2222]);
is_DASH_s_DASH_dot4132127.$var = anf_assign41452128;
var anf_assign41462130 = G(Expr363141929.$var,"s-dot",L[2222]);
s_DASH_dot4142129.$var = anf_assign41462130;
var anf_assign41472132 = G(Expr363141929.$var,"is-s-get-bang",L[2221]);
is_DASH_s_DASH_get_DASH_bang4152131.$var = anf_assign41472132;
var anf_assign41482134 = G(Expr363141929.$var,"s-get-bang",L[2221]);
s_DASH_get_DASH_bang4162133.$var = anf_assign41482134;
var anf_assign41492136 = G(Expr363141929.$var,"is-s-bracket",L[2220]);
is_DASH_s_DASH_bracket4172135.$var = anf_assign41492136;
var anf_assign41502138 = G(Expr363141929.$var,"s-bracket",L[2220]);
s_DASH_bracket4182137.$var = anf_assign41502138;
var anf_assign41512140 = G(Expr363141929.$var,"is-s-data",L[2219]);
is_DASH_s_DASH_data4192139.$var = anf_assign41512140;
var anf_assign41522142 = G(Expr363141929.$var,"s-data",L[2219]);
s_DASH_data4202141.$var = anf_assign41522142;
var anf_assign41532144 = G(Expr363141929.$var,"is-s-data-expr",L[2218]);
is_DASH_s_DASH_data_DASH_expr4212143.$var = anf_assign41532144;
var anf_assign41542146 = G(Expr363141929.$var,"s-data-expr",L[2218]);
s_DASH_data_DASH_expr4222145.$var = anf_assign41542146;
var anf_assign41552148 = G(Expr363141929.$var,"is-s-for",L[2217]);
is_DASH_s_DASH_for4232147.$var = anf_assign41552148;
var anf_assign41562150 = G(Expr363141929.$var,"s-for",L[2217]);
s_DASH_for4242149.$var = anf_assign41562150;
var anf_assign41572152 = G(Expr363141929.$var,"is-s-check",L[2216]);
is_DASH_s_DASH_check4252151.$var = anf_assign41572152;
var anf_assign41582154 = G(Expr363141929.$var,"s-check",L[2216]);
s_DASH_check4262153.$var = anf_assign41582154;
var anf_shared416611896 = R.makeMethod(function(self100712039) {
return function(visitor100812022) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2211],1,arguments);
}
var anf_fun416012021 = G(self100712039,"_match",L[2215]);
var anf_arg416512023 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2212],0,arguments);
}
var anf_fun416212036 = G(self100712039,"label",L[2214]);
var $z1202812029 = D;
var $f1203412035 = function(_) {
return R.isFunction(anf_fun416212036)?anf_fun416212036.app():R.ffi.throwNonFunApp(L[2213],anf_fun416212036,[]);
};
try {
if(--R.GAS > 0) {
$z1202812029 = $f1203412035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1203412035,
"from":L[2213]});
}
} catch($e1202612027) {
if(R.isCont($e1202612027)) {
var $ss1203012031 = {"from":L[2213],
"go":function(anf_arg416312037) {
return $Hanf_arg988612038(anf_arg416312037,_plus55,raise62);
}};
$e1202612027.stack[R.EXN_STACKHEIGHT++] = $ss1203012031;
}
if(R.isPyretException($e1202612027)) {
$e1202612027.pyretStack.push(L[2213]);
}
throw $e1202612027;
}
var $ret1203212033 = $Hanf_arg988612038($z1202812029,_plus55,raise62);
++R.GAS;
return $ret1203212033;
});
var $z1201312014 = D;
var $f1201912020 = function(_) {
return R.isFunction(anf_fun416012021)?anf_fun416012021.app(visitor100812022,anf_arg416512023):R.ffi.throwNonFunApp(L[2211],anf_fun416012021,[visitor100812022,anf_arg416512023]);
};
try {
if(--R.GAS > 0) {
$z1201312014 = $f1201912020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1201912020,
"from":L[2211]});
}
} catch($e1201112012) {
if(R.isCont($e1201112012)) {
var $ss1201512016 = {"from":L[2211],
"go":function(ann_DASH_check_DASH_temp415912024) {
return $Hann_DASH_check_DASH_temp988712025(ann_DASH_check_DASH_temp415912024);
}};
$e1201112012.stack[R.EXN_STACKHEIGHT++] = $ss1201512016;
}
if(R.isPyretException($e1201112012)) {
$e1201112012.pyretStack.push(L[2211]);
}
throw $e1201112012;
}
var $ret1201712018 = $Hann_DASH_check_DASH_temp988712025($z1201312014);
++R.GAS;
return $ret1201712018;
};
},{"length":2});
var anf_singleton_variant_member417711902 = R.makeMethod(function(self51712010) {
return function(cases_DASH_funs51811989,else_DASH_clause51912000) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2203],2,arguments);
}
var if_DASH_52112003 = R.hasField(cases_DASH_funs51811989,("s-construct-normal"));
var if_helper416811987 = R.makeFunction(function(if_helper_arg416912008) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2203],1,arguments);
}
var ann_DASH_check_DASH_temp416712009 = if_helper_arg416912008;
return ann_DASH_check_DASH_temp416712009;
});
var anf_if417212007 = R.isBoolean(if_DASH_52112003);
if(R.isPyretTrue(anf_if417212007)) {
if(R.isPyretTrue(if_DASH_52112003)) {
var call_DASH_s_DASH_construct_DASH_normal51611985 = G(cases_DASH_funs51811989,"s-construct-normal",L[2203]);
var $z1197711978 = D;
var $f1198311984 = function(_) {
return R.isFunction(call_DASH_s_DASH_construct_DASH_normal51611985)?call_DASH_s_DASH_construct_DASH_normal51611985.app():R.ffi.throwNonFunApp(L[2203],call_DASH_s_DASH_construct_DASH_normal51611985,[]);
};
try {
if(--R.GAS > 0) {
$z1197711978 = $f1198311984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1198311984,
"from":L[2203]});
}
} catch($e1197511976) {
if(R.isCont($e1197511976)) {
var $ss1197911980 = {"from":L[2203],
"go":function(cont_tail_arg417511986) {
return $Hcont_tail_arg988811988(cont_tail_arg417511986,if_helper416811987);
}};
$e1197511976.stack[R.EXN_STACKHEIGHT++] = $ss1197911980;
}
if(R.isPyretException($e1197511976)) {
$e1197511976.pyretStack.push(L[2203]);
}
throw $e1197511976;
}
var $ret1198111982 = $Hcont_tail_arg988811988($z1197711978,if_helper416811987);
++R.GAS;
return $ret1198111982;
} else {
var $z1199211993 = D;
var $f1199811999 = function(_) {
return R.isFunction(else_DASH_clause51912000)?else_DASH_clause51912000.app():R.ffi.throwNonFunApp(L[2203],else_DASH_clause51912000,[]);
};
try {
if(--R.GAS > 0) {
$z1199211993 = $f1199811999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1199811999,
"from":L[2203]});
}
} catch($e1199011991) {
if(R.isCont($e1199011991)) {
var $ss1199411995 = {"from":L[2203],
"go":function(cont_tail_arg417312001) {
return $Hcont_tail_arg988912002(cont_tail_arg417312001,if_helper416811987);
}};
$e1199011991.stack[R.EXN_STACKHEIGHT++] = $ss1199411995;
}
if(R.isPyretException($e1199011991)) {
$e1199011991.pyretStack.push(L[2203]);
}
throw $e1199011991;
}
var $ret1199611997 = $Hcont_tail_arg988912002($z1199211993,if_helper416811987);
++R.GAS;
return $ret1199611997;
}
} else {
var cont_tail_arg417012006 = R.throwNonBooleanCondition(L[2203],("if"),if_DASH_52112003);
if(--R.GAS > 0) {
$z1200412005 = R.isFunction(if_helper416811987)?if_helper416811987.app(cont_tail_arg417012006):R.ffi.throwNonFunApp(L[2203],if_helper416811987,[cont_tail_arg417012006]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper416811987)?if_helper416811987.app(cont_tail_arg417012006):R.ffi.throwNonFunApp(L[2203],if_helper416811987,[cont_tail_arg417012006]);
},
"from":L[2203]});
}
++R.GAS;
return $z1200412005;
}
};
},{"length":3});
var anf_singleton_variant_member417911903 = R.makeMethod(function(self52011974) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2203],0,arguments);
}
var ann_DASH_check_DASH_temp417811973 = ("s-construct-normal");
return ann_DASH_check_DASH_temp417811973;
};
},{"length":1});
var anf_singleton_variant_member418111904 = R.makeMethod(function(self100311972) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2210],0,arguments);
}
var ann_DASH_check_DASH_temp418011971 = ("s-construct-normal");
return ann_DASH_check_DASH_temp418011971;
};
},{"length":1});
var anf_singleton_variant_member418311905 = R.makeMethod(function(self100411970) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2209],0,arguments);
}
var ann_DASH_check_DASH_temp418211969 = G(PP170,"mt-doc",L[2208]);
return ann_DASH_check_DASH_temp418211969;
};
},{"length":1});
var anf_singleton_variant_member419411911 = R.makeMethod(function(self52311968) {
return function(cases_DASH_funs52411947,else_DASH_clause52511958) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2202],2,arguments);
}
var if_DASH_52711961 = R.hasField(cases_DASH_funs52411947,("s-construct-lazy"));
var if_helper418511945 = R.makeFunction(function(if_helper_arg418611966) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2202],1,arguments);
}
var ann_DASH_check_DASH_temp418411967 = if_helper_arg418611966;
return ann_DASH_check_DASH_temp418411967;
});
var anf_if418911965 = R.isBoolean(if_DASH_52711961);
if(R.isPyretTrue(anf_if418911965)) {
if(R.isPyretTrue(if_DASH_52711961)) {
var call_DASH_s_DASH_construct_DASH_lazy52211943 = G(cases_DASH_funs52411947,"s-construct-lazy",L[2202]);
var $z1193511936 = D;
var $f1194111942 = function(_) {
return R.isFunction(call_DASH_s_DASH_construct_DASH_lazy52211943)?call_DASH_s_DASH_construct_DASH_lazy52211943.app():R.ffi.throwNonFunApp(L[2202],call_DASH_s_DASH_construct_DASH_lazy52211943,[]);
};
try {
if(--R.GAS > 0) {
$z1193511936 = $f1194111942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1194111942,
"from":L[2202]});
}
} catch($e1193311934) {
if(R.isCont($e1193311934)) {
var $ss1193711938 = {"from":L[2202],
"go":function(cont_tail_arg419211944) {
return $Hcont_tail_arg989011946(cont_tail_arg419211944,if_helper418511945);
}};
$e1193311934.stack[R.EXN_STACKHEIGHT++] = $ss1193711938;
}
if(R.isPyretException($e1193311934)) {
$e1193311934.pyretStack.push(L[2202]);
}
throw $e1193311934;
}
var $ret1193911940 = $Hcont_tail_arg989011946($z1193511936,if_helper418511945);
++R.GAS;
return $ret1193911940;
} else {
var $z1195011951 = D;
var $f1195611957 = function(_) {
return R.isFunction(else_DASH_clause52511958)?else_DASH_clause52511958.app():R.ffi.throwNonFunApp(L[2202],else_DASH_clause52511958,[]);
};
try {
if(--R.GAS > 0) {
$z1195011951 = $f1195611957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1195611957,
"from":L[2202]});
}
} catch($e1194811949) {
if(R.isCont($e1194811949)) {
var $ss1195211953 = {"from":L[2202],
"go":function(cont_tail_arg419011959) {
return $Hcont_tail_arg989111960(cont_tail_arg419011959,if_helper418511945);
}};
$e1194811949.stack[R.EXN_STACKHEIGHT++] = $ss1195211953;
}
if(R.isPyretException($e1194811949)) {
$e1194811949.pyretStack.push(L[2202]);
}
throw $e1194811949;
}
var $ret1195411955 = $Hcont_tail_arg989111960($z1195011951,if_helper418511945);
++R.GAS;
return $ret1195411955;
}
} else {
var cont_tail_arg418711964 = R.throwNonBooleanCondition(L[2202],("if"),if_DASH_52711961);
if(--R.GAS > 0) {
$z1196211963 = R.isFunction(if_helper418511945)?if_helper418511945.app(cont_tail_arg418711964):R.ffi.throwNonFunApp(L[2202],if_helper418511945,[cont_tail_arg418711964]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper418511945)?if_helper418511945.app(cont_tail_arg418711964):R.ffi.throwNonFunApp(L[2202],if_helper418511945,[cont_tail_arg418711964]);
},
"from":L[2202]});
}
++R.GAS;
return $z1196211963;
}
};
},{"length":3});
var anf_singleton_variant_member419611912 = R.makeMethod(function(self52611932) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2202],0,arguments);
}
var ann_DASH_check_DASH_temp419511931 = ("s-construct-lazy");
return ann_DASH_check_DASH_temp419511931;
};
},{"length":1});
var anf_singleton_variant_member419811913 = R.makeMethod(function(self100511930) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2207],0,arguments);
}
var ann_DASH_check_DASH_temp419711929 = ("s-construct-lazy");
return ann_DASH_check_DASH_temp419711929;
};
},{"length":1});
var anf_singleton_variant_member420111914 = R.makeMethod(function(self100611928) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2205],0,arguments);
}
var anf_fun420011925 = G(PP170,"str",L[2206]);
var $z1191711918 = D;
var $f1192311924 = function(_) {
return R.isFunction(anf_fun420011925)?anf_fun420011925.app(("lazy")):R.ffi.throwNonFunApp(L[2205],anf_fun420011925,[("lazy")]);
};
try {
if(--R.GAS > 0) {
$z1191711918 = $f1192311924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1192311924,
"from":L[2205]});
}
} catch($e1191511916) {
if(R.isCont($e1191511916)) {
var $ss1191911920 = {"from":L[2205],
"go":function(ann_DASH_check_DASH_temp419911926) {
return $Hann_DASH_check_DASH_temp989211927(ann_DASH_check_DASH_temp419911926);
}};
$e1191511916.stack[R.EXN_STACKHEIGHT++] = $ss1191911920;
}
if(R.isPyretException($e1191511916)) {
$e1191511916.pyretStack.push(L[2205]);
}
throw $e1191511916;
}
var $ret1192111922 = $Hann_DASH_check_DASH_temp989211927($z1191711918);
++R.GAS;
return $ret1192111922;
};
},{"length":1});
var anf_assign42022156 = (function() {
var $s_DASH_construct_DASH_normal_DASH_base1189711898 = {"visit":anf_shared416611896,
"_match":anf_singleton_variant_member417711902,
"_torepr":anf_singleton_variant_member417911903,
"label":anf_singleton_variant_member418111904,
"tosource":anf_singleton_variant_member418311905};
var $s_DASH_construct_DASH_normal_DASH_brands1190011901 = {"$brand-s-construct-normal11899":true};
$s_DASH_construct_DASH_normal_DASH_brands1190011901[ConstructModifierT1289106._brand] = true
var $s_DASH_construct_DASH_lazy_DASH_base1190611907 = {"visit":anf_shared416611896,
"_match":anf_singleton_variant_member419411911,
"_torepr":anf_singleton_variant_member419611912,
"label":anf_singleton_variant_member419811913,
"tosource":anf_singleton_variant_member420111914};
var $s_DASH_construct_DASH_lazy_DASH_brands1190911910 = {"$brand-s-construct-lazy11908":true};
$s_DASH_construct_DASH_lazy_DASH_brands1190911910[ConstructModifierT1289106._brand] = true
return R.makeObject({"ConstructModifier":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2204],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ConstructModifierT1289106._brand));
}),
"is-s-construct-normal":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2203],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-construct-normal11899"));
}),
"s-construct-normal":R.makeBrandedObject($s_DASH_construct_DASH_normal_DASH_base1189711898,$s_DASH_construct_DASH_normal_DASH_brands1190011901),
"is-s-construct-lazy":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2202],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-construct-lazy11908"));
}),
"s-construct-lazy":R.makeBrandedObject($s_DASH_construct_DASH_lazy_DASH_base1190611907,$s_DASH_construct_DASH_lazy_DASH_brands1190911910)});
})();
ConstructModifier374272155.$var = anf_assign42022156;
var anf_assign42032158 = G(ConstructModifier374272155.$var,"ConstructModifier",L[2204]);
ConstructModifier4282157.$var = anf_assign42032158;
var anf_assign42042160 = G(ConstructModifier374272155.$var,"ConstructModifier",L[2204]);
is_DASH_ConstructModifier4292159.$var = anf_assign42042160;
var anf_assign42052162 = G(ConstructModifier374272155.$var,"is-s-construct-normal",L[2203]);
is_DASH_s_DASH_construct_DASH_normal4302161.$var = anf_assign42052162;
var anf_assign42062164 = G(ConstructModifier374272155.$var,"s-construct-normal",L[2203]);
s_DASH_construct_DASH_normal4312163.$var = anf_assign42062164;
var anf_assign42072166 = G(ConstructModifier374272155.$var,"is-s-construct-lazy",L[2202]);
is_DASH_s_DASH_construct_DASH_lazy4322165.$var = anf_assign42072166;
var anf_assign42082168 = G(ConstructModifier374272155.$var,"s-construct-lazy",L[2202]);
s_DASH_construct_DASH_lazy4332167.$var = anf_assign42082168;
var anf_shared421611783 = R.makeMethod(function(self101511895) {
return function(visitor101611878) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2197],1,arguments);
}
var anf_fun421011877 = G(self101511895,"_match",L[2201]);
var anf_arg421511879 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2198],0,arguments);
}
var anf_fun421211892 = G(self101511895,"label",L[2200]);
var $z1188411885 = D;
var $f1189011891 = function(_) {
return R.isFunction(anf_fun421211892)?anf_fun421211892.app():R.ffi.throwNonFunApp(L[2199],anf_fun421211892,[]);
};
try {
if(--R.GAS > 0) {
$z1188411885 = $f1189011891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1189011891,
"from":L[2199]});
}
} catch($e1188211883) {
if(R.isCont($e1188211883)) {
var $ss1188611887 = {"from":L[2199],
"go":function(anf_arg421311893) {
return $Hanf_arg989511894(anf_arg421311893,_plus55,raise62);
}};
$e1188211883.stack[R.EXN_STACKHEIGHT++] = $ss1188611887;
}
if(R.isPyretException($e1188211883)) {
$e1188211883.pyretStack.push(L[2199]);
}
throw $e1188211883;
}
var $ret1188811889 = $Hanf_arg989511894($z1188411885,_plus55,raise62);
++R.GAS;
return $ret1188811889;
});
var $z1186911870 = D;
var $f1187511876 = function(_) {
return R.isFunction(anf_fun421011877)?anf_fun421011877.app(visitor101611878,anf_arg421511879):R.ffi.throwNonFunApp(L[2197],anf_fun421011877,[visitor101611878,anf_arg421511879]);
};
try {
if(--R.GAS > 0) {
$z1186911870 = $f1187511876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1187511876,
"from":L[2197]});
}
} catch($e1186711868) {
if(R.isCont($e1186711868)) {
var $ss1187111872 = {"from":L[2197],
"go":function(ann_DASH_check_DASH_temp420911880) {
return $Hann_DASH_check_DASH_temp989611881(ann_DASH_check_DASH_temp420911880);
}};
$e1186711868.stack[R.EXN_STACKHEIGHT++] = $ss1187111872;
}
if(R.isPyretException($e1186711868)) {
$e1186711868.pyretStack.push(L[2197]);
}
throw $e1186711868;
}
var $ret1187311874 = $Hann_DASH_check_DASH_temp989611881($z1186911870);
++R.GAS;
return $ret1187311874;
};
},{"length":2});
var anf_variant_member423111789 = R.makeMethod(function(self52911845) {
return function(cases_DASH_funs53011846,else_DASH_clause53111857) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2181],2,arguments);
}
var if_DASH_53311860 = R.hasField(cases_DASH_funs53011846,("s-bind"));
var if_helper421811843 = R.makeFunction(function(if_helper_arg421911865) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2181],1,arguments);
}
var ann_DASH_check_DASH_temp421711866 = if_helper_arg421911865;
return ann_DASH_check_DASH_temp421711866;
});
var anf_if422211864 = R.isBoolean(if_DASH_53311860);
if(R.isPyretTrue(anf_if422211864)) {
if(R.isPyretTrue(if_DASH_53311860)) {
var call_DASH_s_DASH_bind52811837 = G(cases_DASH_funs53011846,"s-bind",L[2181]);
var anf_arg422511838 = G(self52911845,"l",L[2196]);
var anf_arg422611839 = G(self52911845,"shadows",L[2195]);
var anf_arg422711840 = G(self52911845,"id",L[2194]);
var anf_arg422811841 = G(self52911845,"ann",L[2193]);
var $z1182911830 = D;
var $f1183511836 = function(_) {
return R.isFunction(call_DASH_s_DASH_bind52811837)?call_DASH_s_DASH_bind52811837.app(anf_arg422511838,anf_arg422611839,anf_arg422711840,anf_arg422811841):R.ffi.throwNonFunApp(L[2181],call_DASH_s_DASH_bind52811837,[anf_arg422511838,anf_arg422611839,anf_arg422711840,anf_arg422811841]);
};
try {
if(--R.GAS > 0) {
$z1182911830 = $f1183511836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1183511836,
"from":L[2181]});
}
} catch($e1182711828) {
if(R.isCont($e1182711828)) {
var $ss1183111832 = {"from":L[2181],
"go":function(cont_tail_arg422911842) {
return $Hcont_tail_arg989711844(cont_tail_arg422911842,if_helper421811843);
}};
$e1182711828.stack[R.EXN_STACKHEIGHT++] = $ss1183111832;
}
if(R.isPyretException($e1182711828)) {
$e1182711828.pyretStack.push(L[2181]);
}
throw $e1182711828;
}
var $ret1183311834 = $Hcont_tail_arg989711844($z1182911830,if_helper421811843);
++R.GAS;
return $ret1183311834;
} else {
var $z1184911850 = D;
var $f1185511856 = function(_) {
return R.isFunction(else_DASH_clause53111857)?else_DASH_clause53111857.app():R.ffi.throwNonFunApp(L[2181],else_DASH_clause53111857,[]);
};
try {
if(--R.GAS > 0) {
$z1184911850 = $f1185511856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1185511856,
"from":L[2181]});
}
} catch($e1184711848) {
if(R.isCont($e1184711848)) {
var $ss1185111852 = {"from":L[2181],
"go":function(cont_tail_arg422311858) {
return $Hcont_tail_arg989811859(cont_tail_arg422311858,if_helper421811843);
}};
$e1184711848.stack[R.EXN_STACKHEIGHT++] = $ss1185111852;
}
if(R.isPyretException($e1184711848)) {
$e1184711848.pyretStack.push(L[2181]);
}
throw $e1184711848;
}
var $ret1185311854 = $Hcont_tail_arg989811859($z1184911850,if_helper421811843);
++R.GAS;
return $ret1185311854;
}
} else {
var cont_tail_arg422011863 = R.throwNonBooleanCondition(L[2181],("if"),if_DASH_53311860);
if(--R.GAS > 0) {
$z1186111862 = R.isFunction(if_helper421811843)?if_helper421811843.app(cont_tail_arg422011863):R.ffi.throwNonFunApp(L[2181],if_helper421811843,[cont_tail_arg422011863]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper421811843)?if_helper421811843.app(cont_tail_arg422011863):R.ffi.throwNonFunApp(L[2181],if_helper421811843,[cont_tail_arg422011863]);
},
"from":L[2181]});
}
++R.GAS;
return $z1186111862;
}
};
},{"length":3});
var anf_variant_member424911790 = R.makeMethod(function(self53211825) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2181],0,arguments);
}
var anf_arg423311823 = G(self53211825,"l",L[2181]);
var $z1181511816 = D;
var $f1182111822 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg423311823):R.ffi.throwNonFunApp(L[2181],torepr65,[anf_arg423311823]);
};
try {
if(--R.GAS > 0) {
$z1181511816 = $f1182111822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1182111822,
"from":L[2181]});
}
} catch($e1181311814) {
if(R.isCont($e1181311814)) {
var $ss1181711818 = {"from":L[2181],
"go":function(anf_arg423411824) {
return $Hanf_arg991111826(anf_arg423411824,self53211825,_plus55,torepr65);
}};
$e1181311814.stack[R.EXN_STACKHEIGHT++] = $ss1181711818;
}
if(R.isPyretException($e1181311814)) {
$e1181311814.pyretStack.push(L[2181]);
}
throw $e1181311814;
}
var $ret1181911820 = $Hanf_arg991111826($z1181511816,self53211825,_plus55,torepr65);
++R.GAS;
return $ret1181911820;
};
},{"length":1});
var anf_variant_member429511791 = R.makeMethod(function(self101311811) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2192],0,arguments);
}
var anf_arg425111809 = G(self101311811,"ann",L[2191]);
var $z1180111802 = D;
var $f1180711808 = function(_) {
return R.isFunction(is_DASH_a_DASH_blank5062313.$var === D?U(L[2189],"is-a-blank"):is_DASH_a_DASH_blank5062313.$var)?is_DASH_a_DASH_blank5062313.$var === D?U(L[2189],"is-a-blank"):is_DASH_a_DASH_blank5062313.$var.app(anf_arg425111809):R.ffi.throwNonFunApp(L[2190],is_DASH_a_DASH_blank5062313.$var === D?U(L[2189],"is-a-blank"):is_DASH_a_DASH_blank5062313.$var,[anf_arg425111809]);
};
try {
if(--R.GAS > 0) {
$z1180111802 = $f1180711808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1180711808,
"from":L[2190]});
}
} catch($e1179911800) {
if(R.isCont($e1179911800)) {
var $ss1180311804 = {"from":L[2190],
"go":function(if_DASH_53511810) {
return $Hif_DASH_992411812(if_DASH_53511810,INDENT118169,PP170,self101311811,str_DASH_coloncolon135377,_plus55);
}};
$e1179911800.stack[R.EXN_STACKHEIGHT++] = $ss1180311804;
}
if(R.isPyretException($e1179911800)) {
$e1179911800.pyretStack.push(L[2190]);
}
throw $e1179911800;
}
var $ret1180511806 = $Hif_DASH_992411812($z1180111802,INDENT118169,PP170,self101311811,str_DASH_coloncolon135377,_plus55);
++R.GAS;
return $ret1180511806;
};
},{"length":1});
var anf_variant_member429711792 = R.makeMethod(function(self101411798) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2188],0,arguments);
}
var ann_DASH_check_DASH_temp429611797 = ("s_bind");
return ann_DASH_check_DASH_temp429611797;
};
},{"length":1});
var anf_assign42982170 = (function() {
var $s_DASH_bind_DASH_base1178411785 = {"visit":anf_shared421611783,
"_match":anf_variant_member423111789,
"_torepr":anf_variant_member424911790,
"tosource":anf_variant_member429511791,
"label":anf_variant_member429711792};
var $s_DASH_bind_DASH_brands1178711788 = {"$brand-s-bind11786":true};
$s_DASH_bind_DASH_brands1178711788[BindT1391102._brand] = true
return R.makeObject({"Bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2182],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,BindT1391102._brand));
}),
"is-s-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2181],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-bind11786"));
}),
"s-bind":R.makeFunction(function(l100911793,shadows101011794,id101111795,ann101211796) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2183],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Boolean67,Name66133,Ann11299],[l100911793,shadows101011794,id101111795,ann101211796],[L[2184],L[2185],L[2186],L[2187]],function() {
var dict = R.create($s_DASH_bind_DASH_base1178411785);
dict["l"] = l100911793
dict["shadows"] = shadows101011794
dict["id"] = id101111795
dict["ann"] = ann101211796
return R.makeBrandedObject(dict,$s_DASH_bind_DASH_brands1178711788);
});
})});
})();
Bind384342169.$var = anf_assign42982170;
var anf_assign42992172 = G(Bind384342169.$var,"Bind",L[2182]);
Bind4352171.$var = anf_assign42992172;
var anf_assign43002174 = G(Bind384342169.$var,"Bind",L[2182]);
is_DASH_Bind4362173.$var = anf_assign43002174;
var anf_assign43012176 = G(Bind384342169.$var,"is-s-bind",L[2181]);
is_DASH_s_DASH_bind4372175.$var = anf_assign43012176;
var anf_assign43022178 = G(Bind384342169.$var,"s-bind",L[2181]);
s_DASH_bind4382177.$var = anf_assign43022178;
var anf_shared431011395 = R.makeMethod(function(self104511782) {
return function(visitor104611765) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2176],1,arguments);
}
var anf_fun430411764 = G(self104511782,"_match",L[2180]);
var anf_arg430911766 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2177],0,arguments);
}
var anf_fun430611779 = G(self104511782,"label",L[2179]);
var $z1177111772 = D;
var $f1177711778 = function(_) {
return R.isFunction(anf_fun430611779)?anf_fun430611779.app():R.ffi.throwNonFunApp(L[2178],anf_fun430611779,[]);
};
try {
if(--R.GAS > 0) {
$z1177111772 = $f1177711778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1177711778,
"from":L[2178]});
}
} catch($e1176911770) {
if(R.isCont($e1176911770)) {
var $ss1177311774 = {"from":L[2178],
"go":function(anf_arg430711780) {
return $Hanf_arg992711781(anf_arg430711780,_plus55,raise62);
}};
$e1176911770.stack[R.EXN_STACKHEIGHT++] = $ss1177311774;
}
if(R.isPyretException($e1176911770)) {
$e1176911770.pyretStack.push(L[2178]);
}
throw $e1176911770;
}
var $ret1177511776 = $Hanf_arg992711781($z1177111772,_plus55,raise62);
++R.GAS;
return $ret1177511776;
});
var $z1175611757 = D;
var $f1176211763 = function(_) {
return R.isFunction(anf_fun430411764)?anf_fun430411764.app(visitor104611765,anf_arg430911766):R.ffi.throwNonFunApp(L[2176],anf_fun430411764,[visitor104611765,anf_arg430911766]);
};
try {
if(--R.GAS > 0) {
$z1175611757 = $f1176211763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1176211763,
"from":L[2176]});
}
} catch($e1175411755) {
if(R.isCont($e1175411755)) {
var $ss1175811759 = {"from":L[2176],
"go":function(ann_DASH_check_DASH_temp430311767) {
return $Hann_DASH_check_DASH_temp992811768(ann_DASH_check_DASH_temp430311767);
}};
$e1175411755.stack[R.EXN_STACKHEIGHT++] = $ss1175811759;
}
if(R.isPyretException($e1175411755)) {
$e1175411755.pyretStack.push(L[2176]);
}
throw $e1175411755;
}
var $ret1176011761 = $Hann_DASH_check_DASH_temp992811768($z1175611757);
++R.GAS;
return $ret1176011761;
};
},{"length":2});
var anf_variant_member432411401 = R.makeMethod(function(self53811732) {
return function(cases_DASH_funs53911733,else_DASH_clause54011744) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2112],2,arguments);
}
var if_DASH_54211747 = R.hasField(cases_DASH_funs53911733,("s-data-field"));
var if_helper431211730 = R.makeFunction(function(if_helper_arg431311752) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2112],1,arguments);
}
var ann_DASH_check_DASH_temp431111753 = if_helper_arg431311752;
return ann_DASH_check_DASH_temp431111753;
});
var anf_if431611751 = R.isBoolean(if_DASH_54211747);
if(R.isPyretTrue(anf_if431611751)) {
if(R.isPyretTrue(if_DASH_54211747)) {
var call_DASH_s_DASH_data_DASH_field53711725 = G(cases_DASH_funs53911733,"s-data-field",L[2112]);
var anf_arg431911726 = G(self53811732,"l",L[2175]);
var anf_arg432011727 = G(self53811732,"name",L[2174]);
var anf_arg432111728 = G(self53811732,"value",L[2173]);
var $z1171711718 = D;
var $f1172311724 = function(_) {
return R.isFunction(call_DASH_s_DASH_data_DASH_field53711725)?call_DASH_s_DASH_data_DASH_field53711725.app(anf_arg431911726,anf_arg432011727,anf_arg432111728):R.ffi.throwNonFunApp(L[2112],call_DASH_s_DASH_data_DASH_field53711725,[anf_arg431911726,anf_arg432011727,anf_arg432111728]);
};
try {
if(--R.GAS > 0) {
$z1171711718 = $f1172311724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1172311724,
"from":L[2112]});
}
} catch($e1171511716) {
if(R.isCont($e1171511716)) {
var $ss1171911720 = {"from":L[2112],
"go":function(cont_tail_arg432211729) {
return $Hcont_tail_arg992911731(cont_tail_arg432211729,if_helper431211730);
}};
$e1171511716.stack[R.EXN_STACKHEIGHT++] = $ss1171911720;
}
if(R.isPyretException($e1171511716)) {
$e1171511716.pyretStack.push(L[2112]);
}
throw $e1171511716;
}
var $ret1172111722 = $Hcont_tail_arg992911731($z1171711718,if_helper431211730);
++R.GAS;
return $ret1172111722;
} else {
var $z1173611737 = D;
var $f1174211743 = function(_) {
return R.isFunction(else_DASH_clause54011744)?else_DASH_clause54011744.app():R.ffi.throwNonFunApp(L[2112],else_DASH_clause54011744,[]);
};
try {
if(--R.GAS > 0) {
$z1173611737 = $f1174211743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1174211743,
"from":L[2112]});
}
} catch($e1173411735) {
if(R.isCont($e1173411735)) {
var $ss1173811739 = {"from":L[2112],
"go":function(cont_tail_arg431711745) {
return $Hcont_tail_arg993011746(cont_tail_arg431711745,if_helper431211730);
}};
$e1173411735.stack[R.EXN_STACKHEIGHT++] = $ss1173811739;
}
if(R.isPyretException($e1173411735)) {
$e1173411735.pyretStack.push(L[2112]);
}
throw $e1173411735;
}
var $ret1174011741 = $Hcont_tail_arg993011746($z1173611737,if_helper431211730);
++R.GAS;
return $ret1174011741;
}
} else {
var cont_tail_arg431411750 = R.throwNonBooleanCondition(L[2112],("if"),if_DASH_54211747);
if(--R.GAS > 0) {
$z1174811749 = R.isFunction(if_helper431211730)?if_helper431211730.app(cont_tail_arg431411750):R.ffi.throwNonFunApp(L[2112],if_helper431211730,[cont_tail_arg431411750]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper431211730)?if_helper431211730.app(cont_tail_arg431411750):R.ffi.throwNonFunApp(L[2112],if_helper431211730,[cont_tail_arg431411750]);
},
"from":L[2112]});
}
++R.GAS;
return $z1174811749;
}
};
},{"length":3});
var anf_variant_member433811402 = R.makeMethod(function(self54111713) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2112],0,arguments);
}
var anf_arg432611711 = G(self54111713,"l",L[2112]);
var $z1170311704 = D;
var $f1170911710 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg432611711):R.ffi.throwNonFunApp(L[2112],torepr65,[anf_arg432611711]);
};
try {
if(--R.GAS > 0) {
$z1170311704 = $f1170911710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1170911710,
"from":L[2112]});
}
} catch($e1170111702) {
if(R.isCont($e1170111702)) {
var $ss1170511706 = {"from":L[2112],
"go":function(anf_arg432711712) {
return $Hanf_arg994011714(anf_arg432711712,self54111713,_plus55,torepr65);
}};
$e1170111702.stack[R.EXN_STACKHEIGHT++] = $ss1170511706;
}
if(R.isPyretException($e1170111702)) {
$e1170111702.pyretStack.push(L[2112]);
}
throw $e1170111702;
}
var $ret1170711708 = $Hanf_arg994011714($z1170311704,self54111713,_plus55,torepr65);
++R.GAS;
return $ret1170711708;
};
},{"length":1});
var anf_variant_member434011403 = R.makeMethod(function(self102011700) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2172],0,arguments);
}
var ann_DASH_check_DASH_temp433911699 = ("s-data-field");
return ann_DASH_check_DASH_temp433911699;
};
},{"length":1});
var anf_variant_member435111404 = R.makeMethod(function(self102111696) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2171],0,arguments);
}
var anf_fun434211695 = G(PP170,"nest",L[2170]);
var anf_bracket434311698 = G(self102111696,"name",L[2169]);
var anf_fun434411693 = G(anf_bracket434311698,"tosource",L[2168]);
var $z1168511686 = D;
var $f1169111692 = function(_) {
return R.isFunction(anf_fun434411693)?anf_fun434411693.app():R.ffi.throwNonFunApp(L[2167],anf_fun434411693,[]);
};
try {
if(--R.GAS > 0) {
$z1168511686 = $f1169111692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1169111692,
"from":L[2167]});
}
} catch($e1168311684) {
if(R.isCont($e1168311684)) {
var $ss1168711688 = {"from":L[2167],
"go":function(anf_arg434511694) {
return $Hanf_arg994511697(anf_arg434511694,INDENT118169,anf_fun434211695,self102111696,str_DASH_colonspace136390,_plus55);
}};
$e1168311684.stack[R.EXN_STACKHEIGHT++] = $ss1168711688;
}
if(R.isPyretException($e1168311684)) {
$e1168311684.pyretStack.push(L[2167]);
}
throw $e1168311684;
}
var $ret1168911690 = $Hanf_arg994511697($z1168511686,INDENT118169,anf_fun434211695,self102111696,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret1168911690;
};
},{"length":1});
var anf_variant_member436611413 = R.makeMethod(function(self54411661) {
return function(cases_DASH_funs54511662,else_DASH_clause54611673) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2111],2,arguments);
}
var if_DASH_54811676 = R.hasField(cases_DASH_funs54511662,("s-mutable-field"));
var if_helper435311659 = R.makeFunction(function(if_helper_arg435411681) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2111],1,arguments);
}
var ann_DASH_check_DASH_temp435211682 = if_helper_arg435411681;
return ann_DASH_check_DASH_temp435211682;
});
var anf_if435711680 = R.isBoolean(if_DASH_54811676);
if(R.isPyretTrue(anf_if435711680)) {
if(R.isPyretTrue(if_DASH_54811676)) {
var call_DASH_s_DASH_mutable_DASH_field54311653 = G(cases_DASH_funs54511662,"s-mutable-field",L[2111]);
var anf_arg436011654 = G(self54411661,"l",L[2166]);
var anf_arg436111655 = G(self54411661,"name",L[2165]);
var anf_arg436211656 = G(self54411661,"ann",L[2164]);
var anf_arg436311657 = G(self54411661,"value",L[2163]);
var $z1164511646 = D;
var $f1165111652 = function(_) {
return R.isFunction(call_DASH_s_DASH_mutable_DASH_field54311653)?call_DASH_s_DASH_mutable_DASH_field54311653.app(anf_arg436011654,anf_arg436111655,anf_arg436211656,anf_arg436311657):R.ffi.throwNonFunApp(L[2111],call_DASH_s_DASH_mutable_DASH_field54311653,[anf_arg436011654,anf_arg436111655,anf_arg436211656,anf_arg436311657]);
};
try {
if(--R.GAS > 0) {
$z1164511646 = $f1165111652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1165111652,
"from":L[2111]});
}
} catch($e1164311644) {
if(R.isCont($e1164311644)) {
var $ss1164711648 = {"from":L[2111],
"go":function(cont_tail_arg436411658) {
return $Hcont_tail_arg994611660(cont_tail_arg436411658,if_helper435311659);
}};
$e1164311644.stack[R.EXN_STACKHEIGHT++] = $ss1164711648;
}
if(R.isPyretException($e1164311644)) {
$e1164311644.pyretStack.push(L[2111]);
}
throw $e1164311644;
}
var $ret1164911650 = $Hcont_tail_arg994611660($z1164511646,if_helper435311659);
++R.GAS;
return $ret1164911650;
} else {
var $z1166511666 = D;
var $f1167111672 = function(_) {
return R.isFunction(else_DASH_clause54611673)?else_DASH_clause54611673.app():R.ffi.throwNonFunApp(L[2111],else_DASH_clause54611673,[]);
};
try {
if(--R.GAS > 0) {
$z1166511666 = $f1167111672();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1167111672,
"from":L[2111]});
}
} catch($e1166311664) {
if(R.isCont($e1166311664)) {
var $ss1166711668 = {"from":L[2111],
"go":function(cont_tail_arg435811674) {
return $Hcont_tail_arg994711675(cont_tail_arg435811674,if_helper435311659);
}};
$e1166311664.stack[R.EXN_STACKHEIGHT++] = $ss1166711668;
}
if(R.isPyretException($e1166311664)) {
$e1166311664.pyretStack.push(L[2111]);
}
throw $e1166311664;
}
var $ret1166911670 = $Hcont_tail_arg994711675($z1166511666,if_helper435311659);
++R.GAS;
return $ret1166911670;
}
} else {
var cont_tail_arg435511679 = R.throwNonBooleanCondition(L[2111],("if"),if_DASH_54811676);
if(--R.GAS > 0) {
$z1167711678 = R.isFunction(if_helper435311659)?if_helper435311659.app(cont_tail_arg435511679):R.ffi.throwNonFunApp(L[2111],if_helper435311659,[cont_tail_arg435511679]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper435311659)?if_helper435311659.app(cont_tail_arg435511679):R.ffi.throwNonFunApp(L[2111],if_helper435311659,[cont_tail_arg435511679]);
},
"from":L[2111]});
}
++R.GAS;
return $z1167711678;
}
};
},{"length":3});
var anf_variant_member438411414 = R.makeMethod(function(self54711641) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2111],0,arguments);
}
var anf_arg436811639 = G(self54711641,"l",L[2111]);
var $z1163111632 = D;
var $f1163711638 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg436811639):R.ffi.throwNonFunApp(L[2111],torepr65,[anf_arg436811639]);
};
try {
if(--R.GAS > 0) {
$z1163111632 = $f1163711638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1163711638,
"from":L[2111]});
}
} catch($e1162911630) {
if(R.isCont($e1162911630)) {
var $ss1163311634 = {"from":L[2111],
"go":function(anf_arg436911640) {
return $Hanf_arg996011642(anf_arg436911640,self54711641,_plus55,torepr65);
}};
$e1162911630.stack[R.EXN_STACKHEIGHT++] = $ss1163311634;
}
if(R.isPyretException($e1162911630)) {
$e1162911630.pyretStack.push(L[2111]);
}
throw $e1162911630;
}
var $ret1163511636 = $Hanf_arg996011642($z1163111632,self54711641,_plus55,torepr65);
++R.GAS;
return $ret1163511636;
};
},{"length":1});
var anf_variant_member438611415 = R.makeMethod(function(self102611628) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2162],0,arguments);
}
var ann_DASH_check_DASH_temp438511627 = ("s-mutable-field");
return ann_DASH_check_DASH_temp438511627;
};
},{"length":1});
var anf_variant_member440311416 = R.makeMethod(function(self102711624) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2161],0,arguments);
}
var anf_fun438811623 = G(PP170,"nest",L[2160]);
var anf_bracket438911626 = G(self102711624,"name",L[2159]);
var anf_fun439011621 = G(anf_bracket438911626,"tosource",L[2158]);
var $z1161311614 = D;
var $f1161911620 = function(_) {
return R.isFunction(anf_fun439011621)?anf_fun439011621.app():R.ffi.throwNonFunApp(L[2157],anf_fun439011621,[]);
};
try {
if(--R.GAS > 0) {
$z1161311614 = $f1161911620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1161911620,
"from":L[2157]});
}
} catch($e1161111612) {
if(R.isCont($e1161111612)) {
var $ss1161511616 = {"from":L[2157],
"go":function(anf_arg439111622) {
return $Hanf_arg996911625(anf_arg439111622,INDENT118169,anf_fun438811623,self102711624,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_mutable159689,_plus55);
}};
$e1161111612.stack[R.EXN_STACKHEIGHT++] = $ss1161511616;
}
if(R.isPyretException($e1161111612)) {
$e1161111612.pyretStack.push(L[2157]);
}
throw $e1161111612;
}
var $ret1161711618 = $Hanf_arg996911625($z1161311614,INDENT118169,anf_fun438811623,self102711624,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_mutable159689,_plus55);
++R.GAS;
return $ret1161711618;
};
},{"length":1});
var anf_variant_member441811426 = R.makeMethod(function(self55011589) {
return function(cases_DASH_funs55111590,else_DASH_clause55211601) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2110],2,arguments);
}
var if_DASH_55411604 = R.hasField(cases_DASH_funs55111590,("s-once-field"));
var if_helper440511587 = R.makeFunction(function(if_helper_arg440611609) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2110],1,arguments);
}
var ann_DASH_check_DASH_temp440411610 = if_helper_arg440611609;
return ann_DASH_check_DASH_temp440411610;
});
var anf_if440911608 = R.isBoolean(if_DASH_55411604);
if(R.isPyretTrue(anf_if440911608)) {
if(R.isPyretTrue(if_DASH_55411604)) {
var call_DASH_s_DASH_once_DASH_field54911581 = G(cases_DASH_funs55111590,"s-once-field",L[2110]);
var anf_arg441211582 = G(self55011589,"l",L[2156]);
var anf_arg441311583 = G(self55011589,"name",L[2155]);
var anf_arg441411584 = G(self55011589,"ann",L[2154]);
var anf_arg441511585 = G(self55011589,"value",L[2153]);
var $z1157311574 = D;
var $f1157911580 = function(_) {
return R.isFunction(call_DASH_s_DASH_once_DASH_field54911581)?call_DASH_s_DASH_once_DASH_field54911581.app(anf_arg441211582,anf_arg441311583,anf_arg441411584,anf_arg441511585):R.ffi.throwNonFunApp(L[2110],call_DASH_s_DASH_once_DASH_field54911581,[anf_arg441211582,anf_arg441311583,anf_arg441411584,anf_arg441511585]);
};
try {
if(--R.GAS > 0) {
$z1157311574 = $f1157911580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1157911580,
"from":L[2110]});
}
} catch($e1157111572) {
if(R.isCont($e1157111572)) {
var $ss1157511576 = {"from":L[2110],
"go":function(cont_tail_arg441611586) {
return $Hcont_tail_arg997011588(cont_tail_arg441611586,if_helper440511587);
}};
$e1157111572.stack[R.EXN_STACKHEIGHT++] = $ss1157511576;
}
if(R.isPyretException($e1157111572)) {
$e1157111572.pyretStack.push(L[2110]);
}
throw $e1157111572;
}
var $ret1157711578 = $Hcont_tail_arg997011588($z1157311574,if_helper440511587);
++R.GAS;
return $ret1157711578;
} else {
var $z1159311594 = D;
var $f1159911600 = function(_) {
return R.isFunction(else_DASH_clause55211601)?else_DASH_clause55211601.app():R.ffi.throwNonFunApp(L[2110],else_DASH_clause55211601,[]);
};
try {
if(--R.GAS > 0) {
$z1159311594 = $f1159911600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1159911600,
"from":L[2110]});
}
} catch($e1159111592) {
if(R.isCont($e1159111592)) {
var $ss1159511596 = {"from":L[2110],
"go":function(cont_tail_arg441011602) {
return $Hcont_tail_arg997111603(cont_tail_arg441011602,if_helper440511587);
}};
$e1159111592.stack[R.EXN_STACKHEIGHT++] = $ss1159511596;
}
if(R.isPyretException($e1159111592)) {
$e1159111592.pyretStack.push(L[2110]);
}
throw $e1159111592;
}
var $ret1159711598 = $Hcont_tail_arg997111603($z1159311594,if_helper440511587);
++R.GAS;
return $ret1159711598;
}
} else {
var cont_tail_arg440711607 = R.throwNonBooleanCondition(L[2110],("if"),if_DASH_55411604);
if(--R.GAS > 0) {
$z1160511606 = R.isFunction(if_helper440511587)?if_helper440511587.app(cont_tail_arg440711607):R.ffi.throwNonFunApp(L[2110],if_helper440511587,[cont_tail_arg440711607]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper440511587)?if_helper440511587.app(cont_tail_arg440711607):R.ffi.throwNonFunApp(L[2110],if_helper440511587,[cont_tail_arg440711607]);
},
"from":L[2110]});
}
++R.GAS;
return $z1160511606;
}
};
},{"length":3});
var anf_variant_member443611427 = R.makeMethod(function(self55311569) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2110],0,arguments);
}
var anf_arg442011567 = G(self55311569,"l",L[2110]);
var $z1155911560 = D;
var $f1156511566 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg442011567):R.ffi.throwNonFunApp(L[2110],torepr65,[anf_arg442011567]);
};
try {
if(--R.GAS > 0) {
$z1155911560 = $f1156511566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1156511566,
"from":L[2110]});
}
} catch($e1155711558) {
if(R.isCont($e1155711558)) {
var $ss1156111562 = {"from":L[2110],
"go":function(anf_arg442111568) {
return $Hanf_arg998411570(anf_arg442111568,self55311569,_plus55,torepr65);
}};
$e1155711558.stack[R.EXN_STACKHEIGHT++] = $ss1156111562;
}
if(R.isPyretException($e1155711558)) {
$e1155711558.pyretStack.push(L[2110]);
}
throw $e1155711558;
}
var $ret1156311564 = $Hanf_arg998411570($z1155911560,self55311569,_plus55,torepr65);
++R.GAS;
return $ret1156311564;
};
},{"length":1});
var anf_variant_member443811428 = R.makeMethod(function(self103211556) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2152],0,arguments);
}
var ann_DASH_check_DASH_temp443711555 = ("s-once-field");
return ann_DASH_check_DASH_temp443711555;
};
},{"length":1});
var anf_variant_member445611438 = R.makeMethod(function(self55611533) {
return function(cases_DASH_funs55711534,else_DASH_clause55811545) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2109],2,arguments);
}
var if_DASH_56011548 = R.hasField(cases_DASH_funs55711534,("s-method-field"));
var if_helper444011531 = R.makeFunction(function(if_helper_arg444111553) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2109],1,arguments);
}
var ann_DASH_check_DASH_temp443911554 = if_helper_arg444111553;
return ann_DASH_check_DASH_temp443911554;
});
var anf_if444411552 = R.isBoolean(if_DASH_56011548);
if(R.isPyretTrue(anf_if444411552)) {
if(R.isPyretTrue(if_DASH_56011548)) {
var call_DASH_s_DASH_method_DASH_field55511522 = G(cases_DASH_funs55711534,"s-method-field",L[2109]);
var anf_arg444711523 = G(self55611533,"l",L[2151]);
var anf_arg444811524 = G(self55611533,"name",L[2150]);
var anf_arg444911525 = G(self55611533,"args",L[2149]);
var anf_arg445011526 = G(self55611533,"ann",L[2148]);
var anf_arg445111527 = G(self55611533,"doc",L[2147]);
var anf_arg445211528 = G(self55611533,"body",L[2146]);
var anf_arg445311529 = G(self55611533,"_check",L[2145]);
var $z1151411515 = D;
var $f1152011521 = function(_) {
return R.isFunction(call_DASH_s_DASH_method_DASH_field55511522)?call_DASH_s_DASH_method_DASH_field55511522.app(anf_arg444711523,anf_arg444811524,anf_arg444911525,anf_arg445011526,anf_arg445111527,anf_arg445211528,anf_arg445311529):R.ffi.throwNonFunApp(L[2109],call_DASH_s_DASH_method_DASH_field55511522,[anf_arg444711523,anf_arg444811524,anf_arg444911525,anf_arg445011526,anf_arg445111527,anf_arg445211528,anf_arg445311529]);
};
try {
if(--R.GAS > 0) {
$z1151411515 = $f1152011521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1152011521,
"from":L[2109]});
}
} catch($e1151211513) {
if(R.isCont($e1151211513)) {
var $ss1151611517 = {"from":L[2109],
"go":function(cont_tail_arg445411530) {
return $Hcont_tail_arg998511532(cont_tail_arg445411530,if_helper444011531);
}};
$e1151211513.stack[R.EXN_STACKHEIGHT++] = $ss1151611517;
}
if(R.isPyretException($e1151211513)) {
$e1151211513.pyretStack.push(L[2109]);
}
throw $e1151211513;
}
var $ret1151811519 = $Hcont_tail_arg998511532($z1151411515,if_helper444011531);
++R.GAS;
return $ret1151811519;
} else {
var $z1153711538 = D;
var $f1154311544 = function(_) {
return R.isFunction(else_DASH_clause55811545)?else_DASH_clause55811545.app():R.ffi.throwNonFunApp(L[2109],else_DASH_clause55811545,[]);
};
try {
if(--R.GAS > 0) {
$z1153711538 = $f1154311544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1154311544,
"from":L[2109]});
}
} catch($e1153511536) {
if(R.isCont($e1153511536)) {
var $ss1153911540 = {"from":L[2109],
"go":function(cont_tail_arg444511546) {
return $Hcont_tail_arg998611547(cont_tail_arg444511546,if_helper444011531);
}};
$e1153511536.stack[R.EXN_STACKHEIGHT++] = $ss1153911540;
}
if(R.isPyretException($e1153511536)) {
$e1153511536.pyretStack.push(L[2109]);
}
throw $e1153511536;
}
var $ret1154111542 = $Hcont_tail_arg998611547($z1153711538,if_helper444011531);
++R.GAS;
return $ret1154111542;
}
} else {
var cont_tail_arg444211551 = R.throwNonBooleanCondition(L[2109],("if"),if_DASH_56011548);
if(--R.GAS > 0) {
$z1154911550 = R.isFunction(if_helper444011531)?if_helper444011531.app(cont_tail_arg444211551):R.ffi.throwNonFunApp(L[2109],if_helper444011531,[cont_tail_arg444211551]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper444011531)?if_helper444011531.app(cont_tail_arg444211551):R.ffi.throwNonFunApp(L[2109],if_helper444011531,[cont_tail_arg444211551]);
},
"from":L[2109]});
}
++R.GAS;
return $z1154911550;
}
};
},{"length":3});
var anf_variant_member448611439 = R.makeMethod(function(self55911510) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2109],0,arguments);
}
var anf_arg445811508 = G(self55911510,"l",L[2109]);
var $z1150011501 = D;
var $f1150611507 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg445811508):R.ffi.throwNonFunApp(L[2109],torepr65,[anf_arg445811508]);
};
try {
if(--R.GAS > 0) {
$z1150011501 = $f1150611507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1150611507,
"from":L[2109]});
}
} catch($e1149811499) {
if(R.isCont($e1149811499)) {
var $ss1150211503 = {"from":L[2109],
"go":function(anf_arg445911509) {
return $Hanf_arg1000811511(anf_arg445911509,self55911510,_plus55,torepr65);
}};
$e1149811499.stack[R.EXN_STACKHEIGHT++] = $ss1150211503;
}
if(R.isPyretException($e1149811499)) {
$e1149811499.pyretStack.push(L[2109]);
}
throw $e1149811499;
}
var $ret1150411505 = $Hanf_arg1000811511($z1150011501,self55911510,_plus55,torepr65);
++R.GAS;
return $ret1150411505;
};
},{"length":1});
var anf_variant_member448811440 = R.makeMethod(function(self104011497) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2144],0,arguments);
}
var ann_DASH_check_DASH_temp448711496 = ("s-method-field");
return ann_DASH_check_DASH_temp448711496;
};
},{"length":1});
var anf_variant_member450411441 = R.makeMethod(function(self104111463) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2143],0,arguments);
}
var cases_DASH_val56111495 = G(self104111463,"name",L[2142]);
var anf_fun449011459 = G(cases_DASH_val56111495,"_match",L[2137]);
var anf_obj449311479 = R.makeFunction(function(l104311480,s104411481) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2140],2,arguments);
}
var anf_fun449211492 = G(PP170,"str",L[2141]);
var $z1148411485 = D;
var $f1149011491 = function(_) {
return R.isFunction(anf_fun449211492)?anf_fun449211492.app(s104411481):R.ffi.throwNonFunApp(L[2140],anf_fun449211492,[s104411481]);
};
try {
if(--R.GAS > 0) {
$z1148411485 = $f1149011491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1149011491,
"from":L[2140]});
}
} catch($e1148211483) {
if(R.isCont($e1148211483)) {
var $ss1148611487 = {"from":L[2140],
"go":function(ann_DASH_check_DASH_temp449111493) {
return $Hann_DASH_check_DASH_temp1000911494(ann_DASH_check_DASH_temp449111493);
}};
$e1148211483.stack[R.EXN_STACKHEIGHT++] = $ss1148611487;
}
if(R.isPyretException($e1148211483)) {
$e1148211483.pyretStack.push(L[2140]);
}
throw $e1148211483;
}
var $ret1148811489 = $Hann_DASH_check_DASH_temp1000911494($z1148411485);
++R.GAS;
return $ret1148811489;
});
var anf_arg449411460 = R.makeObject({"s-str":anf_obj449311479});
var anf_arg449811461 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2137],0,arguments);
}
var anf_bracket449611478 = G(self104111463,"name",L[2139]);
var anf_fun449711475 = G(anf_bracket449611478,"tosource",L[2138]);
var $z1146711468 = D;
var $f1147311474 = function(_) {
return R.isFunction(anf_fun449711475)?anf_fun449711475.app():R.ffi.throwNonFunApp(L[2137],anf_fun449711475,[]);
};
try {
if(--R.GAS > 0) {
$z1146711468 = $f1147311474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1147311474,
"from":L[2137]});
}
} catch($e1146511466) {
if(R.isCont($e1146511466)) {
var $ss1146911470 = {"from":L[2137],
"go":function(ann_DASH_check_DASH_temp449511476) {
return $Hann_DASH_check_DASH_temp1001011477(ann_DASH_check_DASH_temp449511476);
}};
$e1146511466.stack[R.EXN_STACKHEIGHT++] = $ss1146911470;
}
if(R.isPyretException($e1146511466)) {
$e1146511466.pyretStack.push(L[2137]);
}
throw $e1146511466;
}
var $ret1147111472 = $Hann_DASH_check_DASH_temp1001011477($z1146711468);
++R.GAS;
return $ret1147111472;
});
var $z1145111452 = D;
var $f1145711458 = function(_) {
return R.isFunction(anf_fun449011459)?anf_fun449011459.app(anf_arg449411460,anf_arg449811461):R.ffi.throwNonFunApp(L[2136],anf_fun449011459,[anf_arg449411460,anf_arg449811461]);
};
try {
if(--R.GAS > 0) {
$z1145111452 = $f1145711458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1145711458,
"from":L[2136]});
}
} catch($e1144911450) {
if(R.isCont($e1144911450)) {
var $ss1145311454 = {"from":L[2136],
"go":function(name_DASH_part104211462) {
return $Hname_DASH_part1001211464(name_DASH_part104211462,funlam_DASH_tosource2501801,self104111463,nothing61);
}};
$e1144911450.stack[R.EXN_STACKHEIGHT++] = $ss1145311454;
}
if(R.isPyretException($e1144911450)) {
$e1144911450.pyretStack.push(L[2136]);
}
throw $e1144911450;
}
var $ret1145511456 = $Hname_DASH_part1001211464($z1145111452,funlam_DASH_tosource2501801,self104111463,nothing61);
++R.GAS;
return $ret1145511456;
};
},{"length":1});
var anf_assign45052180 = (function() {
var $s_DASH_data_DASH_field_DASH_base1139611397 = {"visit":anf_shared431011395,
"_match":anf_variant_member432411401,
"_torepr":anf_variant_member433811402,
"label":anf_variant_member434011403,
"tosource":anf_variant_member435111404};
var $s_DASH_data_DASH_field_DASH_brands1139911400 = {"$brand-s-data-field11398":true};
$s_DASH_data_DASH_field_DASH_brands1139911400[MemberT1493132._brand] = true
var $s_DASH_mutable_DASH_field_DASH_base1140811409 = {"visit":anf_shared431011395,
"_match":anf_variant_member436611413,
"_torepr":anf_variant_member438411414,
"label":anf_variant_member438611415,
"tosource":anf_variant_member440311416};
var $s_DASH_mutable_DASH_field_DASH_brands1141111412 = {"$brand-s-mutable-field11410":true};
$s_DASH_mutable_DASH_field_DASH_brands1141111412[MemberT1493132._brand] = true
var $s_DASH_once_DASH_field_DASH_base1142111422 = {"visit":anf_shared431011395,
"_match":anf_variant_member441811426,
"_torepr":anf_variant_member443611427,
"label":anf_variant_member443811428};
var $s_DASH_once_DASH_field_DASH_brands1142411425 = {"$brand-s-once-field11423":true};
$s_DASH_once_DASH_field_DASH_brands1142411425[MemberT1493132._brand] = true
var $s_DASH_method_DASH_field_DASH_base1143311434 = {"visit":anf_shared431011395,
"_match":anf_variant_member445611438,
"_torepr":anf_variant_member448611439,
"label":anf_variant_member448811440,
"tosource":anf_variant_member450411441};
var $s_DASH_method_DASH_field_DASH_brands1143611437 = {"$brand-s-method-field11435":true};
$s_DASH_method_DASH_field_DASH_brands1143611437[MemberT1493132._brand] = true
return R.makeObject({"Member":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2113],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,MemberT1493132._brand));
}),
"is-s-data-field":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2112],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-data-field11398"));
}),
"s-data-field":R.makeFunction(function(l101711405,name101811406,value101911407) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2114],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l101711405,name101811406,value101911407],[L[2115],L[2116],L[2117]],function() {
var dict = R.create($s_DASH_data_DASH_field_DASH_base1139611397);
dict["l"] = l101711405
dict["name"] = name101811406
dict["value"] = value101911407
return R.makeBrandedObject(dict,$s_DASH_data_DASH_field_DASH_brands1139911400);
});
}),
"is-s-mutable-field":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2111],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-mutable-field11410"));
}),
"s-mutable-field":R.makeFunction(function(l102211417,name102311418,ann102411419,value102511420) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2118],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Ann11299,Expr86111],[l102211417,name102311418,ann102411419,value102511420],[L[2119],L[2120],L[2121],L[2122]],function() {
var dict = R.create($s_DASH_mutable_DASH_field_DASH_base1140811409);
dict["l"] = l102211417
dict["name"] = name102311418
dict["ann"] = ann102411419
dict["value"] = value102511420
return R.makeBrandedObject(dict,$s_DASH_mutable_DASH_field_DASH_brands1141111412);
});
}),
"is-s-once-field":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2110],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-once-field11423"));
}),
"s-once-field":R.makeFunction(function(l102811429,name102911430,ann103011431,value103111432) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[2123],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Ann11299,Expr86111],[l102811429,name102911430,ann103011431,value103111432],[L[2124],L[2125],L[2126],L[2127]],function() {
var dict = R.create($s_DASH_once_DASH_field_DASH_base1142111422);
dict["l"] = l102811429
dict["name"] = name102911430
dict["ann"] = ann103011431
dict["value"] = value103111432
return R.makeBrandedObject(dict,$s_DASH_once_DASH_field_DASH_brands1142411425);
});
}),
"is-s-method-field":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2109],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-method-field11435"));
}),
"s-method-field":R.makeFunction(function(l103311442,name103411443,args103511444,ann103611445,doc103711446,body103811447,_check103911448) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[2128],7,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l103311442,name103411443,args103511444,ann103611445,doc103711446,body103811447,_check103911448],[L[2129],L[2130],L[2131],L[2132],L[2133],L[2134],L[2135]],function() {
var dict = R.create($s_DASH_method_DASH_field_DASH_base1143311434);
dict["l"] = l103311442
dict["name"] = name103411443
dict["args"] = args103511444
dict["ann"] = ann103611445
dict["doc"] = doc103711446
dict["body"] = body103811447
dict["_check"] = _check103911448
return R.makeBrandedObject(dict,$s_DASH_method_DASH_field_DASH_brands1143611437);
});
})});
})();
Member394392179.$var = anf_assign45052180;
var anf_assign45062182 = G(Member394392179.$var,"Member",L[2113]);
Member4402181.$var = anf_assign45062182;
var anf_assign45072184 = G(Member394392179.$var,"Member",L[2113]);
is_DASH_Member4412183.$var = anf_assign45072184;
var anf_assign45082186 = G(Member394392179.$var,"is-s-data-field",L[2112]);
is_DASH_s_DASH_data_DASH_field4422185.$var = anf_assign45082186;
var anf_assign45092188 = G(Member394392179.$var,"s-data-field",L[2112]);
s_DASH_data_DASH_field4432187.$var = anf_assign45092188;
var anf_assign45102190 = G(Member394392179.$var,"is-s-mutable-field",L[2111]);
is_DASH_s_DASH_mutable_DASH_field4442189.$var = anf_assign45102190;
var anf_assign45112192 = G(Member394392179.$var,"s-mutable-field",L[2111]);
s_DASH_mutable_DASH_field4452191.$var = anf_assign45112192;
var anf_assign45122194 = G(Member394392179.$var,"is-s-once-field",L[2110]);
is_DASH_s_DASH_once_DASH_field4462193.$var = anf_assign45122194;
var anf_assign45132196 = G(Member394392179.$var,"s-once-field",L[2110]);
s_DASH_once_DASH_field4472195.$var = anf_assign45132196;
var anf_assign45142198 = G(Member394392179.$var,"is-s-method-field",L[2109]);
is_DASH_s_DASH_method_DASH_field4482197.$var = anf_assign45142198;
var anf_assign45152200 = G(Member394392179.$var,"s-method-field",L[2109]);
s_DASH_method_DASH_field4492199.$var = anf_assign45152200;
var anf_shared452311282 = R.makeMethod(function(self105211394) {
return function(visitor105311377) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2104],1,arguments);
}
var anf_fun451711376 = G(self105211394,"_match",L[2108]);
var anf_arg452211378 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2105],0,arguments);
}
var anf_fun451911391 = G(self105211394,"label",L[2107]);
var $z1138311384 = D;
var $f1138911390 = function(_) {
return R.isFunction(anf_fun451911391)?anf_fun451911391.app():R.ffi.throwNonFunApp(L[2106],anf_fun451911391,[]);
};
try {
if(--R.GAS > 0) {
$z1138311384 = $f1138911390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1138911390,
"from":L[2106]});
}
} catch($e1138111382) {
if(R.isCont($e1138111382)) {
var $ss1138511386 = {"from":L[2106],
"go":function(anf_arg452011392) {
return $Hanf_arg1001511393(anf_arg452011392,_plus55,raise62);
}};
$e1138111382.stack[R.EXN_STACKHEIGHT++] = $ss1138511386;
}
if(R.isPyretException($e1138111382)) {
$e1138111382.pyretStack.push(L[2106]);
}
throw $e1138111382;
}
var $ret1138711388 = $Hanf_arg1001511393($z1138311384,_plus55,raise62);
++R.GAS;
return $ret1138711388;
});
var $z1136811369 = D;
var $f1137411375 = function(_) {
return R.isFunction(anf_fun451711376)?anf_fun451711376.app(visitor105311377,anf_arg452211378):R.ffi.throwNonFunApp(L[2104],anf_fun451711376,[visitor105311377,anf_arg452211378]);
};
try {
if(--R.GAS > 0) {
$z1136811369 = $f1137411375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1137411375,
"from":L[2104]});
}
} catch($e1136611367) {
if(R.isCont($e1136611367)) {
var $ss1137011371 = {"from":L[2104],
"go":function(ann_DASH_check_DASH_temp451611379) {
return $Hann_DASH_check_DASH_temp1001611380(ann_DASH_check_DASH_temp451611379);
}};
$e1136611367.stack[R.EXN_STACKHEIGHT++] = $ss1137011371;
}
if(R.isPyretException($e1136611367)) {
$e1136611367.pyretStack.push(L[2104]);
}
throw $e1136611367;
}
var $ret1137211373 = $Hann_DASH_check_DASH_temp1001611380($z1136811369);
++R.GAS;
return $ret1137211373;
};
},{"length":2});
var anf_variant_member453711288 = R.makeMethod(function(self56311344) {
return function(cases_DASH_funs56411345,else_DASH_clause56511356) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2089],2,arguments);
}
var if_DASH_56711359 = R.hasField(cases_DASH_funs56411345,("s-for-bind"));
var if_helper452511342 = R.makeFunction(function(if_helper_arg452611364) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2089],1,arguments);
}
var ann_DASH_check_DASH_temp452411365 = if_helper_arg452611364;
return ann_DASH_check_DASH_temp452411365;
});
var anf_if452911363 = R.isBoolean(if_DASH_56711359);
if(R.isPyretTrue(anf_if452911363)) {
if(R.isPyretTrue(if_DASH_56711359)) {
var call_DASH_s_DASH_for_DASH_bind56211337 = G(cases_DASH_funs56411345,"s-for-bind",L[2089]);
var anf_arg453211338 = G(self56311344,"l",L[2103]);
var anf_arg453311339 = G(self56311344,"bind",L[2102]);
var anf_arg453411340 = G(self56311344,"value",L[2101]);
var $z1132911330 = D;
var $f1133511336 = function(_) {
return R.isFunction(call_DASH_s_DASH_for_DASH_bind56211337)?call_DASH_s_DASH_for_DASH_bind56211337.app(anf_arg453211338,anf_arg453311339,anf_arg453411340):R.ffi.throwNonFunApp(L[2089],call_DASH_s_DASH_for_DASH_bind56211337,[anf_arg453211338,anf_arg453311339,anf_arg453411340]);
};
try {
if(--R.GAS > 0) {
$z1132911330 = $f1133511336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1133511336,
"from":L[2089]});
}
} catch($e1132711328) {
if(R.isCont($e1132711328)) {
var $ss1133111332 = {"from":L[2089],
"go":function(cont_tail_arg453511341) {
return $Hcont_tail_arg1001711343(cont_tail_arg453511341,if_helper452511342);
}};
$e1132711328.stack[R.EXN_STACKHEIGHT++] = $ss1133111332;
}
if(R.isPyretException($e1132711328)) {
$e1132711328.pyretStack.push(L[2089]);
}
throw $e1132711328;
}
var $ret1133311334 = $Hcont_tail_arg1001711343($z1132911330,if_helper452511342);
++R.GAS;
return $ret1133311334;
} else {
var $z1134811349 = D;
var $f1135411355 = function(_) {
return R.isFunction(else_DASH_clause56511356)?else_DASH_clause56511356.app():R.ffi.throwNonFunApp(L[2089],else_DASH_clause56511356,[]);
};
try {
if(--R.GAS > 0) {
$z1134811349 = $f1135411355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1135411355,
"from":L[2089]});
}
} catch($e1134611347) {
if(R.isCont($e1134611347)) {
var $ss1135011351 = {"from":L[2089],
"go":function(cont_tail_arg453011357) {
return $Hcont_tail_arg1001811358(cont_tail_arg453011357,if_helper452511342);
}};
$e1134611347.stack[R.EXN_STACKHEIGHT++] = $ss1135011351;
}
if(R.isPyretException($e1134611347)) {
$e1134611347.pyretStack.push(L[2089]);
}
throw $e1134611347;
}
var $ret1135211353 = $Hcont_tail_arg1001811358($z1134811349,if_helper452511342);
++R.GAS;
return $ret1135211353;
}
} else {
var cont_tail_arg452711362 = R.throwNonBooleanCondition(L[2089],("if"),if_DASH_56711359);
if(--R.GAS > 0) {
$z1136011361 = R.isFunction(if_helper452511342)?if_helper452511342.app(cont_tail_arg452711362):R.ffi.throwNonFunApp(L[2089],if_helper452511342,[cont_tail_arg452711362]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper452511342)?if_helper452511342.app(cont_tail_arg452711362):R.ffi.throwNonFunApp(L[2089],if_helper452511342,[cont_tail_arg452711362]);
},
"from":L[2089]});
}
++R.GAS;
return $z1136011361;
}
};
},{"length":3});
var anf_variant_member455111289 = R.makeMethod(function(self56611325) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2089],0,arguments);
}
var anf_arg453911323 = G(self56611325,"l",L[2089]);
var $z1131511316 = D;
var $f1132111322 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg453911323):R.ffi.throwNonFunApp(L[2089],torepr65,[anf_arg453911323]);
};
try {
if(--R.GAS > 0) {
$z1131511316 = $f1132111322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1132111322,
"from":L[2089]});
}
} catch($e1131311314) {
if(R.isCont($e1131311314)) {
var $ss1131711318 = {"from":L[2089],
"go":function(anf_arg454011324) {
return $Hanf_arg1002811326(anf_arg454011324,self56611325,_plus55,torepr65);
}};
$e1131311314.stack[R.EXN_STACKHEIGHT++] = $ss1131711318;
}
if(R.isPyretException($e1131311314)) {
$e1131311314.pyretStack.push(L[2089]);
}
throw $e1131311314;
}
var $ret1131911320 = $Hanf_arg1002811326($z1131511316,self56611325,_plus55,torepr65);
++R.GAS;
return $ret1131911320;
};
},{"length":1});
var anf_variant_member455311290 = R.makeMethod(function(self105011312) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2100],0,arguments);
}
var ann_DASH_check_DASH_temp455211311 = ("s-for-bind");
return ann_DASH_check_DASH_temp455211311;
};
},{"length":1});
var anf_variant_member456611291 = R.makeMethod(function(self105111308) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2099],0,arguments);
}
var anf_fun455511307 = G(PP170,"group",L[2098]);
var anf_bracket455611310 = G(self105111308,"bind",L[2097]);
var anf_fun455711305 = G(anf_bracket455611310,"tosource",L[2096]);
var $z1129711298 = D;
var $f1130311304 = function(_) {
return R.isFunction(anf_fun455711305)?anf_fun455711305.app():R.ffi.throwNonFunApp(L[2095],anf_fun455711305,[]);
};
try {
if(--R.GAS > 0) {
$z1129711298 = $f1130311304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1130311304,
"from":L[2095]});
}
} catch($e1129511296) {
if(R.isCont($e1129511296)) {
var $ss1129911300 = {"from":L[2095],
"go":function(anf_arg455811306) {
return $Hanf_arg1003511309(anf_arg455811306,anf_fun455511307,break_DASH_one119168,self105111308,str_DASH_from151585,_plus55);
}};
$e1129511296.stack[R.EXN_STACKHEIGHT++] = $ss1129911300;
}
if(R.isPyretException($e1129511296)) {
$e1129511296.pyretStack.push(L[2095]);
}
throw $e1129511296;
}
var $ret1130111302 = $Hanf_arg1003511309($z1129711298,anf_fun455511307,break_DASH_one119168,self105111308,str_DASH_from151585,_plus55);
++R.GAS;
return $ret1130111302;
};
},{"length":1});
var anf_assign45672202 = (function() {
var $s_DASH_for_DASH_bind_DASH_base1128311284 = {"visit":anf_shared452311282,
"_match":anf_variant_member453711288,
"_torepr":anf_variant_member455111289,
"label":anf_variant_member455311290,
"tosource":anf_variant_member456611291};
var $s_DASH_for_DASH_bind_DASH_brands1128611287 = {"$brand-s-for-bind11285":true};
$s_DASH_for_DASH_bind_DASH_brands1128611287[ForBindT1595114._brand] = true
return R.makeObject({"ForBind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2090],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ForBindT1595114._brand));
}),
"is-s-for-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2089],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-for-bind11285"));
}),
"s-for-bind":R.makeFunction(function(l104711292,bind104811293,value104911294) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2091],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l104711292,bind104811293,value104911294],[L[2092],L[2093],L[2094]],function() {
var dict = R.create($s_DASH_for_DASH_bind_DASH_base1128311284);
dict["l"] = l104711292
dict["bind"] = bind104811293
dict["value"] = value104911294
return R.makeBrandedObject(dict,$s_DASH_for_DASH_bind_DASH_brands1128611287);
});
})});
})();
ForBind404502201.$var = anf_assign45672202;
var anf_assign45682204 = G(ForBind404502201.$var,"ForBind",L[2090]);
ForBind4512203.$var = anf_assign45682204;
var anf_assign45692206 = G(ForBind404502201.$var,"ForBind",L[2090]);
is_DASH_ForBind4522205.$var = anf_assign45692206;
var anf_assign45702208 = G(ForBind404502201.$var,"is-s-for-bind",L[2089]);
is_DASH_s_DASH_for_DASH_bind4532207.$var = anf_assign45702208;
var anf_assign45712210 = G(ForBind404502201.$var,"s-for-bind",L[2089]);
s_DASH_for_DASH_bind4542209.$var = anf_assign45712210;
var anf_shared457911075 = R.makeMethod(function(self106011281) {
return function(visitor106111264) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2084],1,arguments);
}
var anf_fun457311263 = G(self106011281,"_match",L[2088]);
var anf_arg457811265 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2085],0,arguments);
}
var anf_fun457511278 = G(self106011281,"label",L[2087]);
var $z1127011271 = D;
var $f1127611277 = function(_) {
return R.isFunction(anf_fun457511278)?anf_fun457511278.app():R.ffi.throwNonFunApp(L[2086],anf_fun457511278,[]);
};
try {
if(--R.GAS > 0) {
$z1127011271 = $f1127611277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1127611277,
"from":L[2086]});
}
} catch($e1126811269) {
if(R.isCont($e1126811269)) {
var $ss1127211273 = {"from":L[2086],
"go":function(anf_arg457611279) {
return $Hanf_arg1003811280(anf_arg457611279,_plus55,raise62);
}};
$e1126811269.stack[R.EXN_STACKHEIGHT++] = $ss1127211273;
}
if(R.isPyretException($e1126811269)) {
$e1126811269.pyretStack.push(L[2086]);
}
throw $e1126811269;
}
var $ret1127411275 = $Hanf_arg1003811280($z1127011271,_plus55,raise62);
++R.GAS;
return $ret1127411275;
});
var $z1125511256 = D;
var $f1126111262 = function(_) {
return R.isFunction(anf_fun457311263)?anf_fun457311263.app(visitor106111264,anf_arg457811265):R.ffi.throwNonFunApp(L[2084],anf_fun457311263,[visitor106111264,anf_arg457811265]);
};
try {
if(--R.GAS > 0) {
$z1125511256 = $f1126111262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1126111262,
"from":L[2084]});
}
} catch($e1125311254) {
if(R.isCont($e1125311254)) {
var $ss1125711258 = {"from":L[2084],
"go":function(ann_DASH_check_DASH_temp457211266) {
return $Hann_DASH_check_DASH_temp1003911267(ann_DASH_check_DASH_temp457211266);
}};
$e1125311254.stack[R.EXN_STACKHEIGHT++] = $ss1125711258;
}
if(R.isPyretException($e1125311254)) {
$e1125311254.pyretStack.push(L[2084]);
}
throw $e1125311254;
}
var $ret1125911260 = $Hann_DASH_check_DASH_temp1003911267($z1125511256);
++R.GAS;
return $ret1125911260;
};
},{"length":2});
var anf_singleton_variant_member459011081 = R.makeMethod(function(self56911252) {
return function(cases_DASH_funs57011231,else_DASH_clause57111242) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2073],2,arguments);
}
var if_DASH_57311245 = R.hasField(cases_DASH_funs57011231,("s-normal"));
var if_helper458111229 = R.makeFunction(function(if_helper_arg458211250) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2073],1,arguments);
}
var ann_DASH_check_DASH_temp458011251 = if_helper_arg458211250;
return ann_DASH_check_DASH_temp458011251;
});
var anf_if458511249 = R.isBoolean(if_DASH_57311245);
if(R.isPyretTrue(anf_if458511249)) {
if(R.isPyretTrue(if_DASH_57311245)) {
var call_DASH_s_DASH_normal56811227 = G(cases_DASH_funs57011231,"s-normal",L[2073]);
var $z1121911220 = D;
var $f1122511226 = function(_) {
return R.isFunction(call_DASH_s_DASH_normal56811227)?call_DASH_s_DASH_normal56811227.app():R.ffi.throwNonFunApp(L[2073],call_DASH_s_DASH_normal56811227,[]);
};
try {
if(--R.GAS > 0) {
$z1121911220 = $f1122511226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1122511226,
"from":L[2073]});
}
} catch($e1121711218) {
if(R.isCont($e1121711218)) {
var $ss1122111222 = {"from":L[2073],
"go":function(cont_tail_arg458811228) {
return $Hcont_tail_arg1004011230(cont_tail_arg458811228,if_helper458111229);
}};
$e1121711218.stack[R.EXN_STACKHEIGHT++] = $ss1122111222;
}
if(R.isPyretException($e1121711218)) {
$e1121711218.pyretStack.push(L[2073]);
}
throw $e1121711218;
}
var $ret1122311224 = $Hcont_tail_arg1004011230($z1121911220,if_helper458111229);
++R.GAS;
return $ret1122311224;
} else {
var $z1123411235 = D;
var $f1124011241 = function(_) {
return R.isFunction(else_DASH_clause57111242)?else_DASH_clause57111242.app():R.ffi.throwNonFunApp(L[2073],else_DASH_clause57111242,[]);
};
try {
if(--R.GAS > 0) {
$z1123411235 = $f1124011241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1124011241,
"from":L[2073]});
}
} catch($e1123211233) {
if(R.isCont($e1123211233)) {
var $ss1123611237 = {"from":L[2073],
"go":function(cont_tail_arg458611243) {
return $Hcont_tail_arg1004111244(cont_tail_arg458611243,if_helper458111229);
}};
$e1123211233.stack[R.EXN_STACKHEIGHT++] = $ss1123611237;
}
if(R.isPyretException($e1123211233)) {
$e1123211233.pyretStack.push(L[2073]);
}
throw $e1123211233;
}
var $ret1123811239 = $Hcont_tail_arg1004111244($z1123411235,if_helper458111229);
++R.GAS;
return $ret1123811239;
}
} else {
var cont_tail_arg458311248 = R.throwNonBooleanCondition(L[2073],("if"),if_DASH_57311245);
if(--R.GAS > 0) {
$z1124611247 = R.isFunction(if_helper458111229)?if_helper458111229.app(cont_tail_arg458311248):R.ffi.throwNonFunApp(L[2073],if_helper458111229,[cont_tail_arg458311248]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper458111229)?if_helper458111229.app(cont_tail_arg458311248):R.ffi.throwNonFunApp(L[2073],if_helper458111229,[cont_tail_arg458311248]);
},
"from":L[2073]});
}
++R.GAS;
return $z1124611247;
}
};
},{"length":3});
var anf_singleton_variant_member459211082 = R.makeMethod(function(self57211216) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2073],0,arguments);
}
var ann_DASH_check_DASH_temp459111215 = ("s-normal");
return ann_DASH_check_DASH_temp459111215;
};
},{"length":1});
var anf_singleton_variant_member459411083 = R.makeMethod(function(self105411214) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2083],0,arguments);
}
var ann_DASH_check_DASH_temp459311213 = ("s-normal");
return ann_DASH_check_DASH_temp459311213;
};
},{"length":1});
var anf_singleton_variant_member459611084 = R.makeMethod(function(self105511212) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2082],0,arguments);
}
var ann_DASH_check_DASH_temp459511211 = G(PP170,"mt-doc",L[2081]);
return ann_DASH_check_DASH_temp459511211;
};
},{"length":1});
var anf_singleton_variant_member460711090 = R.makeMethod(function(self57511210) {
return function(cases_DASH_funs57611189,else_DASH_clause57711200) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2072],2,arguments);
}
var if_DASH_57911203 = R.hasField(cases_DASH_funs57611189,("s-cyclic"));
var if_helper459811187 = R.makeFunction(function(if_helper_arg459911208) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2072],1,arguments);
}
var ann_DASH_check_DASH_temp459711209 = if_helper_arg459911208;
return ann_DASH_check_DASH_temp459711209;
});
var anf_if460211207 = R.isBoolean(if_DASH_57911203);
if(R.isPyretTrue(anf_if460211207)) {
if(R.isPyretTrue(if_DASH_57911203)) {
var call_DASH_s_DASH_cyclic57411185 = G(cases_DASH_funs57611189,"s-cyclic",L[2072]);
var $z1117711178 = D;
var $f1118311184 = function(_) {
return R.isFunction(call_DASH_s_DASH_cyclic57411185)?call_DASH_s_DASH_cyclic57411185.app():R.ffi.throwNonFunApp(L[2072],call_DASH_s_DASH_cyclic57411185,[]);
};
try {
if(--R.GAS > 0) {
$z1117711178 = $f1118311184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1118311184,
"from":L[2072]});
}
} catch($e1117511176) {
if(R.isCont($e1117511176)) {
var $ss1117911180 = {"from":L[2072],
"go":function(cont_tail_arg460511186) {
return $Hcont_tail_arg1004211188(cont_tail_arg460511186,if_helper459811187);
}};
$e1117511176.stack[R.EXN_STACKHEIGHT++] = $ss1117911180;
}
if(R.isPyretException($e1117511176)) {
$e1117511176.pyretStack.push(L[2072]);
}
throw $e1117511176;
}
var $ret1118111182 = $Hcont_tail_arg1004211188($z1117711178,if_helper459811187);
++R.GAS;
return $ret1118111182;
} else {
var $z1119211193 = D;
var $f1119811199 = function(_) {
return R.isFunction(else_DASH_clause57711200)?else_DASH_clause57711200.app():R.ffi.throwNonFunApp(L[2072],else_DASH_clause57711200,[]);
};
try {
if(--R.GAS > 0) {
$z1119211193 = $f1119811199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1119811199,
"from":L[2072]});
}
} catch($e1119011191) {
if(R.isCont($e1119011191)) {
var $ss1119411195 = {"from":L[2072],
"go":function(cont_tail_arg460311201) {
return $Hcont_tail_arg1004311202(cont_tail_arg460311201,if_helper459811187);
}};
$e1119011191.stack[R.EXN_STACKHEIGHT++] = $ss1119411195;
}
if(R.isPyretException($e1119011191)) {
$e1119011191.pyretStack.push(L[2072]);
}
throw $e1119011191;
}
var $ret1119611197 = $Hcont_tail_arg1004311202($z1119211193,if_helper459811187);
++R.GAS;
return $ret1119611197;
}
} else {
var cont_tail_arg460011206 = R.throwNonBooleanCondition(L[2072],("if"),if_DASH_57911203);
if(--R.GAS > 0) {
$z1120411205 = R.isFunction(if_helper459811187)?if_helper459811187.app(cont_tail_arg460011206):R.ffi.throwNonFunApp(L[2072],if_helper459811187,[cont_tail_arg460011206]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper459811187)?if_helper459811187.app(cont_tail_arg460011206):R.ffi.throwNonFunApp(L[2072],if_helper459811187,[cont_tail_arg460011206]);
},
"from":L[2072]});
}
++R.GAS;
return $z1120411205;
}
};
},{"length":3});
var anf_singleton_variant_member460911091 = R.makeMethod(function(self57811174) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2072],0,arguments);
}
var ann_DASH_check_DASH_temp460811173 = ("s-cyclic");
return ann_DASH_check_DASH_temp460811173;
};
},{"length":1});
var anf_singleton_variant_member461111092 = R.makeMethod(function(self105611172) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2080],0,arguments);
}
var ann_DASH_check_DASH_temp461011171 = ("s-cyclic");
return ann_DASH_check_DASH_temp461011171;
};
},{"length":1});
var anf_singleton_variant_member461411093 = R.makeMethod(function(self105711170) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2078],0,arguments);
}
var anf_fun461311167 = G(PP170,"str",L[2079]);
var $z1115911160 = D;
var $f1116511166 = function(_) {
return R.isFunction(anf_fun461311167)?anf_fun461311167.app(("cyclic ")):R.ffi.throwNonFunApp(L[2078],anf_fun461311167,[("cyclic ")]);
};
try {
if(--R.GAS > 0) {
$z1115911160 = $f1116511166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1116511166,
"from":L[2078]});
}
} catch($e1115711158) {
if(R.isCont($e1115711158)) {
var $ss1116111162 = {"from":L[2078],
"go":function(ann_DASH_check_DASH_temp461211168) {
return $Hann_DASH_check_DASH_temp1004411169(ann_DASH_check_DASH_temp461211168);
}};
$e1115711158.stack[R.EXN_STACKHEIGHT++] = $ss1116111162;
}
if(R.isPyretException($e1115711158)) {
$e1115711158.pyretStack.push(L[2078]);
}
throw $e1115711158;
}
var $ret1116311164 = $Hann_DASH_check_DASH_temp1004411169($z1115911160);
++R.GAS;
return $ret1116311164;
};
},{"length":1});
var anf_singleton_variant_member462511099 = R.makeMethod(function(self58111156) {
return function(cases_DASH_funs58211135,else_DASH_clause58311146) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2071],2,arguments);
}
var if_DASH_58511149 = R.hasField(cases_DASH_funs58211135,("s-mutable"));
var if_helper461611133 = R.makeFunction(function(if_helper_arg461711154) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2071],1,arguments);
}
var ann_DASH_check_DASH_temp461511155 = if_helper_arg461711154;
return ann_DASH_check_DASH_temp461511155;
});
var anf_if462011153 = R.isBoolean(if_DASH_58511149);
if(R.isPyretTrue(anf_if462011153)) {
if(R.isPyretTrue(if_DASH_58511149)) {
var call_DASH_s_DASH_mutable58011131 = G(cases_DASH_funs58211135,"s-mutable",L[2071]);
var $z1112311124 = D;
var $f1112911130 = function(_) {
return R.isFunction(call_DASH_s_DASH_mutable58011131)?call_DASH_s_DASH_mutable58011131.app():R.ffi.throwNonFunApp(L[2071],call_DASH_s_DASH_mutable58011131,[]);
};
try {
if(--R.GAS > 0) {
$z1112311124 = $f1112911130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1112911130,
"from":L[2071]});
}
} catch($e1112111122) {
if(R.isCont($e1112111122)) {
var $ss1112511126 = {"from":L[2071],
"go":function(cont_tail_arg462311132) {
return $Hcont_tail_arg1004511134(cont_tail_arg462311132,if_helper461611133);
}};
$e1112111122.stack[R.EXN_STACKHEIGHT++] = $ss1112511126;
}
if(R.isPyretException($e1112111122)) {
$e1112111122.pyretStack.push(L[2071]);
}
throw $e1112111122;
}
var $ret1112711128 = $Hcont_tail_arg1004511134($z1112311124,if_helper461611133);
++R.GAS;
return $ret1112711128;
} else {
var $z1113811139 = D;
var $f1114411145 = function(_) {
return R.isFunction(else_DASH_clause58311146)?else_DASH_clause58311146.app():R.ffi.throwNonFunApp(L[2071],else_DASH_clause58311146,[]);
};
try {
if(--R.GAS > 0) {
$z1113811139 = $f1114411145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1114411145,
"from":L[2071]});
}
} catch($e1113611137) {
if(R.isCont($e1113611137)) {
var $ss1114011141 = {"from":L[2071],
"go":function(cont_tail_arg462111147) {
return $Hcont_tail_arg1004611148(cont_tail_arg462111147,if_helper461611133);
}};
$e1113611137.stack[R.EXN_STACKHEIGHT++] = $ss1114011141;
}
if(R.isPyretException($e1113611137)) {
$e1113611137.pyretStack.push(L[2071]);
}
throw $e1113611137;
}
var $ret1114211143 = $Hcont_tail_arg1004611148($z1113811139,if_helper461611133);
++R.GAS;
return $ret1114211143;
}
} else {
var cont_tail_arg461811152 = R.throwNonBooleanCondition(L[2071],("if"),if_DASH_58511149);
if(--R.GAS > 0) {
$z1115011151 = R.isFunction(if_helper461611133)?if_helper461611133.app(cont_tail_arg461811152):R.ffi.throwNonFunApp(L[2071],if_helper461611133,[cont_tail_arg461811152]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper461611133)?if_helper461611133.app(cont_tail_arg461811152):R.ffi.throwNonFunApp(L[2071],if_helper461611133,[cont_tail_arg461811152]);
},
"from":L[2071]});
}
++R.GAS;
return $z1115011151;
}
};
},{"length":3});
var anf_singleton_variant_member462711100 = R.makeMethod(function(self58411120) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2071],0,arguments);
}
var ann_DASH_check_DASH_temp462611119 = ("s-mutable");
return ann_DASH_check_DASH_temp462611119;
};
},{"length":1});
var anf_singleton_variant_member462911101 = R.makeMethod(function(self105811118) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2077],0,arguments);
}
var ann_DASH_check_DASH_temp462811117 = ("s-mutable");
return ann_DASH_check_DASH_temp462811117;
};
},{"length":1});
var anf_singleton_variant_member463211102 = R.makeMethod(function(self105911116) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2075],0,arguments);
}
var anf_fun463111113 = G(PP170,"str",L[2076]);
var $z1110511106 = D;
var $f1111111112 = function(_) {
return R.isFunction(anf_fun463111113)?anf_fun463111113.app(("mutable ")):R.ffi.throwNonFunApp(L[2075],anf_fun463111113,[("mutable ")]);
};
try {
if(--R.GAS > 0) {
$z1110511106 = $f1111111112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1111111112,
"from":L[2075]});
}
} catch($e1110311104) {
if(R.isCont($e1110311104)) {
var $ss1110711108 = {"from":L[2075],
"go":function(ann_DASH_check_DASH_temp463011114) {
return $Hann_DASH_check_DASH_temp1004711115(ann_DASH_check_DASH_temp463011114);
}};
$e1110311104.stack[R.EXN_STACKHEIGHT++] = $ss1110711108;
}
if(R.isPyretException($e1110311104)) {
$e1110311104.pyretStack.push(L[2075]);
}
throw $e1110311104;
}
var $ret1110911110 = $Hann_DASH_check_DASH_temp1004711115($z1110511106);
++R.GAS;
return $ret1110911110;
};
},{"length":1});
var anf_assign46332212 = (function() {
var $s_DASH_normal_DASH_base1107611077 = {"visit":anf_shared457911075,
"_match":anf_singleton_variant_member459011081,
"_torepr":anf_singleton_variant_member459211082,
"label":anf_singleton_variant_member459411083,
"tosource":anf_singleton_variant_member459611084};
var $s_DASH_normal_DASH_brands1107911080 = {"$brand-s-normal11078":true};
$s_DASH_normal_DASH_brands1107911080[VariantMemberTypeT1697148._brand] = true
var $s_DASH_cyclic_DASH_base1108511086 = {"visit":anf_shared457911075,
"_match":anf_singleton_variant_member460711090,
"_torepr":anf_singleton_variant_member460911091,
"label":anf_singleton_variant_member461111092,
"tosource":anf_singleton_variant_member461411093};
var $s_DASH_cyclic_DASH_brands1108811089 = {"$brand-s-cyclic11087":true};
$s_DASH_cyclic_DASH_brands1108811089[VariantMemberTypeT1697148._brand] = true
var $s_DASH_mutable_DASH_base1109411095 = {"visit":anf_shared457911075,
"_match":anf_singleton_variant_member462511099,
"_torepr":anf_singleton_variant_member462711100,
"label":anf_singleton_variant_member462911101,
"tosource":anf_singleton_variant_member463211102};
var $s_DASH_mutable_DASH_brands1109711098 = {"$brand-s-mutable11096":true};
$s_DASH_mutable_DASH_brands1109711098[VariantMemberTypeT1697148._brand] = true
return R.makeObject({"VariantMemberType":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2074],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,VariantMemberTypeT1697148._brand));
}),
"is-s-normal":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2073],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-normal11078"));
}),
"s-normal":R.makeBrandedObject($s_DASH_normal_DASH_base1107611077,$s_DASH_normal_DASH_brands1107911080),
"is-s-cyclic":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2072],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-cyclic11087"));
}),
"s-cyclic":R.makeBrandedObject($s_DASH_cyclic_DASH_base1108511086,$s_DASH_cyclic_DASH_brands1108811089),
"is-s-mutable":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2071],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-mutable11096"));
}),
"s-mutable":R.makeBrandedObject($s_DASH_mutable_DASH_base1109411095,$s_DASH_mutable_DASH_brands1109711098)});
})();
VariantMemberType414552211.$var = anf_assign46332212;
var anf_assign46342214 = G(VariantMemberType414552211.$var,"VariantMemberType",L[2074]);
VariantMemberType4562213.$var = anf_assign46342214;
var anf_assign46352216 = G(VariantMemberType414552211.$var,"VariantMemberType",L[2074]);
is_DASH_VariantMemberType4572215.$var = anf_assign46352216;
var anf_assign46362218 = G(VariantMemberType414552211.$var,"is-s-normal",L[2073]);
is_DASH_s_DASH_normal4582217.$var = anf_assign46362218;
var anf_assign46372220 = G(VariantMemberType414552211.$var,"s-normal",L[2073]);
s_DASH_normal4592219.$var = anf_assign46372220;
var anf_assign46382222 = G(VariantMemberType414552211.$var,"is-s-cyclic",L[2072]);
is_DASH_s_DASH_cyclic4602221.$var = anf_assign46382222;
var anf_assign46392224 = G(VariantMemberType414552211.$var,"s-cyclic",L[2072]);
s_DASH_cyclic4612223.$var = anf_assign46392224;
var anf_assign46402226 = G(VariantMemberType414552211.$var,"is-s-mutable",L[2071]);
is_DASH_s_DASH_mutable4622225.$var = anf_assign46402226;
var anf_assign46412228 = G(VariantMemberType414552211.$var,"s-mutable",L[2071]);
s_DASH_mutable4632227.$var = anf_assign46412228;
var anf_shared464910963 = R.makeMethod(function(self106711074) {
return function(visitor106811057) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2066],1,arguments);
}
var anf_fun464311056 = G(self106711074,"_match",L[2070]);
var anf_arg464811058 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2067],0,arguments);
}
var anf_fun464511071 = G(self106711074,"label",L[2069]);
var $z1106311064 = D;
var $f1106911070 = function(_) {
return R.isFunction(anf_fun464511071)?anf_fun464511071.app():R.ffi.throwNonFunApp(L[2068],anf_fun464511071,[]);
};
try {
if(--R.GAS > 0) {
$z1106311064 = $f1106911070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1106911070,
"from":L[2068]});
}
} catch($e1106111062) {
if(R.isCont($e1106111062)) {
var $ss1106511066 = {"from":L[2068],
"go":function(anf_arg464611072) {
return $Hanf_arg1005011073(anf_arg464611072,_plus55,raise62);
}};
$e1106111062.stack[R.EXN_STACKHEIGHT++] = $ss1106511066;
}
if(R.isPyretException($e1106111062)) {
$e1106111062.pyretStack.push(L[2068]);
}
throw $e1106111062;
}
var $ret1106711068 = $Hanf_arg1005011073($z1106311064,_plus55,raise62);
++R.GAS;
return $ret1106711068;
});
var $z1104811049 = D;
var $f1105411055 = function(_) {
return R.isFunction(anf_fun464311056)?anf_fun464311056.app(visitor106811057,anf_arg464811058):R.ffi.throwNonFunApp(L[2066],anf_fun464311056,[visitor106811057,anf_arg464811058]);
};
try {
if(--R.GAS > 0) {
$z1104811049 = $f1105411055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1105411055,
"from":L[2066]});
}
} catch($e1104611047) {
if(R.isCont($e1104611047)) {
var $ss1105011051 = {"from":L[2066],
"go":function(ann_DASH_check_DASH_temp464211059) {
return $Hann_DASH_check_DASH_temp1005111060(ann_DASH_check_DASH_temp464211059);
}};
$e1104611047.stack[R.EXN_STACKHEIGHT++] = $ss1105011051;
}
if(R.isPyretException($e1104611047)) {
$e1104611047.pyretStack.push(L[2066]);
}
throw $e1104611047;
}
var $ret1105211053 = $Hann_DASH_check_DASH_temp1005111060($z1104811049);
++R.GAS;
return $ret1105211053;
};
},{"length":2});
var anf_variant_member466310969 = R.makeMethod(function(self58711024) {
return function(cases_DASH_funs58811025,else_DASH_clause58911036) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2052],2,arguments);
}
var if_DASH_59111039 = R.hasField(cases_DASH_funs58811025,("s-variant-member"));
var if_helper465111022 = R.makeFunction(function(if_helper_arg465211044) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2052],1,arguments);
}
var ann_DASH_check_DASH_temp465011045 = if_helper_arg465211044;
return ann_DASH_check_DASH_temp465011045;
});
var anf_if465511043 = R.isBoolean(if_DASH_59111039);
if(R.isPyretTrue(anf_if465511043)) {
if(R.isPyretTrue(if_DASH_59111039)) {
var call_DASH_s_DASH_variant_DASH_member58611017 = G(cases_DASH_funs58811025,"s-variant-member",L[2052]);
var anf_arg465811018 = G(self58711024,"l",L[2065]);
var anf_arg465911019 = G(self58711024,"member-type",L[2064]);
var anf_arg466011020 = G(self58711024,"bind",L[2063]);
var $z1100911010 = D;
var $f1101511016 = function(_) {
return R.isFunction(call_DASH_s_DASH_variant_DASH_member58611017)?call_DASH_s_DASH_variant_DASH_member58611017.app(anf_arg465811018,anf_arg465911019,anf_arg466011020):R.ffi.throwNonFunApp(L[2052],call_DASH_s_DASH_variant_DASH_member58611017,[anf_arg465811018,anf_arg465911019,anf_arg466011020]);
};
try {
if(--R.GAS > 0) {
$z1100911010 = $f1101511016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1101511016,
"from":L[2052]});
}
} catch($e1100711008) {
if(R.isCont($e1100711008)) {
var $ss1101111012 = {"from":L[2052],
"go":function(cont_tail_arg466111021) {
return $Hcont_tail_arg1005211023(cont_tail_arg466111021,if_helper465111022);
}};
$e1100711008.stack[R.EXN_STACKHEIGHT++] = $ss1101111012;
}
if(R.isPyretException($e1100711008)) {
$e1100711008.pyretStack.push(L[2052]);
}
throw $e1100711008;
}
var $ret1101311014 = $Hcont_tail_arg1005211023($z1100911010,if_helper465111022);
++R.GAS;
return $ret1101311014;
} else {
var $z1102811029 = D;
var $f1103411035 = function(_) {
return R.isFunction(else_DASH_clause58911036)?else_DASH_clause58911036.app():R.ffi.throwNonFunApp(L[2052],else_DASH_clause58911036,[]);
};
try {
if(--R.GAS > 0) {
$z1102811029 = $f1103411035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1103411035,
"from":L[2052]});
}
} catch($e1102611027) {
if(R.isCont($e1102611027)) {
var $ss1103011031 = {"from":L[2052],
"go":function(cont_tail_arg465611037) {
return $Hcont_tail_arg1005311038(cont_tail_arg465611037,if_helper465111022);
}};
$e1102611027.stack[R.EXN_STACKHEIGHT++] = $ss1103011031;
}
if(R.isPyretException($e1102611027)) {
$e1102611027.pyretStack.push(L[2052]);
}
throw $e1102611027;
}
var $ret1103211033 = $Hcont_tail_arg1005311038($z1102811029,if_helper465111022);
++R.GAS;
return $ret1103211033;
}
} else {
var cont_tail_arg465311042 = R.throwNonBooleanCondition(L[2052],("if"),if_DASH_59111039);
if(--R.GAS > 0) {
$z1104011041 = R.isFunction(if_helper465111022)?if_helper465111022.app(cont_tail_arg465311042):R.ffi.throwNonFunApp(L[2052],if_helper465111022,[cont_tail_arg465311042]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper465111022)?if_helper465111022.app(cont_tail_arg465311042):R.ffi.throwNonFunApp(L[2052],if_helper465111022,[cont_tail_arg465311042]);
},
"from":L[2052]});
}
++R.GAS;
return $z1104011041;
}
};
},{"length":3});
var anf_variant_member467710970 = R.makeMethod(function(self59011005) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2052],0,arguments);
}
var anf_arg466511003 = G(self59011005,"l",L[2052]);
var $z1099510996 = D;
var $f1100111002 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg466511003):R.ffi.throwNonFunApp(L[2052],torepr65,[anf_arg466511003]);
};
try {
if(--R.GAS > 0) {
$z1099510996 = $f1100111002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1100111002,
"from":L[2052]});
}
} catch($e1099310994) {
if(R.isCont($e1099310994)) {
var $ss1099710998 = {"from":L[2052],
"go":function(anf_arg466611004) {
return $Hanf_arg1006311006(anf_arg466611004,self59011005,_plus55,torepr65);
}};
$e1099310994.stack[R.EXN_STACKHEIGHT++] = $ss1099710998;
}
if(R.isPyretException($e1099310994)) {
$e1099310994.pyretStack.push(L[2052]);
}
throw $e1099310994;
}
var $ret1099911000 = $Hanf_arg1006311006($z1099510996,self59011005,_plus55,torepr65);
++R.GAS;
return $ret1099911000;
};
},{"length":1});
var anf_variant_member467910971 = R.makeMethod(function(self106510992) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2062],0,arguments);
}
var ann_DASH_check_DASH_temp467810991 = ("s-variant-member");
return ann_DASH_check_DASH_temp467810991;
};
},{"length":1});
var anf_variant_member468710972 = R.makeMethod(function(self106610988) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2061],0,arguments);
}
var anf_bracket468110990 = G(self106610988,"member-type",L[2060]);
var anf_fun468210986 = G(anf_bracket468110990,"tosource",L[2059]);
var $z1097810979 = D;
var $f1098410985 = function(_) {
return R.isFunction(anf_fun468210986)?anf_fun468210986.app():R.ffi.throwNonFunApp(L[2058],anf_fun468210986,[]);
};
try {
if(--R.GAS > 0) {
$z1097810979 = $f1098410985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1098410985,
"from":L[2058]});
}
} catch($e1097610977) {
if(R.isCont($e1097610977)) {
var $ss1098010981 = {"from":L[2058],
"go":function(anf_arg468310987) {
return $Hanf_arg1006610989(anf_arg468310987,self106610988,_plus55);
}};
$e1097610977.stack[R.EXN_STACKHEIGHT++] = $ss1098010981;
}
if(R.isPyretException($e1097610977)) {
$e1097610977.pyretStack.push(L[2058]);
}
throw $e1097610977;
}
var $ret1098210983 = $Hanf_arg1006610989($z1097810979,self106610988,_plus55);
++R.GAS;
return $ret1098210983;
};
},{"length":1});
var anf_assign46882230 = (function() {
var $s_DASH_variant_DASH_member_DASH_base1096410965 = {"visit":anf_shared464910963,
"_match":anf_variant_member466310969,
"_torepr":anf_variant_member467710970,
"label":anf_variant_member467910971,
"tosource":anf_variant_member468710972};
var $s_DASH_variant_DASH_member_DASH_brands1096710968 = {"$brand-s-variant-member10966":true};
$s_DASH_variant_DASH_member_DASH_brands1096710968[VariantMemberT1799146._brand] = true
return R.makeObject({"VariantMember":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2053],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,VariantMemberT1799146._brand));
}),
"is-s-variant-member":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2052],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-variant-member10966"));
}),
"s-variant-member":R.makeFunction(function(l106210973,member_DASH_type106310974,bind106410975) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2054],3,arguments);
}
return R.checkAnnArgs([Loc116130,VariantMemberType96147,Bind90101],[l106210973,member_DASH_type106310974,bind106410975],[L[2055],L[2056],L[2057]],function() {
var dict = R.create($s_DASH_variant_DASH_member_DASH_base1096410965);
dict["l"] = l106210973
dict["member-type"] = member_DASH_type106310974
dict["bind"] = bind106410975
return R.makeBrandedObject(dict,$s_DASH_variant_DASH_member_DASH_brands1096710968);
});
})});
})();
VariantMember424642229.$var = anf_assign46882230;
var anf_assign46892232 = G(VariantMember424642229.$var,"VariantMember",L[2053]);
VariantMember4652231.$var = anf_assign46892232;
var anf_assign46902234 = G(VariantMember424642229.$var,"VariantMember",L[2053]);
is_DASH_VariantMember4662233.$var = anf_assign46902234;
var anf_assign46912236 = G(VariantMember424642229.$var,"is-s-variant-member",L[2052]);
is_DASH_s_DASH_variant_DASH_member4672235.$var = anf_assign46912236;
var anf_assign46922238 = G(VariantMember424642229.$var,"s-variant-member",L[2052]);
s_DASH_variant_DASH_member4682237.$var = anf_assign46922238;
var anf_shared470010765 = R.makeMethod(function(self109010962) {
return function(visitor109110945) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2047],1,arguments);
}
var anf_fun469410944 = G(self109010962,"_match",L[2051]);
var anf_arg469910946 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2048],0,arguments);
}
var anf_fun469610959 = G(self109010962,"label",L[2050]);
var $z1095110952 = D;
var $f1095710958 = function(_) {
return R.isFunction(anf_fun469610959)?anf_fun469610959.app():R.ffi.throwNonFunApp(L[2049],anf_fun469610959,[]);
};
try {
if(--R.GAS > 0) {
$z1095110952 = $f1095710958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1095710958,
"from":L[2049]});
}
} catch($e1094910950) {
if(R.isCont($e1094910950)) {
var $ss1095310954 = {"from":L[2049],
"go":function(anf_arg469710960) {
return $Hanf_arg1006910961(anf_arg469710960,_plus55,raise62);
}};
$e1094910950.stack[R.EXN_STACKHEIGHT++] = $ss1095310954;
}
if(R.isPyretException($e1094910950)) {
$e1094910950.pyretStack.push(L[2049]);
}
throw $e1094910950;
}
var $ret1095510956 = $Hanf_arg1006910961($z1095110952,_plus55,raise62);
++R.GAS;
return $ret1095510956;
});
var $z1093610937 = D;
var $f1094210943 = function(_) {
return R.isFunction(anf_fun469410944)?anf_fun469410944.app(visitor109110945,anf_arg469910946):R.ffi.throwNonFunApp(L[2047],anf_fun469410944,[visitor109110945,anf_arg469910946]);
};
try {
if(--R.GAS > 0) {
$z1093610937 = $f1094210943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1094210943,
"from":L[2047]});
}
} catch($e1093410935) {
if(R.isCont($e1093410935)) {
var $ss1093810939 = {"from":L[2047],
"go":function(ann_DASH_check_DASH_temp469310947) {
return $Hann_DASH_check_DASH_temp1007010948(ann_DASH_check_DASH_temp469310947);
}};
$e1093410935.stack[R.EXN_STACKHEIGHT++] = $ss1093810939;
}
if(R.isPyretException($e1093410935)) {
$e1093410935.pyretStack.push(L[2047]);
}
throw $e1093410935;
}
var $ret1094010941 = $Hann_DASH_check_DASH_temp1007010948($z1093610937);
++R.GAS;
return $ret1094010941;
};
},{"length":2});
var anf_variant_member471610771 = R.makeMethod(function(self59310912) {
return function(cases_DASH_funs59410913,else_DASH_clause59510924) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2017],2,arguments);
}
var if_DASH_59710927 = R.hasField(cases_DASH_funs59410913,("s-variant"));
var if_helper470210910 = R.makeFunction(function(if_helper_arg470310932) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2017],1,arguments);
}
var ann_DASH_check_DASH_temp470110933 = if_helper_arg470310932;
return ann_DASH_check_DASH_temp470110933;
});
var anf_if470610931 = R.isBoolean(if_DASH_59710927);
if(R.isPyretTrue(anf_if470610931)) {
if(R.isPyretTrue(if_DASH_59710927)) {
var call_DASH_s_DASH_variant59210903 = G(cases_DASH_funs59410913,"s-variant",L[2017]);
var anf_arg470910904 = G(self59310912,"l",L[2046]);
var anf_arg471010905 = G(self59310912,"constr-loc",L[2045]);
var anf_arg471110906 = G(self59310912,"name",L[2044]);
var anf_arg471210907 = G(self59310912,"members",L[2043]);
var anf_arg471310908 = G(self59310912,"with-members",L[2042]);
var $z1089510896 = D;
var $f1090110902 = function(_) {
return R.isFunction(call_DASH_s_DASH_variant59210903)?call_DASH_s_DASH_variant59210903.app(anf_arg470910904,anf_arg471010905,anf_arg471110906,anf_arg471210907,anf_arg471310908):R.ffi.throwNonFunApp(L[2017],call_DASH_s_DASH_variant59210903,[anf_arg470910904,anf_arg471010905,anf_arg471110906,anf_arg471210907,anf_arg471310908]);
};
try {
if(--R.GAS > 0) {
$z1089510896 = $f1090110902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1090110902,
"from":L[2017]});
}
} catch($e1089310894) {
if(R.isCont($e1089310894)) {
var $ss1089710898 = {"from":L[2017],
"go":function(cont_tail_arg471410909) {
return $Hcont_tail_arg1007110911(cont_tail_arg471410909,if_helper470210910);
}};
$e1089310894.stack[R.EXN_STACKHEIGHT++] = $ss1089710898;
}
if(R.isPyretException($e1089310894)) {
$e1089310894.pyretStack.push(L[2017]);
}
throw $e1089310894;
}
var $ret1089910900 = $Hcont_tail_arg1007110911($z1089510896,if_helper470210910);
++R.GAS;
return $ret1089910900;
} else {
var $z1091610917 = D;
var $f1092210923 = function(_) {
return R.isFunction(else_DASH_clause59510924)?else_DASH_clause59510924.app():R.ffi.throwNonFunApp(L[2017],else_DASH_clause59510924,[]);
};
try {
if(--R.GAS > 0) {
$z1091610917 = $f1092210923();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1092210923,
"from":L[2017]});
}
} catch($e1091410915) {
if(R.isCont($e1091410915)) {
var $ss1091810919 = {"from":L[2017],
"go":function(cont_tail_arg470710925) {
return $Hcont_tail_arg1007210926(cont_tail_arg470710925,if_helper470210910);
}};
$e1091410915.stack[R.EXN_STACKHEIGHT++] = $ss1091810919;
}
if(R.isPyretException($e1091410915)) {
$e1091410915.pyretStack.push(L[2017]);
}
throw $e1091410915;
}
var $ret1092010921 = $Hcont_tail_arg1007210926($z1091610917,if_helper470210910);
++R.GAS;
return $ret1092010921;
}
} else {
var cont_tail_arg470410930 = R.throwNonBooleanCondition(L[2017],("if"),if_DASH_59710927);
if(--R.GAS > 0) {
$z1092810929 = R.isFunction(if_helper470210910)?if_helper470210910.app(cont_tail_arg470410930):R.ffi.throwNonFunApp(L[2017],if_helper470210910,[cont_tail_arg470410930]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper470210910)?if_helper470210910.app(cont_tail_arg470410930):R.ffi.throwNonFunApp(L[2017],if_helper470210910,[cont_tail_arg470410930]);
},
"from":L[2017]});
}
++R.GAS;
return $z1092810929;
}
};
},{"length":3});
var anf_variant_member473810772 = R.makeMethod(function(self59610891) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2017],0,arguments);
}
var anf_arg471810889 = G(self59610891,"l",L[2017]);
var $z1088110882 = D;
var $f1088710888 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg471810889):R.ffi.throwNonFunApp(L[2017],torepr65,[anf_arg471810889]);
};
try {
if(--R.GAS > 0) {
$z1088110882 = $f1088710888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1088710888,
"from":L[2017]});
}
} catch($e1087910880) {
if(R.isCont($e1087910880)) {
var $ss1088310884 = {"from":L[2017],
"go":function(anf_arg471910890) {
return $Hanf_arg1008810892(anf_arg471910890,self59610891,_plus55,torepr65);
}};
$e1087910880.stack[R.EXN_STACKHEIGHT++] = $ss1088310884;
}
if(R.isPyretException($e1087910880)) {
$e1087910880.pyretStack.push(L[2017]);
}
throw $e1087910880;
}
var $ret1088510886 = $Hanf_arg1008810892($z1088110882,self59610891,_plus55,torepr65);
++R.GAS;
return $ret1088510886;
};
},{"length":1});
var anf_variant_member474010773 = R.makeMethod(function(self107410878) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2041],0,arguments);
}
var ann_DASH_check_DASH_temp473910877 = ("s-variant");
return ann_DASH_check_DASH_temp473910877;
};
},{"length":1});
var anf_variant_member478210774 = R.makeMethod(function(self107510875) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2040],0,arguments);
}
var anf_fun474210872 = G(PP170,"str",L[2039]);
var anf_arg474310873 = G(self107510875,"name",L[2038]);
var $z1086410865 = D;
var $f1087010871 = function(_) {
return R.isFunction(anf_fun474210872)?anf_fun474210872.app(anf_arg474310873):R.ffi.throwNonFunApp(L[2037],anf_fun474210872,[anf_arg474310873]);
};
try {
if(--R.GAS > 0) {
$z1086410865 = $f1087010871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1087010871,
"from":L[2037]});
}
} catch($e1086210863) {
if(R.isCont($e1086210863)) {
var $ss1086610867 = {"from":L[2037],
"go":function(anf_arg474410874) {
return $Hanf_arg1010510876(anf_arg474410874,INDENT118169,PP170,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55);
}};
$e1086210863.stack[R.EXN_STACKHEIGHT++] = $ss1086610867;
}
if(R.isPyretException($e1086210863)) {
$e1086210863.pyretStack.push(L[2037]);
}
throw $e1086210863;
}
var $ret1086810869 = $Hanf_arg1010510876($z1086410865,INDENT118169,PP170,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55);
++R.GAS;
return $ret1086810869;
};
},{"length":1});
var anf_variant_member479610785 = R.makeMethod(function(self60010840) {
return function(cases_DASH_funs60110841,else_DASH_clause60210852) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[2016],2,arguments);
}
var if_DASH_60410855 = R.hasField(cases_DASH_funs60110841,("s-singleton-variant"));
var if_helper478410838 = R.makeFunction(function(if_helper_arg478510860) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2016],1,arguments);
}
var ann_DASH_check_DASH_temp478310861 = if_helper_arg478510860;
return ann_DASH_check_DASH_temp478310861;
});
var anf_if478810859 = R.isBoolean(if_DASH_60410855);
if(R.isPyretTrue(anf_if478810859)) {
if(R.isPyretTrue(if_DASH_60410855)) {
var call_DASH_s_DASH_singleton_DASH_variant59910833 = G(cases_DASH_funs60110841,"s-singleton-variant",L[2016]);
var anf_arg479110834 = G(self60010840,"l",L[2036]);
var anf_arg479210835 = G(self60010840,"name",L[2035]);
var anf_arg479310836 = G(self60010840,"with-members",L[2034]);
var $z1082510826 = D;
var $f1083110832 = function(_) {
return R.isFunction(call_DASH_s_DASH_singleton_DASH_variant59910833)?call_DASH_s_DASH_singleton_DASH_variant59910833.app(anf_arg479110834,anf_arg479210835,anf_arg479310836):R.ffi.throwNonFunApp(L[2016],call_DASH_s_DASH_singleton_DASH_variant59910833,[anf_arg479110834,anf_arg479210835,anf_arg479310836]);
};
try {
if(--R.GAS > 0) {
$z1082510826 = $f1083110832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1083110832,
"from":L[2016]});
}
} catch($e1082310824) {
if(R.isCont($e1082310824)) {
var $ss1082710828 = {"from":L[2016],
"go":function(cont_tail_arg479410837) {
return $Hcont_tail_arg1010610839(cont_tail_arg479410837,if_helper478410838);
}};
$e1082310824.stack[R.EXN_STACKHEIGHT++] = $ss1082710828;
}
if(R.isPyretException($e1082310824)) {
$e1082310824.pyretStack.push(L[2016]);
}
throw $e1082310824;
}
var $ret1082910830 = $Hcont_tail_arg1010610839($z1082510826,if_helper478410838);
++R.GAS;
return $ret1082910830;
} else {
var $z1084410845 = D;
var $f1085010851 = function(_) {
return R.isFunction(else_DASH_clause60210852)?else_DASH_clause60210852.app():R.ffi.throwNonFunApp(L[2016],else_DASH_clause60210852,[]);
};
try {
if(--R.GAS > 0) {
$z1084410845 = $f1085010851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1085010851,
"from":L[2016]});
}
} catch($e1084210843) {
if(R.isCont($e1084210843)) {
var $ss1084610847 = {"from":L[2016],
"go":function(cont_tail_arg478910853) {
return $Hcont_tail_arg1010710854(cont_tail_arg478910853,if_helper478410838);
}};
$e1084210843.stack[R.EXN_STACKHEIGHT++] = $ss1084610847;
}
if(R.isPyretException($e1084210843)) {
$e1084210843.pyretStack.push(L[2016]);
}
throw $e1084210843;
}
var $ret1084810849 = $Hcont_tail_arg1010710854($z1084410845,if_helper478410838);
++R.GAS;
return $ret1084810849;
}
} else {
var cont_tail_arg478610858 = R.throwNonBooleanCondition(L[2016],("if"),if_DASH_60410855);
if(--R.GAS > 0) {
$z1085610857 = R.isFunction(if_helper478410838)?if_helper478410838.app(cont_tail_arg478610858):R.ffi.throwNonFunApp(L[2016],if_helper478410838,[cont_tail_arg478610858]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper478410838)?if_helper478410838.app(cont_tail_arg478610858):R.ffi.throwNonFunApp(L[2016],if_helper478410838,[cont_tail_arg478610858]);
},
"from":L[2016]});
}
++R.GAS;
return $z1085610857;
}
};
},{"length":3});
var anf_variant_member481010786 = R.makeMethod(function(self60310821) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2016],0,arguments);
}
var anf_arg479810819 = G(self60310821,"l",L[2016]);
var $z1081110812 = D;
var $f1081710818 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg479810819):R.ffi.throwNonFunApp(L[2016],torepr65,[anf_arg479810819]);
};
try {
if(--R.GAS > 0) {
$z1081110812 = $f1081710818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1081710818,
"from":L[2016]});
}
} catch($e1080910810) {
if(R.isCont($e1080910810)) {
var $ss1081310814 = {"from":L[2016],
"go":function(anf_arg479910820) {
return $Hanf_arg1011710822(anf_arg479910820,self60310821,_plus55,torepr65);
}};
$e1080910810.stack[R.EXN_STACKHEIGHT++] = $ss1081310814;
}
if(R.isPyretException($e1080910810)) {
$e1080910810.pyretStack.push(L[2016]);
}
throw $e1080910810;
}
var $ret1081510816 = $Hanf_arg1011710822($z1081110812,self60310821,_plus55,torepr65);
++R.GAS;
return $ret1081510816;
};
},{"length":1});
var anf_variant_member481210787 = R.makeMethod(function(self108410808) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2033],0,arguments);
}
var ann_DASH_check_DASH_temp481110807 = ("s-singleton-variant");
return ann_DASH_check_DASH_temp481110807;
};
},{"length":1});
var anf_variant_member484110788 = R.makeMethod(function(self108510805) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2032],0,arguments);
}
var anf_fun481410802 = G(PP170,"str",L[2031]);
var anf_arg481510803 = G(self108510805,"name",L[2030]);
var $z1079410795 = D;
var $f1080010801 = function(_) {
return R.isFunction(anf_fun481410802)?anf_fun481410802.app(anf_arg481510803):R.ffi.throwNonFunApp(L[2029],anf_fun481410802,[anf_arg481510803]);
};
try {
if(--R.GAS > 0) {
$z1079410795 = $f1080010801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1080010801,
"from":L[2029]});
}
} catch($e1079210793) {
if(R.isCont($e1079210793)) {
var $ss1079610797 = {"from":L[2029],
"go":function(header_DASH_nowith108610804) {
return $Hheader_DASH_nowith1013010806(header_DASH_nowith108610804,INDENT118169,PP170,break_DASH_one119168,lists974,self108510805,str_DASH_with1831001,_plus55);
}};
$e1079210793.stack[R.EXN_STACKHEIGHT++] = $ss1079610797;
}
if(R.isPyretException($e1079210793)) {
$e1079210793.pyretStack.push(L[2029]);
}
throw $e1079210793;
}
var $ret1079810799 = $Hheader_DASH_nowith1013010806($z1079410795,INDENT118169,PP170,break_DASH_one119168,lists974,self108510805,str_DASH_with1831001,_plus55);
++R.GAS;
return $ret1079810799;
};
},{"length":1});
var anf_assign48422240 = (function() {
var $s_DASH_variant_DASH_base1076610767 = {"visit":anf_shared470010765,
"_match":anf_variant_member471610771,
"_torepr":anf_variant_member473810772,
"label":anf_variant_member474010773,
"tosource":anf_variant_member478210774};
var $s_DASH_variant_DASH_brands1076910770 = {"$brand-s-variant10768":true};
$s_DASH_variant_DASH_brands1076910770[VariantT18101149._brand] = true
var $s_DASH_singleton_DASH_variant_DASH_base1078010781 = {"visit":anf_shared470010765,
"_match":anf_variant_member479610785,
"_torepr":anf_variant_member481010786,
"label":anf_variant_member481210787,
"tosource":anf_variant_member484110788};
var $s_DASH_singleton_DASH_variant_DASH_brands1078310784 = {"$brand-s-singleton-variant10782":true};
$s_DASH_singleton_DASH_variant_DASH_brands1078310784[VariantT18101149._brand] = true
return R.makeObject({"Variant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2018],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,VariantT18101149._brand));
}),
"is-s-variant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2017],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-variant10768"));
}),
"s-variant":R.makeFunction(function(l106910775,constr_DASH_loc107010776,name107110777,members107210778,with_DASH_members107310779) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[2019],5,arguments);
}
return R.checkAnnArgs([Loc116130,Loc116130,$type$String69,List17129,List17129],[l106910775,constr_DASH_loc107010776,name107110777,members107210778,with_DASH_members107310779],[L[2020],L[2021],L[2022],L[2023],L[2024]],function() {
var dict = R.create($s_DASH_variant_DASH_base1076610767);
dict["l"] = l106910775
dict["constr-loc"] = constr_DASH_loc107010776
dict["name"] = name107110777
dict["members"] = members107210778
dict["with-members"] = with_DASH_members107310779
return R.makeBrandedObject(dict,$s_DASH_variant_DASH_brands1076910770);
});
}),
"is-s-singleton-variant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2016],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-singleton-variant10782"));
}),
"s-singleton-variant":R.makeFunction(function(l108110789,name108210790,with_DASH_members108310791) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[2025],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129],[l108110789,name108210790,with_DASH_members108310791],[L[2026],L[2027],L[2028]],function() {
var dict = R.create($s_DASH_singleton_DASH_variant_DASH_base1078010781);
dict["l"] = l108110789
dict["name"] = name108210790
dict["with-members"] = with_DASH_members108310791
return R.makeBrandedObject(dict,$s_DASH_singleton_DASH_variant_DASH_brands1078310784);
});
})});
})();
Variant434692239.$var = anf_assign48422240;
var anf_assign48432242 = G(Variant434692239.$var,"Variant",L[2018]);
Variant4702241.$var = anf_assign48432242;
var anf_assign48442244 = G(Variant434692239.$var,"Variant",L[2018]);
is_DASH_Variant4712243.$var = anf_assign48442244;
var anf_assign48452246 = G(Variant434692239.$var,"is-s-variant",L[2017]);
is_DASH_s_DASH_variant4722245.$var = anf_assign48452246;
var anf_assign48462248 = G(Variant434692239.$var,"s-variant",L[2017]);
s_DASH_variant4732247.$var = anf_assign48462248;
var anf_assign48472250 = G(Variant434692239.$var,"is-s-singleton-variant",L[2016]);
is_DASH_s_DASH_singleton_DASH_variant4742249.$var = anf_assign48472250;
var anf_assign48482252 = G(Variant434692239.$var,"s-singleton-variant",L[2016]);
s_DASH_singleton_DASH_variant4752251.$var = anf_assign48482252;
var anf_shared485610571 = R.makeMethod(function(self110310764) {
return function(visitor110410747) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2011],1,arguments);
}
var anf_fun485010746 = G(self110310764,"_match",L[2015]);
var anf_arg485510748 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2012],0,arguments);
}
var anf_fun485210761 = G(self110310764,"label",L[2014]);
var $z1075310754 = D;
var $f1075910760 = function(_) {
return R.isFunction(anf_fun485210761)?anf_fun485210761.app():R.ffi.throwNonFunApp(L[2013],anf_fun485210761,[]);
};
try {
if(--R.GAS > 0) {
$z1075310754 = $f1075910760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1075910760,
"from":L[2013]});
}
} catch($e1075110752) {
if(R.isCont($e1075110752)) {
var $ss1075510756 = {"from":L[2013],
"go":function(anf_arg485310762) {
return $Hanf_arg1013310763(anf_arg485310762,_plus55,raise62);
}};
$e1075110752.stack[R.EXN_STACKHEIGHT++] = $ss1075510756;
}
if(R.isPyretException($e1075110752)) {
$e1075110752.pyretStack.push(L[2013]);
}
throw $e1075110752;
}
var $ret1075710758 = $Hanf_arg1013310763($z1075310754,_plus55,raise62);
++R.GAS;
return $ret1075710758;
});
var $z1073810739 = D;
var $f1074410745 = function(_) {
return R.isFunction(anf_fun485010746)?anf_fun485010746.app(visitor110410747,anf_arg485510748):R.ffi.throwNonFunApp(L[2011],anf_fun485010746,[visitor110410747,anf_arg485510748]);
};
try {
if(--R.GAS > 0) {
$z1073810739 = $f1074410745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1074410745,
"from":L[2011]});
}
} catch($e1073610737) {
if(R.isCont($e1073610737)) {
var $ss1074010741 = {"from":L[2011],
"go":function(ann_DASH_check_DASH_temp484910749) {
return $Hann_DASH_check_DASH_temp1013410750(ann_DASH_check_DASH_temp484910749);
}};
$e1073610737.stack[R.EXN_STACKHEIGHT++] = $ss1074010741;
}
if(R.isPyretException($e1073610737)) {
$e1073610737.pyretStack.push(L[2011]);
}
throw $e1073610737;
}
var $ret1074210743 = $Hann_DASH_check_DASH_temp1013410750($z1073810739);
++R.GAS;
return $ret1074210743;
};
},{"length":2});
var anf_variant_member487110577 = R.makeMethod(function(self60710714) {
return function(cases_DASH_funs60810715,else_DASH_clause60910726) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1987],2,arguments);
}
var if_DASH_61110729 = R.hasField(cases_DASH_funs60810715,("s-datatype-variant"));
var if_helper485810712 = R.makeFunction(function(if_helper_arg485910734) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1987],1,arguments);
}
var ann_DASH_check_DASH_temp485710735 = if_helper_arg485910734;
return ann_DASH_check_DASH_temp485710735;
});
var anf_if486210733 = R.isBoolean(if_DASH_61110729);
if(R.isPyretTrue(anf_if486210733)) {
if(R.isPyretTrue(if_DASH_61110729)) {
var call_DASH_s_DASH_datatype_DASH_variant60610706 = G(cases_DASH_funs60810715,"s-datatype-variant",L[1987]);
var anf_arg486510707 = G(self60710714,"l",L[2010]);
var anf_arg486610708 = G(self60710714,"name",L[2009]);
var anf_arg486710709 = G(self60710714,"members",L[2008]);
var anf_arg486810710 = G(self60710714,"constructor",L[2007]);
var $z1069810699 = D;
var $f1070410705 = function(_) {
return R.isFunction(call_DASH_s_DASH_datatype_DASH_variant60610706)?call_DASH_s_DASH_datatype_DASH_variant60610706.app(anf_arg486510707,anf_arg486610708,anf_arg486710709,anf_arg486810710):R.ffi.throwNonFunApp(L[1987],call_DASH_s_DASH_datatype_DASH_variant60610706,[anf_arg486510707,anf_arg486610708,anf_arg486710709,anf_arg486810710]);
};
try {
if(--R.GAS > 0) {
$z1069810699 = $f1070410705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1070410705,
"from":L[1987]});
}
} catch($e1069610697) {
if(R.isCont($e1069610697)) {
var $ss1070010701 = {"from":L[1987],
"go":function(cont_tail_arg486910711) {
return $Hcont_tail_arg1013510713(cont_tail_arg486910711,if_helper485810712);
}};
$e1069610697.stack[R.EXN_STACKHEIGHT++] = $ss1070010701;
}
if(R.isPyretException($e1069610697)) {
$e1069610697.pyretStack.push(L[1987]);
}
throw $e1069610697;
}
var $ret1070210703 = $Hcont_tail_arg1013510713($z1069810699,if_helper485810712);
++R.GAS;
return $ret1070210703;
} else {
var $z1071810719 = D;
var $f1072410725 = function(_) {
return R.isFunction(else_DASH_clause60910726)?else_DASH_clause60910726.app():R.ffi.throwNonFunApp(L[1987],else_DASH_clause60910726,[]);
};
try {
if(--R.GAS > 0) {
$z1071810719 = $f1072410725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1072410725,
"from":L[1987]});
}
} catch($e1071610717) {
if(R.isCont($e1071610717)) {
var $ss1072010721 = {"from":L[1987],
"go":function(cont_tail_arg486310727) {
return $Hcont_tail_arg1013610728(cont_tail_arg486310727,if_helper485810712);
}};
$e1071610717.stack[R.EXN_STACKHEIGHT++] = $ss1072010721;
}
if(R.isPyretException($e1071610717)) {
$e1071610717.pyretStack.push(L[1987]);
}
throw $e1071610717;
}
var $ret1072210723 = $Hcont_tail_arg1013610728($z1071810719,if_helper485810712);
++R.GAS;
return $ret1072210723;
}
} else {
var cont_tail_arg486010732 = R.throwNonBooleanCondition(L[1987],("if"),if_DASH_61110729);
if(--R.GAS > 0) {
$z1073010731 = R.isFunction(if_helper485810712)?if_helper485810712.app(cont_tail_arg486010732):R.ffi.throwNonFunApp(L[1987],if_helper485810712,[cont_tail_arg486010732]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper485810712)?if_helper485810712.app(cont_tail_arg486010732):R.ffi.throwNonFunApp(L[1987],if_helper485810712,[cont_tail_arg486010732]);
},
"from":L[1987]});
}
++R.GAS;
return $z1073010731;
}
};
},{"length":3});
var anf_variant_member488910578 = R.makeMethod(function(self61010694) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1987],0,arguments);
}
var anf_arg487310692 = G(self61010694,"l",L[1987]);
var $z1068410685 = D;
var $f1069010691 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg487310692):R.ffi.throwNonFunApp(L[1987],torepr65,[anf_arg487310692]);
};
try {
if(--R.GAS > 0) {
$z1068410685 = $f1069010691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1069010691,
"from":L[1987]});
}
} catch($e1068210683) {
if(R.isCont($e1068210683)) {
var $ss1068610687 = {"from":L[1987],
"go":function(anf_arg487410693) {
return $Hanf_arg1014910695(anf_arg487410693,self61010694,_plus55,torepr65);
}};
$e1068210683.stack[R.EXN_STACKHEIGHT++] = $ss1068610687;
}
if(R.isPyretException($e1068210683)) {
$e1068210683.pyretStack.push(L[1987]);
}
throw $e1068210683;
}
var $ret1068810689 = $Hanf_arg1014910695($z1068410685,self61010694,_plus55,torepr65);
++R.GAS;
return $ret1068810689;
};
},{"length":1});
var anf_variant_member489110579 = R.makeMethod(function(self109610681) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2006],0,arguments);
}
var ann_DASH_check_DASH_temp489010680 = ("s-datatype-variant");
return ann_DASH_check_DASH_temp489010680;
};
},{"length":1});
var anf_variant_member489410580 = R.makeMethod(function(self109710679) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2004],0,arguments);
}
var anf_fun489310676 = G(PP170,"str",L[2005]);
var $z1066810669 = D;
var $f1067410675 = function(_) {
return R.isFunction(anf_fun489310676)?anf_fun489310676.app(("FIXME 10/24/2013: dbp doesn't understand this pp stuff")):R.ffi.throwNonFunApp(L[2004],anf_fun489310676,[("FIXME 10/24/2013: dbp doesn't understand this pp stuff")]);
};
try {
if(--R.GAS > 0) {
$z1066810669 = $f1067410675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1067410675,
"from":L[2004]});
}
} catch($e1066610667) {
if(R.isCont($e1066610667)) {
var $ss1067010671 = {"from":L[2004],
"go":function(ann_DASH_check_DASH_temp489210677) {
return $Hann_DASH_check_DASH_temp1015010678(ann_DASH_check_DASH_temp489210677);
}};
$e1066610667.stack[R.EXN_STACKHEIGHT++] = $ss1067010671;
}
if(R.isPyretException($e1066610667)) {
$e1066610667.pyretStack.push(L[2004]);
}
throw $e1066610667;
}
var $ret1067210673 = $Hann_DASH_check_DASH_temp1015010678($z1066810669);
++R.GAS;
return $ret1067210673;
};
},{"length":1});
var anf_variant_member490810590 = R.makeMethod(function(self61310644) {
return function(cases_DASH_funs61410645,else_DASH_clause61510656) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1986],2,arguments);
}
var if_DASH_61710659 = R.hasField(cases_DASH_funs61410645,("s-datatype-singleton-variant"));
var if_helper489610642 = R.makeFunction(function(if_helper_arg489710664) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1986],1,arguments);
}
var ann_DASH_check_DASH_temp489510665 = if_helper_arg489710664;
return ann_DASH_check_DASH_temp489510665;
});
var anf_if490010663 = R.isBoolean(if_DASH_61710659);
if(R.isPyretTrue(anf_if490010663)) {
if(R.isPyretTrue(if_DASH_61710659)) {
var call_DASH_s_DASH_datatype_DASH_singleton_DASH_variant61210637 = G(cases_DASH_funs61410645,"s-datatype-singleton-variant",L[1986]);
var anf_arg490310638 = G(self61310644,"l",L[2003]);
var anf_arg490410639 = G(self61310644,"name",L[2002]);
var anf_arg490510640 = G(self61310644,"constructor",L[2001]);
var $z1062910630 = D;
var $f1063510636 = function(_) {
return R.isFunction(call_DASH_s_DASH_datatype_DASH_singleton_DASH_variant61210637)?call_DASH_s_DASH_datatype_DASH_singleton_DASH_variant61210637.app(anf_arg490310638,anf_arg490410639,anf_arg490510640):R.ffi.throwNonFunApp(L[1986],call_DASH_s_DASH_datatype_DASH_singleton_DASH_variant61210637,[anf_arg490310638,anf_arg490410639,anf_arg490510640]);
};
try {
if(--R.GAS > 0) {
$z1062910630 = $f1063510636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1063510636,
"from":L[1986]});
}
} catch($e1062710628) {
if(R.isCont($e1062710628)) {
var $ss1063110632 = {"from":L[1986],
"go":function(cont_tail_arg490610641) {
return $Hcont_tail_arg1015110643(cont_tail_arg490610641,if_helper489610642);
}};
$e1062710628.stack[R.EXN_STACKHEIGHT++] = $ss1063110632;
}
if(R.isPyretException($e1062710628)) {
$e1062710628.pyretStack.push(L[1986]);
}
throw $e1062710628;
}
var $ret1063310634 = $Hcont_tail_arg1015110643($z1062910630,if_helper489610642);
++R.GAS;
return $ret1063310634;
} else {
var $z1064810649 = D;
var $f1065410655 = function(_) {
return R.isFunction(else_DASH_clause61510656)?else_DASH_clause61510656.app():R.ffi.throwNonFunApp(L[1986],else_DASH_clause61510656,[]);
};
try {
if(--R.GAS > 0) {
$z1064810649 = $f1065410655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1065410655,
"from":L[1986]});
}
} catch($e1064610647) {
if(R.isCont($e1064610647)) {
var $ss1065010651 = {"from":L[1986],
"go":function(cont_tail_arg490110657) {
return $Hcont_tail_arg1015210658(cont_tail_arg490110657,if_helper489610642);
}};
$e1064610647.stack[R.EXN_STACKHEIGHT++] = $ss1065010651;
}
if(R.isPyretException($e1064610647)) {
$e1064610647.pyretStack.push(L[1986]);
}
throw $e1064610647;
}
var $ret1065210653 = $Hcont_tail_arg1015210658($z1064810649,if_helper489610642);
++R.GAS;
return $ret1065210653;
}
} else {
var cont_tail_arg489810662 = R.throwNonBooleanCondition(L[1986],("if"),if_DASH_61710659);
if(--R.GAS > 0) {
$z1066010661 = R.isFunction(if_helper489610642)?if_helper489610642.app(cont_tail_arg489810662):R.ffi.throwNonFunApp(L[1986],if_helper489610642,[cont_tail_arg489810662]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper489610642)?if_helper489610642.app(cont_tail_arg489810662):R.ffi.throwNonFunApp(L[1986],if_helper489610642,[cont_tail_arg489810662]);
},
"from":L[1986]});
}
++R.GAS;
return $z1066010661;
}
};
},{"length":3});
var anf_variant_member492210591 = R.makeMethod(function(self61610625) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1986],0,arguments);
}
var anf_arg491010623 = G(self61610625,"l",L[1986]);
var $z1061510616 = D;
var $f1062110622 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg491010623):R.ffi.throwNonFunApp(L[1986],torepr65,[anf_arg491010623]);
};
try {
if(--R.GAS > 0) {
$z1061510616 = $f1062110622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1062110622,
"from":L[1986]});
}
} catch($e1061310614) {
if(R.isCont($e1061310614)) {
var $ss1061710618 = {"from":L[1986],
"go":function(anf_arg491110624) {
return $Hanf_arg1016210626(anf_arg491110624,self61610625,_plus55,torepr65);
}};
$e1061310614.stack[R.EXN_STACKHEIGHT++] = $ss1061710618;
}
if(R.isPyretException($e1061310614)) {
$e1061310614.pyretStack.push(L[1986]);
}
throw $e1061310614;
}
var $ret1061910620 = $Hanf_arg1016210626($z1061510616,self61610625,_plus55,torepr65);
++R.GAS;
return $ret1061910620;
};
},{"length":1});
var anf_variant_member492410592 = R.makeMethod(function(self110110612) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2000],0,arguments);
}
var ann_DASH_check_DASH_temp492310611 = ("s-datatype-singleton-variant");
return ann_DASH_check_DASH_temp492310611;
};
},{"length":1});
var anf_variant_member492710593 = R.makeMethod(function(self110210610) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1998],0,arguments);
}
var anf_fun492610607 = G(PP170,"str",L[1999]);
var $z1059910600 = D;
var $f1060510606 = function(_) {
return R.isFunction(anf_fun492610607)?anf_fun492610607.app(("FIXME 10/24/2013: dbp doesn't understand this pp stuff")):R.ffi.throwNonFunApp(L[1998],anf_fun492610607,[("FIXME 10/24/2013: dbp doesn't understand this pp stuff")]);
};
try {
if(--R.GAS > 0) {
$z1059910600 = $f1060510606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1060510606,
"from":L[1998]});
}
} catch($e1059710598) {
if(R.isCont($e1059710598)) {
var $ss1060110602 = {"from":L[1998],
"go":function(ann_DASH_check_DASH_temp492510608) {
return $Hann_DASH_check_DASH_temp1016310609(ann_DASH_check_DASH_temp492510608);
}};
$e1059710598.stack[R.EXN_STACKHEIGHT++] = $ss1060110602;
}
if(R.isPyretException($e1059710598)) {
$e1059710598.pyretStack.push(L[1998]);
}
throw $e1059710598;
}
var $ret1060310604 = $Hann_DASH_check_DASH_temp1016310609($z1059910600);
++R.GAS;
return $ret1060310604;
};
},{"length":1});
var anf_assign49282254 = (function() {
var $s_DASH_datatype_DASH_variant_DASH_base1057210573 = {"visit":anf_shared485610571,
"_match":anf_variant_member487110577,
"_torepr":anf_variant_member488910578,
"label":anf_variant_member489110579,
"tosource":anf_variant_member489410580};
var $s_DASH_datatype_DASH_variant_DASH_brands1057510576 = {"$brand-s-datatype-variant10574":true};
$s_DASH_datatype_DASH_variant_DASH_brands1057510576[DatatypeVariantT19103110._brand] = true
var $s_DASH_datatype_DASH_singleton_DASH_variant_DASH_base1058510586 = {"visit":anf_shared485610571,
"_match":anf_variant_member490810590,
"_torepr":anf_variant_member492210591,
"label":anf_variant_member492410592,
"tosource":anf_variant_member492710593};
var $s_DASH_datatype_DASH_singleton_DASH_variant_DASH_brands1058810589 = {"$brand-s-datatype-singleton-variant10587":true};
$s_DASH_datatype_DASH_singleton_DASH_variant_DASH_brands1058810589[DatatypeVariantT19103110._brand] = true
return R.makeObject({"DatatypeVariant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1988],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,DatatypeVariantT19103110._brand));
}),
"is-s-datatype-variant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1987],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-datatype-variant10574"));
}),
"s-datatype-variant":R.makeFunction(function(l109210581,name109310582,members109410583,constructor109510584) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1989],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,Constructor104107],[l109210581,name109310582,members109410583,constructor109510584],[L[1990],L[1991],L[1992],L[1993]],function() {
var dict = R.create($s_DASH_datatype_DASH_variant_DASH_base1057210573);
dict["l"] = l109210581
dict["name"] = name109310582
dict["members"] = members109410583
dict["constructor"] = constructor109510584
return R.makeBrandedObject(dict,$s_DASH_datatype_DASH_variant_DASH_brands1057510576);
});
}),
"is-s-datatype-singleton-variant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1986],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-datatype-singleton-variant10587"));
}),
"s-datatype-singleton-variant":R.makeFunction(function(l109810594,name109910595,constructor110010596) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1994],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Constructor104107],[l109810594,name109910595,constructor110010596],[L[1995],L[1996],L[1997]],function() {
var dict = R.create($s_DASH_datatype_DASH_singleton_DASH_variant_DASH_base1058510586);
dict["l"] = l109810594
dict["name"] = name109910595
dict["constructor"] = constructor110010596
return R.makeBrandedObject(dict,$s_DASH_datatype_DASH_singleton_DASH_variant_DASH_brands1058810589);
});
})});
})();
DatatypeVariant444762253.$var = anf_assign49282254;
var anf_assign49292256 = G(DatatypeVariant444762253.$var,"DatatypeVariant",L[1988]);
DatatypeVariant4772255.$var = anf_assign49292256;
var anf_assign49302258 = G(DatatypeVariant444762253.$var,"DatatypeVariant",L[1988]);
is_DASH_DatatypeVariant4782257.$var = anf_assign49302258;
var anf_assign49312260 = G(DatatypeVariant444762253.$var,"is-s-datatype-variant",L[1987]);
is_DASH_s_DASH_datatype_DASH_variant4792259.$var = anf_assign49312260;
var anf_assign49322262 = G(DatatypeVariant444762253.$var,"s-datatype-variant",L[1987]);
s_DASH_datatype_DASH_variant4802261.$var = anf_assign49322262;
var anf_assign49332264 = G(DatatypeVariant444762253.$var,"is-s-datatype-singleton-variant",L[1986]);
is_DASH_s_DASH_datatype_DASH_singleton_DASH_variant4812263.$var = anf_assign49332264;
var anf_assign49342266 = G(DatatypeVariant444762253.$var,"s-datatype-singleton-variant",L[1986]);
s_DASH_datatype_DASH_singleton_DASH_variant4822265.$var = anf_assign49342266;
var anf_shared494210460 = R.makeMethod(function(self111010570) {
return function(visitor111110553) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1981],1,arguments);
}
var anf_fun493610552 = G(self111010570,"_match",L[1985]);
var anf_arg494110554 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1982],0,arguments);
}
var anf_fun493810567 = G(self111010570,"label",L[1984]);
var $z1055910560 = D;
var $f1056510566 = function(_) {
return R.isFunction(anf_fun493810567)?anf_fun493810567.app():R.ffi.throwNonFunApp(L[1983],anf_fun493810567,[]);
};
try {
if(--R.GAS > 0) {
$z1055910560 = $f1056510566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1056510566,
"from":L[1983]});
}
} catch($e1055710558) {
if(R.isCont($e1055710558)) {
var $ss1056110562 = {"from":L[1983],
"go":function(anf_arg493910568) {
return $Hanf_arg1016610569(anf_arg493910568,_plus55,raise62);
}};
$e1055710558.stack[R.EXN_STACKHEIGHT++] = $ss1056110562;
}
if(R.isPyretException($e1055710558)) {
$e1055710558.pyretStack.push(L[1983]);
}
throw $e1055710558;
}
var $ret1056310564 = $Hanf_arg1016610569($z1055910560,_plus55,raise62);
++R.GAS;
return $ret1056310564;
});
var $z1054410545 = D;
var $f1055010551 = function(_) {
return R.isFunction(anf_fun493610552)?anf_fun493610552.app(visitor111110553,anf_arg494110554):R.ffi.throwNonFunApp(L[1981],anf_fun493610552,[visitor111110553,anf_arg494110554]);
};
try {
if(--R.GAS > 0) {
$z1054410545 = $f1055010551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1055010551,
"from":L[1981]});
}
} catch($e1054210543) {
if(R.isCont($e1054210543)) {
var $ss1054610547 = {"from":L[1981],
"go":function(ann_DASH_check_DASH_temp493510555) {
return $Hann_DASH_check_DASH_temp1016710556(ann_DASH_check_DASH_temp493510555);
}};
$e1054210543.stack[R.EXN_STACKHEIGHT++] = $ss1054610547;
}
if(R.isPyretException($e1054210543)) {
$e1054210543.pyretStack.push(L[1981]);
}
throw $e1054210543;
}
var $ret1054810549 = $Hann_DASH_check_DASH_temp1016710556($z1054410545);
++R.GAS;
return $ret1054810549;
};
},{"length":2});
var anf_variant_member495610466 = R.makeMethod(function(self61910520) {
return function(cases_DASH_funs62010521,else_DASH_clause62110532) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1969],2,arguments);
}
var if_DASH_62310535 = R.hasField(cases_DASH_funs62010521,("s-datatype-constructor"));
var if_helper494410518 = R.makeFunction(function(if_helper_arg494510540) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1969],1,arguments);
}
var ann_DASH_check_DASH_temp494310541 = if_helper_arg494510540;
return ann_DASH_check_DASH_temp494310541;
});
var anf_if494810539 = R.isBoolean(if_DASH_62310535);
if(R.isPyretTrue(anf_if494810539)) {
if(R.isPyretTrue(if_DASH_62310535)) {
var call_DASH_s_DASH_datatype_DASH_constructor61810513 = G(cases_DASH_funs62010521,"s-datatype-constructor",L[1969]);
var anf_arg495110514 = G(self61910520,"l",L[1980]);
var anf_arg495210515 = G(self61910520,"self",L[1979]);
var anf_arg495310516 = G(self61910520,"body",L[1978]);
var $z1050510506 = D;
var $f1051110512 = function(_) {
return R.isFunction(call_DASH_s_DASH_datatype_DASH_constructor61810513)?call_DASH_s_DASH_datatype_DASH_constructor61810513.app(anf_arg495110514,anf_arg495210515,anf_arg495310516):R.ffi.throwNonFunApp(L[1969],call_DASH_s_DASH_datatype_DASH_constructor61810513,[anf_arg495110514,anf_arg495210515,anf_arg495310516]);
};
try {
if(--R.GAS > 0) {
$z1050510506 = $f1051110512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1051110512,
"from":L[1969]});
}
} catch($e1050310504) {
if(R.isCont($e1050310504)) {
var $ss1050710508 = {"from":L[1969],
"go":function(cont_tail_arg495410517) {
return $Hcont_tail_arg1016810519(cont_tail_arg495410517,if_helper494410518);
}};
$e1050310504.stack[R.EXN_STACKHEIGHT++] = $ss1050710508;
}
if(R.isPyretException($e1050310504)) {
$e1050310504.pyretStack.push(L[1969]);
}
throw $e1050310504;
}
var $ret1050910510 = $Hcont_tail_arg1016810519($z1050510506,if_helper494410518);
++R.GAS;
return $ret1050910510;
} else {
var $z1052410525 = D;
var $f1053010531 = function(_) {
return R.isFunction(else_DASH_clause62110532)?else_DASH_clause62110532.app():R.ffi.throwNonFunApp(L[1969],else_DASH_clause62110532,[]);
};
try {
if(--R.GAS > 0) {
$z1052410525 = $f1053010531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1053010531,
"from":L[1969]});
}
} catch($e1052210523) {
if(R.isCont($e1052210523)) {
var $ss1052610527 = {"from":L[1969],
"go":function(cont_tail_arg494910533) {
return $Hcont_tail_arg1016910534(cont_tail_arg494910533,if_helper494410518);
}};
$e1052210523.stack[R.EXN_STACKHEIGHT++] = $ss1052610527;
}
if(R.isPyretException($e1052210523)) {
$e1052210523.pyretStack.push(L[1969]);
}
throw $e1052210523;
}
var $ret1052810529 = $Hcont_tail_arg1016910534($z1052410525,if_helper494410518);
++R.GAS;
return $ret1052810529;
}
} else {
var cont_tail_arg494610538 = R.throwNonBooleanCondition(L[1969],("if"),if_DASH_62310535);
if(--R.GAS > 0) {
$z1053610537 = R.isFunction(if_helper494410518)?if_helper494410518.app(cont_tail_arg494610538):R.ffi.throwNonFunApp(L[1969],if_helper494410518,[cont_tail_arg494610538]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper494410518)?if_helper494410518.app(cont_tail_arg494610538):R.ffi.throwNonFunApp(L[1969],if_helper494410518,[cont_tail_arg494610538]);
},
"from":L[1969]});
}
++R.GAS;
return $z1053610537;
}
};
},{"length":3});
var anf_variant_member497010467 = R.makeMethod(function(self62210501) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1969],0,arguments);
}
var anf_arg495810499 = G(self62210501,"l",L[1969]);
var $z1049110492 = D;
var $f1049710498 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg495810499):R.ffi.throwNonFunApp(L[1969],torepr65,[anf_arg495810499]);
};
try {
if(--R.GAS > 0) {
$z1049110492 = $f1049710498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1049710498,
"from":L[1969]});
}
} catch($e1048910490) {
if(R.isCont($e1048910490)) {
var $ss1049310494 = {"from":L[1969],
"go":function(anf_arg495910500) {
return $Hanf_arg1017910502(anf_arg495910500,self62210501,_plus55,torepr65);
}};
$e1048910490.stack[R.EXN_STACKHEIGHT++] = $ss1049310494;
}
if(R.isPyretException($e1048910490)) {
$e1048910490.pyretStack.push(L[1969]);
}
throw $e1048910490;
}
var $ret1049510496 = $Hanf_arg1017910502($z1049110492,self62210501,_plus55,torepr65);
++R.GAS;
return $ret1049510496;
};
},{"length":1});
var anf_variant_member497210468 = R.makeMethod(function(self110810488) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1977],0,arguments);
}
var ann_DASH_check_DASH_temp497110487 = ("s-datatype-constructor");
return ann_DASH_check_DASH_temp497110487;
};
},{"length":1});
var anf_variant_member497510469 = R.makeMethod(function(self110910486) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1975],0,arguments);
}
var anf_fun497410483 = G(PP170,"str",L[1976]);
var $z1047510476 = D;
var $f1048110482 = function(_) {
return R.isFunction(anf_fun497410483)?anf_fun497410483.app(("FIXME 10/24/2013: dbp doesn't understand this pp stuff")):R.ffi.throwNonFunApp(L[1975],anf_fun497410483,[("FIXME 10/24/2013: dbp doesn't understand this pp stuff")]);
};
try {
if(--R.GAS > 0) {
$z1047510476 = $f1048110482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1048110482,
"from":L[1975]});
}
} catch($e1047310474) {
if(R.isCont($e1047310474)) {
var $ss1047710478 = {"from":L[1975],
"go":function(ann_DASH_check_DASH_temp497310484) {
return $Hann_DASH_check_DASH_temp1018010485(ann_DASH_check_DASH_temp497310484);
}};
$e1047310474.stack[R.EXN_STACKHEIGHT++] = $ss1047710478;
}
if(R.isPyretException($e1047310474)) {
$e1047310474.pyretStack.push(L[1975]);
}
throw $e1047310474;
}
var $ret1047910480 = $Hann_DASH_check_DASH_temp1018010485($z1047510476);
++R.GAS;
return $ret1047910480;
};
},{"length":1});
var anf_assign49762268 = (function() {
var $s_DASH_datatype_DASH_constructor_DASH_base1046110462 = {"visit":anf_shared494210460,
"_match":anf_variant_member495610466,
"_torepr":anf_variant_member497010467,
"label":anf_variant_member497210468,
"tosource":anf_variant_member497510469};
var $s_DASH_datatype_DASH_constructor_DASH_brands1046410465 = {"$brand-s-datatype-constructor10463":true};
$s_DASH_datatype_DASH_constructor_DASH_brands1046410465[ConstructorT20105108._brand] = true
return R.makeObject({"Constructor":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1970],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ConstructorT20105108._brand));
}),
"is-s-datatype-constructor":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1969],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-datatype-constructor10463"));
}),
"s-datatype-constructor":R.makeFunction(function(l110510470,self110610471,body110710472) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1971],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111],[l110510470,self110610471,body110710472],[L[1972],L[1973],L[1974]],function() {
var dict = R.create($s_DASH_datatype_DASH_constructor_DASH_base1046110462);
dict["l"] = l110510470
dict["self"] = self110610471
dict["body"] = body110710472
return R.makeBrandedObject(dict,$s_DASH_datatype_DASH_constructor_DASH_brands1046410465);
});
})});
})();
Constructor454832267.$var = anf_assign49762268;
var anf_assign49772270 = G(Constructor454832267.$var,"Constructor",L[1970]);
Constructor4842269.$var = anf_assign49772270;
var anf_assign49782272 = G(Constructor454832267.$var,"Constructor",L[1970]);
is_DASH_Constructor4852271.$var = anf_assign49782272;
var anf_assign49792274 = G(Constructor454832267.$var,"is-s-datatype-constructor",L[1969]);
is_DASH_s_DASH_datatype_DASH_constructor4862273.$var = anf_assign49792274;
var anf_assign49802276 = G(Constructor454832267.$var,"s-datatype-constructor",L[1969]);
s_DASH_datatype_DASH_constructor4872275.$var = anf_assign49802276;
var anf_shared498810349 = R.makeMethod(function(self111710459) {
return function(visitor111810442) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1964],1,arguments);
}
var anf_fun498210441 = G(self111710459,"_match",L[1968]);
var anf_arg498710443 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1965],0,arguments);
}
var anf_fun498410456 = G(self111710459,"label",L[1967]);
var $z1044810449 = D;
var $f1045410455 = function(_) {
return R.isFunction(anf_fun498410456)?anf_fun498410456.app():R.ffi.throwNonFunApp(L[1966],anf_fun498410456,[]);
};
try {
if(--R.GAS > 0) {
$z1044810449 = $f1045410455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1045410455,
"from":L[1966]});
}
} catch($e1044610447) {
if(R.isCont($e1044610447)) {
var $ss1045010451 = {"from":L[1966],
"go":function(anf_arg498510457) {
return $Hanf_arg1018310458(anf_arg498510457,_plus55,raise62);
}};
$e1044610447.stack[R.EXN_STACKHEIGHT++] = $ss1045010451;
}
if(R.isPyretException($e1044610447)) {
$e1044610447.pyretStack.push(L[1966]);
}
throw $e1044610447;
}
var $ret1045210453 = $Hanf_arg1018310458($z1044810449,_plus55,raise62);
++R.GAS;
return $ret1045210453;
});
var $z1043310434 = D;
var $f1043910440 = function(_) {
return R.isFunction(anf_fun498210441)?anf_fun498210441.app(visitor111810442,anf_arg498710443):R.ffi.throwNonFunApp(L[1964],anf_fun498210441,[visitor111810442,anf_arg498710443]);
};
try {
if(--R.GAS > 0) {
$z1043310434 = $f1043910440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1043910440,
"from":L[1964]});
}
} catch($e1043110432) {
if(R.isCont($e1043110432)) {
var $ss1043510436 = {"from":L[1964],
"go":function(ann_DASH_check_DASH_temp498110444) {
return $Hann_DASH_check_DASH_temp1018410445(ann_DASH_check_DASH_temp498110444);
}};
$e1043110432.stack[R.EXN_STACKHEIGHT++] = $ss1043510436;
}
if(R.isPyretException($e1043110432)) {
$e1043110432.pyretStack.push(L[1964]);
}
throw $e1043110432;
}
var $ret1043710438 = $Hann_DASH_check_DASH_temp1018410445($z1043310434);
++R.GAS;
return $ret1043710438;
};
},{"length":2});
var anf_variant_member500210355 = R.makeMethod(function(self62510409) {
return function(cases_DASH_funs62610410,else_DASH_clause62710421) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1951],2,arguments);
}
var if_DASH_62910424 = R.hasField(cases_DASH_funs62610410,("s-if-branch"));
var if_helper499010407 = R.makeFunction(function(if_helper_arg499110429) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1951],1,arguments);
}
var ann_DASH_check_DASH_temp498910430 = if_helper_arg499110429;
return ann_DASH_check_DASH_temp498910430;
});
var anf_if499410428 = R.isBoolean(if_DASH_62910424);
if(R.isPyretTrue(anf_if499410428)) {
if(R.isPyretTrue(if_DASH_62910424)) {
var call_DASH_s_DASH_if_DASH_branch62410402 = G(cases_DASH_funs62610410,"s-if-branch",L[1951]);
var anf_arg499710403 = G(self62510409,"l",L[1963]);
var anf_arg499810404 = G(self62510409,"test",L[1962]);
var anf_arg499910405 = G(self62510409,"body",L[1961]);
var $z1039410395 = D;
var $f1040010401 = function(_) {
return R.isFunction(call_DASH_s_DASH_if_DASH_branch62410402)?call_DASH_s_DASH_if_DASH_branch62410402.app(anf_arg499710403,anf_arg499810404,anf_arg499910405):R.ffi.throwNonFunApp(L[1951],call_DASH_s_DASH_if_DASH_branch62410402,[anf_arg499710403,anf_arg499810404,anf_arg499910405]);
};
try {
if(--R.GAS > 0) {
$z1039410395 = $f1040010401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1040010401,
"from":L[1951]});
}
} catch($e1039210393) {
if(R.isCont($e1039210393)) {
var $ss1039610397 = {"from":L[1951],
"go":function(cont_tail_arg500010406) {
return $Hcont_tail_arg1018510408(cont_tail_arg500010406,if_helper499010407);
}};
$e1039210393.stack[R.EXN_STACKHEIGHT++] = $ss1039610397;
}
if(R.isPyretException($e1039210393)) {
$e1039210393.pyretStack.push(L[1951]);
}
throw $e1039210393;
}
var $ret1039810399 = $Hcont_tail_arg1018510408($z1039410395,if_helper499010407);
++R.GAS;
return $ret1039810399;
} else {
var $z1041310414 = D;
var $f1041910420 = function(_) {
return R.isFunction(else_DASH_clause62710421)?else_DASH_clause62710421.app():R.ffi.throwNonFunApp(L[1951],else_DASH_clause62710421,[]);
};
try {
if(--R.GAS > 0) {
$z1041310414 = $f1041910420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1041910420,
"from":L[1951]});
}
} catch($e1041110412) {
if(R.isCont($e1041110412)) {
var $ss1041510416 = {"from":L[1951],
"go":function(cont_tail_arg499510422) {
return $Hcont_tail_arg1018610423(cont_tail_arg499510422,if_helper499010407);
}};
$e1041110412.stack[R.EXN_STACKHEIGHT++] = $ss1041510416;
}
if(R.isPyretException($e1041110412)) {
$e1041110412.pyretStack.push(L[1951]);
}
throw $e1041110412;
}
var $ret1041710418 = $Hcont_tail_arg1018610423($z1041310414,if_helper499010407);
++R.GAS;
return $ret1041710418;
}
} else {
var cont_tail_arg499210427 = R.throwNonBooleanCondition(L[1951],("if"),if_DASH_62910424);
if(--R.GAS > 0) {
$z1042510426 = R.isFunction(if_helper499010407)?if_helper499010407.app(cont_tail_arg499210427):R.ffi.throwNonFunApp(L[1951],if_helper499010407,[cont_tail_arg499210427]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper499010407)?if_helper499010407.app(cont_tail_arg499210427):R.ffi.throwNonFunApp(L[1951],if_helper499010407,[cont_tail_arg499210427]);
},
"from":L[1951]});
}
++R.GAS;
return $z1042510426;
}
};
},{"length":3});
var anf_variant_member501610356 = R.makeMethod(function(self62810390) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1951],0,arguments);
}
var anf_arg500410388 = G(self62810390,"l",L[1951]);
var $z1038010381 = D;
var $f1038610387 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg500410388):R.ffi.throwNonFunApp(L[1951],torepr65,[anf_arg500410388]);
};
try {
if(--R.GAS > 0) {
$z1038010381 = $f1038610387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1038610387,
"from":L[1951]});
}
} catch($e1037810379) {
if(R.isCont($e1037810379)) {
var $ss1038210383 = {"from":L[1951],
"go":function(anf_arg500510389) {
return $Hanf_arg1019610391(anf_arg500510389,self62810390,_plus55,torepr65);
}};
$e1037810379.stack[R.EXN_STACKHEIGHT++] = $ss1038210383;
}
if(R.isPyretException($e1037810379)) {
$e1037810379.pyretStack.push(L[1951]);
}
throw $e1037810379;
}
var $ret1038410385 = $Hanf_arg1019610391($z1038010381,self62810390,_plus55,torepr65);
++R.GAS;
return $ret1038410385;
};
},{"length":1});
var anf_variant_member501810357 = R.makeMethod(function(self111510377) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1960],0,arguments);
}
var ann_DASH_check_DASH_temp501710376 = ("s-if-branch");
return ann_DASH_check_DASH_temp501710376;
};
},{"length":1});
var anf_variant_member503410358 = R.makeMethod(function(self111610374) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1959],0,arguments);
}
var anf_fun502010373 = G(PP170,"nest",L[1958]);
var $z1036410365 = D;
var $f1037010371 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[1957],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z1036410365 = $f1037010371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1037010371,
"from":L[1957]});
}
} catch($e1036210363) {
if(R.isCont($e1036210363)) {
var $ss1036610367 = {"from":L[1957],
"go":function(anf_arg502110372) {
return $Hanf_arg1020510375(anf_arg502110372,INDENT118169,PP170,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_colon134364,str_DASH_if155637,_plus55);
}};
$e1036210363.stack[R.EXN_STACKHEIGHT++] = $ss1036610367;
}
if(R.isPyretException($e1036210363)) {
$e1036210363.pyretStack.push(L[1957]);
}
throw $e1036210363;
}
var $ret1036810369 = $Hanf_arg1020510375($z1036410365,INDENT118169,PP170,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_colon134364,str_DASH_if155637,_plus55);
++R.GAS;
return $ret1036810369;
};
},{"length":1});
var anf_assign50352278 = (function() {
var $s_DASH_if_DASH_branch_DASH_base1035010351 = {"visit":anf_shared498810349,
"_match":anf_variant_member500210355,
"_torepr":anf_variant_member501610356,
"label":anf_variant_member501810357,
"tosource":anf_variant_member503410358};
var $s_DASH_if_DASH_branch_DASH_brands1035310354 = {"$brand-s-if-branch10352":true};
$s_DASH_if_DASH_branch_DASH_brands1035310354[IfBranchT21107118._brand] = true
return R.makeObject({"IfBranch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1952],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,IfBranchT21107118._brand));
}),
"is-s-if-branch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1951],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-if-branch10352"));
}),
"s-if-branch":R.makeFunction(function(l111210359,test111310360,body111410361) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1953],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l111210359,test111310360,body111410361],[L[1954],L[1955],L[1956]],function() {
var dict = R.create($s_DASH_if_DASH_branch_DASH_base1035010351);
dict["l"] = l111210359
dict["test"] = test111310360
dict["body"] = body111410361
return R.makeBrandedObject(dict,$s_DASH_if_DASH_branch_DASH_brands1035310354);
});
})});
})();
IfBranch464882277.$var = anf_assign50352278;
var anf_assign50362280 = G(IfBranch464882277.$var,"IfBranch",L[1952]);
IfBranch4892279.$var = anf_assign50362280;
var anf_assign50372282 = G(IfBranch464882277.$var,"IfBranch",L[1952]);
is_DASH_IfBranch4902281.$var = anf_assign50372282;
var anf_assign50382284 = G(IfBranch464882277.$var,"is-s-if-branch",L[1951]);
is_DASH_s_DASH_if_DASH_branch4912283.$var = anf_assign50382284;
var anf_assign50392286 = G(IfBranch464882277.$var,"s-if-branch",L[1951]);
s_DASH_if_DASH_branch4922285.$var = anf_assign50392286;
var anf_shared504710238 = R.makeMethod(function(self112410348) {
return function(visitor112510331) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1946],1,arguments);
}
var anf_fun504110330 = G(self112410348,"_match",L[1950]);
var anf_arg504610332 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1947],0,arguments);
}
var anf_fun504310345 = G(self112410348,"label",L[1949]);
var $z1033710338 = D;
var $f1034310344 = function(_) {
return R.isFunction(anf_fun504310345)?anf_fun504310345.app():R.ffi.throwNonFunApp(L[1948],anf_fun504310345,[]);
};
try {
if(--R.GAS > 0) {
$z1033710338 = $f1034310344();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1034310344,
"from":L[1948]});
}
} catch($e1033510336) {
if(R.isCont($e1033510336)) {
var $ss1033910340 = {"from":L[1948],
"go":function(anf_arg504410346) {
return $Hanf_arg1020810347(anf_arg504410346,_plus55,raise62);
}};
$e1033510336.stack[R.EXN_STACKHEIGHT++] = $ss1033910340;
}
if(R.isPyretException($e1033510336)) {
$e1033510336.pyretStack.push(L[1948]);
}
throw $e1033510336;
}
var $ret1034110342 = $Hanf_arg1020810347($z1033710338,_plus55,raise62);
++R.GAS;
return $ret1034110342;
});
var $z1032210323 = D;
var $f1032810329 = function(_) {
return R.isFunction(anf_fun504110330)?anf_fun504110330.app(visitor112510331,anf_arg504610332):R.ffi.throwNonFunApp(L[1946],anf_fun504110330,[visitor112510331,anf_arg504610332]);
};
try {
if(--R.GAS > 0) {
$z1032210323 = $f1032810329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1032810329,
"from":L[1946]});
}
} catch($e1032010321) {
if(R.isCont($e1032010321)) {
var $ss1032410325 = {"from":L[1946],
"go":function(ann_DASH_check_DASH_temp504010333) {
return $Hann_DASH_check_DASH_temp1020910334(ann_DASH_check_DASH_temp504010333);
}};
$e1032010321.stack[R.EXN_STACKHEIGHT++] = $ss1032410325;
}
if(R.isPyretException($e1032010321)) {
$e1032010321.pyretStack.push(L[1946]);
}
throw $e1032010321;
}
var $ret1032610327 = $Hann_DASH_check_DASH_temp1020910334($z1032210323);
++R.GAS;
return $ret1032610327;
};
},{"length":2});
var anf_variant_member506110244 = R.makeMethod(function(self63110298) {
return function(cases_DASH_funs63210299,else_DASH_clause63310310) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1933],2,arguments);
}
var if_DASH_63510313 = R.hasField(cases_DASH_funs63210299,("s-if-pipe-branch"));
var if_helper504910296 = R.makeFunction(function(if_helper_arg505010318) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1933],1,arguments);
}
var ann_DASH_check_DASH_temp504810319 = if_helper_arg505010318;
return ann_DASH_check_DASH_temp504810319;
});
var anf_if505310317 = R.isBoolean(if_DASH_63510313);
if(R.isPyretTrue(anf_if505310317)) {
if(R.isPyretTrue(if_DASH_63510313)) {
var call_DASH_s_DASH_if_DASH_pipe_DASH_branch63010291 = G(cases_DASH_funs63210299,"s-if-pipe-branch",L[1933]);
var anf_arg505610292 = G(self63110298,"l",L[1945]);
var anf_arg505710293 = G(self63110298,"test",L[1944]);
var anf_arg505810294 = G(self63110298,"body",L[1943]);
var $z1028310284 = D;
var $f1028910290 = function(_) {
return R.isFunction(call_DASH_s_DASH_if_DASH_pipe_DASH_branch63010291)?call_DASH_s_DASH_if_DASH_pipe_DASH_branch63010291.app(anf_arg505610292,anf_arg505710293,anf_arg505810294):R.ffi.throwNonFunApp(L[1933],call_DASH_s_DASH_if_DASH_pipe_DASH_branch63010291,[anf_arg505610292,anf_arg505710293,anf_arg505810294]);
};
try {
if(--R.GAS > 0) {
$z1028310284 = $f1028910290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1028910290,
"from":L[1933]});
}
} catch($e1028110282) {
if(R.isCont($e1028110282)) {
var $ss1028510286 = {"from":L[1933],
"go":function(cont_tail_arg505910295) {
return $Hcont_tail_arg1021010297(cont_tail_arg505910295,if_helper504910296);
}};
$e1028110282.stack[R.EXN_STACKHEIGHT++] = $ss1028510286;
}
if(R.isPyretException($e1028110282)) {
$e1028110282.pyretStack.push(L[1933]);
}
throw $e1028110282;
}
var $ret1028710288 = $Hcont_tail_arg1021010297($z1028310284,if_helper504910296);
++R.GAS;
return $ret1028710288;
} else {
var $z1030210303 = D;
var $f1030810309 = function(_) {
return R.isFunction(else_DASH_clause63310310)?else_DASH_clause63310310.app():R.ffi.throwNonFunApp(L[1933],else_DASH_clause63310310,[]);
};
try {
if(--R.GAS > 0) {
$z1030210303 = $f1030810309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1030810309,
"from":L[1933]});
}
} catch($e1030010301) {
if(R.isCont($e1030010301)) {
var $ss1030410305 = {"from":L[1933],
"go":function(cont_tail_arg505410311) {
return $Hcont_tail_arg1021110312(cont_tail_arg505410311,if_helper504910296);
}};
$e1030010301.stack[R.EXN_STACKHEIGHT++] = $ss1030410305;
}
if(R.isPyretException($e1030010301)) {
$e1030010301.pyretStack.push(L[1933]);
}
throw $e1030010301;
}
var $ret1030610307 = $Hcont_tail_arg1021110312($z1030210303,if_helper504910296);
++R.GAS;
return $ret1030610307;
}
} else {
var cont_tail_arg505110316 = R.throwNonBooleanCondition(L[1933],("if"),if_DASH_63510313);
if(--R.GAS > 0) {
$z1031410315 = R.isFunction(if_helper504910296)?if_helper504910296.app(cont_tail_arg505110316):R.ffi.throwNonFunApp(L[1933],if_helper504910296,[cont_tail_arg505110316]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper504910296)?if_helper504910296.app(cont_tail_arg505110316):R.ffi.throwNonFunApp(L[1933],if_helper504910296,[cont_tail_arg505110316]);
},
"from":L[1933]});
}
++R.GAS;
return $z1031410315;
}
};
},{"length":3});
var anf_variant_member507510245 = R.makeMethod(function(self63410279) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1933],0,arguments);
}
var anf_arg506310277 = G(self63410279,"l",L[1933]);
var $z1026910270 = D;
var $f1027510276 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg506310277):R.ffi.throwNonFunApp(L[1933],torepr65,[anf_arg506310277]);
};
try {
if(--R.GAS > 0) {
$z1026910270 = $f1027510276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1027510276,
"from":L[1933]});
}
} catch($e1026710268) {
if(R.isCont($e1026710268)) {
var $ss1027110272 = {"from":L[1933],
"go":function(anf_arg506410278) {
return $Hanf_arg1022110280(anf_arg506410278,self63410279,_plus55,torepr65);
}};
$e1026710268.stack[R.EXN_STACKHEIGHT++] = $ss1027110272;
}
if(R.isPyretException($e1026710268)) {
$e1026710268.pyretStack.push(L[1933]);
}
throw $e1026710268;
}
var $ret1027310274 = $Hanf_arg1022110280($z1026910270,self63410279,_plus55,torepr65);
++R.GAS;
return $ret1027310274;
};
},{"length":1});
var anf_variant_member507710246 = R.makeMethod(function(self112210266) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1942],0,arguments);
}
var ann_DASH_check_DASH_temp507610265 = ("s-if-pipe-branch");
return ann_DASH_check_DASH_temp507610265;
};
},{"length":1});
var anf_variant_member509410247 = R.makeMethod(function(self112310263) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1941],0,arguments);
}
var anf_fun507910262 = G(PP170,"nest",L[1940]);
var $z1025310254 = D;
var $f1025910260 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[1939],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z1025310254 = $f1025910260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1025910260,
"from":L[1939]});
}
} catch($e1025110252) {
if(R.isCont($e1025110252)) {
var $ss1025510256 = {"from":L[1939],
"go":function(anf_arg508010261) {
return $Hanf_arg1023110264(anf_arg508010261,INDENT118169,PP170,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55);
}};
$e1025110252.stack[R.EXN_STACKHEIGHT++] = $ss1025510256;
}
if(R.isPyretException($e1025110252)) {
$e1025110252.pyretStack.push(L[1939]);
}
throw $e1025110252;
}
var $ret1025710258 = $Hanf_arg1023110264($z1025310254,INDENT118169,PP170,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55);
++R.GAS;
return $ret1025710258;
};
},{"length":1});
var anf_assign50952288 = (function() {
var $s_DASH_if_DASH_pipe_DASH_branch_DASH_base1023910240 = {"visit":anf_shared504710238,
"_match":anf_variant_member506110244,
"_torepr":anf_variant_member507510245,
"label":anf_variant_member507710246,
"tosource":anf_variant_member509410247};
var $s_DASH_if_DASH_pipe_DASH_branch_DASH_brands1024210243 = {"$brand-s-if-pipe-branch10241":true};
$s_DASH_if_DASH_pipe_DASH_branch_DASH_brands1024210243[IfPipeBranchT22109120._brand] = true
return R.makeObject({"IfPipeBranch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1934],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,IfPipeBranchT22109120._brand));
}),
"is-s-if-pipe-branch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1933],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-if-pipe-branch10241"));
}),
"s-if-pipe-branch":R.makeFunction(function(l111910248,test112010249,body112110250) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1935],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l111910248,test112010249,body112110250],[L[1936],L[1937],L[1938]],function() {
var dict = R.create($s_DASH_if_DASH_pipe_DASH_branch_DASH_base1023910240);
dict["l"] = l111910248
dict["test"] = test112010249
dict["body"] = body112110250
return R.makeBrandedObject(dict,$s_DASH_if_DASH_pipe_DASH_branch_DASH_brands1024210243);
});
})});
})();
IfPipeBranch474932287.$var = anf_assign50952288;
var anf_assign50962290 = G(IfPipeBranch474932287.$var,"IfPipeBranch",L[1934]);
IfPipeBranch4942289.$var = anf_assign50962290;
var anf_assign50972292 = G(IfPipeBranch474932287.$var,"IfPipeBranch",L[1934]);
is_DASH_IfPipeBranch4952291.$var = anf_assign50972292;
var anf_assign50982294 = G(IfPipeBranch474932287.$var,"is-s-if-pipe-branch",L[1933]);
is_DASH_s_DASH_if_DASH_pipe_DASH_branch4962293.$var = anf_assign50982294;
var anf_assign50992296 = G(IfPipeBranch474932287.$var,"s-if-pipe-branch",L[1933]);
s_DASH_if_DASH_pipe_DASH_branch4972295.$var = anf_assign50992296;
var anf_shared510710122 = R.makeMethod(function(self113310237) {
return function(visitor113410220) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1928],1,arguments);
}
var anf_fun510110219 = G(self113310237,"_match",L[1932]);
var anf_arg510610221 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1929],0,arguments);
}
var anf_fun510310234 = G(self113310237,"label",L[1931]);
var $z1022610227 = D;
var $f1023210233 = function(_) {
return R.isFunction(anf_fun510310234)?anf_fun510310234.app():R.ffi.throwNonFunApp(L[1930],anf_fun510310234,[]);
};
try {
if(--R.GAS > 0) {
$z1022610227 = $f1023210233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1023210233,
"from":L[1930]});
}
} catch($e1022410225) {
if(R.isCont($e1022410225)) {
var $ss1022810229 = {"from":L[1930],
"go":function(anf_arg510410235) {
return $Hanf_arg1023410236(anf_arg510410235,_plus55,raise62);
}};
$e1022410225.stack[R.EXN_STACKHEIGHT++] = $ss1022810229;
}
if(R.isPyretException($e1022410225)) {
$e1022410225.pyretStack.push(L[1930]);
}
throw $e1022410225;
}
var $ret1023010231 = $Hanf_arg1023410236($z1022610227,_plus55,raise62);
++R.GAS;
return $ret1023010231;
});
var $z1021110212 = D;
var $f1021710218 = function(_) {
return R.isFunction(anf_fun510110219)?anf_fun510110219.app(visitor113410220,anf_arg510610221):R.ffi.throwNonFunApp(L[1928],anf_fun510110219,[visitor113410220,anf_arg510610221]);
};
try {
if(--R.GAS > 0) {
$z1021110212 = $f1021710218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1021710218,
"from":L[1928]});
}
} catch($e1020910210) {
if(R.isCont($e1020910210)) {
var $ss1021310214 = {"from":L[1928],
"go":function(ann_DASH_check_DASH_temp510010222) {
return $Hann_DASH_check_DASH_temp1023510223(ann_DASH_check_DASH_temp510010222);
}};
$e1020910210.stack[R.EXN_STACKHEIGHT++] = $ss1021310214;
}
if(R.isPyretException($e1020910210)) {
$e1020910210.pyretStack.push(L[1928]);
}
throw $e1020910210;
}
var $ret1021510216 = $Hann_DASH_check_DASH_temp1023510223($z1021110212);
++R.GAS;
return $ret1021510216;
};
},{"length":2});
var anf_variant_member512210128 = R.makeMethod(function(self63710187) {
return function(cases_DASH_funs63810188,else_DASH_clause63910199) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1910],2,arguments);
}
var if_DASH_64110202 = R.hasField(cases_DASH_funs63810188,("s-cases-branch"));
var if_helper510910185 = R.makeFunction(function(if_helper_arg511010207) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1910],1,arguments);
}
var ann_DASH_check_DASH_temp510810208 = if_helper_arg511010207;
return ann_DASH_check_DASH_temp510810208;
});
var anf_if511310206 = R.isBoolean(if_DASH_64110202);
if(R.isPyretTrue(anf_if511310206)) {
if(R.isPyretTrue(if_DASH_64110202)) {
var call_DASH_s_DASH_cases_DASH_branch63610179 = G(cases_DASH_funs63810188,"s-cases-branch",L[1910]);
var anf_arg511610180 = G(self63710187,"l",L[1927]);
var anf_arg511710181 = G(self63710187,"name",L[1926]);
var anf_arg511810182 = G(self63710187,"args",L[1925]);
var anf_arg511910183 = G(self63710187,"body",L[1924]);
var $z1017110172 = D;
var $f1017710178 = function(_) {
return R.isFunction(call_DASH_s_DASH_cases_DASH_branch63610179)?call_DASH_s_DASH_cases_DASH_branch63610179.app(anf_arg511610180,anf_arg511710181,anf_arg511810182,anf_arg511910183):R.ffi.throwNonFunApp(L[1910],call_DASH_s_DASH_cases_DASH_branch63610179,[anf_arg511610180,anf_arg511710181,anf_arg511810182,anf_arg511910183]);
};
try {
if(--R.GAS > 0) {
$z1017110172 = $f1017710178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1017710178,
"from":L[1910]});
}
} catch($e1016910170) {
if(R.isCont($e1016910170)) {
var $ss1017310174 = {"from":L[1910],
"go":function(cont_tail_arg512010184) {
return $Hcont_tail_arg1023610186(cont_tail_arg512010184,if_helper510910185);
}};
$e1016910170.stack[R.EXN_STACKHEIGHT++] = $ss1017310174;
}
if(R.isPyretException($e1016910170)) {
$e1016910170.pyretStack.push(L[1910]);
}
throw $e1016910170;
}
var $ret1017510176 = $Hcont_tail_arg1023610186($z1017110172,if_helper510910185);
++R.GAS;
return $ret1017510176;
} else {
var $z1019110192 = D;
var $f1019710198 = function(_) {
return R.isFunction(else_DASH_clause63910199)?else_DASH_clause63910199.app():R.ffi.throwNonFunApp(L[1910],else_DASH_clause63910199,[]);
};
try {
if(--R.GAS > 0) {
$z1019110192 = $f1019710198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1019710198,
"from":L[1910]});
}
} catch($e1018910190) {
if(R.isCont($e1018910190)) {
var $ss1019310194 = {"from":L[1910],
"go":function(cont_tail_arg511410200) {
return $Hcont_tail_arg1023710201(cont_tail_arg511410200,if_helper510910185);
}};
$e1018910190.stack[R.EXN_STACKHEIGHT++] = $ss1019310194;
}
if(R.isPyretException($e1018910190)) {
$e1018910190.pyretStack.push(L[1910]);
}
throw $e1018910190;
}
var $ret1019510196 = $Hcont_tail_arg1023710201($z1019110192,if_helper510910185);
++R.GAS;
return $ret1019510196;
}
} else {
var cont_tail_arg511110205 = R.throwNonBooleanCondition(L[1910],("if"),if_DASH_64110202);
if(--R.GAS > 0) {
$z1020310204 = R.isFunction(if_helper510910185)?if_helper510910185.app(cont_tail_arg511110205):R.ffi.throwNonFunApp(L[1910],if_helper510910185,[cont_tail_arg511110205]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper510910185)?if_helper510910185.app(cont_tail_arg511110205):R.ffi.throwNonFunApp(L[1910],if_helper510910185,[cont_tail_arg511110205]);
},
"from":L[1910]});
}
++R.GAS;
return $z1020310204;
}
};
},{"length":3});
var anf_variant_member514010129 = R.makeMethod(function(self64010167) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1910],0,arguments);
}
var anf_arg512410165 = G(self64010167,"l",L[1910]);
var $z1015710158 = D;
var $f1016310164 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg512410165):R.ffi.throwNonFunApp(L[1910],torepr65,[anf_arg512410165]);
};
try {
if(--R.GAS > 0) {
$z1015710158 = $f1016310164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1016310164,
"from":L[1910]});
}
} catch($e1015510156) {
if(R.isCont($e1015510156)) {
var $ss1015910160 = {"from":L[1910],
"go":function(anf_arg512510166) {
return $Hanf_arg1025010168(anf_arg512510166,self64010167,_plus55,torepr65);
}};
$e1015510156.stack[R.EXN_STACKHEIGHT++] = $ss1015910160;
}
if(R.isPyretException($e1015510156)) {
$e1015510156.pyretStack.push(L[1910]);
}
throw $e1015510156;
}
var $ret1016110162 = $Hanf_arg1025010168($z1015710158,self64010167,_plus55,torepr65);
++R.GAS;
return $ret1016110162;
};
},{"length":1});
var anf_variant_member514210130 = R.makeMethod(function(self113010154) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1923],0,arguments);
}
var ann_DASH_check_DASH_temp514110153 = ("s-cases-branch");
return ann_DASH_check_DASH_temp514110153;
};
},{"length":1});
var anf_variant_member517110131 = R.makeMethod(function(self113110151) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1922],0,arguments);
}
var anf_fun514410148 = G(PP170,"nest",L[1921]);
var anf_fun514510149 = G(PP170,"group",L[1920]);
var anf_fun514610150 = G(PP170,"str",L[1919]);
var anf_arg514710146 = G(self113110151,"name",L[1918]);
var $z1013810139 = D;
var $f1014410145 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("| "),anf_arg514710146):R.ffi.throwNonFunApp(L[1917],_plus55,[("| "),anf_arg514710146]);
};
try {
if(--R.GAS > 0) {
$z1013810139 = $f1014410145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1014410145,
"from":L[1917]});
}
} catch($e1013610137) {
if(R.isCont($e1013610137)) {
var $ss1014010141 = {"from":L[1917],
"go":function(anf_arg514810147) {
return $Hanf_arg1026310152(anf_arg514810147,INDENT118169,PP170,anf_fun514410148,anf_fun514510149,anf_fun514610150,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
}};
$e1013610137.stack[R.EXN_STACKHEIGHT++] = $ss1014010141;
}
if(R.isPyretException($e1013610137)) {
$e1013610137.pyretStack.push(L[1917]);
}
throw $e1013610137;
}
var $ret1014210143 = $Hanf_arg1026310152($z1013810139,INDENT118169,PP170,anf_fun514410148,anf_fun514510149,anf_fun514610150,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
++R.GAS;
return $ret1014210143;
};
},{"length":1});
var anf_assign51722298 = (function() {
var $s_DASH_cases_DASH_branch_DASH_base1012310124 = {"visit":anf_shared510710122,
"_match":anf_variant_member512210128,
"_torepr":anf_variant_member514010129,
"label":anf_variant_member514210130,
"tosource":anf_variant_member517110131};
var $s_DASH_cases_DASH_branch_DASH_brands1012610127 = {"$brand-s-cases-branch10125":true};
$s_DASH_cases_DASH_branch_DASH_brands1012610127[CasesBranchT23111104._brand] = true
return R.makeObject({"CasesBranch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1911],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CasesBranchT23111104._brand));
}),
"is-s-cases-branch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1910],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-s-cases-branch10125"));
}),
"s-cases-branch":R.makeFunction(function(l112610132,name112710133,args112810134,body112910135) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1912],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,Expr86111],[l112610132,name112710133,args112810134,body112910135],[L[1913],L[1914],L[1915],L[1916]],function() {
var dict = R.create($s_DASH_cases_DASH_branch_DASH_base1012310124);
dict["l"] = l112610132
dict["name"] = name112710133
dict["args"] = args112810134
dict["body"] = body112910135
return R.makeBrandedObject(dict,$s_DASH_cases_DASH_branch_DASH_brands1012610127);
});
})});
})();
CasesBranch484982297.$var = anf_assign51722298;
var anf_assign51732300 = G(CasesBranch484982297.$var,"CasesBranch",L[1911]);
CasesBranch4992299.$var = anf_assign51732300;
var anf_assign51742302 = G(CasesBranch484982297.$var,"CasesBranch",L[1911]);
is_DASH_CasesBranch5002301.$var = anf_assign51742302;
var anf_assign51752304 = G(CasesBranch484982297.$var,"is-s-cases-branch",L[1910]);
is_DASH_s_DASH_cases_DASH_branch5012303.$var = anf_assign51752304;
var anf_assign51762306 = G(CasesBranch484982297.$var,"s-cases-branch",L[1910]);
s_DASH_cases_DASH_branch5022305.$var = anf_assign51762306;
var anf_shared51849398 = R.makeMethod(function(self117410121) {
return function(visitor117510104) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1905],1,arguments);
}
var anf_fun517810103 = G(self117410121,"_match",L[1909]);
var anf_arg518310105 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1906],0,arguments);
}
var anf_fun518010118 = G(self117410121,"label",L[1908]);
var $z1011010111 = D;
var $f1011610117 = function(_) {
return R.isFunction(anf_fun518010118)?anf_fun518010118.app():R.ffi.throwNonFunApp(L[1907],anf_fun518010118,[]);
};
try {
if(--R.GAS > 0) {
$z1011010111 = $f1011610117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1011610117,
"from":L[1907]});
}
} catch($e1010810109) {
if(R.isCont($e1010810109)) {
var $ss1011210113 = {"from":L[1907],
"go":function(anf_arg518110119) {
return $Hanf_arg1026610120(anf_arg518110119,_plus55,raise62);
}};
$e1010810109.stack[R.EXN_STACKHEIGHT++] = $ss1011210113;
}
if(R.isPyretException($e1010810109)) {
$e1010810109.pyretStack.push(L[1907]);
}
throw $e1010810109;
}
var $ret1011410115 = $Hanf_arg1026610120($z1011010111,_plus55,raise62);
++R.GAS;
return $ret1011410115;
});
var $z1009510096 = D;
var $f1010110102 = function(_) {
return R.isFunction(anf_fun517810103)?anf_fun517810103.app(visitor117510104,anf_arg518310105):R.ffi.throwNonFunApp(L[1905],anf_fun517810103,[visitor117510104,anf_arg518310105]);
};
try {
if(--R.GAS > 0) {
$z1009510096 = $f1010110102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1010110102,
"from":L[1905]});
}
} catch($e1009310094) {
if(R.isCont($e1009310094)) {
var $ss1009710098 = {"from":L[1905],
"go":function(ann_DASH_check_DASH_temp517710106) {
return $Hann_DASH_check_DASH_temp1026710107(ann_DASH_check_DASH_temp517710106);
}};
$e1009310094.stack[R.EXN_STACKHEIGHT++] = $ss1009710098;
}
if(R.isPyretException($e1009310094)) {
$e1009310094.pyretStack.push(L[1905]);
}
throw $e1009310094;
}
var $ret1009910100 = $Hann_DASH_check_DASH_temp1026710107($z1009510096);
++R.GAS;
return $ret1009910100;
};
},{"length":2});
var anf_singleton_variant_member51959404 = R.makeMethod(function(self64310092) {
return function(cases_DASH_funs64410071,else_DASH_clause64510082) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1813],2,arguments);
}
var if_DASH_64710085 = R.hasField(cases_DASH_funs64410071,("a-blank"));
var if_helper518610069 = R.makeFunction(function(if_helper_arg518710090) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1813],1,arguments);
}
var ann_DASH_check_DASH_temp518510091 = if_helper_arg518710090;
return ann_DASH_check_DASH_temp518510091;
});
var anf_if519010089 = R.isBoolean(if_DASH_64710085);
if(R.isPyretTrue(anf_if519010089)) {
if(R.isPyretTrue(if_DASH_64710085)) {
var call_DASH_a_DASH_blank64210067 = G(cases_DASH_funs64410071,"a-blank",L[1813]);
var $z1005910060 = D;
var $f1006510066 = function(_) {
return R.isFunction(call_DASH_a_DASH_blank64210067)?call_DASH_a_DASH_blank64210067.app():R.ffi.throwNonFunApp(L[1813],call_DASH_a_DASH_blank64210067,[]);
};
try {
if(--R.GAS > 0) {
$z1005910060 = $f1006510066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1006510066,
"from":L[1813]});
}
} catch($e1005710058) {
if(R.isCont($e1005710058)) {
var $ss1006110062 = {"from":L[1813],
"go":function(cont_tail_arg519310068) {
return $Hcont_tail_arg1026810070(cont_tail_arg519310068,if_helper518610069);
}};
$e1005710058.stack[R.EXN_STACKHEIGHT++] = $ss1006110062;
}
if(R.isPyretException($e1005710058)) {
$e1005710058.pyretStack.push(L[1813]);
}
throw $e1005710058;
}
var $ret1006310064 = $Hcont_tail_arg1026810070($z1005910060,if_helper518610069);
++R.GAS;
return $ret1006310064;
} else {
var $z1007410075 = D;
var $f1008010081 = function(_) {
return R.isFunction(else_DASH_clause64510082)?else_DASH_clause64510082.app():R.ffi.throwNonFunApp(L[1813],else_DASH_clause64510082,[]);
};
try {
if(--R.GAS > 0) {
$z1007410075 = $f1008010081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1008010081,
"from":L[1813]});
}
} catch($e1007210073) {
if(R.isCont($e1007210073)) {
var $ss1007610077 = {"from":L[1813],
"go":function(cont_tail_arg519110083) {
return $Hcont_tail_arg1026910084(cont_tail_arg519110083,if_helper518610069);
}};
$e1007210073.stack[R.EXN_STACKHEIGHT++] = $ss1007610077;
}
if(R.isPyretException($e1007210073)) {
$e1007210073.pyretStack.push(L[1813]);
}
throw $e1007210073;
}
var $ret1007810079 = $Hcont_tail_arg1026910084($z1007410075,if_helper518610069);
++R.GAS;
return $ret1007810079;
}
} else {
var cont_tail_arg518810088 = R.throwNonBooleanCondition(L[1813],("if"),if_DASH_64710085);
if(--R.GAS > 0) {
$z1008610087 = R.isFunction(if_helper518610069)?if_helper518610069.app(cont_tail_arg518810088):R.ffi.throwNonFunApp(L[1813],if_helper518610069,[cont_tail_arg518810088]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper518610069)?if_helper518610069.app(cont_tail_arg518810088):R.ffi.throwNonFunApp(L[1813],if_helper518610069,[cont_tail_arg518810088]);
},
"from":L[1813]});
}
++R.GAS;
return $z1008610087;
}
};
},{"length":3});
var anf_singleton_variant_member51979405 = R.makeMethod(function(self64610056) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1813],0,arguments);
}
var ann_DASH_check_DASH_temp519610055 = ("a-blank");
return ann_DASH_check_DASH_temp519610055;
};
},{"length":1});
var anf_singleton_variant_member51999406 = R.makeMethod(function(self113510054) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1904],0,arguments);
}
var ann_DASH_check_DASH_temp519810053 = ("a-blank");
return ann_DASH_check_DASH_temp519810053;
};
},{"length":1});
var anf_singleton_variant_member52019407 = R.makeMethod(function(self113610052) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1903],0,arguments);
}
var ann_DASH_check_DASH_temp520010051 = str_DASH_any120182;
return ann_DASH_check_DASH_temp520010051;
};
},{"length":1});
var anf_singleton_variant_member52129413 = R.makeMethod(function(self64910050) {
return function(cases_DASH_funs65010029,else_DASH_clause65110040) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1812],2,arguments);
}
var if_DASH_65310043 = R.hasField(cases_DASH_funs65010029,("a-any"));
var if_helper520310027 = R.makeFunction(function(if_helper_arg520410048) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1812],1,arguments);
}
var ann_DASH_check_DASH_temp520210049 = if_helper_arg520410048;
return ann_DASH_check_DASH_temp520210049;
});
var anf_if520710047 = R.isBoolean(if_DASH_65310043);
if(R.isPyretTrue(anf_if520710047)) {
if(R.isPyretTrue(if_DASH_65310043)) {
var call_DASH_a_DASH_any64810025 = G(cases_DASH_funs65010029,"a-any",L[1812]);
var $z1001710018 = D;
var $f1002310024 = function(_) {
return R.isFunction(call_DASH_a_DASH_any64810025)?call_DASH_a_DASH_any64810025.app():R.ffi.throwNonFunApp(L[1812],call_DASH_a_DASH_any64810025,[]);
};
try {
if(--R.GAS > 0) {
$z1001710018 = $f1002310024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1002310024,
"from":L[1812]});
}
} catch($e1001510016) {
if(R.isCont($e1001510016)) {
var $ss1001910020 = {"from":L[1812],
"go":function(cont_tail_arg521010026) {
return $Hcont_tail_arg1027010028(cont_tail_arg521010026,if_helper520310027);
}};
$e1001510016.stack[R.EXN_STACKHEIGHT++] = $ss1001910020;
}
if(R.isPyretException($e1001510016)) {
$e1001510016.pyretStack.push(L[1812]);
}
throw $e1001510016;
}
var $ret1002110022 = $Hcont_tail_arg1027010028($z1001710018,if_helper520310027);
++R.GAS;
return $ret1002110022;
} else {
var $z1003210033 = D;
var $f1003810039 = function(_) {
return R.isFunction(else_DASH_clause65110040)?else_DASH_clause65110040.app():R.ffi.throwNonFunApp(L[1812],else_DASH_clause65110040,[]);
};
try {
if(--R.GAS > 0) {
$z1003210033 = $f1003810039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1003810039,
"from":L[1812]});
}
} catch($e1003010031) {
if(R.isCont($e1003010031)) {
var $ss1003410035 = {"from":L[1812],
"go":function(cont_tail_arg520810041) {
return $Hcont_tail_arg1027110042(cont_tail_arg520810041,if_helper520310027);
}};
$e1003010031.stack[R.EXN_STACKHEIGHT++] = $ss1003410035;
}
if(R.isPyretException($e1003010031)) {
$e1003010031.pyretStack.push(L[1812]);
}
throw $e1003010031;
}
var $ret1003610037 = $Hcont_tail_arg1027110042($z1003210033,if_helper520310027);
++R.GAS;
return $ret1003610037;
}
} else {
var cont_tail_arg520510046 = R.throwNonBooleanCondition(L[1812],("if"),if_DASH_65310043);
if(--R.GAS > 0) {
$z1004410045 = R.isFunction(if_helper520310027)?if_helper520310027.app(cont_tail_arg520510046):R.ffi.throwNonFunApp(L[1812],if_helper520310027,[cont_tail_arg520510046]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper520310027)?if_helper520310027.app(cont_tail_arg520510046):R.ffi.throwNonFunApp(L[1812],if_helper520310027,[cont_tail_arg520510046]);
},
"from":L[1812]});
}
++R.GAS;
return $z1004410045;
}
};
},{"length":3});
var anf_singleton_variant_member52149414 = R.makeMethod(function(self65210014) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1812],0,arguments);
}
var ann_DASH_check_DASH_temp521310013 = ("a-any");
return ann_DASH_check_DASH_temp521310013;
};
},{"length":1});
var anf_singleton_variant_member52169415 = R.makeMethod(function(self113710012) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1902],0,arguments);
}
var ann_DASH_check_DASH_temp521510011 = ("a-any");
return ann_DASH_check_DASH_temp521510011;
};
},{"length":1});
var anf_singleton_variant_member52189416 = R.makeMethod(function(self113810010) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1901],0,arguments);
}
var ann_DASH_check_DASH_temp521710009 = str_DASH_any120182;
return ann_DASH_check_DASH_temp521710009;
};
},{"length":1});
var anf_variant_member52319422 = R.makeMethod(function(self6559987) {
return function(cases_DASH_funs6569988,else_DASH_clause6579999) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1811],2,arguments);
}
var if_DASH_65910002 = R.hasField(cases_DASH_funs6569988,("a-name"));
var if_helper52209985 = R.makeFunction(function(if_helper_arg522110007) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1811],1,arguments);
}
var ann_DASH_check_DASH_temp521910008 = if_helper_arg522110007;
return ann_DASH_check_DASH_temp521910008;
});
var anf_if522410006 = R.isBoolean(if_DASH_65910002);
if(R.isPyretTrue(anf_if522410006)) {
if(R.isPyretTrue(if_DASH_65910002)) {
var call_DASH_a_DASH_name6549981 = G(cases_DASH_funs6569988,"a-name",L[1811]);
var anf_arg52279982 = G(self6559987,"l",L[1900]);
var anf_arg52289983 = G(self6559987,"id",L[1899]);
var $z99739974 = D;
var $f99799980 = function(_) {
return R.isFunction(call_DASH_a_DASH_name6549981)?call_DASH_a_DASH_name6549981.app(anf_arg52279982,anf_arg52289983):R.ffi.throwNonFunApp(L[1811],call_DASH_a_DASH_name6549981,[anf_arg52279982,anf_arg52289983]);
};
try {
if(--R.GAS > 0) {
$z99739974 = $f99799980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99799980,
"from":L[1811]});
}
} catch($e99719972) {
if(R.isCont($e99719972)) {
var $ss99759976 = {"from":L[1811],
"go":function(cont_tail_arg52299984) {
return $Hcont_tail_arg102729986(cont_tail_arg52299984,if_helper52209985);
}};
$e99719972.stack[R.EXN_STACKHEIGHT++] = $ss99759976;
}
if(R.isPyretException($e99719972)) {
$e99719972.pyretStack.push(L[1811]);
}
throw $e99719972;
}
var $ret99779978 = $Hcont_tail_arg102729986($z99739974,if_helper52209985);
++R.GAS;
return $ret99779978;
} else {
var $z99919992 = D;
var $f99979998 = function(_) {
return R.isFunction(else_DASH_clause6579999)?else_DASH_clause6579999.app():R.ffi.throwNonFunApp(L[1811],else_DASH_clause6579999,[]);
};
try {
if(--R.GAS > 0) {
$z99919992 = $f99979998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99979998,
"from":L[1811]});
}
} catch($e99899990) {
if(R.isCont($e99899990)) {
var $ss99939994 = {"from":L[1811],
"go":function(cont_tail_arg522510000) {
return $Hcont_tail_arg1027310001(cont_tail_arg522510000,if_helper52209985);
}};
$e99899990.stack[R.EXN_STACKHEIGHT++] = $ss99939994;
}
if(R.isPyretException($e99899990)) {
$e99899990.pyretStack.push(L[1811]);
}
throw $e99899990;
}
var $ret99959996 = $Hcont_tail_arg1027310001($z99919992,if_helper52209985);
++R.GAS;
return $ret99959996;
}
} else {
var cont_tail_arg522210005 = R.throwNonBooleanCondition(L[1811],("if"),if_DASH_65910002);
if(--R.GAS > 0) {
$z1000310004 = R.isFunction(if_helper52209985)?if_helper52209985.app(cont_tail_arg522210005):R.ffi.throwNonFunApp(L[1811],if_helper52209985,[cont_tail_arg522210005]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper52209985)?if_helper52209985.app(cont_tail_arg522210005):R.ffi.throwNonFunApp(L[1811],if_helper52209985,[cont_tail_arg522210005]);
},
"from":L[1811]});
}
++R.GAS;
return $z1000310004;
}
};
},{"length":3});
var anf_variant_member52419423 = R.makeMethod(function(self6589969) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1811],0,arguments);
}
var anf_arg52339967 = G(self6589969,"l",L[1811]);
var $z99599960 = D;
var $f99659966 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg52339967):R.ffi.throwNonFunApp(L[1811],torepr65,[anf_arg52339967]);
};
try {
if(--R.GAS > 0) {
$z99599960 = $f99659966();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99659966,
"from":L[1811]});
}
} catch($e99579958) {
if(R.isCont($e99579958)) {
var $ss99619962 = {"from":L[1811],
"go":function(anf_arg52349968) {
return $Hanf_arg102809970(anf_arg52349968,self6589969,_plus55,torepr65);
}};
$e99579958.stack[R.EXN_STACKHEIGHT++] = $ss99619962;
}
if(R.isPyretException($e99579958)) {
$e99579958.pyretStack.push(L[1811]);
}
throw $e99579958;
}
var $ret99639964 = $Hanf_arg102809970($z99599960,self6589969,_plus55,torepr65);
++R.GAS;
return $ret99639964;
};
},{"length":1});
var anf_variant_member52439424 = R.makeMethod(function(self11419956) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1898],0,arguments);
}
var ann_DASH_check_DASH_temp52429955 = ("a-name");
return ann_DASH_check_DASH_temp52429955;
};
},{"length":1});
var anf_variant_member52479425 = R.makeMethod(function(self11429954) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1895],0,arguments);
}
var anf_bracket52459953 = G(self11429954,"id",L[1897]);
var anf_fun52469950 = G(anf_bracket52459953,"tosource",L[1896]);
var $z99429943 = D;
var $f99489949 = function(_) {
return R.isFunction(anf_fun52469950)?anf_fun52469950.app():R.ffi.throwNonFunApp(L[1895],anf_fun52469950,[]);
};
try {
if(--R.GAS > 0) {
$z99429943 = $f99489949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99489949,
"from":L[1895]});
}
} catch($e99409941) {
if(R.isCont($e99409941)) {
var $ss99449945 = {"from":L[1895],
"go":function(ann_DASH_check_DASH_temp52449951) {
return $Hann_DASH_check_DASH_temp102819952(ann_DASH_check_DASH_temp52449951);
}};
$e99409941.stack[R.EXN_STACKHEIGHT++] = $ss99449945;
}
if(R.isPyretException($e99409941)) {
$e99409941.pyretStack.push(L[1895]);
}
throw $e99409941;
}
var $ret99469947 = $Hann_DASH_check_DASH_temp102819952($z99429943);
++R.GAS;
return $ret99469947;
};
},{"length":1});
var anf_variant_member52629433 = R.makeMethod(function(self6619918) {
return function(cases_DASH_funs6629919,else_DASH_clause6639930) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1810],2,arguments);
}
var if_DASH_6659933 = R.hasField(cases_DASH_funs6629919,("a-arrow"));
var if_helper52499916 = R.makeFunction(function(if_helper_arg52509938) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1810],1,arguments);
}
var ann_DASH_check_DASH_temp52489939 = if_helper_arg52509938;
return ann_DASH_check_DASH_temp52489939;
});
var anf_if52539937 = R.isBoolean(if_DASH_6659933);
if(R.isPyretTrue(anf_if52539937)) {
if(R.isPyretTrue(if_DASH_6659933)) {
var call_DASH_a_DASH_arrow6609910 = G(cases_DASH_funs6629919,"a-arrow",L[1810]);
var anf_arg52569911 = G(self6619918,"l",L[1894]);
var anf_arg52579912 = G(self6619918,"args",L[1893]);
var anf_arg52589913 = G(self6619918,"ret",L[1892]);
var anf_arg52599914 = G(self6619918,"use-parens",L[1891]);
var $z99029903 = D;
var $f99089909 = function(_) {
return R.isFunction(call_DASH_a_DASH_arrow6609910)?call_DASH_a_DASH_arrow6609910.app(anf_arg52569911,anf_arg52579912,anf_arg52589913,anf_arg52599914):R.ffi.throwNonFunApp(L[1810],call_DASH_a_DASH_arrow6609910,[anf_arg52569911,anf_arg52579912,anf_arg52589913,anf_arg52599914]);
};
try {
if(--R.GAS > 0) {
$z99029903 = $f99089909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99089909,
"from":L[1810]});
}
} catch($e99009901) {
if(R.isCont($e99009901)) {
var $ss99049905 = {"from":L[1810],
"go":function(cont_tail_arg52609915) {
return $Hcont_tail_arg102829917(cont_tail_arg52609915,if_helper52499916);
}};
$e99009901.stack[R.EXN_STACKHEIGHT++] = $ss99049905;
}
if(R.isPyretException($e99009901)) {
$e99009901.pyretStack.push(L[1810]);
}
throw $e99009901;
}
var $ret99069907 = $Hcont_tail_arg102829917($z99029903,if_helper52499916);
++R.GAS;
return $ret99069907;
} else {
var $z99229923 = D;
var $f99289929 = function(_) {
return R.isFunction(else_DASH_clause6639930)?else_DASH_clause6639930.app():R.ffi.throwNonFunApp(L[1810],else_DASH_clause6639930,[]);
};
try {
if(--R.GAS > 0) {
$z99229923 = $f99289929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99289929,
"from":L[1810]});
}
} catch($e99209921) {
if(R.isCont($e99209921)) {
var $ss99249925 = {"from":L[1810],
"go":function(cont_tail_arg52549931) {
return $Hcont_tail_arg102839932(cont_tail_arg52549931,if_helper52499916);
}};
$e99209921.stack[R.EXN_STACKHEIGHT++] = $ss99249925;
}
if(R.isPyretException($e99209921)) {
$e99209921.pyretStack.push(L[1810]);
}
throw $e99209921;
}
var $ret99269927 = $Hcont_tail_arg102839932($z99229923,if_helper52499916);
++R.GAS;
return $ret99269927;
}
} else {
var cont_tail_arg52519936 = R.throwNonBooleanCondition(L[1810],("if"),if_DASH_6659933);
if(--R.GAS > 0) {
$z99349935 = R.isFunction(if_helper52499916)?if_helper52499916.app(cont_tail_arg52519936):R.ffi.throwNonFunApp(L[1810],if_helper52499916,[cont_tail_arg52519936]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper52499916)?if_helper52499916.app(cont_tail_arg52519936):R.ffi.throwNonFunApp(L[1810],if_helper52499916,[cont_tail_arg52519936]);
},
"from":L[1810]});
}
++R.GAS;
return $z99349935;
}
};
},{"length":3});
var anf_variant_member52809434 = R.makeMethod(function(self6649898) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1810],0,arguments);
}
var anf_arg52649896 = G(self6649898,"l",L[1810]);
var $z98889889 = D;
var $f98949895 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg52649896):R.ffi.throwNonFunApp(L[1810],torepr65,[anf_arg52649896]);
};
try {
if(--R.GAS > 0) {
$z98889889 = $f98949895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98949895,
"from":L[1810]});
}
} catch($e98869887) {
if(R.isCont($e98869887)) {
var $ss98909891 = {"from":L[1810],
"go":function(anf_arg52659897) {
return $Hanf_arg102969899(anf_arg52659897,self6649898,_plus55,torepr65);
}};
$e98869887.stack[R.EXN_STACKHEIGHT++] = $ss98909891;
}
if(R.isPyretException($e98869887)) {
$e98869887.pyretStack.push(L[1810]);
}
throw $e98869887;
}
var $ret98929893 = $Hanf_arg102969899($z98889889,self6649898,_plus55,torepr65);
++R.GAS;
return $ret98929893;
};
},{"length":1});
var anf_variant_member52829435 = R.makeMethod(function(self11479885) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1890],0,arguments);
}
var ann_DASH_check_DASH_temp52819884 = ("a-arrow");
return ann_DASH_check_DASH_temp52819884;
};
},{"length":1});
var anf_variant_member53139436 = R.makeMethod(function(self11489867) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1889],0,arguments);
}
var anf_fun52849864 = G(PP170,"separate",L[1888]);
var anf_fun52859865 = G(list25154,"make",L[1887]);
var anf_fun52869866 = G(PP170,"separate",L[1886]);
var anf_arg52879863 = G(PP170,"commabreak",L[1885]);
var anf_bracket52889883 = G(self11489867,"args",L[1884]);
var anf_fun52899860 = G(anf_bracket52889883,"map",L[1883]);
var anf_arg52929861 = R.makeFunction(function(recv_DASH_6669869) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1882],1,arguments);
}
var anf_fun52919880 = G(recv_DASH_6669869,"tosource",L[1882]);
var $z98729873 = D;
var $f98789879 = function(_) {
return R.isFunction(anf_fun52919880)?anf_fun52919880.app():R.ffi.throwNonFunApp(L[1882],anf_fun52919880,[]);
};
try {
if(--R.GAS > 0) {
$z98729873 = $f98789879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98789879,
"from":L[1882]});
}
} catch($e98709871) {
if(R.isCont($e98709871)) {
var $ss98749875 = {"from":L[1882],
"go":function(ann_DASH_check_DASH_temp52909881) {
return $Hann_DASH_check_DASH_temp102979882(ann_DASH_check_DASH_temp52909881);
}};
$e98709871.stack[R.EXN_STACKHEIGHT++] = $ss98749875;
}
if(R.isPyretException($e98709871)) {
$e98709871.pyretStack.push(L[1882]);
}
throw $e98709871;
}
var $ret98769877 = $Hann_DASH_check_DASH_temp102979882($z98729873);
++R.GAS;
return $ret98769877;
});
var $z98529853 = D;
var $f98589859 = function(_) {
return R.isFunction(anf_fun52899860)?anf_fun52899860.app(anf_arg52929861):R.ffi.throwNonFunApp(L[1881],anf_fun52899860,[anf_arg52929861]);
};
try {
if(--R.GAS > 0) {
$z98529853 = $f98589859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98589859,
"from":L[1881]});
}
} catch($e98509851) {
if(R.isCont($e98509851)) {
var $ss98549855 = {"from":L[1881],
"go":function(anf_arg52939862) {
return $Hanf_arg103069868(anf_arg52939862,INDENT118169,PP170,anf_arg52879863,anf_fun52849864,anf_fun52859865,anf_fun52869866,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55);
}};
$e98509851.stack[R.EXN_STACKHEIGHT++] = $ss98549855;
}
if(R.isPyretException($e98509851)) {
$e98509851.pyretStack.push(L[1881]);
}
throw $e98509851;
}
var $ret98569857 = $Hanf_arg103069868($z98529853,INDENT118169,PP170,anf_arg52879863,anf_fun52849864,anf_fun52859865,anf_fun52869866,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55);
++R.GAS;
return $ret98569857;
};
},{"length":1});
var anf_variant_member53279446 = R.makeMethod(function(self6699828) {
return function(cases_DASH_funs6709829,else_DASH_clause6719840) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1809],2,arguments);
}
var if_DASH_6739843 = R.hasField(cases_DASH_funs6709829,("a-method"));
var if_helper53159826 = R.makeFunction(function(if_helper_arg53169848) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1809],1,arguments);
}
var ann_DASH_check_DASH_temp53149849 = if_helper_arg53169848;
return ann_DASH_check_DASH_temp53149849;
});
var anf_if53199847 = R.isBoolean(if_DASH_6739843);
if(R.isPyretTrue(anf_if53199847)) {
if(R.isPyretTrue(if_DASH_6739843)) {
var call_DASH_a_DASH_method6689821 = G(cases_DASH_funs6709829,"a-method",L[1809]);
var anf_arg53229822 = G(self6699828,"l",L[1880]);
var anf_arg53239823 = G(self6699828,"args",L[1879]);
var anf_arg53249824 = G(self6699828,"ret",L[1878]);
var $z98139814 = D;
var $f98199820 = function(_) {
return R.isFunction(call_DASH_a_DASH_method6689821)?call_DASH_a_DASH_method6689821.app(anf_arg53229822,anf_arg53239823,anf_arg53249824):R.ffi.throwNonFunApp(L[1809],call_DASH_a_DASH_method6689821,[anf_arg53229822,anf_arg53239823,anf_arg53249824]);
};
try {
if(--R.GAS > 0) {
$z98139814 = $f98199820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98199820,
"from":L[1809]});
}
} catch($e98119812) {
if(R.isCont($e98119812)) {
var $ss98159816 = {"from":L[1809],
"go":function(cont_tail_arg53259825) {
return $Hcont_tail_arg103079827(cont_tail_arg53259825,if_helper53159826);
}};
$e98119812.stack[R.EXN_STACKHEIGHT++] = $ss98159816;
}
if(R.isPyretException($e98119812)) {
$e98119812.pyretStack.push(L[1809]);
}
throw $e98119812;
}
var $ret98179818 = $Hcont_tail_arg103079827($z98139814,if_helper53159826);
++R.GAS;
return $ret98179818;
} else {
var $z98329833 = D;
var $f98389839 = function(_) {
return R.isFunction(else_DASH_clause6719840)?else_DASH_clause6719840.app():R.ffi.throwNonFunApp(L[1809],else_DASH_clause6719840,[]);
};
try {
if(--R.GAS > 0) {
$z98329833 = $f98389839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98389839,
"from":L[1809]});
}
} catch($e98309831) {
if(R.isCont($e98309831)) {
var $ss98349835 = {"from":L[1809],
"go":function(cont_tail_arg53209841) {
return $Hcont_tail_arg103089842(cont_tail_arg53209841,if_helper53159826);
}};
$e98309831.stack[R.EXN_STACKHEIGHT++] = $ss98349835;
}
if(R.isPyretException($e98309831)) {
$e98309831.pyretStack.push(L[1809]);
}
throw $e98309831;
}
var $ret98369837 = $Hcont_tail_arg103089842($z98329833,if_helper53159826);
++R.GAS;
return $ret98369837;
}
} else {
var cont_tail_arg53179846 = R.throwNonBooleanCondition(L[1809],("if"),if_DASH_6739843);
if(--R.GAS > 0) {
$z98449845 = R.isFunction(if_helper53159826)?if_helper53159826.app(cont_tail_arg53179846):R.ffi.throwNonFunApp(L[1809],if_helper53159826,[cont_tail_arg53179846]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53159826)?if_helper53159826.app(cont_tail_arg53179846):R.ffi.throwNonFunApp(L[1809],if_helper53159826,[cont_tail_arg53179846]);
},
"from":L[1809]});
}
++R.GAS;
return $z98449845;
}
};
},{"length":3});
var anf_variant_member53419447 = R.makeMethod(function(self6729809) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1809],0,arguments);
}
var anf_arg53299807 = G(self6729809,"l",L[1809]);
var $z97999800 = D;
var $f98059806 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg53299807):R.ffi.throwNonFunApp(L[1809],torepr65,[anf_arg53299807]);
};
try {
if(--R.GAS > 0) {
$z97999800 = $f98059806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98059806,
"from":L[1809]});
}
} catch($e97979798) {
if(R.isCont($e97979798)) {
var $ss98019802 = {"from":L[1809],
"go":function(anf_arg53309808) {
return $Hanf_arg103189810(anf_arg53309808,self6729809,_plus55,torepr65);
}};
$e97979798.stack[R.EXN_STACKHEIGHT++] = $ss98019802;
}
if(R.isPyretException($e97979798)) {
$e97979798.pyretStack.push(L[1809]);
}
throw $e97979798;
}
var $ret98039804 = $Hanf_arg103189810($z97999800,self6729809,_plus55,torepr65);
++R.GAS;
return $ret98039804;
};
},{"length":1});
var anf_variant_member53439448 = R.makeMethod(function(self11539796) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1877],0,arguments);
}
var ann_DASH_check_DASH_temp53429795 = ("a-method");
return ann_DASH_check_DASH_temp53429795;
};
},{"length":1});
var anf_variant_member53469449 = R.makeMethod(function(self11549794) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1875],0,arguments);
}
var anf_fun53459791 = G(PP170,"str",L[1876]);
var $z97839784 = D;
var $f97899790 = function(_) {
return R.isFunction(anf_fun53459791)?anf_fun53459791.app(("NYI: A-method")):R.ffi.throwNonFunApp(L[1875],anf_fun53459791,[("NYI: A-method")]);
};
try {
if(--R.GAS > 0) {
$z97839784 = $f97899790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97899790,
"from":L[1875]});
}
} catch($e97819782) {
if(R.isCont($e97819782)) {
var $ss97859786 = {"from":L[1875],
"go":function(ann_DASH_check_DASH_temp53449792) {
return $Hann_DASH_check_DASH_temp103199793(ann_DASH_check_DASH_temp53449792);
}};
$e97819782.stack[R.EXN_STACKHEIGHT++] = $ss97859786;
}
if(R.isPyretException($e97819782)) {
$e97819782.pyretStack.push(L[1875]);
}
throw $e97819782;
}
var $ret97879788 = $Hann_DASH_check_DASH_temp103199793($z97839784);
++R.GAS;
return $ret97879788;
};
},{"length":1});
var anf_variant_member53599458 = R.makeMethod(function(self6759759) {
return function(cases_DASH_funs6769760,else_DASH_clause6779771) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1808],2,arguments);
}
var if_DASH_6799774 = R.hasField(cases_DASH_funs6769760,("a-record"));
var if_helper53489757 = R.makeFunction(function(if_helper_arg53499779) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1808],1,arguments);
}
var ann_DASH_check_DASH_temp53479780 = if_helper_arg53499779;
return ann_DASH_check_DASH_temp53479780;
});
var anf_if53529778 = R.isBoolean(if_DASH_6799774);
if(R.isPyretTrue(anf_if53529778)) {
if(R.isPyretTrue(if_DASH_6799774)) {
var call_DASH_a_DASH_record6749753 = G(cases_DASH_funs6769760,"a-record",L[1808]);
var anf_arg53559754 = G(self6759759,"l",L[1874]);
var anf_arg53569755 = G(self6759759,"fields",L[1873]);
var $z97459746 = D;
var $f97519752 = function(_) {
return R.isFunction(call_DASH_a_DASH_record6749753)?call_DASH_a_DASH_record6749753.app(anf_arg53559754,anf_arg53569755):R.ffi.throwNonFunApp(L[1808],call_DASH_a_DASH_record6749753,[anf_arg53559754,anf_arg53569755]);
};
try {
if(--R.GAS > 0) {
$z97459746 = $f97519752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97519752,
"from":L[1808]});
}
} catch($e97439744) {
if(R.isCont($e97439744)) {
var $ss97479748 = {"from":L[1808],
"go":function(cont_tail_arg53579756) {
return $Hcont_tail_arg103209758(cont_tail_arg53579756,if_helper53489757);
}};
$e97439744.stack[R.EXN_STACKHEIGHT++] = $ss97479748;
}
if(R.isPyretException($e97439744)) {
$e97439744.pyretStack.push(L[1808]);
}
throw $e97439744;
}
var $ret97499750 = $Hcont_tail_arg103209758($z97459746,if_helper53489757);
++R.GAS;
return $ret97499750;
} else {
var $z97639764 = D;
var $f97699770 = function(_) {
return R.isFunction(else_DASH_clause6779771)?else_DASH_clause6779771.app():R.ffi.throwNonFunApp(L[1808],else_DASH_clause6779771,[]);
};
try {
if(--R.GAS > 0) {
$z97639764 = $f97699770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97699770,
"from":L[1808]});
}
} catch($e97619762) {
if(R.isCont($e97619762)) {
var $ss97659766 = {"from":L[1808],
"go":function(cont_tail_arg53539772) {
return $Hcont_tail_arg103219773(cont_tail_arg53539772,if_helper53489757);
}};
$e97619762.stack[R.EXN_STACKHEIGHT++] = $ss97659766;
}
if(R.isPyretException($e97619762)) {
$e97619762.pyretStack.push(L[1808]);
}
throw $e97619762;
}
var $ret97679768 = $Hcont_tail_arg103219773($z97639764,if_helper53489757);
++R.GAS;
return $ret97679768;
}
} else {
var cont_tail_arg53509777 = R.throwNonBooleanCondition(L[1808],("if"),if_DASH_6799774);
if(--R.GAS > 0) {
$z97759776 = R.isFunction(if_helper53489757)?if_helper53489757.app(cont_tail_arg53509777):R.ffi.throwNonFunApp(L[1808],if_helper53489757,[cont_tail_arg53509777]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53489757)?if_helper53489757.app(cont_tail_arg53509777):R.ffi.throwNonFunApp(L[1808],if_helper53489757,[cont_tail_arg53509777]);
},
"from":L[1808]});
}
++R.GAS;
return $z97759776;
}
};
},{"length":3});
var anf_variant_member53699459 = R.makeMethod(function(self6789741) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1808],0,arguments);
}
var anf_arg53619739 = G(self6789741,"l",L[1808]);
var $z97319732 = D;
var $f97379738 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg53619739):R.ffi.throwNonFunApp(L[1808],torepr65,[anf_arg53619739]);
};
try {
if(--R.GAS > 0) {
$z97319732 = $f97379738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97379738,
"from":L[1808]});
}
} catch($e97299730) {
if(R.isCont($e97299730)) {
var $ss97339734 = {"from":L[1808],
"go":function(anf_arg53629740) {
return $Hanf_arg103289742(anf_arg53629740,self6789741,_plus55,torepr65);
}};
$e97299730.stack[R.EXN_STACKHEIGHT++] = $ss97339734;
}
if(R.isPyretException($e97299730)) {
$e97299730.pyretStack.push(L[1808]);
}
throw $e97299730;
}
var $ret97359736 = $Hanf_arg103289742($z97319732,self6789741,_plus55,torepr65);
++R.GAS;
return $ret97359736;
};
},{"length":1});
var anf_variant_member53719460 = R.makeMethod(function(self11579728) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1872],0,arguments);
}
var ann_DASH_check_DASH_temp53709727 = ("a-record");
return ann_DASH_check_DASH_temp53709727;
};
},{"length":1});
var anf_variant_member53869461 = R.makeMethod(function(self11589725) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1871],0,arguments);
}
var anf_fun53739724 = G(PP170,"surround-separate",L[1870]);
var anf_arg53749721 = G(PP170,"lbrace",L[1869]);
var anf_arg53759722 = G(PP170,"rbrace",L[1868]);
var $z97139714 = D;
var $f97199720 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg53749721,anf_arg53759722):R.ffi.throwNonFunApp(L[1867],_plus55,[anf_arg53749721,anf_arg53759722]);
};
try {
if(--R.GAS > 0) {
$z97139714 = $f97199720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97199720,
"from":L[1867]});
}
} catch($e97119712) {
if(R.isCont($e97119712)) {
var $ss97159716 = {"from":L[1867],
"go":function(anf_arg53769723) {
return $Hanf_arg103329726(anf_arg53769723,INDENT118169,PP170,anf_fun53739724,self11589725);
}};
$e97119712.stack[R.EXN_STACKHEIGHT++] = $ss97159716;
}
if(R.isPyretException($e97119712)) {
$e97119712.pyretStack.push(L[1867]);
}
throw $e97119712;
}
var $ret97179718 = $Hanf_arg103329726($z97139714,INDENT118169,PP170,anf_fun53739724,self11589725);
++R.GAS;
return $ret97179718;
};
},{"length":1});
var anf_variant_member54009469 = R.makeMethod(function(self6829689) {
return function(cases_DASH_funs6839690,else_DASH_clause6849701) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1807],2,arguments);
}
var if_DASH_6869704 = R.hasField(cases_DASH_funs6839690,("a-app"));
var if_helper53889687 = R.makeFunction(function(if_helper_arg53899709) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1807],1,arguments);
}
var ann_DASH_check_DASH_temp53879710 = if_helper_arg53899709;
return ann_DASH_check_DASH_temp53879710;
});
var anf_if53929708 = R.isBoolean(if_DASH_6869704);
if(R.isPyretTrue(anf_if53929708)) {
if(R.isPyretTrue(if_DASH_6869704)) {
var call_DASH_a_DASH_app6819682 = G(cases_DASH_funs6839690,"a-app",L[1807]);
var anf_arg53959683 = G(self6829689,"l",L[1866]);
var anf_arg53969684 = G(self6829689,"ann",L[1865]);
var anf_arg53979685 = G(self6829689,"args",L[1864]);
var $z96749675 = D;
var $f96809681 = function(_) {
return R.isFunction(call_DASH_a_DASH_app6819682)?call_DASH_a_DASH_app6819682.app(anf_arg53959683,anf_arg53969684,anf_arg53979685):R.ffi.throwNonFunApp(L[1807],call_DASH_a_DASH_app6819682,[anf_arg53959683,anf_arg53969684,anf_arg53979685]);
};
try {
if(--R.GAS > 0) {
$z96749675 = $f96809681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96809681,
"from":L[1807]});
}
} catch($e96729673) {
if(R.isCont($e96729673)) {
var $ss96769677 = {"from":L[1807],
"go":function(cont_tail_arg53989686) {
return $Hcont_tail_arg103339688(cont_tail_arg53989686,if_helper53889687);
}};
$e96729673.stack[R.EXN_STACKHEIGHT++] = $ss96769677;
}
if(R.isPyretException($e96729673)) {
$e96729673.pyretStack.push(L[1807]);
}
throw $e96729673;
}
var $ret96789679 = $Hcont_tail_arg103339688($z96749675,if_helper53889687);
++R.GAS;
return $ret96789679;
} else {
var $z96939694 = D;
var $f96999700 = function(_) {
return R.isFunction(else_DASH_clause6849701)?else_DASH_clause6849701.app():R.ffi.throwNonFunApp(L[1807],else_DASH_clause6849701,[]);
};
try {
if(--R.GAS > 0) {
$z96939694 = $f96999700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96999700,
"from":L[1807]});
}
} catch($e96919692) {
if(R.isCont($e96919692)) {
var $ss96959696 = {"from":L[1807],
"go":function(cont_tail_arg53939702) {
return $Hcont_tail_arg103349703(cont_tail_arg53939702,if_helper53889687);
}};
$e96919692.stack[R.EXN_STACKHEIGHT++] = $ss96959696;
}
if(R.isPyretException($e96919692)) {
$e96919692.pyretStack.push(L[1807]);
}
throw $e96919692;
}
var $ret96979698 = $Hcont_tail_arg103349703($z96939694,if_helper53889687);
++R.GAS;
return $ret96979698;
}
} else {
var cont_tail_arg53909707 = R.throwNonBooleanCondition(L[1807],("if"),if_DASH_6869704);
if(--R.GAS > 0) {
$z97059706 = R.isFunction(if_helper53889687)?if_helper53889687.app(cont_tail_arg53909707):R.ffi.throwNonFunApp(L[1807],if_helper53889687,[cont_tail_arg53909707]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53889687)?if_helper53889687.app(cont_tail_arg53909707):R.ffi.throwNonFunApp(L[1807],if_helper53889687,[cont_tail_arg53909707]);
},
"from":L[1807]});
}
++R.GAS;
return $z97059706;
}
};
},{"length":3});
var anf_variant_member54149470 = R.makeMethod(function(self6859670) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1807],0,arguments);
}
var anf_arg54029668 = G(self6859670,"l",L[1807]);
var $z96609661 = D;
var $f96669667 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg54029668):R.ffi.throwNonFunApp(L[1807],torepr65,[anf_arg54029668]);
};
try {
if(--R.GAS > 0) {
$z96609661 = $f96669667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96669667,
"from":L[1807]});
}
} catch($e96589659) {
if(R.isCont($e96589659)) {
var $ss96629663 = {"from":L[1807],
"go":function(anf_arg54039669) {
return $Hanf_arg103449671(anf_arg54039669,self6859670,_plus55,torepr65);
}};
$e96589659.stack[R.EXN_STACKHEIGHT++] = $ss96629663;
}
if(R.isPyretException($e96589659)) {
$e96589659.pyretStack.push(L[1807]);
}
throw $e96589659;
}
var $ret96649665 = $Hanf_arg103449671($z96609661,self6859670,_plus55,torepr65);
++R.GAS;
return $ret96649665;
};
},{"length":1});
var anf_variant_member54169471 = R.makeMethod(function(self11629657) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1863],0,arguments);
}
var ann_DASH_check_DASH_temp54159656 = ("a-app");
return ann_DASH_check_DASH_temp54159656;
};
},{"length":1});
var anf_variant_member54409472 = R.makeMethod(function(self11639653) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1862],0,arguments);
}
var anf_fun54189652 = G(PP170,"group",L[1861]);
var anf_bracket54199655 = G(self11639653,"ann",L[1860]);
var anf_fun54209650 = G(anf_bracket54199655,"tosource",L[1859]);
var $z96429643 = D;
var $f96489649 = function(_) {
return R.isFunction(anf_fun54209650)?anf_fun54209650.app():R.ffi.throwNonFunApp(L[1858],anf_fun54209650,[]);
};
try {
if(--R.GAS > 0) {
$z96429643 = $f96489649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96489649,
"from":L[1858]});
}
} catch($e96409641) {
if(R.isCont($e96409641)) {
var $ss96449645 = {"from":L[1858],
"go":function(anf_arg54219651) {
return $Hanf_arg103549654(anf_arg54219651,INDENT118169,PP170,anf_fun54189652,self11639653,_plus55);
}};
$e96409641.stack[R.EXN_STACKHEIGHT++] = $ss96449645;
}
if(R.isPyretException($e96409641)) {
$e96409641.pyretStack.push(L[1858]);
}
throw $e96409641;
}
var $ret96469647 = $Hanf_arg103549654($z96429643,INDENT118169,PP170,anf_fun54189652,self11639653,_plus55);
++R.GAS;
return $ret96469647;
};
},{"length":1});
var anf_variant_member54549481 = R.makeMethod(function(self6899618) {
return function(cases_DASH_funs6909619,else_DASH_clause6919630) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1806],2,arguments);
}
var if_DASH_6939633 = R.hasField(cases_DASH_funs6909619,("a-pred"));
var if_helper54429616 = R.makeFunction(function(if_helper_arg54439638) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1806],1,arguments);
}
var ann_DASH_check_DASH_temp54419639 = if_helper_arg54439638;
return ann_DASH_check_DASH_temp54419639;
});
var anf_if54469637 = R.isBoolean(if_DASH_6939633);
if(R.isPyretTrue(anf_if54469637)) {
if(R.isPyretTrue(if_DASH_6939633)) {
var call_DASH_a_DASH_pred6889611 = G(cases_DASH_funs6909619,"a-pred",L[1806]);
var anf_arg54499612 = G(self6899618,"l",L[1857]);
var anf_arg54509613 = G(self6899618,"ann",L[1856]);
var anf_arg54519614 = G(self6899618,"exp",L[1855]);
var $z96039604 = D;
var $f96099610 = function(_) {
return R.isFunction(call_DASH_a_DASH_pred6889611)?call_DASH_a_DASH_pred6889611.app(anf_arg54499612,anf_arg54509613,anf_arg54519614):R.ffi.throwNonFunApp(L[1806],call_DASH_a_DASH_pred6889611,[anf_arg54499612,anf_arg54509613,anf_arg54519614]);
};
try {
if(--R.GAS > 0) {
$z96039604 = $f96099610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96099610,
"from":L[1806]});
}
} catch($e96019602) {
if(R.isCont($e96019602)) {
var $ss96059606 = {"from":L[1806],
"go":function(cont_tail_arg54529615) {
return $Hcont_tail_arg103559617(cont_tail_arg54529615,if_helper54429616);
}};
$e96019602.stack[R.EXN_STACKHEIGHT++] = $ss96059606;
}
if(R.isPyretException($e96019602)) {
$e96019602.pyretStack.push(L[1806]);
}
throw $e96019602;
}
var $ret96079608 = $Hcont_tail_arg103559617($z96039604,if_helper54429616);
++R.GAS;
return $ret96079608;
} else {
var $z96229623 = D;
var $f96289629 = function(_) {
return R.isFunction(else_DASH_clause6919630)?else_DASH_clause6919630.app():R.ffi.throwNonFunApp(L[1806],else_DASH_clause6919630,[]);
};
try {
if(--R.GAS > 0) {
$z96229623 = $f96289629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96289629,
"from":L[1806]});
}
} catch($e96209621) {
if(R.isCont($e96209621)) {
var $ss96249625 = {"from":L[1806],
"go":function(cont_tail_arg54479631) {
return $Hcont_tail_arg103569632(cont_tail_arg54479631,if_helper54429616);
}};
$e96209621.stack[R.EXN_STACKHEIGHT++] = $ss96249625;
}
if(R.isPyretException($e96209621)) {
$e96209621.pyretStack.push(L[1806]);
}
throw $e96209621;
}
var $ret96269627 = $Hcont_tail_arg103569632($z96229623,if_helper54429616);
++R.GAS;
return $ret96269627;
}
} else {
var cont_tail_arg54449636 = R.throwNonBooleanCondition(L[1806],("if"),if_DASH_6939633);
if(--R.GAS > 0) {
$z96349635 = R.isFunction(if_helper54429616)?if_helper54429616.app(cont_tail_arg54449636):R.ffi.throwNonFunApp(L[1806],if_helper54429616,[cont_tail_arg54449636]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper54429616)?if_helper54429616.app(cont_tail_arg54449636):R.ffi.throwNonFunApp(L[1806],if_helper54429616,[cont_tail_arg54449636]);
},
"from":L[1806]});
}
++R.GAS;
return $z96349635;
}
};
},{"length":3});
var anf_variant_member54689482 = R.makeMethod(function(self6929599) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1806],0,arguments);
}
var anf_arg54569597 = G(self6929599,"l",L[1806]);
var $z95899590 = D;
var $f95959596 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg54569597):R.ffi.throwNonFunApp(L[1806],torepr65,[anf_arg54569597]);
};
try {
if(--R.GAS > 0) {
$z95899590 = $f95959596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95959596,
"from":L[1806]});
}
} catch($e95879588) {
if(R.isCont($e95879588)) {
var $ss95919592 = {"from":L[1806],
"go":function(anf_arg54579598) {
return $Hanf_arg103669600(anf_arg54579598,self6929599,_plus55,torepr65);
}};
$e95879588.stack[R.EXN_STACKHEIGHT++] = $ss95919592;
}
if(R.isPyretException($e95879588)) {
$e95879588.pyretStack.push(L[1806]);
}
throw $e95879588;
}
var $ret95939594 = $Hanf_arg103669600($z95899590,self6929599,_plus55,torepr65);
++R.GAS;
return $ret95939594;
};
},{"length":1});
var anf_variant_member54709483 = R.makeMethod(function(self11679586) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1854],0,arguments);
}
var ann_DASH_check_DASH_temp54699585 = ("a-pred");
return ann_DASH_check_DASH_temp54699585;
};
},{"length":1});
var anf_variant_member54809484 = R.makeMethod(function(self11689582) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1853],0,arguments);
}
var anf_bracket54729584 = G(self11689582,"ann",L[1852]);
var anf_fun54739580 = G(anf_bracket54729584,"tosource",L[1851]);
var $z95729573 = D;
var $f95789579 = function(_) {
return R.isFunction(anf_fun54739580)?anf_fun54739580.app():R.ffi.throwNonFunApp(L[1850],anf_fun54739580,[]);
};
try {
if(--R.GAS > 0) {
$z95729573 = $f95789579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95789579,
"from":L[1850]});
}
} catch($e95709571) {
if(R.isCont($e95709571)) {
var $ss95749575 = {"from":L[1850],
"go":function(anf_arg54749581) {
return $Hanf_arg103709583(anf_arg54749581,PP170,self11689582,_plus55);
}};
$e95709571.stack[R.EXN_STACKHEIGHT++] = $ss95749575;
}
if(R.isPyretException($e95709571)) {
$e95709571.pyretStack.push(L[1850]);
}
throw $e95709571;
}
var $ret95769577 = $Hanf_arg103709583($z95729573,PP170,self11689582,_plus55);
++R.GAS;
return $ret95769577;
};
},{"length":1});
var anf_variant_member54949493 = R.makeMethod(function(self6959548) {
return function(cases_DASH_funs6969549,else_DASH_clause6979560) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1805],2,arguments);
}
var if_DASH_6999563 = R.hasField(cases_DASH_funs6969549,("a-dot"));
var if_helper54829546 = R.makeFunction(function(if_helper_arg54839568) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1805],1,arguments);
}
var ann_DASH_check_DASH_temp54819569 = if_helper_arg54839568;
return ann_DASH_check_DASH_temp54819569;
});
var anf_if54869567 = R.isBoolean(if_DASH_6999563);
if(R.isPyretTrue(anf_if54869567)) {
if(R.isPyretTrue(if_DASH_6999563)) {
var call_DASH_a_DASH_dot6949541 = G(cases_DASH_funs6969549,"a-dot",L[1805]);
var anf_arg54899542 = G(self6959548,"l",L[1849]);
var anf_arg54909543 = G(self6959548,"obj",L[1848]);
var anf_arg54919544 = G(self6959548,"field",L[1847]);
var $z95339534 = D;
var $f95399540 = function(_) {
return R.isFunction(call_DASH_a_DASH_dot6949541)?call_DASH_a_DASH_dot6949541.app(anf_arg54899542,anf_arg54909543,anf_arg54919544):R.ffi.throwNonFunApp(L[1805],call_DASH_a_DASH_dot6949541,[anf_arg54899542,anf_arg54909543,anf_arg54919544]);
};
try {
if(--R.GAS > 0) {
$z95339534 = $f95399540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95399540,
"from":L[1805]});
}
} catch($e95319532) {
if(R.isCont($e95319532)) {
var $ss95359536 = {"from":L[1805],
"go":function(cont_tail_arg54929545) {
return $Hcont_tail_arg103719547(cont_tail_arg54929545,if_helper54829546);
}};
$e95319532.stack[R.EXN_STACKHEIGHT++] = $ss95359536;
}
if(R.isPyretException($e95319532)) {
$e95319532.pyretStack.push(L[1805]);
}
throw $e95319532;
}
var $ret95379538 = $Hcont_tail_arg103719547($z95339534,if_helper54829546);
++R.GAS;
return $ret95379538;
} else {
var $z95529553 = D;
var $f95589559 = function(_) {
return R.isFunction(else_DASH_clause6979560)?else_DASH_clause6979560.app():R.ffi.throwNonFunApp(L[1805],else_DASH_clause6979560,[]);
};
try {
if(--R.GAS > 0) {
$z95529553 = $f95589559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95589559,
"from":L[1805]});
}
} catch($e95509551) {
if(R.isCont($e95509551)) {
var $ss95549555 = {"from":L[1805],
"go":function(cont_tail_arg54879561) {
return $Hcont_tail_arg103729562(cont_tail_arg54879561,if_helper54829546);
}};
$e95509551.stack[R.EXN_STACKHEIGHT++] = $ss95549555;
}
if(R.isPyretException($e95509551)) {
$e95509551.pyretStack.push(L[1805]);
}
throw $e95509551;
}
var $ret95569557 = $Hcont_tail_arg103729562($z95529553,if_helper54829546);
++R.GAS;
return $ret95569557;
}
} else {
var cont_tail_arg54849566 = R.throwNonBooleanCondition(L[1805],("if"),if_DASH_6999563);
if(--R.GAS > 0) {
$z95649565 = R.isFunction(if_helper54829546)?if_helper54829546.app(cont_tail_arg54849566):R.ffi.throwNonFunApp(L[1805],if_helper54829546,[cont_tail_arg54849566]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper54829546)?if_helper54829546.app(cont_tail_arg54849566):R.ffi.throwNonFunApp(L[1805],if_helper54829546,[cont_tail_arg54849566]);
},
"from":L[1805]});
}
++R.GAS;
return $z95649565;
}
};
},{"length":3});
var anf_variant_member55089494 = R.makeMethod(function(self6989529) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1805],0,arguments);
}
var anf_arg54969527 = G(self6989529,"l",L[1805]);
var $z95199520 = D;
var $f95259526 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg54969527):R.ffi.throwNonFunApp(L[1805],torepr65,[anf_arg54969527]);
};
try {
if(--R.GAS > 0) {
$z95199520 = $f95259526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95259526,
"from":L[1805]});
}
} catch($e95179518) {
if(R.isCont($e95179518)) {
var $ss95219522 = {"from":L[1805],
"go":function(anf_arg54979528) {
return $Hanf_arg103829530(anf_arg54979528,self6989529,_plus55,torepr65);
}};
$e95179518.stack[R.EXN_STACKHEIGHT++] = $ss95219522;
}
if(R.isPyretException($e95179518)) {
$e95179518.pyretStack.push(L[1805]);
}
throw $e95179518;
}
var $ret95239524 = $Hanf_arg103829530($z95199520,self6989529,_plus55,torepr65);
++R.GAS;
return $ret95239524;
};
},{"length":1});
var anf_variant_member55109495 = R.makeMethod(function(self11729516) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1846],0,arguments);
}
var ann_DASH_check_DASH_temp55099515 = ("a-dot");
return ann_DASH_check_DASH_temp55099515;
};
},{"length":1});
var anf_variant_member55199496 = R.makeMethod(function(self11739512) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1845],0,arguments);
}
var anf_bracket55129514 = G(self11739512,"obj",L[1844]);
var anf_fun55139510 = G(anf_bracket55129514,"tosource",L[1843]);
var $z95029503 = D;
var $f95089509 = function(_) {
return R.isFunction(anf_fun55139510)?anf_fun55139510.app():R.ffi.throwNonFunApp(L[1842],anf_fun55139510,[]);
};
try {
if(--R.GAS > 0) {
$z95029503 = $f95089509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95089509,
"from":L[1842]});
}
} catch($e95009501) {
if(R.isCont($e95009501)) {
var $ss95049505 = {"from":L[1842],
"go":function(anf_arg55149511) {
return $Hanf_arg103869513(anf_arg55149511,PP170,self11739512,_plus55);
}};
$e95009501.stack[R.EXN_STACKHEIGHT++] = $ss95049505;
}
if(R.isPyretException($e95009501)) {
$e95009501.pyretStack.push(L[1842]);
}
throw $e95009501;
}
var $ret95069507 = $Hanf_arg103869513($z95029503,PP170,self11739512,_plus55);
++R.GAS;
return $ret95069507;
};
},{"length":1});
var anf_assign55202308 = (function() {
var $a_DASH_blank_DASH_base93999400 = {"visit":anf_shared51849398,
"_match":anf_singleton_variant_member51959404,
"_torepr":anf_singleton_variant_member51979405,
"label":anf_singleton_variant_member51999406,
"tosource":anf_singleton_variant_member52019407};
var $a_DASH_blank_DASH_brands94029403 = {"$brand-a-blank9401":true};
$a_DASH_blank_DASH_brands94029403[AnnT24113100._brand] = true
var $a_DASH_any_DASH_base94089409 = {"visit":anf_shared51849398,
"_match":anf_singleton_variant_member52129413,
"_torepr":anf_singleton_variant_member52149414,
"label":anf_singleton_variant_member52169415,
"tosource":anf_singleton_variant_member52189416};
var $a_DASH_any_DASH_brands94119412 = {"$brand-a-any9410":true};
$a_DASH_any_DASH_brands94119412[AnnT24113100._brand] = true
var $a_DASH_name_DASH_base94179418 = {"visit":anf_shared51849398,
"_match":anf_variant_member52319422,
"_torepr":anf_variant_member52419423,
"label":anf_variant_member52439424,
"tosource":anf_variant_member52479425};
var $a_DASH_name_DASH_brands94209421 = {"$brand-a-name9419":true};
$a_DASH_name_DASH_brands94209421[AnnT24113100._brand] = true
var $a_DASH_arrow_DASH_base94289429 = {"visit":anf_shared51849398,
"_match":anf_variant_member52629433,
"_torepr":anf_variant_member52809434,
"label":anf_variant_member52829435,
"tosource":anf_variant_member53139436};
var $a_DASH_arrow_DASH_brands94319432 = {"$brand-a-arrow9430":true};
$a_DASH_arrow_DASH_brands94319432[AnnT24113100._brand] = true
var $a_DASH_method_DASH_base94419442 = {"visit":anf_shared51849398,
"_match":anf_variant_member53279446,
"_torepr":anf_variant_member53419447,
"label":anf_variant_member53439448,
"tosource":anf_variant_member53469449};
var $a_DASH_method_DASH_brands94449445 = {"$brand-a-method9443":true};
$a_DASH_method_DASH_brands94449445[AnnT24113100._brand] = true
var $a_DASH_record_DASH_base94539454 = {"visit":anf_shared51849398,
"_match":anf_variant_member53599458,
"_torepr":anf_variant_member53699459,
"label":anf_variant_member53719460,
"tosource":anf_variant_member53869461};
var $a_DASH_record_DASH_brands94569457 = {"$brand-a-record9455":true};
$a_DASH_record_DASH_brands94569457[AnnT24113100._brand] = true
var $a_DASH_app_DASH_base94649465 = {"visit":anf_shared51849398,
"_match":anf_variant_member54009469,
"_torepr":anf_variant_member54149470,
"label":anf_variant_member54169471,
"tosource":anf_variant_member54409472};
var $a_DASH_app_DASH_brands94679468 = {"$brand-a-app9466":true};
$a_DASH_app_DASH_brands94679468[AnnT24113100._brand] = true
var $a_DASH_pred_DASH_base94769477 = {"visit":anf_shared51849398,
"_match":anf_variant_member54549481,
"_torepr":anf_variant_member54689482,
"label":anf_variant_member54709483,
"tosource":anf_variant_member54809484};
var $a_DASH_pred_DASH_brands94799480 = {"$brand-a-pred9478":true};
$a_DASH_pred_DASH_brands94799480[AnnT24113100._brand] = true
var $a_DASH_dot_DASH_base94889489 = {"visit":anf_shared51849398,
"_match":anf_variant_member54949493,
"_torepr":anf_variant_member55089494,
"label":anf_variant_member55109495,
"tosource":anf_variant_member55199496};
var $a_DASH_dot_DASH_brands94919492 = {"$brand-a-dot9490":true};
$a_DASH_dot_DASH_brands94919492[AnnT24113100._brand] = true
return R.makeObject({"Ann":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1814],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AnnT24113100._brand));
}),
"is-a-blank":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1813],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-blank9401"));
}),
"a-blank":R.makeBrandedObject($a_DASH_blank_DASH_base93999400,$a_DASH_blank_DASH_brands94029403),
"is-a-any":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1812],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-any9410"));
}),
"a-any":R.makeBrandedObject($a_DASH_any_DASH_base94089409,$a_DASH_any_DASH_brands94119412),
"is-a-name":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1811],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-name9419"));
}),
"a-name":R.makeFunction(function(l11399426,id11409427) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1815],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l11399426,id11409427],[L[1816],L[1817]],function() {
var dict = R.create($a_DASH_name_DASH_base94179418);
dict["l"] = l11399426
dict["id"] = id11409427
return R.makeBrandedObject(dict,$a_DASH_name_DASH_brands94209421);
});
}),
"is-a-arrow":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1810],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-arrow9430"));
}),
"a-arrow":R.makeFunction(function(l11439437,args11449438,ret11459439,use_DASH_parens11469440) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1818],4,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Ann11299,$type$Boolean67],[l11439437,args11449438,ret11459439,use_DASH_parens11469440],[L[1819],L[1820],L[1821],L[1822]],function() {
var dict = R.create($a_DASH_arrow_DASH_base94289429);
dict["l"] = l11439437
dict["args"] = args11449438
dict["ret"] = ret11459439
dict["use-parens"] = use_DASH_parens11469440
return R.makeBrandedObject(dict,$a_DASH_arrow_DASH_brands94319432);
});
}),
"is-a-method":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1809],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-method9443"));
}),
"a-method":R.makeFunction(function(l11509450,args11519451,ret11529452) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1823],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Ann11299],[l11509450,args11519451,ret11529452],[L[1824],L[1825],L[1826]],function() {
var dict = R.create($a_DASH_method_DASH_base94419442);
dict["l"] = l11509450
dict["args"] = args11519451
dict["ret"] = ret11529452
return R.makeBrandedObject(dict,$a_DASH_method_DASH_brands94449445);
});
}),
"is-a-record":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1808],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-record9455"));
}),
"a-record":R.makeFunction(function(l11559462,fields11569463) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1827],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l11559462,fields11569463],[L[1828],L[1829]],function() {
var dict = R.create($a_DASH_record_DASH_base94539454);
dict["l"] = l11559462
dict["fields"] = fields11569463
return R.makeBrandedObject(dict,$a_DASH_record_DASH_brands94569457);
});
}),
"is-a-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1807],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-app9466"));
}),
"a-app":R.makeFunction(function(l11599473,ann11609474,args11619475) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1830],3,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,List17129],[l11599473,ann11609474,args11619475],[L[1831],L[1832],L[1833]],function() {
var dict = R.create($a_DASH_app_DASH_base94649465);
dict["l"] = l11599473
dict["ann"] = ann11609474
dict["args"] = args11619475
return R.makeBrandedObject(dict,$a_DASH_app_DASH_brands94679468);
});
}),
"is-a-pred":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1806],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-pred9478"));
}),
"a-pred":R.makeFunction(function(l11649485,ann11659486,exp11669487) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1834],3,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111],[l11649485,ann11659486,exp11669487],[L[1835],L[1836],L[1837]],function() {
var dict = R.create($a_DASH_pred_DASH_base94769477);
dict["l"] = l11649485
dict["ann"] = ann11659486
dict["exp"] = exp11669487
return R.makeBrandedObject(dict,$a_DASH_pred_DASH_brands94799480);
});
}),
"is-a-dot":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1805],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-dot9490"));
}),
"a-dot":R.makeFunction(function(l11699497,obj11709498,field11719499) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1838],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,$type$String69],[l11699497,obj11709498,field11719499],[L[1839],L[1840],L[1841]],function() {
var dict = R.create($a_DASH_dot_DASH_base94889489);
dict["l"] = l11699497
dict["obj"] = obj11709498
dict["field"] = field11719499
return R.makeBrandedObject(dict,$a_DASH_dot_DASH_brands94919492);
});
})});
})();
Ann495032307.$var = anf_assign55202308;
var anf_assign55212310 = G(Ann495032307.$var,"Ann",L[1814]);
Ann5042309.$var = anf_assign55212310;
var anf_assign55222312 = G(Ann495032307.$var,"Ann",L[1814]);
is_DASH_Ann5052311.$var = anf_assign55222312;
var anf_assign55232314 = G(Ann495032307.$var,"is-a-blank",L[1813]);
is_DASH_a_DASH_blank5062313.$var = anf_assign55232314;
var anf_assign55242316 = G(Ann495032307.$var,"a-blank",L[1813]);
a_DASH_blank5072315.$var = anf_assign55242316;
var anf_assign55252318 = G(Ann495032307.$var,"is-a-any",L[1812]);
is_DASH_a_DASH_any5082317.$var = anf_assign55252318;
var anf_assign55262320 = G(Ann495032307.$var,"a-any",L[1812]);
a_DASH_any5092319.$var = anf_assign55262320;
var anf_assign55272322 = G(Ann495032307.$var,"is-a-name",L[1811]);
is_DASH_a_DASH_name5102321.$var = anf_assign55272322;
var anf_assign55282324 = G(Ann495032307.$var,"a-name",L[1811]);
a_DASH_name5112323.$var = anf_assign55282324;
var anf_assign55292326 = G(Ann495032307.$var,"is-a-arrow",L[1810]);
is_DASH_a_DASH_arrow5122325.$var = anf_assign55292326;
var anf_assign55302328 = G(Ann495032307.$var,"a-arrow",L[1810]);
a_DASH_arrow5132327.$var = anf_assign55302328;
var anf_assign55312330 = G(Ann495032307.$var,"is-a-method",L[1809]);
is_DASH_a_DASH_method5142329.$var = anf_assign55312330;
var anf_assign55322332 = G(Ann495032307.$var,"a-method",L[1809]);
a_DASH_method5152331.$var = anf_assign55322332;
var anf_assign55332334 = G(Ann495032307.$var,"is-a-record",L[1808]);
is_DASH_a_DASH_record5162333.$var = anf_assign55332334;
var anf_assign55342336 = G(Ann495032307.$var,"a-record",L[1808]);
a_DASH_record5172335.$var = anf_assign55342336;
var anf_assign55352338 = G(Ann495032307.$var,"is-a-app",L[1807]);
is_DASH_a_DASH_app5182337.$var = anf_assign55352338;
var anf_assign55362340 = G(Ann495032307.$var,"a-app",L[1807]);
a_DASH_app5192339.$var = anf_assign55362340;
var anf_assign55372342 = G(Ann495032307.$var,"is-a-pred",L[1806]);
is_DASH_a_DASH_pred5202341.$var = anf_assign55372342;
var anf_assign55382344 = G(Ann495032307.$var,"a-pred",L[1806]);
a_DASH_pred5212343.$var = anf_assign55382344;
var anf_assign55392346 = G(Ann495032307.$var,"is-a-dot",L[1805]);
is_DASH_a_DASH_dot5222345.$var = anf_assign55392346;
var anf_assign55402348 = G(Ann495032307.$var,"a-dot",L[1805]);
a_DASH_dot5232347.$var = anf_assign55402348;
var anf_shared55489287 = R.makeMethod(function(self11819397) {
return function(visitor11829380) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1800],1,arguments);
}
var anf_fun55429379 = G(self11819397,"_match",L[1804]);
var anf_arg55479381 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1801],0,arguments);
}
var anf_fun55449394 = G(self11819397,"label",L[1803]);
var $z93869387 = D;
var $f93929393 = function(_) {
return R.isFunction(anf_fun55449394)?anf_fun55449394.app():R.ffi.throwNonFunApp(L[1802],anf_fun55449394,[]);
};
try {
if(--R.GAS > 0) {
$z93869387 = $f93929393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93929393,
"from":L[1802]});
}
} catch($e93849385) {
if(R.isCont($e93849385)) {
var $ss93889389 = {"from":L[1802],
"go":function(anf_arg55459395) {
return $Hanf_arg103899396(anf_arg55459395,_plus55,raise62);
}};
$e93849385.stack[R.EXN_STACKHEIGHT++] = $ss93889389;
}
if(R.isPyretException($e93849385)) {
$e93849385.pyretStack.push(L[1802]);
}
throw $e93849385;
}
var $ret93909391 = $Hanf_arg103899396($z93869387,_plus55,raise62);
++R.GAS;
return $ret93909391;
});
var $z93719372 = D;
var $f93779378 = function(_) {
return R.isFunction(anf_fun55429379)?anf_fun55429379.app(visitor11829380,anf_arg55479381):R.ffi.throwNonFunApp(L[1800],anf_fun55429379,[visitor11829380,anf_arg55479381]);
};
try {
if(--R.GAS > 0) {
$z93719372 = $f93779378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93779378,
"from":L[1800]});
}
} catch($e93699370) {
if(R.isCont($e93699370)) {
var $ss93739374 = {"from":L[1800],
"go":function(ann_DASH_check_DASH_temp55419382) {
return $Hann_DASH_check_DASH_temp103909383(ann_DASH_check_DASH_temp55419382);
}};
$e93699370.stack[R.EXN_STACKHEIGHT++] = $ss93739374;
}
if(R.isPyretException($e93699370)) {
$e93699370.pyretStack.push(L[1800]);
}
throw $e93699370;
}
var $ret93759376 = $Hann_DASH_check_DASH_temp103909383($z93719372);
++R.GAS;
return $ret93759376;
};
},{"length":2});
var anf_variant_member55629293 = R.makeMethod(function(self7019347) {
return function(cases_DASH_funs7029348,else_DASH_clause7039359) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1787],2,arguments);
}
var if_DASH_7059362 = R.hasField(cases_DASH_funs7029348,("a-field"));
var if_helper55509345 = R.makeFunction(function(if_helper_arg55519367) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1787],1,arguments);
}
var ann_DASH_check_DASH_temp55499368 = if_helper_arg55519367;
return ann_DASH_check_DASH_temp55499368;
});
var anf_if55549366 = R.isBoolean(if_DASH_7059362);
if(R.isPyretTrue(anf_if55549366)) {
if(R.isPyretTrue(if_DASH_7059362)) {
var call_DASH_a_DASH_field7009340 = G(cases_DASH_funs7029348,"a-field",L[1787]);
var anf_arg55579341 = G(self7019347,"l",L[1799]);
var anf_arg55589342 = G(self7019347,"name",L[1798]);
var anf_arg55599343 = G(self7019347,"ann",L[1797]);
var $z93329333 = D;
var $f93389339 = function(_) {
return R.isFunction(call_DASH_a_DASH_field7009340)?call_DASH_a_DASH_field7009340.app(anf_arg55579341,anf_arg55589342,anf_arg55599343):R.ffi.throwNonFunApp(L[1787],call_DASH_a_DASH_field7009340,[anf_arg55579341,anf_arg55589342,anf_arg55599343]);
};
try {
if(--R.GAS > 0) {
$z93329333 = $f93389339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93389339,
"from":L[1787]});
}
} catch($e93309331) {
if(R.isCont($e93309331)) {
var $ss93349335 = {"from":L[1787],
"go":function(cont_tail_arg55609344) {
return $Hcont_tail_arg103919346(cont_tail_arg55609344,if_helper55509345);
}};
$e93309331.stack[R.EXN_STACKHEIGHT++] = $ss93349335;
}
if(R.isPyretException($e93309331)) {
$e93309331.pyretStack.push(L[1787]);
}
throw $e93309331;
}
var $ret93369337 = $Hcont_tail_arg103919346($z93329333,if_helper55509345);
++R.GAS;
return $ret93369337;
} else {
var $z93519352 = D;
var $f93579358 = function(_) {
return R.isFunction(else_DASH_clause7039359)?else_DASH_clause7039359.app():R.ffi.throwNonFunApp(L[1787],else_DASH_clause7039359,[]);
};
try {
if(--R.GAS > 0) {
$z93519352 = $f93579358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93579358,
"from":L[1787]});
}
} catch($e93499350) {
if(R.isCont($e93499350)) {
var $ss93539354 = {"from":L[1787],
"go":function(cont_tail_arg55559360) {
return $Hcont_tail_arg103929361(cont_tail_arg55559360,if_helper55509345);
}};
$e93499350.stack[R.EXN_STACKHEIGHT++] = $ss93539354;
}
if(R.isPyretException($e93499350)) {
$e93499350.pyretStack.push(L[1787]);
}
throw $e93499350;
}
var $ret93559356 = $Hcont_tail_arg103929361($z93519352,if_helper55509345);
++R.GAS;
return $ret93559356;
}
} else {
var cont_tail_arg55529365 = R.throwNonBooleanCondition(L[1787],("if"),if_DASH_7059362);
if(--R.GAS > 0) {
$z93639364 = R.isFunction(if_helper55509345)?if_helper55509345.app(cont_tail_arg55529365):R.ffi.throwNonFunApp(L[1787],if_helper55509345,[cont_tail_arg55529365]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper55509345)?if_helper55509345.app(cont_tail_arg55529365):R.ffi.throwNonFunApp(L[1787],if_helper55509345,[cont_tail_arg55529365]);
},
"from":L[1787]});
}
++R.GAS;
return $z93639364;
}
};
},{"length":3});
var anf_variant_member55769294 = R.makeMethod(function(self7049328) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1787],0,arguments);
}
var anf_arg55649326 = G(self7049328,"l",L[1787]);
var $z93189319 = D;
var $f93249325 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg55649326):R.ffi.throwNonFunApp(L[1787],torepr65,[anf_arg55649326]);
};
try {
if(--R.GAS > 0) {
$z93189319 = $f93249325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93249325,
"from":L[1787]});
}
} catch($e93169317) {
if(R.isCont($e93169317)) {
var $ss93209321 = {"from":L[1787],
"go":function(anf_arg55659327) {
return $Hanf_arg104029329(anf_arg55659327,self7049328,_plus55,torepr65);
}};
$e93169317.stack[R.EXN_STACKHEIGHT++] = $ss93209321;
}
if(R.isPyretException($e93169317)) {
$e93169317.pyretStack.push(L[1787]);
}
throw $e93169317;
}
var $ret93229323 = $Hanf_arg104029329($z93189319,self7049328,_plus55,torepr65);
++R.GAS;
return $ret93229323;
};
},{"length":1});
var anf_variant_member55789295 = R.makeMethod(function(self11799315) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1796],0,arguments);
}
var ann_DASH_check_DASH_temp55779314 = ("a-field");
return ann_DASH_check_DASH_temp55779314;
};
},{"length":1});
var anf_variant_member55999296 = R.makeMethod(function(self11809312) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1795],0,arguments);
}
var anf_arg55809310 = G(self11809312,"ann",L[1794]);
var $z93029303 = D;
var $f93089309 = function(_) {
return R.isFunction(is_DASH_a_DASH_blank5062313.$var)?is_DASH_a_DASH_blank5062313.$var.app(anf_arg55809310):R.ffi.throwNonFunApp(L[1793],is_DASH_a_DASH_blank5062313.$var,[anf_arg55809310]);
};
try {
if(--R.GAS > 0) {
$z93029303 = $f93089309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93089309,
"from":L[1793]});
}
} catch($e93009301) {
if(R.isCont($e93009301)) {
var $ss93049305 = {"from":L[1793],
"go":function(if_DASH_7069311) {
return $Hif_DASH_104079313(if_DASH_7069311,INDENT118169,PP170,self11809312,str_DASH_coloncolon135377);
}};
$e93009301.stack[R.EXN_STACKHEIGHT++] = $ss93049305;
}
if(R.isPyretException($e93009301)) {
$e93009301.pyretStack.push(L[1793]);
}
throw $e93009301;
}
var $ret93069307 = $Hif_DASH_104079313($z93029303,INDENT118169,PP170,self11809312,str_DASH_coloncolon135377);
++R.GAS;
return $ret93069307;
};
},{"length":1});
var anf_assign56002350 = (function() {
var $a_DASH_field_DASH_base92889289 = {"visit":anf_shared55489287,
"_match":anf_variant_member55629293,
"_torepr":anf_variant_member55769294,
"label":anf_variant_member55789295,
"tosource":anf_variant_member55999296};
var $a_DASH_field_DASH_brands92919292 = {"$brand-a-field9290":true};
$a_DASH_field_DASH_brands92919292[AFieldT2511598._brand] = true
return R.makeObject({"AField":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1788],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AFieldT2511598._brand));
}),
"is-a-field":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1787],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-field9290"));
}),
"a-field":R.makeFunction(function(l11769297,name11779298,ann11789299) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1789],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Ann11299],[l11769297,name11779298,ann11789299],[L[1790],L[1791],L[1792]],function() {
var dict = R.create($a_DASH_field_DASH_base92889289);
dict["l"] = l11769297
dict["name"] = name11779298
dict["ann"] = ann11789299
return R.makeBrandedObject(dict,$a_DASH_field_DASH_brands92919292);
});
})});
})();
AField505242349.$var = anf_assign56002350;
var anf_assign56012352 = G(AField505242349.$var,"AField",L[1788]);
AField5252351.$var = anf_assign56012352;
var anf_assign56022354 = G(AField505242349.$var,"AField",L[1788]);
is_DASH_AField5262353.$var = anf_assign56022354;
var anf_assign56032356 = G(AField505242349.$var,"is-a-field",L[1787]);
is_DASH_a_DASH_field5272355.$var = anf_assign56032356;
var anf_assign56042358 = G(AField505242349.$var,"a-field",L[1787]);
a_DASH_field5282357.$var = anf_assign56042358;
var anf_assign56062360 = R.makeFunction(function(name11839274) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1786],1,arguments);
}
var $z92779278 = D;
var $f92839284 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("is-"),name11839274):R.ffi.throwNonFunApp(L[1786],_plus55,[("is-"),name11839274]);
};
try {
if(--R.GAS > 0) {
$z92779278 = $f92839284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92839284,
"from":L[1786]});
}
} catch($e92759276) {
if(R.isCont($e92759276)) {
var $ss92799280 = {"from":L[1786],
"go":function(ann_DASH_check_DASH_temp56059285) {
return $Hann_DASH_check_DASH_temp104089286(ann_DASH_check_DASH_temp56059285);
}};
$e92759276.stack[R.EXN_STACKHEIGHT++] = $ss92799280;
}
if(R.isPyretException($e92759276)) {
$e92759276.pyretStack.push(L[1786]);
}
throw $e92759276;
}
var $ret92819282 = $Hann_DASH_check_DASH_temp104089286($z92779278);
++R.GAS;
return $ret92819282;
});
make_DASH_checker_DASH_name5292359.$var = anf_assign56062360;
var anf_assign56122362 = R.makeFunction(function(list_DASH_of_DASH_lists11849245) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1782],1,arguments);
}
return R.checkAnnArgs([List17129],[list_DASH_of_DASH_lists11849245],[L[1785]],function() {
var anf_arg56099258 = R.makeFunction(function(biglist11859260,piece11869261) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1784],2,arguments);
}
var $z92649265 = D;
var $f92709271 = function(_) {
return R.isFunction(_plus55)?_plus55.app(biglist11859260,piece11869261):R.ffi.throwNonFunApp(L[1784],_plus55,[biglist11859260,piece11869261]);
};
try {
if(--R.GAS > 0) {
$z92649265 = $f92709271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92709271,
"from":L[1784]});
}
} catch($e92629263) {
if(R.isCont($e92629263)) {
var $ss92669267 = {"from":L[1784],
"go":function(ann_DASH_check_DASH_temp56089272) {
return $Hann_DASH_check_DASH_temp104099273(ann_DASH_check_DASH_temp56089272);
}};
$e92629263.stack[R.EXN_STACKHEIGHT++] = $ss92669267;
}
if(R.isPyretException($e92629263)) {
$e92629263.pyretStack.push(L[1784]);
}
throw $e92629263;
}
var $ret92689269 = $Hann_DASH_check_DASH_temp104099273($z92649265);
++R.GAS;
return $ret92689269;
});
var anf_fun56109256 = G(list25154,"make",L[1783]);
var $z92489249 = D;
var $f92549255 = function(_) {
return R.isFunction(anf_fun56109256)?anf_fun56109256.app([]):R.ffi.throwNonFunApp(L[1783],anf_fun56109256,[[]]);
};
try {
if(--R.GAS > 0) {
$z92489249 = $f92549255();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92549255,
"from":L[1783]});
}
} catch($e92469247) {
if(R.isCont($e92469247)) {
var $ss92509251 = {"from":L[1783],
"go":function(anf_arg56119257) {
return $Hanf_arg104119259(anf_arg56119257,anf_arg56099258,fold53151,list_DASH_of_DASH_lists11849245);
}};
$e92469247.stack[R.EXN_STACKHEIGHT++] = $ss92509251;
}
if(R.isPyretException($e92469247)) {
$e92469247.pyretStack.push(L[1783]);
}
throw $e92469247;
}
var $ret92529253 = $Hanf_arg104119259($z92489249,anf_arg56099258,fold53151,list_DASH_of_DASH_lists11849245);
++R.GAS;
return $ret92529253;
});
});
flatten5302361.$var = anf_assign56122362;
var anf_assign56312364 = R.makeFunction(function(stmt11879170) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1773],1,arguments);
}
var cases_DASH_val7079244 = stmt11879170;
var anf_fun56149181 = G(cases_DASH_val7079244,"_match",L[1774]);
var anf_obj56189187 = R.makeFunction(function(l11889227,name11899228,$underscore11909229) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1780],3,arguments);
}
var anf_fun56169240 = G(list25154,"make",L[1781]);
var anf_array_val56179241 = R.makeObject({"bind-type":("normal"),
"name":name11899228});
var $z92329233 = D;
var $f92389239 = function(_) {
return R.isFunction(anf_fun56169240)?anf_fun56169240.app([anf_array_val56179241]):R.ffi.throwNonFunApp(L[1780],anf_fun56169240,[[anf_array_val56179241]]);
};
try {
if(--R.GAS > 0) {
$z92329233 = $f92389239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92389239,
"from":L[1780]});
}
} catch($e92309231) {
if(R.isCont($e92309231)) {
var $ss92349235 = {"from":L[1780],
"go":function(ann_DASH_check_DASH_temp56159242) {
return $Hann_DASH_check_DASH_temp104129243(ann_DASH_check_DASH_temp56159242);
}};
$e92309231.stack[R.EXN_STACKHEIGHT++] = $ss92349235;
}
if(R.isPyretException($e92309231)) {
$e92309231.pyretStack.push(L[1780]);
}
throw $e92309231;
}
var $ret92369237 = $Hann_DASH_check_DASH_temp104129243($z92329233);
++R.GAS;
return $ret92369237;
});
var anf_obj56229188 = R.makeFunction(function(l11919210,name11929211,$underscore11939212) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1778],3,arguments);
}
var anf_fun56209223 = G(list25154,"make",L[1779]);
var anf_array_val56219224 = R.makeObject({"bind-type":("normal"),
"name":name11929211});
var $z92159216 = D;
var $f92219222 = function(_) {
return R.isFunction(anf_fun56209223)?anf_fun56209223.app([anf_array_val56219224]):R.ffi.throwNonFunApp(L[1778],anf_fun56209223,[[anf_array_val56219224]]);
};
try {
if(--R.GAS > 0) {
$z92159216 = $f92219222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92219222,
"from":L[1778]});
}
} catch($e92139214) {
if(R.isCont($e92139214)) {
var $ss92179218 = {"from":L[1778],
"go":function(ann_DASH_check_DASH_temp56199225) {
return $Hann_DASH_check_DASH_temp104139226(ann_DASH_check_DASH_temp56199225);
}};
$e92139214.stack[R.EXN_STACKHEIGHT++] = $ss92179218;
}
if(R.isPyretException($e92139214)) {
$e92139214.pyretStack.push(L[1778]);
}
throw $e92139214;
}
var $ret92199220 = $Hann_DASH_check_DASH_temp104139226($z92159216);
++R.GAS;
return $ret92199220;
});
var anf_obj56279189 = R.makeFunction(function(l11949190,name11959191,$underscore11969192,$underscore11979193,$underscore11989194,$underscore11999195,$underscore12009196) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[1775],7,arguments);
}
var anf_fun56249208 = G(list25154,"make",L[1777]);
var $z91999200 = D;
var $f92059206 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l11949190,name11959191):R.ffi.throwNonFunApp(L[1776],s_DASH_name1901015.$var,[l11949190,name11959191]);
};
try {
if(--R.GAS > 0) {
$z91999200 = $f92059206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92059206,
"from":L[1776]});
}
} catch($e91979198) {
if(R.isCont($e91979198)) {
var $ss92019202 = {"from":L[1776],
"go":function(anf_obj56259207) {
return $Hanf_obj104159209(anf_obj56259207,anf_fun56249208);
}};
$e91979198.stack[R.EXN_STACKHEIGHT++] = $ss92019202;
}
if(R.isPyretException($e91979198)) {
$e91979198.pyretStack.push(L[1776]);
}
throw $e91979198;
}
var $ret92039204 = $Hanf_obj104159209($z91999200,anf_fun56249208);
++R.GAS;
return $ret92039204;
});
var anf_arg56289182 = R.makeObject({"s-newtype":anf_obj56189187,
"s-type":anf_obj56229188,
"s-data":anf_obj56279189});
var anf_arg56309183 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1774],0,arguments);
}
var ann_DASH_check_DASH_temp56299186 = empty28150;
return ann_DASH_check_DASH_temp56299186;
});
var $z91739174 = D;
var $f91799180 = function(_) {
return R.isFunction(anf_fun56149181)?anf_fun56149181.app(anf_arg56289182,anf_arg56309183):R.ffi.throwNonFunApp(L[1773],anf_fun56149181,[anf_arg56289182,anf_arg56309183]);
};
try {
if(--R.GAS > 0) {
$z91739174 = $f91799180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91799180,
"from":L[1773]});
}
} catch($e91719172) {
if(R.isCont($e91719172)) {
var $ss91759176 = {"from":L[1773],
"go":function(ann_DASH_check_DASH_temp56139184) {
return $Hann_DASH_check_DASH_temp104169185(ann_DASH_check_DASH_temp56139184,List17129,Name66133);
}};
$e91719172.stack[R.EXN_STACKHEIGHT++] = $ss91759176;
}
if(R.isPyretException($e91719172)) {
$e91719172.pyretStack.push(L[1773]);
}
throw $e91719172;
}
var $ret91779178 = $Hann_DASH_check_DASH_temp104169185($z91739174,List17129,Name66133);
++R.GAS;
return $ret91779178;
});
binding_DASH_type_DASH_ids5312363.$var = anf_assign56312364;
var anf_assign56412366 = R.makeFunction(function(b12019125) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1767],1,arguments);
}
return R.checkAnnArgs([R.makePredAnn(Expr86111,is_DASH_s_DASH_block3291959.$var,"is-s-block")],[b12019125],[L[1772]],function() {
var cases_DASH_val7089169 = b12019125;
var anf_fun56339136 = G(cases_DASH_val7089169,"_match",L[1768]);
var anf_obj56379153 = R.makeFunction(function($underscore12029154,stmts12039155) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1769],2,arguments);
}
var anf_fun56359166 = G(stmts12039155,"map",L[1771]);
var $z91589159 = D;
var $f91649165 = function(_) {
return R.isFunction(anf_fun56359166)?anf_fun56359166.app(binding_DASH_type_DASH_ids5312363.$var):R.ffi.throwNonFunApp(L[1770],anf_fun56359166,[binding_DASH_type_DASH_ids5312363.$var]);
};
try {
if(--R.GAS > 0) {
$z91589159 = $f91649165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91649165,
"from":L[1770]});
}
} catch($e91569157) {
if(R.isCont($e91569157)) {
var $ss91609161 = {"from":L[1770],
"go":function(anf_arg56369167) {
return $Hanf_arg104189168(anf_arg56369167,flatten5302361);
}};
$e91569157.stack[R.EXN_STACKHEIGHT++] = $ss91609161;
}
if(R.isPyretException($e91569157)) {
$e91569157.pyretStack.push(L[1770]);
}
throw $e91569157;
}
var $ret91629163 = $Hanf_arg104189168($z91589159,flatten5302361);
++R.GAS;
return $ret91629163;
});
var anf_arg56389137 = R.makeObject({"s-block":anf_obj56379153});
var anf_arg56409138 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1768],0,arguments);
}
var $z91439144 = D;
var $f91499150 = function(_) {
return R.isFunction(raise62)?raise62.app(("Non-block given to block-ids")):R.ffi.throwNonFunApp(L[1768],raise62,[("Non-block given to block-ids")]);
};
try {
if(--R.GAS > 0) {
$z91439144 = $f91499150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91499150,
"from":L[1768]});
}
} catch($e91419142) {
if(R.isCont($e91419142)) {
var $ss91459146 = {"from":L[1768],
"go":function(ann_DASH_check_DASH_temp56399151) {
return $Hann_DASH_check_DASH_temp104199152(ann_DASH_check_DASH_temp56399151);
}};
$e91419142.stack[R.EXN_STACKHEIGHT++] = $ss91459146;
}
if(R.isPyretException($e91419142)) {
$e91419142.pyretStack.push(L[1768]);
}
throw $e91419142;
}
var $ret91479148 = $Hann_DASH_check_DASH_temp104199152($z91439144);
++R.GAS;
return $ret91479148;
});
var $z91289129 = D;
var $f91349135 = function(_) {
return R.isFunction(anf_fun56339136)?anf_fun56339136.app(anf_arg56389137,anf_arg56409138):R.ffi.throwNonFunApp(L[1767],anf_fun56339136,[anf_arg56389137,anf_arg56409138]);
};
try {
if(--R.GAS > 0) {
$z91289129 = $f91349135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91349135,
"from":L[1767]});
}
} catch($e91269127) {
if(R.isCont($e91269127)) {
var $ss91309131 = {"from":L[1767],
"go":function(ann_DASH_check_DASH_temp56329139) {
return $Hann_DASH_check_DASH_temp104209140(ann_DASH_check_DASH_temp56329139,List17129,Name66133);
}};
$e91269127.stack[R.EXN_STACKHEIGHT++] = $ss91309131;
}
if(R.isPyretException($e91269127)) {
$e91269127.pyretStack.push(L[1767]);
}
throw $e91269127;
}
var $ret91329133 = $Hann_DASH_check_DASH_temp104209140($z91289129,List17129,Name66133);
++R.GAS;
return $ret91329133;
});
});
block_DASH_type_DASH_ids5322365.$var = anf_assign56412366;
var anf_assign56952368 = R.makeFunction(function(stmt12048915) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1737],1,arguments);
}
var variant_DASH_ids12058916 = {"$var":D,
"$name":"variant-ids"};
var anf_assign56608917 = R.makeFunction(function(variant12069071) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1759],1,arguments);
}
var cases_DASH_val7099124 = variant12069071;
var anf_fun56449082 = G(cases_DASH_val7099124,"_match",L[1760]);
var anf_obj56509088 = R.makeFunction(function($underscore12079106,l212089107,name12099108,$underscore12109109,$underscore12119110) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1764],5,arguments);
}
var anf_fun56469122 = G(list25154,"make",L[1766]);
var $z91139114 = D;
var $f91199120 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l212089107,name12099108):R.ffi.throwNonFunApp(L[1765],s_DASH_name1901015.$var,[l212089107,name12099108]);
};
try {
if(--R.GAS > 0) {
$z91139114 = $f91199120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91199120,
"from":L[1765]});
}
} catch($e91119112) {
if(R.isCont($e91119112)) {
var $ss91159116 = {"from":L[1765],
"go":function(anf_array_val56479121) {
return $Hanf_array_val104249123(anf_array_val56479121,anf_fun56469122,l212089107,make_DASH_checker_DASH_name5292359,name12099108,s_DASH_name1901015);
}};
$e91119112.stack[R.EXN_STACKHEIGHT++] = $ss91159116;
}
if(R.isPyretException($e91119112)) {
$e91119112.pyretStack.push(L[1765]);
}
throw $e91119112;
}
var $ret91179118 = $Hanf_array_val104249123($z91139114,anf_fun56469122,l212089107,make_DASH_checker_DASH_name5292359,name12099108,s_DASH_name1901015);
++R.GAS;
return $ret91179118;
});
var anf_obj56569089 = R.makeFunction(function(l12129090,name12139091,$underscore12149092) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1761],3,arguments);
}
var anf_fun56529104 = G(list25154,"make",L[1763]);
var $z90959096 = D;
var $f91019102 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l12129090,name12139091):R.ffi.throwNonFunApp(L[1762],s_DASH_name1901015.$var,[l12129090,name12139091]);
};
try {
if(--R.GAS > 0) {
$z90959096 = $f91019102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91019102,
"from":L[1762]});
}
} catch($e90939094) {
if(R.isCont($e90939094)) {
var $ss90979098 = {"from":L[1762],
"go":function(anf_array_val56539103) {
return $Hanf_array_val104289105(anf_array_val56539103,anf_fun56529104,l12129090,make_DASH_checker_DASH_name5292359,name12139091,s_DASH_name1901015);
}};
$e90939094.stack[R.EXN_STACKHEIGHT++] = $ss90979098;
}
if(R.isPyretException($e90939094)) {
$e90939094.pyretStack.push(L[1762]);
}
throw $e90939094;
}
var $ret90999100 = $Hanf_array_val104289105($z90959096,anf_fun56529104,l12129090,make_DASH_checker_DASH_name5292359,name12139091,s_DASH_name1901015);
++R.GAS;
return $ret90999100;
});
var anf_arg56579083 = R.makeObject({"s-variant":anf_obj56509088,
"s-singleton-variant":anf_obj56569089});
var anf_arg56599084 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1760],0,arguments);
}
var ann_DASH_check_DASH_temp56589087 = R.throwNoBranchesMatched(L[1760],("cases"));
return ann_DASH_check_DASH_temp56589087;
});
var $z90749075 = D;
var $f90809081 = function(_) {
return R.isFunction(anf_fun56449082)?anf_fun56449082.app(anf_arg56579083,anf_arg56599084):R.ffi.throwNonFunApp(L[1759],anf_fun56449082,[anf_arg56579083,anf_arg56599084]);
};
try {
if(--R.GAS > 0) {
$z90749075 = $f90809081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90809081,
"from":L[1759]});
}
} catch($e90729073) {
if(R.isCont($e90729073)) {
var $ss90769077 = {"from":L[1759],
"go":function(ann_DASH_check_DASH_temp56439085) {
return $Hann_DASH_check_DASH_temp104299086(ann_DASH_check_DASH_temp56439085);
}};
$e90729073.stack[R.EXN_STACKHEIGHT++] = $ss90769077;
}
if(R.isPyretException($e90729073)) {
$e90729073.pyretStack.push(L[1759]);
}
throw $e90729073;
}
var $ret90789079 = $Hann_DASH_check_DASH_temp104299086($z90749075);
++R.GAS;
return $ret90789079;
});
variant_DASH_ids12058916.$var = anf_assign56608917;
var cases_DASH_val7129070 = stmt12048915;
var anf_fun56618928 = G(cases_DASH_val7129070,"_match",L[1738]);
var anf_obj56658946 = R.makeFunction(function($underscore12159052,b12169053,$underscore12179054,$underscore12189055) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1756],4,arguments);
}
var anf_fun56639066 = G(list25154,"make",L[1758]);
var anf_array_val56649067 = G(b12169053,"id",L[1757]);
var $z90589059 = D;
var $f90649065 = function(_) {
return R.isFunction(anf_fun56639066)?anf_fun56639066.app([anf_array_val56649067]):R.ffi.throwNonFunApp(L[1756],anf_fun56639066,[[anf_array_val56649067]]);
};
try {
if(--R.GAS > 0) {
$z90589059 = $f90649065();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90649065,
"from":L[1756]});
}
} catch($e90569057) {
if(R.isCont($e90569057)) {
var $ss90609061 = {"from":L[1756],
"go":function(ann_DASH_check_DASH_temp56629068) {
return $Hann_DASH_check_DASH_temp104309069(ann_DASH_check_DASH_temp56629068);
}};
$e90569057.stack[R.EXN_STACKHEIGHT++] = $ss90609061;
}
if(R.isPyretException($e90569057)) {
$e90569057.pyretStack.push(L[1756]);
}
throw $e90569057;
}
var $ret90629063 = $Hann_DASH_check_DASH_temp104309069($z90589059);
++R.GAS;
return $ret90629063;
});
var anf_obj56698947 = R.makeFunction(function($underscore12199035,b12209036,$underscore12219037) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1753],3,arguments);
}
var anf_fun56679048 = G(list25154,"make",L[1755]);
var anf_array_val56689049 = G(b12209036,"id",L[1754]);
var $z90409041 = D;
var $f90469047 = function(_) {
return R.isFunction(anf_fun56679048)?anf_fun56679048.app([anf_array_val56689049]):R.ffi.throwNonFunApp(L[1753],anf_fun56679048,[[anf_array_val56689049]]);
};
try {
if(--R.GAS > 0) {
$z90409041 = $f90469047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90469047,
"from":L[1753]});
}
} catch($e90389039) {
if(R.isCont($e90389039)) {
var $ss90429043 = {"from":L[1753],
"go":function(ann_DASH_check_DASH_temp56669050) {
return $Hann_DASH_check_DASH_temp104319051(ann_DASH_check_DASH_temp56669050);
}};
$e90389039.stack[R.EXN_STACKHEIGHT++] = $ss90429043;
}
if(R.isPyretException($e90389039)) {
$e90389039.pyretStack.push(L[1753]);
}
throw $e90389039;
}
var $ret90449045 = $Hann_DASH_check_DASH_temp104319051($z90409041);
++R.GAS;
return $ret90449045;
});
var anf_obj56738948 = R.makeFunction(function(l12229014,name12239015,$underscore12249016,$underscore12259017,$underscore12269018,$underscore12279019,$underscore12289020,$underscore12299021) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[1750],8,arguments);
}
var anf_fun56719033 = G(list25154,"make",L[1752]);
var $z90249025 = D;
var $f90309031 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l12229014,name12239015):R.ffi.throwNonFunApp(L[1751],s_DASH_name1901015.$var,[l12229014,name12239015]);
};
try {
if(--R.GAS > 0) {
$z90249025 = $f90309031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90309031,
"from":L[1751]});
}
} catch($e90229023) {
if(R.isCont($e90229023)) {
var $ss90269027 = {"from":L[1751],
"go":function(anf_array_val56729032) {
return $Hanf_array_val104339034(anf_array_val56729032,anf_fun56719033);
}};
$e90229023.stack[R.EXN_STACKHEIGHT++] = $ss90269027;
}
if(R.isPyretException($e90229023)) {
$e90229023.pyretStack.push(L[1751]);
}
throw $e90229023;
}
var $ret90289029 = $Hanf_array_val104339034($z90249025,anf_fun56719033);
++R.GAS;
return $ret90289029;
});
var anf_obj56778949 = R.makeFunction(function($underscore12308999,bindings12319000) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1747],2,arguments);
}
var anf_fun56759011 = G(bindings12319000,"map",L[1749]);
var $z90039004 = D;
var $f90099010 = function(_) {
return R.isFunction(anf_fun56759011)?anf_fun56759011.app(binding_DASH_ids5332367.$var):R.ffi.throwNonFunApp(L[1748],anf_fun56759011,[binding_DASH_ids5332367.$var]);
};
try {
if(--R.GAS > 0) {
$z90039004 = $f90099010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90099010,
"from":L[1748]});
}
} catch($e90019002) {
if(R.isCont($e90019002)) {
var $ss90059006 = {"from":L[1748],
"go":function(anf_arg56769012) {
return $Hanf_arg104359013(anf_arg56769012,flatten5302361);
}};
$e90019002.stack[R.EXN_STACKHEIGHT++] = $ss90059006;
}
if(R.isPyretException($e90019002)) {
$e90019002.pyretStack.push(L[1748]);
}
throw $e90019002;
}
var $ret90079008 = $Hanf_arg104359013($z90039004,flatten5302361);
++R.GAS;
return $ret90079008;
});
var anf_obj56908950 = R.makeFunction(function(l12328951,name12338952,$underscore12348953,$underscore12358954,variants12368955,$underscore12378956,$underscore12388957) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[1740],7,arguments);
}
var anf_fun56888969 = R.makeFunction(function(arg_DASH_7118971) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1742],1,arguments);
}
var anf_fun56848983 = R.makeFunction(function(arg_DASH_7108985) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1744],1,arguments);
}
var anf_fun56818996 = G(variants12368955,"map",L[1746]);
var $z89888989 = D;
var $f89948995 = function(_) {
return R.isFunction(anf_fun56818996)?anf_fun56818996.app(variant_DASH_ids12058916.$var):R.ffi.throwNonFunApp(L[1745],anf_fun56818996,[variant_DASH_ids12058916.$var]);
};
try {
if(--R.GAS > 0) {
$z89888989 = $f89948995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89948995,
"from":L[1745]});
}
} catch($e89868987) {
if(R.isCont($e89868987)) {
var $ss89908991 = {"from":L[1745],
"go":function(anf_arg56828997) {
return $Hanf_arg104388998(anf_arg56828997,arg_DASH_7108985,flatten5302361,link29153);
}};
$e89868987.stack[R.EXN_STACKHEIGHT++] = $ss89908991;
}
if(R.isPyretException($e89868987)) {
$e89868987.pyretStack.push(L[1745]);
}
throw $e89868987;
}
var $ret89928993 = $Hanf_arg104388998($z89888989,arg_DASH_7108985,flatten5302361,link29153);
++R.GAS;
return $ret89928993;
});
var $z89748975 = D;
var $f89808981 = function(_) {
return R.isFunction(make_DASH_checker_DASH_name5292359.$var)?make_DASH_checker_DASH_name5292359.$var.app(name12338952):R.ffi.throwNonFunApp(L[1743],make_DASH_checker_DASH_name5292359.$var,[name12338952]);
};
try {
if(--R.GAS > 0) {
$z89748975 = $f89808981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89808981,
"from":L[1743]});
}
} catch($e89728973) {
if(R.isCont($e89728973)) {
var $ss89768977 = {"from":L[1743],
"go":function(anf_arg56858982) {
return $Hanf_arg104428984(anf_arg56858982,anf_fun56848983,arg_DASH_7118971,l12328951,link29153,s_DASH_name1901015);
}};
$e89728973.stack[R.EXN_STACKHEIGHT++] = $ss89768977;
}
if(R.isPyretException($e89728973)) {
$e89728973.pyretStack.push(L[1743]);
}
throw $e89728973;
}
var $ret89788979 = $Hanf_arg104428984($z89748975,anf_fun56848983,arg_DASH_7118971,l12328951,link29153,s_DASH_name1901015);
++R.GAS;
return $ret89788979;
});
var $z89608961 = D;
var $f89668967 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l12328951,name12338952):R.ffi.throwNonFunApp(L[1741],s_DASH_name1901015.$var,[l12328951,name12338952]);
};
try {
if(--R.GAS > 0) {
$z89608961 = $f89668967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89668967,
"from":L[1741]});
}
} catch($e89588959) {
if(R.isCont($e89588959)) {
var $ss89628963 = {"from":L[1741],
"go":function(anf_arg56898968) {
return $Hanf_arg104448970(anf_arg56898968,anf_fun56888969);
}};
$e89588959.stack[R.EXN_STACKHEIGHT++] = $ss89628963;
}
if(R.isPyretException($e89588959)) {
$e89588959.pyretStack.push(L[1741]);
}
throw $e89588959;
}
var $ret89648965 = $Hanf_arg104448970($z89608961,anf_fun56888969);
++R.GAS;
return $ret89648965;
});
var anf_arg56918929 = R.makeObject({"s-let":anf_obj56658946,
"s-var":anf_obj56698947,
"s-fun":anf_obj56738948,
"s-graph":anf_obj56778949,
"s-data":anf_obj56908950});
var anf_arg56948930 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1738],0,arguments);
}
var anf_fun56938943 = G(list25154,"make",L[1739]);
var $z89358936 = D;
var $f89418942 = function(_) {
return R.isFunction(anf_fun56938943)?anf_fun56938943.app([]):R.ffi.throwNonFunApp(L[1738],anf_fun56938943,[[]]);
};
try {
if(--R.GAS > 0) {
$z89358936 = $f89418942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89418942,
"from":L[1738]});
}
} catch($e89338934) {
if(R.isCont($e89338934)) {
var $ss89378938 = {"from":L[1738],
"go":function(ann_DASH_check_DASH_temp56928944) {
return $Hann_DASH_check_DASH_temp104458945(ann_DASH_check_DASH_temp56928944);
}};
$e89338934.stack[R.EXN_STACKHEIGHT++] = $ss89378938;
}
if(R.isPyretException($e89338934)) {
$e89338934.pyretStack.push(L[1738]);
}
throw $e89338934;
}
var $ret89398940 = $Hann_DASH_check_DASH_temp104458945($z89358936);
++R.GAS;
return $ret89398940;
});
var $z89208921 = D;
var $f89268927 = function(_) {
return R.isFunction(anf_fun56618928)?anf_fun56618928.app(anf_arg56918929,anf_arg56948930):R.ffi.throwNonFunApp(L[1737],anf_fun56618928,[anf_arg56918929,anf_arg56948930]);
};
try {
if(--R.GAS > 0) {
$z89208921 = $f89268927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89268927,
"from":L[1737]});
}
} catch($e89188919) {
if(R.isCont($e89188919)) {
var $ss89228923 = {"from":L[1737],
"go":function(ann_DASH_check_DASH_temp56428931) {
return $Hann_DASH_check_DASH_temp104468932(ann_DASH_check_DASH_temp56428931,List17129,Name66133);
}};
$e89188919.stack[R.EXN_STACKHEIGHT++] = $ss89228923;
}
if(R.isPyretException($e89188919)) {
$e89188919.pyretStack.push(L[1737]);
}
throw $e89188919;
}
var $ret89248925 = $Hann_DASH_check_DASH_temp104468932($z89208921,List17129,Name66133);
++R.GAS;
return $ret89248925;
});
binding_DASH_ids5332367.$var = anf_assign56952368;
var anf_assign57052370 = R.makeFunction(function(b12398870) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1731],1,arguments);
}
return R.checkAnnArgs([R.makePredAnn(Expr86111,is_DASH_s_DASH_block3291959.$var,"is-s-block")],[b12398870],[L[1736]],function() {
var cases_DASH_val7138914 = b12398870;
var anf_fun56978881 = G(cases_DASH_val7138914,"_match",L[1732]);
var anf_obj57018898 = R.makeFunction(function($underscore12408899,stmts12418900) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1733],2,arguments);
}
var anf_fun56998911 = G(stmts12418900,"map",L[1735]);
var $z89038904 = D;
var $f89098910 = function(_) {
return R.isFunction(anf_fun56998911)?anf_fun56998911.app(binding_DASH_ids5332367.$var):R.ffi.throwNonFunApp(L[1734],anf_fun56998911,[binding_DASH_ids5332367.$var]);
};
try {
if(--R.GAS > 0) {
$z89038904 = $f89098910();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89098910,
"from":L[1734]});
}
} catch($e89018902) {
if(R.isCont($e89018902)) {
var $ss89058906 = {"from":L[1734],
"go":function(anf_arg57008912) {
return $Hanf_arg104488913(anf_arg57008912,flatten5302361);
}};
$e89018902.stack[R.EXN_STACKHEIGHT++] = $ss89058906;
}
if(R.isPyretException($e89018902)) {
$e89018902.pyretStack.push(L[1734]);
}
throw $e89018902;
}
var $ret89078908 = $Hanf_arg104488913($z89038904,flatten5302361);
++R.GAS;
return $ret89078908;
});
var anf_arg57028882 = R.makeObject({"s-block":anf_obj57018898});
var anf_arg57048883 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1732],0,arguments);
}
var $z88888889 = D;
var $f88948895 = function(_) {
return R.isFunction(raise62)?raise62.app(("Non-block given to block-ids")):R.ffi.throwNonFunApp(L[1732],raise62,[("Non-block given to block-ids")]);
};
try {
if(--R.GAS > 0) {
$z88888889 = $f88948895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88948895,
"from":L[1732]});
}
} catch($e88868887) {
if(R.isCont($e88868887)) {
var $ss88908891 = {"from":L[1732],
"go":function(ann_DASH_check_DASH_temp57038896) {
return $Hann_DASH_check_DASH_temp104498897(ann_DASH_check_DASH_temp57038896);
}};
$e88868887.stack[R.EXN_STACKHEIGHT++] = $ss88908891;
}
if(R.isPyretException($e88868887)) {
$e88868887.pyretStack.push(L[1732]);
}
throw $e88868887;
}
var $ret88928893 = $Hann_DASH_check_DASH_temp104498897($z88888889);
++R.GAS;
return $ret88928893;
});
var $z88738874 = D;
var $f88798880 = function(_) {
return R.isFunction(anf_fun56978881)?anf_fun56978881.app(anf_arg57028882,anf_arg57048883):R.ffi.throwNonFunApp(L[1731],anf_fun56978881,[anf_arg57028882,anf_arg57048883]);
};
try {
if(--R.GAS > 0) {
$z88738874 = $f88798880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88798880,
"from":L[1731]});
}
} catch($e88718872) {
if(R.isCont($e88718872)) {
var $ss88758876 = {"from":L[1731],
"go":function(ann_DASH_check_DASH_temp56968884) {
return $Hann_DASH_check_DASH_temp104508885(ann_DASH_check_DASH_temp56968884,List17129,Name66133);
}};
$e88718872.stack[R.EXN_STACKHEIGHT++] = $ss88758876;
}
if(R.isPyretException($e88718872)) {
$e88718872.pyretStack.push(L[1731]);
}
throw $e88718872;
}
var $ret88778878 = $Hann_DASH_check_DASH_temp104508885($z88738874,List17129,Name66133);
++R.GAS;
return $ret88778878;
});
});
block_DASH_ids5342369.$var = anf_assign57052370;
var anf_assign57132372 = R.makeFunction(function(program12428823) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1727],1,arguments);
}
return R.checkAnnArgs([Program68136],[program12428823],[L[1730]],function() {
var cases_DASH_val7148869 = program12428823;
var anf_fun57078834 = G(cases_DASH_val7148869,"_match",L[1728]);
var anf_obj57098851 = R.makeFunction(function($underscore12438852,$underscore12448853,$underscore12458854,$underscore12468855,b12478856) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1729],5,arguments);
}
var $z88598860 = D;
var $f88658866 = function(_) {
return R.isFunction(block_DASH_ids5342369.$var)?block_DASH_ids5342369.$var.app(b12478856):R.ffi.throwNonFunApp(L[1729],block_DASH_ids5342369.$var,[b12478856]);
};
try {
if(--R.GAS > 0) {
$z88598860 = $f88658866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88658866,
"from":L[1729]});
}
} catch($e88578858) {
if(R.isCont($e88578858)) {
var $ss88618862 = {"from":L[1729],
"go":function(ann_DASH_check_DASH_temp57088867) {
return $Hann_DASH_check_DASH_temp104518868(ann_DASH_check_DASH_temp57088867);
}};
$e88578858.stack[R.EXN_STACKHEIGHT++] = $ss88618862;
}
if(R.isPyretException($e88578858)) {
$e88578858.pyretStack.push(L[1729]);
}
throw $e88578858;
}
var $ret88638864 = $Hann_DASH_check_DASH_temp104518868($z88598860);
++R.GAS;
return $ret88638864;
});
var anf_arg57108835 = R.makeObject({"s-program":anf_obj57098851});
var anf_arg57128836 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1728],0,arguments);
}
var $z88418842 = D;
var $f88478848 = function(_) {
return R.isFunction(raise62)?raise62.app(("Non-program given to toplevel-ids")):R.ffi.throwNonFunApp(L[1728],raise62,[("Non-program given to toplevel-ids")]);
};
try {
if(--R.GAS > 0) {
$z88418842 = $f88478848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88478848,
"from":L[1728]});
}
} catch($e88398840) {
if(R.isCont($e88398840)) {
var $ss88438844 = {"from":L[1728],
"go":function(ann_DASH_check_DASH_temp57118849) {
return $Hann_DASH_check_DASH_temp104528850(ann_DASH_check_DASH_temp57118849);
}};
$e88398840.stack[R.EXN_STACKHEIGHT++] = $ss88438844;
}
if(R.isPyretException($e88398840)) {
$e88398840.pyretStack.push(L[1728]);
}
throw $e88398840;
}
var $ret88458846 = $Hann_DASH_check_DASH_temp104528850($z88418842);
++R.GAS;
return $ret88458846;
});
var $z88268827 = D;
var $f88328833 = function(_) {
return R.isFunction(anf_fun57078834)?anf_fun57078834.app(anf_arg57108835,anf_arg57128836):R.ffi.throwNonFunApp(L[1727],anf_fun57078834,[anf_arg57108835,anf_arg57128836]);
};
try {
if(--R.GAS > 0) {
$z88268827 = $f88328833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88328833,
"from":L[1727]});
}
} catch($e88248825) {
if(R.isCont($e88248825)) {
var $ss88288829 = {"from":L[1727],
"go":function(ann_DASH_check_DASH_temp57068837) {
return $Hann_DASH_check_DASH_temp104538838(ann_DASH_check_DASH_temp57068837,List17129,Name66133);
}};
$e88248825.stack[R.EXN_STACKHEIGHT++] = $ss88288829;
}
if(R.isPyretException($e88248825)) {
$e88248825.pyretStack.push(L[1727]);
}
throw $e88248825;
}
var $ret88308831 = $Hann_DASH_check_DASH_temp104538838($z88268827,List17129,Name66133);
++R.GAS;
return $ret88308831;
});
});
toplevel_DASH_ids5352371.$var = anf_assign57132372;
var anf_obj57256613 = R.makeMethod(function(self12498817) {
return function(opt12508822) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1721],1,arguments);
}
var cases_DASH_val7158821 = opt12508822;
var anf_fun57158797 = G(cases_DASH_val7158821,"_match",L[1722]);
var anf_obj57178803 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1726],0,arguments);
}
var ann_DASH_check_DASH_temp57168820 = none61155;
return ann_DASH_check_DASH_temp57168820;
});
var anf_obj57218804 = R.makeFunction(function(v12518805) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1723],1,arguments);
}
var anf_fun57198816 = G(v12518805,"visit",L[1725]);
var $z88088809 = D;
var $f88148815 = function(_) {
return R.isFunction(anf_fun57198816)?anf_fun57198816.app(self12498817):R.ffi.throwNonFunApp(L[1724],anf_fun57198816,[self12498817]);
};
try {
if(--R.GAS > 0) {
$z88088809 = $f88148815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88148815,
"from":L[1724]});
}
} catch($e88068807) {
if(R.isCont($e88068807)) {
var $ss88108811 = {"from":L[1724],
"go":function(anf_arg57208818) {
return $Hanf_arg104558819(anf_arg57208818,some62156);
}};
$e88068807.stack[R.EXN_STACKHEIGHT++] = $ss88108811;
}
if(R.isPyretException($e88068807)) {
$e88068807.pyretStack.push(L[1724]);
}
throw $e88068807;
}
var $ret88128813 = $Hanf_arg104558819($z88088809,some62156);
++R.GAS;
return $ret88128813;
});
var anf_arg57228798 = R.makeObject({"none":anf_obj57178803,
"some":anf_obj57218804});
var anf_arg57248799 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1722],0,arguments);
}
var ann_DASH_check_DASH_temp57238802 = R.throwNoBranchesMatched(L[1722],("cases"));
return ann_DASH_check_DASH_temp57238802;
});
var $z87898790 = D;
var $f87958796 = function(_) {
return R.isFunction(anf_fun57158797)?anf_fun57158797.app(anf_arg57228798,anf_arg57248799):R.ffi.throwNonFunApp(L[1721],anf_fun57158797,[anf_arg57228798,anf_arg57248799]);
};
try {
if(--R.GAS > 0) {
$z87898790 = $f87958796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87958796,
"from":L[1721]});
}
} catch($e87878788) {
if(R.isCont($e87878788)) {
var $ss87918792 = {"from":L[1721],
"go":function(ann_DASH_check_DASH_temp57148800) {
return $Hann_DASH_check_DASH_temp104568801(ann_DASH_check_DASH_temp57148800);
}};
$e87878788.stack[R.EXN_STACKHEIGHT++] = $ss87918792;
}
if(R.isPyretException($e87878788)) {
$e87878788.pyretStack.push(L[1721]);
}
throw $e87878788;
}
var $ret87938794 = $Hann_DASH_check_DASH_temp104568801($z87898790);
++R.GAS;
return $ret87938794;
};
},{"length":2});
var anf_obj57276614 = R.makeMethod(function(self12528786) {
return function(l12538783) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1720],1,arguments);
}
var $z87758776 = D;
var $f87818782 = function(_) {
return R.isFunction(s_DASH_underscore1881011.$var)?s_DASH_underscore1881011.$var.app(l12538783):R.ffi.throwNonFunApp(L[1720],s_DASH_underscore1881011.$var,[l12538783]);
};
try {
if(--R.GAS > 0) {
$z87758776 = $f87818782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87818782,
"from":L[1720]});
}
} catch($e87738774) {
if(R.isCont($e87738774)) {
var $ss87778778 = {"from":L[1720],
"go":function(ann_DASH_check_DASH_temp57268784) {
return $Hann_DASH_check_DASH_temp104578785(ann_DASH_check_DASH_temp57268784);
}};
$e87738774.stack[R.EXN_STACKHEIGHT++] = $ss87778778;
}
if(R.isPyretException($e87738774)) {
$e87738774.pyretStack.push(L[1720]);
}
throw $e87738774;
}
var $ret87798780 = $Hann_DASH_check_DASH_temp104578785($z87758776);
++R.GAS;
return $ret87798780;
};
},{"length":2});
var anf_obj57296615 = R.makeMethod(function(self12548772) {
return function(l12558768,s12568769) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1719],2,arguments);
}
var $z87608761 = D;
var $f87668767 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l12558768,s12568769):R.ffi.throwNonFunApp(L[1719],s_DASH_name1901015.$var,[l12558768,s12568769]);
};
try {
if(--R.GAS > 0) {
$z87608761 = $f87668767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87668767,
"from":L[1719]});
}
} catch($e87588759) {
if(R.isCont($e87588759)) {
var $ss87628763 = {"from":L[1719],
"go":function(ann_DASH_check_DASH_temp57288770) {
return $Hann_DASH_check_DASH_temp104588771(ann_DASH_check_DASH_temp57288770);
}};
$e87588759.stack[R.EXN_STACKHEIGHT++] = $ss87628763;
}
if(R.isPyretException($e87588759)) {
$e87588759.pyretStack.push(L[1719]);
}
throw $e87588759;
}
var $ret87648765 = $Hann_DASH_check_DASH_temp104588771($z87608761);
++R.GAS;
return $ret87648765;
};
},{"length":3});
var anf_obj57316616 = R.makeMethod(function(self12578757) {
return function(s12588754) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1718],1,arguments);
}
var $z87468747 = D;
var $f87528753 = function(_) {
return R.isFunction(s_DASH_type_DASH_global1941023.$var)?s_DASH_type_DASH_global1941023.$var.app(s12588754):R.ffi.throwNonFunApp(L[1718],s_DASH_type_DASH_global1941023.$var,[s12588754]);
};
try {
if(--R.GAS > 0) {
$z87468747 = $f87528753();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87528753,
"from":L[1718]});
}
} catch($e87448745) {
if(R.isCont($e87448745)) {
var $ss87488749 = {"from":L[1718],
"go":function(ann_DASH_check_DASH_temp57308755) {
return $Hann_DASH_check_DASH_temp104598756(ann_DASH_check_DASH_temp57308755);
}};
$e87448745.stack[R.EXN_STACKHEIGHT++] = $ss87488749;
}
if(R.isPyretException($e87448745)) {
$e87448745.pyretStack.push(L[1718]);
}
throw $e87448745;
}
var $ret87508751 = $Hann_DASH_check_DASH_temp104598756($z87468747);
++R.GAS;
return $ret87508751;
};
},{"length":2});
var anf_obj57336617 = R.makeMethod(function(self12598743) {
return function(s12608740) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1717],1,arguments);
}
var $z87328733 = D;
var $f87388739 = function(_) {
return R.isFunction(s_DASH_global1921019.$var)?s_DASH_global1921019.$var.app(s12608740):R.ffi.throwNonFunApp(L[1717],s_DASH_global1921019.$var,[s12608740]);
};
try {
if(--R.GAS > 0) {
$z87328733 = $f87388739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87388739,
"from":L[1717]});
}
} catch($e87308731) {
if(R.isCont($e87308731)) {
var $ss87348735 = {"from":L[1717],
"go":function(ann_DASH_check_DASH_temp57328741) {
return $Hann_DASH_check_DASH_temp104608742(ann_DASH_check_DASH_temp57328741);
}};
$e87308731.stack[R.EXN_STACKHEIGHT++] = $ss87348735;
}
if(R.isPyretException($e87308731)) {
$e87308731.pyretStack.push(L[1717]);
}
throw $e87308731;
}
var $ret87368737 = $Hann_DASH_check_DASH_temp104608742($z87328733);
++R.GAS;
return $ret87368737;
};
},{"length":2});
var anf_obj57356618 = R.makeMethod(function(self12618729) {
return function(base12628725,serial12638726) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1716],2,arguments);
}
var $z87178718 = D;
var $f87238724 = function(_) {
return R.isFunction(s_DASH_atom1961027.$var)?s_DASH_atom1961027.$var.app(base12628725,serial12638726):R.ffi.throwNonFunApp(L[1716],s_DASH_atom1961027.$var,[base12628725,serial12638726]);
};
try {
if(--R.GAS > 0) {
$z87178718 = $f87238724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87238724,
"from":L[1716]});
}
} catch($e87158716) {
if(R.isCont($e87158716)) {
var $ss87198720 = {"from":L[1716],
"go":function(ann_DASH_check_DASH_temp57348727) {
return $Hann_DASH_check_DASH_temp104618728(ann_DASH_check_DASH_temp57348727);
}};
$e87158716.stack[R.EXN_STACKHEIGHT++] = $ss87198720;
}
if(R.isPyretException($e87158716)) {
$e87158716.pyretStack.push(L[1716]);
}
throw $e87158716;
}
var $ret87218722 = $Hann_DASH_check_DASH_temp104618728($z87178718);
++R.GAS;
return $ret87218722;
};
},{"length":3});
var anf_obj57486619 = R.makeMethod(function(self12648707) {
return function(l12658710,answer12668714,provides12678711,types12688712,checks12698709) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1715],5,arguments);
}
var anf_fun57378706 = G(answer12668714,"visit",L[1714]);
var $z86988699 = D;
var $f87048705 = function(_) {
return R.isFunction(anf_fun57378706)?anf_fun57378706.app(self12648707):R.ffi.throwNonFunApp(L[1713],anf_fun57378706,[self12648707]);
};
try {
if(--R.GAS > 0) {
$z86988699 = $f87048705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87048705,
"from":L[1713]});
}
} catch($e86968697) {
if(R.isCont($e86968697)) {
var $ss87008701 = {"from":L[1713],
"go":function(anf_arg57388708) {
return $Hanf_arg104678713(anf_arg57388708,checks12698709,l12658710,lists974,provides12678711,s_DASH_module3181937,self12648707,types12688712);
}};
$e86968697.stack[R.EXN_STACKHEIGHT++] = $ss87008701;
}
if(R.isPyretException($e86968697)) {
$e86968697.pyretStack.push(L[1713]);
}
throw $e86968697;
}
var $ret87028703 = $Hanf_arg104678713($z86988699,checks12698709,l12658710,lists974,provides12678711,s_DASH_module3181937,self12648707,types12688712);
++R.GAS;
return $ret87028703;
};
},{"length":6});
var anf_obj57616620 = R.makeMethod(function(self12708688) {
return function(l12718692,_provide12728695,provided_DASH_types12738693,imports12748691,body12758690) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1712],5,arguments);
}
var anf_fun57508687 = G(_provide12728695,"visit",L[1711]);
var $z86798680 = D;
var $f86858686 = function(_) {
return R.isFunction(anf_fun57508687)?anf_fun57508687.app(self12708688):R.ffi.throwNonFunApp(L[1710],anf_fun57508687,[self12708688]);
};
try {
if(--R.GAS > 0) {
$z86798680 = $f86858686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86858686,
"from":L[1710]});
}
} catch($e86778678) {
if(R.isCont($e86778678)) {
var $ss86818682 = {"from":L[1710],
"go":function(anf_arg57518689) {
return $Hanf_arg104738694(anf_arg57518689,body12758690,imports12748691,l12718692,provided_DASH_types12738693,s_DASH_program2551811,self12708688);
}};
$e86778678.stack[R.EXN_STACKHEIGHT++] = $ss86818682;
}
if(R.isPyretException($e86778678)) {
$e86778678.pyretStack.push(L[1710]);
}
throw $e86778678;
}
var $ret86838684 = $Hanf_arg104738694($z86798680,body12758690,imports12748691,l12718692,provided_DASH_types12738693,s_DASH_program2551811,self12708688);
++R.GAS;
return $ret86838684;
};
},{"length":6});
var anf_obj57676621 = R.makeMethod(function(self12768671) {
return function(l12778673,import_DASH_type12788676,name12798674) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1709],3,arguments);
}
var anf_fun57638670 = G(import_DASH_type12788676,"visit",L[1708]);
var $z86628663 = D;
var $f86688669 = function(_) {
return R.isFunction(anf_fun57638670)?anf_fun57638670.app(self12768671):R.ffi.throwNonFunApp(L[1707],anf_fun57638670,[self12768671]);
};
try {
if(--R.GAS > 0) {
$z86628663 = $f86688669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86688669,
"from":L[1707]});
}
} catch($e86608661) {
if(R.isCont($e86608661)) {
var $ss86648665 = {"from":L[1707],
"go":function(anf_arg57648672) {
return $Hanf_arg104768675(anf_arg57648672,l12778673,name12798674,s_DASH_import2601821,self12768671);
}};
$e86608661.stack[R.EXN_STACKHEIGHT++] = $ss86648665;
}
if(R.isPyretException($e86608661)) {
$e86608661.pyretStack.push(L[1707]);
}
throw $e86608661;
}
var $ret86668667 = $Hanf_arg104768675($z86628663,l12778673,name12798674,s_DASH_import2601821,self12768671);
++R.GAS;
return $ret86668667;
};
},{"length":4});
var anf_obj57696622 = R.makeMethod(function(self12808659) {
return function(l12818655,file12828656) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1706],2,arguments);
}
var $z86478648 = D;
var $f86538654 = function(_) {
return R.isFunction(s_DASH_file_DASH_import2871875.$var)?s_DASH_file_DASH_import2871875.$var.app(l12818655,file12828656):R.ffi.throwNonFunApp(L[1706],s_DASH_file_DASH_import2871875.$var,[l12818655,file12828656]);
};
try {
if(--R.GAS > 0) {
$z86478648 = $f86538654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86538654,
"from":L[1706]});
}
} catch($e86458646) {
if(R.isCont($e86458646)) {
var $ss86498650 = {"from":L[1706],
"go":function(ann_DASH_check_DASH_temp57688657) {
return $Hann_DASH_check_DASH_temp104778658(ann_DASH_check_DASH_temp57688657);
}};
$e86458646.stack[R.EXN_STACKHEIGHT++] = $ss86498650;
}
if(R.isPyretException($e86458646)) {
$e86458646.pyretStack.push(L[1706]);
}
throw $e86458646;
}
var $ret86518652 = $Hann_DASH_check_DASH_temp104778658($z86478648);
++R.GAS;
return $ret86518652;
};
},{"length":3});
var anf_obj57716623 = R.makeMethod(function(self12838644) {
return function(l12848640,mod12858641) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1705],2,arguments);
}
var $z86328633 = D;
var $f86388639 = function(_) {
return R.isFunction(s_DASH_const_DASH_import2891879.$var)?s_DASH_const_DASH_import2891879.$var.app(l12848640,mod12858641):R.ffi.throwNonFunApp(L[1705],s_DASH_const_DASH_import2891879.$var,[l12848640,mod12858641]);
};
try {
if(--R.GAS > 0) {
$z86328633 = $f86388639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86388639,
"from":L[1705]});
}
} catch($e86308631) {
if(R.isCont($e86308631)) {
var $ss86348635 = {"from":L[1705],
"go":function(ann_DASH_check_DASH_temp57708642) {
return $Hann_DASH_check_DASH_temp104788643(ann_DASH_check_DASH_temp57708642);
}};
$e86308631.stack[R.EXN_STACKHEIGHT++] = $ss86348635;
}
if(R.isPyretException($e86308631)) {
$e86308631.pyretStack.push(L[1705]);
}
throw $e86308631;
}
var $ret86368637 = $Hann_DASH_check_DASH_temp104788643($z86328633);
++R.GAS;
return $ret86368637;
};
},{"length":3});
var anf_obj57776624 = R.makeMethod(function(self12868623) {
return function(l12878626,import_DASH_type12888625,name12898629,types12908627) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1704],4,arguments);
}
var anf_fun57738622 = G(name12898629,"visit",L[1703]);
var $z86148615 = D;
var $f86208621 = function(_) {
return R.isFunction(anf_fun57738622)?anf_fun57738622.app(self12868623):R.ffi.throwNonFunApp(L[1702],anf_fun57738622,[self12868623]);
};
try {
if(--R.GAS > 0) {
$z86148615 = $f86208621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86208621,
"from":L[1702]});
}
} catch($e86128613) {
if(R.isCont($e86128613)) {
var $ss86168617 = {"from":L[1702],
"go":function(anf_arg57748624) {
return $Hanf_arg104818628(anf_arg57748624,import_DASH_type12888625,l12878626,s_DASH_import_DASH_types2621825,self12868623,types12908627);
}};
$e86128613.stack[R.EXN_STACKHEIGHT++] = $ss86168617;
}
if(R.isPyretException($e86128613)) {
$e86128613.pyretStack.push(L[1702]);
}
throw $e86128613;
}
var $ret86188619 = $Hanf_arg104818628($z86148615,import_DASH_type12888625,l12878626,s_DASH_import_DASH_types2621825,self12868623,types12908627);
++R.GAS;
return $ret86188619;
};
},{"length":5});
var anf_obj57846625 = R.makeMethod(function(self12918608) {
return function(l12928594,fields12938611,import_DASH_type12948593) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1701],3,arguments);
}
var anf_fun57798590 = G(fields12938611,"map",L[1700]);
var anf_arg57828591 = R.makeFunction(function(recv_DASH_7188596) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1699],1,arguments);
}
var anf_fun57818607 = G(recv_DASH_7188596,"visit",L[1699]);
var $z85998600 = D;
var $f86058606 = function(_) {
return R.isFunction(anf_fun57818607)?anf_fun57818607.app(self12918608):R.ffi.throwNonFunApp(L[1699],anf_fun57818607,[self12918608]);
};
try {
if(--R.GAS > 0) {
$z85998600 = $f86058606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86058606,
"from":L[1699]});
}
} catch($e85978598) {
if(R.isCont($e85978598)) {
var $ss86018602 = {"from":L[1699],
"go":function(ann_DASH_check_DASH_temp57808609) {
return $Hann_DASH_check_DASH_temp104828610(ann_DASH_check_DASH_temp57808609);
}};
$e85978598.stack[R.EXN_STACKHEIGHT++] = $ss86018602;
}
if(R.isPyretException($e85978598)) {
$e85978598.pyretStack.push(L[1699]);
}
throw $e85978598;
}
var $ret86038604 = $Hann_DASH_check_DASH_temp104828610($z85998600);
++R.GAS;
return $ret86038604;
});
var $z85828583 = D;
var $f85888589 = function(_) {
return R.isFunction(anf_fun57798590)?anf_fun57798590.app(anf_arg57828591):R.ffi.throwNonFunApp(L[1698],anf_fun57798590,[anf_arg57828591]);
};
try {
if(--R.GAS > 0) {
$z85828583 = $f85888589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85888589,
"from":L[1698]});
}
} catch($e85808581) {
if(R.isCont($e85808581)) {
var $ss85848585 = {"from":L[1698],
"go":function(anf_arg57838592) {
return $Hanf_arg104848595(anf_arg57838592,import_DASH_type12948593,l12928594,s_DASH_import_DASH_fields2641829);
}};
$e85808581.stack[R.EXN_STACKHEIGHT++] = $ss85848585;
}
if(R.isPyretException($e85808581)) {
$e85808581.pyretStack.push(L[1698]);
}
throw $e85808581;
}
var $ret85868587 = $Hanf_arg104848595($z85828583,import_DASH_type12948593,l12928594,s_DASH_import_DASH_fields2641829);
++R.GAS;
return $ret85868587;
};
},{"length":4});
var anf_obj57886626 = R.makeMethod(function(self12958575) {
return function(l12968577,expr12978579) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1697],2,arguments);
}
var anf_fun57868574 = G(expr12978579,"visit",L[1696]);
var $z85668567 = D;
var $f85728573 = function(_) {
return R.isFunction(anf_fun57868574)?anf_fun57868574.app(self12958575):R.ffi.throwNonFunApp(L[1695],anf_fun57868574,[self12958575]);
};
try {
if(--R.GAS > 0) {
$z85668567 = $f85728573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85728573,
"from":L[1695]});
}
} catch($e85648565) {
if(R.isCont($e85648565)) {
var $ss85688569 = {"from":L[1695],
"go":function(anf_arg57878576) {
return $Hanf_arg104868578(anf_arg57878576,l12968577,s_DASH_provide2691839);
}};
$e85648565.stack[R.EXN_STACKHEIGHT++] = $ss85688569;
}
if(R.isPyretException($e85648565)) {
$e85648565.pyretStack.push(L[1695]);
}
throw $e85648565;
}
var $ret85708571 = $Hanf_arg104868578($z85668567,l12968577,s_DASH_provide2691839);
++R.GAS;
return $ret85708571;
};
},{"length":3});
var anf_obj57906627 = R.makeMethod(function(self12988563) {
return function(l12998560) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1694],1,arguments);
}
var $z85528553 = D;
var $f85588559 = function(_) {
return R.isFunction(s_DASH_provide_DASH_all2711843.$var)?s_DASH_provide_DASH_all2711843.$var.app(l12998560):R.ffi.throwNonFunApp(L[1694],s_DASH_provide_DASH_all2711843.$var,[l12998560]);
};
try {
if(--R.GAS > 0) {
$z85528553 = $f85588559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85588559,
"from":L[1694]});
}
} catch($e85508551) {
if(R.isCont($e85508551)) {
var $ss85548555 = {"from":L[1694],
"go":function(ann_DASH_check_DASH_temp57898561) {
return $Hann_DASH_check_DASH_temp104878562(ann_DASH_check_DASH_temp57898561);
}};
$e85508551.stack[R.EXN_STACKHEIGHT++] = $ss85548555;
}
if(R.isPyretException($e85508551)) {
$e85508551.pyretStack.push(L[1694]);
}
throw $e85508551;
}
var $ret85568557 = $Hann_DASH_check_DASH_temp104878562($z85528553);
++R.GAS;
return $ret85568557;
};
},{"length":2});
var anf_obj57926628 = R.makeMethod(function(self13008549) {
return function(l13018546) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1693],1,arguments);
}
var $z85388539 = D;
var $f85448545 = function(_) {
return R.isFunction(s_DASH_provide_DASH_none2731847.$var)?s_DASH_provide_DASH_none2731847.$var.app(l13018546):R.ffi.throwNonFunApp(L[1693],s_DASH_provide_DASH_none2731847.$var,[l13018546]);
};
try {
if(--R.GAS > 0) {
$z85388539 = $f85448545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85448545,
"from":L[1693]});
}
} catch($e85368537) {
if(R.isCont($e85368537)) {
var $ss85408541 = {"from":L[1693],
"go":function(ann_DASH_check_DASH_temp57918547) {
return $Hann_DASH_check_DASH_temp104888548(ann_DASH_check_DASH_temp57918547);
}};
$e85368537.stack[R.EXN_STACKHEIGHT++] = $ss85408541;
}
if(R.isPyretException($e85368537)) {
$e85368537.pyretStack.push(L[1693]);
}
throw $e85368537;
}
var $ret85428543 = $Hann_DASH_check_DASH_temp104888548($z85388539);
++R.GAS;
return $ret85428543;
};
},{"length":2});
var anf_obj57996629 = R.makeMethod(function(self13028532) {
return function(l13038518,anns13048535) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1692],2,arguments);
}
var anf_fun57948515 = G(anns13048535,"map",L[1691]);
var anf_arg57978516 = R.makeFunction(function(recv_DASH_7198520) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1690],1,arguments);
}
var anf_fun57968531 = G(recv_DASH_7198520,"visit",L[1690]);
var $z85238524 = D;
var $f85298530 = function(_) {
return R.isFunction(anf_fun57968531)?anf_fun57968531.app(self13028532):R.ffi.throwNonFunApp(L[1690],anf_fun57968531,[self13028532]);
};
try {
if(--R.GAS > 0) {
$z85238524 = $f85298530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85298530,
"from":L[1690]});
}
} catch($e85218522) {
if(R.isCont($e85218522)) {
var $ss85258526 = {"from":L[1690],
"go":function(ann_DASH_check_DASH_temp57958533) {
return $Hann_DASH_check_DASH_temp104898534(ann_DASH_check_DASH_temp57958533);
}};
$e85218522.stack[R.EXN_STACKHEIGHT++] = $ss85258526;
}
if(R.isPyretException($e85218522)) {
$e85218522.pyretStack.push(L[1690]);
}
throw $e85218522;
}
var $ret85278528 = $Hann_DASH_check_DASH_temp104898534($z85238524);
++R.GAS;
return $ret85278528;
});
var $z85078508 = D;
var $f85138514 = function(_) {
return R.isFunction(anf_fun57948515)?anf_fun57948515.app(anf_arg57978516):R.ffi.throwNonFunApp(L[1689],anf_fun57948515,[anf_arg57978516]);
};
try {
if(--R.GAS > 0) {
$z85078508 = $f85138514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85138514,
"from":L[1689]});
}
} catch($e85058506) {
if(R.isCont($e85058506)) {
var $ss85098510 = {"from":L[1689],
"go":function(anf_arg57988517) {
return $Hanf_arg104918519(anf_arg57988517,l13038518,s_DASH_provide_DASH_types2781857);
}};
$e85058506.stack[R.EXN_STACKHEIGHT++] = $ss85098510;
}
if(R.isPyretException($e85058506)) {
$e85058506.pyretStack.push(L[1689]);
}
throw $e85058506;
}
var $ret85118512 = $Hanf_arg104918519($z85078508,l13038518,s_DASH_provide_DASH_types2781857);
++R.GAS;
return $ret85118512;
};
},{"length":3});
var anf_obj58016630 = R.makeMethod(function(self13058504) {
return function(l13068501) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1688],1,arguments);
}
var $z84938494 = D;
var $f84998500 = function(_) {
return R.isFunction(s_DASH_provide_DASH_types_DASH_all2801861.$var)?s_DASH_provide_DASH_types_DASH_all2801861.$var.app(l13068501):R.ffi.throwNonFunApp(L[1688],s_DASH_provide_DASH_types_DASH_all2801861.$var,[l13068501]);
};
try {
if(--R.GAS > 0) {
$z84938494 = $f84998500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84998500,
"from":L[1688]});
}
} catch($e84918492) {
if(R.isCont($e84918492)) {
var $ss84958496 = {"from":L[1688],
"go":function(ann_DASH_check_DASH_temp58008502) {
return $Hann_DASH_check_DASH_temp104928503(ann_DASH_check_DASH_temp58008502);
}};
$e84918492.stack[R.EXN_STACKHEIGHT++] = $ss84958496;
}
if(R.isPyretException($e84918492)) {
$e84918492.pyretStack.push(L[1688]);
}
throw $e84918492;
}
var $ret84978498 = $Hann_DASH_check_DASH_temp104928503($z84938494);
++R.GAS;
return $ret84978498;
};
},{"length":2});
var anf_obj58036631 = R.makeMethod(function(self13078490) {
return function(l13088487) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1687],1,arguments);
}
var $z84798480 = D;
var $f84858486 = function(_) {
return R.isFunction(s_DASH_provide_DASH_types_DASH_none2821865.$var)?s_DASH_provide_DASH_types_DASH_none2821865.$var.app(l13088487):R.ffi.throwNonFunApp(L[1687],s_DASH_provide_DASH_types_DASH_none2821865.$var,[l13088487]);
};
try {
if(--R.GAS > 0) {
$z84798480 = $f84858486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84858486,
"from":L[1687]});
}
} catch($e84778478) {
if(R.isCont($e84778478)) {
var $ss84818482 = {"from":L[1687],
"go":function(ann_DASH_check_DASH_temp58028488) {
return $Hann_DASH_check_DASH_temp104938489(ann_DASH_check_DASH_temp58028488);
}};
$e84778478.stack[R.EXN_STACKHEIGHT++] = $ss84818482;
}
if(R.isPyretException($e84778478)) {
$e84778478.pyretStack.push(L[1687]);
}
throw $e84778478;
}
var $ret84838484 = $Hann_DASH_check_DASH_temp104938489($z84798480);
++R.GAS;
return $ret84838484;
};
},{"length":2});
var anf_obj58096632 = R.makeMethod(function(self13098470) {
return function(l13108473,shadows13118474,name13128476,ann13138472) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1686],4,arguments);
}
var anf_fun58058469 = G(name13128476,"visit",L[1685]);
var $z84618462 = D;
var $f84678468 = function(_) {
return R.isFunction(anf_fun58058469)?anf_fun58058469.app(self13098470):R.ffi.throwNonFunApp(L[1684],anf_fun58058469,[self13098470]);
};
try {
if(--R.GAS > 0) {
$z84618462 = $f84678468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84678468,
"from":L[1684]});
}
} catch($e84598460) {
if(R.isCont($e84598460)) {
var $ss84638464 = {"from":L[1684],
"go":function(anf_arg58068471) {
return $Hanf_arg104968475(anf_arg58068471,ann13138472,l13108473,s_DASH_bind4382177,self13098470,shadows13118474);
}};
$e84598460.stack[R.EXN_STACKHEIGHT++] = $ss84638464;
}
if(R.isPyretException($e84598460)) {
$e84598460.pyretStack.push(L[1684]);
}
throw $e84598460;
}
var $ret84658466 = $Hanf_arg104968475($z84618462,ann13138472,l13108473,s_DASH_bind4382177,self13098470,shadows13118474);
++R.GAS;
return $ret84658466;
};
},{"length":5});
var anf_obj58156633 = R.makeMethod(function(self13148453) {
return function(l13158456,bind13168458,expr13178455) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1683],3,arguments);
}
var anf_fun58118452 = G(bind13168458,"visit",L[1682]);
var $z84448445 = D;
var $f84508451 = function(_) {
return R.isFunction(anf_fun58118452)?anf_fun58118452.app(self13148453):R.ffi.throwNonFunApp(L[1681],anf_fun58118452,[self13148453]);
};
try {
if(--R.GAS > 0) {
$z84448445 = $f84508451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84508451,
"from":L[1681]});
}
} catch($e84428443) {
if(R.isCont($e84428443)) {
var $ss84468447 = {"from":L[1681],
"go":function(anf_arg58128454) {
return $Hanf_arg104998457(anf_arg58128454,expr13178455,l13158456,s_DASH_var_DASH_bind3011903,self13148453);
}};
$e84428443.stack[R.EXN_STACKHEIGHT++] = $ss84468447;
}
if(R.isPyretException($e84428443)) {
$e84428443.pyretStack.push(L[1681]);
}
throw $e84428443;
}
var $ret84488449 = $Hanf_arg104998457($z84448445,expr13178455,l13158456,s_DASH_var_DASH_bind3011903,self13148453);
++R.GAS;
return $ret84488449;
};
},{"length":4});
var anf_obj58216634 = R.makeMethod(function(self13188436) {
return function(l13198439,bind13208441,expr13218438) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1680],3,arguments);
}
var anf_fun58178435 = G(bind13208441,"visit",L[1679]);
var $z84278428 = D;
var $f84338434 = function(_) {
return R.isFunction(anf_fun58178435)?anf_fun58178435.app(self13188436):R.ffi.throwNonFunApp(L[1678],anf_fun58178435,[self13188436]);
};
try {
if(--R.GAS > 0) {
$z84278428 = $f84338434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84338434,
"from":L[1678]});
}
} catch($e84258426) {
if(R.isCont($e84258426)) {
var $ss84298430 = {"from":L[1678],
"go":function(anf_arg58188437) {
return $Hanf_arg105028440(anf_arg58188437,expr13218438,l13198439,s_DASH_let_DASH_bind2991899,self13188436);
}};
$e84258426.stack[R.EXN_STACKHEIGHT++] = $ss84298430;
}
if(R.isPyretException($e84258426)) {
$e84258426.pyretStack.push(L[1678]);
}
throw $e84258426;
}
var $ret84318432 = $Hanf_arg105028440($z84278428,expr13218438,l13198439,s_DASH_let_DASH_bind2991899,self13188436);
++R.GAS;
return $ret84318432;
};
},{"length":4});
var anf_obj58276635 = R.makeMethod(function(self13228419) {
return function(l13238422,name13248424,ann13258421) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1677],3,arguments);
}
var anf_fun58238418 = G(name13248424,"visit",L[1676]);
var $z84108411 = D;
var $f84168417 = function(_) {
return R.isFunction(anf_fun58238418)?anf_fun58238418.app(self13228419):R.ffi.throwNonFunApp(L[1675],anf_fun58238418,[self13228419]);
};
try {
if(--R.GAS > 0) {
$z84108411 = $f84168417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84168417,
"from":L[1675]});
}
} catch($e84088409) {
if(R.isCont($e84088409)) {
var $ss84128413 = {"from":L[1675],
"go":function(anf_arg58248420) {
return $Hanf_arg105058423(anf_arg58248420,ann13258421,l13238422,s_DASH_type_DASH_bind3111923,self13228419);
}};
$e84088409.stack[R.EXN_STACKHEIGHT++] = $ss84128413;
}
if(R.isPyretException($e84088409)) {
$e84088409.pyretStack.push(L[1675]);
}
throw $e84088409;
}
var $ret84148415 = $Hanf_arg105058423($z84108411,ann13258421,l13238422,s_DASH_type_DASH_bind3111923,self13228419);
++R.GAS;
return $ret84148415;
};
},{"length":4});
var anf_obj58336636 = R.makeMethod(function(self13268402) {
return function(l13278404,name13288407,namet13298405) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1674],3,arguments);
}
var anf_fun58298401 = G(name13288407,"visit",L[1673]);
var $z83938394 = D;
var $f83998400 = function(_) {
return R.isFunction(anf_fun58298401)?anf_fun58298401.app(self13268402):R.ffi.throwNonFunApp(L[1672],anf_fun58298401,[self13268402]);
};
try {
if(--R.GAS > 0) {
$z83938394 = $f83998400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83998400,
"from":L[1672]});
}
} catch($e83918392) {
if(R.isCont($e83918392)) {
var $ss83958396 = {"from":L[1672],
"go":function(anf_arg58308403) {
return $Hanf_arg105088406(anf_arg58308403,l13278404,namet13298405,s_DASH_newtype_DASH_bind3131927,self13268402);
}};
$e83918392.stack[R.EXN_STACKHEIGHT++] = $ss83958396;
}
if(R.isPyretException($e83918392)) {
$e83918392.pyretStack.push(L[1672]);
}
throw $e83918392;
}
var $ret83978398 = $Hanf_arg105088406($z83938394,l13278404,namet13298405,s_DASH_newtype_DASH_bind3131927,self13268402);
++R.GAS;
return $ret83978398;
};
},{"length":4});
var anf_obj58426637 = R.makeMethod(function(self13308374) {
return function(l13318373,binds13328390,body13338372) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1671],3,arguments);
}
var anf_fun58358369 = G(binds13328390,"map",L[1670]);
var anf_arg58388370 = R.makeFunction(function(recv_DASH_7208376) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1669],1,arguments);
}
var anf_fun58378387 = G(recv_DASH_7208376,"visit",L[1669]);
var $z83798380 = D;
var $f83858386 = function(_) {
return R.isFunction(anf_fun58378387)?anf_fun58378387.app(self13308374):R.ffi.throwNonFunApp(L[1669],anf_fun58378387,[self13308374]);
};
try {
if(--R.GAS > 0) {
$z83798380 = $f83858386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83858386,
"from":L[1669]});
}
} catch($e83778378) {
if(R.isCont($e83778378)) {
var $ss83818382 = {"from":L[1669],
"go":function(ann_DASH_check_DASH_temp58368388) {
return $Hann_DASH_check_DASH_temp105098389(ann_DASH_check_DASH_temp58368388);
}};
$e83778378.stack[R.EXN_STACKHEIGHT++] = $ss83818382;
}
if(R.isPyretException($e83778378)) {
$e83778378.pyretStack.push(L[1669]);
}
throw $e83778378;
}
var $ret83838384 = $Hann_DASH_check_DASH_temp105098389($z83798380);
++R.GAS;
return $ret83838384;
});
var $z83618362 = D;
var $f83678368 = function(_) {
return R.isFunction(anf_fun58358369)?anf_fun58358369.app(anf_arg58388370):R.ffi.throwNonFunApp(L[1668],anf_fun58358369,[anf_arg58388370]);
};
try {
if(--R.GAS > 0) {
$z83618362 = $f83678368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83678368,
"from":L[1668]});
}
} catch($e83598360) {
if(R.isCont($e83598360)) {
var $ss83638364 = {"from":L[1668],
"go":function(anf_arg58398371) {
return $Hanf_arg105128375(anf_arg58398371,body13338372,l13318373,s_DASH_type_DASH_let_DASH_expr3201941,self13308374);
}};
$e83598360.stack[R.EXN_STACKHEIGHT++] = $ss83638364;
}
if(R.isPyretException($e83598360)) {
$e83598360.pyretStack.push(L[1668]);
}
throw $e83598360;
}
var $ret83658366 = $Hanf_arg105128375($z83618362,body13338372,l13318373,s_DASH_type_DASH_let_DASH_expr3201941,self13308374);
++R.GAS;
return $ret83658366;
};
},{"length":4});
var anf_obj58516638 = R.makeMethod(function(self13348342) {
return function(l13358341,binds13368358,body13378340) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1667],3,arguments);
}
var anf_fun58448337 = G(binds13368358,"map",L[1666]);
var anf_arg58478338 = R.makeFunction(function(recv_DASH_7218344) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1665],1,arguments);
}
var anf_fun58468355 = G(recv_DASH_7218344,"visit",L[1665]);
var $z83478348 = D;
var $f83538354 = function(_) {
return R.isFunction(anf_fun58468355)?anf_fun58468355.app(self13348342):R.ffi.throwNonFunApp(L[1665],anf_fun58468355,[self13348342]);
};
try {
if(--R.GAS > 0) {
$z83478348 = $f83538354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83538354,
"from":L[1665]});
}
} catch($e83458346) {
if(R.isCont($e83458346)) {
var $ss83498350 = {"from":L[1665],
"go":function(ann_DASH_check_DASH_temp58458356) {
return $Hann_DASH_check_DASH_temp105138357(ann_DASH_check_DASH_temp58458356);
}};
$e83458346.stack[R.EXN_STACKHEIGHT++] = $ss83498350;
}
if(R.isPyretException($e83458346)) {
$e83458346.pyretStack.push(L[1665]);
}
throw $e83458346;
}
var $ret83518352 = $Hann_DASH_check_DASH_temp105138357($z83478348);
++R.GAS;
return $ret83518352;
});
var $z83298330 = D;
var $f83358336 = function(_) {
return R.isFunction(anf_fun58448337)?anf_fun58448337.app(anf_arg58478338):R.ffi.throwNonFunApp(L[1664],anf_fun58448337,[anf_arg58478338]);
};
try {
if(--R.GAS > 0) {
$z83298330 = $f83358336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83358336,
"from":L[1664]});
}
} catch($e83278328) {
if(R.isCont($e83278328)) {
var $ss83318332 = {"from":L[1664],
"go":function(anf_arg58488339) {
return $Hanf_arg105168343(anf_arg58488339,body13378340,l13358341,s_DASH_let_DASH_expr3221945,self13348342);
}};
$e83278328.stack[R.EXN_STACKHEIGHT++] = $ss83318332;
}
if(R.isPyretException($e83278328)) {
$e83278328.pyretStack.push(L[1664]);
}
throw $e83278328;
}
var $ret83338334 = $Hanf_arg105168343($z83298330,body13378340,l13358341,s_DASH_let_DASH_expr3221945,self13348342);
++R.GAS;
return $ret83338334;
};
},{"length":4});
var anf_obj58576639 = R.makeMethod(function(self13388321) {
return function(l13398324,bind13408326,expr13418323) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1663],3,arguments);
}
var anf_fun58538320 = G(bind13408326,"visit",L[1662]);
var $z83128313 = D;
var $f83188319 = function(_) {
return R.isFunction(anf_fun58538320)?anf_fun58538320.app(self13388321):R.ffi.throwNonFunApp(L[1661],anf_fun58538320,[self13388321]);
};
try {
if(--R.GAS > 0) {
$z83128313 = $f83188319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83188319,
"from":L[1661]});
}
} catch($e83108311) {
if(R.isCont($e83108311)) {
var $ss83148315 = {"from":L[1661],
"go":function(anf_arg58548322) {
return $Hanf_arg105198325(anf_arg58548322,expr13418323,l13398324,s_DASH_letrec_DASH_bind3061913,self13388321);
}};
$e83108311.stack[R.EXN_STACKHEIGHT++] = $ss83148315;
}
if(R.isPyretException($e83108311)) {
$e83108311.pyretStack.push(L[1661]);
}
throw $e83108311;
}
var $ret83168317 = $Hanf_arg105198325($z83128313,expr13418323,l13398324,s_DASH_letrec_DASH_bind3061913,self13388321);
++R.GAS;
return $ret83168317;
};
},{"length":4});
var anf_obj58666640 = R.makeMethod(function(self13428293) {
return function(l13438292,binds13448309,body13458291) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1660],3,arguments);
}
var anf_fun58598288 = G(binds13448309,"map",L[1659]);
var anf_arg58628289 = R.makeFunction(function(recv_DASH_7228295) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1658],1,arguments);
}
var anf_fun58618306 = G(recv_DASH_7228295,"visit",L[1658]);
var $z82988299 = D;
var $f83048305 = function(_) {
return R.isFunction(anf_fun58618306)?anf_fun58618306.app(self13428293):R.ffi.throwNonFunApp(L[1658],anf_fun58618306,[self13428293]);
};
try {
if(--R.GAS > 0) {
$z82988299 = $f83048305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83048305,
"from":L[1658]});
}
} catch($e82968297) {
if(R.isCont($e82968297)) {
var $ss83008301 = {"from":L[1658],
"go":function(ann_DASH_check_DASH_temp58608307) {
return $Hann_DASH_check_DASH_temp105208308(ann_DASH_check_DASH_temp58608307);
}};
$e82968297.stack[R.EXN_STACKHEIGHT++] = $ss83008301;
}
if(R.isPyretException($e82968297)) {
$e82968297.pyretStack.push(L[1658]);
}
throw $e82968297;
}
var $ret83028303 = $Hann_DASH_check_DASH_temp105208308($z82988299);
++R.GAS;
return $ret83028303;
});
var $z82808281 = D;
var $f82868287 = function(_) {
return R.isFunction(anf_fun58598288)?anf_fun58598288.app(anf_arg58628289):R.ffi.throwNonFunApp(L[1657],anf_fun58598288,[anf_arg58628289]);
};
try {
if(--R.GAS > 0) {
$z82808281 = $f82868287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82868287,
"from":L[1657]});
}
} catch($e82788279) {
if(R.isCont($e82788279)) {
var $ss82828283 = {"from":L[1657],
"go":function(anf_arg58638290) {
return $Hanf_arg105238294(anf_arg58638290,body13458291,l13438292,s_DASH_letrec3241949,self13428293);
}};
$e82788279.stack[R.EXN_STACKHEIGHT++] = $ss82828283;
}
if(R.isPyretException($e82788279)) {
$e82788279.pyretStack.push(L[1657]);
}
throw $e82788279;
}
var $ret82848285 = $Hanf_arg105238294($z82808281,body13458291,l13438292,s_DASH_letrec3241949,self13428293);
++R.GAS;
return $ret82848285;
};
},{"length":4});
var anf_obj58706641 = R.makeMethod(function(self13468272) {
return function(l13478275,hints13488274,exp13498277) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1656],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l13478275,hints13488274,exp13498277],[L[1653],L[1654],L[1655]],function() {
var anf_fun58688271 = G(exp13498277,"visit",L[1652]);
var $z82638264 = D;
var $f82698270 = function(_) {
return R.isFunction(anf_fun58688271)?anf_fun58688271.app(self13468272):R.ffi.throwNonFunApp(L[1651],anf_fun58688271,[self13468272]);
};
try {
if(--R.GAS > 0) {
$z82638264 = $f82698270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82698270,
"from":L[1651]});
}
} catch($e82618262) {
if(R.isCont($e82618262)) {
var $ss82658266 = {"from":L[1651],
"go":function(anf_arg58698273) {
return $Hanf_arg105258276(anf_arg58698273,hints13488274,l13478275,s_DASH_hint_DASH_exp3261953);
}};
$e82618262.stack[R.EXN_STACKHEIGHT++] = $ss82658266;
}
if(R.isPyretException($e82618262)) {
$e82618262.pyretStack.push(L[1651]);
}
throw $e82618262;
}
var $ret82678268 = $Hanf_arg105258276($z82638264,hints13488274,l13478275,s_DASH_hint_DASH_exp3261953);
++R.GAS;
return $ret82678268;
});
};
},{"length":4});
var anf_obj58796642 = R.makeMethod(function(self13508255) {
return function(l13518257,expr13528260,params13538258) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1650],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l13518257,expr13528260,params13538258],[L[1647],L[1648],L[1649]],function() {
var anf_fun58728254 = G(expr13528260,"visit",L[1646]);
var $z82468247 = D;
var $f82528253 = function(_) {
return R.isFunction(anf_fun58728254)?anf_fun58728254.app(self13508255):R.ffi.throwNonFunApp(L[1645],anf_fun58728254,[self13508255]);
};
try {
if(--R.GAS > 0) {
$z82468247 = $f82528253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82528253,
"from":L[1645]});
}
} catch($e82448245) {
if(R.isCont($e82448245)) {
var $ss82488249 = {"from":L[1645],
"go":function(anf_arg58738256) {
return $Hanf_arg105298259(anf_arg58738256,l13518257,params13538258,s_DASH_instantiate3281957,self13508255);
}};
$e82448245.stack[R.EXN_STACKHEIGHT++] = $ss82488249;
}
if(R.isPyretException($e82448245)) {
$e82448245.pyretStack.push(L[1645]);
}
throw $e82448245;
}
var $ret82508251 = $Hanf_arg105298259($z82468247,l13518257,params13538258,s_DASH_instantiate3281957,self13508255);
++R.GAS;
return $ret82508251;
});
};
},{"length":4});
var anf_obj58866643 = R.makeMethod(function(self13548240) {
return function(l13558226,stmts13568243) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1644],2,arguments);
}
var anf_fun58818223 = G(stmts13568243,"map",L[1643]);
var anf_arg58848224 = R.makeFunction(function(recv_DASH_7248228) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1642],1,arguments);
}
var anf_fun58838239 = G(recv_DASH_7248228,"visit",L[1642]);
var $z82318232 = D;
var $f82378238 = function(_) {
return R.isFunction(anf_fun58838239)?anf_fun58838239.app(self13548240):R.ffi.throwNonFunApp(L[1642],anf_fun58838239,[self13548240]);
};
try {
if(--R.GAS > 0) {
$z82318232 = $f82378238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82378238,
"from":L[1642]});
}
} catch($e82298230) {
if(R.isCont($e82298230)) {
var $ss82338234 = {"from":L[1642],
"go":function(ann_DASH_check_DASH_temp58828241) {
return $Hann_DASH_check_DASH_temp105308242(ann_DASH_check_DASH_temp58828241);
}};
$e82298230.stack[R.EXN_STACKHEIGHT++] = $ss82338234;
}
if(R.isPyretException($e82298230)) {
$e82298230.pyretStack.push(L[1642]);
}
throw $e82298230;
}
var $ret82358236 = $Hann_DASH_check_DASH_temp105308242($z82318232);
++R.GAS;
return $ret82358236;
});
var $z82158216 = D;
var $f82218222 = function(_) {
return R.isFunction(anf_fun58818223)?anf_fun58818223.app(anf_arg58848224):R.ffi.throwNonFunApp(L[1641],anf_fun58818223,[anf_arg58848224]);
};
try {
if(--R.GAS > 0) {
$z82158216 = $f82218222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82218222,
"from":L[1641]});
}
} catch($e82138214) {
if(R.isCont($e82138214)) {
var $ss82178218 = {"from":L[1641],
"go":function(anf_arg58858225) {
return $Hanf_arg105328227(anf_arg58858225,l13558226,s_DASH_block3301961);
}};
$e82138214.stack[R.EXN_STACKHEIGHT++] = $ss82178218;
}
if(R.isPyretException($e82138214)) {
$e82138214.pyretStack.push(L[1641]);
}
throw $e82138214;
}
var $ret82198220 = $Hanf_arg105328227($z82158216,l13558226,s_DASH_block3301961);
++R.GAS;
return $ret82198220;
};
},{"length":3});
var anf_obj58906644 = R.makeMethod(function(self13578208) {
return function(l13588210,body13598212) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1640],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l13588210,body13598212],[L[1638],L[1639]],function() {
var anf_fun58888207 = G(body13598212,"visit",L[1637]);
var $z81998200 = D;
var $f82058206 = function(_) {
return R.isFunction(anf_fun58888207)?anf_fun58888207.app(self13578208):R.ffi.throwNonFunApp(L[1636],anf_fun58888207,[self13578208]);
};
try {
if(--R.GAS > 0) {
$z81998200 = $f82058206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82058206,
"from":L[1636]});
}
} catch($e81978198) {
if(R.isCont($e81978198)) {
var $ss82018202 = {"from":L[1636],
"go":function(anf_arg58898209) {
return $Hanf_arg105348211(anf_arg58898209,l13588210,s_DASH_user_DASH_block3321965);
}};
$e81978198.stack[R.EXN_STACKHEIGHT++] = $ss82018202;
}
if(R.isPyretException($e81978198)) {
$e81978198.pyretStack.push(L[1636]);
}
throw $e81978198;
}
var $ret82038204 = $Hanf_arg105348211($z81998200,l13588210,s_DASH_user_DASH_block3321965);
++R.GAS;
return $ret82038204;
});
};
},{"length":3});
var anf_obj59036645 = R.makeMethod(function(self13608180) {
return function(l13618177,name13628178,params13638179,args13648196,ann13658174,doc13668176,body13678175,_check13688173) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[1635],8,arguments);
}
var anf_fun58928170 = G(args13648196,"map",L[1634]);
var anf_arg58958171 = R.makeFunction(function(recv_DASH_7258182) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1633],1,arguments);
}
var anf_fun58948193 = G(recv_DASH_7258182,"visit",L[1633]);
var $z81858186 = D;
var $f81918192 = function(_) {
return R.isFunction(anf_fun58948193)?anf_fun58948193.app(self13608180):R.ffi.throwNonFunApp(L[1633],anf_fun58948193,[self13608180]);
};
try {
if(--R.GAS > 0) {
$z81858186 = $f81918192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81918192,
"from":L[1633]});
}
} catch($e81838184) {
if(R.isCont($e81838184)) {
var $ss81878188 = {"from":L[1633],
"go":function(ann_DASH_check_DASH_temp58938194) {
return $Hann_DASH_check_DASH_temp105358195(ann_DASH_check_DASH_temp58938194);
}};
$e81838184.stack[R.EXN_STACKHEIGHT++] = $ss81878188;
}
if(R.isPyretException($e81838184)) {
$e81838184.pyretStack.push(L[1633]);
}
throw $e81838184;
}
var $ret81898190 = $Hann_DASH_check_DASH_temp105358195($z81858186);
++R.GAS;
return $ret81898190;
});
var $z81628163 = D;
var $f81688169 = function(_) {
return R.isFunction(anf_fun58928170)?anf_fun58928170.app(anf_arg58958171):R.ffi.throwNonFunApp(L[1632],anf_fun58928170,[anf_arg58958171]);
};
try {
if(--R.GAS > 0) {
$z81628163 = $f81688169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81688169,
"from":L[1632]});
}
} catch($e81608161) {
if(R.isCont($e81608161)) {
var $ss81648165 = {"from":L[1632],
"go":function(anf_arg58968172) {
return $Hanf_arg105408181(anf_arg58968172,_check13688173,ann13658174,body13678175,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180);
}};
$e81608161.stack[R.EXN_STACKHEIGHT++] = $ss81648165;
}
if(R.isPyretException($e81608161)) {
$e81608161.pyretStack.push(L[1632]);
}
throw $e81608161;
}
var $ret81668167 = $Hanf_arg105408181($z81628163,_check13688173,ann13658174,body13678175,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180);
++R.GAS;
return $ret81668167;
};
},{"length":9});
var anf_obj59096646 = R.makeMethod(function(self13698154) {
return function(l13708157,name13718159,ann13728156) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1631],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Ann11299],[l13708157,name13718159,ann13728156],[L[1628],L[1629],L[1630]],function() {
var anf_fun59058153 = G(name13718159,"visit",L[1627]);
var $z81458146 = D;
var $f81518152 = function(_) {
return R.isFunction(anf_fun59058153)?anf_fun59058153.app(self13698154):R.ffi.throwNonFunApp(L[1626],anf_fun59058153,[self13698154]);
};
try {
if(--R.GAS > 0) {
$z81458146 = $f81518152();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81518152,
"from":L[1626]});
}
} catch($e81438144) {
if(R.isCont($e81438144)) {
var $ss81478148 = {"from":L[1626],
"go":function(anf_arg59068155) {
return $Hanf_arg105438158(anf_arg59068155,ann13728156,l13708157,s_DASH_type3361973,self13698154);
}};
$e81438144.stack[R.EXN_STACKHEIGHT++] = $ss81478148;
}
if(R.isPyretException($e81438144)) {
$e81438144.pyretStack.push(L[1626]);
}
throw $e81438144;
}
var $ret81498150 = $Hanf_arg105438158($z81458146,ann13728156,l13708157,s_DASH_type3361973,self13698154);
++R.GAS;
return $ret81498150;
});
};
},{"length":4});
var anf_obj59156647 = R.makeMethod(function(self13738137) {
return function(l13748139,name13758142,namet13768140) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1625],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Name66133],[l13748139,name13758142,namet13768140],[L[1622],L[1623],L[1624]],function() {
var anf_fun59118136 = G(name13758142,"visit",L[1621]);
var $z81288129 = D;
var $f81348135 = function(_) {
return R.isFunction(anf_fun59118136)?anf_fun59118136.app(self13738137):R.ffi.throwNonFunApp(L[1620],anf_fun59118136,[self13738137]);
};
try {
if(--R.GAS > 0) {
$z81288129 = $f81348135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81348135,
"from":L[1620]});
}
} catch($e81268127) {
if(R.isCont($e81268127)) {
var $ss81308131 = {"from":L[1620],
"go":function(anf_arg59128138) {
return $Hanf_arg105468141(anf_arg59128138,l13748139,namet13768140,s_DASH_newtype3381977,self13738137);
}};
$e81268127.stack[R.EXN_STACKHEIGHT++] = $ss81308131;
}
if(R.isPyretException($e81268127)) {
$e81268127.pyretStack.push(L[1620]);
}
throw $e81268127;
}
var $ret81328133 = $Hanf_arg105468141($z81288129,l13748139,namet13768140,s_DASH_newtype3381977,self13738137);
++R.GAS;
return $ret81328133;
});
};
},{"length":4});
var anf_obj59216648 = R.makeMethod(function(self13778120) {
return function(l13788122,name13798125,value13808123) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1619],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l13788122,name13798125,value13808123],[L[1616],L[1617],L[1618]],function() {
var anf_fun59178119 = G(name13798125,"visit",L[1615]);
var $z81118112 = D;
var $f81178118 = function(_) {
return R.isFunction(anf_fun59178119)?anf_fun59178119.app(self13778120):R.ffi.throwNonFunApp(L[1614],anf_fun59178119,[self13778120]);
};
try {
if(--R.GAS > 0) {
$z81118112 = $f81178118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81178118,
"from":L[1614]});
}
} catch($e81098110) {
if(R.isCont($e81098110)) {
var $ss81138114 = {"from":L[1614],
"go":function(anf_arg59188121) {
return $Hanf_arg105498124(anf_arg59188121,l13788122,s_DASH_var3401981,self13778120,value13808123);
}};
$e81098110.stack[R.EXN_STACKHEIGHT++] = $ss81138114;
}
if(R.isPyretException($e81098110)) {
$e81098110.pyretStack.push(L[1614]);
}
throw $e81098110;
}
var $ret81158116 = $Hanf_arg105498124($z81118112,l13788122,s_DASH_var3401981,self13778120,value13808123);
++R.GAS;
return $ret81158116;
});
};
},{"length":4});
var anf_obj59276649 = R.makeMethod(function(self13818102) {
return function(l13828105,name13838108,value13848106,keyword_DASH_val13858104) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1613],4,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111,$type$Boolean67],[l13828105,name13838108,value13848106,keyword_DASH_val13858104],[L[1609],L[1610],L[1611],L[1612]],function() {
var anf_fun59238101 = G(name13838108,"visit",L[1608]);
var $z80938094 = D;
var $f80998100 = function(_) {
return R.isFunction(anf_fun59238101)?anf_fun59238101.app(self13818102):R.ffi.throwNonFunApp(L[1607],anf_fun59238101,[self13818102]);
};
try {
if(--R.GAS > 0) {
$z80938094 = $f80998100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80998100,
"from":L[1607]});
}
} catch($e80918092) {
if(R.isCont($e80918092)) {
var $ss80958096 = {"from":L[1607],
"go":function(anf_arg59248103) {
return $Hanf_arg105528107(anf_arg59248103,keyword_DASH_val13858104,l13828105,s_DASH_let3421985,self13818102,value13848106);
}};
$e80918092.stack[R.EXN_STACKHEIGHT++] = $ss80958096;
}
if(R.isPyretException($e80918092)) {
$e80918092.pyretStack.push(L[1607]);
}
throw $e80918092;
}
var $ret80978098 = $Hanf_arg105528107($z80938094,keyword_DASH_val13858104,l13828105,s_DASH_let3421985,self13818102,value13848106);
++R.GAS;
return $ret80978098;
});
};
},{"length":5});
var anf_obj59346650 = R.makeMethod(function(self13868087) {
return function(l13878073,bindings13888090) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1606],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l13878073,bindings13888090],[L[1604],L[1605]],function() {
var anf_fun59298070 = G(bindings13888090,"map",L[1603]);
var anf_arg59328071 = R.makeFunction(function(recv_DASH_7268075) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1602],1,arguments);
}
var anf_fun59318086 = G(recv_DASH_7268075,"visit",L[1602]);
var $z80788079 = D;
var $f80848085 = function(_) {
return R.isFunction(anf_fun59318086)?anf_fun59318086.app(self13868087):R.ffi.throwNonFunApp(L[1602],anf_fun59318086,[self13868087]);
};
try {
if(--R.GAS > 0) {
$z80788079 = $f80848085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80848085,
"from":L[1602]});
}
} catch($e80768077) {
if(R.isCont($e80768077)) {
var $ss80808081 = {"from":L[1602],
"go":function(ann_DASH_check_DASH_temp59308088) {
return $Hann_DASH_check_DASH_temp105538089(ann_DASH_check_DASH_temp59308088);
}};
$e80768077.stack[R.EXN_STACKHEIGHT++] = $ss80808081;
}
if(R.isPyretException($e80768077)) {
$e80768077.pyretStack.push(L[1602]);
}
throw $e80768077;
}
var $ret80828083 = $Hann_DASH_check_DASH_temp105538089($z80788079);
++R.GAS;
return $ret80828083;
});
var $z80628063 = D;
var $f80688069 = function(_) {
return R.isFunction(anf_fun59298070)?anf_fun59298070.app(anf_arg59328071):R.ffi.throwNonFunApp(L[1601],anf_fun59298070,[anf_arg59328071]);
};
try {
if(--R.GAS > 0) {
$z80628063 = $f80688069();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80688069,
"from":L[1601]});
}
} catch($e80608061) {
if(R.isCont($e80608061)) {
var $ss80648065 = {"from":L[1601],
"go":function(anf_arg59338072) {
return $Hanf_arg105558074(anf_arg59338072,l13878073,s_DASH_graph3441989);
}};
$e80608061.stack[R.EXN_STACKHEIGHT++] = $ss80648065;
}
if(R.isPyretException($e80608061)) {
$e80608061.pyretStack.push(L[1601]);
}
throw $e80608061;
}
var $ret80668067 = $Hanf_arg105558074($z80628063,l13878073,s_DASH_graph3441989);
++R.GAS;
return $ret80668067;
});
};
},{"length":3});
var anf_obj59406651 = R.makeMethod(function(self13898054) {
return function(l13908057,test13918059,block13928056) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1600],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l13908057,test13918059,block13928056],[L[1597],L[1598],L[1599]],function() {
var anf_fun59368053 = G(test13918059,"visit",L[1596]);
var $z80458046 = D;
var $f80518052 = function(_) {
return R.isFunction(anf_fun59368053)?anf_fun59368053.app(self13898054):R.ffi.throwNonFunApp(L[1595],anf_fun59368053,[self13898054]);
};
try {
if(--R.GAS > 0) {
$z80458046 = $f80518052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80518052,
"from":L[1595]});
}
} catch($e80438044) {
if(R.isCont($e80438044)) {
var $ss80478048 = {"from":L[1595],
"go":function(anf_arg59378055) {
return $Hanf_arg105588058(anf_arg59378055,block13928056,l13908057,s_DASH_when3481997,self13898054);
}};
$e80438044.stack[R.EXN_STACKHEIGHT++] = $ss80478048;
}
if(R.isPyretException($e80438044)) {
$e80438044.pyretStack.push(L[1595]);
}
throw $e80438044;
}
var $ret80498050 = $Hanf_arg105588058($z80458046,block13928056,l13908057,s_DASH_when3481997,self13898054);
++R.GAS;
return $ret80498050;
});
};
},{"length":4});
var anf_obj59466652 = R.makeMethod(function(self13938037) {
return function(l13948040,name13958042,ann13968039) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1594],3,arguments);
}
var anf_fun59428036 = G(name13958042,"visit",L[1593]);
var $z80288029 = D;
var $f80348035 = function(_) {
return R.isFunction(anf_fun59428036)?anf_fun59428036.app(self13938037):R.ffi.throwNonFunApp(L[1592],anf_fun59428036,[self13938037]);
};
try {
if(--R.GAS > 0) {
$z80288029 = $f80348035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80348035,
"from":L[1592]});
}
} catch($e80268027) {
if(R.isCont($e80268027)) {
var $ss80308031 = {"from":L[1592],
"go":function(anf_arg59438038) {
return $Hanf_arg105618041(anf_arg59438038,ann13968039,l13948040,s_DASH_contract3461993,self13938037);
}};
$e80268027.stack[R.EXN_STACKHEIGHT++] = $ss80308031;
}
if(R.isPyretException($e80268027)) {
$e80268027.pyretStack.push(L[1592]);
}
throw $e80268027;
}
var $ret80328033 = $Hanf_arg105618041($z80288029,ann13968039,l13948040,s_DASH_contract3461993,self13938037);
++R.GAS;
return $ret80328033;
};
},{"length":4});
var anf_obj59526653 = R.makeMethod(function(self13978020) {
return function(l13988022,id13998025,value14008023) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1591],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Expr86111],[l13988022,id13998025,value14008023],[L[1588],L[1589],L[1590]],function() {
var anf_fun59488019 = G(id13998025,"visit",L[1587]);
var $z80118012 = D;
var $f80178018 = function(_) {
return R.isFunction(anf_fun59488019)?anf_fun59488019.app(self13978020):R.ffi.throwNonFunApp(L[1586],anf_fun59488019,[self13978020]);
};
try {
if(--R.GAS > 0) {
$z80118012 = $f80178018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80178018,
"from":L[1586]});
}
} catch($e80098010) {
if(R.isCont($e80098010)) {
var $ss80138014 = {"from":L[1586],
"go":function(anf_arg59498021) {
return $Hanf_arg105648024(anf_arg59498021,l13988022,s_DASH_assign3502001,self13978020,value14008023);
}};
$e80098010.stack[R.EXN_STACKHEIGHT++] = $ss80138014;
}
if(R.isPyretException($e80098010)) {
$e80098010.pyretStack.push(L[1586]);
}
throw $e80098010;
}
var $ret80158016 = $Hanf_arg105648024($z80118012,l13988022,s_DASH_assign3502001,self13978020,value14008023);
++R.GAS;
return $ret80158016;
});
};
},{"length":4});
var anf_obj59586654 = R.makeMethod(function(self14018003) {
return function(l14028006,test14038008,body14048005) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1585],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l14028006,test14038008,body14048005],[L[1582],L[1583],L[1584]],function() {
var anf_fun59548002 = G(test14038008,"visit",L[1581]);
var $z79947995 = D;
var $f80008001 = function(_) {
return R.isFunction(anf_fun59548002)?anf_fun59548002.app(self14018003):R.ffi.throwNonFunApp(L[1580],anf_fun59548002,[self14018003]);
};
try {
if(--R.GAS > 0) {
$z79947995 = $f80008001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80008001,
"from":L[1580]});
}
} catch($e79927993) {
if(R.isCont($e79927993)) {
var $ss79967997 = {"from":L[1580],
"go":function(anf_arg59558004) {
return $Hanf_arg105678007(anf_arg59558004,body14048005,l14028006,s_DASH_if_DASH_branch4922285,self14018003);
}};
$e79927993.stack[R.EXN_STACKHEIGHT++] = $ss79967997;
}
if(R.isPyretException($e79927993)) {
$e79927993.pyretStack.push(L[1580]);
}
throw $e79927993;
}
var $ret79987999 = $Hanf_arg105678007($z79947995,body14048005,l14028006,s_DASH_if_DASH_branch4922285,self14018003);
++R.GAS;
return $ret79987999;
});
};
},{"length":4});
var anf_obj59646655 = R.makeMethod(function(self14057986) {
return function(l14067989,test14077991,body14087988) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1579],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l14067989,test14077991,body14087988],[L[1576],L[1577],L[1578]],function() {
var anf_fun59607985 = G(test14077991,"visit",L[1575]);
var $z79777978 = D;
var $f79837984 = function(_) {
return R.isFunction(anf_fun59607985)?anf_fun59607985.app(self14057986):R.ffi.throwNonFunApp(L[1574],anf_fun59607985,[self14057986]);
};
try {
if(--R.GAS > 0) {
$z79777978 = $f79837984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79837984,
"from":L[1574]});
}
} catch($e79757976) {
if(R.isCont($e79757976)) {
var $ss79797980 = {"from":L[1574],
"go":function(anf_arg59617987) {
return $Hanf_arg105707990(anf_arg59617987,body14087988,l14067989,s_DASH_if_DASH_pipe_DASH_branch4972295,self14057986);
}};
$e79757976.stack[R.EXN_STACKHEIGHT++] = $ss79797980;
}
if(R.isPyretException($e79757976)) {
$e79757976.pyretStack.push(L[1574]);
}
throw $e79757976;
}
var $ret79817982 = $Hanf_arg105707990($z79777978,body14087988,l14067989,s_DASH_if_DASH_pipe_DASH_branch4972295,self14057986);
++R.GAS;
return $ret79817982;
});
};
},{"length":4});
var anf_obj59716656 = R.makeMethod(function(self14097971) {
return function(l14107957,branches14117974) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1573],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l14107957,branches14117974],[L[1571],L[1572]],function() {
var anf_fun59667954 = G(branches14117974,"map",L[1570]);
var anf_arg59697955 = R.makeFunction(function(recv_DASH_7277959) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1569],1,arguments);
}
var anf_fun59687970 = G(recv_DASH_7277959,"visit",L[1569]);
var $z79627963 = D;
var $f79687969 = function(_) {
return R.isFunction(anf_fun59687970)?anf_fun59687970.app(self14097971):R.ffi.throwNonFunApp(L[1569],anf_fun59687970,[self14097971]);
};
try {
if(--R.GAS > 0) {
$z79627963 = $f79687969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79687969,
"from":L[1569]});
}
} catch($e79607961) {
if(R.isCont($e79607961)) {
var $ss79647965 = {"from":L[1569],
"go":function(ann_DASH_check_DASH_temp59677972) {
return $Hann_DASH_check_DASH_temp105717973(ann_DASH_check_DASH_temp59677972);
}};
$e79607961.stack[R.EXN_STACKHEIGHT++] = $ss79647965;
}
if(R.isPyretException($e79607961)) {
$e79607961.pyretStack.push(L[1569]);
}
throw $e79607961;
}
var $ret79667967 = $Hann_DASH_check_DASH_temp105717973($z79627963);
++R.GAS;
return $ret79667967;
});
var $z79467947 = D;
var $f79527953 = function(_) {
return R.isFunction(anf_fun59667954)?anf_fun59667954.app(anf_arg59697955):R.ffi.throwNonFunApp(L[1568],anf_fun59667954,[anf_arg59697955]);
};
try {
if(--R.GAS > 0) {
$z79467947 = $f79527953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79527953,
"from":L[1568]});
}
} catch($e79447945) {
if(R.isCont($e79447945)) {
var $ss79487949 = {"from":L[1568],
"go":function(anf_arg59707956) {
return $Hanf_arg105737958(anf_arg59707956,l14107957,s_DASH_if3562013);
}};
$e79447945.stack[R.EXN_STACKHEIGHT++] = $ss79487949;
}
if(R.isPyretException($e79447945)) {
$e79447945.pyretStack.push(L[1568]);
}
throw $e79447945;
}
var $ret79507951 = $Hanf_arg105737958($z79467947,l14107957,s_DASH_if3562013);
++R.GAS;
return $ret79507951;
});
};
},{"length":3});
var anf_obj59806657 = R.makeMethod(function(self14127927) {
return function(l14137926,branches14147943,_else14157925) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1567],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l14137926,branches14147943,_else14157925],[L[1564],L[1565],L[1566]],function() {
var anf_fun59737922 = G(branches14147943,"map",L[1563]);
var anf_arg59767923 = R.makeFunction(function(recv_DASH_7287929) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1562],1,arguments);
}
var anf_fun59757940 = G(recv_DASH_7287929,"visit",L[1562]);
var $z79327933 = D;
var $f79387939 = function(_) {
return R.isFunction(anf_fun59757940)?anf_fun59757940.app(self14127927):R.ffi.throwNonFunApp(L[1562],anf_fun59757940,[self14127927]);
};
try {
if(--R.GAS > 0) {
$z79327933 = $f79387939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79387939,
"from":L[1562]});
}
} catch($e79307931) {
if(R.isCont($e79307931)) {
var $ss79347935 = {"from":L[1562],
"go":function(ann_DASH_check_DASH_temp59747941) {
return $Hann_DASH_check_DASH_temp105747942(ann_DASH_check_DASH_temp59747941);
}};
$e79307931.stack[R.EXN_STACKHEIGHT++] = $ss79347935;
}
if(R.isPyretException($e79307931)) {
$e79307931.pyretStack.push(L[1562]);
}
throw $e79307931;
}
var $ret79367937 = $Hann_DASH_check_DASH_temp105747942($z79327933);
++R.GAS;
return $ret79367937;
});
var $z79147915 = D;
var $f79207921 = function(_) {
return R.isFunction(anf_fun59737922)?anf_fun59737922.app(anf_arg59767923):R.ffi.throwNonFunApp(L[1561],anf_fun59737922,[anf_arg59767923]);
};
try {
if(--R.GAS > 0) {
$z79147915 = $f79207921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79207921,
"from":L[1561]});
}
} catch($e79127913) {
if(R.isCont($e79127913)) {
var $ss79167917 = {"from":L[1561],
"go":function(anf_arg59777924) {
return $Hanf_arg105777928(anf_arg59777924,_else14157925,l14137926,s_DASH_if_DASH_else3582017,self14127927);
}};
$e79127913.stack[R.EXN_STACKHEIGHT++] = $ss79167917;
}
if(R.isPyretException($e79127913)) {
$e79127913.pyretStack.push(L[1561]);
}
throw $e79127913;
}
var $ret79187919 = $Hanf_arg105777928($z79147915,_else14157925,l14137926,s_DASH_if_DASH_else3582017,self14127927);
++R.GAS;
return $ret79187919;
});
};
},{"length":4});
var anf_obj59876658 = R.makeMethod(function(self14167908) {
return function(l14177894,branches14187911) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1560],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l14177894,branches14187911],[L[1558],L[1559]],function() {
var anf_fun59827891 = G(branches14187911,"map",L[1557]);
var anf_arg59857892 = R.makeFunction(function(recv_DASH_7297896) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1556],1,arguments);
}
var anf_fun59847907 = G(recv_DASH_7297896,"visit",L[1556]);
var $z78997900 = D;
var $f79057906 = function(_) {
return R.isFunction(anf_fun59847907)?anf_fun59847907.app(self14167908):R.ffi.throwNonFunApp(L[1556],anf_fun59847907,[self14167908]);
};
try {
if(--R.GAS > 0) {
$z78997900 = $f79057906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79057906,
"from":L[1556]});
}
} catch($e78977898) {
if(R.isCont($e78977898)) {
var $ss79017902 = {"from":L[1556],
"go":function(ann_DASH_check_DASH_temp59837909) {
return $Hann_DASH_check_DASH_temp105787910(ann_DASH_check_DASH_temp59837909);
}};
$e78977898.stack[R.EXN_STACKHEIGHT++] = $ss79017902;
}
if(R.isPyretException($e78977898)) {
$e78977898.pyretStack.push(L[1556]);
}
throw $e78977898;
}
var $ret79037904 = $Hann_DASH_check_DASH_temp105787910($z78997900);
++R.GAS;
return $ret79037904;
});
var $z78837884 = D;
var $f78897890 = function(_) {
return R.isFunction(anf_fun59827891)?anf_fun59827891.app(anf_arg59857892):R.ffi.throwNonFunApp(L[1555],anf_fun59827891,[anf_arg59857892]);
};
try {
if(--R.GAS > 0) {
$z78837884 = $f78897890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78897890,
"from":L[1555]});
}
} catch($e78817882) {
if(R.isCont($e78817882)) {
var $ss78857886 = {"from":L[1555],
"go":function(anf_arg59867893) {
return $Hanf_arg105807895(anf_arg59867893,l14177894,s_DASH_if_DASH_pipe3522005);
}};
$e78817882.stack[R.EXN_STACKHEIGHT++] = $ss78857886;
}
if(R.isPyretException($e78817882)) {
$e78817882.pyretStack.push(L[1555]);
}
throw $e78817882;
}
var $ret78877888 = $Hanf_arg105807895($z78837884,l14177894,s_DASH_if_DASH_pipe3522005);
++R.GAS;
return $ret78877888;
});
};
},{"length":3});
var anf_obj59966659 = R.makeMethod(function(self14197864) {
return function(l14207863,branches14217880,_else14227862) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1554],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l14207863,branches14217880,_else14227862],[L[1551],L[1552],L[1553]],function() {
var anf_fun59897859 = G(branches14217880,"map",L[1550]);
var anf_arg59927860 = R.makeFunction(function(recv_DASH_7307866) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1549],1,arguments);
}
var anf_fun59917877 = G(recv_DASH_7307866,"visit",L[1549]);
var $z78697870 = D;
var $f78757876 = function(_) {
return R.isFunction(anf_fun59917877)?anf_fun59917877.app(self14197864):R.ffi.throwNonFunApp(L[1549],anf_fun59917877,[self14197864]);
};
try {
if(--R.GAS > 0) {
$z78697870 = $f78757876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78757876,
"from":L[1549]});
}
} catch($e78677868) {
if(R.isCont($e78677868)) {
var $ss78717872 = {"from":L[1549],
"go":function(ann_DASH_check_DASH_temp59907878) {
return $Hann_DASH_check_DASH_temp105817879(ann_DASH_check_DASH_temp59907878);
}};
$e78677868.stack[R.EXN_STACKHEIGHT++] = $ss78717872;
}
if(R.isPyretException($e78677868)) {
$e78677868.pyretStack.push(L[1549]);
}
throw $e78677868;
}
var $ret78737874 = $Hann_DASH_check_DASH_temp105817879($z78697870);
++R.GAS;
return $ret78737874;
});
var $z78517852 = D;
var $f78577858 = function(_) {
return R.isFunction(anf_fun59897859)?anf_fun59897859.app(anf_arg59927860):R.ffi.throwNonFunApp(L[1548],anf_fun59897859,[anf_arg59927860]);
};
try {
if(--R.GAS > 0) {
$z78517852 = $f78577858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78577858,
"from":L[1548]});
}
} catch($e78497850) {
if(R.isCont($e78497850)) {
var $ss78537854 = {"from":L[1548],
"go":function(anf_arg59937861) {
return $Hanf_arg105847865(anf_arg59937861,_else14227862,l14207863,s_DASH_if_DASH_pipe_DASH_else3542009,self14197864);
}};
$e78497850.stack[R.EXN_STACKHEIGHT++] = $ss78537854;
}
if(R.isPyretException($e78497850)) {
$e78497850.pyretStack.push(L[1548]);
}
throw $e78497850;
}
var $ret78557856 = $Hanf_arg105847865($z78517852,_else14227862,l14207863,s_DASH_if_DASH_pipe_DASH_else3542009,self14197864);
++R.GAS;
return $ret78557856;
});
};
},{"length":4});
var anf_obj60056660 = R.makeMethod(function(self14237832) {
return function(l14247830,name14257831,args14267848,body14277829) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1547],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,Expr86111],[l14247830,name14257831,args14267848,body14277829],[L[1543],L[1544],L[1545],L[1546]],function() {
var anf_fun59987826 = G(args14267848,"map",L[1542]);
var anf_arg60017827 = R.makeFunction(function(recv_DASH_7317834) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1541],1,arguments);
}
var anf_fun60007845 = G(recv_DASH_7317834,"visit",L[1541]);
var $z78377838 = D;
var $f78437844 = function(_) {
return R.isFunction(anf_fun60007845)?anf_fun60007845.app(self14237832):R.ffi.throwNonFunApp(L[1541],anf_fun60007845,[self14237832]);
};
try {
if(--R.GAS > 0) {
$z78377838 = $f78437844();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78437844,
"from":L[1541]});
}
} catch($e78357836) {
if(R.isCont($e78357836)) {
var $ss78397840 = {"from":L[1541],
"go":function(ann_DASH_check_DASH_temp59997846) {
return $Hann_DASH_check_DASH_temp105857847(ann_DASH_check_DASH_temp59997846);
}};
$e78357836.stack[R.EXN_STACKHEIGHT++] = $ss78397840;
}
if(R.isPyretException($e78357836)) {
$e78357836.pyretStack.push(L[1541]);
}
throw $e78357836;
}
var $ret78417842 = $Hann_DASH_check_DASH_temp105857847($z78377838);
++R.GAS;
return $ret78417842;
});
var $z78187819 = D;
var $f78247825 = function(_) {
return R.isFunction(anf_fun59987826)?anf_fun59987826.app(anf_arg60017827):R.ffi.throwNonFunApp(L[1540],anf_fun59987826,[anf_arg60017827]);
};
try {
if(--R.GAS > 0) {
$z78187819 = $f78247825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78247825,
"from":L[1540]});
}
} catch($e78167817) {
if(R.isCont($e78167817)) {
var $ss78207821 = {"from":L[1540],
"go":function(anf_arg60027828) {
return $Hanf_arg105887833(anf_arg60027828,body14277829,l14247830,name14257831,s_DASH_cases_DASH_branch5022305,self14237832);
}};
$e78167817.stack[R.EXN_STACKHEIGHT++] = $ss78207821;
}
if(R.isPyretException($e78167817)) {
$e78167817.pyretStack.push(L[1540]);
}
throw $e78167817;
}
var $ret78227823 = $Hanf_arg105887833($z78187819,body14277829,l14247830,name14257831,s_DASH_cases_DASH_branch5022305,self14237832);
++R.GAS;
return $ret78227823;
});
};
},{"length":5});
var anf_obj60166661 = R.makeMethod(function(self14287809) {
return function(l14297812,typ14307815,val14317813,branches14327811) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1539],4,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111,List17129],[l14297812,typ14307815,val14317813,branches14327811],[L[1535],L[1536],L[1537],L[1538]],function() {
var anf_fun60077808 = G(typ14307815,"visit",L[1534]);
var $z78007801 = D;
var $f78067807 = function(_) {
return R.isFunction(anf_fun60077808)?anf_fun60077808.app(self14287809):R.ffi.throwNonFunApp(L[1533],anf_fun60077808,[self14287809]);
};
try {
if(--R.GAS > 0) {
$z78007801 = $f78067807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78067807,
"from":L[1533]});
}
} catch($e77987799) {
if(R.isCont($e77987799)) {
var $ss78027803 = {"from":L[1533],
"go":function(anf_arg60087810) {
return $Hanf_arg105937814(anf_arg60087810,branches14327811,l14297812,s_DASH_cases3602021,self14287809,val14317813);
}};
$e77987799.stack[R.EXN_STACKHEIGHT++] = $ss78027803;
}
if(R.isPyretException($e77987799)) {
$e77987799.pyretStack.push(L[1533]);
}
throw $e77987799;
}
var $ret78047805 = $Hanf_arg105937814($z78007801,branches14327811,l14297812,s_DASH_cases3602021,self14287809,val14317813);
++R.GAS;
return $ret78047805;
});
};
},{"length":5});
var anf_obj60296662 = R.makeMethod(function(self14337790) {
return function(l14347794,typ14357797,val14367795,branches14377793,_else14387792) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1532],5,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111,List17129,Expr86111],[l14347794,typ14357797,val14367795,branches14377793,_else14387792],[L[1527],L[1528],L[1529],L[1530],L[1531]],function() {
var anf_fun60187789 = G(typ14357797,"visit",L[1526]);
var $z77817782 = D;
var $f77877788 = function(_) {
return R.isFunction(anf_fun60187789)?anf_fun60187789.app(self14337790):R.ffi.throwNonFunApp(L[1525],anf_fun60187789,[self14337790]);
};
try {
if(--R.GAS > 0) {
$z77817782 = $f77877788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77877788,
"from":L[1525]});
}
} catch($e77797780) {
if(R.isCont($e77797780)) {
var $ss77837784 = {"from":L[1525],
"go":function(anf_arg60197791) {
return $Hanf_arg105997796(anf_arg60197791,_else14387792,branches14377793,l14347794,s_DASH_cases_DASH_else3622025,self14337790,val14367795);
}};
$e77797780.stack[R.EXN_STACKHEIGHT++] = $ss77837784;
}
if(R.isPyretException($e77797780)) {
$e77797780.pyretStack.push(L[1525]);
}
throw $e77797780;
}
var $ret77857786 = $Hanf_arg105997796($z77817782,_else14387792,branches14377793,l14347794,s_DASH_cases_DASH_else3622025,self14337790,val14367795);
++R.GAS;
return $ret77857786;
});
};
},{"length":6});
var anf_obj60376663 = R.makeMethod(function(self14397772) {
return function(l14407776,body14417778,id14427775,_except14437774) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1524],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Bind90101,Expr86111],[l14407776,body14417778,id14427775,_except14437774],[L[1520],L[1521],L[1522],L[1523]],function() {
var anf_fun60317771 = G(body14417778,"visit",L[1519]);
var $z77637764 = D;
var $f77697770 = function(_) {
return R.isFunction(anf_fun60317771)?anf_fun60317771.app(self14397772):R.ffi.throwNonFunApp(L[1518],anf_fun60317771,[self14397772]);
};
try {
if(--R.GAS > 0) {
$z77637764 = $f77697770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77697770,
"from":L[1518]});
}
} catch($e77617762) {
if(R.isCont($e77617762)) {
var $ss77657766 = {"from":L[1518],
"go":function(anf_arg60327773) {
return $Hanf_arg106037777(anf_arg60327773,_except14437774,id14427775,l14407776,s_DASH_try3642029,self14397772);
}};
$e77617762.stack[R.EXN_STACKHEIGHT++] = $ss77657766;
}
if(R.isPyretException($e77617762)) {
$e77617762.pyretStack.push(L[1518]);
}
throw $e77617762;
}
var $ret77677768 = $Hanf_arg106037777($z77637764,_except14437774,id14427775,l14407776,s_DASH_try3642029,self14397772);
++R.GAS;
return $ret77677768;
});
};
},{"length":5});
var anf_obj60436664 = R.makeMethod(function(self14447754) {
return function(l14457756,op14467757,left14477760,right14487758) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1517],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111,Expr86111],[l14457756,op14467757,left14477760,right14487758],[L[1513],L[1514],L[1515],L[1516]],function() {
var anf_fun60397753 = G(left14477760,"visit",L[1512]);
var $z77457746 = D;
var $f77517752 = function(_) {
return R.isFunction(anf_fun60397753)?anf_fun60397753.app(self14447754):R.ffi.throwNonFunApp(L[1511],anf_fun60397753,[self14447754]);
};
try {
if(--R.GAS > 0) {
$z77457746 = $f77517752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77517752,
"from":L[1511]});
}
} catch($e77437744) {
if(R.isCont($e77437744)) {
var $ss77477748 = {"from":L[1511],
"go":function(anf_arg60407755) {
return $Hanf_arg106067759(anf_arg60407755,l14457756,op14467757,right14487758,s_DASH_op3662033,self14447754);
}};
$e77437744.stack[R.EXN_STACKHEIGHT++] = $ss77477748;
}
if(R.isPyretException($e77437744)) {
$e77437744.pyretStack.push(L[1511]);
}
throw $e77437744;
}
var $ret77497750 = $Hanf_arg106067759($z77457746,l14457756,op14467757,right14487758,s_DASH_op3662033,self14447754);
++R.GAS;
return $ret77497750;
});
};
},{"length":5});
var anf_obj60496665 = R.makeMethod(function(self14497736) {
return function(l14507738,op14517739,left14527742,right14537740) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1510],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111,Expr86111],[l14507738,op14517739,left14527742,right14537740],[L[1506],L[1507],L[1508],L[1509]],function() {
var anf_fun60457735 = G(left14527742,"visit",L[1505]);
var $z77277728 = D;
var $f77337734 = function(_) {
return R.isFunction(anf_fun60457735)?anf_fun60457735.app(self14497736):R.ffi.throwNonFunApp(L[1504],anf_fun60457735,[self14497736]);
};
try {
if(--R.GAS > 0) {
$z77277728 = $f77337734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77337734,
"from":L[1504]});
}
} catch($e77257726) {
if(R.isCont($e77257726)) {
var $ss77297730 = {"from":L[1504],
"go":function(anf_arg60467737) {
return $Hanf_arg106097741(anf_arg60467737,l14507738,op14517739,right14537740,s_DASH_check_DASH_test3682037,self14497736);
}};
$e77257726.stack[R.EXN_STACKHEIGHT++] = $ss77297730;
}
if(R.isPyretException($e77257726)) {
$e77257726.pyretStack.push(L[1504]);
}
throw $e77257726;
}
var $ret77317732 = $Hanf_arg106097741($z77277728,l14507738,op14517739,right14537740,s_DASH_check_DASH_test3682037,self14497736);
++R.GAS;
return $ret77317732;
});
};
},{"length":5});
var anf_obj60536666 = R.makeMethod(function(self14547720) {
return function(l14557722,expr14567724) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1503],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l14557722,expr14567724],[L[1501],L[1502]],function() {
var anf_fun60517719 = G(expr14567724,"visit",L[1500]);
var $z77117712 = D;
var $f77177718 = function(_) {
return R.isFunction(anf_fun60517719)?anf_fun60517719.app(self14547720):R.ffi.throwNonFunApp(L[1499],anf_fun60517719,[self14547720]);
};
try {
if(--R.GAS > 0) {
$z77117712 = $f77177718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77177718,
"from":L[1499]});
}
} catch($e77097710) {
if(R.isCont($e77097710)) {
var $ss77137714 = {"from":L[1499],
"go":function(anf_arg60527721) {
return $Hanf_arg106117723(anf_arg60527721,l14557722,s_DASH_paren3702041);
}};
$e77097710.stack[R.EXN_STACKHEIGHT++] = $ss77137714;
}
if(R.isPyretException($e77097710)) {
$e77097710.pyretStack.push(L[1499]);
}
throw $e77097710;
}
var $ret77157716 = $Hanf_arg106117723($z77117712,l14557722,s_DASH_paren3702041);
++R.GAS;
return $ret77157716;
});
};
},{"length":3});
var anf_obj60716667 = R.makeMethod(function(self14577692) {
return function(l14587691,params14597708,args14607688,ann14617687,doc14627690,body14637689,_check14647686) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[1498],7,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l14587691,params14597708,args14607688,ann14617687,doc14627690,body14637689,_check14647686],[L[1491],L[1492],L[1493],L[1494],L[1495],L[1496],L[1497]],function() {
var anf_fun60557683 = G(params14597708,"map",L[1490]);
var anf_arg60587684 = R.makeFunction(function(recv_DASH_7347694) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1489],1,arguments);
}
var anf_fun60577705 = G(recv_DASH_7347694,"visit",L[1489]);
var $z76977698 = D;
var $f77037704 = function(_) {
return R.isFunction(anf_fun60577705)?anf_fun60577705.app(self14577692):R.ffi.throwNonFunApp(L[1489],anf_fun60577705,[self14577692]);
};
try {
if(--R.GAS > 0) {
$z76977698 = $f77037704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77037704,
"from":L[1489]});
}
} catch($e76957696) {
if(R.isCont($e76957696)) {
var $ss76997700 = {"from":L[1489],
"go":function(ann_DASH_check_DASH_temp60567706) {
return $Hann_DASH_check_DASH_temp106127707(ann_DASH_check_DASH_temp60567706);
}};
$e76957696.stack[R.EXN_STACKHEIGHT++] = $ss76997700;
}
if(R.isPyretException($e76957696)) {
$e76957696.pyretStack.push(L[1489]);
}
throw $e76957696;
}
var $ret77017702 = $Hann_DASH_check_DASH_temp106127707($z76977698);
++R.GAS;
return $ret77017702;
});
var $z76757676 = D;
var $f76817682 = function(_) {
return R.isFunction(anf_fun60557683)?anf_fun60557683.app(anf_arg60587684):R.ffi.throwNonFunApp(L[1488],anf_fun60557683,[anf_arg60587684]);
};
try {
if(--R.GAS > 0) {
$z76757676 = $f76817682();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76817682,
"from":L[1488]});
}
} catch($e76737674) {
if(R.isCont($e76737674)) {
var $ss76777678 = {"from":L[1488],
"go":function(anf_arg60597685) {
return $Hanf_arg106197693(anf_arg60597685,_check14647686,ann14617687,args14607688,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692);
}};
$e76737674.stack[R.EXN_STACKHEIGHT++] = $ss76777678;
}
if(R.isPyretException($e76737674)) {
$e76737674.pyretStack.push(L[1488]);
}
throw $e76737674;
}
var $ret76797680 = $Hanf_arg106197693($z76757676,_check14647686,ann14617687,args14607688,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692);
++R.GAS;
return $ret76797680;
});
};
},{"length":8});
var anf_obj60846668 = R.makeMethod(function(self14657656) {
return function(l14667655,args14677672,ann14687652,doc14697654,body14707653,_check14717651) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[1487],6,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l14667655,args14677672,ann14687652,doc14697654,body14707653,_check14717651],[L[1481],L[1482],L[1483],L[1484],L[1485],L[1486]],function() {
var anf_fun60737648 = G(args14677672,"map",L[1480]);
var anf_arg60767649 = R.makeFunction(function(recv_DASH_7367658) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1479],1,arguments);
}
var anf_fun60757669 = G(recv_DASH_7367658,"visit",L[1479]);
var $z76617662 = D;
var $f76677668 = function(_) {
return R.isFunction(anf_fun60757669)?anf_fun60757669.app(self14657656):R.ffi.throwNonFunApp(L[1479],anf_fun60757669,[self14657656]);
};
try {
if(--R.GAS > 0) {
$z76617662 = $f76677668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76677668,
"from":L[1479]});
}
} catch($e76597660) {
if(R.isCont($e76597660)) {
var $ss76637664 = {"from":L[1479],
"go":function(ann_DASH_check_DASH_temp60747670) {
return $Hann_DASH_check_DASH_temp106207671(ann_DASH_check_DASH_temp60747670);
}};
$e76597660.stack[R.EXN_STACKHEIGHT++] = $ss76637664;
}
if(R.isPyretException($e76597660)) {
$e76597660.pyretStack.push(L[1479]);
}
throw $e76597660;
}
var $ret76657666 = $Hann_DASH_check_DASH_temp106207671($z76617662);
++R.GAS;
return $ret76657666;
});
var $z76407641 = D;
var $f76467647 = function(_) {
return R.isFunction(anf_fun60737648)?anf_fun60737648.app(anf_arg60767649):R.ffi.throwNonFunApp(L[1478],anf_fun60737648,[anf_arg60767649]);
};
try {
if(--R.GAS > 0) {
$z76407641 = $f76467647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76467647,
"from":L[1478]});
}
} catch($e76387639) {
if(R.isCont($e76387639)) {
var $ss76427643 = {"from":L[1478],
"go":function(anf_arg60777650) {
return $Hanf_arg106257657(anf_arg60777650,_check14717651,ann14687652,body14707653,doc14697654,l14667655,s_DASH_method3742049,self14657656);
}};
$e76387639.stack[R.EXN_STACKHEIGHT++] = $ss76427643;
}
if(R.isPyretException($e76387639)) {
$e76387639.pyretStack.push(L[1478]);
}
throw $e76387639;
}
var $ret76447645 = $Hanf_arg106257657($z76407641,_check14717651,ann14687652,body14707653,doc14697654,l14667655,s_DASH_method3742049,self14657656);
++R.GAS;
return $ret76447645;
});
};
},{"length":7});
var anf_obj60936669 = R.makeMethod(function(self14727632) {
return function(l14737635,supe14747637,fields14757634) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1477],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l14737635,supe14747637,fields14757634],[L[1474],L[1475],L[1476]],function() {
var anf_fun60867631 = G(supe14747637,"visit",L[1473]);
var $z76237624 = D;
var $f76297630 = function(_) {
return R.isFunction(anf_fun60867631)?anf_fun60867631.app(self14727632):R.ffi.throwNonFunApp(L[1472],anf_fun60867631,[self14727632]);
};
try {
if(--R.GAS > 0) {
$z76237624 = $f76297630();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76297630,
"from":L[1472]});
}
} catch($e76217622) {
if(R.isCont($e76217622)) {
var $ss76257626 = {"from":L[1472],
"go":function(anf_arg60877633) {
return $Hanf_arg106297636(anf_arg60877633,fields14757634,l14737635,s_DASH_extend3762053,self14727632);
}};
$e76217622.stack[R.EXN_STACKHEIGHT++] = $ss76257626;
}
if(R.isPyretException($e76217622)) {
$e76217622.pyretStack.push(L[1472]);
}
throw $e76217622;
}
var $ret76277628 = $Hanf_arg106297636($z76237624,fields14757634,l14737635,s_DASH_extend3762053,self14727632);
++R.GAS;
return $ret76277628;
});
};
},{"length":4});
var anf_obj61026670 = R.makeMethod(function(self14767615) {
return function(l14777618,supe14787620,fields14797617) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1471],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l14777618,supe14787620,fields14797617],[L[1468],L[1469],L[1470]],function() {
var anf_fun60957614 = G(supe14787620,"visit",L[1467]);
var $z76067607 = D;
var $f76127613 = function(_) {
return R.isFunction(anf_fun60957614)?anf_fun60957614.app(self14767615):R.ffi.throwNonFunApp(L[1466],anf_fun60957614,[self14767615]);
};
try {
if(--R.GAS > 0) {
$z76067607 = $f76127613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76127613,
"from":L[1466]});
}
} catch($e76047605) {
if(R.isCont($e76047605)) {
var $ss76087609 = {"from":L[1466],
"go":function(anf_arg60967616) {
return $Hanf_arg106337619(anf_arg60967616,fields14797617,l14777618,s_DASH_update3782057,self14767615);
}};
$e76047605.stack[R.EXN_STACKHEIGHT++] = $ss76087609;
}
if(R.isPyretException($e76047605)) {
$e76047605.pyretStack.push(L[1466]);
}
throw $e76047605;
}
var $ret76107611 = $Hanf_arg106337619($z76067607,fields14797617,l14777618,s_DASH_update3782057,self14767615);
++R.GAS;
return $ret76107611;
});
};
},{"length":4});
var anf_obj61096671 = R.makeMethod(function(self14807600) {
return function(l14817586,fields14827603) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1465],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l14817586,fields14827603],[L[1463],L[1464]],function() {
var anf_fun61047583 = G(fields14827603,"map",L[1462]);
var anf_arg61077584 = R.makeFunction(function(recv_DASH_7397588) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1461],1,arguments);
}
var anf_fun61067599 = G(recv_DASH_7397588,"visit",L[1461]);
var $z75917592 = D;
var $f75977598 = function(_) {
return R.isFunction(anf_fun61067599)?anf_fun61067599.app(self14807600):R.ffi.throwNonFunApp(L[1461],anf_fun61067599,[self14807600]);
};
try {
if(--R.GAS > 0) {
$z75917592 = $f75977598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75977598,
"from":L[1461]});
}
} catch($e75897590) {
if(R.isCont($e75897590)) {
var $ss75937594 = {"from":L[1461],
"go":function(ann_DASH_check_DASH_temp61057601) {
return $Hann_DASH_check_DASH_temp106347602(ann_DASH_check_DASH_temp61057601);
}};
$e75897590.stack[R.EXN_STACKHEIGHT++] = $ss75937594;
}
if(R.isPyretException($e75897590)) {
$e75897590.pyretStack.push(L[1461]);
}
throw $e75897590;
}
var $ret75957596 = $Hann_DASH_check_DASH_temp106347602($z75917592);
++R.GAS;
return $ret75957596;
});
var $z75757576 = D;
var $f75817582 = function(_) {
return R.isFunction(anf_fun61047583)?anf_fun61047583.app(anf_arg61077584):R.ffi.throwNonFunApp(L[1460],anf_fun61047583,[anf_arg61077584]);
};
try {
if(--R.GAS > 0) {
$z75757576 = $f75817582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75817582,
"from":L[1460]});
}
} catch($e75737574) {
if(R.isCont($e75737574)) {
var $ss75777578 = {"from":L[1460],
"go":function(anf_arg61087585) {
return $Hanf_arg106367587(anf_arg61087585,l14817586,s_DASH_obj3802061);
}};
$e75737574.stack[R.EXN_STACKHEIGHT++] = $ss75777578;
}
if(R.isPyretException($e75737574)) {
$e75737574.pyretStack.push(L[1460]);
}
throw $e75737574;
}
var $ret75797580 = $Hanf_arg106367587($z75757576,l14817586,s_DASH_obj3802061);
++R.GAS;
return $ret75797580;
});
};
},{"length":3});
var anf_obj61166672 = R.makeMethod(function(self14837569) {
return function(l14847555,values14857572) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1459],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l14847555,values14857572],[L[1457],L[1458]],function() {
var anf_fun61117552 = G(values14857572,"map",L[1456]);
var anf_arg61147553 = R.makeFunction(function(recv_DASH_7407557) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1455],1,arguments);
}
var anf_fun61137568 = G(recv_DASH_7407557,"visit",L[1455]);
var $z75607561 = D;
var $f75667567 = function(_) {
return R.isFunction(anf_fun61137568)?anf_fun61137568.app(self14837569):R.ffi.throwNonFunApp(L[1455],anf_fun61137568,[self14837569]);
};
try {
if(--R.GAS > 0) {
$z75607561 = $f75667567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75667567,
"from":L[1455]});
}
} catch($e75587559) {
if(R.isCont($e75587559)) {
var $ss75627563 = {"from":L[1455],
"go":function(ann_DASH_check_DASH_temp61127570) {
return $Hann_DASH_check_DASH_temp106377571(ann_DASH_check_DASH_temp61127570);
}};
$e75587559.stack[R.EXN_STACKHEIGHT++] = $ss75627563;
}
if(R.isPyretException($e75587559)) {
$e75587559.pyretStack.push(L[1455]);
}
throw $e75587559;
}
var $ret75647565 = $Hann_DASH_check_DASH_temp106377571($z75607561);
++R.GAS;
return $ret75647565;
});
var $z75447545 = D;
var $f75507551 = function(_) {
return R.isFunction(anf_fun61117552)?anf_fun61117552.app(anf_arg61147553):R.ffi.throwNonFunApp(L[1454],anf_fun61117552,[anf_arg61147553]);
};
try {
if(--R.GAS > 0) {
$z75447545 = $f75507551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75507551,
"from":L[1454]});
}
} catch($e75427543) {
if(R.isCont($e75427543)) {
var $ss75467547 = {"from":L[1454],
"go":function(anf_arg61157554) {
return $Hanf_arg106397556(anf_arg61157554,l14847555,s_DASH_array3822065);
}};
$e75427543.stack[R.EXN_STACKHEIGHT++] = $ss75467547;
}
if(R.isPyretException($e75427543)) {
$e75427543.pyretStack.push(L[1454]);
}
throw $e75427543;
}
var $ret75487549 = $Hanf_arg106397556($z75447545,l14847555,s_DASH_array3822065);
++R.GAS;
return $ret75487549;
});
};
},{"length":3});
var anf_obj61226673 = R.makeMethod(function(self14867536) {
return function(l14877538,expr14887541,typ14897539) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1453],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Name66133],[l14877538,expr14887541,typ14897539],[L[1450],L[1451],L[1452]],function() {
var anf_fun61187535 = G(expr14887541,"visit",L[1449]);
var $z75277528 = D;
var $f75337534 = function(_) {
return R.isFunction(anf_fun61187535)?anf_fun61187535.app(self14867536):R.ffi.throwNonFunApp(L[1448],anf_fun61187535,[self14867536]);
};
try {
if(--R.GAS > 0) {
$z75277528 = $f75337534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75337534,
"from":L[1448]});
}
} catch($e75257526) {
if(R.isCont($e75257526)) {
var $ss75297530 = {"from":L[1448],
"go":function(anf_arg61197537) {
return $Hanf_arg106427540(anf_arg61197537,l14877538,s_DASH_bless3882077,self14867536,typ14897539);
}};
$e75257526.stack[R.EXN_STACKHEIGHT++] = $ss75297530;
}
if(R.isPyretException($e75257526)) {
$e75257526.pyretStack.push(L[1448]);
}
throw $e75257526;
}
var $ret75317532 = $Hanf_arg106427540($z75277528,l14877538,s_DASH_bless3882077,self14867536,typ14897539);
++R.GAS;
return $ret75317532;
});
};
},{"length":4});
var anf_obj61286674 = R.makeMethod(function(self14907519) {
return function(l14917521,expr14927524,typ14937522) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1447],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Name66133],[l14917521,expr14927524,typ14937522],[L[1444],L[1445],L[1446]],function() {
var anf_fun61247518 = G(expr14927524,"visit",L[1443]);
var $z75107511 = D;
var $f75167517 = function(_) {
return R.isFunction(anf_fun61247518)?anf_fun61247518.app(self14907519):R.ffi.throwNonFunApp(L[1442],anf_fun61247518,[self14907519]);
};
try {
if(--R.GAS > 0) {
$z75107511 = $f75167517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75167517,
"from":L[1442]});
}
} catch($e75087509) {
if(R.isCont($e75087509)) {
var $ss75127513 = {"from":L[1442],
"go":function(anf_arg61257520) {
return $Hanf_arg106457523(anf_arg61257520,l14917521,s_DASH_confirm3862073,self14907519,typ14937522);
}};
$e75087509.stack[R.EXN_STACKHEIGHT++] = $ss75127513;
}
if(R.isPyretException($e75087509)) {
$e75087509.pyretStack.push(L[1442]);
}
throw $e75087509;
}
var $ret75147515 = $Hanf_arg106457523($z75107511,l14917521,s_DASH_confirm3862073,self14907519,typ14937522);
++R.GAS;
return $ret75147515;
});
};
},{"length":4});
var anf_obj61376675 = R.makeMethod(function(self14947501) {
return function(l14957503,mod14967504,constructor14977507,values14987505) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1441],4,arguments);
}
return R.checkAnnArgs([Loc116130,ConstructModifier88105,Expr86111,List17129],[l14957503,mod14967504,constructor14977507,values14987505],[L[1437],L[1438],L[1439],L[1440]],function() {
var anf_fun61307500 = G(constructor14977507,"visit",L[1436]);
var $z74927493 = D;
var $f74987499 = function(_) {
return R.isFunction(anf_fun61307500)?anf_fun61307500.app(self14947501):R.ffi.throwNonFunApp(L[1435],anf_fun61307500,[self14947501]);
};
try {
if(--R.GAS > 0) {
$z74927493 = $f74987499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74987499,
"from":L[1435]});
}
} catch($e74907491) {
if(R.isCont($e74907491)) {
var $ss74947495 = {"from":L[1435],
"go":function(anf_arg61317502) {
return $Hanf_arg106497506(anf_arg61317502,l14957503,mod14967504,s_DASH_construct3842069,self14947501,values14987505);
}};
$e74907491.stack[R.EXN_STACKHEIGHT++] = $ss74947495;
}
if(R.isPyretException($e74907491)) {
$e74907491.pyretStack.push(L[1435]);
}
throw $e74907491;
}
var $ret74967497 = $Hanf_arg106497506($z74927493,l14957503,mod14967504,s_DASH_construct3842069,self14947501,values14987505);
++R.GAS;
return $ret74967497;
});
};
},{"length":5});
var anf_obj61466676 = R.makeMethod(function(self14997484) {
return function(l15007487,_fun15017489,args15027486) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1434],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l15007487,_fun15017489,args15027486],[L[1431],L[1432],L[1433]],function() {
var anf_fun61397483 = G(_fun15017489,"visit",L[1430]);
var $z74757476 = D;
var $f74817482 = function(_) {
return R.isFunction(anf_fun61397483)?anf_fun61397483.app(self14997484):R.ffi.throwNonFunApp(L[1429],anf_fun61397483,[self14997484]);
};
try {
if(--R.GAS > 0) {
$z74757476 = $f74817482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74817482,
"from":L[1429]});
}
} catch($e74737474) {
if(R.isCont($e74737474)) {
var $ss74777478 = {"from":L[1429],
"go":function(anf_arg61407485) {
return $Hanf_arg106537488(anf_arg61407485,args15027486,l15007487,s_DASH_app3902081,self14997484);
}};
$e74737474.stack[R.EXN_STACKHEIGHT++] = $ss74777478;
}
if(R.isPyretException($e74737474)) {
$e74737474.pyretStack.push(L[1429]);
}
throw $e74737474;
}
var $ret74797480 = $Hanf_arg106537488($z74757476,args15027486,l15007487,s_DASH_app3902081,self14997484);
++R.GAS;
return $ret74797480;
});
};
},{"length":4});
var anf_obj61536677 = R.makeMethod(function(self15037469) {
return function(l15047455,_fun15057454,args15067472) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1428],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129],[l15047455,_fun15057454,args15067472],[L[1425],L[1426],L[1427]],function() {
var anf_fun61487451 = G(args15067472,"map",L[1424]);
var anf_arg61517452 = R.makeFunction(function(recv_DASH_7437457) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1423],1,arguments);
}
var anf_fun61507468 = G(recv_DASH_7437457,"visit",L[1423]);
var $z74607461 = D;
var $f74667467 = function(_) {
return R.isFunction(anf_fun61507468)?anf_fun61507468.app(self15037469):R.ffi.throwNonFunApp(L[1423],anf_fun61507468,[self15037469]);
};
try {
if(--R.GAS > 0) {
$z74607461 = $f74667467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74667467,
"from":L[1423]});
}
} catch($e74587459) {
if(R.isCont($e74587459)) {
var $ss74627463 = {"from":L[1423],
"go":function(ann_DASH_check_DASH_temp61497470) {
return $Hann_DASH_check_DASH_temp106547471(ann_DASH_check_DASH_temp61497470);
}};
$e74587459.stack[R.EXN_STACKHEIGHT++] = $ss74627463;
}
if(R.isPyretException($e74587459)) {
$e74587459.pyretStack.push(L[1423]);
}
throw $e74587459;
}
var $ret74647465 = $Hann_DASH_check_DASH_temp106547471($z74607461);
++R.GAS;
return $ret74647465;
});
var $z74437444 = D;
var $f74497450 = function(_) {
return R.isFunction(anf_fun61487451)?anf_fun61487451.app(anf_arg61517452):R.ffi.throwNonFunApp(L[1422],anf_fun61487451,[anf_arg61517452]);
};
try {
if(--R.GAS > 0) {
$z74437444 = $f74497450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74497450,
"from":L[1422]});
}
} catch($e74417442) {
if(R.isCont($e74417442)) {
var $ss74457446 = {"from":L[1422],
"go":function(anf_arg61527453) {
return $Hanf_arg106567456(anf_arg61527453,_fun15057454,l15047455,s_DASH_prim_DASH_app3922085);
}};
$e74417442.stack[R.EXN_STACKHEIGHT++] = $ss74457446;
}
if(R.isPyretException($e74417442)) {
$e74417442.pyretStack.push(L[1422]);
}
throw $e74417442;
}
var $ret74477448 = $Hanf_arg106567456($z74437444,_fun15057454,l15047455,s_DASH_prim_DASH_app3922085);
++R.GAS;
return $ret74477448;
});
};
},{"length":4});
var anf_obj61556678 = R.makeMethod(function(self15077440) {
return function(l15087436,name15097437) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1419],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l15087436,name15097437],[L[1420],L[1421]],function() {
var $z74287429 = D;
var $f74347435 = function(_) {
return R.isFunction(s_DASH_prim_DASH_val3942089.$var)?s_DASH_prim_DASH_val3942089.$var.app(l15087436,name15097437):R.ffi.throwNonFunApp(L[1419],s_DASH_prim_DASH_val3942089.$var,[l15087436,name15097437]);
};
try {
if(--R.GAS > 0) {
$z74287429 = $f74347435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74347435,
"from":L[1419]});
}
} catch($e74267427) {
if(R.isCont($e74267427)) {
var $ss74307431 = {"from":L[1419],
"go":function(ann_DASH_check_DASH_temp61547438) {
return $Hann_DASH_check_DASH_temp106577439(ann_DASH_check_DASH_temp61547438);
}};
$e74267427.stack[R.EXN_STACKHEIGHT++] = $ss74307431;
}
if(R.isPyretException($e74267427)) {
$e74267427.pyretStack.push(L[1419]);
}
throw $e74267427;
}
var $ret74327433 = $Hann_DASH_check_DASH_temp106577439($z74287429);
++R.GAS;
return $ret74327433;
});
};
},{"length":3});
var anf_obj61596679 = R.makeMethod(function(self15107421) {
return function(l15117423,id15127425) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1418],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l15117423,id15127425],[L[1416],L[1417]],function() {
var anf_fun61577420 = G(id15127425,"visit",L[1415]);
var $z74127413 = D;
var $f74187419 = function(_) {
return R.isFunction(anf_fun61577420)?anf_fun61577420.app(self15107421):R.ffi.throwNonFunApp(L[1414],anf_fun61577420,[self15107421]);
};
try {
if(--R.GAS > 0) {
$z74127413 = $f74187419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74187419,
"from":L[1414]});
}
} catch($e74107411) {
if(R.isCont($e74107411)) {
var $ss74147415 = {"from":L[1414],
"go":function(anf_arg61587422) {
return $Hanf_arg106597424(anf_arg61587422,l15117423,s_DASH_id3962093);
}};
$e74107411.stack[R.EXN_STACKHEIGHT++] = $ss74147415;
}
if(R.isPyretException($e74107411)) {
$e74107411.pyretStack.push(L[1414]);
}
throw $e74107411;
}
var $ret74167417 = $Hanf_arg106597424($z74127413,l15117423,s_DASH_id3962093);
++R.GAS;
return $ret74167417;
});
};
},{"length":3});
var anf_obj61636680 = R.makeMethod(function(self15137405) {
return function(l15147407,id15157409) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1413],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l15147407,id15157409],[L[1411],L[1412]],function() {
var anf_fun61617404 = G(id15157409,"visit",L[1410]);
var $z73967397 = D;
var $f74027403 = function(_) {
return R.isFunction(anf_fun61617404)?anf_fun61617404.app(self15137405):R.ffi.throwNonFunApp(L[1409],anf_fun61617404,[self15137405]);
};
try {
if(--R.GAS > 0) {
$z73967397 = $f74027403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74027403,
"from":L[1409]});
}
} catch($e73947395) {
if(R.isCont($e73947395)) {
var $ss73987399 = {"from":L[1409],
"go":function(anf_arg61627406) {
return $Hanf_arg106617408(anf_arg61627406,l15147407,s_DASH_id_DASH_var3982097);
}};
$e73947395.stack[R.EXN_STACKHEIGHT++] = $ss73987399;
}
if(R.isPyretException($e73947395)) {
$e73947395.pyretStack.push(L[1409]);
}
throw $e73947395;
}
var $ret74007401 = $Hanf_arg106617408($z73967397,l15147407,s_DASH_id_DASH_var3982097);
++R.GAS;
return $ret74007401;
});
};
},{"length":3});
var anf_obj61676681 = R.makeMethod(function(self15167388) {
return function(l15177390,id15187393,safe15197391) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1408],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,$type$Boolean67],[l15177390,id15187393,safe15197391],[L[1405],L[1406],L[1407]],function() {
var anf_fun61657387 = G(id15187393,"visit",L[1404]);
var $z73797380 = D;
var $f73857386 = function(_) {
return R.isFunction(anf_fun61657387)?anf_fun61657387.app(self15167388):R.ffi.throwNonFunApp(L[1403],anf_fun61657387,[self15167388]);
};
try {
if(--R.GAS > 0) {
$z73797380 = $f73857386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73857386,
"from":L[1403]});
}
} catch($e73777378) {
if(R.isCont($e73777378)) {
var $ss73817382 = {"from":L[1403],
"go":function(anf_arg61667389) {
return $Hanf_arg106637392(anf_arg61667389,l15177390,s_DASH_id_DASH_letrec4002101,safe15197391);
}};
$e73777378.stack[R.EXN_STACKHEIGHT++] = $ss73817382;
}
if(R.isPyretException($e73777378)) {
$e73777378.pyretStack.push(L[1403]);
}
throw $e73777378;
}
var $ret73837384 = $Hanf_arg106637392($z73797380,l15177390,s_DASH_id_DASH_letrec4002101,safe15197391);
++R.GAS;
return $ret73837384;
});
};
},{"length":4});
var anf_obj61696682 = R.makeMethod(function(self15207373) {
return function(l15217376) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1401],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l15217376],[L[1402]],function() {
var $z73657366 = D;
var $f73717372 = function(_) {
return R.isFunction(s_DASH_undefined4022105.$var)?s_DASH_undefined4022105.$var.app(self15207373):R.ffi.throwNonFunApp(L[1401],s_DASH_undefined4022105.$var,[self15207373]);
};
try {
if(--R.GAS > 0) {
$z73657366 = $f73717372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73717372,
"from":L[1401]});
}
} catch($e73637364) {
if(R.isCont($e73637364)) {
var $ss73677368 = {"from":L[1401],
"go":function(ann_DASH_check_DASH_temp61687374) {
return $Hann_DASH_check_DASH_temp106647375(ann_DASH_check_DASH_temp61687374);
}};
$e73637364.stack[R.EXN_STACKHEIGHT++] = $ss73677368;
}
if(R.isPyretException($e73637364)) {
$e73637364.pyretStack.push(L[1401]);
}
throw $e73637364;
}
var $ret73697370 = $Hann_DASH_check_DASH_temp106647375($z73657366);
++R.GAS;
return $ret73697370;
});
};
},{"length":2});
var anf_obj61716683 = R.makeMethod(function(self15227362) {
return function(l15237358,loc15247359) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1400],2,arguments);
}
var $z73507351 = D;
var $f73567357 = function(_) {
return R.isFunction(s_DASH_srcloc4042109.$var)?s_DASH_srcloc4042109.$var.app(l15237358,loc15247359):R.ffi.throwNonFunApp(L[1400],s_DASH_srcloc4042109.$var,[l15237358,loc15247359]);
};
try {
if(--R.GAS > 0) {
$z73507351 = $f73567357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73567357,
"from":L[1400]});
}
} catch($e73487349) {
if(R.isCont($e73487349)) {
var $ss73527353 = {"from":L[1400],
"go":function(ann_DASH_check_DASH_temp61707360) {
return $Hann_DASH_check_DASH_temp106657361(ann_DASH_check_DASH_temp61707360);
}};
$e73487349.stack[R.EXN_STACKHEIGHT++] = $ss73527353;
}
if(R.isPyretException($e73487349)) {
$e73487349.pyretStack.push(L[1400]);
}
throw $e73487349;
}
var $ret73547355 = $Hann_DASH_check_DASH_temp106657361($z73507351);
++R.GAS;
return $ret73547355;
};
},{"length":3});
var anf_obj61736684 = R.makeMethod(function(self15257347) {
return function(l15267343,n15277344) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1397],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Number68],[l15267343,n15277344],[L[1398],L[1399]],function() {
var $z73357336 = D;
var $f73417342 = function(_) {
return R.isFunction(s_DASH_num4062113.$var)?s_DASH_num4062113.$var.app(l15267343,n15277344):R.ffi.throwNonFunApp(L[1397],s_DASH_num4062113.$var,[l15267343,n15277344]);
};
try {
if(--R.GAS > 0) {
$z73357336 = $f73417342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73417342,
"from":L[1397]});
}
} catch($e73337334) {
if(R.isCont($e73337334)) {
var $ss73377338 = {"from":L[1397],
"go":function(ann_DASH_check_DASH_temp61727345) {
return $Hann_DASH_check_DASH_temp106667346(ann_DASH_check_DASH_temp61727345);
}};
$e73337334.stack[R.EXN_STACKHEIGHT++] = $ss73377338;
}
if(R.isPyretException($e73337334)) {
$e73337334.pyretStack.push(L[1397]);
}
throw $e73337334;
}
var $ret73397340 = $Hann_DASH_check_DASH_temp106667346($z73357336);
++R.GAS;
return $ret73397340;
});
};
},{"length":3});
var anf_obj61756685 = R.makeMethod(function(self15287332) {
return function(l15297327,num15307328,den15317329) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1393],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Number68,$type$Number68],[l15297327,num15307328,den15317329],[L[1394],L[1395],L[1396]],function() {
var $z73197320 = D;
var $f73257326 = function(_) {
return R.isFunction(s_DASH_frac4082117.$var)?s_DASH_frac4082117.$var.app(l15297327,num15307328,den15317329):R.ffi.throwNonFunApp(L[1393],s_DASH_frac4082117.$var,[l15297327,num15307328,den15317329]);
};
try {
if(--R.GAS > 0) {
$z73197320 = $f73257326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73257326,
"from":L[1393]});
}
} catch($e73177318) {
if(R.isCont($e73177318)) {
var $ss73217322 = {"from":L[1393],
"go":function(ann_DASH_check_DASH_temp61747330) {
return $Hann_DASH_check_DASH_temp106677331(ann_DASH_check_DASH_temp61747330);
}};
$e73177318.stack[R.EXN_STACKHEIGHT++] = $ss73217322;
}
if(R.isPyretException($e73177318)) {
$e73177318.pyretStack.push(L[1393]);
}
throw $e73177318;
}
var $ret73237324 = $Hann_DASH_check_DASH_temp106677331($z73197320);
++R.GAS;
return $ret73237324;
});
};
},{"length":4});
var anf_obj61776686 = R.makeMethod(function(self15327316) {
return function(l15337312,b15347313) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1390],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Boolean67],[l15337312,b15347313],[L[1391],L[1392]],function() {
var $z73047305 = D;
var $f73107311 = function(_) {
return R.isFunction(s_DASH_bool4102121.$var)?s_DASH_bool4102121.$var.app(l15337312,b15347313):R.ffi.throwNonFunApp(L[1390],s_DASH_bool4102121.$var,[l15337312,b15347313]);
};
try {
if(--R.GAS > 0) {
$z73047305 = $f73107311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73107311,
"from":L[1390]});
}
} catch($e73027303) {
if(R.isCont($e73027303)) {
var $ss73067307 = {"from":L[1390],
"go":function(ann_DASH_check_DASH_temp61767314) {
return $Hann_DASH_check_DASH_temp106687315(ann_DASH_check_DASH_temp61767314);
}};
$e73027303.stack[R.EXN_STACKHEIGHT++] = $ss73067307;
}
if(R.isPyretException($e73027303)) {
$e73027303.pyretStack.push(L[1390]);
}
throw $e73027303;
}
var $ret73087309 = $Hann_DASH_check_DASH_temp106687315($z73047305);
++R.GAS;
return $ret73087309;
});
};
},{"length":3});
var anf_obj61796687 = R.makeMethod(function(self15357301) {
return function(l15367297,s15377298) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1387],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l15367297,s15377298],[L[1388],L[1389]],function() {
var $z72897290 = D;
var $f72957296 = function(_) {
return R.isFunction(s_DASH_str4122125.$var)?s_DASH_str4122125.$var.app(l15367297,s15377298):R.ffi.throwNonFunApp(L[1387],s_DASH_str4122125.$var,[l15367297,s15377298]);
};
try {
if(--R.GAS > 0) {
$z72897290 = $f72957296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72957296,
"from":L[1387]});
}
} catch($e72877288) {
if(R.isCont($e72877288)) {
var $ss72917292 = {"from":L[1387],
"go":function(ann_DASH_check_DASH_temp61787299) {
return $Hann_DASH_check_DASH_temp106697300(ann_DASH_check_DASH_temp61787299);
}};
$e72877288.stack[R.EXN_STACKHEIGHT++] = $ss72917292;
}
if(R.isPyretException($e72877288)) {
$e72877288.pyretStack.push(L[1387]);
}
throw $e72877288;
}
var $ret72937294 = $Hann_DASH_check_DASH_temp106697300($z72897290);
++R.GAS;
return $ret72937294;
});
};
},{"length":3});
var anf_obj61836688 = R.makeMethod(function(self15387281) {
return function(l15397284,obj15407286,field15417283) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1386],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,$type$String69],[l15397284,obj15407286,field15417283],[L[1383],L[1384],L[1385]],function() {
var anf_fun61817280 = G(obj15407286,"visit",L[1382]);
var $z72727273 = D;
var $f72787279 = function(_) {
return R.isFunction(anf_fun61817280)?anf_fun61817280.app(self15387281):R.ffi.throwNonFunApp(L[1381],anf_fun61817280,[self15387281]);
};
try {
if(--R.GAS > 0) {
$z72727273 = $f72787279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72787279,
"from":L[1381]});
}
} catch($e72707271) {
if(R.isCont($e72707271)) {
var $ss72747275 = {"from":L[1381],
"go":function(anf_arg61827282) {
return $Hanf_arg106717285(anf_arg61827282,field15417283,l15397284,s_DASH_dot4142129);
}};
$e72707271.stack[R.EXN_STACKHEIGHT++] = $ss72747275;
}
if(R.isPyretException($e72707271)) {
$e72707271.pyretStack.push(L[1381]);
}
throw $e72707271;
}
var $ret72767277 = $Hanf_arg106717285($z72727273,field15417283,l15397284,s_DASH_dot4142129);
++R.GAS;
return $ret72767277;
});
};
},{"length":4});
var anf_obj61876689 = R.makeMethod(function(self15427264) {
return function(l15437267,obj15447269,field15457266) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1380],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,$type$String69],[l15437267,obj15447269,field15457266],[L[1377],L[1378],L[1379]],function() {
var anf_fun61857263 = G(obj15447269,"visit",L[1376]);
var $z72557256 = D;
var $f72617262 = function(_) {
return R.isFunction(anf_fun61857263)?anf_fun61857263.app(self15427264):R.ffi.throwNonFunApp(L[1375],anf_fun61857263,[self15427264]);
};
try {
if(--R.GAS > 0) {
$z72557256 = $f72617262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72617262,
"from":L[1375]});
}
} catch($e72537254) {
if(R.isCont($e72537254)) {
var $ss72577258 = {"from":L[1375],
"go":function(anf_arg61867265) {
return $Hanf_arg106737268(anf_arg61867265,field15457266,l15437267,s_DASH_get_DASH_bang4162133);
}};
$e72537254.stack[R.EXN_STACKHEIGHT++] = $ss72577258;
}
if(R.isPyretException($e72537254)) {
$e72537254.pyretStack.push(L[1375]);
}
throw $e72537254;
}
var $ret72597260 = $Hanf_arg106737268($z72557256,field15457266,l15437267,s_DASH_get_DASH_bang4162133);
++R.GAS;
return $ret72597260;
});
};
},{"length":4});
var anf_obj61936690 = R.makeMethod(function(self15467247) {
return function(l15477250,obj15487252,field15497249) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1374],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l15477250,obj15487252,field15497249],[L[1371],L[1372],L[1373]],function() {
var anf_fun61897246 = G(obj15487252,"visit",L[1370]);
var $z72387239 = D;
var $f72447245 = function(_) {
return R.isFunction(anf_fun61897246)?anf_fun61897246.app(self15467247):R.ffi.throwNonFunApp(L[1369],anf_fun61897246,[self15467247]);
};
try {
if(--R.GAS > 0) {
$z72387239 = $f72447245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72447245,
"from":L[1369]});
}
} catch($e72367237) {
if(R.isCont($e72367237)) {
var $ss72407241 = {"from":L[1369],
"go":function(anf_arg61907248) {
return $Hanf_arg106767251(anf_arg61907248,field15497249,l15477250,s_DASH_bracket4182137,self15467247);
}};
$e72367237.stack[R.EXN_STACKHEIGHT++] = $ss72407241;
}
if(R.isPyretException($e72367237)) {
$e72367237.pyretStack.push(L[1369]);
}
throw $e72367237;
}
var $ret72427243 = $Hanf_arg106767251($z72387239,field15497249,l15477250,s_DASH_bracket4182137,self15467247);
++R.GAS;
return $ret72427243;
});
};
},{"length":4});
var anf_obj62176691 = R.makeMethod(function(self15507217) {
return function(l15517214,name15527216,params15537235,mixins15547215,variants15557219,shared_DASH_members15567218,_check15577213) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[1368],7,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,List17129,List17129,List17129,Option18135],[l15517214,name15527216,params15537235,mixins15547215,variants15557219,shared_DASH_members15567218,_check15577213],[L[1361],L[1362],L[1363],L[1364],L[1365],L[1366],L[1367]],function() {
var anf_fun61957210 = G(params15537235,"map",L[1360]);
var anf_arg61987211 = R.makeFunction(function(recv_DASH_7447221) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1359],1,arguments);
}
var anf_fun61977232 = G(recv_DASH_7447221,"visit",L[1359]);
var $z72247225 = D;
var $f72307231 = function(_) {
return R.isFunction(anf_fun61977232)?anf_fun61977232.app(self15507217):R.ffi.throwNonFunApp(L[1359],anf_fun61977232,[self15507217]);
};
try {
if(--R.GAS > 0) {
$z72247225 = $f72307231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72307231,
"from":L[1359]});
}
} catch($e72227223) {
if(R.isCont($e72227223)) {
var $ss72267227 = {"from":L[1359],
"go":function(ann_DASH_check_DASH_temp61967233) {
return $Hann_DASH_check_DASH_temp106777234(ann_DASH_check_DASH_temp61967233);
}};
$e72227223.stack[R.EXN_STACKHEIGHT++] = $ss72267227;
}
if(R.isPyretException($e72227223)) {
$e72227223.pyretStack.push(L[1359]);
}
throw $e72227223;
}
var $ret72287229 = $Hann_DASH_check_DASH_temp106777234($z72247225);
++R.GAS;
return $ret72287229;
});
var $z72027203 = D;
var $f72087209 = function(_) {
return R.isFunction(anf_fun61957210)?anf_fun61957210.app(anf_arg61987211):R.ffi.throwNonFunApp(L[1358],anf_fun61957210,[anf_arg61987211]);
};
try {
if(--R.GAS > 0) {
$z72027203 = $f72087209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72087209,
"from":L[1358]});
}
} catch($e72007201) {
if(R.isCont($e72007201)) {
var $ss72047205 = {"from":L[1358],
"go":function(anf_arg61997212) {
return $Hanf_arg106867220(anf_arg61997212,_check15577213,l15517214,mixins15547215,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218,variants15557219);
}};
$e72007201.stack[R.EXN_STACKHEIGHT++] = $ss72047205;
}
if(R.isPyretException($e72007201)) {
$e72007201.pyretStack.push(L[1358]);
}
throw $e72007201;
}
var $ret72067207 = $Hanf_arg106867220($z72027203,_check15577213,l15517214,mixins15547215,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218,variants15557219);
++R.GAS;
return $ret72067207;
});
};
},{"length":8});
var anf_obj62436692 = R.makeMethod(function(self15587189) {
return function(l15597192,name15607194,namet15617199,params15627195,mixins15637193,variants15647197,shared_DASH_members15657196,_check15667191) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[1357],8,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Name66133,List17129,List17129,List17129,List17129,Option18135],[l15597192,name15607194,namet15617199,params15627195,mixins15637193,variants15647197,shared_DASH_members15657196,_check15667191],[L[1349],L[1350],L[1351],L[1352],L[1353],L[1354],L[1355],L[1356]],function() {
var anf_fun62197188 = G(namet15617199,"visit",L[1348]);
var $z71807181 = D;
var $f71867187 = function(_) {
return R.isFunction(anf_fun62197188)?anf_fun62197188.app(self15587189):R.ffi.throwNonFunApp(L[1347],anf_fun62197188,[self15587189]);
};
try {
if(--R.GAS > 0) {
$z71807181 = $f71867187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71867187,
"from":L[1347]});
}
} catch($e71787179) {
if(R.isCont($e71787179)) {
var $ss71827183 = {"from":L[1347],
"go":function(anf_arg62207190) {
return $Hanf_arg106977198(anf_arg62207190,_check15667191,l15597192,mixins15637193,name15607194,params15627195,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197);
}};
$e71787179.stack[R.EXN_STACKHEIGHT++] = $ss71827183;
}
if(R.isPyretException($e71787179)) {
$e71787179.pyretStack.push(L[1347]);
}
throw $e71787179;
}
var $ret71847185 = $Hanf_arg106977198($z71807181,_check15667191,l15597192,mixins15637193,name15607194,params15627195,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197);
++R.GAS;
return $ret71847185;
});
};
},{"length":9});
var anf_obj62566693 = R.makeMethod(function(self15677170) {
return function(l15687175,iterator15697177,bindings15707173,ann15717172,body15727174) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1346],5,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129,Ann11299,Expr86111],[l15687175,iterator15697177,bindings15707173,ann15717172,body15727174],[L[1341],L[1342],L[1343],L[1344],L[1345]],function() {
var anf_fun62457169 = G(iterator15697177,"visit",L[1340]);
var $z71617162 = D;
var $f71677168 = function(_) {
return R.isFunction(anf_fun62457169)?anf_fun62457169.app(self15677170):R.ffi.throwNonFunApp(L[1339],anf_fun62457169,[self15677170]);
};
try {
if(--R.GAS > 0) {
$z71617162 = $f71677168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71677168,
"from":L[1339]});
}
} catch($e71597160) {
if(R.isCont($e71597160)) {
var $ss71637164 = {"from":L[1339],
"go":function(anf_arg62467171) {
return $Hanf_arg107037176(anf_arg62467171,ann15717172,bindings15707173,body15727174,l15687175,s_DASH_for4242149,self15677170);
}};
$e71597160.stack[R.EXN_STACKHEIGHT++] = $ss71637164;
}
if(R.isPyretException($e71597160)) {
$e71597160.pyretStack.push(L[1339]);
}
throw $e71597160;
}
var $ret71657166 = $Hanf_arg107037176($z71617162,ann15717172,bindings15707173,body15727174,l15687175,s_DASH_for4242149,self15677170);
++R.GAS;
return $ret71657166;
});
};
},{"length":6});
var anf_obj62606694 = R.makeMethod(function(self15737152) {
return function(l15747155,name15757156,body15767158,keyword_DASH_check15777154) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1338],4,arguments);
}
return R.checkAnnArgs([Loc116130,Option18135,Expr86111,$type$Boolean67],[l15747155,name15757156,body15767158,keyword_DASH_check15777154],[L[1334],L[1335],L[1336],L[1337]],function() {
var anf_fun62587151 = G(body15767158,"visit",L[1333]);
var $z71437144 = D;
var $f71497150 = function(_) {
return R.isFunction(anf_fun62587151)?anf_fun62587151.app(self15737152):R.ffi.throwNonFunApp(L[1332],anf_fun62587151,[self15737152]);
};
try {
if(--R.GAS > 0) {
$z71437144 = $f71497150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71497150,
"from":L[1332]});
}
} catch($e71417142) {
if(R.isCont($e71417142)) {
var $ss71457146 = {"from":L[1332],
"go":function(anf_arg62597153) {
return $Hanf_arg107057157(anf_arg62597153,keyword_DASH_check15777154,l15747155,name15757156,s_DASH_check4262153);
}};
$e71417142.stack[R.EXN_STACKHEIGHT++] = $ss71457146;
}
if(R.isPyretException($e71417142)) {
$e71417142.pyretStack.push(L[1332]);
}
throw $e71417142;
}
var $ret71477148 = $Hanf_arg107057157($z71437144,keyword_DASH_check15777154,l15747155,name15757156,s_DASH_check4262153);
++R.GAS;
return $ret71477148;
});
};
},{"length":5});
var anf_obj62666695 = R.makeMethod(function(self15787135) {
return function(l15797137,name15807140,value15817138) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1331],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l15797137,name15807140,value15817138],[L[1328],L[1329],L[1330]],function() {
var anf_fun62627134 = G(name15807140,"visit",L[1327]);
var $z71267127 = D;
var $f71327133 = function(_) {
return R.isFunction(anf_fun62627134)?anf_fun62627134.app(self15787135):R.ffi.throwNonFunApp(L[1326],anf_fun62627134,[self15787135]);
};
try {
if(--R.GAS > 0) {
$z71267127 = $f71327133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71327133,
"from":L[1326]});
}
} catch($e71247125) {
if(R.isCont($e71247125)) {
var $ss71287129 = {"from":L[1326],
"go":function(anf_arg62637136) {
return $Hanf_arg107087139(anf_arg62637136,l15797137,s_DASH_data_DASH_field4432187,self15787135,value15817138);
}};
$e71247125.stack[R.EXN_STACKHEIGHT++] = $ss71287129;
}
if(R.isPyretException($e71247125)) {
$e71247125.pyretStack.push(L[1326]);
}
throw $e71247125;
}
var $ret71307131 = $Hanf_arg107087139($z71267127,l15797137,s_DASH_data_DASH_field4432187,self15787135,value15817138);
++R.GAS;
return $ret71307131;
});
};
},{"length":4});
var anf_obj62746696 = R.makeMethod(function(self15827117) {
return function(l15837120,name15847123,ann15857119,value15867121) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1325],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Ann11299,Expr86111],[l15837120,name15847123,ann15857119,value15867121],[L[1321],L[1322],L[1323],L[1324]],function() {
var anf_fun62687116 = G(name15847123,"visit",L[1320]);
var $z71087109 = D;
var $f71147115 = function(_) {
return R.isFunction(anf_fun62687116)?anf_fun62687116.app(self15827117):R.ffi.throwNonFunApp(L[1319],anf_fun62687116,[self15827117]);
};
try {
if(--R.GAS > 0) {
$z71087109 = $f71147115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71147115,
"from":L[1319]});
}
} catch($e71067107) {
if(R.isCont($e71067107)) {
var $ss71107111 = {"from":L[1319],
"go":function(anf_arg62697118) {
return $Hanf_arg107127122(anf_arg62697118,ann15857119,l15837120,s_DASH_mutable_DASH_field4452191,self15827117,value15867121);
}};
$e71067107.stack[R.EXN_STACKHEIGHT++] = $ss71107111;
}
if(R.isPyretException($e71067107)) {
$e71067107.pyretStack.push(L[1319]);
}
throw $e71067107;
}
var $ret71127113 = $Hanf_arg107127122($z71087109,ann15857119,l15837120,s_DASH_mutable_DASH_field4452191,self15827117,value15867121);
++R.GAS;
return $ret71127113;
});
};
},{"length":5});
var anf_obj62826697 = R.makeMethod(function(self15877099) {
return function(l15887102,name15897105,ann15907101,value15917103) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1318],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Ann11299,Expr86111],[l15887102,name15897105,ann15907101,value15917103],[L[1314],L[1315],L[1316],L[1317]],function() {
var anf_fun62767098 = G(name15897105,"visit",L[1313]);
var $z70907091 = D;
var $f70967097 = function(_) {
return R.isFunction(anf_fun62767098)?anf_fun62767098.app(self15877099):R.ffi.throwNonFunApp(L[1312],anf_fun62767098,[self15877099]);
};
try {
if(--R.GAS > 0) {
$z70907091 = $f70967097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70967097,
"from":L[1312]});
}
} catch($e70887089) {
if(R.isCont($e70887089)) {
var $ss70927093 = {"from":L[1312],
"go":function(anf_arg62777100) {
return $Hanf_arg107167104(anf_arg62777100,ann15907101,l15887102,s_DASH_once_DASH_field4472195,self15877099,value15917103);
}};
$e70887089.stack[R.EXN_STACKHEIGHT++] = $ss70927093;
}
if(R.isPyretException($e70887089)) {
$e70887089.pyretStack.push(L[1312]);
}
throw $e70887089;
}
var $ret70947095 = $Hanf_arg107167104($z70907091,ann15907101,l15887102,s_DASH_once_DASH_field4472195,self15877099,value15917103);
++R.GAS;
return $ret70947095;
});
};
},{"length":5});
var anf_obj62976698 = R.makeMethod(function(self15927078) {
return function(l15937085,name15947087,args15957082,ann15967081,doc15977084,body15987083,_check15997080) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[1311],7,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l15937085,name15947087,args15957082,ann15967081,doc15977084,body15987083,_check15997080],[L[1304],L[1305],L[1306],L[1307],L[1308],L[1309],L[1310]],function() {
var anf_fun62847077 = G(name15947087,"visit",L[1303]);
var $z70697070 = D;
var $f70757076 = function(_) {
return R.isFunction(anf_fun62847077)?anf_fun62847077.app(self15927078):R.ffi.throwNonFunApp(L[1302],anf_fun62847077,[self15927078]);
};
try {
if(--R.GAS > 0) {
$z70697070 = $f70757076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70757076,
"from":L[1302]});
}
} catch($e70677068) {
if(R.isCont($e70677068)) {
var $ss70717072 = {"from":L[1302],
"go":function(anf_arg62857079) {
return $Hanf_arg107237086(anf_arg62857079,_check15997080,ann15967081,args15957082,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078);
}};
$e70677068.stack[R.EXN_STACKHEIGHT++] = $ss70717072;
}
if(R.isPyretException($e70677068)) {
$e70677068.pyretStack.push(L[1302]);
}
throw $e70677068;
}
var $ret70737074 = $Hanf_arg107237086($z70697070,_check15997080,ann15967081,args15957082,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078);
++R.GAS;
return $ret70737074;
});
};
},{"length":8});
var anf_obj63036699 = R.makeMethod(function(self16007061) {
return function(l16017063,bind16027066,value16037064) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1301],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l16017063,bind16027066,value16037064],[L[1298],L[1299],L[1300]],function() {
var anf_fun62997060 = G(bind16027066,"visit",L[1297]);
var $z70527053 = D;
var $f70587059 = function(_) {
return R.isFunction(anf_fun62997060)?anf_fun62997060.app(self16007061):R.ffi.throwNonFunApp(L[1296],anf_fun62997060,[self16007061]);
};
try {
if(--R.GAS > 0) {
$z70527053 = $f70587059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70587059,
"from":L[1296]});
}
} catch($e70507051) {
if(R.isCont($e70507051)) {
var $ss70547055 = {"from":L[1296],
"go":function(anf_arg63007062) {
return $Hanf_arg107267065(anf_arg63007062,l16017063,s_DASH_for_DASH_bind4542209,self16007061,value16037064);
}};
$e70507051.stack[R.EXN_STACKHEIGHT++] = $ss70547055;
}
if(R.isPyretException($e70507051)) {
$e70507051.pyretStack.push(L[1296]);
}
throw $e70507051;
}
var $ret70567057 = $Hanf_arg107267065($z70527053,l16017063,s_DASH_for_DASH_bind4542209,self16007061,value16037064);
++R.GAS;
return $ret70567057;
});
};
},{"length":4});
var anf_obj63076700 = R.makeMethod(function(self16047044) {
return function(l16057046,member_DASH_type16067047,bind16077049) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1295],3,arguments);
}
return R.checkAnnArgs([Loc116130,VariantMemberType96147,Bind90101],[l16057046,member_DASH_type16067047,bind16077049],[L[1292],L[1293],L[1294]],function() {
var anf_fun63057043 = G(bind16077049,"visit",L[1291]);
var $z70357036 = D;
var $f70417042 = function(_) {
return R.isFunction(anf_fun63057043)?anf_fun63057043.app(self16047044):R.ffi.throwNonFunApp(L[1290],anf_fun63057043,[self16047044]);
};
try {
if(--R.GAS > 0) {
$z70357036 = $f70417042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70417042,
"from":L[1290]});
}
} catch($e70337034) {
if(R.isCont($e70337034)) {
var $ss70377038 = {"from":L[1290],
"go":function(anf_arg63067045) {
return $Hanf_arg107287048(anf_arg63067045,l16057046,member_DASH_type16067047,s_DASH_variant_DASH_member4682237);
}};
$e70337034.stack[R.EXN_STACKHEIGHT++] = $ss70377038;
}
if(R.isPyretException($e70337034)) {
$e70337034.pyretStack.push(L[1290]);
}
throw $e70337034;
}
var $ret70397040 = $Hanf_arg107287048($z70357036,l16057046,member_DASH_type16067047,s_DASH_variant_DASH_member4682237);
++R.GAS;
return $ret70397040;
});
};
},{"length":4});
var anf_obj63196701 = R.makeMethod(function(self16087015) {
return function(l16097013,constr_DASH_loc16107012,name16117014,members16127032,with_DASH_members16137016) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1289],5,arguments);
}
return R.checkAnnArgs([Loc116130,Loc116130,$type$String69,List17129,List17129],[l16097013,constr_DASH_loc16107012,name16117014,members16127032,with_DASH_members16137016],[L[1284],L[1285],L[1286],L[1287],L[1288]],function() {
var anf_fun63097009 = G(members16127032,"map",L[1283]);
var anf_arg63127010 = R.makeFunction(function(recv_DASH_7547018) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1282],1,arguments);
}
var anf_fun63117029 = G(recv_DASH_7547018,"visit",L[1282]);
var $z70217022 = D;
var $f70277028 = function(_) {
return R.isFunction(anf_fun63117029)?anf_fun63117029.app(self16087015):R.ffi.throwNonFunApp(L[1282],anf_fun63117029,[self16087015]);
};
try {
if(--R.GAS > 0) {
$z70217022 = $f70277028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70277028,
"from":L[1282]});
}
} catch($e70197020) {
if(R.isCont($e70197020)) {
var $ss70237024 = {"from":L[1282],
"go":function(ann_DASH_check_DASH_temp63107030) {
return $Hann_DASH_check_DASH_temp107297031(ann_DASH_check_DASH_temp63107030);
}};
$e70197020.stack[R.EXN_STACKHEIGHT++] = $ss70237024;
}
if(R.isPyretException($e70197020)) {
$e70197020.pyretStack.push(L[1282]);
}
throw $e70197020;
}
var $ret70257026 = $Hann_DASH_check_DASH_temp107297031($z70217022);
++R.GAS;
return $ret70257026;
});
var $z70017002 = D;
var $f70077008 = function(_) {
return R.isFunction(anf_fun63097009)?anf_fun63097009.app(anf_arg63127010):R.ffi.throwNonFunApp(L[1281],anf_fun63097009,[anf_arg63127010]);
};
try {
if(--R.GAS > 0) {
$z70017002 = $f70077008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70077008,
"from":L[1281]});
}
} catch($e69997000) {
if(R.isCont($e69997000)) {
var $ss70037004 = {"from":L[1281],
"go":function(anf_arg63137011) {
return $Hanf_arg107337017(anf_arg63137011,constr_DASH_loc16107012,l16097013,name16117014,s_DASH_variant4732247,self16087015,with_DASH_members16137016);
}};
$e69997000.stack[R.EXN_STACKHEIGHT++] = $ss70037004;
}
if(R.isPyretException($e69997000)) {
$e69997000.pyretStack.push(L[1281]);
}
throw $e69997000;
}
var $ret70057006 = $Hanf_arg107337017($z70017002,constr_DASH_loc16107012,l16097013,name16117014,s_DASH_variant4732247,self16087015,with_DASH_members16137016);
++R.GAS;
return $ret70057006;
});
};
},{"length":6});
var anf_obj63266702 = R.makeMethod(function(self16146995) {
return function(l16156980,name16166981,with_DASH_members16176998) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1280],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129],[l16156980,name16166981,with_DASH_members16176998],[L[1277],L[1278],L[1279]],function() {
var anf_fun63216977 = G(with_DASH_members16176998,"map",L[1276]);
var anf_arg63246978 = R.makeFunction(function(recv_DASH_7566983) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1275],1,arguments);
}
var anf_fun63236994 = G(recv_DASH_7566983,"visit",L[1275]);
var $z69866987 = D;
var $f69926993 = function(_) {
return R.isFunction(anf_fun63236994)?anf_fun63236994.app(self16146995):R.ffi.throwNonFunApp(L[1275],anf_fun63236994,[self16146995]);
};
try {
if(--R.GAS > 0) {
$z69866987 = $f69926993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69926993,
"from":L[1275]});
}
} catch($e69846985) {
if(R.isCont($e69846985)) {
var $ss69886989 = {"from":L[1275],
"go":function(ann_DASH_check_DASH_temp63226996) {
return $Hann_DASH_check_DASH_temp107346997(ann_DASH_check_DASH_temp63226996);
}};
$e69846985.stack[R.EXN_STACKHEIGHT++] = $ss69886989;
}
if(R.isPyretException($e69846985)) {
$e69846985.pyretStack.push(L[1275]);
}
throw $e69846985;
}
var $ret69906991 = $Hann_DASH_check_DASH_temp107346997($z69866987);
++R.GAS;
return $ret69906991;
});
var $z69696970 = D;
var $f69756976 = function(_) {
return R.isFunction(anf_fun63216977)?anf_fun63216977.app(anf_arg63246978):R.ffi.throwNonFunApp(L[1274],anf_fun63216977,[anf_arg63246978]);
};
try {
if(--R.GAS > 0) {
$z69696970 = $f69756976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69756976,
"from":L[1274]});
}
} catch($e69676968) {
if(R.isCont($e69676968)) {
var $ss69716972 = {"from":L[1274],
"go":function(anf_arg63256979) {
return $Hanf_arg107366982(anf_arg63256979,l16156980,name16166981,s_DASH_singleton_DASH_variant4752251);
}};
$e69676968.stack[R.EXN_STACKHEIGHT++] = $ss69716972;
}
if(R.isPyretException($e69676968)) {
$e69676968.pyretStack.push(L[1274]);
}
throw $e69676968;
}
var $ret69736974 = $Hanf_arg107366982($z69696970,l16156980,name16166981,s_DASH_singleton_DASH_variant4752251);
++R.GAS;
return $ret69736974;
});
};
},{"length":4});
var anf_obj63356703 = R.makeMethod(function(self16186950) {
return function(l16196948,name16206949,members16216966,constructor16226947) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1273],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,Constructor104107],[l16196948,name16206949,members16216966,constructor16226947],[L[1269],L[1270],L[1271],L[1272]],function() {
var anf_fun63286944 = G(members16216966,"map",L[1268]);
var anf_arg63316945 = R.makeFunction(function(recv_DASH_7576952) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1267],1,arguments);
}
var anf_fun63306963 = G(recv_DASH_7576952,"visit",L[1267]);
var $z69556956 = D;
var $f69616962 = function(_) {
return R.isFunction(anf_fun63306963)?anf_fun63306963.app(self16186950):R.ffi.throwNonFunApp(L[1267],anf_fun63306963,[self16186950]);
};
try {
if(--R.GAS > 0) {
$z69556956 = $f69616962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69616962,
"from":L[1267]});
}
} catch($e69536954) {
if(R.isCont($e69536954)) {
var $ss69576958 = {"from":L[1267],
"go":function(ann_DASH_check_DASH_temp63296964) {
return $Hann_DASH_check_DASH_temp107376965(ann_DASH_check_DASH_temp63296964);
}};
$e69536954.stack[R.EXN_STACKHEIGHT++] = $ss69576958;
}
if(R.isPyretException($e69536954)) {
$e69536954.pyretStack.push(L[1267]);
}
throw $e69536954;
}
var $ret69596960 = $Hann_DASH_check_DASH_temp107376965($z69556956);
++R.GAS;
return $ret69596960;
});
var $z69366937 = D;
var $f69426943 = function(_) {
return R.isFunction(anf_fun63286944)?anf_fun63286944.app(anf_arg63316945):R.ffi.throwNonFunApp(L[1266],anf_fun63286944,[anf_arg63316945]);
};
try {
if(--R.GAS > 0) {
$z69366937 = $f69426943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69426943,
"from":L[1266]});
}
} catch($e69346935) {
if(R.isCont($e69346935)) {
var $ss69386939 = {"from":L[1266],
"go":function(anf_arg63326946) {
return $Hanf_arg107406951(anf_arg63326946,constructor16226947,l16196948,name16206949,s_DASH_datatype_DASH_variant4802261,self16186950);
}};
$e69346935.stack[R.EXN_STACKHEIGHT++] = $ss69386939;
}
if(R.isPyretException($e69346935)) {
$e69346935.pyretStack.push(L[1266]);
}
throw $e69346935;
}
var $ret69406941 = $Hanf_arg107406951($z69366937,constructor16226947,l16196948,name16206949,s_DASH_datatype_DASH_variant4802261,self16186950);
++R.GAS;
return $ret69406941;
});
};
},{"length":5});
var anf_obj63396704 = R.makeMethod(function(self16236928) {
return function(l16246930,name16256931,constructor16266933) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1265],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Constructor104107],[l16246930,name16256931,constructor16266933],[L[1262],L[1263],L[1264]],function() {
var anf_fun63376927 = G(constructor16266933,"visit",L[1261]);
var $z69196920 = D;
var $f69256926 = function(_) {
return R.isFunction(anf_fun63376927)?anf_fun63376927.app(self16236928):R.ffi.throwNonFunApp(L[1260],anf_fun63376927,[self16236928]);
};
try {
if(--R.GAS > 0) {
$z69196920 = $f69256926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69256926,
"from":L[1260]});
}
} catch($e69176918) {
if(R.isCont($e69176918)) {
var $ss69216922 = {"from":L[1260],
"go":function(anf_arg63386929) {
return $Hanf_arg107426932(anf_arg63386929,l16246930,name16256931,s_DASH_datatype_DASH_singleton_DASH_variant4822265);
}};
$e69176918.stack[R.EXN_STACKHEIGHT++] = $ss69216922;
}
if(R.isPyretException($e69176918)) {
$e69176918.pyretStack.push(L[1260]);
}
throw $e69176918;
}
var $ret69236924 = $Hanf_arg107426932($z69196920,l16246930,name16256931,s_DASH_datatype_DASH_singleton_DASH_variant4822265);
++R.GAS;
return $ret69236924;
});
};
},{"length":4});
var anf_obj63436705 = R.makeMethod(function(self16276911) {
return function(l16286913,self_DASH_arg16296914,body16306916) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1259],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111],[l16286913,self_DASH_arg16296914,body16306916],[L[1256],L[1257],L[1258]],function() {
var anf_fun63416910 = G(body16306916,"visit",L[1255]);
var $z69026903 = D;
var $f69086909 = function(_) {
return R.isFunction(anf_fun63416910)?anf_fun63416910.app(self16276911):R.ffi.throwNonFunApp(L[1254],anf_fun63416910,[self16276911]);
};
try {
if(--R.GAS > 0) {
$z69026903 = $f69086909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69086909,
"from":L[1254]});
}
} catch($e69006901) {
if(R.isCont($e69006901)) {
var $ss69046905 = {"from":L[1254],
"go":function(anf_arg63426912) {
return $Hanf_arg107446915(anf_arg63426912,l16286913,s_DASH_datatype_DASH_constructor4872275,self_DASH_arg16296914);
}};
$e69006901.stack[R.EXN_STACKHEIGHT++] = $ss69046905;
}
if(R.isPyretException($e69006901)) {
$e69006901.pyretStack.push(L[1254]);
}
throw $e69006901;
}
var $ret69066907 = $Hanf_arg107446915($z69026903,l16286913,s_DASH_datatype_DASH_constructor4872275,self_DASH_arg16296914);
++R.GAS;
return $ret69066907;
});
};
},{"length":4});
var anf_obj63456706 = R.makeMethod(function(self16316899) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1253],0,arguments);
}
var ann_DASH_check_DASH_temp63446898 = a_DASH_blank5072315.$var;
return ann_DASH_check_DASH_temp63446898;
};
},{"length":1});
var anf_obj63476707 = R.makeMethod(function(self16326897) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1252],0,arguments);
}
var ann_DASH_check_DASH_temp63466896 = a_DASH_any5092319.$var;
return ann_DASH_check_DASH_temp63466896;
};
},{"length":1});
var anf_obj63516708 = R.makeMethod(function(self16336891) {
return function(l16346893,id16356895) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1251],2,arguments);
}
var anf_fun63496890 = G(id16356895,"visit",L[1250]);
var $z68826883 = D;
var $f68886889 = function(_) {
return R.isFunction(anf_fun63496890)?anf_fun63496890.app(self16336891):R.ffi.throwNonFunApp(L[1249],anf_fun63496890,[self16336891]);
};
try {
if(--R.GAS > 0) {
$z68826883 = $f68886889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68886889,
"from":L[1249]});
}
} catch($e68806881) {
if(R.isCont($e68806881)) {
var $ss68846885 = {"from":L[1249],
"go":function(anf_arg63506892) {
return $Hanf_arg107466894(anf_arg63506892,a_DASH_name5112323,l16346893);
}};
$e68806881.stack[R.EXN_STACKHEIGHT++] = $ss68846885;
}
if(R.isPyretException($e68806881)) {
$e68806881.pyretStack.push(L[1249]);
}
throw $e68806881;
}
var $ret68866887 = $Hanf_arg107466894($z68826883,a_DASH_name5112323,l16346893);
++R.GAS;
return $ret68866887;
};
},{"length":3});
var anf_obj63606709 = R.makeMethod(function(self16366862) {
return function(l16376860,args16386879,ret16396861,use_DASH_parens16406863) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1248],4,arguments);
}
var anf_fun63536857 = G(args16386879,"map",L[1247]);
var anf_arg63566858 = R.makeFunction(function(recv_DASH_7586865) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1246],1,arguments);
}
var anf_fun63556876 = G(recv_DASH_7586865,"visit",L[1246]);
var $z68686869 = D;
var $f68746875 = function(_) {
return R.isFunction(anf_fun63556876)?anf_fun63556876.app(self16366862):R.ffi.throwNonFunApp(L[1246],anf_fun63556876,[self16366862]);
};
try {
if(--R.GAS > 0) {
$z68686869 = $f68746875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68746875,
"from":L[1246]});
}
} catch($e68666867) {
if(R.isCont($e68666867)) {
var $ss68706871 = {"from":L[1246],
"go":function(ann_DASH_check_DASH_temp63546877) {
return $Hann_DASH_check_DASH_temp107476878(ann_DASH_check_DASH_temp63546877);
}};
$e68666867.stack[R.EXN_STACKHEIGHT++] = $ss68706871;
}
if(R.isPyretException($e68666867)) {
$e68666867.pyretStack.push(L[1246]);
}
throw $e68666867;
}
var $ret68726873 = $Hann_DASH_check_DASH_temp107476878($z68686869);
++R.GAS;
return $ret68726873;
});
var $z68496850 = D;
var $f68556856 = function(_) {
return R.isFunction(anf_fun63536857)?anf_fun63536857.app(anf_arg63566858):R.ffi.throwNonFunApp(L[1245],anf_fun63536857,[anf_arg63566858]);
};
try {
if(--R.GAS > 0) {
$z68496850 = $f68556856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68556856,
"from":L[1245]});
}
} catch($e68476848) {
if(R.isCont($e68476848)) {
var $ss68516852 = {"from":L[1245],
"go":function(anf_arg63576859) {
return $Hanf_arg107506864(anf_arg63576859,a_DASH_arrow5132327,l16376860,ret16396861,self16366862,use_DASH_parens16406863);
}};
$e68476848.stack[R.EXN_STACKHEIGHT++] = $ss68516852;
}
if(R.isPyretException($e68476848)) {
$e68476848.pyretStack.push(L[1245]);
}
throw $e68476848;
}
var $ret68536854 = $Hanf_arg107506864($z68496850,a_DASH_arrow5132327,l16376860,ret16396861,self16366862,use_DASH_parens16406863);
++R.GAS;
return $ret68536854;
};
},{"length":5});
var anf_obj63696710 = R.makeMethod(function(self16416830) {
return function(l16426828,args16436846,ret16446829) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1244],3,arguments);
}
var anf_fun63626825 = G(args16436846,"map",L[1243]);
var anf_arg63656826 = R.makeFunction(function(recv_DASH_7596832) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1242],1,arguments);
}
var anf_fun63646843 = G(recv_DASH_7596832,"visit",L[1242]);
var $z68356836 = D;
var $f68416842 = function(_) {
return R.isFunction(anf_fun63646843)?anf_fun63646843.app(self16416830):R.ffi.throwNonFunApp(L[1242],anf_fun63646843,[self16416830]);
};
try {
if(--R.GAS > 0) {
$z68356836 = $f68416842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68416842,
"from":L[1242]});
}
} catch($e68336834) {
if(R.isCont($e68336834)) {
var $ss68376838 = {"from":L[1242],
"go":function(ann_DASH_check_DASH_temp63636844) {
return $Hann_DASH_check_DASH_temp107516845(ann_DASH_check_DASH_temp63636844);
}};
$e68336834.stack[R.EXN_STACKHEIGHT++] = $ss68376838;
}
if(R.isPyretException($e68336834)) {
$e68336834.pyretStack.push(L[1242]);
}
throw $e68336834;
}
var $ret68396840 = $Hann_DASH_check_DASH_temp107516845($z68356836);
++R.GAS;
return $ret68396840;
});
var $z68176818 = D;
var $f68236824 = function(_) {
return R.isFunction(anf_fun63626825)?anf_fun63626825.app(anf_arg63656826):R.ffi.throwNonFunApp(L[1241],anf_fun63626825,[anf_arg63656826]);
};
try {
if(--R.GAS > 0) {
$z68176818 = $f68236824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68236824,
"from":L[1241]});
}
} catch($e68156816) {
if(R.isCont($e68156816)) {
var $ss68196820 = {"from":L[1241],
"go":function(anf_arg63666827) {
return $Hanf_arg107546831(anf_arg63666827,a_DASH_method5152331,l16426828,ret16446829,self16416830);
}};
$e68156816.stack[R.EXN_STACKHEIGHT++] = $ss68196820;
}
if(R.isPyretException($e68156816)) {
$e68156816.pyretStack.push(L[1241]);
}
throw $e68156816;
}
var $ret68216822 = $Hanf_arg107546831($z68176818,a_DASH_method5152331,l16426828,ret16446829,self16416830);
++R.GAS;
return $ret68216822;
};
},{"length":4});
var anf_obj63766711 = R.makeMethod(function(self16456811) {
return function(l16466797,fields16476814) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1240],2,arguments);
}
var anf_fun63716794 = G(fields16476814,"map",L[1239]);
var anf_arg63746795 = R.makeFunction(function(recv_DASH_7606799) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1238],1,arguments);
}
var anf_fun63736810 = G(recv_DASH_7606799,"visit",L[1238]);
var $z68026803 = D;
var $f68086809 = function(_) {
return R.isFunction(anf_fun63736810)?anf_fun63736810.app(self16456811):R.ffi.throwNonFunApp(L[1238],anf_fun63736810,[self16456811]);
};
try {
if(--R.GAS > 0) {
$z68026803 = $f68086809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68086809,
"from":L[1238]});
}
} catch($e68006801) {
if(R.isCont($e68006801)) {
var $ss68046805 = {"from":L[1238],
"go":function(ann_DASH_check_DASH_temp63726812) {
return $Hann_DASH_check_DASH_temp107556813(ann_DASH_check_DASH_temp63726812);
}};
$e68006801.stack[R.EXN_STACKHEIGHT++] = $ss68046805;
}
if(R.isPyretException($e68006801)) {
$e68006801.pyretStack.push(L[1238]);
}
throw $e68006801;
}
var $ret68066807 = $Hann_DASH_check_DASH_temp107556813($z68026803);
++R.GAS;
return $ret68066807;
});
var $z67866787 = D;
var $f67926793 = function(_) {
return R.isFunction(anf_fun63716794)?anf_fun63716794.app(anf_arg63746795):R.ffi.throwNonFunApp(L[1237],anf_fun63716794,[anf_arg63746795]);
};
try {
if(--R.GAS > 0) {
$z67866787 = $f67926793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67926793,
"from":L[1237]});
}
} catch($e67846785) {
if(R.isCont($e67846785)) {
var $ss67886789 = {"from":L[1237],
"go":function(anf_arg63756796) {
return $Hanf_arg107576798(anf_arg63756796,a_DASH_record5172335,l16466797);
}};
$e67846785.stack[R.EXN_STACKHEIGHT++] = $ss67886789;
}
if(R.isPyretException($e67846785)) {
$e67846785.pyretStack.push(L[1237]);
}
throw $e67846785;
}
var $ret67906791 = $Hanf_arg107576798($z67866787,a_DASH_record5172335,l16466797);
++R.GAS;
return $ret67906791;
};
},{"length":3});
var anf_obj63856712 = R.makeMethod(function(self16486778) {
return function(l16496781,ann16506783,args16516780) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1236],3,arguments);
}
var anf_fun63786777 = G(ann16506783,"visit",L[1235]);
var $z67696770 = D;
var $f67756776 = function(_) {
return R.isFunction(anf_fun63786777)?anf_fun63786777.app(self16486778):R.ffi.throwNonFunApp(L[1234],anf_fun63786777,[self16486778]);
};
try {
if(--R.GAS > 0) {
$z67696770 = $f67756776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67756776,
"from":L[1234]});
}
} catch($e67676768) {
if(R.isCont($e67676768)) {
var $ss67716772 = {"from":L[1234],
"go":function(anf_arg63796779) {
return $Hanf_arg107616782(anf_arg63796779,a_DASH_app5192339,args16516780,l16496781,self16486778);
}};
$e67676768.stack[R.EXN_STACKHEIGHT++] = $ss67716772;
}
if(R.isPyretException($e67676768)) {
$e67676768.pyretStack.push(L[1234]);
}
throw $e67676768;
}
var $ret67736774 = $Hanf_arg107616782($z67696770,a_DASH_app5192339,args16516780,l16496781,self16486778);
++R.GAS;
return $ret67736774;
};
},{"length":4});
var anf_obj63916713 = R.makeMethod(function(self16526761) {
return function(l16536764,ann16546766,exp16556763) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1233],3,arguments);
}
var anf_fun63876760 = G(ann16546766,"visit",L[1232]);
var $z67526753 = D;
var $f67586759 = function(_) {
return R.isFunction(anf_fun63876760)?anf_fun63876760.app(self16526761):R.ffi.throwNonFunApp(L[1231],anf_fun63876760,[self16526761]);
};
try {
if(--R.GAS > 0) {
$z67526753 = $f67586759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67586759,
"from":L[1231]});
}
} catch($e67506751) {
if(R.isCont($e67506751)) {
var $ss67546755 = {"from":L[1231],
"go":function(anf_arg63886762) {
return $Hanf_arg107646765(anf_arg63886762,a_DASH_pred5212343,exp16556763,l16536764,self16526761);
}};
$e67506751.stack[R.EXN_STACKHEIGHT++] = $ss67546755;
}
if(R.isPyretException($e67506751)) {
$e67506751.pyretStack.push(L[1231]);
}
throw $e67506751;
}
var $ret67566757 = $Hanf_arg107646765($z67526753,a_DASH_pred5212343,exp16556763,l16536764,self16526761);
++R.GAS;
return $ret67566757;
};
},{"length":4});
var anf_obj63956714 = R.makeMethod(function(self16566744) {
return function(l16576747,obj16586749,field16596746) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1230],3,arguments);
}
var anf_fun63936743 = G(obj16586749,"visit",L[1229]);
var $z67356736 = D;
var $f67416742 = function(_) {
return R.isFunction(anf_fun63936743)?anf_fun63936743.app(self16566744):R.ffi.throwNonFunApp(L[1228],anf_fun63936743,[self16566744]);
};
try {
if(--R.GAS > 0) {
$z67356736 = $f67416742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67416742,
"from":L[1228]});
}
} catch($e67336734) {
if(R.isCont($e67336734)) {
var $ss67376738 = {"from":L[1228],
"go":function(anf_arg63946745) {
return $Hanf_arg107666748(anf_arg63946745,a_DASH_dot5232347,field16596746,l16576747);
}};
$e67336734.stack[R.EXN_STACKHEIGHT++] = $ss67376738;
}
if(R.isPyretException($e67336734)) {
$e67336734.pyretStack.push(L[1228]);
}
throw $e67336734;
}
var $ret67396740 = $Hanf_arg107666748($z67356736,a_DASH_dot5232347,field16596746,l16576747);
++R.GAS;
return $ret67396740;
};
},{"length":4});
var anf_obj63996715 = R.makeMethod(function(self16606727) {
return function(l16616729,name16626730,ann16636732) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1227],3,arguments);
}
var anf_fun63976726 = G(ann16636732,"visit",L[1226]);
var $z67186719 = D;
var $f67246725 = function(_) {
return R.isFunction(anf_fun63976726)?anf_fun63976726.app(self16606727):R.ffi.throwNonFunApp(L[1225],anf_fun63976726,[self16606727]);
};
try {
if(--R.GAS > 0) {
$z67186719 = $f67246725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67246725,
"from":L[1225]});
}
} catch($e67166717) {
if(R.isCont($e67166717)) {
var $ss67206721 = {"from":L[1225],
"go":function(anf_arg63986728) {
return $Hanf_arg107686731(anf_arg63986728,a_DASH_field5282357,l16616729,name16626730);
}};
$e67166717.stack[R.EXN_STACKHEIGHT++] = $ss67206721;
}
if(R.isPyretException($e67166717)) {
$e67166717.pyretStack.push(L[1225]);
}
throw $e67166717;
}
var $ret67226723 = $Hanf_arg107686731($z67186719,a_DASH_field5282357,l16616729,name16626730);
++R.GAS;
return $ret67226723;
};
},{"length":4});
var default_DASH_map_DASH_visitor12482387 = R.makeObject({"option":anf_obj57256613,
"s-underscore":anf_obj57276614,
"s-name":anf_obj57296615,
"s-type-global":anf_obj57316616,
"s-global":anf_obj57336617,
"s-atom":anf_obj57356618,
"s-module":anf_obj57486619,
"s-program":anf_obj57616620,
"s-import":anf_obj57676621,
"s-file-import":anf_obj57696622,
"s-const-import":anf_obj57716623,
"s-import-types":anf_obj57776624,
"s-import-fields":anf_obj57846625,
"s-provide":anf_obj57886626,
"s-provide-all":anf_obj57906627,
"s-provide-none":anf_obj57926628,
"s-provide-types":anf_obj57996629,
"s-provide-types-all":anf_obj58016630,
"s-provide-types-none":anf_obj58036631,
"s-bind":anf_obj58096632,
"s-var-bind":anf_obj58156633,
"s-let-bind":anf_obj58216634,
"s-type-bind":anf_obj58276635,
"s-newtype-bind":anf_obj58336636,
"s-type-let-expr":anf_obj58426637,
"s-let-expr":anf_obj58516638,
"s-letrec-bind":anf_obj58576639,
"s-letrec":anf_obj58666640,
"s-hint-exp":anf_obj58706641,
"s-instantiate":anf_obj58796642,
"s-block":anf_obj58866643,
"s-user-block":anf_obj58906644,
"s-fun":anf_obj59036645,
"s-type":anf_obj59096646,
"s-newtype":anf_obj59156647,
"s-var":anf_obj59216648,
"s-let":anf_obj59276649,
"s-graph":anf_obj59346650,
"s-when":anf_obj59406651,
"s-contract":anf_obj59466652,
"s-assign":anf_obj59526653,
"s-if-branch":anf_obj59586654,
"s-if-pipe-branch":anf_obj59646655,
"s-if":anf_obj59716656,
"s-if-else":anf_obj59806657,
"s-if-pipe":anf_obj59876658,
"s-if-pipe-else":anf_obj59966659,
"s-cases-branch":anf_obj60056660,
"s-cases":anf_obj60166661,
"s-cases-else":anf_obj60296662,
"s-try":anf_obj60376663,
"s-op":anf_obj60436664,
"s-check-test":anf_obj60496665,
"s-paren":anf_obj60536666,
"s-lam":anf_obj60716667,
"s-method":anf_obj60846668,
"s-extend":anf_obj60936669,
"s-update":anf_obj61026670,
"s-obj":anf_obj61096671,
"s-array":anf_obj61166672,
"s-bless":anf_obj61226673,
"s-confirm":anf_obj61286674,
"s-construct":anf_obj61376675,
"s-app":anf_obj61466676,
"s-prim-app":anf_obj61536677,
"s-prim-val":anf_obj61556678,
"s-id":anf_obj61596679,
"s-id-var":anf_obj61636680,
"s-id-letrec":anf_obj61676681,
"s-undefined":anf_obj61696682,
"s-srcloc":anf_obj61716683,
"s-num":anf_obj61736684,
"s-frac":anf_obj61756685,
"s-bool":anf_obj61776686,
"s-str":anf_obj61796687,
"s-dot":anf_obj61836688,
"s-get-bang":anf_obj61876689,
"s-bracket":anf_obj61936690,
"s-data":anf_obj62176691,
"s-data-expr":anf_obj62436692,
"s-for":anf_obj62566693,
"s-check":anf_obj62606694,
"s-data-field":anf_obj62666695,
"s-mutable-field":anf_obj62746696,
"s-once-field":anf_obj62826697,
"s-method-field":anf_obj62976698,
"s-for-bind":anf_obj63036699,
"s-variant-member":anf_obj63076700,
"s-variant":anf_obj63196701,
"s-singleton-variant":anf_obj63266702,
"s-datatype-variant":anf_obj63356703,
"s-datatype-singleton-variant":anf_obj63396704,
"s-datatype-constructor":anf_obj63436705,
"a-blank":anf_obj63456706,
"a-any":anf_obj63476707,
"a-name":anf_obj63516708,
"a-arrow":anf_obj63606709,
"a-method":anf_obj63696710,
"a-record":anf_obj63766711,
"a-app":anf_obj63856712,
"a-pred":anf_obj63916713,
"a-dot":anf_obj63956714,
"a-field":anf_obj63996715});
var anf_obj64104613 = R.makeMethod(function(self16656607) {
return function(opt16666612) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1220],1,arguments);
}
var cases_DASH_val7626611 = opt16666612;
var anf_fun64016587 = G(cases_DASH_val7626611,"_match",L[1221]);
var anf_obj64036593 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1224],0,arguments);
}
var ann_DASH_check_DASH_temp64026610 = (true);
return ann_DASH_check_DASH_temp64026610;
});
var anf_obj64066594 = R.makeFunction(function(v16676595) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1222],1,arguments);
}
var anf_fun64056606 = G(v16676595,"visit",L[1223]);
var $z65986599 = D;
var $f66046605 = function(_) {
return R.isFunction(anf_fun64056606)?anf_fun64056606.app(self16656607):R.ffi.throwNonFunApp(L[1222],anf_fun64056606,[self16656607]);
};
try {
if(--R.GAS > 0) {
$z65986599 = $f66046605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66046605,
"from":L[1222]});
}
} catch($e65966597) {
if(R.isCont($e65966597)) {
var $ss66006601 = {"from":L[1222],
"go":function(ann_DASH_check_DASH_temp64046608) {
return $Hann_DASH_check_DASH_temp107696609(ann_DASH_check_DASH_temp64046608);
}};
$e65966597.stack[R.EXN_STACKHEIGHT++] = $ss66006601;
}
if(R.isPyretException($e65966597)) {
$e65966597.pyretStack.push(L[1222]);
}
throw $e65966597;
}
var $ret66026603 = $Hann_DASH_check_DASH_temp107696609($z65986599);
++R.GAS;
return $ret66026603;
});
var anf_arg64076588 = R.makeObject({"none":anf_obj64036593,
"some":anf_obj64066594});
var anf_arg64096589 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1221],0,arguments);
}
var ann_DASH_check_DASH_temp64086592 = R.throwNoBranchesMatched(L[1221],("cases"));
return ann_DASH_check_DASH_temp64086592;
});
var $z65796580 = D;
var $f65856586 = function(_) {
return R.isFunction(anf_fun64016587)?anf_fun64016587.app(anf_arg64076588,anf_arg64096589):R.ffi.throwNonFunApp(L[1220],anf_fun64016587,[anf_arg64076588,anf_arg64096589]);
};
try {
if(--R.GAS > 0) {
$z65796580 = $f65856586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65856586,
"from":L[1220]});
}
} catch($e65776578) {
if(R.isCont($e65776578)) {
var $ss65816582 = {"from":L[1220],
"go":function(ann_DASH_check_DASH_temp64006590) {
return $Hann_DASH_check_DASH_temp107706591(ann_DASH_check_DASH_temp64006590);
}};
$e65776578.stack[R.EXN_STACKHEIGHT++] = $ss65816582;
}
if(R.isPyretException($e65776578)) {
$e65776578.pyretStack.push(L[1220]);
}
throw $e65776578;
}
var $ret65836584 = $Hann_DASH_check_DASH_temp107706591($z65796580);
++R.GAS;
return $ret65836584;
};
},{"length":2});
var anf_obj64124614 = R.makeMethod(function(self16686575) {
return function(l16696576) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1219],1,arguments);
}
var ann_DASH_check_DASH_temp64116574 = (true);
return ann_DASH_check_DASH_temp64116574;
};
},{"length":2});
var anf_obj64144615 = R.makeMethod(function(self16706571) {
return function(l16716572,s16726573) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1218],2,arguments);
}
var ann_DASH_check_DASH_temp64136570 = (true);
return ann_DASH_check_DASH_temp64136570;
};
},{"length":3});
var anf_obj64164616 = R.makeMethod(function(self16736568) {
return function(s16746569) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1217],1,arguments);
}
var ann_DASH_check_DASH_temp64156567 = (true);
return ann_DASH_check_DASH_temp64156567;
};
},{"length":2});
var anf_obj64184617 = R.makeMethod(function(self16756565) {
return function(s16766566) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1216],1,arguments);
}
var ann_DASH_check_DASH_temp64176564 = (true);
return ann_DASH_check_DASH_temp64176564;
};
},{"length":2});
var anf_obj64204618 = R.makeMethod(function(self16776561) {
return function(base16786562,serial16796563) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1215],2,arguments);
}
var ann_DASH_check_DASH_temp64196560 = (true);
return ann_DASH_check_DASH_temp64196560;
};
},{"length":3});
var anf_obj64474619 = R.makeMethod(function(self16806552) {
return function(l16816559,answer16826558,provides16836555,types16846556,checks16856554) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1214],5,arguments);
}
var anf_fun64226551 = G(answer16826558,"visit",L[1213]);
var $z65436544 = D;
var $f65496550 = function(_) {
return R.isFunction(anf_fun64226551)?anf_fun64226551.app(self16806552):R.ffi.throwNonFunApp(L[1212],anf_fun64226551,[self16806552]);
};
try {
if(--R.GAS > 0) {
$z65436544 = $f65496550();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65496550,
"from":L[1212]});
}
} catch($e65416542) {
if(R.isCont($e65416542)) {
var $ss65456546 = {"from":L[1212],
"go":function(and_DASH_oper_DASH_7636553) {
return $Hand_DASH_oper_DASH_107796557(and_DASH_oper_DASH_7636553,checks16856554,lists974,provides16836555,self16806552,types16846556);
}};
$e65416542.stack[R.EXN_STACKHEIGHT++] = $ss65456546;
}
if(R.isPyretException($e65416542)) {
$e65416542.pyretStack.push(L[1212]);
}
throw $e65416542;
}
var $ret65476548 = $Hand_DASH_oper_DASH_107796557($z65436544,checks16856554,lists974,provides16836555,self16806552,types16846556);
++R.GAS;
return $ret65476548;
};
},{"length":6});
var anf_obj64774620 = R.makeMethod(function(self16866533) {
return function(l16876540,_provide16886539,provided_DASH_types16896537,imports16906536,body16916535) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1211],5,arguments);
}
var anf_fun64496532 = G(_provide16886539,"visit",L[1210]);
var $z65246525 = D;
var $f65306531 = function(_) {
return R.isFunction(anf_fun64496532)?anf_fun64496532.app(self16866533):R.ffi.throwNonFunApp(L[1209],anf_fun64496532,[self16866533]);
};
try {
if(--R.GAS > 0) {
$z65246525 = $f65306531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65306531,
"from":L[1209]});
}
} catch($e65226523) {
if(R.isCont($e65226523)) {
var $ss65266527 = {"from":L[1209],
"go":function(and_DASH_oper_DASH_7686534) {
return $Hand_DASH_oper_DASH_107896538(and_DASH_oper_DASH_7686534,body16916535,imports16906536,lists974,provided_DASH_types16896537,self16866533);
}};
$e65226523.stack[R.EXN_STACKHEIGHT++] = $ss65266527;
}
if(R.isPyretException($e65226523)) {
$e65226523.pyretStack.push(L[1209]);
}
throw $e65226523;
}
var $ret65286529 = $Hand_DASH_oper_DASH_107896538($z65246525,body16916535,imports16906536,lists974,provided_DASH_types16896537,self16866533);
++R.GAS;
return $ret65286529;
};
},{"length":6});
var anf_obj64914621 = R.makeMethod(function(self16926516) {
return function(l16936521,import_DASH_type16946520,name16956518) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1208],3,arguments);
}
var anf_fun64796515 = G(import_DASH_type16946520,"visit",L[1207]);
var $z65076508 = D;
var $f65136514 = function(_) {
return R.isFunction(anf_fun64796515)?anf_fun64796515.app(self16926516):R.ffi.throwNonFunApp(L[1206],anf_fun64796515,[self16926516]);
};
try {
if(--R.GAS > 0) {
$z65076508 = $f65136514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65136514,
"from":L[1206]});
}
} catch($e65056506) {
if(R.isCont($e65056506)) {
var $ss65096510 = {"from":L[1206],
"go":function(and_DASH_oper_DASH_7746517) {
return $Hand_DASH_oper_DASH_107936519(and_DASH_oper_DASH_7746517,name16956518,self16926516);
}};
$e65056506.stack[R.EXN_STACKHEIGHT++] = $ss65096510;
}
if(R.isPyretException($e65056506)) {
$e65056506.pyretStack.push(L[1206]);
}
throw $e65056506;
}
var $ret65116512 = $Hand_DASH_oper_DASH_107936519($z65076508,name16956518,self16926516);
++R.GAS;
return $ret65116512;
};
},{"length":4});
var anf_obj64934622 = R.makeMethod(function(self16966502) {
return function(l16976503,file16986504) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1205],2,arguments);
}
var ann_DASH_check_DASH_temp64926501 = (true);
return ann_DASH_check_DASH_temp64926501;
};
},{"length":3});
var anf_obj64954623 = R.makeMethod(function(self16996498) {
return function(l17006499,mod17016500) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1204],2,arguments);
}
var ann_DASH_check_DASH_temp64946497 = (true);
return ann_DASH_check_DASH_temp64946497;
};
},{"length":3});
var anf_obj65094624 = R.makeMethod(function(self17026490) {
return function(l17036495,import_DASH_type17046496,name17056494,types17066492) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1203],4,arguments);
}
var anf_fun64976489 = G(name17056494,"visit",L[1202]);
var $z64816482 = D;
var $f64876488 = function(_) {
return R.isFunction(anf_fun64976489)?anf_fun64976489.app(self17026490):R.ffi.throwNonFunApp(L[1201],anf_fun64976489,[self17026490]);
};
try {
if(--R.GAS > 0) {
$z64816482 = $f64876488();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64876488,
"from":L[1201]});
}
} catch($e64796480) {
if(R.isCont($e64796480)) {
var $ss64836484 = {"from":L[1201],
"go":function(and_DASH_oper_DASH_7766491) {
return $Hand_DASH_oper_DASH_107976493(and_DASH_oper_DASH_7766491,self17026490,types17066492);
}};
$e64796480.stack[R.EXN_STACKHEIGHT++] = $ss64836484;
}
if(R.isPyretException($e64796480)) {
$e64796480.pyretStack.push(L[1201]);
}
throw $e64796480;
}
var $ret64856486 = $Hand_DASH_oper_DASH_107976493($z64816482,self17026490,types17066492);
++R.GAS;
return $ret64856486;
};
},{"length":5});
var anf_obj65154625 = R.makeMethod(function(self17076474) {
return function(l17086477,fields17096459,import_DASH_type17106478) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1198],3,arguments);
}
var anf_fun65116457 = G(lists974,"all",L[1200]);
var anf_arg65146458 = R.makeFunction(function(recv_DASH_7786462) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1199],1,arguments);
}
var anf_fun65136473 = G(recv_DASH_7786462,"visit",L[1199]);
var $z64656466 = D;
var $f64716472 = function(_) {
return R.isFunction(anf_fun65136473)?anf_fun65136473.app(self17076474):R.ffi.throwNonFunApp(L[1199],anf_fun65136473,[self17076474]);
};
try {
if(--R.GAS > 0) {
$z64656466 = $f64716472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64716472,
"from":L[1199]});
}
} catch($e64636464) {
if(R.isCont($e64636464)) {
var $ss64676468 = {"from":L[1199],
"go":function(ann_DASH_check_DASH_temp65126475) {
return $Hann_DASH_check_DASH_temp107986476(ann_DASH_check_DASH_temp65126475);
}};
$e64636464.stack[R.EXN_STACKHEIGHT++] = $ss64676468;
}
if(R.isPyretException($e64636464)) {
$e64636464.pyretStack.push(L[1199]);
}
throw $e64636464;
}
var $ret64696470 = $Hann_DASH_check_DASH_temp107986476($z64656466);
++R.GAS;
return $ret64696470;
});
var $z64496450 = D;
var $f64556456 = function(_) {
return R.isFunction(anf_fun65116457)?anf_fun65116457.app(anf_arg65146458,fields17096459):R.ffi.throwNonFunApp(L[1198],anf_fun65116457,[anf_arg65146458,fields17096459]);
};
try {
if(--R.GAS > 0) {
$z64496450 = $f64556456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64556456,
"from":L[1198]});
}
} catch($e64476448) {
if(R.isCont($e64476448)) {
var $ss64516452 = {"from":L[1198],
"go":function(ann_DASH_check_DASH_temp65106460) {
return $Hann_DASH_check_DASH_temp107996461(ann_DASH_check_DASH_temp65106460);
}};
$e64476448.stack[R.EXN_STACKHEIGHT++] = $ss64516452;
}
if(R.isPyretException($e64476448)) {
$e64476448.pyretStack.push(L[1198]);
}
throw $e64476448;
}
var $ret64536454 = $Hann_DASH_check_DASH_temp107996461($z64496450);
++R.GAS;
return $ret64536454;
};
},{"length":4});
var anf_obj65184626 = R.makeMethod(function(self17116442) {
return function(l17126446,expr17136445) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1196],2,arguments);
}
var anf_fun65176441 = G(expr17136445,"visit",L[1197]);
var $z64336434 = D;
var $f64396440 = function(_) {
return R.isFunction(anf_fun65176441)?anf_fun65176441.app(self17116442):R.ffi.throwNonFunApp(L[1196],anf_fun65176441,[self17116442]);
};
try {
if(--R.GAS > 0) {
$z64336434 = $f64396440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64396440,
"from":L[1196]});
}
} catch($e64316432) {
if(R.isCont($e64316432)) {
var $ss64356436 = {"from":L[1196],
"go":function(ann_DASH_check_DASH_temp65166443) {
return $Hann_DASH_check_DASH_temp108006444(ann_DASH_check_DASH_temp65166443);
}};
$e64316432.stack[R.EXN_STACKHEIGHT++] = $ss64356436;
}
if(R.isPyretException($e64316432)) {
$e64316432.pyretStack.push(L[1196]);
}
throw $e64316432;
}
var $ret64376438 = $Hann_DASH_check_DASH_temp108006444($z64336434);
++R.GAS;
return $ret64376438;
};
},{"length":3});
var anf_obj65204627 = R.makeMethod(function(self17146429) {
return function(l17156430) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1195],1,arguments);
}
var ann_DASH_check_DASH_temp65196428 = (true);
return ann_DASH_check_DASH_temp65196428;
};
},{"length":2});
var anf_obj65224628 = R.makeMethod(function(self17166426) {
return function(l17176427) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1194],1,arguments);
}
var ann_DASH_check_DASH_temp65216425 = (true);
return ann_DASH_check_DASH_temp65216425;
};
},{"length":2});
var anf_obj65284629 = R.makeMethod(function(self17186421) {
return function(l17196424,anns17206406) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1191],2,arguments);
}
var anf_fun65246404 = G(lists974,"all",L[1193]);
var anf_arg65276405 = R.makeFunction(function(recv_DASH_7796409) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1192],1,arguments);
}
var anf_fun65266420 = G(recv_DASH_7796409,"visit",L[1192]);
var $z64126413 = D;
var $f64186419 = function(_) {
return R.isFunction(anf_fun65266420)?anf_fun65266420.app(self17186421):R.ffi.throwNonFunApp(L[1192],anf_fun65266420,[self17186421]);
};
try {
if(--R.GAS > 0) {
$z64126413 = $f64186419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64186419,
"from":L[1192]});
}
} catch($e64106411) {
if(R.isCont($e64106411)) {
var $ss64146415 = {"from":L[1192],
"go":function(ann_DASH_check_DASH_temp65256422) {
return $Hann_DASH_check_DASH_temp108016423(ann_DASH_check_DASH_temp65256422);
}};
$e64106411.stack[R.EXN_STACKHEIGHT++] = $ss64146415;
}
if(R.isPyretException($e64106411)) {
$e64106411.pyretStack.push(L[1192]);
}
throw $e64106411;
}
var $ret64166417 = $Hann_DASH_check_DASH_temp108016423($z64126413);
++R.GAS;
return $ret64166417;
});
var $z63966397 = D;
var $f64026403 = function(_) {
return R.isFunction(anf_fun65246404)?anf_fun65246404.app(anf_arg65276405,anns17206406):R.ffi.throwNonFunApp(L[1191],anf_fun65246404,[anf_arg65276405,anns17206406]);
};
try {
if(--R.GAS > 0) {
$z63966397 = $f64026403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64026403,
"from":L[1191]});
}
} catch($e63946395) {
if(R.isCont($e63946395)) {
var $ss63986399 = {"from":L[1191],
"go":function(ann_DASH_check_DASH_temp65236407) {
return $Hann_DASH_check_DASH_temp108026408(ann_DASH_check_DASH_temp65236407);
}};
$e63946395.stack[R.EXN_STACKHEIGHT++] = $ss63986399;
}
if(R.isPyretException($e63946395)) {
$e63946395.pyretStack.push(L[1191]);
}
throw $e63946395;
}
var $ret64006401 = $Hann_DASH_check_DASH_temp108026408($z63966397);
++R.GAS;
return $ret64006401;
};
},{"length":3});
var anf_obj65304630 = R.makeMethod(function(self17216392) {
return function(l17226393) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1190],1,arguments);
}
var ann_DASH_check_DASH_temp65296391 = (true);
return ann_DASH_check_DASH_temp65296391;
};
},{"length":2});
var anf_obj65324631 = R.makeMethod(function(self17236389) {
return function(l17246390) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1189],1,arguments);
}
var ann_DASH_check_DASH_temp65316388 = (true);
return ann_DASH_check_DASH_temp65316388;
};
},{"length":2});
var anf_obj65464632 = R.makeMethod(function(self17256381) {
return function(l17266386,shadows17276387,name17286385,ann17296383) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1188],4,arguments);
}
var anf_fun65346380 = G(name17286385,"visit",L[1187]);
var $z63726373 = D;
var $f63786379 = function(_) {
return R.isFunction(anf_fun65346380)?anf_fun65346380.app(self17256381):R.ffi.throwNonFunApp(L[1186],anf_fun65346380,[self17256381]);
};
try {
if(--R.GAS > 0) {
$z63726373 = $f63786379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63786379,
"from":L[1186]});
}
} catch($e63706371) {
if(R.isCont($e63706371)) {
var $ss63746375 = {"from":L[1186],
"go":function(and_DASH_oper_DASH_7806382) {
return $Hand_DASH_oper_DASH_108066384(and_DASH_oper_DASH_7806382,ann17296383,self17256381);
}};
$e63706371.stack[R.EXN_STACKHEIGHT++] = $ss63746375;
}
if(R.isPyretException($e63706371)) {
$e63706371.pyretStack.push(L[1186]);
}
throw $e63706371;
}
var $ret63766377 = $Hand_DASH_oper_DASH_108066384($z63726373,ann17296383,self17256381);
++R.GAS;
return $ret63766377;
};
},{"length":5});
var anf_obj65604633 = R.makeMethod(function(self17306364) {
return function(l17316369,bind17326368,expr17336366) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1185],3,arguments);
}
var anf_fun65486363 = G(bind17326368,"visit",L[1184]);
var $z63556356 = D;
var $f63616362 = function(_) {
return R.isFunction(anf_fun65486363)?anf_fun65486363.app(self17306364):R.ffi.throwNonFunApp(L[1183],anf_fun65486363,[self17306364]);
};
try {
if(--R.GAS > 0) {
$z63556356 = $f63616362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63616362,
"from":L[1183]});
}
} catch($e63536354) {
if(R.isCont($e63536354)) {
var $ss63576358 = {"from":L[1183],
"go":function(and_DASH_oper_DASH_7826365) {
return $Hand_DASH_oper_DASH_108106367(and_DASH_oper_DASH_7826365,expr17336366,self17306364);
}};
$e63536354.stack[R.EXN_STACKHEIGHT++] = $ss63576358;
}
if(R.isPyretException($e63536354)) {
$e63536354.pyretStack.push(L[1183]);
}
throw $e63536354;
}
var $ret63596360 = $Hand_DASH_oper_DASH_108106367($z63556356,expr17336366,self17306364);
++R.GAS;
return $ret63596360;
};
},{"length":4});
var anf_obj65744634 = R.makeMethod(function(self17346347) {
return function(l17356352,bind17366351,expr17376349) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1182],3,arguments);
}
var anf_fun65626346 = G(bind17366351,"visit",L[1181]);
var $z63386339 = D;
var $f63446345 = function(_) {
return R.isFunction(anf_fun65626346)?anf_fun65626346.app(self17346347):R.ffi.throwNonFunApp(L[1180],anf_fun65626346,[self17346347]);
};
try {
if(--R.GAS > 0) {
$z63386339 = $f63446345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63446345,
"from":L[1180]});
}
} catch($e63366337) {
if(R.isCont($e63366337)) {
var $ss63406341 = {"from":L[1180],
"go":function(and_DASH_oper_DASH_7846348) {
return $Hand_DASH_oper_DASH_108146350(and_DASH_oper_DASH_7846348,expr17376349,self17346347);
}};
$e63366337.stack[R.EXN_STACKHEIGHT++] = $ss63406341;
}
if(R.isPyretException($e63366337)) {
$e63366337.pyretStack.push(L[1180]);
}
throw $e63366337;
}
var $ret63426343 = $Hand_DASH_oper_DASH_108146350($z63386339,expr17376349,self17346347);
++R.GAS;
return $ret63426343;
};
},{"length":4});
var anf_obj65884635 = R.makeMethod(function(self17386330) {
return function(l17396335,name17406334,ann17416332) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1179],3,arguments);
}
var anf_fun65766329 = G(name17406334,"visit",L[1178]);
var $z63216322 = D;
var $f63276328 = function(_) {
return R.isFunction(anf_fun65766329)?anf_fun65766329.app(self17386330):R.ffi.throwNonFunApp(L[1177],anf_fun65766329,[self17386330]);
};
try {
if(--R.GAS > 0) {
$z63216322 = $f63276328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63276328,
"from":L[1177]});
}
} catch($e63196320) {
if(R.isCont($e63196320)) {
var $ss63236324 = {"from":L[1177],
"go":function(and_DASH_oper_DASH_7866331) {
return $Hand_DASH_oper_DASH_108186333(and_DASH_oper_DASH_7866331,ann17416332,self17386330);
}};
$e63196320.stack[R.EXN_STACKHEIGHT++] = $ss63236324;
}
if(R.isPyretException($e63196320)) {
$e63196320.pyretStack.push(L[1177]);
}
throw $e63196320;
}
var $ret63256326 = $Hand_DASH_oper_DASH_108186333($z63216322,ann17416332,self17386330);
++R.GAS;
return $ret63256326;
};
},{"length":4});
var anf_obj66024636 = R.makeMethod(function(self17426313) {
return function(l17436318,name17446317,namet17456315) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1176],3,arguments);
}
var anf_fun65906312 = G(name17446317,"visit",L[1175]);
var $z63046305 = D;
var $f63106311 = function(_) {
return R.isFunction(anf_fun65906312)?anf_fun65906312.app(self17426313):R.ffi.throwNonFunApp(L[1174],anf_fun65906312,[self17426313]);
};
try {
if(--R.GAS > 0) {
$z63046305 = $f63106311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63106311,
"from":L[1174]});
}
} catch($e63026303) {
if(R.isCont($e63026303)) {
var $ss63066307 = {"from":L[1174],
"go":function(and_DASH_oper_DASH_7886314) {
return $Hand_DASH_oper_DASH_108226316(and_DASH_oper_DASH_7886314,namet17456315,self17426313);
}};
$e63026303.stack[R.EXN_STACKHEIGHT++] = $ss63066307;
}
if(R.isPyretException($e63026303)) {
$e63026303.pyretStack.push(L[1174]);
}
throw $e63026303;
}
var $ret63086309 = $Hand_DASH_oper_DASH_108226316($z63046305,namet17456315,self17426313);
++R.GAS;
return $ret63086309;
};
},{"length":4});
var anf_obj66194637 = R.makeMethod(function(self17466285) {
return function(l17476301,binds17486282,body17496284) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1173],3,arguments);
}
var anf_fun66046280 = G(lists974,"all",L[1172]);
var anf_arg66076281 = R.makeFunction(function(recv_DASH_7916287) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1171],1,arguments);
}
var anf_fun66066298 = G(recv_DASH_7916287,"visit",L[1171]);
var $z62906291 = D;
var $f62966297 = function(_) {
return R.isFunction(anf_fun66066298)?anf_fun66066298.app(self17466285):R.ffi.throwNonFunApp(L[1171],anf_fun66066298,[self17466285]);
};
try {
if(--R.GAS > 0) {
$z62906291 = $f62966297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62966297,
"from":L[1171]});
}
} catch($e62886289) {
if(R.isCont($e62886289)) {
var $ss62926293 = {"from":L[1171],
"go":function(ann_DASH_check_DASH_temp66056299) {
return $Hann_DASH_check_DASH_temp108236300(ann_DASH_check_DASH_temp66056299);
}};
$e62886289.stack[R.EXN_STACKHEIGHT++] = $ss62926293;
}
if(R.isPyretException($e62886289)) {
$e62886289.pyretStack.push(L[1171]);
}
throw $e62886289;
}
var $ret62946295 = $Hann_DASH_check_DASH_temp108236300($z62906291);
++R.GAS;
return $ret62946295;
});
var $z62726273 = D;
var $f62786279 = function(_) {
return R.isFunction(anf_fun66046280)?anf_fun66046280.app(anf_arg66076281,binds17486282):R.ffi.throwNonFunApp(L[1170],anf_fun66046280,[anf_arg66076281,binds17486282]);
};
try {
if(--R.GAS > 0) {
$z62726273 = $f62786279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62786279,
"from":L[1170]});
}
} catch($e62706271) {
if(R.isCont($e62706271)) {
var $ss62746275 = {"from":L[1170],
"go":function(and_DASH_oper_DASH_7906283) {
return $Hand_DASH_oper_DASH_108276286(and_DASH_oper_DASH_7906283,body17496284,self17466285);
}};
$e62706271.stack[R.EXN_STACKHEIGHT++] = $ss62746275;
}
if(R.isPyretException($e62706271)) {
$e62706271.pyretStack.push(L[1170]);
}
throw $e62706271;
}
var $ret62766277 = $Hand_DASH_oper_DASH_108276286($z62726273,body17496284,self17466285);
++R.GAS;
return $ret62766277;
};
},{"length":4});
var anf_obj66364638 = R.makeMethod(function(self17506253) {
return function(l17516269,binds17526250,body17536252) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1169],3,arguments);
}
var anf_fun66216248 = G(lists974,"all",L[1168]);
var anf_arg66246249 = R.makeFunction(function(recv_DASH_7946255) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1167],1,arguments);
}
var anf_fun66236266 = G(recv_DASH_7946255,"visit",L[1167]);
var $z62586259 = D;
var $f62646265 = function(_) {
return R.isFunction(anf_fun66236266)?anf_fun66236266.app(self17506253):R.ffi.throwNonFunApp(L[1167],anf_fun66236266,[self17506253]);
};
try {
if(--R.GAS > 0) {
$z62586259 = $f62646265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62646265,
"from":L[1167]});
}
} catch($e62566257) {
if(R.isCont($e62566257)) {
var $ss62606261 = {"from":L[1167],
"go":function(ann_DASH_check_DASH_temp66226267) {
return $Hann_DASH_check_DASH_temp108286268(ann_DASH_check_DASH_temp66226267);
}};
$e62566257.stack[R.EXN_STACKHEIGHT++] = $ss62606261;
}
if(R.isPyretException($e62566257)) {
$e62566257.pyretStack.push(L[1167]);
}
throw $e62566257;
}
var $ret62626263 = $Hann_DASH_check_DASH_temp108286268($z62586259);
++R.GAS;
return $ret62626263;
});
var $z62406241 = D;
var $f62466247 = function(_) {
return R.isFunction(anf_fun66216248)?anf_fun66216248.app(anf_arg66246249,binds17526250):R.ffi.throwNonFunApp(L[1166],anf_fun66216248,[anf_arg66246249,binds17526250]);
};
try {
if(--R.GAS > 0) {
$z62406241 = $f62466247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62466247,
"from":L[1166]});
}
} catch($e62386239) {
if(R.isCont($e62386239)) {
var $ss62426243 = {"from":L[1166],
"go":function(and_DASH_oper_DASH_7936251) {
return $Hand_DASH_oper_DASH_108326254(and_DASH_oper_DASH_7936251,body17536252,self17506253);
}};
$e62386239.stack[R.EXN_STACKHEIGHT++] = $ss62426243;
}
if(R.isPyretException($e62386239)) {
$e62386239.pyretStack.push(L[1166]);
}
throw $e62386239;
}
var $ret62446245 = $Hand_DASH_oper_DASH_108326254($z62406241,body17536252,self17506253);
++R.GAS;
return $ret62446245;
};
},{"length":4});
var anf_obj66504639 = R.makeMethod(function(self17546232) {
return function(l17556237,bind17566236,expr17576234) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1165],3,arguments);
}
var anf_fun66386231 = G(bind17566236,"visit",L[1164]);
var $z62236224 = D;
var $f62296230 = function(_) {
return R.isFunction(anf_fun66386231)?anf_fun66386231.app(self17546232):R.ffi.throwNonFunApp(L[1163],anf_fun66386231,[self17546232]);
};
try {
if(--R.GAS > 0) {
$z62236224 = $f62296230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62296230,
"from":L[1163]});
}
} catch($e62216222) {
if(R.isCont($e62216222)) {
var $ss62256226 = {"from":L[1163],
"go":function(and_DASH_oper_DASH_7966233) {
return $Hand_DASH_oper_DASH_108366235(and_DASH_oper_DASH_7966233,expr17576234,self17546232);
}};
$e62216222.stack[R.EXN_STACKHEIGHT++] = $ss62256226;
}
if(R.isPyretException($e62216222)) {
$e62216222.pyretStack.push(L[1163]);
}
throw $e62216222;
}
var $ret62276228 = $Hand_DASH_oper_DASH_108366235($z62236224,expr17576234,self17546232);
++R.GAS;
return $ret62276228;
};
},{"length":4});
var anf_obj66674640 = R.makeMethod(function(self17586204) {
return function(l17596220,binds17606201,body17616203) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1162],3,arguments);
}
var anf_fun66526199 = G(lists974,"all",L[1161]);
var anf_arg66556200 = R.makeFunction(function(recv_DASH_7996206) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1160],1,arguments);
}
var anf_fun66546217 = G(recv_DASH_7996206,"visit",L[1160]);
var $z62096210 = D;
var $f62156216 = function(_) {
return R.isFunction(anf_fun66546217)?anf_fun66546217.app(self17586204):R.ffi.throwNonFunApp(L[1160],anf_fun66546217,[self17586204]);
};
try {
if(--R.GAS > 0) {
$z62096210 = $f62156216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62156216,
"from":L[1160]});
}
} catch($e62076208) {
if(R.isCont($e62076208)) {
var $ss62116212 = {"from":L[1160],
"go":function(ann_DASH_check_DASH_temp66536218) {
return $Hann_DASH_check_DASH_temp108376219(ann_DASH_check_DASH_temp66536218);
}};
$e62076208.stack[R.EXN_STACKHEIGHT++] = $ss62116212;
}
if(R.isPyretException($e62076208)) {
$e62076208.pyretStack.push(L[1160]);
}
throw $e62076208;
}
var $ret62136214 = $Hann_DASH_check_DASH_temp108376219($z62096210);
++R.GAS;
return $ret62136214;
});
var $z61916192 = D;
var $f61976198 = function(_) {
return R.isFunction(anf_fun66526199)?anf_fun66526199.app(anf_arg66556200,binds17606201):R.ffi.throwNonFunApp(L[1159],anf_fun66526199,[anf_arg66556200,binds17606201]);
};
try {
if(--R.GAS > 0) {
$z61916192 = $f61976198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61976198,
"from":L[1159]});
}
} catch($e61896190) {
if(R.isCont($e61896190)) {
var $ss61936194 = {"from":L[1159],
"go":function(and_DASH_oper_DASH_7986202) {
return $Hand_DASH_oper_DASH_108416205(and_DASH_oper_DASH_7986202,body17616203,self17586204);
}};
$e61896190.stack[R.EXN_STACKHEIGHT++] = $ss61936194;
}
if(R.isPyretException($e61896190)) {
$e61896190.pyretStack.push(L[1159]);
}
throw $e61896190;
}
var $ret61956196 = $Hand_DASH_oper_DASH_108416205($z61916192,body17616203,self17586204);
++R.GAS;
return $ret61956196;
};
},{"length":4});
var anf_obj66704641 = R.makeMethod(function(self17626183) {
return function(l17636187,hints17646188,exp17656186) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1154],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l17636187,hints17646188,exp17656186],[L[1156],L[1157],L[1158]],function() {
var anf_fun66696182 = G(exp17656186,"visit",L[1155]);
var $z61746175 = D;
var $f61806181 = function(_) {
return R.isFunction(anf_fun66696182)?anf_fun66696182.app(self17626183):R.ffi.throwNonFunApp(L[1154],anf_fun66696182,[self17626183]);
};
try {
if(--R.GAS > 0) {
$z61746175 = $f61806181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61806181,
"from":L[1154]});
}
} catch($e61726173) {
if(R.isCont($e61726173)) {
var $ss61766177 = {"from":L[1154],
"go":function(ann_DASH_check_DASH_temp66686184) {
return $Hann_DASH_check_DASH_temp108426185(ann_DASH_check_DASH_temp66686184);
}};
$e61726173.stack[R.EXN_STACKHEIGHT++] = $ss61766177;
}
if(R.isPyretException($e61726173)) {
$e61726173.pyretStack.push(L[1154]);
}
throw $e61726173;
}
var $ret61786179 = $Hann_DASH_check_DASH_temp108426185($z61746175);
++R.GAS;
return $ret61786179;
});
};
},{"length":4});
var anf_obj66874642 = R.makeMethod(function(self17666166) {
return function(l17676171,expr17686170,params17696168) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1153],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l17676171,expr17686170,params17696168],[L[1150],L[1151],L[1152]],function() {
var anf_fun66726165 = G(expr17686170,"visit",L[1149]);
var $z61576158 = D;
var $f61636164 = function(_) {
return R.isFunction(anf_fun66726165)?anf_fun66726165.app(self17666166):R.ffi.throwNonFunApp(L[1148],anf_fun66726165,[self17666166]);
};
try {
if(--R.GAS > 0) {
$z61576158 = $f61636164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61636164,
"from":L[1148]});
}
} catch($e61556156) {
if(R.isCont($e61556156)) {
var $ss61596160 = {"from":L[1148],
"go":function(and_DASH_oper_DASH_8016167) {
return $Hand_DASH_oper_DASH_108476169(and_DASH_oper_DASH_8016167,lists974,params17696168,self17666166);
}};
$e61556156.stack[R.EXN_STACKHEIGHT++] = $ss61596160;
}
if(R.isPyretException($e61556156)) {
$e61556156.pyretStack.push(L[1148]);
}
throw $e61556156;
}
var $ret61616162 = $Hand_DASH_oper_DASH_108476169($z61576158,lists974,params17696168,self17666166);
++R.GAS;
return $ret61616162;
});
};
},{"length":4});
var anf_obj66934643 = R.makeMethod(function(self17706151) {
return function(l17716154,stmts17726136) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1145],2,arguments);
}
var anf_fun66896134 = G(lists974,"all",L[1147]);
var anf_arg66926135 = R.makeFunction(function(recv_DASH_8046139) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1146],1,arguments);
}
var anf_fun66916150 = G(recv_DASH_8046139,"visit",L[1146]);
var $z61426143 = D;
var $f61486149 = function(_) {
return R.isFunction(anf_fun66916150)?anf_fun66916150.app(self17706151):R.ffi.throwNonFunApp(L[1146],anf_fun66916150,[self17706151]);
};
try {
if(--R.GAS > 0) {
$z61426143 = $f61486149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61486149,
"from":L[1146]});
}
} catch($e61406141) {
if(R.isCont($e61406141)) {
var $ss61446145 = {"from":L[1146],
"go":function(ann_DASH_check_DASH_temp66906152) {
return $Hann_DASH_check_DASH_temp108486153(ann_DASH_check_DASH_temp66906152);
}};
$e61406141.stack[R.EXN_STACKHEIGHT++] = $ss61446145;
}
if(R.isPyretException($e61406141)) {
$e61406141.pyretStack.push(L[1146]);
}
throw $e61406141;
}
var $ret61466147 = $Hann_DASH_check_DASH_temp108486153($z61426143);
++R.GAS;
return $ret61466147;
});
var $z61266127 = D;
var $f61326133 = function(_) {
return R.isFunction(anf_fun66896134)?anf_fun66896134.app(anf_arg66926135,stmts17726136):R.ffi.throwNonFunApp(L[1145],anf_fun66896134,[anf_arg66926135,stmts17726136]);
};
try {
if(--R.GAS > 0) {
$z61266127 = $f61326133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61326133,
"from":L[1145]});
}
} catch($e61246125) {
if(R.isCont($e61246125)) {
var $ss61286129 = {"from":L[1145],
"go":function(ann_DASH_check_DASH_temp66886137) {
return $Hann_DASH_check_DASH_temp108496138(ann_DASH_check_DASH_temp66886137);
}};
$e61246125.stack[R.EXN_STACKHEIGHT++] = $ss61286129;
}
if(R.isPyretException($e61246125)) {
$e61246125.pyretStack.push(L[1145]);
}
throw $e61246125;
}
var $ret61306131 = $Hann_DASH_check_DASH_temp108496138($z61266127);
++R.GAS;
return $ret61306131;
};
},{"length":3});
var anf_obj66964644 = R.makeMethod(function(self17736119) {
return function(l17746123,body17756122) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1141],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l17746123,body17756122],[L[1143],L[1144]],function() {
var anf_fun66956118 = G(body17756122,"visit",L[1142]);
var $z61106111 = D;
var $f61166117 = function(_) {
return R.isFunction(anf_fun66956118)?anf_fun66956118.app(self17736119):R.ffi.throwNonFunApp(L[1141],anf_fun66956118,[self17736119]);
};
try {
if(--R.GAS > 0) {
$z61106111 = $f61166117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61166117,
"from":L[1141]});
}
} catch($e61086109) {
if(R.isCont($e61086109)) {
var $ss61126113 = {"from":L[1141],
"go":function(ann_DASH_check_DASH_temp66946120) {
return $Hann_DASH_check_DASH_temp108506121(ann_DASH_check_DASH_temp66946120);
}};
$e61086109.stack[R.EXN_STACKHEIGHT++] = $ss61126113;
}
if(R.isPyretException($e61086109)) {
$e61086109.pyretStack.push(L[1141]);
}
throw $e61086109;
}
var $ret61146115 = $Hann_DASH_check_DASH_temp108506121($z61106111);
++R.GAS;
return $ret61146115;
});
};
},{"length":3});
var anf_obj67314645 = R.makeMethod(function(self17766089) {
return function(l17776105,name17786106,params17796083,args17806087,ann17816086,doc17826107,body17836088,_check17846085) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[1140],8,arguments);
}
var anf_fun66986081 = G(lists974,"app",L[1139]);
var anf_arg67016082 = R.makeFunction(function(recv_DASH_8066091) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1138],1,arguments);
}
var anf_fun67006102 = G(recv_DASH_8066091,"visit",L[1138]);
var $z60946095 = D;
var $f61006101 = function(_) {
return R.isFunction(anf_fun67006102)?anf_fun67006102.app(self17766089):R.ffi.throwNonFunApp(L[1138],anf_fun67006102,[self17766089]);
};
try {
if(--R.GAS > 0) {
$z60946095 = $f61006101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61006101,
"from":L[1138]});
}
} catch($e60926093) {
if(R.isCont($e60926093)) {
var $ss60966097 = {"from":L[1138],
"go":function(ann_DASH_check_DASH_temp66996103) {
return $Hann_DASH_check_DASH_temp108516104(ann_DASH_check_DASH_temp66996103);
}};
$e60926093.stack[R.EXN_STACKHEIGHT++] = $ss60966097;
}
if(R.isPyretException($e60926093)) {
$e60926093.pyretStack.push(L[1138]);
}
throw $e60926093;
}
var $ret60986099 = $Hann_DASH_check_DASH_temp108516104($z60946095);
++R.GAS;
return $ret60986099;
});
var $z60736074 = D;
var $f60796080 = function(_) {
return R.isFunction(anf_fun66986081)?anf_fun66986081.app(anf_arg67016082,params17796083):R.ffi.throwNonFunApp(L[1137],anf_fun66986081,[anf_arg67016082,params17796083]);
};
try {
if(--R.GAS > 0) {
$z60736074 = $f60796080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60796080,
"from":L[1137]});
}
} catch($e60716072) {
if(R.isCont($e60716072)) {
var $ss60756076 = {"from":L[1137],
"go":function(and_DASH_oper_DASH_8056084) {
return $Hand_DASH_oper_DASH_108626090(and_DASH_oper_DASH_8056084,_check17846085,ann17816086,args17806087,body17836088,lists974,self17766089);
}};
$e60716072.stack[R.EXN_STACKHEIGHT++] = $ss60756076;
}
if(R.isPyretException($e60716072)) {
$e60716072.pyretStack.push(L[1137]);
}
throw $e60716072;
}
var $ret60776078 = $Hand_DASH_oper_DASH_108626090($z60736074,_check17846085,ann17816086,args17806087,body17836088,lists974,self17766089);
++R.GAS;
return $ret60776078;
};
},{"length":9});
var anf_obj67454646 = R.makeMethod(function(self17856065) {
return function(l17866070,name17876069,ann17886067) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1136],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Ann11299],[l17866070,name17876069,ann17886067],[L[1133],L[1134],L[1135]],function() {
var anf_fun67336064 = G(name17876069,"visit",L[1132]);
var $z60566057 = D;
var $f60626063 = function(_) {
return R.isFunction(anf_fun67336064)?anf_fun67336064.app(self17856065):R.ffi.throwNonFunApp(L[1131],anf_fun67336064,[self17856065]);
};
try {
if(--R.GAS > 0) {
$z60566057 = $f60626063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60626063,
"from":L[1131]});
}
} catch($e60546055) {
if(R.isCont($e60546055)) {
var $ss60586059 = {"from":L[1131],
"go":function(and_DASH_oper_DASH_8126066) {
return $Hand_DASH_oper_DASH_108666068(and_DASH_oper_DASH_8126066,ann17886067,self17856065);
}};
$e60546055.stack[R.EXN_STACKHEIGHT++] = $ss60586059;
}
if(R.isPyretException($e60546055)) {
$e60546055.pyretStack.push(L[1131]);
}
throw $e60546055;
}
var $ret60606061 = $Hand_DASH_oper_DASH_108666068($z60566057,ann17886067,self17856065);
++R.GAS;
return $ret60606061;
});
};
},{"length":4});
var anf_obj67594647 = R.makeMethod(function(self17896048) {
return function(l17906053,name17916052,namet17926050) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1130],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Name66133],[l17906053,name17916052,namet17926050],[L[1127],L[1128],L[1129]],function() {
var anf_fun67476047 = G(name17916052,"visit",L[1126]);
var $z60396040 = D;
var $f60456046 = function(_) {
return R.isFunction(anf_fun67476047)?anf_fun67476047.app(self17896048):R.ffi.throwNonFunApp(L[1125],anf_fun67476047,[self17896048]);
};
try {
if(--R.GAS > 0) {
$z60396040 = $f60456046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60456046,
"from":L[1125]});
}
} catch($e60376038) {
if(R.isCont($e60376038)) {
var $ss60416042 = {"from":L[1125],
"go":function(and_DASH_oper_DASH_8146049) {
return $Hand_DASH_oper_DASH_108706051(and_DASH_oper_DASH_8146049,namet17926050,self17896048);
}};
$e60376038.stack[R.EXN_STACKHEIGHT++] = $ss60416042;
}
if(R.isPyretException($e60376038)) {
$e60376038.pyretStack.push(L[1125]);
}
throw $e60376038;
}
var $ret60436044 = $Hand_DASH_oper_DASH_108706051($z60396040,namet17926050,self17896048);
++R.GAS;
return $ret60436044;
});
};
},{"length":4});
var anf_obj67734648 = R.makeMethod(function(self17936031) {
return function(l17946036,name17956035,value17966033) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1124],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l17946036,name17956035,value17966033],[L[1121],L[1122],L[1123]],function() {
var anf_fun67616030 = G(name17956035,"visit",L[1120]);
var $z60226023 = D;
var $f60286029 = function(_) {
return R.isFunction(anf_fun67616030)?anf_fun67616030.app(self17936031):R.ffi.throwNonFunApp(L[1119],anf_fun67616030,[self17936031]);
};
try {
if(--R.GAS > 0) {
$z60226023 = $f60286029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60286029,
"from":L[1119]});
}
} catch($e60206021) {
if(R.isCont($e60206021)) {
var $ss60246025 = {"from":L[1119],
"go":function(and_DASH_oper_DASH_8166032) {
return $Hand_DASH_oper_DASH_108746034(and_DASH_oper_DASH_8166032,self17936031,value17966033);
}};
$e60206021.stack[R.EXN_STACKHEIGHT++] = $ss60246025;
}
if(R.isPyretException($e60206021)) {
$e60206021.pyretStack.push(L[1119]);
}
throw $e60206021;
}
var $ret60266027 = $Hand_DASH_oper_DASH_108746034($z60226023,self17936031,value17966033);
++R.GAS;
return $ret60266027;
});
};
},{"length":4});
var anf_obj67874649 = R.makeMethod(function(self17976013) {
return function(l17986018,name17996017,value18006015,keyword_DASH_val18016019) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1118],4,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111,$type$Boolean67],[l17986018,name17996017,value18006015,keyword_DASH_val18016019],[L[1114],L[1115],L[1116],L[1117]],function() {
var anf_fun67756012 = G(name17996017,"visit",L[1113]);
var $z60046005 = D;
var $f60106011 = function(_) {
return R.isFunction(anf_fun67756012)?anf_fun67756012.app(self17976013):R.ffi.throwNonFunApp(L[1112],anf_fun67756012,[self17976013]);
};
try {
if(--R.GAS > 0) {
$z60046005 = $f60106011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60106011,
"from":L[1112]});
}
} catch($e60026003) {
if(R.isCont($e60026003)) {
var $ss60066007 = {"from":L[1112],
"go":function(and_DASH_oper_DASH_8186014) {
return $Hand_DASH_oper_DASH_108786016(and_DASH_oper_DASH_8186014,self17976013,value18006015);
}};
$e60026003.stack[R.EXN_STACKHEIGHT++] = $ss60066007;
}
if(R.isPyretException($e60026003)) {
$e60026003.pyretStack.push(L[1112]);
}
throw $e60026003;
}
var $ret60086009 = $Hand_DASH_oper_DASH_108786016($z60046005,self17976013,value18006015);
++R.GAS;
return $ret60086009;
});
};
},{"length":5});
var anf_obj67934650 = R.makeMethod(function(self18025998) {
return function(l18036001,bindings18045983) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1107],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l18036001,bindings18045983],[L[1110],L[1111]],function() {
var anf_fun67895981 = G(lists974,"all",L[1109]);
var anf_arg67925982 = R.makeFunction(function(recv_DASH_8205986) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1108],1,arguments);
}
var anf_fun67915997 = G(recv_DASH_8205986,"visit",L[1108]);
var $z59895990 = D;
var $f59955996 = function(_) {
return R.isFunction(anf_fun67915997)?anf_fun67915997.app(self18025998):R.ffi.throwNonFunApp(L[1108],anf_fun67915997,[self18025998]);
};
try {
if(--R.GAS > 0) {
$z59895990 = $f59955996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59955996,
"from":L[1108]});
}
} catch($e59875988) {
if(R.isCont($e59875988)) {
var $ss59915992 = {"from":L[1108],
"go":function(ann_DASH_check_DASH_temp67905999) {
return $Hann_DASH_check_DASH_temp108796000(ann_DASH_check_DASH_temp67905999);
}};
$e59875988.stack[R.EXN_STACKHEIGHT++] = $ss59915992;
}
if(R.isPyretException($e59875988)) {
$e59875988.pyretStack.push(L[1108]);
}
throw $e59875988;
}
var $ret59935994 = $Hann_DASH_check_DASH_temp108796000($z59895990);
++R.GAS;
return $ret59935994;
});
var $z59735974 = D;
var $f59795980 = function(_) {
return R.isFunction(anf_fun67895981)?anf_fun67895981.app(anf_arg67925982,bindings18045983):R.ffi.throwNonFunApp(L[1107],anf_fun67895981,[anf_arg67925982,bindings18045983]);
};
try {
if(--R.GAS > 0) {
$z59735974 = $f59795980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59795980,
"from":L[1107]});
}
} catch($e59715972) {
if(R.isCont($e59715972)) {
var $ss59755976 = {"from":L[1107],
"go":function(ann_DASH_check_DASH_temp67885984) {
return $Hann_DASH_check_DASH_temp108805985(ann_DASH_check_DASH_temp67885984);
}};
$e59715972.stack[R.EXN_STACKHEIGHT++] = $ss59755976;
}
if(R.isPyretException($e59715972)) {
$e59715972.pyretStack.push(L[1107]);
}
throw $e59715972;
}
var $ret59775978 = $Hann_DASH_check_DASH_temp108805985($z59735974);
++R.GAS;
return $ret59775978;
});
};
},{"length":3});
var anf_obj68074651 = R.makeMethod(function(self18055965) {
return function(l18065970,test18075969,block18085967) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1106],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l18065970,test18075969,block18085967],[L[1103],L[1104],L[1105]],function() {
var anf_fun67955964 = G(test18075969,"visit",L[1102]);
var $z59565957 = D;
var $f59625963 = function(_) {
return R.isFunction(anf_fun67955964)?anf_fun67955964.app(self18055965):R.ffi.throwNonFunApp(L[1101],anf_fun67955964,[self18055965]);
};
try {
if(--R.GAS > 0) {
$z59565957 = $f59625963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59625963,
"from":L[1101]});
}
} catch($e59545955) {
if(R.isCont($e59545955)) {
var $ss59585959 = {"from":L[1101],
"go":function(and_DASH_oper_DASH_8215966) {
return $Hand_DASH_oper_DASH_108845968(and_DASH_oper_DASH_8215966,block18085967,self18055965);
}};
$e59545955.stack[R.EXN_STACKHEIGHT++] = $ss59585959;
}
if(R.isPyretException($e59545955)) {
$e59545955.pyretStack.push(L[1101]);
}
throw $e59545955;
}
var $ret59605961 = $Hand_DASH_oper_DASH_108845968($z59565957,block18085967,self18055965);
++R.GAS;
return $ret59605961;
});
};
},{"length":4});
var anf_obj68214652 = R.makeMethod(function(self18095948) {
return function(l18105953,name18115952,ann18125950) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1100],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Ann11299],[l18105953,name18115952,ann18125950],[L[1097],L[1098],L[1099]],function() {
var anf_fun68095947 = G(name18115952,"visit",L[1096]);
var $z59395940 = D;
var $f59455946 = function(_) {
return R.isFunction(anf_fun68095947)?anf_fun68095947.app(self18095948):R.ffi.throwNonFunApp(L[1095],anf_fun68095947,[self18095948]);
};
try {
if(--R.GAS > 0) {
$z59395940 = $f59455946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59455946,
"from":L[1095]});
}
} catch($e59375938) {
if(R.isCont($e59375938)) {
var $ss59415942 = {"from":L[1095],
"go":function(and_DASH_oper_DASH_8235949) {
return $Hand_DASH_oper_DASH_108885951(and_DASH_oper_DASH_8235949,ann18125950,self18095948);
}};
$e59375938.stack[R.EXN_STACKHEIGHT++] = $ss59415942;
}
if(R.isPyretException($e59375938)) {
$e59375938.pyretStack.push(L[1095]);
}
throw $e59375938;
}
var $ret59435944 = $Hand_DASH_oper_DASH_108885951($z59395940,ann18125950,self18095948);
++R.GAS;
return $ret59435944;
});
};
},{"length":4});
var anf_obj68354653 = R.makeMethod(function(self18135931) {
return function(l18145936,id18155935,value18165933) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1094],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Expr86111],[l18145936,id18155935,value18165933],[L[1091],L[1092],L[1093]],function() {
var anf_fun68235930 = G(id18155935,"visit",L[1090]);
var $z59225923 = D;
var $f59285929 = function(_) {
return R.isFunction(anf_fun68235930)?anf_fun68235930.app(self18135931):R.ffi.throwNonFunApp(L[1089],anf_fun68235930,[self18135931]);
};
try {
if(--R.GAS > 0) {
$z59225923 = $f59285929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59285929,
"from":L[1089]});
}
} catch($e59205921) {
if(R.isCont($e59205921)) {
var $ss59245925 = {"from":L[1089],
"go":function(and_DASH_oper_DASH_8255932) {
return $Hand_DASH_oper_DASH_108925934(and_DASH_oper_DASH_8255932,self18135931,value18165933);
}};
$e59205921.stack[R.EXN_STACKHEIGHT++] = $ss59245925;
}
if(R.isPyretException($e59205921)) {
$e59205921.pyretStack.push(L[1089]);
}
throw $e59205921;
}
var $ret59265927 = $Hand_DASH_oper_DASH_108925934($z59225923,self18135931,value18165933);
++R.GAS;
return $ret59265927;
});
};
},{"length":4});
var anf_obj68494654 = R.makeMethod(function(self18175914) {
return function(l18185919,test18195918,body18205916) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1088],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l18185919,test18195918,body18205916],[L[1085],L[1086],L[1087]],function() {
var anf_fun68375913 = G(test18195918,"visit",L[1084]);
var $z59055906 = D;
var $f59115912 = function(_) {
return R.isFunction(anf_fun68375913)?anf_fun68375913.app(self18175914):R.ffi.throwNonFunApp(L[1083],anf_fun68375913,[self18175914]);
};
try {
if(--R.GAS > 0) {
$z59055906 = $f59115912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59115912,
"from":L[1083]});
}
} catch($e59035904) {
if(R.isCont($e59035904)) {
var $ss59075908 = {"from":L[1083],
"go":function(and_DASH_oper_DASH_8275915) {
return $Hand_DASH_oper_DASH_108965917(and_DASH_oper_DASH_8275915,body18205916,self18175914);
}};
$e59035904.stack[R.EXN_STACKHEIGHT++] = $ss59075908;
}
if(R.isPyretException($e59035904)) {
$e59035904.pyretStack.push(L[1083]);
}
throw $e59035904;
}
var $ret59095910 = $Hand_DASH_oper_DASH_108965917($z59055906,body18205916,self18175914);
++R.GAS;
return $ret59095910;
});
};
},{"length":4});
var anf_obj68634655 = R.makeMethod(function(self18215897) {
return function(l18225902,test18235901,body18245899) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1082],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l18225902,test18235901,body18245899],[L[1079],L[1080],L[1081]],function() {
var anf_fun68515896 = G(test18235901,"visit",L[1078]);
var $z58885889 = D;
var $f58945895 = function(_) {
return R.isFunction(anf_fun68515896)?anf_fun68515896.app(self18215897):R.ffi.throwNonFunApp(L[1077],anf_fun68515896,[self18215897]);
};
try {
if(--R.GAS > 0) {
$z58885889 = $f58945895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58945895,
"from":L[1077]});
}
} catch($e58865887) {
if(R.isCont($e58865887)) {
var $ss58905891 = {"from":L[1077],
"go":function(and_DASH_oper_DASH_8295898) {
return $Hand_DASH_oper_DASH_109005900(and_DASH_oper_DASH_8295898,body18245899,self18215897);
}};
$e58865887.stack[R.EXN_STACKHEIGHT++] = $ss58905891;
}
if(R.isPyretException($e58865887)) {
$e58865887.pyretStack.push(L[1077]);
}
throw $e58865887;
}
var $ret58925893 = $Hand_DASH_oper_DASH_109005900($z58885889,body18245899,self18215897);
++R.GAS;
return $ret58925893;
});
};
},{"length":4});
var anf_obj68694656 = R.makeMethod(function(self18255882) {
return function(l18265885,branches18275867) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1072],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l18265885,branches18275867],[L[1075],L[1076]],function() {
var anf_fun68655865 = G(lists974,"all",L[1074]);
var anf_arg68685866 = R.makeFunction(function(recv_DASH_8315870) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1073],1,arguments);
}
var anf_fun68675881 = G(recv_DASH_8315870,"visit",L[1073]);
var $z58735874 = D;
var $f58795880 = function(_) {
return R.isFunction(anf_fun68675881)?anf_fun68675881.app(self18255882):R.ffi.throwNonFunApp(L[1073],anf_fun68675881,[self18255882]);
};
try {
if(--R.GAS > 0) {
$z58735874 = $f58795880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58795880,
"from":L[1073]});
}
} catch($e58715872) {
if(R.isCont($e58715872)) {
var $ss58755876 = {"from":L[1073],
"go":function(ann_DASH_check_DASH_temp68665883) {
return $Hann_DASH_check_DASH_temp109015884(ann_DASH_check_DASH_temp68665883);
}};
$e58715872.stack[R.EXN_STACKHEIGHT++] = $ss58755876;
}
if(R.isPyretException($e58715872)) {
$e58715872.pyretStack.push(L[1073]);
}
throw $e58715872;
}
var $ret58775878 = $Hann_DASH_check_DASH_temp109015884($z58735874);
++R.GAS;
return $ret58775878;
});
var $z58575858 = D;
var $f58635864 = function(_) {
return R.isFunction(anf_fun68655865)?anf_fun68655865.app(anf_arg68685866,branches18275867):R.ffi.throwNonFunApp(L[1072],anf_fun68655865,[anf_arg68685866,branches18275867]);
};
try {
if(--R.GAS > 0) {
$z58575858 = $f58635864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58635864,
"from":L[1072]});
}
} catch($e58555856) {
if(R.isCont($e58555856)) {
var $ss58595860 = {"from":L[1072],
"go":function(ann_DASH_check_DASH_temp68645868) {
return $Hann_DASH_check_DASH_temp109025869(ann_DASH_check_DASH_temp68645868);
}};
$e58555856.stack[R.EXN_STACKHEIGHT++] = $ss58595860;
}
if(R.isPyretException($e58555856)) {
$e58555856.pyretStack.push(L[1072]);
}
throw $e58555856;
}
var $ret58615862 = $Hann_DASH_check_DASH_temp109025869($z58575858);
++R.GAS;
return $ret58615862;
});
};
},{"length":3});
var anf_obj68864657 = R.makeMethod(function(self18285838) {
return function(l18295854,branches18305835,_else18315837) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1071],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l18295854,branches18305835,_else18315837],[L[1068],L[1069],L[1070]],function() {
var anf_fun68715833 = G(lists974,"all",L[1067]);
var anf_arg68745834 = R.makeFunction(function(recv_DASH_8335840) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1066],1,arguments);
}
var anf_fun68735851 = G(recv_DASH_8335840,"visit",L[1066]);
var $z58435844 = D;
var $f58495850 = function(_) {
return R.isFunction(anf_fun68735851)?anf_fun68735851.app(self18285838):R.ffi.throwNonFunApp(L[1066],anf_fun68735851,[self18285838]);
};
try {
if(--R.GAS > 0) {
$z58435844 = $f58495850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58495850,
"from":L[1066]});
}
} catch($e58415842) {
if(R.isCont($e58415842)) {
var $ss58455846 = {"from":L[1066],
"go":function(ann_DASH_check_DASH_temp68725852) {
return $Hann_DASH_check_DASH_temp109035853(ann_DASH_check_DASH_temp68725852);
}};
$e58415842.stack[R.EXN_STACKHEIGHT++] = $ss58455846;
}
if(R.isPyretException($e58415842)) {
$e58415842.pyretStack.push(L[1066]);
}
throw $e58415842;
}
var $ret58475848 = $Hann_DASH_check_DASH_temp109035853($z58435844);
++R.GAS;
return $ret58475848;
});
var $z58255826 = D;
var $f58315832 = function(_) {
return R.isFunction(anf_fun68715833)?anf_fun68715833.app(anf_arg68745834,branches18305835):R.ffi.throwNonFunApp(L[1065],anf_fun68715833,[anf_arg68745834,branches18305835]);
};
try {
if(--R.GAS > 0) {
$z58255826 = $f58315832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58315832,
"from":L[1065]});
}
} catch($e58235824) {
if(R.isCont($e58235824)) {
var $ss58275828 = {"from":L[1065],
"go":function(and_DASH_oper_DASH_8325836) {
return $Hand_DASH_oper_DASH_109075839(and_DASH_oper_DASH_8325836,_else18315837,self18285838);
}};
$e58235824.stack[R.EXN_STACKHEIGHT++] = $ss58275828;
}
if(R.isPyretException($e58235824)) {
$e58235824.pyretStack.push(L[1065]);
}
throw $e58235824;
}
var $ret58295830 = $Hand_DASH_oper_DASH_109075839($z58255826,_else18315837,self18285838);
++R.GAS;
return $ret58295830;
});
};
},{"length":4});
var anf_obj68924658 = R.makeMethod(function(self18325819) {
return function(l18335822,branches18345804) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1060],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l18335822,branches18345804],[L[1063],L[1064]],function() {
var anf_fun68885802 = G(lists974,"all",L[1062]);
var anf_arg68915803 = R.makeFunction(function(recv_DASH_8355807) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1061],1,arguments);
}
var anf_fun68905818 = G(recv_DASH_8355807,"visit",L[1061]);
var $z58105811 = D;
var $f58165817 = function(_) {
return R.isFunction(anf_fun68905818)?anf_fun68905818.app(self18325819):R.ffi.throwNonFunApp(L[1061],anf_fun68905818,[self18325819]);
};
try {
if(--R.GAS > 0) {
$z58105811 = $f58165817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58165817,
"from":L[1061]});
}
} catch($e58085809) {
if(R.isCont($e58085809)) {
var $ss58125813 = {"from":L[1061],
"go":function(ann_DASH_check_DASH_temp68895820) {
return $Hann_DASH_check_DASH_temp109085821(ann_DASH_check_DASH_temp68895820);
}};
$e58085809.stack[R.EXN_STACKHEIGHT++] = $ss58125813;
}
if(R.isPyretException($e58085809)) {
$e58085809.pyretStack.push(L[1061]);
}
throw $e58085809;
}
var $ret58145815 = $Hann_DASH_check_DASH_temp109085821($z58105811);
++R.GAS;
return $ret58145815;
});
var $z57945795 = D;
var $f58005801 = function(_) {
return R.isFunction(anf_fun68885802)?anf_fun68885802.app(anf_arg68915803,branches18345804):R.ffi.throwNonFunApp(L[1060],anf_fun68885802,[anf_arg68915803,branches18345804]);
};
try {
if(--R.GAS > 0) {
$z57945795 = $f58005801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58005801,
"from":L[1060]});
}
} catch($e57925793) {
if(R.isCont($e57925793)) {
var $ss57965797 = {"from":L[1060],
"go":function(ann_DASH_check_DASH_temp68875805) {
return $Hann_DASH_check_DASH_temp109095806(ann_DASH_check_DASH_temp68875805);
}};
$e57925793.stack[R.EXN_STACKHEIGHT++] = $ss57965797;
}
if(R.isPyretException($e57925793)) {
$e57925793.pyretStack.push(L[1060]);
}
throw $e57925793;
}
var $ret57985799 = $Hann_DASH_check_DASH_temp109095806($z57945795);
++R.GAS;
return $ret57985799;
});
};
},{"length":3});
var anf_obj69094659 = R.makeMethod(function(self18355775) {
return function(l18365791,branches18375772,_else18385774) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1059],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l18365791,branches18375772,_else18385774],[L[1056],L[1057],L[1058]],function() {
var anf_fun68945770 = G(lists974,"all",L[1055]);
var anf_arg68975771 = R.makeFunction(function(recv_DASH_8375777) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1054],1,arguments);
}
var anf_fun68965788 = G(recv_DASH_8375777,"visit",L[1054]);
var $z57805781 = D;
var $f57865787 = function(_) {
return R.isFunction(anf_fun68965788)?anf_fun68965788.app(self18355775):R.ffi.throwNonFunApp(L[1054],anf_fun68965788,[self18355775]);
};
try {
if(--R.GAS > 0) {
$z57805781 = $f57865787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57865787,
"from":L[1054]});
}
} catch($e57785779) {
if(R.isCont($e57785779)) {
var $ss57825783 = {"from":L[1054],
"go":function(ann_DASH_check_DASH_temp68955789) {
return $Hann_DASH_check_DASH_temp109105790(ann_DASH_check_DASH_temp68955789);
}};
$e57785779.stack[R.EXN_STACKHEIGHT++] = $ss57825783;
}
if(R.isPyretException($e57785779)) {
$e57785779.pyretStack.push(L[1054]);
}
throw $e57785779;
}
var $ret57845785 = $Hann_DASH_check_DASH_temp109105790($z57805781);
++R.GAS;
return $ret57845785;
});
var $z57625763 = D;
var $f57685769 = function(_) {
return R.isFunction(anf_fun68945770)?anf_fun68945770.app(anf_arg68975771,branches18375772):R.ffi.throwNonFunApp(L[1053],anf_fun68945770,[anf_arg68975771,branches18375772]);
};
try {
if(--R.GAS > 0) {
$z57625763 = $f57685769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57685769,
"from":L[1053]});
}
} catch($e57605761) {
if(R.isCont($e57605761)) {
var $ss57645765 = {"from":L[1053],
"go":function(and_DASH_oper_DASH_8365773) {
return $Hand_DASH_oper_DASH_109145776(and_DASH_oper_DASH_8365773,_else18385774,self18355775);
}};
$e57605761.stack[R.EXN_STACKHEIGHT++] = $ss57645765;
}
if(R.isPyretException($e57605761)) {
$e57605761.pyretStack.push(L[1053]);
}
throw $e57605761;
}
var $ret57665767 = $Hand_DASH_oper_DASH_109145776($z57625763,_else18385774,self18355775);
++R.GAS;
return $ret57665767;
});
};
},{"length":4});
var anf_obj69264660 = R.makeMethod(function(self18395742) {
return function(l18405758,name18415759,args18425739,body18435741) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1052],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,Expr86111],[l18405758,name18415759,args18425739,body18435741],[L[1048],L[1049],L[1050],L[1051]],function() {
var anf_fun69115737 = G(lists974,"all",L[1047]);
var anf_arg69145738 = R.makeFunction(function(recv_DASH_8405744) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1046],1,arguments);
}
var anf_fun69135755 = G(recv_DASH_8405744,"visit",L[1046]);
var $z57475748 = D;
var $f57535754 = function(_) {
return R.isFunction(anf_fun69135755)?anf_fun69135755.app(self18395742):R.ffi.throwNonFunApp(L[1046],anf_fun69135755,[self18395742]);
};
try {
if(--R.GAS > 0) {
$z57475748 = $f57535754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57535754,
"from":L[1046]});
}
} catch($e57455746) {
if(R.isCont($e57455746)) {
var $ss57495750 = {"from":L[1046],
"go":function(ann_DASH_check_DASH_temp69125756) {
return $Hann_DASH_check_DASH_temp109155757(ann_DASH_check_DASH_temp69125756);
}};
$e57455746.stack[R.EXN_STACKHEIGHT++] = $ss57495750;
}
if(R.isPyretException($e57455746)) {
$e57455746.pyretStack.push(L[1046]);
}
throw $e57455746;
}
var $ret57515752 = $Hann_DASH_check_DASH_temp109155757($z57475748);
++R.GAS;
return $ret57515752;
});
var $z57295730 = D;
var $f57355736 = function(_) {
return R.isFunction(anf_fun69115737)?anf_fun69115737.app(anf_arg69145738,args18425739):R.ffi.throwNonFunApp(L[1045],anf_fun69115737,[anf_arg69145738,args18425739]);
};
try {
if(--R.GAS > 0) {
$z57295730 = $f57355736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57355736,
"from":L[1045]});
}
} catch($e57275728) {
if(R.isCont($e57275728)) {
var $ss57315732 = {"from":L[1045],
"go":function(and_DASH_oper_DASH_8395740) {
return $Hand_DASH_oper_DASH_109195743(and_DASH_oper_DASH_8395740,body18435741,self18395742);
}};
$e57275728.stack[R.EXN_STACKHEIGHT++] = $ss57315732;
}
if(R.isPyretException($e57275728)) {
$e57275728.pyretStack.push(L[1045]);
}
throw $e57275728;
}
var $ret57335734 = $Hand_DASH_oper_DASH_109195743($z57295730,body18435741,self18395742);
++R.GAS;
return $ret57335734;
});
};
},{"length":5});
var anf_obj69484661 = R.makeMethod(function(self18445720) {
return function(l18455726,typ18465725,val18475723,branches18485722) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1044],4,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111,List17129],[l18455726,typ18465725,val18475723,branches18485722],[L[1040],L[1041],L[1042],L[1043]],function() {
var anf_fun69285719 = G(typ18465725,"visit",L[1039]);
var $z57115712 = D;
var $f57175718 = function(_) {
return R.isFunction(anf_fun69285719)?anf_fun69285719.app(self18445720):R.ffi.throwNonFunApp(L[1038],anf_fun69285719,[self18445720]);
};
try {
if(--R.GAS > 0) {
$z57115712 = $f57175718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57175718,
"from":L[1038]});
}
} catch($e57095710) {
if(R.isCont($e57095710)) {
var $ss57135714 = {"from":L[1038],
"go":function(and_DASH_oper_DASH_8425721) {
return $Hand_DASH_oper_DASH_109265724(and_DASH_oper_DASH_8425721,branches18485722,lists974,self18445720,val18475723);
}};
$e57095710.stack[R.EXN_STACKHEIGHT++] = $ss57135714;
}
if(R.isPyretException($e57095710)) {
$e57095710.pyretStack.push(L[1038]);
}
throw $e57095710;
}
var $ret57155716 = $Hand_DASH_oper_DASH_109265724($z57115712,branches18485722,lists974,self18445720,val18475723);
++R.GAS;
return $ret57155716;
});
};
},{"length":5});
var anf_obj69754662 = R.makeMethod(function(self18495701) {
return function(l18505708,typ18515707,val18525705,branches18535704,_else18545703) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1037],5,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111,List17129,Expr86111],[l18505708,typ18515707,val18525705,branches18535704,_else18545703],[L[1032],L[1033],L[1034],L[1035],L[1036]],function() {
var anf_fun69505700 = G(typ18515707,"visit",L[1031]);
var $z56925693 = D;
var $f56985699 = function(_) {
return R.isFunction(anf_fun69505700)?anf_fun69505700.app(self18495701):R.ffi.throwNonFunApp(L[1030],anf_fun69505700,[self18495701]);
};
try {
if(--R.GAS > 0) {
$z56925693 = $f56985699();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56985699,
"from":L[1030]});
}
} catch($e56905691) {
if(R.isCont($e56905691)) {
var $ss56945695 = {"from":L[1030],
"go":function(and_DASH_oper_DASH_8465702) {
return $Hand_DASH_oper_DASH_109355706(and_DASH_oper_DASH_8465702,_else18545703,branches18535704,lists974,self18495701,val18525705);
}};
$e56905691.stack[R.EXN_STACKHEIGHT++] = $ss56945695;
}
if(R.isPyretException($e56905691)) {
$e56905691.pyretStack.push(L[1030]);
}
throw $e56905691;
}
var $ret56965697 = $Hand_DASH_oper_DASH_109355706($z56925693,_else18545703,branches18535704,lists974,self18495701,val18525705);
++R.GAS;
return $ret56965697;
});
};
},{"length":6});
var anf_obj69944663 = R.makeMethod(function(self18555683) {
return function(l18565689,body18575688,id18585686,_except18595685) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1029],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Bind90101,Expr86111],[l18565689,body18575688,id18585686,_except18595685],[L[1025],L[1026],L[1027],L[1028]],function() {
var anf_fun69775682 = G(body18575688,"visit",L[1024]);
var $z56745675 = D;
var $f56805681 = function(_) {
return R.isFunction(anf_fun69775682)?anf_fun69775682.app(self18555683):R.ffi.throwNonFunApp(L[1023],anf_fun69775682,[self18555683]);
};
try {
if(--R.GAS > 0) {
$z56745675 = $f56805681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56805681,
"from":L[1023]});
}
} catch($e56725673) {
if(R.isCont($e56725673)) {
var $ss56765677 = {"from":L[1023],
"go":function(and_DASH_oper_DASH_8515684) {
return $Hand_DASH_oper_DASH_109415687(and_DASH_oper_DASH_8515684,_except18595685,id18585686,self18555683);
}};
$e56725673.stack[R.EXN_STACKHEIGHT++] = $ss56765677;
}
if(R.isPyretException($e56725673)) {
$e56725673.pyretStack.push(L[1023]);
}
throw $e56725673;
}
var $ret56785679 = $Hand_DASH_oper_DASH_109415687($z56745675,_except18595685,id18585686,self18555683);
++R.GAS;
return $ret56785679;
});
};
},{"length":5});
var anf_obj70084664 = R.makeMethod(function(self18605665) {
return function(l18615670,op18625671,left18635669,right18645667) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1022],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111,Expr86111],[l18615670,op18625671,left18635669,right18645667],[L[1018],L[1019],L[1020],L[1021]],function() {
var anf_fun69965664 = G(left18635669,"visit",L[1017]);
var $z56565657 = D;
var $f56625663 = function(_) {
return R.isFunction(anf_fun69965664)?anf_fun69965664.app(self18605665):R.ffi.throwNonFunApp(L[1016],anf_fun69965664,[self18605665]);
};
try {
if(--R.GAS > 0) {
$z56565657 = $f56625663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56625663,
"from":L[1016]});
}
} catch($e56545655) {
if(R.isCont($e56545655)) {
var $ss56585659 = {"from":L[1016],
"go":function(and_DASH_oper_DASH_8545666) {
return $Hand_DASH_oper_DASH_109455668(and_DASH_oper_DASH_8545666,right18645667,self18605665);
}};
$e56545655.stack[R.EXN_STACKHEIGHT++] = $ss56585659;
}
if(R.isPyretException($e56545655)) {
$e56545655.pyretStack.push(L[1016]);
}
throw $e56545655;
}
var $ret56605661 = $Hand_DASH_oper_DASH_109455668($z56565657,right18645667,self18605665);
++R.GAS;
return $ret56605661;
});
};
},{"length":5});
var anf_obj70224665 = R.makeMethod(function(self18655647) {
return function(l18665652,op18675653,left18685651,right18695649) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1015],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111,Expr86111],[l18665652,op18675653,left18685651,right18695649],[L[1011],L[1012],L[1013],L[1014]],function() {
var anf_fun70105646 = G(left18685651,"visit",L[1010]);
var $z56385639 = D;
var $f56445645 = function(_) {
return R.isFunction(anf_fun70105646)?anf_fun70105646.app(self18655647):R.ffi.throwNonFunApp(L[1009],anf_fun70105646,[self18655647]);
};
try {
if(--R.GAS > 0) {
$z56385639 = $f56445645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56445645,
"from":L[1009]});
}
} catch($e56365637) {
if(R.isCont($e56365637)) {
var $ss56405641 = {"from":L[1009],
"go":function(and_DASH_oper_DASH_8565648) {
return $Hand_DASH_oper_DASH_109495650(and_DASH_oper_DASH_8565648,right18695649,self18655647);
}};
$e56365637.stack[R.EXN_STACKHEIGHT++] = $ss56405641;
}
if(R.isPyretException($e56365637)) {
$e56365637.pyretStack.push(L[1009]);
}
throw $e56365637;
}
var $ret56425643 = $Hand_DASH_oper_DASH_109495650($z56385639,right18695649,self18655647);
++R.GAS;
return $ret56425643;
});
};
},{"length":5});
var anf_obj70254666 = R.makeMethod(function(self18705631) {
return function(l18715635,expr18725634) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1005],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l18715635,expr18725634],[L[1007],L[1008]],function() {
var anf_fun70245630 = G(expr18725634,"visit",L[1006]);
var $z56225623 = D;
var $f56285629 = function(_) {
return R.isFunction(anf_fun70245630)?anf_fun70245630.app(self18705631):R.ffi.throwNonFunApp(L[1005],anf_fun70245630,[self18705631]);
};
try {
if(--R.GAS > 0) {
$z56225623 = $f56285629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56285629,
"from":L[1005]});
}
} catch($e56205621) {
if(R.isCont($e56205621)) {
var $ss56245625 = {"from":L[1005],
"go":function(ann_DASH_check_DASH_temp70235632) {
return $Hann_DASH_check_DASH_temp109505633(ann_DASH_check_DASH_temp70235632);
}};
$e56205621.stack[R.EXN_STACKHEIGHT++] = $ss56245625;
}
if(R.isPyretException($e56205621)) {
$e56205621.pyretStack.push(L[1005]);
}
throw $e56205621;
}
var $ret56265627 = $Hann_DASH_check_DASH_temp109505633($z56225623);
++R.GAS;
return $ret56265627;
});
};
},{"length":3});
var anf_obj70604667 = R.makeMethod(function(self18735602) {
return function(l18745618,params18755596,args18765600,ann18775599,doc18785619,body18795601,_check18805598) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[1004],7,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l18745618,params18755596,args18765600,ann18775599,doc18785619,body18795601,_check18805598],[L[997],L[998],L[999],L[1000],L[1001],L[1002],L[1003]],function() {
var anf_fun70275594 = G(lists974,"all",L[996]);
var anf_arg70305595 = R.makeFunction(function(recv_DASH_8595604) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[995],1,arguments);
}
var anf_fun70295615 = G(recv_DASH_8595604,"visit",L[995]);
var $z56075608 = D;
var $f56135614 = function(_) {
return R.isFunction(anf_fun70295615)?anf_fun70295615.app(self18735602):R.ffi.throwNonFunApp(L[995],anf_fun70295615,[self18735602]);
};
try {
if(--R.GAS > 0) {
$z56075608 = $f56135614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56135614,
"from":L[995]});
}
} catch($e56055606) {
if(R.isCont($e56055606)) {
var $ss56095610 = {"from":L[995],
"go":function(ann_DASH_check_DASH_temp70285616) {
return $Hann_DASH_check_DASH_temp109515617(ann_DASH_check_DASH_temp70285616);
}};
$e56055606.stack[R.EXN_STACKHEIGHT++] = $ss56095610;
}
if(R.isPyretException($e56055606)) {
$e56055606.pyretStack.push(L[995]);
}
throw $e56055606;
}
var $ret56115612 = $Hann_DASH_check_DASH_temp109515617($z56075608);
++R.GAS;
return $ret56115612;
});
var $z55865587 = D;
var $f55925593 = function(_) {
return R.isFunction(anf_fun70275594)?anf_fun70275594.app(anf_arg70305595,params18755596):R.ffi.throwNonFunApp(L[994],anf_fun70275594,[anf_arg70305595,params18755596]);
};
try {
if(--R.GAS > 0) {
$z55865587 = $f55925593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55925593,
"from":L[994]});
}
} catch($e55845585) {
if(R.isCont($e55845585)) {
var $ss55885589 = {"from":L[994],
"go":function(and_DASH_oper_DASH_8585597) {
return $Hand_DASH_oper_DASH_109625603(and_DASH_oper_DASH_8585597,_check18805598,ann18775599,args18765600,body18795601,lists974,self18735602);
}};
$e55845585.stack[R.EXN_STACKHEIGHT++] = $ss55885589;
}
if(R.isPyretException($e55845585)) {
$e55845585.pyretStack.push(L[994]);
}
throw $e55845585;
}
var $ret55905591 = $Hand_DASH_oper_DASH_109625603($z55865587,_check18805598,ann18775599,args18765600,body18795601,lists974,self18735602);
++R.GAS;
return $ret55905591;
});
};
},{"length":8});
var anf_obj70874668 = R.makeMethod(function(self18815566) {
return function(l18825582,args18835561,ann18845564,doc18855583,body18865565,_check18875563) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[993],6,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l18825582,args18835561,ann18845564,doc18855583,body18865565,_check18875563],[L[987],L[988],L[989],L[990],L[991],L[992]],function() {
var anf_fun70625559 = G(lists974,"all",L[986]);
var anf_arg70655560 = R.makeFunction(function(recv_DASH_8665568) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[985],1,arguments);
}
var anf_fun70645579 = G(recv_DASH_8665568,"visit",L[985]);
var $z55715572 = D;
var $f55775578 = function(_) {
return R.isFunction(anf_fun70645579)?anf_fun70645579.app(self18815566):R.ffi.throwNonFunApp(L[985],anf_fun70645579,[self18815566]);
};
try {
if(--R.GAS > 0) {
$z55715572 = $f55775578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55775578,
"from":L[985]});
}
} catch($e55695570) {
if(R.isCont($e55695570)) {
var $ss55735574 = {"from":L[985],
"go":function(ann_DASH_check_DASH_temp70635580) {
return $Hann_DASH_check_DASH_temp109635581(ann_DASH_check_DASH_temp70635580);
}};
$e55695570.stack[R.EXN_STACKHEIGHT++] = $ss55735574;
}
if(R.isPyretException($e55695570)) {
$e55695570.pyretStack.push(L[985]);
}
throw $e55695570;
}
var $ret55755576 = $Hann_DASH_check_DASH_temp109635581($z55715572);
++R.GAS;
return $ret55755576;
});
var $z55515552 = D;
var $f55575558 = function(_) {
return R.isFunction(anf_fun70625559)?anf_fun70625559.app(anf_arg70655560,args18835561):R.ffi.throwNonFunApp(L[984],anf_fun70625559,[anf_arg70655560,args18835561]);
};
try {
if(--R.GAS > 0) {
$z55515552 = $f55575558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55575558,
"from":L[984]});
}
} catch($e55495550) {
if(R.isCont($e55495550)) {
var $ss55535554 = {"from":L[984],
"go":function(and_DASH_oper_DASH_8655562) {
return $Hand_DASH_oper_DASH_109715567(and_DASH_oper_DASH_8655562,_check18875563,ann18845564,body18865565,self18815566);
}};
$e55495550.stack[R.EXN_STACKHEIGHT++] = $ss55535554;
}
if(R.isPyretException($e55495550)) {
$e55495550.pyretStack.push(L[984]);
}
throw $e55495550;
}
var $ret55555556 = $Hand_DASH_oper_DASH_109715567($z55515552,_check18875563,ann18845564,body18865565,self18815566);
++R.GAS;
return $ret55555556;
});
};
},{"length":7});
var anf_obj71044669 = R.makeMethod(function(self18885543) {
return function(l18895548,supe18905547,fields18915545) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[983],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l18895548,supe18905547,fields18915545],[L[980],L[981],L[982]],function() {
var anf_fun70895542 = G(supe18905547,"visit",L[979]);
var $z55345535 = D;
var $f55405541 = function(_) {
return R.isFunction(anf_fun70895542)?anf_fun70895542.app(self18885543):R.ffi.throwNonFunApp(L[978],anf_fun70895542,[self18885543]);
};
try {
if(--R.GAS > 0) {
$z55345535 = $f55405541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55405541,
"from":L[978]});
}
} catch($e55325533) {
if(R.isCont($e55325533)) {
var $ss55365537 = {"from":L[978],
"go":function(and_DASH_oper_DASH_8705544) {
return $Hand_DASH_oper_DASH_109765546(and_DASH_oper_DASH_8705544,fields18915545,lists974,self18885543);
}};
$e55325533.stack[R.EXN_STACKHEIGHT++] = $ss55365537;
}
if(R.isPyretException($e55325533)) {
$e55325533.pyretStack.push(L[978]);
}
throw $e55325533;
}
var $ret55385539 = $Hand_DASH_oper_DASH_109765546($z55345535,fields18915545,lists974,self18885543);
++R.GAS;
return $ret55385539;
});
};
},{"length":4});
var anf_obj71214670 = R.makeMethod(function(self18925526) {
return function(l18935531,supe18945530,fields18955528) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[977],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l18935531,supe18945530,fields18955528],[L[974],L[975],L[976]],function() {
var anf_fun71065525 = G(supe18945530,"visit",L[973]);
var $z55175518 = D;
var $f55235524 = function(_) {
return R.isFunction(anf_fun71065525)?anf_fun71065525.app(self18925526):R.ffi.throwNonFunApp(L[972],anf_fun71065525,[self18925526]);
};
try {
if(--R.GAS > 0) {
$z55175518 = $f55235524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55235524,
"from":L[972]});
}
} catch($e55155516) {
if(R.isCont($e55155516)) {
var $ss55195520 = {"from":L[972],
"go":function(and_DASH_oper_DASH_8735527) {
return $Hand_DASH_oper_DASH_109815529(and_DASH_oper_DASH_8735527,fields18955528,lists974,self18925526);
}};
$e55155516.stack[R.EXN_STACKHEIGHT++] = $ss55195520;
}
if(R.isPyretException($e55155516)) {
$e55155516.pyretStack.push(L[972]);
}
throw $e55155516;
}
var $ret55215522 = $Hand_DASH_oper_DASH_109815529($z55175518,fields18955528,lists974,self18925526);
++R.GAS;
return $ret55215522;
});
};
},{"length":4});
var anf_obj71274671 = R.makeMethod(function(self18965511) {
return function(l18975514,fields18985496) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[967],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l18975514,fields18985496],[L[970],L[971]],function() {
var anf_fun71235494 = G(lists974,"all",L[969]);
var anf_arg71265495 = R.makeFunction(function(recv_DASH_8765499) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[968],1,arguments);
}
var anf_fun71255510 = G(recv_DASH_8765499,"visit",L[968]);
var $z55025503 = D;
var $f55085509 = function(_) {
return R.isFunction(anf_fun71255510)?anf_fun71255510.app(self18965511):R.ffi.throwNonFunApp(L[968],anf_fun71255510,[self18965511]);
};
try {
if(--R.GAS > 0) {
$z55025503 = $f55085509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55085509,
"from":L[968]});
}
} catch($e55005501) {
if(R.isCont($e55005501)) {
var $ss55045505 = {"from":L[968],
"go":function(ann_DASH_check_DASH_temp71245512) {
return $Hann_DASH_check_DASH_temp109825513(ann_DASH_check_DASH_temp71245512);
}};
$e55005501.stack[R.EXN_STACKHEIGHT++] = $ss55045505;
}
if(R.isPyretException($e55005501)) {
$e55005501.pyretStack.push(L[968]);
}
throw $e55005501;
}
var $ret55065507 = $Hann_DASH_check_DASH_temp109825513($z55025503);
++R.GAS;
return $ret55065507;
});
var $z54865487 = D;
var $f54925493 = function(_) {
return R.isFunction(anf_fun71235494)?anf_fun71235494.app(anf_arg71265495,fields18985496):R.ffi.throwNonFunApp(L[967],anf_fun71235494,[anf_arg71265495,fields18985496]);
};
try {
if(--R.GAS > 0) {
$z54865487 = $f54925493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54925493,
"from":L[967]});
}
} catch($e54845485) {
if(R.isCont($e54845485)) {
var $ss54885489 = {"from":L[967],
"go":function(ann_DASH_check_DASH_temp71225497) {
return $Hann_DASH_check_DASH_temp109835498(ann_DASH_check_DASH_temp71225497);
}};
$e54845485.stack[R.EXN_STACKHEIGHT++] = $ss54885489;
}
if(R.isPyretException($e54845485)) {
$e54845485.pyretStack.push(L[967]);
}
throw $e54845485;
}
var $ret54905491 = $Hann_DASH_check_DASH_temp109835498($z54865487);
++R.GAS;
return $ret54905491;
});
};
},{"length":3});
var anf_obj71334672 = R.makeMethod(function(self18995480) {
return function(l19005483,values19015465) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[962],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l19005483,values19015465],[L[965],L[966]],function() {
var anf_fun71295463 = G(lists974,"all",L[964]);
var anf_arg71325464 = R.makeFunction(function(recv_DASH_8775468) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[963],1,arguments);
}
var anf_fun71315479 = G(recv_DASH_8775468,"visit",L[963]);
var $z54715472 = D;
var $f54775478 = function(_) {
return R.isFunction(anf_fun71315479)?anf_fun71315479.app(self18995480):R.ffi.throwNonFunApp(L[963],anf_fun71315479,[self18995480]);
};
try {
if(--R.GAS > 0) {
$z54715472 = $f54775478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54775478,
"from":L[963]});
}
} catch($e54695470) {
if(R.isCont($e54695470)) {
var $ss54735474 = {"from":L[963],
"go":function(ann_DASH_check_DASH_temp71305481) {
return $Hann_DASH_check_DASH_temp109845482(ann_DASH_check_DASH_temp71305481);
}};
$e54695470.stack[R.EXN_STACKHEIGHT++] = $ss54735474;
}
if(R.isPyretException($e54695470)) {
$e54695470.pyretStack.push(L[963]);
}
throw $e54695470;
}
var $ret54755476 = $Hann_DASH_check_DASH_temp109845482($z54715472);
++R.GAS;
return $ret54755476;
});
var $z54555456 = D;
var $f54615462 = function(_) {
return R.isFunction(anf_fun71295463)?anf_fun71295463.app(anf_arg71325464,values19015465):R.ffi.throwNonFunApp(L[962],anf_fun71295463,[anf_arg71325464,values19015465]);
};
try {
if(--R.GAS > 0) {
$z54555456 = $f54615462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54615462,
"from":L[962]});
}
} catch($e54535454) {
if(R.isCont($e54535454)) {
var $ss54575458 = {"from":L[962],
"go":function(ann_DASH_check_DASH_temp71285466) {
return $Hann_DASH_check_DASH_temp109855467(ann_DASH_check_DASH_temp71285466);
}};
$e54535454.stack[R.EXN_STACKHEIGHT++] = $ss54575458;
}
if(R.isPyretException($e54535454)) {
$e54535454.pyretStack.push(L[962]);
}
throw $e54535454;
}
var $ret54595460 = $Hann_DASH_check_DASH_temp109855467($z54555456);
++R.GAS;
return $ret54595460;
});
};
},{"length":3});
var anf_obj71474673 = R.makeMethod(function(self19025447) {
return function(l19035452,expr19045451,typ19055449) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[961],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Name66133],[l19035452,expr19045451,typ19055449],[L[958],L[959],L[960]],function() {
var anf_fun71355446 = G(expr19045451,"visit",L[957]);
var $z54385439 = D;
var $f54445445 = function(_) {
return R.isFunction(anf_fun71355446)?anf_fun71355446.app(self19025447):R.ffi.throwNonFunApp(L[956],anf_fun71355446,[self19025447]);
};
try {
if(--R.GAS > 0) {
$z54385439 = $f54445445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54445445,
"from":L[956]});
}
} catch($e54365437) {
if(R.isCont($e54365437)) {
var $ss54405441 = {"from":L[956],
"go":function(and_DASH_oper_DASH_8785448) {
return $Hand_DASH_oper_DASH_109895450(and_DASH_oper_DASH_8785448,self19025447,typ19055449);
}};
$e54365437.stack[R.EXN_STACKHEIGHT++] = $ss54405441;
}
if(R.isPyretException($e54365437)) {
$e54365437.pyretStack.push(L[956]);
}
throw $e54365437;
}
var $ret54425443 = $Hand_DASH_oper_DASH_109895450($z54385439,self19025447,typ19055449);
++R.GAS;
return $ret54425443;
});
};
},{"length":4});
var anf_obj71614674 = R.makeMethod(function(self19065430) {
return function(l19075435,expr19085434,typ19095432) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[955],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Name66133],[l19075435,expr19085434,typ19095432],[L[952],L[953],L[954]],function() {
var anf_fun71495429 = G(expr19085434,"visit",L[951]);
var $z54215422 = D;
var $f54275428 = function(_) {
return R.isFunction(anf_fun71495429)?anf_fun71495429.app(self19065430):R.ffi.throwNonFunApp(L[950],anf_fun71495429,[self19065430]);
};
try {
if(--R.GAS > 0) {
$z54215422 = $f54275428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54275428,
"from":L[950]});
}
} catch($e54195420) {
if(R.isCont($e54195420)) {
var $ss54235424 = {"from":L[950],
"go":function(and_DASH_oper_DASH_8805431) {
return $Hand_DASH_oper_DASH_109935433(and_DASH_oper_DASH_8805431,self19065430,typ19095432);
}};
$e54195420.stack[R.EXN_STACKHEIGHT++] = $ss54235424;
}
if(R.isPyretException($e54195420)) {
$e54195420.pyretStack.push(L[950]);
}
throw $e54195420;
}
var $ret54255426 = $Hand_DASH_oper_DASH_109935433($z54215422,self19065430,typ19095432);
++R.GAS;
return $ret54255426;
});
};
},{"length":4});
var anf_obj71784675 = R.makeMethod(function(self19105412) {
return function(l19115417,mod19125418,constructor19135416,values19145414) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[949],4,arguments);
}
return R.checkAnnArgs([Loc116130,ConstructModifier88105,Expr86111,List17129],[l19115417,mod19125418,constructor19135416,values19145414],[L[945],L[946],L[947],L[948]],function() {
var anf_fun71635411 = G(constructor19135416,"visit",L[944]);
var $z54035404 = D;
var $f54095410 = function(_) {
return R.isFunction(anf_fun71635411)?anf_fun71635411.app(self19105412):R.ffi.throwNonFunApp(L[943],anf_fun71635411,[self19105412]);
};
try {
if(--R.GAS > 0) {
$z54035404 = $f54095410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54095410,
"from":L[943]});
}
} catch($e54015402) {
if(R.isCont($e54015402)) {
var $ss54055406 = {"from":L[943],
"go":function(and_DASH_oper_DASH_8825413) {
return $Hand_DASH_oper_DASH_109985415(and_DASH_oper_DASH_8825413,lists974,self19105412,values19145414);
}};
$e54015402.stack[R.EXN_STACKHEIGHT++] = $ss54055406;
}
if(R.isPyretException($e54015402)) {
$e54015402.pyretStack.push(L[943]);
}
throw $e54015402;
}
var $ret54075408 = $Hand_DASH_oper_DASH_109985415($z54035404,lists974,self19105412,values19145414);
++R.GAS;
return $ret54075408;
});
};
},{"length":5});
var anf_obj71954676 = R.makeMethod(function(self19155395) {
return function(l19165400,_fun19175399,args19185397) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[942],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l19165400,_fun19175399,args19185397],[L[939],L[940],L[941]],function() {
var anf_fun71805394 = G(_fun19175399,"visit",L[938]);
var $z53865387 = D;
var $f53925393 = function(_) {
return R.isFunction(anf_fun71805394)?anf_fun71805394.app(self19155395):R.ffi.throwNonFunApp(L[937],anf_fun71805394,[self19155395]);
};
try {
if(--R.GAS > 0) {
$z53865387 = $f53925393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53925393,
"from":L[937]});
}
} catch($e53845385) {
if(R.isCont($e53845385)) {
var $ss53885389 = {"from":L[937],
"go":function(and_DASH_oper_DASH_8855396) {
return $Hand_DASH_oper_DASH_110035398(and_DASH_oper_DASH_8855396,args19185397,lists974,self19155395);
}};
$e53845385.stack[R.EXN_STACKHEIGHT++] = $ss53885389;
}
if(R.isPyretException($e53845385)) {
$e53845385.pyretStack.push(L[937]);
}
throw $e53845385;
}
var $ret53905391 = $Hand_DASH_oper_DASH_110035398($z53865387,args19185397,lists974,self19155395);
++R.GAS;
return $ret53905391;
});
};
},{"length":4});
var anf_obj72014677 = R.makeMethod(function(self19195379) {
return function(l19205382,_fun19215383,args19225364) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[931],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129],[l19205382,_fun19215383,args19225364],[L[934],L[935],L[936]],function() {
var anf_fun71975362 = G(lists974,"all",L[933]);
var anf_arg72005363 = R.makeFunction(function(recv_DASH_8885367) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[932],1,arguments);
}
var anf_fun71995378 = G(recv_DASH_8885367,"visit",L[932]);
var $z53705371 = D;
var $f53765377 = function(_) {
return R.isFunction(anf_fun71995378)?anf_fun71995378.app(self19195379):R.ffi.throwNonFunApp(L[932],anf_fun71995378,[self19195379]);
};
try {
if(--R.GAS > 0) {
$z53705371 = $f53765377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53765377,
"from":L[932]});
}
} catch($e53685369) {
if(R.isCont($e53685369)) {
var $ss53725373 = {"from":L[932],
"go":function(ann_DASH_check_DASH_temp71985380) {
return $Hann_DASH_check_DASH_temp110045381(ann_DASH_check_DASH_temp71985380);
}};
$e53685369.stack[R.EXN_STACKHEIGHT++] = $ss53725373;
}
if(R.isPyretException($e53685369)) {
$e53685369.pyretStack.push(L[932]);
}
throw $e53685369;
}
var $ret53745375 = $Hann_DASH_check_DASH_temp110045381($z53705371);
++R.GAS;
return $ret53745375;
});
var $z53545355 = D;
var $f53605361 = function(_) {
return R.isFunction(anf_fun71975362)?anf_fun71975362.app(anf_arg72005363,args19225364):R.ffi.throwNonFunApp(L[931],anf_fun71975362,[anf_arg72005363,args19225364]);
};
try {
if(--R.GAS > 0) {
$z53545355 = $f53605361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53605361,
"from":L[931]});
}
} catch($e53525353) {
if(R.isCont($e53525353)) {
var $ss53565357 = {"from":L[931],
"go":function(ann_DASH_check_DASH_temp71965365) {
return $Hann_DASH_check_DASH_temp110055366(ann_DASH_check_DASH_temp71965365);
}};
$e53525353.stack[R.EXN_STACKHEIGHT++] = $ss53565357;
}
if(R.isPyretException($e53525353)) {
$e53525353.pyretStack.push(L[931]);
}
throw $e53525353;
}
var $ret53585359 = $Hann_DASH_check_DASH_temp110055366($z53545355);
++R.GAS;
return $ret53585359;
});
};
},{"length":4});
var anf_obj72034678 = R.makeMethod(function(self19235351) {
return function(l19245349,name19255350) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[930],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l19245349,name19255350],[L[928],L[929]],function() {
var ann_DASH_check_DASH_temp72025348 = (true);
return ann_DASH_check_DASH_temp72025348;
});
};
},{"length":3});
var anf_obj72064679 = R.makeMethod(function(self19265343) {
return function(l19275347,id19285346) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[924],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l19275347,id19285346],[L[926],L[927]],function() {
var anf_fun72055342 = G(id19285346,"visit",L[925]);
var $z53345335 = D;
var $f53405341 = function(_) {
return R.isFunction(anf_fun72055342)?anf_fun72055342.app(self19265343):R.ffi.throwNonFunApp(L[924],anf_fun72055342,[self19265343]);
};
try {
if(--R.GAS > 0) {
$z53345335 = $f53405341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53405341,
"from":L[924]});
}
} catch($e53325333) {
if(R.isCont($e53325333)) {
var $ss53365337 = {"from":L[924],
"go":function(ann_DASH_check_DASH_temp72045344) {
return $Hann_DASH_check_DASH_temp110065345(ann_DASH_check_DASH_temp72045344);
}};
$e53325333.stack[R.EXN_STACKHEIGHT++] = $ss53365337;
}
if(R.isPyretException($e53325333)) {
$e53325333.pyretStack.push(L[924]);
}
throw $e53325333;
}
var $ret53385339 = $Hann_DASH_check_DASH_temp110065345($z53345335);
++R.GAS;
return $ret53385339;
});
};
},{"length":3});
var anf_obj72094680 = R.makeMethod(function(self19295327) {
return function(l19305331,id19315330) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[920],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l19305331,id19315330],[L[922],L[923]],function() {
var anf_fun72085326 = G(id19315330,"visit",L[921]);
var $z53185319 = D;
var $f53245325 = function(_) {
return R.isFunction(anf_fun72085326)?anf_fun72085326.app(self19295327):R.ffi.throwNonFunApp(L[920],anf_fun72085326,[self19295327]);
};
try {
if(--R.GAS > 0) {
$z53185319 = $f53245325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53245325,
"from":L[920]});
}
} catch($e53165317) {
if(R.isCont($e53165317)) {
var $ss53205321 = {"from":L[920],
"go":function(ann_DASH_check_DASH_temp72075328) {
return $Hann_DASH_check_DASH_temp110075329(ann_DASH_check_DASH_temp72075328);
}};
$e53165317.stack[R.EXN_STACKHEIGHT++] = $ss53205321;
}
if(R.isPyretException($e53165317)) {
$e53165317.pyretStack.push(L[920]);
}
throw $e53165317;
}
var $ret53225323 = $Hann_DASH_check_DASH_temp110075329($z53185319);
++R.GAS;
return $ret53225323;
});
};
},{"length":3});
var anf_obj72124681 = R.makeMethod(function(self19325310) {
return function(l19335314,id19345313,safe19355315) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[915],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,$type$Boolean67],[l19335314,id19345313,safe19355315],[L[917],L[918],L[919]],function() {
var anf_fun72115309 = G(id19345313,"visit",L[916]);
var $z53015302 = D;
var $f53075308 = function(_) {
return R.isFunction(anf_fun72115309)?anf_fun72115309.app(self19325310):R.ffi.throwNonFunApp(L[915],anf_fun72115309,[self19325310]);
};
try {
if(--R.GAS > 0) {
$z53015302 = $f53075308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53075308,
"from":L[915]});
}
} catch($e52995300) {
if(R.isCont($e52995300)) {
var $ss53035304 = {"from":L[915],
"go":function(ann_DASH_check_DASH_temp72105311) {
return $Hann_DASH_check_DASH_temp110085312(ann_DASH_check_DASH_temp72105311);
}};
$e52995300.stack[R.EXN_STACKHEIGHT++] = $ss53035304;
}
if(R.isPyretException($e52995300)) {
$e52995300.pyretStack.push(L[915]);
}
throw $e52995300;
}
var $ret53055306 = $Hann_DASH_check_DASH_temp110085312($z53015302);
++R.GAS;
return $ret53055306;
});
};
},{"length":4});
var anf_obj72144682 = R.makeMethod(function(self19365298) {
return function(l19375297) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[914],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l19375297],[L[913]],function() {
var ann_DASH_check_DASH_temp72135296 = (true);
return ann_DASH_check_DASH_temp72135296;
});
};
},{"length":2});
var anf_obj72164683 = R.makeMethod(function(self19385293) {
return function(l19395294,loc19405295) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[912],2,arguments);
}
var ann_DASH_check_DASH_temp72155292 = (true);
return ann_DASH_check_DASH_temp72155292;
};
},{"length":3});
var anf_obj72184684 = R.makeMethod(function(self19415291) {
return function(l19425289,n19435290) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[911],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Number68],[l19425289,n19435290],[L[909],L[910]],function() {
var ann_DASH_check_DASH_temp72175288 = (true);
return ann_DASH_check_DASH_temp72175288;
});
};
},{"length":3});
var anf_obj72204685 = R.makeMethod(function(self19445287) {
return function(l19455284,num19465285,den19475286) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[908],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Number68,$type$Number68],[l19455284,num19465285,den19475286],[L[905],L[906],L[907]],function() {
var ann_DASH_check_DASH_temp72195283 = (true);
return ann_DASH_check_DASH_temp72195283;
});
};
},{"length":4});
var anf_obj72224686 = R.makeMethod(function(self19485282) {
return function(l19495280,b19505281) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[904],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Boolean67],[l19495280,b19505281],[L[902],L[903]],function() {
var ann_DASH_check_DASH_temp72215279 = (true);
return ann_DASH_check_DASH_temp72215279;
});
};
},{"length":3});
var anf_obj72244687 = R.makeMethod(function(self19515278) {
return function(l19525276,s19535277) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[901],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l19525276,s19535277],[L[899],L[900]],function() {
var ann_DASH_check_DASH_temp72235275 = (true);
return ann_DASH_check_DASH_temp72235275;
});
};
},{"length":3});
var anf_obj72274688 = R.makeMethod(function(self19545269) {
return function(l19555273,obj19565272,field19575274) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[894],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,$type$String69],[l19555273,obj19565272,field19575274],[L[896],L[897],L[898]],function() {
var anf_fun72265268 = G(obj19565272,"visit",L[895]);
var $z52605261 = D;
var $f52665267 = function(_) {
return R.isFunction(anf_fun72265268)?anf_fun72265268.app(self19545269):R.ffi.throwNonFunApp(L[894],anf_fun72265268,[self19545269]);
};
try {
if(--R.GAS > 0) {
$z52605261 = $f52665267();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52665267,
"from":L[894]});
}
} catch($e52585259) {
if(R.isCont($e52585259)) {
var $ss52625263 = {"from":L[894],
"go":function(ann_DASH_check_DASH_temp72255270) {
return $Hann_DASH_check_DASH_temp110095271(ann_DASH_check_DASH_temp72255270);
}};
$e52585259.stack[R.EXN_STACKHEIGHT++] = $ss52625263;
}
if(R.isPyretException($e52585259)) {
$e52585259.pyretStack.push(L[894]);
}
throw $e52585259;
}
var $ret52645265 = $Hann_DASH_check_DASH_temp110095271($z52605261);
++R.GAS;
return $ret52645265;
});
};
},{"length":4});
var anf_obj72304689 = R.makeMethod(function(self19585252) {
return function(l19595256,obj19605255,field19615257) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[889],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,$type$String69],[l19595256,obj19605255,field19615257],[L[891],L[892],L[893]],function() {
var anf_fun72295251 = G(obj19605255,"visit",L[890]);
var $z52435244 = D;
var $f52495250 = function(_) {
return R.isFunction(anf_fun72295251)?anf_fun72295251.app(self19585252):R.ffi.throwNonFunApp(L[889],anf_fun72295251,[self19585252]);
};
try {
if(--R.GAS > 0) {
$z52435244 = $f52495250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52495250,
"from":L[889]});
}
} catch($e52415242) {
if(R.isCont($e52415242)) {
var $ss52455246 = {"from":L[889],
"go":function(ann_DASH_check_DASH_temp72285253) {
return $Hann_DASH_check_DASH_temp110105254(ann_DASH_check_DASH_temp72285253);
}};
$e52415242.stack[R.EXN_STACKHEIGHT++] = $ss52455246;
}
if(R.isPyretException($e52415242)) {
$e52415242.pyretStack.push(L[889]);
}
throw $e52415242;
}
var $ret52475248 = $Hann_DASH_check_DASH_temp110105254($z52435244);
++R.GAS;
return $ret52475248;
});
};
},{"length":4});
var anf_obj72444690 = R.makeMethod(function(self19625235) {
return function(l19635240,obj19645239,field19655237) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[888],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l19635240,obj19645239,field19655237],[L[885],L[886],L[887]],function() {
var anf_fun72325234 = G(obj19645239,"visit",L[884]);
var $z52265227 = D;
var $f52325233 = function(_) {
return R.isFunction(anf_fun72325234)?anf_fun72325234.app(self19625235):R.ffi.throwNonFunApp(L[883],anf_fun72325234,[self19625235]);
};
try {
if(--R.GAS > 0) {
$z52265227 = $f52325233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52325233,
"from":L[883]});
}
} catch($e52245225) {
if(R.isCont($e52245225)) {
var $ss52285229 = {"from":L[883],
"go":function(and_DASH_oper_DASH_8895236) {
return $Hand_DASH_oper_DASH_110145238(and_DASH_oper_DASH_8895236,field19655237,self19625235);
}};
$e52245225.stack[R.EXN_STACKHEIGHT++] = $ss52285229;
}
if(R.isPyretException($e52245225)) {
$e52245225.pyretStack.push(L[883]);
}
throw $e52245225;
}
var $ret52305231 = $Hand_DASH_oper_DASH_110145238($z52265227,field19655237,self19625235);
++R.GAS;
return $ret52305231;
});
};
},{"length":4});
var anf_obj72854691 = R.makeMethod(function(self19665204) {
return function(l19675222,name19685223,params19695200,mixins19705203,variants19715206,shared_DASH_members19725205,_check19735202) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[882],7,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,List17129,List17129,List17129,Option18135],[l19675222,name19685223,params19695200,mixins19705203,variants19715206,shared_DASH_members19725205,_check19735202],[L[875],L[876],L[877],L[878],L[879],L[880],L[881]],function() {
var anf_fun72465198 = G(lists974,"all",L[874]);
var anf_arg72495199 = R.makeFunction(function(recv_DASH_8925208) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[873],1,arguments);
}
var anf_fun72485219 = G(recv_DASH_8925208,"visit",L[873]);
var $z52115212 = D;
var $f52175218 = function(_) {
return R.isFunction(anf_fun72485219)?anf_fun72485219.app(self19665204):R.ffi.throwNonFunApp(L[873],anf_fun72485219,[self19665204]);
};
try {
if(--R.GAS > 0) {
$z52115212 = $f52175218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52175218,
"from":L[873]});
}
} catch($e52095210) {
if(R.isCont($e52095210)) {
var $ss52135214 = {"from":L[873],
"go":function(ann_DASH_check_DASH_temp72475220) {
return $Hann_DASH_check_DASH_temp110155221(ann_DASH_check_DASH_temp72475220);
}};
$e52095210.stack[R.EXN_STACKHEIGHT++] = $ss52135214;
}
if(R.isPyretException($e52095210)) {
$e52095210.pyretStack.push(L[873]);
}
throw $e52095210;
}
var $ret52155216 = $Hann_DASH_check_DASH_temp110155221($z52115212);
++R.GAS;
return $ret52155216;
});
var $z51905191 = D;
var $f51965197 = function(_) {
return R.isFunction(anf_fun72465198)?anf_fun72465198.app(anf_arg72495199,params19695200):R.ffi.throwNonFunApp(L[872],anf_fun72465198,[anf_arg72495199,params19695200]);
};
try {
if(--R.GAS > 0) {
$z51905191 = $f51965197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51965197,
"from":L[872]});
}
} catch($e51885189) {
if(R.isCont($e51885189)) {
var $ss51925193 = {"from":L[872],
"go":function(and_DASH_oper_DASH_8915201) {
return $Hand_DASH_oper_DASH_110285207(and_DASH_oper_DASH_8915201,_check19735202,lists974,mixins19705203,self19665204,shared_DASH_members19725205,variants19715206);
}};
$e51885189.stack[R.EXN_STACKHEIGHT++] = $ss51925193;
}
if(R.isPyretException($e51885189)) {
$e51885189.pyretStack.push(L[872]);
}
throw $e51885189;
}
var $ret51945195 = $Hand_DASH_oper_DASH_110285207($z51905191,_check19735202,lists974,mixins19705203,self19665204,shared_DASH_members19725205,variants19715206);
++R.GAS;
return $ret51945195;
});
};
},{"length":8});
var anf_obj73314692 = R.makeMethod(function(self19745177) {
return function(l19755186,name19765187,namet19775185,params19785181,mixins19795180,variants19805183,shared_DASH_members19815182,_check19825179) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[871],8,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Name66133,List17129,List17129,List17129,List17129,Option18135],[l19755186,name19765187,namet19775185,params19785181,mixins19795180,variants19805183,shared_DASH_members19815182,_check19825179],[L[863],L[864],L[865],L[866],L[867],L[868],L[869],L[870]],function() {
var anf_fun72875176 = G(namet19775185,"visit",L[862]);
var $z51685169 = D;
var $f51745175 = function(_) {
return R.isFunction(anf_fun72875176)?anf_fun72875176.app(self19745177):R.ffi.throwNonFunApp(L[861],anf_fun72875176,[self19745177]);
};
try {
if(--R.GAS > 0) {
$z51685169 = $f51745175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51745175,
"from":L[861]});
}
} catch($e51665167) {
if(R.isCont($e51665167)) {
var $ss51705171 = {"from":L[861],
"go":function(and_DASH_oper_DASH_9005178) {
return $Hand_DASH_oper_DASH_110445184(and_DASH_oper_DASH_9005178,_check19825179,lists974,mixins19795180,params19785181,self19745177,shared_DASH_members19815182,variants19805183);
}};
$e51665167.stack[R.EXN_STACKHEIGHT++] = $ss51705171;
}
if(R.isPyretException($e51665167)) {
$e51665167.pyretStack.push(L[861]);
}
throw $e51665167;
}
var $ret51725173 = $Hand_DASH_oper_DASH_110445184($z51685169,_check19825179,lists974,mixins19795180,params19785181,self19745177,shared_DASH_members19815182,variants19805183);
++R.GAS;
return $ret51725173;
});
};
},{"length":9});
var anf_obj73584693 = R.makeMethod(function(self19835158) {
return function(l19845165,iterator19855164,bindings19865161,ann19875160,body19885162) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[860],5,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129,Ann11299,Expr86111],[l19845165,iterator19855164,bindings19865161,ann19875160,body19885162],[L[855],L[856],L[857],L[858],L[859]],function() {
var anf_fun73335157 = G(iterator19855164,"visit",L[854]);
var $z51495150 = D;
var $f51555156 = function(_) {
return R.isFunction(anf_fun73335157)?anf_fun73335157.app(self19835158):R.ffi.throwNonFunApp(L[853],anf_fun73335157,[self19835158]);
};
try {
if(--R.GAS > 0) {
$z51495150 = $f51555156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51555156,
"from":L[853]});
}
} catch($e51475148) {
if(R.isCont($e51475148)) {
var $ss51515152 = {"from":L[853],
"go":function(and_DASH_oper_DASH_9105159) {
return $Hand_DASH_oper_DASH_110535163(and_DASH_oper_DASH_9105159,ann19875160,bindings19865161,body19885162,lists974,self19835158);
}};
$e51475148.stack[R.EXN_STACKHEIGHT++] = $ss51515152;
}
if(R.isPyretException($e51475148)) {
$e51475148.pyretStack.push(L[853]);
}
throw $e51475148;
}
var $ret51535154 = $Hand_DASH_oper_DASH_110535163($z51495150,ann19875160,bindings19865161,body19885162,lists974,self19835158);
++R.GAS;
return $ret51535154;
});
};
},{"length":6});
var anf_obj73614694 = R.makeMethod(function(self19895140) {
return function(l19905144,name19915145,body19925143,keyword_DASH_check19935146) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[847],4,arguments);
}
return R.checkAnnArgs([Loc116130,Option18135,Expr86111,$type$Boolean67],[l19905144,name19915145,body19925143,keyword_DASH_check19935146],[L[849],L[850],L[851],L[852]],function() {
var anf_fun73605139 = G(body19925143,"visit",L[848]);
var $z51315132 = D;
var $f51375138 = function(_) {
return R.isFunction(anf_fun73605139)?anf_fun73605139.app(self19895140):R.ffi.throwNonFunApp(L[847],anf_fun73605139,[self19895140]);
};
try {
if(--R.GAS > 0) {
$z51315132 = $f51375138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51375138,
"from":L[847]});
}
} catch($e51295130) {
if(R.isCont($e51295130)) {
var $ss51335134 = {"from":L[847],
"go":function(ann_DASH_check_DASH_temp73595141) {
return $Hann_DASH_check_DASH_temp110545142(ann_DASH_check_DASH_temp73595141);
}};
$e51295130.stack[R.EXN_STACKHEIGHT++] = $ss51335134;
}
if(R.isPyretException($e51295130)) {
$e51295130.pyretStack.push(L[847]);
}
throw $e51295130;
}
var $ret51355136 = $Hann_DASH_check_DASH_temp110545142($z51315132);
++R.GAS;
return $ret51355136;
});
};
},{"length":5});
var anf_obj73754695 = R.makeMethod(function(self19945123) {
return function(l19955128,name19965127,value19975125) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[846],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l19955128,name19965127,value19975125],[L[843],L[844],L[845]],function() {
var anf_fun73635122 = G(name19965127,"visit",L[842]);
var $z51145115 = D;
var $f51205121 = function(_) {
return R.isFunction(anf_fun73635122)?anf_fun73635122.app(self19945123):R.ffi.throwNonFunApp(L[841],anf_fun73635122,[self19945123]);
};
try {
if(--R.GAS > 0) {
$z51145115 = $f51205121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51205121,
"from":L[841]});
}
} catch($e51125113) {
if(R.isCont($e51125113)) {
var $ss51165117 = {"from":L[841],
"go":function(and_DASH_oper_DASH_9155124) {
return $Hand_DASH_oper_DASH_110585126(and_DASH_oper_DASH_9155124,self19945123,value19975125);
}};
$e51125113.stack[R.EXN_STACKHEIGHT++] = $ss51165117;
}
if(R.isPyretException($e51125113)) {
$e51125113.pyretStack.push(L[841]);
}
throw $e51125113;
}
var $ret51185119 = $Hand_DASH_oper_DASH_110585126($z51145115,self19945123,value19975125);
++R.GAS;
return $ret51185119;
});
};
},{"length":4});
var anf_obj73944696 = R.makeMethod(function(self19985105) {
return function(l19995111,name20005110,ann20015107,value20025108) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[840],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Ann11299,Expr86111],[l19995111,name20005110,ann20015107,value20025108],[L[836],L[837],L[838],L[839]],function() {
var anf_fun73775104 = G(name20005110,"visit",L[835]);
var $z50965097 = D;
var $f51025103 = function(_) {
return R.isFunction(anf_fun73775104)?anf_fun73775104.app(self19985105):R.ffi.throwNonFunApp(L[834],anf_fun73775104,[self19985105]);
};
try {
if(--R.GAS > 0) {
$z50965097 = $f51025103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51025103,
"from":L[834]});
}
} catch($e50945095) {
if(R.isCont($e50945095)) {
var $ss50985099 = {"from":L[834],
"go":function(and_DASH_oper_DASH_9175106) {
return $Hand_DASH_oper_DASH_110645109(and_DASH_oper_DASH_9175106,ann20015107,self19985105,value20025108);
}};
$e50945095.stack[R.EXN_STACKHEIGHT++] = $ss50985099;
}
if(R.isPyretException($e50945095)) {
$e50945095.pyretStack.push(L[834]);
}
throw $e50945095;
}
var $ret51005101 = $Hand_DASH_oper_DASH_110645109($z50965097,ann20015107,self19985105,value20025108);
++R.GAS;
return $ret51005101;
});
};
},{"length":5});
var anf_obj74134697 = R.makeMethod(function(self20035087) {
return function(l20045093,name20055092,ann20065089,value20075090) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[833],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Ann11299,Expr86111],[l20045093,name20055092,ann20065089,value20075090],[L[829],L[830],L[831],L[832]],function() {
var anf_fun73965086 = G(name20055092,"visit",L[828]);
var $z50785079 = D;
var $f50845085 = function(_) {
return R.isFunction(anf_fun73965086)?anf_fun73965086.app(self20035087):R.ffi.throwNonFunApp(L[827],anf_fun73965086,[self20035087]);
};
try {
if(--R.GAS > 0) {
$z50785079 = $f50845085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50845085,
"from":L[827]});
}
} catch($e50765077) {
if(R.isCont($e50765077)) {
var $ss50805081 = {"from":L[827],
"go":function(and_DASH_oper_DASH_9205088) {
return $Hand_DASH_oper_DASH_110705091(and_DASH_oper_DASH_9205088,ann20065089,self20035087,value20075090);
}};
$e50765077.stack[R.EXN_STACKHEIGHT++] = $ss50805081;
}
if(R.isPyretException($e50765077)) {
$e50765077.pyretStack.push(L[827]);
}
throw $e50765077;
}
var $ret50825083 = $Hand_DASH_oper_DASH_110705091($z50785079,ann20065089,self20035087,value20075090);
++R.GAS;
return $ret50825083;
});
};
},{"length":5});
var anf_obj74454698 = R.makeMethod(function(self20085066) {
return function(l20095074,name20105073,args20115070,ann20125069,doc20135075,body20145071,_check20155068) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[826],7,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l20095074,name20105073,args20115070,ann20125069,doc20135075,body20145071,_check20155068],[L[819],L[820],L[821],L[822],L[823],L[824],L[825]],function() {
var anf_fun74155065 = G(name20105073,"visit",L[818]);
var $z50575058 = D;
var $f50635064 = function(_) {
return R.isFunction(anf_fun74155065)?anf_fun74155065.app(self20085066):R.ffi.throwNonFunApp(L[817],anf_fun74155065,[self20085066]);
};
try {
if(--R.GAS > 0) {
$z50575058 = $f50635064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50635064,
"from":L[817]});
}
} catch($e50555056) {
if(R.isCont($e50555056)) {
var $ss50595060 = {"from":L[817],
"go":function(and_DASH_oper_DASH_9235067) {
return $Hand_DASH_oper_DASH_110815072(and_DASH_oper_DASH_9235067,_check20155068,ann20125069,args20115070,body20145071,lists974,self20085066);
}};
$e50555056.stack[R.EXN_STACKHEIGHT++] = $ss50595060;
}
if(R.isPyretException($e50555056)) {
$e50555056.pyretStack.push(L[817]);
}
throw $e50555056;
}
var $ret50615062 = $Hand_DASH_oper_DASH_110815072($z50575058,_check20155068,ann20125069,args20115070,body20145071,lists974,self20085066);
++R.GAS;
return $ret50615062;
});
};
},{"length":8});
var anf_obj74594699 = R.makeMethod(function(self20165049) {
return function(l20175054,bind20185053,value20195051) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[816],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l20175054,bind20185053,value20195051],[L[813],L[814],L[815]],function() {
var anf_fun74475048 = G(bind20185053,"visit",L[812]);
var $z50405041 = D;
var $f50465047 = function(_) {
return R.isFunction(anf_fun74475048)?anf_fun74475048.app(self20165049):R.ffi.throwNonFunApp(L[811],anf_fun74475048,[self20165049]);
};
try {
if(--R.GAS > 0) {
$z50405041 = $f50465047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50465047,
"from":L[811]});
}
} catch($e50385039) {
if(R.isCont($e50385039)) {
var $ss50425043 = {"from":L[811],
"go":function(and_DASH_oper_DASH_9295050) {
return $Hand_DASH_oper_DASH_110855052(and_DASH_oper_DASH_9295050,self20165049,value20195051);
}};
$e50385039.stack[R.EXN_STACKHEIGHT++] = $ss50425043;
}
if(R.isPyretException($e50385039)) {
$e50385039.pyretStack.push(L[811]);
}
throw $e50385039;
}
var $ret50445045 = $Hand_DASH_oper_DASH_110855052($z50405041,self20165049,value20195051);
++R.GAS;
return $ret50445045;
});
};
},{"length":4});
var anf_obj74624700 = R.makeMethod(function(self20205032) {
return function(l20215036,member_DASH_type20225037,bind20235035) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[806],3,arguments);
}
return R.checkAnnArgs([Loc116130,VariantMemberType96147,Bind90101],[l20215036,member_DASH_type20225037,bind20235035],[L[808],L[809],L[810]],function() {
var anf_fun74615031 = G(bind20235035,"visit",L[807]);
var $z50235024 = D;
var $f50295030 = function(_) {
return R.isFunction(anf_fun74615031)?anf_fun74615031.app(self20205032):R.ffi.throwNonFunApp(L[806],anf_fun74615031,[self20205032]);
};
try {
if(--R.GAS > 0) {
$z50235024 = $f50295030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50295030,
"from":L[806]});
}
} catch($e50215022) {
if(R.isCont($e50215022)) {
var $ss50255026 = {"from":L[806],
"go":function(ann_DASH_check_DASH_temp74605033) {
return $Hann_DASH_check_DASH_temp110865034(ann_DASH_check_DASH_temp74605033);
}};
$e50215022.stack[R.EXN_STACKHEIGHT++] = $ss50255026;
}
if(R.isPyretException($e50215022)) {
$e50215022.pyretStack.push(L[806]);
}
throw $e50215022;
}
var $ret50275028 = $Hann_DASH_check_DASH_temp110865034($z50235024);
++R.GAS;
return $ret50275028;
});
};
},{"length":4});
var anf_obj74824701 = R.makeMethod(function(self20245001) {
return function(l20255018,constr_DASH_loc20265019,name20275020,members20284999,with_DASH_members20295002) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[805],5,arguments);
}
return R.checkAnnArgs([Loc116130,Loc116130,$type$String69,List17129,List17129],[l20255018,constr_DASH_loc20265019,name20275020,members20284999,with_DASH_members20295002],[L[800],L[801],L[802],L[803],L[804]],function() {
var anf_fun74644997 = G(lists974,"all",L[799]);
var anf_arg74674998 = R.makeFunction(function(recv_DASH_9325004) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[798],1,arguments);
}
var anf_fun74665015 = G(recv_DASH_9325004,"visit",L[798]);
var $z50075008 = D;
var $f50135014 = function(_) {
return R.isFunction(anf_fun74665015)?anf_fun74665015.app(self20245001):R.ffi.throwNonFunApp(L[798],anf_fun74665015,[self20245001]);
};
try {
if(--R.GAS > 0) {
$z50075008 = $f50135014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50135014,
"from":L[798]});
}
} catch($e50055006) {
if(R.isCont($e50055006)) {
var $ss50095010 = {"from":L[798],
"go":function(ann_DASH_check_DASH_temp74655016) {
return $Hann_DASH_check_DASH_temp110875017(ann_DASH_check_DASH_temp74655016);
}};
$e50055006.stack[R.EXN_STACKHEIGHT++] = $ss50095010;
}
if(R.isPyretException($e50055006)) {
$e50055006.pyretStack.push(L[798]);
}
throw $e50055006;
}
var $ret50115012 = $Hann_DASH_check_DASH_temp110875017($z50075008);
++R.GAS;
return $ret50115012;
});
var $z49894990 = D;
var $f49954996 = function(_) {
return R.isFunction(anf_fun74644997)?anf_fun74644997.app(anf_arg74674998,members20284999):R.ffi.throwNonFunApp(L[797],anf_fun74644997,[anf_arg74674998,members20284999]);
};
try {
if(--R.GAS > 0) {
$z49894990 = $f49954996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49954996,
"from":L[797]});
}
} catch($e49874988) {
if(R.isCont($e49874988)) {
var $ss49914992 = {"from":L[797],
"go":function(and_DASH_oper_DASH_9315000) {
return $Hand_DASH_oper_DASH_110925003(and_DASH_oper_DASH_9315000,lists974,self20245001,with_DASH_members20295002);
}};
$e49874988.stack[R.EXN_STACKHEIGHT++] = $ss49914992;
}
if(R.isPyretException($e49874988)) {
$e49874988.pyretStack.push(L[797]);
}
throw $e49874988;
}
var $ret49934994 = $Hand_DASH_oper_DASH_110925003($z49894990,lists974,self20245001,with_DASH_members20295002);
++R.GAS;
return $ret49934994;
});
};
},{"length":6});
var anf_obj74884702 = R.makeMethod(function(self20304982) {
return function(l20314985,name20324986,with_DASH_members20334967) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[791],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129],[l20314985,name20324986,with_DASH_members20334967],[L[794],L[795],L[796]],function() {
var anf_fun74844965 = G(lists974,"all",L[793]);
var anf_arg74874966 = R.makeFunction(function(recv_DASH_9354970) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[792],1,arguments);
}
var anf_fun74864981 = G(recv_DASH_9354970,"visit",L[792]);
var $z49734974 = D;
var $f49794980 = function(_) {
return R.isFunction(anf_fun74864981)?anf_fun74864981.app(self20304982):R.ffi.throwNonFunApp(L[792],anf_fun74864981,[self20304982]);
};
try {
if(--R.GAS > 0) {
$z49734974 = $f49794980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49794980,
"from":L[792]});
}
} catch($e49714972) {
if(R.isCont($e49714972)) {
var $ss49754976 = {"from":L[792],
"go":function(ann_DASH_check_DASH_temp74854983) {
return $Hann_DASH_check_DASH_temp110934984(ann_DASH_check_DASH_temp74854983);
}};
$e49714972.stack[R.EXN_STACKHEIGHT++] = $ss49754976;
}
if(R.isPyretException($e49714972)) {
$e49714972.pyretStack.push(L[792]);
}
throw $e49714972;
}
var $ret49774978 = $Hann_DASH_check_DASH_temp110934984($z49734974);
++R.GAS;
return $ret49774978;
});
var $z49574958 = D;
var $f49634964 = function(_) {
return R.isFunction(anf_fun74844965)?anf_fun74844965.app(anf_arg74874966,with_DASH_members20334967):R.ffi.throwNonFunApp(L[791],anf_fun74844965,[anf_arg74874966,with_DASH_members20334967]);
};
try {
if(--R.GAS > 0) {
$z49574958 = $f49634964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49634964,
"from":L[791]});
}
} catch($e49554956) {
if(R.isCont($e49554956)) {
var $ss49594960 = {"from":L[791],
"go":function(ann_DASH_check_DASH_temp74834968) {
return $Hann_DASH_check_DASH_temp110944969(ann_DASH_check_DASH_temp74834968);
}};
$e49554956.stack[R.EXN_STACKHEIGHT++] = $ss49594960;
}
if(R.isPyretException($e49554956)) {
$e49554956.pyretStack.push(L[791]);
}
throw $e49554956;
}
var $ret49614962 = $Hann_DASH_check_DASH_temp110944969($z49574958);
++R.GAS;
return $ret49614962;
});
};
},{"length":4});
var anf_obj75054703 = R.makeMethod(function(self20344937) {
return function(l20354953,name20364954,members20374934,constructor20384936) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[790],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,Constructor104107],[l20354953,name20364954,members20374934,constructor20384936],[L[786],L[787],L[788],L[789]],function() {
var anf_fun74904932 = G(lists974,"all",L[785]);
var anf_arg74934933 = R.makeFunction(function(recv_DASH_9374939) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[784],1,arguments);
}
var anf_fun74924950 = G(recv_DASH_9374939,"visit",L[784]);
var $z49424943 = D;
var $f49484949 = function(_) {
return R.isFunction(anf_fun74924950)?anf_fun74924950.app(self20344937):R.ffi.throwNonFunApp(L[784],anf_fun74924950,[self20344937]);
};
try {
if(--R.GAS > 0) {
$z49424943 = $f49484949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49484949,
"from":L[784]});
}
} catch($e49404941) {
if(R.isCont($e49404941)) {
var $ss49444945 = {"from":L[784],
"go":function(ann_DASH_check_DASH_temp74914951) {
return $Hann_DASH_check_DASH_temp110954952(ann_DASH_check_DASH_temp74914951);
}};
$e49404941.stack[R.EXN_STACKHEIGHT++] = $ss49444945;
}
if(R.isPyretException($e49404941)) {
$e49404941.pyretStack.push(L[784]);
}
throw $e49404941;
}
var $ret49464947 = $Hann_DASH_check_DASH_temp110954952($z49424943);
++R.GAS;
return $ret49464947;
});
var $z49244925 = D;
var $f49304931 = function(_) {
return R.isFunction(anf_fun74904932)?anf_fun74904932.app(anf_arg74934933,members20374934):R.ffi.throwNonFunApp(L[783],anf_fun74904932,[anf_arg74934933,members20374934]);
};
try {
if(--R.GAS > 0) {
$z49244925 = $f49304931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49304931,
"from":L[783]});
}
} catch($e49224923) {
if(R.isCont($e49224923)) {
var $ss49264927 = {"from":L[783],
"go":function(and_DASH_oper_DASH_9364935) {
return $Hand_DASH_oper_DASH_110994938(and_DASH_oper_DASH_9364935,constructor20384936,self20344937);
}};
$e49224923.stack[R.EXN_STACKHEIGHT++] = $ss49264927;
}
if(R.isPyretException($e49224923)) {
$e49224923.pyretStack.push(L[783]);
}
throw $e49224923;
}
var $ret49284929 = $Hand_DASH_oper_DASH_110994938($z49244925,constructor20384936,self20344937);
++R.GAS;
return $ret49284929;
});
};
},{"length":5});
var anf_obj75084704 = R.makeMethod(function(self20394916) {
return function(l20404920,name20414921,constructor20424919) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[778],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Constructor104107],[l20404920,name20414921,constructor20424919],[L[780],L[781],L[782]],function() {
var anf_fun75074915 = G(constructor20424919,"visit",L[779]);
var $z49074908 = D;
var $f49134914 = function(_) {
return R.isFunction(anf_fun75074915)?anf_fun75074915.app(self20394916):R.ffi.throwNonFunApp(L[778],anf_fun75074915,[self20394916]);
};
try {
if(--R.GAS > 0) {
$z49074908 = $f49134914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49134914,
"from":L[778]});
}
} catch($e49054906) {
if(R.isCont($e49054906)) {
var $ss49094910 = {"from":L[778],
"go":function(ann_DASH_check_DASH_temp75064917) {
return $Hann_DASH_check_DASH_temp111004918(ann_DASH_check_DASH_temp75064917);
}};
$e49054906.stack[R.EXN_STACKHEIGHT++] = $ss49094910;
}
if(R.isPyretException($e49054906)) {
$e49054906.pyretStack.push(L[778]);
}
throw $e49054906;
}
var $ret49114912 = $Hann_DASH_check_DASH_temp111004918($z49074908);
++R.GAS;
return $ret49114912;
});
};
},{"length":4});
var anf_obj75114705 = R.makeMethod(function(self20434899) {
return function(l20444903,self_DASH_arg20454904,body20464902) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[773],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111],[l20444903,self_DASH_arg20454904,body20464902],[L[775],L[776],L[777]],function() {
var anf_fun75104898 = G(body20464902,"visit",L[774]);
var $z48904891 = D;
var $f48964897 = function(_) {
return R.isFunction(anf_fun75104898)?anf_fun75104898.app(self20434899):R.ffi.throwNonFunApp(L[773],anf_fun75104898,[self20434899]);
};
try {
if(--R.GAS > 0) {
$z48904891 = $f48964897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48964897,
"from":L[773]});
}
} catch($e48884889) {
if(R.isCont($e48884889)) {
var $ss48924893 = {"from":L[773],
"go":function(ann_DASH_check_DASH_temp75094900) {
return $Hann_DASH_check_DASH_temp111014901(ann_DASH_check_DASH_temp75094900);
}};
$e48884889.stack[R.EXN_STACKHEIGHT++] = $ss48924893;
}
if(R.isPyretException($e48884889)) {
$e48884889.pyretStack.push(L[773]);
}
throw $e48884889;
}
var $ret48944895 = $Hann_DASH_check_DASH_temp111014901($z48904891);
++R.GAS;
return $ret48944895;
});
};
},{"length":4});
var anf_obj75134706 = R.makeMethod(function(self20474887) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[772],0,arguments);
}
var ann_DASH_check_DASH_temp75124886 = (true);
return ann_DASH_check_DASH_temp75124886;
};
},{"length":1});
var anf_obj75154707 = R.makeMethod(function(self20484885) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[771],0,arguments);
}
var ann_DASH_check_DASH_temp75144884 = (true);
return ann_DASH_check_DASH_temp75144884;
};
},{"length":1});
var anf_obj75174708 = R.makeMethod(function(self20494881) {
return function(l20504882,id20514883) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[770],2,arguments);
}
var ann_DASH_check_DASH_temp75164880 = (true);
return ann_DASH_check_DASH_temp75164880;
};
},{"length":3});
var anf_obj75344709 = R.makeMethod(function(self20524862) {
return function(l20534878,args20544859,ret20554861,$underscore20564879) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[769],4,arguments);
}
var anf_fun75194857 = G(lists974,"all",L[768]);
var anf_arg75224858 = R.makeFunction(function(recv_DASH_9404864) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[767],1,arguments);
}
var anf_fun75214875 = G(recv_DASH_9404864,"visit",L[767]);
var $z48674868 = D;
var $f48734874 = function(_) {
return R.isFunction(anf_fun75214875)?anf_fun75214875.app(self20524862):R.ffi.throwNonFunApp(L[767],anf_fun75214875,[self20524862]);
};
try {
if(--R.GAS > 0) {
$z48674868 = $f48734874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48734874,
"from":L[767]});
}
} catch($e48654866) {
if(R.isCont($e48654866)) {
var $ss48694870 = {"from":L[767],
"go":function(ann_DASH_check_DASH_temp75204876) {
return $Hann_DASH_check_DASH_temp111024877(ann_DASH_check_DASH_temp75204876);
}};
$e48654866.stack[R.EXN_STACKHEIGHT++] = $ss48694870;
}
if(R.isPyretException($e48654866)) {
$e48654866.pyretStack.push(L[767]);
}
throw $e48654866;
}
var $ret48714872 = $Hann_DASH_check_DASH_temp111024877($z48674868);
++R.GAS;
return $ret48714872;
});
var $z48494850 = D;
var $f48554856 = function(_) {
return R.isFunction(anf_fun75194857)?anf_fun75194857.app(anf_arg75224858,args20544859):R.ffi.throwNonFunApp(L[766],anf_fun75194857,[anf_arg75224858,args20544859]);
};
try {
if(--R.GAS > 0) {
$z48494850 = $f48554856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48554856,
"from":L[766]});
}
} catch($e48474848) {
if(R.isCont($e48474848)) {
var $ss48514852 = {"from":L[766],
"go":function(and_DASH_oper_DASH_9394860) {
return $Hand_DASH_oper_DASH_111064863(and_DASH_oper_DASH_9394860,ret20554861,self20524862);
}};
$e48474848.stack[R.EXN_STACKHEIGHT++] = $ss48514852;
}
if(R.isPyretException($e48474848)) {
$e48474848.pyretStack.push(L[766]);
}
throw $e48474848;
}
var $ret48534854 = $Hand_DASH_oper_DASH_111064863($z48494850,ret20554861,self20524862);
++R.GAS;
return $ret48534854;
};
},{"length":5});
var anf_obj75514710 = R.makeMethod(function(self20574830) {
return function(l20584846,args20594827,ret20604829) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[765],3,arguments);
}
var anf_fun75364825 = G(lists974,"all",L[764]);
var anf_arg75394826 = R.makeFunction(function(recv_DASH_9434832) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[763],1,arguments);
}
var anf_fun75384843 = G(recv_DASH_9434832,"visit",L[763]);
var $z48354836 = D;
var $f48414842 = function(_) {
return R.isFunction(anf_fun75384843)?anf_fun75384843.app(self20574830):R.ffi.throwNonFunApp(L[763],anf_fun75384843,[self20574830]);
};
try {
if(--R.GAS > 0) {
$z48354836 = $f48414842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48414842,
"from":L[763]});
}
} catch($e48334834) {
if(R.isCont($e48334834)) {
var $ss48374838 = {"from":L[763],
"go":function(ann_DASH_check_DASH_temp75374844) {
return $Hann_DASH_check_DASH_temp111074845(ann_DASH_check_DASH_temp75374844);
}};
$e48334834.stack[R.EXN_STACKHEIGHT++] = $ss48374838;
}
if(R.isPyretException($e48334834)) {
$e48334834.pyretStack.push(L[763]);
}
throw $e48334834;
}
var $ret48394840 = $Hann_DASH_check_DASH_temp111074845($z48354836);
++R.GAS;
return $ret48394840;
});
var $z48174818 = D;
var $f48234824 = function(_) {
return R.isFunction(anf_fun75364825)?anf_fun75364825.app(anf_arg75394826,args20594827):R.ffi.throwNonFunApp(L[762],anf_fun75364825,[anf_arg75394826,args20594827]);
};
try {
if(--R.GAS > 0) {
$z48174818 = $f48234824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48234824,
"from":L[762]});
}
} catch($e48154816) {
if(R.isCont($e48154816)) {
var $ss48194820 = {"from":L[762],
"go":function(and_DASH_oper_DASH_9424828) {
return $Hand_DASH_oper_DASH_111114831(and_DASH_oper_DASH_9424828,ret20604829,self20574830);
}};
$e48154816.stack[R.EXN_STACKHEIGHT++] = $ss48194820;
}
if(R.isPyretException($e48154816)) {
$e48154816.pyretStack.push(L[762]);
}
throw $e48154816;
}
var $ret48214822 = $Hand_DASH_oper_DASH_111114831($z48174818,ret20604829,self20574830);
++R.GAS;
return $ret48214822;
};
},{"length":4});
var anf_obj75574711 = R.makeMethod(function(self20614811) {
return function(l20624814,fields20634796) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[759],2,arguments);
}
var anf_fun75534794 = G(lists974,"all",L[761]);
var anf_arg75564795 = R.makeFunction(function(recv_DASH_9454799) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[760],1,arguments);
}
var anf_fun75554810 = G(recv_DASH_9454799,"visit",L[760]);
var $z48024803 = D;
var $f48084809 = function(_) {
return R.isFunction(anf_fun75554810)?anf_fun75554810.app(self20614811):R.ffi.throwNonFunApp(L[760],anf_fun75554810,[self20614811]);
};
try {
if(--R.GAS > 0) {
$z48024803 = $f48084809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48084809,
"from":L[760]});
}
} catch($e48004801) {
if(R.isCont($e48004801)) {
var $ss48044805 = {"from":L[760],
"go":function(ann_DASH_check_DASH_temp75544812) {
return $Hann_DASH_check_DASH_temp111124813(ann_DASH_check_DASH_temp75544812);
}};
$e48004801.stack[R.EXN_STACKHEIGHT++] = $ss48044805;
}
if(R.isPyretException($e48004801)) {
$e48004801.pyretStack.push(L[760]);
}
throw $e48004801;
}
var $ret48064807 = $Hann_DASH_check_DASH_temp111124813($z48024803);
++R.GAS;
return $ret48064807;
});
var $z47864787 = D;
var $f47924793 = function(_) {
return R.isFunction(anf_fun75534794)?anf_fun75534794.app(anf_arg75564795,fields20634796):R.ffi.throwNonFunApp(L[759],anf_fun75534794,[anf_arg75564795,fields20634796]);
};
try {
if(--R.GAS > 0) {
$z47864787 = $f47924793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47924793,
"from":L[759]});
}
} catch($e47844785) {
if(R.isCont($e47844785)) {
var $ss47884789 = {"from":L[759],
"go":function(ann_DASH_check_DASH_temp75524797) {
return $Hann_DASH_check_DASH_temp111134798(ann_DASH_check_DASH_temp75524797);
}};
$e47844785.stack[R.EXN_STACKHEIGHT++] = $ss47884789;
}
if(R.isPyretException($e47844785)) {
$e47844785.pyretStack.push(L[759]);
}
throw $e47844785;
}
var $ret47904791 = $Hann_DASH_check_DASH_temp111134798($z47864787);
++R.GAS;
return $ret47904791;
};
},{"length":3});
var anf_obj75744712 = R.makeMethod(function(self20644778) {
return function(l20654783,ann20664782,args20674780) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[758],3,arguments);
}
var anf_fun75594777 = G(ann20664782,"visit",L[757]);
var $z47694770 = D;
var $f47754776 = function(_) {
return R.isFunction(anf_fun75594777)?anf_fun75594777.app(self20644778):R.ffi.throwNonFunApp(L[756],anf_fun75594777,[self20644778]);
};
try {
if(--R.GAS > 0) {
$z47694770 = $f47754776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47754776,
"from":L[756]});
}
} catch($e47674768) {
if(R.isCont($e47674768)) {
var $ss47714772 = {"from":L[756],
"go":function(and_DASH_oper_DASH_9464779) {
return $Hand_DASH_oper_DASH_111184781(and_DASH_oper_DASH_9464779,args20674780,lists974,self20644778);
}};
$e47674768.stack[R.EXN_STACKHEIGHT++] = $ss47714772;
}
if(R.isPyretException($e47674768)) {
$e47674768.pyretStack.push(L[756]);
}
throw $e47674768;
}
var $ret47734774 = $Hand_DASH_oper_DASH_111184781($z47694770,args20674780,lists974,self20644778);
++R.GAS;
return $ret47734774;
};
},{"length":4});
var anf_obj75884713 = R.makeMethod(function(self20684761) {
return function(l20694766,ann20704765,exp20714763) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[755],3,arguments);
}
var anf_fun75764760 = G(ann20704765,"visit",L[754]);
var $z47524753 = D;
var $f47584759 = function(_) {
return R.isFunction(anf_fun75764760)?anf_fun75764760.app(self20684761):R.ffi.throwNonFunApp(L[753],anf_fun75764760,[self20684761]);
};
try {
if(--R.GAS > 0) {
$z47524753 = $f47584759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47584759,
"from":L[753]});
}
} catch($e47504751) {
if(R.isCont($e47504751)) {
var $ss47544755 = {"from":L[753],
"go":function(and_DASH_oper_DASH_9494762) {
return $Hand_DASH_oper_DASH_111224764(and_DASH_oper_DASH_9494762,exp20714763,self20684761);
}};
$e47504751.stack[R.EXN_STACKHEIGHT++] = $ss47544755;
}
if(R.isPyretException($e47504751)) {
$e47504751.pyretStack.push(L[753]);
}
throw $e47504751;
}
var $ret47564757 = $Hand_DASH_oper_DASH_111224764($z47524753,exp20714763,self20684761);
++R.GAS;
return $ret47564757;
};
},{"length":4});
var anf_obj75914714 = R.makeMethod(function(self20724744) {
return function(l20734748,obj20744747,field20754749) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[751],3,arguments);
}
var anf_fun75904743 = G(obj20744747,"visit",L[752]);
var $z47354736 = D;
var $f47414742 = function(_) {
return R.isFunction(anf_fun75904743)?anf_fun75904743.app(self20724744):R.ffi.throwNonFunApp(L[751],anf_fun75904743,[self20724744]);
};
try {
if(--R.GAS > 0) {
$z47354736 = $f47414742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47414742,
"from":L[751]});
}
} catch($e47334734) {
if(R.isCont($e47334734)) {
var $ss47374738 = {"from":L[751],
"go":function(ann_DASH_check_DASH_temp75894745) {
return $Hann_DASH_check_DASH_temp111234746(ann_DASH_check_DASH_temp75894745);
}};
$e47334734.stack[R.EXN_STACKHEIGHT++] = $ss47374738;
}
if(R.isPyretException($e47334734)) {
$e47334734.pyretStack.push(L[751]);
}
throw $e47334734;
}
var $ret47394740 = $Hann_DASH_check_DASH_temp111234746($z47354736);
++R.GAS;
return $ret47394740;
};
},{"length":4});
var anf_obj75944715 = R.makeMethod(function(self20764727) {
return function(l20774731,name20784732,ann20794730) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[749],3,arguments);
}
var anf_fun75934726 = G(ann20794730,"visit",L[750]);
var $z47184719 = D;
var $f47244725 = function(_) {
return R.isFunction(anf_fun75934726)?anf_fun75934726.app(self20764727):R.ffi.throwNonFunApp(L[749],anf_fun75934726,[self20764727]);
};
try {
if(--R.GAS > 0) {
$z47184719 = $f47244725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47244725,
"from":L[749]});
}
} catch($e47164717) {
if(R.isCont($e47164717)) {
var $ss47204721 = {"from":L[749],
"go":function(ann_DASH_check_DASH_temp75924728) {
return $Hann_DASH_check_DASH_temp111244729(ann_DASH_check_DASH_temp75924728);
}};
$e47164717.stack[R.EXN_STACKHEIGHT++] = $ss47204721;
}
if(R.isPyretException($e47164717)) {
$e47164717.pyretStack.push(L[749]);
}
throw $e47164717;
}
var $ret47224723 = $Hann_DASH_check_DASH_temp111244729($z47184719);
++R.GAS;
return $ret47224723;
};
},{"length":4});
var default_DASH_iter_DASH_visitor16642388 = R.makeObject({"option":anf_obj64104613,
"s-underscore":anf_obj64124614,
"s-name":anf_obj64144615,
"s-global":anf_obj64164616,
"s-type-global":anf_obj64184617,
"s-atom":anf_obj64204618,
"s-module":anf_obj64474619,
"s-program":anf_obj64774620,
"s-import":anf_obj64914621,
"s-file-import":anf_obj64934622,
"s-const-import":anf_obj64954623,
"s-import-types":anf_obj65094624,
"s-import-fields":anf_obj65154625,
"s-provide":anf_obj65184626,
"s-provide-all":anf_obj65204627,
"s-provide-none":anf_obj65224628,
"s-provide-types":anf_obj65284629,
"s-provide-types-all":anf_obj65304630,
"s-provide-types-none":anf_obj65324631,
"s-bind":anf_obj65464632,
"s-var-bind":anf_obj65604633,
"s-let-bind":anf_obj65744634,
"s-type-bind":anf_obj65884635,
"s-newtype-bind":anf_obj66024636,
"s-type-let-expr":anf_obj66194637,
"s-let-expr":anf_obj66364638,
"s-letrec-bind":anf_obj66504639,
"s-letrec":anf_obj66674640,
"s-hint-exp":anf_obj66704641,
"s-instantiate":anf_obj66874642,
"s-block":anf_obj66934643,
"s-user-block":anf_obj66964644,
"s-fun":anf_obj67314645,
"s-type":anf_obj67454646,
"s-newtype":anf_obj67594647,
"s-var":anf_obj67734648,
"s-let":anf_obj67874649,
"s-graph":anf_obj67934650,
"s-when":anf_obj68074651,
"s-contract":anf_obj68214652,
"s-assign":anf_obj68354653,
"s-if-branch":anf_obj68494654,
"s-if-pipe-branch":anf_obj68634655,
"s-if":anf_obj68694656,
"s-if-else":anf_obj68864657,
"s-if-pipe":anf_obj68924658,
"s-if-pipe-else":anf_obj69094659,
"s-cases-branch":anf_obj69264660,
"s-cases":anf_obj69484661,
"s-cases-else":anf_obj69754662,
"s-try":anf_obj69944663,
"s-op":anf_obj70084664,
"s-check-test":anf_obj70224665,
"s-paren":anf_obj70254666,
"s-lam":anf_obj70604667,
"s-method":anf_obj70874668,
"s-extend":anf_obj71044669,
"s-update":anf_obj71214670,
"s-obj":anf_obj71274671,
"s-array":anf_obj71334672,
"s-bless":anf_obj71474673,
"s-confirm":anf_obj71614674,
"s-construct":anf_obj71784675,
"s-app":anf_obj71954676,
"s-prim-app":anf_obj72014677,
"s-prim-val":anf_obj72034678,
"s-id":anf_obj72064679,
"s-id-var":anf_obj72094680,
"s-id-letrec":anf_obj72124681,
"s-undefined":anf_obj72144682,
"s-srcloc":anf_obj72164683,
"s-num":anf_obj72184684,
"s-frac":anf_obj72204685,
"s-bool":anf_obj72224686,
"s-str":anf_obj72244687,
"s-dot":anf_obj72274688,
"s-get-bang":anf_obj72304689,
"s-bracket":anf_obj72444690,
"s-data":anf_obj72854691,
"s-data-expr":anf_obj73314692,
"s-for":anf_obj73584693,
"s-check":anf_obj73614694,
"s-data-field":anf_obj73754695,
"s-mutable-field":anf_obj73944696,
"s-once-field":anf_obj74134697,
"s-method-field":anf_obj74454698,
"s-for-bind":anf_obj74594699,
"s-variant-member":anf_obj74624700,
"s-variant":anf_obj74824701,
"s-singleton-variant":anf_obj74884702,
"s-datatype-variant":anf_obj75054703,
"s-datatype-singleton-variant":anf_obj75084704,
"s-datatype-constructor":anf_obj75114705,
"a-blank":anf_obj75134706,
"a-any":anf_obj75154707,
"a-name":anf_obj75174708,
"a-arrow":anf_obj75344709,
"a-method":anf_obj75514710,
"a-record":anf_obj75574711,
"a-app":anf_obj75744712,
"a-pred":anf_obj75884713,
"a-dot":anf_obj75914714,
"a-field":anf_obj75944715});
var anf_obj76062390 = R.makeMethod(function(self20814607) {
return function(opt20824612) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[743],1,arguments);
}
var cases_DASH_val9514611 = opt20824612;
var anf_fun75964587 = G(cases_DASH_val9514611,"_match",L[744]);
var anf_obj75984593 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[748],0,arguments);
}
var ann_DASH_check_DASH_temp75974610 = none61155;
return ann_DASH_check_DASH_temp75974610;
});
var anf_obj76024594 = R.makeFunction(function(v20834595) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[745],1,arguments);
}
var anf_fun76004606 = G(v20834595,"visit",L[747]);
var $z45984599 = D;
var $f46044605 = function(_) {
return R.isFunction(anf_fun76004606)?anf_fun76004606.app(self20814607):R.ffi.throwNonFunApp(L[746],anf_fun76004606,[self20814607]);
};
try {
if(--R.GAS > 0) {
$z45984599 = $f46044605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46044605,
"from":L[746]});
}
} catch($e45964597) {
if(R.isCont($e45964597)) {
var $ss46004601 = {"from":L[746],
"go":function(anf_arg76014608) {
return $Hanf_arg111264609(anf_arg76014608,some62156);
}};
$e45964597.stack[R.EXN_STACKHEIGHT++] = $ss46004601;
}
if(R.isPyretException($e45964597)) {
$e45964597.pyretStack.push(L[746]);
}
throw $e45964597;
}
var $ret46024603 = $Hanf_arg111264609($z45984599,some62156);
++R.GAS;
return $ret46024603;
});
var anf_arg76034588 = R.makeObject({"none":anf_obj75984593,
"some":anf_obj76024594});
var anf_arg76054589 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[744],0,arguments);
}
var ann_DASH_check_DASH_temp76044592 = R.throwNoBranchesMatched(L[744],("cases"));
return ann_DASH_check_DASH_temp76044592;
});
var $z45794580 = D;
var $f45854586 = function(_) {
return R.isFunction(anf_fun75964587)?anf_fun75964587.app(anf_arg76034588,anf_arg76054589):R.ffi.throwNonFunApp(L[743],anf_fun75964587,[anf_arg76034588,anf_arg76054589]);
};
try {
if(--R.GAS > 0) {
$z45794580 = $f45854586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45854586,
"from":L[743]});
}
} catch($e45774578) {
if(R.isCont($e45774578)) {
var $ss45814582 = {"from":L[743],
"go":function(ann_DASH_check_DASH_temp75954590) {
return $Hann_DASH_check_DASH_temp111274591(ann_DASH_check_DASH_temp75954590);
}};
$e45774578.stack[R.EXN_STACKHEIGHT++] = $ss45814582;
}
if(R.isPyretException($e45774578)) {
$e45774578.pyretStack.push(L[743]);
}
throw $e45774578;
}
var $ret45834584 = $Hann_DASH_check_DASH_temp111274591($z45794580);
++R.GAS;
return $ret45834584;
};
},{"length":2});
var anf_obj76082391 = R.makeMethod(function(self20844575) {
return function(l20854576) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[742],1,arguments);
}
var $z45654566 = D;
var $f45714572 = function(_) {
return R.isFunction(s_DASH_underscore1881011.$var)?s_DASH_underscore1881011.$var.app(dummy_DASH_loc11796):R.ffi.throwNonFunApp(L[742],s_DASH_underscore1881011.$var,[dummy_DASH_loc11796]);
};
try {
if(--R.GAS > 0) {
$z45654566 = $f45714572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45714572,
"from":L[742]});
}
} catch($e45634564) {
if(R.isCont($e45634564)) {
var $ss45674568 = {"from":L[742],
"go":function(ann_DASH_check_DASH_temp76074573) {
return $Hann_DASH_check_DASH_temp111284574(ann_DASH_check_DASH_temp76074573);
}};
$e45634564.stack[R.EXN_STACKHEIGHT++] = $ss45674568;
}
if(R.isPyretException($e45634564)) {
$e45634564.pyretStack.push(L[742]);
}
throw $e45634564;
}
var $ret45694570 = $Hann_DASH_check_DASH_temp111284574($z45654566);
++R.GAS;
return $ret45694570;
};
},{"length":2});
var anf_obj76102392 = R.makeMethod(function(self20864561) {
return function(l20874562,s20884558) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[741],2,arguments);
}
var $z45504551 = D;
var $f45564557 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(dummy_DASH_loc11796,s20884558):R.ffi.throwNonFunApp(L[741],s_DASH_name1901015.$var,[dummy_DASH_loc11796,s20884558]);
};
try {
if(--R.GAS > 0) {
$z45504551 = $f45564557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45564557,
"from":L[741]});
}
} catch($e45484549) {
if(R.isCont($e45484549)) {
var $ss45524553 = {"from":L[741],
"go":function(ann_DASH_check_DASH_temp76094559) {
return $Hann_DASH_check_DASH_temp111294560(ann_DASH_check_DASH_temp76094559);
}};
$e45484549.stack[R.EXN_STACKHEIGHT++] = $ss45524553;
}
if(R.isPyretException($e45484549)) {
$e45484549.pyretStack.push(L[741]);
}
throw $e45484549;
}
var $ret45544555 = $Hann_DASH_check_DASH_temp111294560($z45504551);
++R.GAS;
return $ret45544555;
};
},{"length":3});
var anf_obj76122393 = R.makeMethod(function(self20894547) {
return function(s20904544) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[740],1,arguments);
}
var $z45364537 = D;
var $f45424543 = function(_) {
return R.isFunction(s_DASH_global1921019.$var)?s_DASH_global1921019.$var.app(s20904544):R.ffi.throwNonFunApp(L[740],s_DASH_global1921019.$var,[s20904544]);
};
try {
if(--R.GAS > 0) {
$z45364537 = $f45424543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45424543,
"from":L[740]});
}
} catch($e45344535) {
if(R.isCont($e45344535)) {
var $ss45384539 = {"from":L[740],
"go":function(ann_DASH_check_DASH_temp76114545) {
return $Hann_DASH_check_DASH_temp111304546(ann_DASH_check_DASH_temp76114545);
}};
$e45344535.stack[R.EXN_STACKHEIGHT++] = $ss45384539;
}
if(R.isPyretException($e45344535)) {
$e45344535.pyretStack.push(L[740]);
}
throw $e45344535;
}
var $ret45404541 = $Hann_DASH_check_DASH_temp111304546($z45364537);
++R.GAS;
return $ret45404541;
};
},{"length":2});
var anf_obj76142394 = R.makeMethod(function(self20914533) {
return function(s20924530) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[739],1,arguments);
}
var $z45224523 = D;
var $f45284529 = function(_) {
return R.isFunction(s_DASH_type_DASH_global1941023.$var)?s_DASH_type_DASH_global1941023.$var.app(s20924530):R.ffi.throwNonFunApp(L[739],s_DASH_type_DASH_global1941023.$var,[s20924530]);
};
try {
if(--R.GAS > 0) {
$z45224523 = $f45284529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45284529,
"from":L[739]});
}
} catch($e45204521) {
if(R.isCont($e45204521)) {
var $ss45244525 = {"from":L[739],
"go":function(ann_DASH_check_DASH_temp76134531) {
return $Hann_DASH_check_DASH_temp111314532(ann_DASH_check_DASH_temp76134531);
}};
$e45204521.stack[R.EXN_STACKHEIGHT++] = $ss45244525;
}
if(R.isPyretException($e45204521)) {
$e45204521.pyretStack.push(L[739]);
}
throw $e45204521;
}
var $ret45264527 = $Hann_DASH_check_DASH_temp111314532($z45224523);
++R.GAS;
return $ret45264527;
};
},{"length":2});
var anf_obj76162395 = R.makeMethod(function(self20934519) {
return function(base20944515,serial20954516) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[738],2,arguments);
}
var $z45074508 = D;
var $f45134514 = function(_) {
return R.isFunction(s_DASH_atom1961027.$var)?s_DASH_atom1961027.$var.app(base20944515,serial20954516):R.ffi.throwNonFunApp(L[738],s_DASH_atom1961027.$var,[base20944515,serial20954516]);
};
try {
if(--R.GAS > 0) {
$z45074508 = $f45134514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45134514,
"from":L[738]});
}
} catch($e45054506) {
if(R.isCont($e45054506)) {
var $ss45094510 = {"from":L[738],
"go":function(ann_DASH_check_DASH_temp76154517) {
return $Hann_DASH_check_DASH_temp111324518(ann_DASH_check_DASH_temp76154517);
}};
$e45054506.stack[R.EXN_STACKHEIGHT++] = $ss45094510;
}
if(R.isPyretException($e45054506)) {
$e45054506.pyretStack.push(L[738]);
}
throw $e45054506;
}
var $ret45114512 = $Hann_DASH_check_DASH_temp111324518($z45074508);
++R.GAS;
return $ret45114512;
};
},{"length":3});
var anf_obj76292396 = R.makeMethod(function(self20964497) {
return function(l20974504,answer20984503,provides20994500,types21004501,checks21014499) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[737],5,arguments);
}
var anf_fun76184496 = G(answer20984503,"visit",L[736]);
var $z44884489 = D;
var $f44944495 = function(_) {
return R.isFunction(anf_fun76184496)?anf_fun76184496.app(self20964497):R.ffi.throwNonFunApp(L[735],anf_fun76184496,[self20964497]);
};
try {
if(--R.GAS > 0) {
$z44884489 = $f44944495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44944495,
"from":L[735]});
}
} catch($e44864487) {
if(R.isCont($e44864487)) {
var $ss44904491 = {"from":L[735],
"go":function(anf_arg76194498) {
return $Hanf_arg111384502(anf_arg76194498,checks21014499,dummy_DASH_loc11796,lists974,provides20994500,s_DASH_module3181937,self20964497,types21004501);
}};
$e44864487.stack[R.EXN_STACKHEIGHT++] = $ss44904491;
}
if(R.isPyretException($e44864487)) {
$e44864487.pyretStack.push(L[735]);
}
throw $e44864487;
}
var $ret44924493 = $Hanf_arg111384502($z44884489,checks21014499,dummy_DASH_loc11796,lists974,provides20994500,s_DASH_module3181937,self20964497,types21004501);
++R.GAS;
return $ret44924493;
};
},{"length":6});
var anf_obj76422397 = R.makeMethod(function(self21024478) {
return function(l21034485,_provide21044484,provided_DASH_types21054482,imports21064481,body21074480) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[734],5,arguments);
}
var anf_fun76314477 = G(_provide21044484,"visit",L[733]);
var $z44694470 = D;
var $f44754476 = function(_) {
return R.isFunction(anf_fun76314477)?anf_fun76314477.app(self21024478):R.ffi.throwNonFunApp(L[732],anf_fun76314477,[self21024478]);
};
try {
if(--R.GAS > 0) {
$z44694470 = $f44754476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44754476,
"from":L[732]});
}
} catch($e44674468) {
if(R.isCont($e44674468)) {
var $ss44714472 = {"from":L[732],
"go":function(anf_arg76324479) {
return $Hanf_arg111444483(anf_arg76324479,body21074480,dummy_DASH_loc11796,imports21064481,provided_DASH_types21054482,s_DASH_program2551811,self21024478);
}};
$e44674468.stack[R.EXN_STACKHEIGHT++] = $ss44714472;
}
if(R.isPyretException($e44674468)) {
$e44674468.pyretStack.push(L[732]);
}
throw $e44674468;
}
var $ret44734474 = $Hanf_arg111444483($z44694470,body21074480,dummy_DASH_loc11796,imports21064481,provided_DASH_types21054482,s_DASH_program2551811,self21024478);
++R.GAS;
return $ret44734474;
};
},{"length":6});
var anf_obj76442398 = R.makeMethod(function(self21084466) {
return function(l21094465,file21104462) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[729],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l21094465,file21104462],[L[730],L[731]],function() {
var $z44544455 = D;
var $f44604461 = function(_) {
return R.isFunction(s_DASH_file_DASH_import2871875.$var)?s_DASH_file_DASH_import2871875.$var.app(dummy_DASH_loc11796,file21104462):R.ffi.throwNonFunApp(L[729],s_DASH_file_DASH_import2871875.$var,[dummy_DASH_loc11796,file21104462]);
};
try {
if(--R.GAS > 0) {
$z44544455 = $f44604461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44604461,
"from":L[729]});
}
} catch($e44524453) {
if(R.isCont($e44524453)) {
var $ss44564457 = {"from":L[729],
"go":function(ann_DASH_check_DASH_temp76434463) {
return $Hann_DASH_check_DASH_temp111454464(ann_DASH_check_DASH_temp76434463);
}};
$e44524453.stack[R.EXN_STACKHEIGHT++] = $ss44564457;
}
if(R.isPyretException($e44524453)) {
$e44524453.pyretStack.push(L[729]);
}
throw $e44524453;
}
var $ret44584459 = $Hann_DASH_check_DASH_temp111454464($z44544455);
++R.GAS;
return $ret44584459;
});
};
},{"length":3});
var anf_obj76462399 = R.makeMethod(function(self21114451) {
return function(l21124450,mod21134447) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[726],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l21124450,mod21134447],[L[727],L[728]],function() {
var $z44394440 = D;
var $f44454446 = function(_) {
return R.isFunction(s_DASH_const_DASH_import2891879.$var)?s_DASH_const_DASH_import2891879.$var.app(dummy_DASH_loc11796,mod21134447):R.ffi.throwNonFunApp(L[726],s_DASH_const_DASH_import2891879.$var,[dummy_DASH_loc11796,mod21134447]);
};
try {
if(--R.GAS > 0) {
$z44394440 = $f44454446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44454446,
"from":L[726]});
}
} catch($e44374438) {
if(R.isCont($e44374438)) {
var $ss44414442 = {"from":L[726],
"go":function(ann_DASH_check_DASH_temp76454448) {
return $Hann_DASH_check_DASH_temp111464449(ann_DASH_check_DASH_temp76454448);
}};
$e44374438.stack[R.EXN_STACKHEIGHT++] = $ss44414442;
}
if(R.isPyretException($e44374438)) {
$e44374438.pyretStack.push(L[726]);
}
throw $e44374438;
}
var $ret44434444 = $Hann_DASH_check_DASH_temp111464449($z44394440);
++R.GAS;
return $ret44434444;
});
};
},{"length":3});
var anf_obj76522400 = R.makeMethod(function(self21144431) {
return function(l21154436,import_DASH_type21164435,name21174433) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[725],3,arguments);
}
var anf_fun76484430 = G(import_DASH_type21164435,"visit",L[724]);
var $z44224423 = D;
var $f44284429 = function(_) {
return R.isFunction(anf_fun76484430)?anf_fun76484430.app(self21144431):R.ffi.throwNonFunApp(L[723],anf_fun76484430,[self21144431]);
};
try {
if(--R.GAS > 0) {
$z44224423 = $f44284429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44284429,
"from":L[723]});
}
} catch($e44204421) {
if(R.isCont($e44204421)) {
var $ss44244425 = {"from":L[723],
"go":function(anf_arg76494432) {
return $Hanf_arg111494434(anf_arg76494432,dummy_DASH_loc11796,name21174433,s_DASH_import2601821,self21144431);
}};
$e44204421.stack[R.EXN_STACKHEIGHT++] = $ss44244425;
}
if(R.isPyretException($e44204421)) {
$e44204421.pyretStack.push(L[723]);
}
throw $e44204421;
}
var $ret44264427 = $Hanf_arg111494434($z44224423,dummy_DASH_loc11796,name21174433,s_DASH_import2601821,self21144431);
++R.GAS;
return $ret44264427;
};
},{"length":4});
var anf_obj76602401 = R.makeMethod(function(self21184413) {
return function(l21194419,import_DASH_type21204418,name21214415,types21224416) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[722],4,arguments);
}
var anf_fun76544412 = G(import_DASH_type21204418,"visit",L[721]);
var $z44044405 = D;
var $f44104411 = function(_) {
return R.isFunction(anf_fun76544412)?anf_fun76544412.app(self21184413):R.ffi.throwNonFunApp(L[720],anf_fun76544412,[self21184413]);
};
try {
if(--R.GAS > 0) {
$z44044405 = $f44104411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44104411,
"from":L[720]});
}
} catch($e44024403) {
if(R.isCont($e44024403)) {
var $ss44064407 = {"from":L[720],
"go":function(anf_arg76554414) {
return $Hanf_arg111534417(anf_arg76554414,dummy_DASH_loc11796,name21214415,s_DASH_import_DASH_types2621825,self21184413,types21224416);
}};
$e44024403.stack[R.EXN_STACKHEIGHT++] = $ss44064407;
}
if(R.isPyretException($e44024403)) {
$e44024403.pyretStack.push(L[720]);
}
throw $e44024403;
}
var $ret44084409 = $Hanf_arg111534417($z44044405,dummy_DASH_loc11796,name21214415,s_DASH_import_DASH_types2621825,self21184413,types21224416);
++R.GAS;
return $ret44084409;
};
},{"length":5});
var anf_obj76692402 = R.makeMethod(function(self21234384) {
return function(l21244401,fields21254400,import_DASH_type21264383) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[719],3,arguments);
}
var anf_fun76624380 = G(fields21254400,"map",L[718]);
var anf_arg76654381 = R.makeFunction(function(recv_DASH_9544386) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[717],1,arguments);
}
var anf_fun76644397 = G(recv_DASH_9544386,"visit",L[717]);
var $z43894390 = D;
var $f43954396 = function(_) {
return R.isFunction(anf_fun76644397)?anf_fun76644397.app(self21234384):R.ffi.throwNonFunApp(L[717],anf_fun76644397,[self21234384]);
};
try {
if(--R.GAS > 0) {
$z43894390 = $f43954396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43954396,
"from":L[717]});
}
} catch($e43874388) {
if(R.isCont($e43874388)) {
var $ss43914392 = {"from":L[717],
"go":function(ann_DASH_check_DASH_temp76634398) {
return $Hann_DASH_check_DASH_temp111544399(ann_DASH_check_DASH_temp76634398);
}};
$e43874388.stack[R.EXN_STACKHEIGHT++] = $ss43914392;
}
if(R.isPyretException($e43874388)) {
$e43874388.pyretStack.push(L[717]);
}
throw $e43874388;
}
var $ret43934394 = $Hann_DASH_check_DASH_temp111544399($z43894390);
++R.GAS;
return $ret43934394;
});
var $z43724373 = D;
var $f43784379 = function(_) {
return R.isFunction(anf_fun76624380)?anf_fun76624380.app(anf_arg76654381):R.ffi.throwNonFunApp(L[716],anf_fun76624380,[anf_arg76654381]);
};
try {
if(--R.GAS > 0) {
$z43724373 = $f43784379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43784379,
"from":L[716]});
}
} catch($e43704371) {
if(R.isCont($e43704371)) {
var $ss43744375 = {"from":L[716],
"go":function(anf_arg76664382) {
return $Hanf_arg111574385(anf_arg76664382,dummy_DASH_loc11796,import_DASH_type21264383,s_DASH_import_DASH_fields2641829,self21234384);
}};
$e43704371.stack[R.EXN_STACKHEIGHT++] = $ss43744375;
}
if(R.isPyretException($e43704371)) {
$e43704371.pyretStack.push(L[716]);
}
throw $e43704371;
}
var $ret43764377 = $Hanf_arg111574385($z43724373,dummy_DASH_loc11796,import_DASH_type21264383,s_DASH_import_DASH_fields2641829,self21234384);
++R.GAS;
return $ret43764377;
};
},{"length":4});
var anf_obj76732403 = R.makeMethod(function(self21274365) {
return function(l21284369,expr21294368) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[715],2,arguments);
}
var anf_fun76714364 = G(expr21294368,"visit",L[714]);
var $z43564357 = D;
var $f43624363 = function(_) {
return R.isFunction(anf_fun76714364)?anf_fun76714364.app(self21274365):R.ffi.throwNonFunApp(L[713],anf_fun76714364,[self21274365]);
};
try {
if(--R.GAS > 0) {
$z43564357 = $f43624363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43624363,
"from":L[713]});
}
} catch($e43544355) {
if(R.isCont($e43544355)) {
var $ss43584359 = {"from":L[713],
"go":function(anf_arg76724366) {
return $Hanf_arg111594367(anf_arg76724366,dummy_DASH_loc11796,s_DASH_provide2691839);
}};
$e43544355.stack[R.EXN_STACKHEIGHT++] = $ss43584359;
}
if(R.isPyretException($e43544355)) {
$e43544355.pyretStack.push(L[713]);
}
throw $e43544355;
}
var $ret43604361 = $Hanf_arg111594367($z43564357,dummy_DASH_loc11796,s_DASH_provide2691839);
++R.GAS;
return $ret43604361;
};
},{"length":3});
var anf_obj76752404 = R.makeMethod(function(self21304352) {
return function(l21314353) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[712],1,arguments);
}
var $z43424343 = D;
var $f43484349 = function(_) {
return R.isFunction(s_DASH_provide_DASH_all2711843.$var)?s_DASH_provide_DASH_all2711843.$var.app(dummy_DASH_loc11796):R.ffi.throwNonFunApp(L[712],s_DASH_provide_DASH_all2711843.$var,[dummy_DASH_loc11796]);
};
try {
if(--R.GAS > 0) {
$z43424343 = $f43484349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43484349,
"from":L[712]});
}
} catch($e43404341) {
if(R.isCont($e43404341)) {
var $ss43444345 = {"from":L[712],
"go":function(ann_DASH_check_DASH_temp76744350) {
return $Hann_DASH_check_DASH_temp111604351(ann_DASH_check_DASH_temp76744350);
}};
$e43404341.stack[R.EXN_STACKHEIGHT++] = $ss43444345;
}
if(R.isPyretException($e43404341)) {
$e43404341.pyretStack.push(L[712]);
}
throw $e43404341;
}
var $ret43464347 = $Hann_DASH_check_DASH_temp111604351($z43424343);
++R.GAS;
return $ret43464347;
};
},{"length":2});
var anf_obj76772405 = R.makeMethod(function(self21324338) {
return function(l21334339) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[711],1,arguments);
}
var $z43284329 = D;
var $f43344335 = function(_) {
return R.isFunction(s_DASH_provide_DASH_none2731847.$var)?s_DASH_provide_DASH_none2731847.$var.app(dummy_DASH_loc11796):R.ffi.throwNonFunApp(L[711],s_DASH_provide_DASH_none2731847.$var,[dummy_DASH_loc11796]);
};
try {
if(--R.GAS > 0) {
$z43284329 = $f43344335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43344335,
"from":L[711]});
}
} catch($e43264327) {
if(R.isCont($e43264327)) {
var $ss43304331 = {"from":L[711],
"go":function(ann_DASH_check_DASH_temp76764336) {
return $Hann_DASH_check_DASH_temp111614337(ann_DASH_check_DASH_temp76764336);
}};
$e43264327.stack[R.EXN_STACKHEIGHT++] = $ss43304331;
}
if(R.isPyretException($e43264327)) {
$e43264327.pyretStack.push(L[711]);
}
throw $e43264327;
}
var $ret43324333 = $Hann_DASH_check_DASH_temp111614337($z43284329);
++R.GAS;
return $ret43324333;
};
},{"length":2});
var anf_obj76842406 = R.makeMethod(function(self21344321) {
return function(l21354325,anns21364324) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[710],2,arguments);
}
var anf_fun76794305 = G(anns21364324,"map",L[709]);
var anf_arg76824306 = R.makeFunction(function(recv_DASH_9554309) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[708],1,arguments);
}
var anf_fun76814320 = G(recv_DASH_9554309,"visit",L[708]);
var $z43124313 = D;
var $f43184319 = function(_) {
return R.isFunction(anf_fun76814320)?anf_fun76814320.app(self21344321):R.ffi.throwNonFunApp(L[708],anf_fun76814320,[self21344321]);
};
try {
if(--R.GAS > 0) {
$z43124313 = $f43184319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43184319,
"from":L[708]});
}
} catch($e43104311) {
if(R.isCont($e43104311)) {
var $ss43144315 = {"from":L[708],
"go":function(ann_DASH_check_DASH_temp76804322) {
return $Hann_DASH_check_DASH_temp111624323(ann_DASH_check_DASH_temp76804322);
}};
$e43104311.stack[R.EXN_STACKHEIGHT++] = $ss43144315;
}
if(R.isPyretException($e43104311)) {
$e43104311.pyretStack.push(L[708]);
}
throw $e43104311;
}
var $ret43164317 = $Hann_DASH_check_DASH_temp111624323($z43124313);
++R.GAS;
return $ret43164317;
});
var $z42974298 = D;
var $f43034304 = function(_) {
return R.isFunction(anf_fun76794305)?anf_fun76794305.app(anf_arg76824306):R.ffi.throwNonFunApp(L[707],anf_fun76794305,[anf_arg76824306]);
};
try {
if(--R.GAS > 0) {
$z42974298 = $f43034304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43034304,
"from":L[707]});
}
} catch($e42954296) {
if(R.isCont($e42954296)) {
var $ss42994300 = {"from":L[707],
"go":function(anf_arg76834307) {
return $Hanf_arg111644308(anf_arg76834307,dummy_DASH_loc11796,s_DASH_provide2691839);
}};
$e42954296.stack[R.EXN_STACKHEIGHT++] = $ss42994300;
}
if(R.isPyretException($e42954296)) {
$e42954296.pyretStack.push(L[707]);
}
throw $e42954296;
}
var $ret43014302 = $Hanf_arg111644308($z42974298,dummy_DASH_loc11796,s_DASH_provide2691839);
++R.GAS;
return $ret43014302;
};
},{"length":3});
var anf_obj76862407 = R.makeMethod(function(self21374293) {
return function(l21384294) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[706],1,arguments);
}
var $z42834284 = D;
var $f42894290 = function(_) {
return R.isFunction(s_DASH_provide_DASH_types_DASH_all2801861.$var)?s_DASH_provide_DASH_types_DASH_all2801861.$var.app(dummy_DASH_loc11796):R.ffi.throwNonFunApp(L[706],s_DASH_provide_DASH_types_DASH_all2801861.$var,[dummy_DASH_loc11796]);
};
try {
if(--R.GAS > 0) {
$z42834284 = $f42894290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42894290,
"from":L[706]});
}
} catch($e42814282) {
if(R.isCont($e42814282)) {
var $ss42854286 = {"from":L[706],
"go":function(ann_DASH_check_DASH_temp76854291) {
return $Hann_DASH_check_DASH_temp111654292(ann_DASH_check_DASH_temp76854291);
}};
$e42814282.stack[R.EXN_STACKHEIGHT++] = $ss42854286;
}
if(R.isPyretException($e42814282)) {
$e42814282.pyretStack.push(L[706]);
}
throw $e42814282;
}
var $ret42874288 = $Hann_DASH_check_DASH_temp111654292($z42834284);
++R.GAS;
return $ret42874288;
};
},{"length":2});
var anf_obj76882408 = R.makeMethod(function(self21394279) {
return function(l21404280) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[705],1,arguments);
}
var $z42694270 = D;
var $f42754276 = function(_) {
return R.isFunction(s_DASH_provide_DASH_types_DASH_none2821865.$var)?s_DASH_provide_DASH_types_DASH_none2821865.$var.app(dummy_DASH_loc11796):R.ffi.throwNonFunApp(L[705],s_DASH_provide_DASH_types_DASH_none2821865.$var,[dummy_DASH_loc11796]);
};
try {
if(--R.GAS > 0) {
$z42694270 = $f42754276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42754276,
"from":L[705]});
}
} catch($e42674268) {
if(R.isCont($e42674268)) {
var $ss42714272 = {"from":L[705],
"go":function(ann_DASH_check_DASH_temp76874277) {
return $Hann_DASH_check_DASH_temp111664278(ann_DASH_check_DASH_temp76874277);
}};
$e42674268.stack[R.EXN_STACKHEIGHT++] = $ss42714272;
}
if(R.isPyretException($e42674268)) {
$e42674268.pyretStack.push(L[705]);
}
throw $e42674268;
}
var $ret42734274 = $Hann_DASH_check_DASH_temp111664278($z42694270);
++R.GAS;
return $ret42734274;
};
},{"length":2});
var anf_obj76942409 = R.makeMethod(function(self21414260) {
return function(l21424266,shadows21434263,name21444265,ann21454262) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[704],4,arguments);
}
var anf_fun76904259 = G(name21444265,"visit",L[703]);
var $z42514252 = D;
var $f42574258 = function(_) {
return R.isFunction(anf_fun76904259)?anf_fun76904259.app(self21414260):R.ffi.throwNonFunApp(L[702],anf_fun76904259,[self21414260]);
};
try {
if(--R.GAS > 0) {
$z42514252 = $f42574258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42574258,
"from":L[702]});
}
} catch($e42494250) {
if(R.isCont($e42494250)) {
var $ss42534254 = {"from":L[702],
"go":function(anf_arg76914261) {
return $Hanf_arg111694264(anf_arg76914261,ann21454262,dummy_DASH_loc11796,s_DASH_bind4382177,self21414260,shadows21434263);
}};
$e42494250.stack[R.EXN_STACKHEIGHT++] = $ss42534254;
}
if(R.isPyretException($e42494250)) {
$e42494250.pyretStack.push(L[702]);
}
throw $e42494250;
}
var $ret42554256 = $Hanf_arg111694264($z42514252,ann21454262,dummy_DASH_loc11796,s_DASH_bind4382177,self21414260,shadows21434263);
++R.GAS;
return $ret42554256;
};
},{"length":5});
var anf_obj77002410 = R.makeMethod(function(self21464243) {
return function(l21474248,bind21484247,expr21494245) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[701],3,arguments);
}
var anf_fun76964242 = G(bind21484247,"visit",L[700]);
var $z42344235 = D;
var $f42404241 = function(_) {
return R.isFunction(anf_fun76964242)?anf_fun76964242.app(self21464243):R.ffi.throwNonFunApp(L[699],anf_fun76964242,[self21464243]);
};
try {
if(--R.GAS > 0) {
$z42344235 = $f42404241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42404241,
"from":L[699]});
}
} catch($e42324233) {
if(R.isCont($e42324233)) {
var $ss42364237 = {"from":L[699],
"go":function(anf_arg76974244) {
return $Hanf_arg111724246(anf_arg76974244,dummy_DASH_loc11796,expr21494245,s_DASH_var_DASH_bind3011903,self21464243);
}};
$e42324233.stack[R.EXN_STACKHEIGHT++] = $ss42364237;
}
if(R.isPyretException($e42324233)) {
$e42324233.pyretStack.push(L[699]);
}
throw $e42324233;
}
var $ret42384239 = $Hanf_arg111724246($z42344235,dummy_DASH_loc11796,expr21494245,s_DASH_var_DASH_bind3011903,self21464243);
++R.GAS;
return $ret42384239;
};
},{"length":4});
var anf_obj77062411 = R.makeMethod(function(self21504226) {
return function(l21514231,bind21524230,expr21534228) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[698],3,arguments);
}
var anf_fun77024225 = G(bind21524230,"visit",L[697]);
var $z42174218 = D;
var $f42234224 = function(_) {
return R.isFunction(anf_fun77024225)?anf_fun77024225.app(self21504226):R.ffi.throwNonFunApp(L[696],anf_fun77024225,[self21504226]);
};
try {
if(--R.GAS > 0) {
$z42174218 = $f42234224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42234224,
"from":L[696]});
}
} catch($e42154216) {
if(R.isCont($e42154216)) {
var $ss42194220 = {"from":L[696],
"go":function(anf_arg77034227) {
return $Hanf_arg111754229(anf_arg77034227,dummy_DASH_loc11796,expr21534228,s_DASH_let_DASH_bind2991899,self21504226);
}};
$e42154216.stack[R.EXN_STACKHEIGHT++] = $ss42194220;
}
if(R.isPyretException($e42154216)) {
$e42154216.pyretStack.push(L[696]);
}
throw $e42154216;
}
var $ret42214222 = $Hanf_arg111754229($z42174218,dummy_DASH_loc11796,expr21534228,s_DASH_let_DASH_bind2991899,self21504226);
++R.GAS;
return $ret42214222;
};
},{"length":4});
var anf_obj77082412 = R.makeMethod(function(self21544213) {
return function(l21554214,name21564209,ann21574210) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[695],3,arguments);
}
var $z42014202 = D;
var $f42074208 = function(_) {
return R.isFunction(s_DASH_type_DASH_bind3111923.$var)?s_DASH_type_DASH_bind3111923.$var.app(dummy_DASH_loc11796,name21564209,ann21574210):R.ffi.throwNonFunApp(L[695],s_DASH_type_DASH_bind3111923.$var,[dummy_DASH_loc11796,name21564209,ann21574210]);
};
try {
if(--R.GAS > 0) {
$z42014202 = $f42074208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42074208,
"from":L[695]});
}
} catch($e41994200) {
if(R.isCont($e41994200)) {
var $ss42034204 = {"from":L[695],
"go":function(ann_DASH_check_DASH_temp77074211) {
return $Hann_DASH_check_DASH_temp111764212(ann_DASH_check_DASH_temp77074211);
}};
$e41994200.stack[R.EXN_STACKHEIGHT++] = $ss42034204;
}
if(R.isPyretException($e41994200)) {
$e41994200.pyretStack.push(L[695]);
}
throw $e41994200;
}
var $ret42054206 = $Hann_DASH_check_DASH_temp111764212($z42014202);
++R.GAS;
return $ret42054206;
};
},{"length":4});
var anf_obj77142413 = R.makeMethod(function(self21584193) {
return function(l21594195,name21604198,namet21614196) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[694],3,arguments);
}
var anf_fun77104192 = G(name21604198,"visit",L[693]);
var $z41844185 = D;
var $f41904191 = function(_) {
return R.isFunction(anf_fun77104192)?anf_fun77104192.app(self21584193):R.ffi.throwNonFunApp(L[692],anf_fun77104192,[self21584193]);
};
try {
if(--R.GAS > 0) {
$z41844185 = $f41904191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41904191,
"from":L[692]});
}
} catch($e41824183) {
if(R.isCont($e41824183)) {
var $ss41864187 = {"from":L[692],
"go":function(anf_arg77114194) {
return $Hanf_arg111794197(anf_arg77114194,l21594195,namet21614196,s_DASH_newtype_DASH_bind3131927,self21584193);
}};
$e41824183.stack[R.EXN_STACKHEIGHT++] = $ss41864187;
}
if(R.isPyretException($e41824183)) {
$e41824183.pyretStack.push(L[692]);
}
throw $e41824183;
}
var $ret41884189 = $Hanf_arg111794197($z41844185,l21594195,namet21614196,s_DASH_newtype_DASH_bind3131927,self21584193);
++R.GAS;
return $ret41884189;
};
},{"length":4});
var anf_obj77232414 = R.makeMethod(function(self21624164) {
return function(l21634181,binds21644180,body21654163) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[691],3,arguments);
}
var anf_fun77164160 = G(binds21644180,"map",L[690]);
var anf_arg77194161 = R.makeFunction(function(recv_DASH_9564166) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[689],1,arguments);
}
var anf_fun77184177 = G(recv_DASH_9564166,"visit",L[689]);
var $z41694170 = D;
var $f41754176 = function(_) {
return R.isFunction(anf_fun77184177)?anf_fun77184177.app(self21624164):R.ffi.throwNonFunApp(L[689],anf_fun77184177,[self21624164]);
};
try {
if(--R.GAS > 0) {
$z41694170 = $f41754176();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41754176,
"from":L[689]});
}
} catch($e41674168) {
if(R.isCont($e41674168)) {
var $ss41714172 = {"from":L[689],
"go":function(ann_DASH_check_DASH_temp77174178) {
return $Hann_DASH_check_DASH_temp111804179(ann_DASH_check_DASH_temp77174178);
}};
$e41674168.stack[R.EXN_STACKHEIGHT++] = $ss41714172;
}
if(R.isPyretException($e41674168)) {
$e41674168.pyretStack.push(L[689]);
}
throw $e41674168;
}
var $ret41734174 = $Hann_DASH_check_DASH_temp111804179($z41694170);
++R.GAS;
return $ret41734174;
});
var $z41524153 = D;
var $f41584159 = function(_) {
return R.isFunction(anf_fun77164160)?anf_fun77164160.app(anf_arg77194161):R.ffi.throwNonFunApp(L[688],anf_fun77164160,[anf_arg77194161]);
};
try {
if(--R.GAS > 0) {
$z41524153 = $f41584159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41584159,
"from":L[688]});
}
} catch($e41504151) {
if(R.isCont($e41504151)) {
var $ss41544155 = {"from":L[688],
"go":function(anf_arg77204162) {
return $Hanf_arg111834165(anf_arg77204162,body21654163,dummy_DASH_loc11796,s_DASH_type_DASH_let_DASH_expr3201941,self21624164);
}};
$e41504151.stack[R.EXN_STACKHEIGHT++] = $ss41544155;
}
if(R.isPyretException($e41504151)) {
$e41504151.pyretStack.push(L[688]);
}
throw $e41504151;
}
var $ret41564157 = $Hanf_arg111834165($z41524153,body21654163,dummy_DASH_loc11796,s_DASH_type_DASH_let_DASH_expr3201941,self21624164);
++R.GAS;
return $ret41564157;
};
},{"length":4});
var anf_obj77322415 = R.makeMethod(function(self21664132) {
return function(l21674149,binds21684148,body21694131) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[687],3,arguments);
}
var anf_fun77254128 = G(binds21684148,"map",L[686]);
var anf_arg77284129 = R.makeFunction(function(recv_DASH_9574134) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[685],1,arguments);
}
var anf_fun77274145 = G(recv_DASH_9574134,"visit",L[685]);
var $z41374138 = D;
var $f41434144 = function(_) {
return R.isFunction(anf_fun77274145)?anf_fun77274145.app(self21664132):R.ffi.throwNonFunApp(L[685],anf_fun77274145,[self21664132]);
};
try {
if(--R.GAS > 0) {
$z41374138 = $f41434144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41434144,
"from":L[685]});
}
} catch($e41354136) {
if(R.isCont($e41354136)) {
var $ss41394140 = {"from":L[685],
"go":function(ann_DASH_check_DASH_temp77264146) {
return $Hann_DASH_check_DASH_temp111844147(ann_DASH_check_DASH_temp77264146);
}};
$e41354136.stack[R.EXN_STACKHEIGHT++] = $ss41394140;
}
if(R.isPyretException($e41354136)) {
$e41354136.pyretStack.push(L[685]);
}
throw $e41354136;
}
var $ret41414142 = $Hann_DASH_check_DASH_temp111844147($z41374138);
++R.GAS;
return $ret41414142;
});
var $z41204121 = D;
var $f41264127 = function(_) {
return R.isFunction(anf_fun77254128)?anf_fun77254128.app(anf_arg77284129):R.ffi.throwNonFunApp(L[684],anf_fun77254128,[anf_arg77284129]);
};
try {
if(--R.GAS > 0) {
$z41204121 = $f41264127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41264127,
"from":L[684]});
}
} catch($e41184119) {
if(R.isCont($e41184119)) {
var $ss41224123 = {"from":L[684],
"go":function(anf_arg77294130) {
return $Hanf_arg111874133(anf_arg77294130,body21694131,dummy_DASH_loc11796,s_DASH_let_DASH_expr3221945,self21664132);
}};
$e41184119.stack[R.EXN_STACKHEIGHT++] = $ss41224123;
}
if(R.isPyretException($e41184119)) {
$e41184119.pyretStack.push(L[684]);
}
throw $e41184119;
}
var $ret41244125 = $Hanf_arg111874133($z41204121,body21694131,dummy_DASH_loc11796,s_DASH_let_DASH_expr3221945,self21664132);
++R.GAS;
return $ret41244125;
};
},{"length":4});
var anf_obj77382416 = R.makeMethod(function(self21704112) {
return function(l21714117,bind21724116,expr21734114) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[683],3,arguments);
}
var anf_fun77344111 = G(bind21724116,"visit",L[682]);
var $z41034104 = D;
var $f41094110 = function(_) {
return R.isFunction(anf_fun77344111)?anf_fun77344111.app(self21704112):R.ffi.throwNonFunApp(L[681],anf_fun77344111,[self21704112]);
};
try {
if(--R.GAS > 0) {
$z41034104 = $f41094110();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41094110,
"from":L[681]});
}
} catch($e41014102) {
if(R.isCont($e41014102)) {
var $ss41054106 = {"from":L[681],
"go":function(anf_arg77354113) {
return $Hanf_arg111904115(anf_arg77354113,dummy_DASH_loc11796,expr21734114,s_DASH_letrec_DASH_bind3061913,self21704112);
}};
$e41014102.stack[R.EXN_STACKHEIGHT++] = $ss41054106;
}
if(R.isPyretException($e41014102)) {
$e41014102.pyretStack.push(L[681]);
}
throw $e41014102;
}
var $ret41074108 = $Hanf_arg111904115($z41034104,dummy_DASH_loc11796,expr21734114,s_DASH_letrec_DASH_bind3061913,self21704112);
++R.GAS;
return $ret41074108;
};
},{"length":4});
var anf_obj77472417 = R.makeMethod(function(self21744083) {
return function(l21754100,binds21764099,body21774082) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[680],3,arguments);
}
var anf_fun77404079 = G(binds21764099,"map",L[679]);
var anf_arg77434080 = R.makeFunction(function(recv_DASH_9584085) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[678],1,arguments);
}
var anf_fun77424096 = G(recv_DASH_9584085,"visit",L[678]);
var $z40884089 = D;
var $f40944095 = function(_) {
return R.isFunction(anf_fun77424096)?anf_fun77424096.app(self21744083):R.ffi.throwNonFunApp(L[678],anf_fun77424096,[self21744083]);
};
try {
if(--R.GAS > 0) {
$z40884089 = $f40944095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40944095,
"from":L[678]});
}
} catch($e40864087) {
if(R.isCont($e40864087)) {
var $ss40904091 = {"from":L[678],
"go":function(ann_DASH_check_DASH_temp77414097) {
return $Hann_DASH_check_DASH_temp111914098(ann_DASH_check_DASH_temp77414097);
}};
$e40864087.stack[R.EXN_STACKHEIGHT++] = $ss40904091;
}
if(R.isPyretException($e40864087)) {
$e40864087.pyretStack.push(L[678]);
}
throw $e40864087;
}
var $ret40924093 = $Hann_DASH_check_DASH_temp111914098($z40884089);
++R.GAS;
return $ret40924093;
});
var $z40714072 = D;
var $f40774078 = function(_) {
return R.isFunction(anf_fun77404079)?anf_fun77404079.app(anf_arg77434080):R.ffi.throwNonFunApp(L[677],anf_fun77404079,[anf_arg77434080]);
};
try {
if(--R.GAS > 0) {
$z40714072 = $f40774078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40774078,
"from":L[677]});
}
} catch($e40694070) {
if(R.isCont($e40694070)) {
var $ss40734074 = {"from":L[677],
"go":function(anf_arg77444081) {
return $Hanf_arg111944084(anf_arg77444081,body21774082,dummy_DASH_loc11796,s_DASH_letrec3241949,self21744083);
}};
$e40694070.stack[R.EXN_STACKHEIGHT++] = $ss40734074;
}
if(R.isPyretException($e40694070)) {
$e40694070.pyretStack.push(L[677]);
}
throw $e40694070;
}
var $ret40754076 = $Hanf_arg111944084($z40714072,body21774082,dummy_DASH_loc11796,s_DASH_letrec3241949,self21744083);
++R.GAS;
return $ret40754076;
};
},{"length":4});
var anf_obj77512418 = R.makeMethod(function(self21784063) {
return function(l21794068,hints21804065,exp21814067) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[676],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l21794068,hints21804065,exp21814067],[L[673],L[674],L[675]],function() {
var anf_fun77494062 = G(exp21814067,"visit",L[672]);
var $z40544055 = D;
var $f40604061 = function(_) {
return R.isFunction(anf_fun77494062)?anf_fun77494062.app(self21784063):R.ffi.throwNonFunApp(L[671],anf_fun77494062,[self21784063]);
};
try {
if(--R.GAS > 0) {
$z40544055 = $f40604061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40604061,
"from":L[671]});
}
} catch($e40524053) {
if(R.isCont($e40524053)) {
var $ss40564057 = {"from":L[671],
"go":function(anf_arg77504064) {
return $Hanf_arg111964066(anf_arg77504064,dummy_DASH_loc11796,hints21804065,s_DASH_hint_DASH_exp3261953);
}};
$e40524053.stack[R.EXN_STACKHEIGHT++] = $ss40564057;
}
if(R.isPyretException($e40524053)) {
$e40524053.pyretStack.push(L[671]);
}
throw $e40524053;
}
var $ret40584059 = $Hanf_arg111964066($z40544055,dummy_DASH_loc11796,hints21804065,s_DASH_hint_DASH_exp3261953);
++R.GAS;
return $ret40584059;
});
};
},{"length":4});
var anf_obj77602419 = R.makeMethod(function(self21824046) {
return function(l21834051,expr21844050,params21854048) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[670],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l21834051,expr21844050,params21854048],[L[667],L[668],L[669]],function() {
var anf_fun77534045 = G(expr21844050,"visit",L[666]);
var $z40374038 = D;
var $f40434044 = function(_) {
return R.isFunction(anf_fun77534045)?anf_fun77534045.app(self21824046):R.ffi.throwNonFunApp(L[665],anf_fun77534045,[self21824046]);
};
try {
if(--R.GAS > 0) {
$z40374038 = $f40434044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40434044,
"from":L[665]});
}
} catch($e40354036) {
if(R.isCont($e40354036)) {
var $ss40394040 = {"from":L[665],
"go":function(anf_arg77544047) {
return $Hanf_arg112004049(anf_arg77544047,dummy_DASH_loc11796,params21854048,s_DASH_instantiate3281957,self21824046);
}};
$e40354036.stack[R.EXN_STACKHEIGHT++] = $ss40394040;
}
if(R.isPyretException($e40354036)) {
$e40354036.pyretStack.push(L[665]);
}
throw $e40354036;
}
var $ret40414042 = $Hanf_arg112004049($z40374038,dummy_DASH_loc11796,params21854048,s_DASH_instantiate3281957,self21824046);
++R.GAS;
return $ret40414042;
});
};
},{"length":4});
var anf_obj77672420 = R.makeMethod(function(self21864030) {
return function(l21874034,stmts21884033) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[664],2,arguments);
}
var anf_fun77624014 = G(stmts21884033,"map",L[663]);
var anf_arg77654015 = R.makeFunction(function(recv_DASH_9604018) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[662],1,arguments);
}
var anf_fun77644029 = G(recv_DASH_9604018,"visit",L[662]);
var $z40214022 = D;
var $f40274028 = function(_) {
return R.isFunction(anf_fun77644029)?anf_fun77644029.app(self21864030):R.ffi.throwNonFunApp(L[662],anf_fun77644029,[self21864030]);
};
try {
if(--R.GAS > 0) {
$z40214022 = $f40274028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40274028,
"from":L[662]});
}
} catch($e40194020) {
if(R.isCont($e40194020)) {
var $ss40234024 = {"from":L[662],
"go":function(ann_DASH_check_DASH_temp77634031) {
return $Hann_DASH_check_DASH_temp112014032(ann_DASH_check_DASH_temp77634031);
}};
$e40194020.stack[R.EXN_STACKHEIGHT++] = $ss40234024;
}
if(R.isPyretException($e40194020)) {
$e40194020.pyretStack.push(L[662]);
}
throw $e40194020;
}
var $ret40254026 = $Hann_DASH_check_DASH_temp112014032($z40214022);
++R.GAS;
return $ret40254026;
});
var $z40064007 = D;
var $f40124013 = function(_) {
return R.isFunction(anf_fun77624014)?anf_fun77624014.app(anf_arg77654015):R.ffi.throwNonFunApp(L[661],anf_fun77624014,[anf_arg77654015]);
};
try {
if(--R.GAS > 0) {
$z40064007 = $f40124013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40124013,
"from":L[661]});
}
} catch($e40044005) {
if(R.isCont($e40044005)) {
var $ss40084009 = {"from":L[661],
"go":function(anf_arg77664016) {
return $Hanf_arg112034017(anf_arg77664016,dummy_DASH_loc11796,s_DASH_block3301961);
}};
$e40044005.stack[R.EXN_STACKHEIGHT++] = $ss40084009;
}
if(R.isPyretException($e40044005)) {
$e40044005.pyretStack.push(L[661]);
}
throw $e40044005;
}
var $ret40104011 = $Hanf_arg112034017($z40064007,dummy_DASH_loc11796,s_DASH_block3301961);
++R.GAS;
return $ret40104011;
};
},{"length":3});
var anf_obj77712421 = R.makeMethod(function(self21893999) {
return function(l21904003,body21914002) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[660],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l21904003,body21914002],[L[658],L[659]],function() {
var anf_fun77693998 = G(body21914002,"visit",L[657]);
var $z39903991 = D;
var $f39963997 = function(_) {
return R.isFunction(anf_fun77693998)?anf_fun77693998.app(self21893999):R.ffi.throwNonFunApp(L[656],anf_fun77693998,[self21893999]);
};
try {
if(--R.GAS > 0) {
$z39903991 = $f39963997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39963997,
"from":L[656]});
}
} catch($e39883989) {
if(R.isCont($e39883989)) {
var $ss39923993 = {"from":L[656],
"go":function(anf_arg77704000) {
return $Hanf_arg112054001(anf_arg77704000,dummy_DASH_loc11796,s_DASH_user_DASH_block3321965);
}};
$e39883989.stack[R.EXN_STACKHEIGHT++] = $ss39923993;
}
if(R.isPyretException($e39883989)) {
$e39883989.pyretStack.push(L[656]);
}
throw $e39883989;
}
var $ret39943995 = $Hanf_arg112054001($z39903991,dummy_DASH_loc11796,s_DASH_user_DASH_block3321965);
++R.GAS;
return $ret39943995;
});
};
},{"length":3});
var anf_obj77892422 = R.makeMethod(function(self21923970) {
return function(l21933987,name21943969,params21953986,args21963966,ann21973965,doc21983968,body21993967,_check22003964) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[655],8,arguments);
}
var anf_fun77733961 = G(params21953986,"map",L[654]);
var anf_arg77763962 = R.makeFunction(function(recv_DASH_9613972) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[653],1,arguments);
}
var anf_fun77753983 = G(recv_DASH_9613972,"visit",L[653]);
var $z39753976 = D;
var $f39813982 = function(_) {
return R.isFunction(anf_fun77753983)?anf_fun77753983.app(self21923970):R.ffi.throwNonFunApp(L[653],anf_fun77753983,[self21923970]);
};
try {
if(--R.GAS > 0) {
$z39753976 = $f39813982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39813982,
"from":L[653]});
}
} catch($e39733974) {
if(R.isCont($e39733974)) {
var $ss39773978 = {"from":L[653],
"go":function(ann_DASH_check_DASH_temp77743984) {
return $Hann_DASH_check_DASH_temp112063985(ann_DASH_check_DASH_temp77743984);
}};
$e39733974.stack[R.EXN_STACKHEIGHT++] = $ss39773978;
}
if(R.isPyretException($e39733974)) {
$e39733974.pyretStack.push(L[653]);
}
throw $e39733974;
}
var $ret39793980 = $Hann_DASH_check_DASH_temp112063985($z39753976);
++R.GAS;
return $ret39793980;
});
var $z39533954 = D;
var $f39593960 = function(_) {
return R.isFunction(anf_fun77733961)?anf_fun77733961.app(anf_arg77763962):R.ffi.throwNonFunApp(L[652],anf_fun77733961,[anf_arg77763962]);
};
try {
if(--R.GAS > 0) {
$z39533954 = $f39593960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39593960,
"from":L[652]});
}
} catch($e39513952) {
if(R.isCont($e39513952)) {
var $ss39553956 = {"from":L[652],
"go":function(anf_arg77773963) {
return $Hanf_arg112133971(anf_arg77773963,_check22003964,ann21973965,args21963966,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970);
}};
$e39513952.stack[R.EXN_STACKHEIGHT++] = $ss39553956;
}
if(R.isPyretException($e39513952)) {
$e39513952.pyretStack.push(L[652]);
}
throw $e39513952;
}
var $ret39573958 = $Hanf_arg112133971($z39533954,_check22003964,ann21973965,args21963966,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970);
++R.GAS;
return $ret39573958;
};
},{"length":9});
var anf_obj77952423 = R.makeMethod(function(self22013945) {
return function(l22023950,name22033949,ann22043947) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[651],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Ann11299],[l22023950,name22033949,ann22043947],[L[648],L[649],L[650]],function() {
var anf_fun77913944 = G(name22033949,"visit",L[647]);
var $z39363937 = D;
var $f39423943 = function(_) {
return R.isFunction(anf_fun77913944)?anf_fun77913944.app(self22013945):R.ffi.throwNonFunApp(L[646],anf_fun77913944,[self22013945]);
};
try {
if(--R.GAS > 0) {
$z39363937 = $f39423943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39423943,
"from":L[646]});
}
} catch($e39343935) {
if(R.isCont($e39343935)) {
var $ss39383939 = {"from":L[646],
"go":function(anf_arg77923946) {
return $Hanf_arg112163948(anf_arg77923946,ann22043947,dummy_DASH_loc11796,s_DASH_type3361973,self22013945);
}};
$e39343935.stack[R.EXN_STACKHEIGHT++] = $ss39383939;
}
if(R.isPyretException($e39343935)) {
$e39343935.pyretStack.push(L[646]);
}
throw $e39343935;
}
var $ret39403941 = $Hanf_arg112163948($z39363937,ann22043947,dummy_DASH_loc11796,s_DASH_type3361973,self22013945);
++R.GAS;
return $ret39403941;
});
};
},{"length":4});
var anf_obj78012424 = R.makeMethod(function(self22053928) {
return function(l22063933,name22073932,namet22083930) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[645],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Name66133],[l22063933,name22073932,namet22083930],[L[642],L[643],L[644]],function() {
var anf_fun77973927 = G(name22073932,"visit",L[641]);
var $z39193920 = D;
var $f39253926 = function(_) {
return R.isFunction(anf_fun77973927)?anf_fun77973927.app(self22053928):R.ffi.throwNonFunApp(L[640],anf_fun77973927,[self22053928]);
};
try {
if(--R.GAS > 0) {
$z39193920 = $f39253926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39253926,
"from":L[640]});
}
} catch($e39173918) {
if(R.isCont($e39173918)) {
var $ss39213922 = {"from":L[640],
"go":function(anf_arg77983929) {
return $Hanf_arg112193931(anf_arg77983929,dummy_DASH_loc11796,namet22083930,s_DASH_newtype3381977,self22053928);
}};
$e39173918.stack[R.EXN_STACKHEIGHT++] = $ss39213922;
}
if(R.isPyretException($e39173918)) {
$e39173918.pyretStack.push(L[640]);
}
throw $e39173918;
}
var $ret39233924 = $Hanf_arg112193931($z39193920,dummy_DASH_loc11796,namet22083930,s_DASH_newtype3381977,self22053928);
++R.GAS;
return $ret39233924;
});
};
},{"length":4});
var anf_obj78072425 = R.makeMethod(function(self22093911) {
return function(l22103916,name22113915,value22123913) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[639],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l22103916,name22113915,value22123913],[L[636],L[637],L[638]],function() {
var anf_fun78033910 = G(name22113915,"visit",L[635]);
var $z39023903 = D;
var $f39083909 = function(_) {
return R.isFunction(anf_fun78033910)?anf_fun78033910.app(self22093911):R.ffi.throwNonFunApp(L[634],anf_fun78033910,[self22093911]);
};
try {
if(--R.GAS > 0) {
$z39023903 = $f39083909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39083909,
"from":L[634]});
}
} catch($e39003901) {
if(R.isCont($e39003901)) {
var $ss39043905 = {"from":L[634],
"go":function(anf_arg78043912) {
return $Hanf_arg112223914(anf_arg78043912,dummy_DASH_loc11796,s_DASH_var3401981,self22093911,value22123913);
}};
$e39003901.stack[R.EXN_STACKHEIGHT++] = $ss39043905;
}
if(R.isPyretException($e39003901)) {
$e39003901.pyretStack.push(L[634]);
}
throw $e39003901;
}
var $ret39063907 = $Hanf_arg112223914($z39023903,dummy_DASH_loc11796,s_DASH_var3401981,self22093911,value22123913);
++R.GAS;
return $ret39063907;
});
};
},{"length":4});
var anf_obj78132426 = R.makeMethod(function(self22133893) {
return function(l22143899,name22153898,value22163896,keyword_DASH_val22173895) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[633],4,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111,$type$Boolean67],[l22143899,name22153898,value22163896,keyword_DASH_val22173895],[L[629],L[630],L[631],L[632]],function() {
var anf_fun78093892 = G(name22153898,"visit",L[628]);
var $z38843885 = D;
var $f38903891 = function(_) {
return R.isFunction(anf_fun78093892)?anf_fun78093892.app(self22133893):R.ffi.throwNonFunApp(L[627],anf_fun78093892,[self22133893]);
};
try {
if(--R.GAS > 0) {
$z38843885 = $f38903891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38903891,
"from":L[627]});
}
} catch($e38823883) {
if(R.isCont($e38823883)) {
var $ss38863887 = {"from":L[627],
"go":function(anf_arg78103894) {
return $Hanf_arg112253897(anf_arg78103894,dummy_DASH_loc11796,keyword_DASH_val22173895,s_DASH_let3421985,self22133893,value22163896);
}};
$e38823883.stack[R.EXN_STACKHEIGHT++] = $ss38863887;
}
if(R.isPyretException($e38823883)) {
$e38823883.pyretStack.push(L[627]);
}
throw $e38823883;
}
var $ret38883889 = $Hanf_arg112253897($z38843885,dummy_DASH_loc11796,keyword_DASH_val22173895,s_DASH_let3421985,self22133893,value22163896);
++R.GAS;
return $ret38883889;
});
};
},{"length":5});
var anf_obj78202427 = R.makeMethod(function(self22183877) {
return function(l22193881,bindings22203880) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[626],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l22193881,bindings22203880],[L[624],L[625]],function() {
var anf_fun78153861 = G(bindings22203880,"map",L[623]);
var anf_arg78183862 = R.makeFunction(function(recv_DASH_9633865) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[622],1,arguments);
}
var anf_fun78173876 = G(recv_DASH_9633865,"visit",L[622]);
var $z38683869 = D;
var $f38743875 = function(_) {
return R.isFunction(anf_fun78173876)?anf_fun78173876.app(self22183877):R.ffi.throwNonFunApp(L[622],anf_fun78173876,[self22183877]);
};
try {
if(--R.GAS > 0) {
$z38683869 = $f38743875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38743875,
"from":L[622]});
}
} catch($e38663867) {
if(R.isCont($e38663867)) {
var $ss38703871 = {"from":L[622],
"go":function(ann_DASH_check_DASH_temp78163878) {
return $Hann_DASH_check_DASH_temp112263879(ann_DASH_check_DASH_temp78163878);
}};
$e38663867.stack[R.EXN_STACKHEIGHT++] = $ss38703871;
}
if(R.isPyretException($e38663867)) {
$e38663867.pyretStack.push(L[622]);
}
throw $e38663867;
}
var $ret38723873 = $Hann_DASH_check_DASH_temp112263879($z38683869);
++R.GAS;
return $ret38723873;
});
var $z38533854 = D;
var $f38593860 = function(_) {
return R.isFunction(anf_fun78153861)?anf_fun78153861.app(anf_arg78183862):R.ffi.throwNonFunApp(L[621],anf_fun78153861,[anf_arg78183862]);
};
try {
if(--R.GAS > 0) {
$z38533854 = $f38593860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38593860,
"from":L[621]});
}
} catch($e38513852) {
if(R.isCont($e38513852)) {
var $ss38553856 = {"from":L[621],
"go":function(anf_arg78193863) {
return $Hanf_arg112283864(anf_arg78193863,dummy_DASH_loc11796,s_DASH_graph3441989);
}};
$e38513852.stack[R.EXN_STACKHEIGHT++] = $ss38553856;
}
if(R.isPyretException($e38513852)) {
$e38513852.pyretStack.push(L[621]);
}
throw $e38513852;
}
var $ret38573858 = $Hanf_arg112283864($z38533854,dummy_DASH_loc11796,s_DASH_graph3441989);
++R.GAS;
return $ret38573858;
});
};
},{"length":3});
var anf_obj78262428 = R.makeMethod(function(self22213845) {
return function(l22223850,test22233849,block22243847) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[620],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l22223850,test22233849,block22243847],[L[617],L[618],L[619]],function() {
var anf_fun78223844 = G(test22233849,"visit",L[616]);
var $z38363837 = D;
var $f38423843 = function(_) {
return R.isFunction(anf_fun78223844)?anf_fun78223844.app(self22213845):R.ffi.throwNonFunApp(L[615],anf_fun78223844,[self22213845]);
};
try {
if(--R.GAS > 0) {
$z38363837 = $f38423843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38423843,
"from":L[615]});
}
} catch($e38343835) {
if(R.isCont($e38343835)) {
var $ss38383839 = {"from":L[615],
"go":function(anf_arg78233846) {
return $Hanf_arg112313848(anf_arg78233846,block22243847,dummy_DASH_loc11796,s_DASH_when3481997,self22213845);
}};
$e38343835.stack[R.EXN_STACKHEIGHT++] = $ss38383839;
}
if(R.isPyretException($e38343835)) {
$e38343835.pyretStack.push(L[615]);
}
throw $e38343835;
}
var $ret38403841 = $Hanf_arg112313848($z38363837,block22243847,dummy_DASH_loc11796,s_DASH_when3481997,self22213845);
++R.GAS;
return $ret38403841;
});
};
},{"length":4});
var anf_obj78322429 = R.makeMethod(function(self22253828) {
return function(l22263833,name22273832,ann22283830) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[614],3,arguments);
}
var anf_fun78283827 = G(name22273832,"visit",L[613]);
var $z38193820 = D;
var $f38253826 = function(_) {
return R.isFunction(anf_fun78283827)?anf_fun78283827.app(self22253828):R.ffi.throwNonFunApp(L[612],anf_fun78283827,[self22253828]);
};
try {
if(--R.GAS > 0) {
$z38193820 = $f38253826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38253826,
"from":L[612]});
}
} catch($e38173818) {
if(R.isCont($e38173818)) {
var $ss38213822 = {"from":L[612],
"go":function(anf_arg78293829) {
return $Hanf_arg112343831(anf_arg78293829,ann22283830,dummy_DASH_loc11796,s_DASH_contract3461993,self22253828);
}};
$e38173818.stack[R.EXN_STACKHEIGHT++] = $ss38213822;
}
if(R.isPyretException($e38173818)) {
$e38173818.pyretStack.push(L[612]);
}
throw $e38173818;
}
var $ret38233824 = $Hanf_arg112343831($z38193820,ann22283830,dummy_DASH_loc11796,s_DASH_contract3461993,self22253828);
++R.GAS;
return $ret38233824;
};
},{"length":4});
var anf_obj78382430 = R.makeMethod(function(self22293811) {
return function(l22303816,id22313815,value22323813) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[611],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,Expr86111],[l22303816,id22313815,value22323813],[L[608],L[609],L[610]],function() {
var anf_fun78343810 = G(id22313815,"visit",L[607]);
var $z38023803 = D;
var $f38083809 = function(_) {
return R.isFunction(anf_fun78343810)?anf_fun78343810.app(self22293811):R.ffi.throwNonFunApp(L[606],anf_fun78343810,[self22293811]);
};
try {
if(--R.GAS > 0) {
$z38023803 = $f38083809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38083809,
"from":L[606]});
}
} catch($e38003801) {
if(R.isCont($e38003801)) {
var $ss38043805 = {"from":L[606],
"go":function(anf_arg78353812) {
return $Hanf_arg112373814(anf_arg78353812,dummy_DASH_loc11796,s_DASH_assign3502001,self22293811,value22323813);
}};
$e38003801.stack[R.EXN_STACKHEIGHT++] = $ss38043805;
}
if(R.isPyretException($e38003801)) {
$e38003801.pyretStack.push(L[606]);
}
throw $e38003801;
}
var $ret38063807 = $Hanf_arg112373814($z38023803,dummy_DASH_loc11796,s_DASH_assign3502001,self22293811,value22323813);
++R.GAS;
return $ret38063807;
});
};
},{"length":4});
var anf_obj78442431 = R.makeMethod(function(self22333794) {
return function(l22343799,test22353798,body22363796) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[605],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l22343799,test22353798,body22363796],[L[602],L[603],L[604]],function() {
var anf_fun78403793 = G(test22353798,"visit",L[601]);
var $z37853786 = D;
var $f37913792 = function(_) {
return R.isFunction(anf_fun78403793)?anf_fun78403793.app(self22333794):R.ffi.throwNonFunApp(L[600],anf_fun78403793,[self22333794]);
};
try {
if(--R.GAS > 0) {
$z37853786 = $f37913792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37913792,
"from":L[600]});
}
} catch($e37833784) {
if(R.isCont($e37833784)) {
var $ss37873788 = {"from":L[600],
"go":function(anf_arg78413795) {
return $Hanf_arg112403797(anf_arg78413795,body22363796,dummy_DASH_loc11796,s_DASH_if_DASH_branch4922285,self22333794);
}};
$e37833784.stack[R.EXN_STACKHEIGHT++] = $ss37873788;
}
if(R.isPyretException($e37833784)) {
$e37833784.pyretStack.push(L[600]);
}
throw $e37833784;
}
var $ret37893790 = $Hanf_arg112403797($z37853786,body22363796,dummy_DASH_loc11796,s_DASH_if_DASH_branch4922285,self22333794);
++R.GAS;
return $ret37893790;
});
};
},{"length":4});
var anf_obj78502432 = R.makeMethod(function(self22373777) {
return function(l22383782,test22393781,body22403779) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[599],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l22383782,test22393781,body22403779],[L[596],L[597],L[598]],function() {
var anf_fun78463776 = G(test22393781,"visit",L[595]);
var $z37683769 = D;
var $f37743775 = function(_) {
return R.isFunction(anf_fun78463776)?anf_fun78463776.app(self22373777):R.ffi.throwNonFunApp(L[594],anf_fun78463776,[self22373777]);
};
try {
if(--R.GAS > 0) {
$z37683769 = $f37743775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37743775,
"from":L[594]});
}
} catch($e37663767) {
if(R.isCont($e37663767)) {
var $ss37703771 = {"from":L[594],
"go":function(anf_arg78473778) {
return $Hanf_arg112433780(anf_arg78473778,body22403779,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_branch4972295,self22373777);
}};
$e37663767.stack[R.EXN_STACKHEIGHT++] = $ss37703771;
}
if(R.isPyretException($e37663767)) {
$e37663767.pyretStack.push(L[594]);
}
throw $e37663767;
}
var $ret37723773 = $Hanf_arg112433780($z37683769,body22403779,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_branch4972295,self22373777);
++R.GAS;
return $ret37723773;
});
};
},{"length":4});
var anf_obj78572433 = R.makeMethod(function(self22413761) {
return function(l22423765,branches22433764) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[593],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l22423765,branches22433764],[L[591],L[592]],function() {
var anf_fun78523745 = G(branches22433764,"map",L[590]);
var anf_arg78553746 = R.makeFunction(function(recv_DASH_9643749) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[589],1,arguments);
}
var anf_fun78543760 = G(recv_DASH_9643749,"visit",L[589]);
var $z37523753 = D;
var $f37583759 = function(_) {
return R.isFunction(anf_fun78543760)?anf_fun78543760.app(self22413761):R.ffi.throwNonFunApp(L[589],anf_fun78543760,[self22413761]);
};
try {
if(--R.GAS > 0) {
$z37523753 = $f37583759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37583759,
"from":L[589]});
}
} catch($e37503751) {
if(R.isCont($e37503751)) {
var $ss37543755 = {"from":L[589],
"go":function(ann_DASH_check_DASH_temp78533762) {
return $Hann_DASH_check_DASH_temp112443763(ann_DASH_check_DASH_temp78533762);
}};
$e37503751.stack[R.EXN_STACKHEIGHT++] = $ss37543755;
}
if(R.isPyretException($e37503751)) {
$e37503751.pyretStack.push(L[589]);
}
throw $e37503751;
}
var $ret37563757 = $Hann_DASH_check_DASH_temp112443763($z37523753);
++R.GAS;
return $ret37563757;
});
var $z37373738 = D;
var $f37433744 = function(_) {
return R.isFunction(anf_fun78523745)?anf_fun78523745.app(anf_arg78553746):R.ffi.throwNonFunApp(L[588],anf_fun78523745,[anf_arg78553746]);
};
try {
if(--R.GAS > 0) {
$z37373738 = $f37433744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37433744,
"from":L[588]});
}
} catch($e37353736) {
if(R.isCont($e37353736)) {
var $ss37393740 = {"from":L[588],
"go":function(anf_arg78563747) {
return $Hanf_arg112463748(anf_arg78563747,dummy_DASH_loc11796,s_DASH_if3562013);
}};
$e37353736.stack[R.EXN_STACKHEIGHT++] = $ss37393740;
}
if(R.isPyretException($e37353736)) {
$e37353736.pyretStack.push(L[588]);
}
throw $e37353736;
}
var $ret37413742 = $Hanf_arg112463748($z37373738,dummy_DASH_loc11796,s_DASH_if3562013);
++R.GAS;
return $ret37413742;
});
};
},{"length":3});
var anf_obj78662434 = R.makeMethod(function(self22443717) {
return function(l22453734,branches22463733,_else22473716) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[587],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l22453734,branches22463733,_else22473716],[L[584],L[585],L[586]],function() {
var anf_fun78593713 = G(branches22463733,"map",L[583]);
var anf_arg78623714 = R.makeFunction(function(recv_DASH_9653719) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[582],1,arguments);
}
var anf_fun78613730 = G(recv_DASH_9653719,"visit",L[582]);
var $z37223723 = D;
var $f37283729 = function(_) {
return R.isFunction(anf_fun78613730)?anf_fun78613730.app(self22443717):R.ffi.throwNonFunApp(L[582],anf_fun78613730,[self22443717]);
};
try {
if(--R.GAS > 0) {
$z37223723 = $f37283729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37283729,
"from":L[582]});
}
} catch($e37203721) {
if(R.isCont($e37203721)) {
var $ss37243725 = {"from":L[582],
"go":function(ann_DASH_check_DASH_temp78603731) {
return $Hann_DASH_check_DASH_temp112473732(ann_DASH_check_DASH_temp78603731);
}};
$e37203721.stack[R.EXN_STACKHEIGHT++] = $ss37243725;
}
if(R.isPyretException($e37203721)) {
$e37203721.pyretStack.push(L[582]);
}
throw $e37203721;
}
var $ret37263727 = $Hann_DASH_check_DASH_temp112473732($z37223723);
++R.GAS;
return $ret37263727;
});
var $z37053706 = D;
var $f37113712 = function(_) {
return R.isFunction(anf_fun78593713)?anf_fun78593713.app(anf_arg78623714):R.ffi.throwNonFunApp(L[581],anf_fun78593713,[anf_arg78623714]);
};
try {
if(--R.GAS > 0) {
$z37053706 = $f37113712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37113712,
"from":L[581]});
}
} catch($e37033704) {
if(R.isCont($e37033704)) {
var $ss37073708 = {"from":L[581],
"go":function(anf_arg78633715) {
return $Hanf_arg112503718(anf_arg78633715,_else22473716,dummy_DASH_loc11796,s_DASH_if_DASH_else3582017,self22443717);
}};
$e37033704.stack[R.EXN_STACKHEIGHT++] = $ss37073708;
}
if(R.isPyretException($e37033704)) {
$e37033704.pyretStack.push(L[581]);
}
throw $e37033704;
}
var $ret37093710 = $Hanf_arg112503718($z37053706,_else22473716,dummy_DASH_loc11796,s_DASH_if_DASH_else3582017,self22443717);
++R.GAS;
return $ret37093710;
});
};
},{"length":4});
var anf_obj78732435 = R.makeMethod(function(self22483698) {
return function(l22493702,branches22503701) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[580],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l22493702,branches22503701],[L[578],L[579]],function() {
var anf_fun78683682 = G(branches22503701,"map",L[577]);
var anf_arg78713683 = R.makeFunction(function(recv_DASH_9663686) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[576],1,arguments);
}
var anf_fun78703697 = G(recv_DASH_9663686,"visit",L[576]);
var $z36893690 = D;
var $f36953696 = function(_) {
return R.isFunction(anf_fun78703697)?anf_fun78703697.app(self22483698):R.ffi.throwNonFunApp(L[576],anf_fun78703697,[self22483698]);
};
try {
if(--R.GAS > 0) {
$z36893690 = $f36953696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36953696,
"from":L[576]});
}
} catch($e36873688) {
if(R.isCont($e36873688)) {
var $ss36913692 = {"from":L[576],
"go":function(ann_DASH_check_DASH_temp78693699) {
return $Hann_DASH_check_DASH_temp112513700(ann_DASH_check_DASH_temp78693699);
}};
$e36873688.stack[R.EXN_STACKHEIGHT++] = $ss36913692;
}
if(R.isPyretException($e36873688)) {
$e36873688.pyretStack.push(L[576]);
}
throw $e36873688;
}
var $ret36933694 = $Hann_DASH_check_DASH_temp112513700($z36893690);
++R.GAS;
return $ret36933694;
});
var $z36743675 = D;
var $f36803681 = function(_) {
return R.isFunction(anf_fun78683682)?anf_fun78683682.app(anf_arg78713683):R.ffi.throwNonFunApp(L[575],anf_fun78683682,[anf_arg78713683]);
};
try {
if(--R.GAS > 0) {
$z36743675 = $f36803681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36803681,
"from":L[575]});
}
} catch($e36723673) {
if(R.isCont($e36723673)) {
var $ss36763677 = {"from":L[575],
"go":function(anf_arg78723684) {
return $Hanf_arg112533685(anf_arg78723684,dummy_DASH_loc11796,s_DASH_if_DASH_pipe3522005);
}};
$e36723673.stack[R.EXN_STACKHEIGHT++] = $ss36763677;
}
if(R.isPyretException($e36723673)) {
$e36723673.pyretStack.push(L[575]);
}
throw $e36723673;
}
var $ret36783679 = $Hanf_arg112533685($z36743675,dummy_DASH_loc11796,s_DASH_if_DASH_pipe3522005);
++R.GAS;
return $ret36783679;
});
};
},{"length":3});
var anf_obj78822436 = R.makeMethod(function(self22513654) {
return function(l22523671,branches22533670,_else22543653) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[574],3,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Expr86111],[l22523671,branches22533670,_else22543653],[L[571],L[572],L[573]],function() {
var anf_fun78753650 = G(branches22533670,"map",L[570]);
var anf_arg78783651 = R.makeFunction(function(recv_DASH_9673656) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[569],1,arguments);
}
var anf_fun78773667 = G(recv_DASH_9673656,"visit",L[569]);
var $z36593660 = D;
var $f36653666 = function(_) {
return R.isFunction(anf_fun78773667)?anf_fun78773667.app(self22513654):R.ffi.throwNonFunApp(L[569],anf_fun78773667,[self22513654]);
};
try {
if(--R.GAS > 0) {
$z36593660 = $f36653666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36653666,
"from":L[569]});
}
} catch($e36573658) {
if(R.isCont($e36573658)) {
var $ss36613662 = {"from":L[569],
"go":function(ann_DASH_check_DASH_temp78763668) {
return $Hann_DASH_check_DASH_temp112543669(ann_DASH_check_DASH_temp78763668);
}};
$e36573658.stack[R.EXN_STACKHEIGHT++] = $ss36613662;
}
if(R.isPyretException($e36573658)) {
$e36573658.pyretStack.push(L[569]);
}
throw $e36573658;
}
var $ret36633664 = $Hann_DASH_check_DASH_temp112543669($z36593660);
++R.GAS;
return $ret36633664;
});
var $z36423643 = D;
var $f36483649 = function(_) {
return R.isFunction(anf_fun78753650)?anf_fun78753650.app(anf_arg78783651):R.ffi.throwNonFunApp(L[568],anf_fun78753650,[anf_arg78783651]);
};
try {
if(--R.GAS > 0) {
$z36423643 = $f36483649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36483649,
"from":L[568]});
}
} catch($e36403641) {
if(R.isCont($e36403641)) {
var $ss36443645 = {"from":L[568],
"go":function(anf_arg78793652) {
return $Hanf_arg112573655(anf_arg78793652,_else22543653,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_else3542009,self22513654);
}};
$e36403641.stack[R.EXN_STACKHEIGHT++] = $ss36443645;
}
if(R.isPyretException($e36403641)) {
$e36403641.pyretStack.push(L[568]);
}
throw $e36403641;
}
var $ret36463647 = $Hanf_arg112573655($z36423643,_else22543653,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_else3542009,self22513654);
++R.GAS;
return $ret36463647;
});
};
},{"length":4});
var anf_obj78912437 = R.makeMethod(function(self22553622) {
return function(l22563639,name22573621,args22583638,body22593620) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[567],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,Expr86111],[l22563639,name22573621,args22583638,body22593620],[L[563],L[564],L[565],L[566]],function() {
var anf_fun78843617 = G(args22583638,"map",L[562]);
var anf_arg78873618 = R.makeFunction(function(recv_DASH_9683624) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[561],1,arguments);
}
var anf_fun78863635 = G(recv_DASH_9683624,"visit",L[561]);
var $z36273628 = D;
var $f36333634 = function(_) {
return R.isFunction(anf_fun78863635)?anf_fun78863635.app(self22553622):R.ffi.throwNonFunApp(L[561],anf_fun78863635,[self22553622]);
};
try {
if(--R.GAS > 0) {
$z36273628 = $f36333634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36333634,
"from":L[561]});
}
} catch($e36253626) {
if(R.isCont($e36253626)) {
var $ss36293630 = {"from":L[561],
"go":function(ann_DASH_check_DASH_temp78853636) {
return $Hann_DASH_check_DASH_temp112583637(ann_DASH_check_DASH_temp78853636);
}};
$e36253626.stack[R.EXN_STACKHEIGHT++] = $ss36293630;
}
if(R.isPyretException($e36253626)) {
$e36253626.pyretStack.push(L[561]);
}
throw $e36253626;
}
var $ret36313632 = $Hann_DASH_check_DASH_temp112583637($z36273628);
++R.GAS;
return $ret36313632;
});
var $z36093610 = D;
var $f36153616 = function(_) {
return R.isFunction(anf_fun78843617)?anf_fun78843617.app(anf_arg78873618):R.ffi.throwNonFunApp(L[560],anf_fun78843617,[anf_arg78873618]);
};
try {
if(--R.GAS > 0) {
$z36093610 = $f36153616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36153616,
"from":L[560]});
}
} catch($e36073608) {
if(R.isCont($e36073608)) {
var $ss36113612 = {"from":L[560],
"go":function(anf_arg78883619) {
return $Hanf_arg112613623(anf_arg78883619,body22593620,dummy_DASH_loc11796,name22573621,s_DASH_cases_DASH_branch5022305,self22553622);
}};
$e36073608.stack[R.EXN_STACKHEIGHT++] = $ss36113612;
}
if(R.isPyretException($e36073608)) {
$e36073608.pyretStack.push(L[560]);
}
throw $e36073608;
}
var $ret36133614 = $Hanf_arg112613623($z36093610,body22593620,dummy_DASH_loc11796,name22573621,s_DASH_cases_DASH_branch5022305,self22553622);
++R.GAS;
return $ret36133614;
});
};
},{"length":5});
var anf_obj79022438 = R.makeMethod(function(self22603600) {
return function(l22613606,typ22623605,val22633603,branches22643602) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[559],4,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111,List17129],[l22613606,typ22623605,val22633603,branches22643602],[L[555],L[556],L[557],L[558]],function() {
var anf_fun78933599 = G(typ22623605,"visit",L[554]);
var $z35913592 = D;
var $f35973598 = function(_) {
return R.isFunction(anf_fun78933599)?anf_fun78933599.app(self22603600):R.ffi.throwNonFunApp(L[553],anf_fun78933599,[self22603600]);
};
try {
if(--R.GAS > 0) {
$z35913592 = $f35973598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35973598,
"from":L[553]});
}
} catch($e35893590) {
if(R.isCont($e35893590)) {
var $ss35933594 = {"from":L[553],
"go":function(anf_arg78943601) {
return $Hanf_arg112663604(anf_arg78943601,branches22643602,dummy_DASH_loc11796,s_DASH_cases3602021,self22603600,val22633603);
}};
$e35893590.stack[R.EXN_STACKHEIGHT++] = $ss35933594;
}
if(R.isPyretException($e35893590)) {
$e35893590.pyretStack.push(L[553]);
}
throw $e35893590;
}
var $ret35953596 = $Hanf_arg112663604($z35913592,branches22643602,dummy_DASH_loc11796,s_DASH_cases3602021,self22603600,val22633603);
++R.GAS;
return $ret35953596;
});
};
},{"length":5});
var anf_obj79152439 = R.makeMethod(function(self22653581) {
return function(l22663588,typ22673587,val22683585,branches22693584,_else22703583) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[552],5,arguments);
}
return R.checkAnnArgs([Loc116130,Ann11299,Expr86111,List17129,Expr86111],[l22663588,typ22673587,val22683585,branches22693584,_else22703583],[L[547],L[548],L[549],L[550],L[551]],function() {
var anf_fun79043580 = G(typ22673587,"visit",L[546]);
var $z35723573 = D;
var $f35783579 = function(_) {
return R.isFunction(anf_fun79043580)?anf_fun79043580.app(self22653581):R.ffi.throwNonFunApp(L[545],anf_fun79043580,[self22653581]);
};
try {
if(--R.GAS > 0) {
$z35723573 = $f35783579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35783579,
"from":L[545]});
}
} catch($e35703571) {
if(R.isCont($e35703571)) {
var $ss35743575 = {"from":L[545],
"go":function(anf_arg79053582) {
return $Hanf_arg112723586(anf_arg79053582,_else22703583,branches22693584,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581,val22683585);
}};
$e35703571.stack[R.EXN_STACKHEIGHT++] = $ss35743575;
}
if(R.isPyretException($e35703571)) {
$e35703571.pyretStack.push(L[545]);
}
throw $e35703571;
}
var $ret35763577 = $Hanf_arg112723586($z35723573,_else22703583,branches22693584,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581,val22683585);
++R.GAS;
return $ret35763577;
});
};
},{"length":6});
var anf_obj79232440 = R.makeMethod(function(self22713563) {
return function(l22723569,body22733568,id22743566,_except22753565) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[544],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Bind90101,Expr86111],[l22723569,body22733568,id22743566,_except22753565],[L[540],L[541],L[542],L[543]],function() {
var anf_fun79173562 = G(body22733568,"visit",L[539]);
var $z35543555 = D;
var $f35603561 = function(_) {
return R.isFunction(anf_fun79173562)?anf_fun79173562.app(self22713563):R.ffi.throwNonFunApp(L[538],anf_fun79173562,[self22713563]);
};
try {
if(--R.GAS > 0) {
$z35543555 = $f35603561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35603561,
"from":L[538]});
}
} catch($e35523553) {
if(R.isCont($e35523553)) {
var $ss35563557 = {"from":L[538],
"go":function(anf_arg79183564) {
return $Hanf_arg112763567(anf_arg79183564,_except22753565,dummy_DASH_loc11796,id22743566,s_DASH_try3642029,self22713563);
}};
$e35523553.stack[R.EXN_STACKHEIGHT++] = $ss35563557;
}
if(R.isPyretException($e35523553)) {
$e35523553.pyretStack.push(L[538]);
}
throw $e35523553;
}
var $ret35583559 = $Hanf_arg112763567($z35543555,_except22753565,dummy_DASH_loc11796,id22743566,s_DASH_try3642029,self22713563);
++R.GAS;
return $ret35583559;
});
};
},{"length":5});
var anf_obj79292441 = R.makeMethod(function(self22763545) {
return function(l22773551,op22783547,left22793550,right22803548) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[537],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111,Expr86111],[l22773551,op22783547,left22793550,right22803548],[L[533],L[534],L[535],L[536]],function() {
var anf_fun79253544 = G(left22793550,"visit",L[532]);
var $z35363537 = D;
var $f35423543 = function(_) {
return R.isFunction(anf_fun79253544)?anf_fun79253544.app(self22763545):R.ffi.throwNonFunApp(L[531],anf_fun79253544,[self22763545]);
};
try {
if(--R.GAS > 0) {
$z35363537 = $f35423543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35423543,
"from":L[531]});
}
} catch($e35343535) {
if(R.isCont($e35343535)) {
var $ss35383539 = {"from":L[531],
"go":function(anf_arg79263546) {
return $Hanf_arg112793549(anf_arg79263546,dummy_DASH_loc11796,op22783547,right22803548,s_DASH_op3662033,self22763545);
}};
$e35343535.stack[R.EXN_STACKHEIGHT++] = $ss35383539;
}
if(R.isPyretException($e35343535)) {
$e35343535.pyretStack.push(L[531]);
}
throw $e35343535;
}
var $ret35403541 = $Hanf_arg112793549($z35363537,dummy_DASH_loc11796,op22783547,right22803548,s_DASH_op3662033,self22763545);
++R.GAS;
return $ret35403541;
});
};
},{"length":5});
var anf_obj79352442 = R.makeMethod(function(self22813527) {
return function(l22823533,op22833529,left22843532,right22853530) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[530],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111,Expr86111],[l22823533,op22833529,left22843532,right22853530],[L[526],L[527],L[528],L[529]],function() {
var anf_fun79313526 = G(left22843532,"visit",L[525]);
var $z35183519 = D;
var $f35243525 = function(_) {
return R.isFunction(anf_fun79313526)?anf_fun79313526.app(self22813527):R.ffi.throwNonFunApp(L[524],anf_fun79313526,[self22813527]);
};
try {
if(--R.GAS > 0) {
$z35183519 = $f35243525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35243525,
"from":L[524]});
}
} catch($e35163517) {
if(R.isCont($e35163517)) {
var $ss35203521 = {"from":L[524],
"go":function(anf_arg79323528) {
return $Hanf_arg112823531(anf_arg79323528,dummy_DASH_loc11796,op22833529,right22853530,s_DASH_check_DASH_test3682037,self22813527);
}};
$e35163517.stack[R.EXN_STACKHEIGHT++] = $ss35203521;
}
if(R.isPyretException($e35163517)) {
$e35163517.pyretStack.push(L[524]);
}
throw $e35163517;
}
var $ret35223523 = $Hanf_arg112823531($z35183519,dummy_DASH_loc11796,op22833529,right22853530,s_DASH_check_DASH_test3682037,self22813527);
++R.GAS;
return $ret35223523;
});
};
},{"length":5});
var anf_obj79392443 = R.makeMethod(function(self22863511) {
return function(l22873515,expr22883514) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[523],2,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111],[l22873515,expr22883514],[L[521],L[522]],function() {
var anf_fun79373510 = G(expr22883514,"visit",L[520]);
var $z35023503 = D;
var $f35083509 = function(_) {
return R.isFunction(anf_fun79373510)?anf_fun79373510.app(self22863511):R.ffi.throwNonFunApp(L[519],anf_fun79373510,[self22863511]);
};
try {
if(--R.GAS > 0) {
$z35023503 = $f35083509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35083509,
"from":L[519]});
}
} catch($e35003501) {
if(R.isCont($e35003501)) {
var $ss35043505 = {"from":L[519],
"go":function(anf_arg79383512) {
return $Hanf_arg112843513(anf_arg79383512,dummy_DASH_loc11796,s_DASH_paren3702041);
}};
$e35003501.stack[R.EXN_STACKHEIGHT++] = $ss35043505;
}
if(R.isPyretException($e35003501)) {
$e35003501.pyretStack.push(L[519]);
}
throw $e35003501;
}
var $ret35063507 = $Hanf_arg112843513($z35023503,dummy_DASH_loc11796,s_DASH_paren3702041);
++R.GAS;
return $ret35063507;
});
};
},{"length":3});
var anf_obj79572444 = R.makeMethod(function(self22893482) {
return function(l22903499,params22913498,args22923479,ann22933478,doc22943481,body22953480,_check22963477) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[518],7,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l22903499,params22913498,args22923479,ann22933478,doc22943481,body22953480,_check22963477],[L[511],L[512],L[513],L[514],L[515],L[516],L[517]],function() {
var anf_fun79413474 = G(params22913498,"map",L[510]);
var anf_arg79443475 = R.makeFunction(function(recv_DASH_9713484) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[509],1,arguments);
}
var anf_fun79433495 = G(recv_DASH_9713484,"visit",L[509]);
var $z34873488 = D;
var $f34933494 = function(_) {
return R.isFunction(anf_fun79433495)?anf_fun79433495.app(self22893482):R.ffi.throwNonFunApp(L[509],anf_fun79433495,[self22893482]);
};
try {
if(--R.GAS > 0) {
$z34873488 = $f34933494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34933494,
"from":L[509]});
}
} catch($e34853486) {
if(R.isCont($e34853486)) {
var $ss34893490 = {"from":L[509],
"go":function(ann_DASH_check_DASH_temp79423496) {
return $Hann_DASH_check_DASH_temp112853497(ann_DASH_check_DASH_temp79423496);
}};
$e34853486.stack[R.EXN_STACKHEIGHT++] = $ss34893490;
}
if(R.isPyretException($e34853486)) {
$e34853486.pyretStack.push(L[509]);
}
throw $e34853486;
}
var $ret34913492 = $Hann_DASH_check_DASH_temp112853497($z34873488);
++R.GAS;
return $ret34913492;
});
var $z34663467 = D;
var $f34723473 = function(_) {
return R.isFunction(anf_fun79413474)?anf_fun79413474.app(anf_arg79443475):R.ffi.throwNonFunApp(L[508],anf_fun79413474,[anf_arg79443475]);
};
try {
if(--R.GAS > 0) {
$z34663467 = $f34723473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34723473,
"from":L[508]});
}
} catch($e34643465) {
if(R.isCont($e34643465)) {
var $ss34683469 = {"from":L[508],
"go":function(anf_arg79453476) {
return $Hanf_arg112923483(anf_arg79453476,_check22963477,ann22933478,args22923479,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482);
}};
$e34643465.stack[R.EXN_STACKHEIGHT++] = $ss34683469;
}
if(R.isPyretException($e34643465)) {
$e34643465.pyretStack.push(L[508]);
}
throw $e34643465;
}
var $ret34703471 = $Hanf_arg112923483($z34663467,_check22963477,ann22933478,args22923479,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482);
++R.GAS;
return $ret34703471;
});
};
},{"length":8});
var anf_obj79702445 = R.makeMethod(function(self22973446) {
return function(l22983463,args22993462,ann23003443,doc23013445,body23023444,_check23033442) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[507],6,arguments);
}
return R.checkAnnArgs([Loc116130,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l22983463,args22993462,ann23003443,doc23013445,body23023444,_check23033442],[L[501],L[502],L[503],L[504],L[505],L[506]],function() {
var anf_fun79593439 = G(args22993462,"map",L[500]);
var anf_arg79623440 = R.makeFunction(function(recv_DASH_9733448) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[499],1,arguments);
}
var anf_fun79613459 = G(recv_DASH_9733448,"visit",L[499]);
var $z34513452 = D;
var $f34573458 = function(_) {
return R.isFunction(anf_fun79613459)?anf_fun79613459.app(self22973446):R.ffi.throwNonFunApp(L[499],anf_fun79613459,[self22973446]);
};
try {
if(--R.GAS > 0) {
$z34513452 = $f34573458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34573458,
"from":L[499]});
}
} catch($e34493450) {
if(R.isCont($e34493450)) {
var $ss34533454 = {"from":L[499],
"go":function(ann_DASH_check_DASH_temp79603460) {
return $Hann_DASH_check_DASH_temp112933461(ann_DASH_check_DASH_temp79603460);
}};
$e34493450.stack[R.EXN_STACKHEIGHT++] = $ss34533454;
}
if(R.isPyretException($e34493450)) {
$e34493450.pyretStack.push(L[499]);
}
throw $e34493450;
}
var $ret34553456 = $Hann_DASH_check_DASH_temp112933461($z34513452);
++R.GAS;
return $ret34553456;
});
var $z34313432 = D;
var $f34373438 = function(_) {
return R.isFunction(anf_fun79593439)?anf_fun79593439.app(anf_arg79623440):R.ffi.throwNonFunApp(L[498],anf_fun79593439,[anf_arg79623440]);
};
try {
if(--R.GAS > 0) {
$z34313432 = $f34373438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34373438,
"from":L[498]});
}
} catch($e34293430) {
if(R.isCont($e34293430)) {
var $ss34333434 = {"from":L[498],
"go":function(anf_arg79633441) {
return $Hanf_arg112983447(anf_arg79633441,_check23033442,ann23003443,body23023444,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446);
}};
$e34293430.stack[R.EXN_STACKHEIGHT++] = $ss34333434;
}
if(R.isPyretException($e34293430)) {
$e34293430.pyretStack.push(L[498]);
}
throw $e34293430;
}
var $ret34353436 = $Hanf_arg112983447($z34313432,_check23033442,ann23003443,body23023444,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446);
++R.GAS;
return $ret34353436;
});
};
},{"length":7});
var anf_obj79792446 = R.makeMethod(function(self23043423) {
return function(l23053428,supe23063427,fields23073425) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[497],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l23053428,supe23063427,fields23073425],[L[494],L[495],L[496]],function() {
var anf_fun79723422 = G(supe23063427,"visit",L[493]);
var $z34143415 = D;
var $f34203421 = function(_) {
return R.isFunction(anf_fun79723422)?anf_fun79723422.app(self23043423):R.ffi.throwNonFunApp(L[492],anf_fun79723422,[self23043423]);
};
try {
if(--R.GAS > 0) {
$z34143415 = $f34203421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34203421,
"from":L[492]});
}
} catch($e34123413) {
if(R.isCont($e34123413)) {
var $ss34163417 = {"from":L[492],
"go":function(anf_arg79733424) {
return $Hanf_arg113023426(anf_arg79733424,dummy_DASH_loc11796,fields23073425,s_DASH_extend3762053,self23043423);
}};
$e34123413.stack[R.EXN_STACKHEIGHT++] = $ss34163417;
}
if(R.isPyretException($e34123413)) {
$e34123413.pyretStack.push(L[492]);
}
throw $e34123413;
}
var $ret34183419 = $Hanf_arg113023426($z34143415,dummy_DASH_loc11796,fields23073425,s_DASH_extend3762053,self23043423);
++R.GAS;
return $ret34183419;
});
};
},{"length":4});
var anf_obj79882447 = R.makeMethod(function(self23083406) {
return function(l23093411,supe23103410,fields23113408) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[491],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l23093411,supe23103410,fields23113408],[L[488],L[489],L[490]],function() {
var anf_fun79813405 = G(supe23103410,"visit",L[487]);
var $z33973398 = D;
var $f34033404 = function(_) {
return R.isFunction(anf_fun79813405)?anf_fun79813405.app(self23083406):R.ffi.throwNonFunApp(L[486],anf_fun79813405,[self23083406]);
};
try {
if(--R.GAS > 0) {
$z33973398 = $f34033404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34033404,
"from":L[486]});
}
} catch($e33953396) {
if(R.isCont($e33953396)) {
var $ss33993400 = {"from":L[486],
"go":function(anf_arg79823407) {
return $Hanf_arg113063409(anf_arg79823407,dummy_DASH_loc11796,fields23113408,s_DASH_update3782057,self23083406);
}};
$e33953396.stack[R.EXN_STACKHEIGHT++] = $ss33993400;
}
if(R.isPyretException($e33953396)) {
$e33953396.pyretStack.push(L[486]);
}
throw $e33953396;
}
var $ret34013402 = $Hanf_arg113063409($z33973398,dummy_DASH_loc11796,fields23113408,s_DASH_update3782057,self23083406);
++R.GAS;
return $ret34013402;
});
};
},{"length":4});
var anf_obj79952448 = R.makeMethod(function(self23123390) {
return function(l23133394,fields23143393) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[485],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l23133394,fields23143393],[L[483],L[484]],function() {
var anf_fun79903374 = G(fields23143393,"map",L[482]);
var anf_arg79933375 = R.makeFunction(function(recv_DASH_9763378) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[481],1,arguments);
}
var anf_fun79923389 = G(recv_DASH_9763378,"visit",L[481]);
var $z33813382 = D;
var $f33873388 = function(_) {
return R.isFunction(anf_fun79923389)?anf_fun79923389.app(self23123390):R.ffi.throwNonFunApp(L[481],anf_fun79923389,[self23123390]);
};
try {
if(--R.GAS > 0) {
$z33813382 = $f33873388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33873388,
"from":L[481]});
}
} catch($e33793380) {
if(R.isCont($e33793380)) {
var $ss33833384 = {"from":L[481],
"go":function(ann_DASH_check_DASH_temp79913391) {
return $Hann_DASH_check_DASH_temp113073392(ann_DASH_check_DASH_temp79913391);
}};
$e33793380.stack[R.EXN_STACKHEIGHT++] = $ss33833384;
}
if(R.isPyretException($e33793380)) {
$e33793380.pyretStack.push(L[481]);
}
throw $e33793380;
}
var $ret33853386 = $Hann_DASH_check_DASH_temp113073392($z33813382);
++R.GAS;
return $ret33853386;
});
var $z33663367 = D;
var $f33723373 = function(_) {
return R.isFunction(anf_fun79903374)?anf_fun79903374.app(anf_arg79933375):R.ffi.throwNonFunApp(L[480],anf_fun79903374,[anf_arg79933375]);
};
try {
if(--R.GAS > 0) {
$z33663367 = $f33723373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33723373,
"from":L[480]});
}
} catch($e33643365) {
if(R.isCont($e33643365)) {
var $ss33683369 = {"from":L[480],
"go":function(anf_arg79943376) {
return $Hanf_arg113093377(anf_arg79943376,dummy_DASH_loc11796,s_DASH_obj3802061);
}};
$e33643365.stack[R.EXN_STACKHEIGHT++] = $ss33683369;
}
if(R.isPyretException($e33643365)) {
$e33643365.pyretStack.push(L[480]);
}
throw $e33643365;
}
var $ret33703371 = $Hanf_arg113093377($z33663367,dummy_DASH_loc11796,s_DASH_obj3802061);
++R.GAS;
return $ret33703371;
});
};
},{"length":3});
var anf_obj80022449 = R.makeMethod(function(self23153359) {
return function(l23163363,values23173362) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[479],2,arguments);
}
return R.checkAnnArgs([Loc116130,List17129],[l23163363,values23173362],[L[477],L[478]],function() {
var anf_fun79973343 = G(values23173362,"map",L[476]);
var anf_arg80003344 = R.makeFunction(function(recv_DASH_9773347) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[475],1,arguments);
}
var anf_fun79993358 = G(recv_DASH_9773347,"visit",L[475]);
var $z33503351 = D;
var $f33563357 = function(_) {
return R.isFunction(anf_fun79993358)?anf_fun79993358.app(self23153359):R.ffi.throwNonFunApp(L[475],anf_fun79993358,[self23153359]);
};
try {
if(--R.GAS > 0) {
$z33503351 = $f33563357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33563357,
"from":L[475]});
}
} catch($e33483349) {
if(R.isCont($e33483349)) {
var $ss33523353 = {"from":L[475],
"go":function(ann_DASH_check_DASH_temp79983360) {
return $Hann_DASH_check_DASH_temp113103361(ann_DASH_check_DASH_temp79983360);
}};
$e33483349.stack[R.EXN_STACKHEIGHT++] = $ss33523353;
}
if(R.isPyretException($e33483349)) {
$e33483349.pyretStack.push(L[475]);
}
throw $e33483349;
}
var $ret33543355 = $Hann_DASH_check_DASH_temp113103361($z33503351);
++R.GAS;
return $ret33543355;
});
var $z33353336 = D;
var $f33413342 = function(_) {
return R.isFunction(anf_fun79973343)?anf_fun79973343.app(anf_arg80003344):R.ffi.throwNonFunApp(L[474],anf_fun79973343,[anf_arg80003344]);
};
try {
if(--R.GAS > 0) {
$z33353336 = $f33413342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33413342,
"from":L[474]});
}
} catch($e33333334) {
if(R.isCont($e33333334)) {
var $ss33373338 = {"from":L[474],
"go":function(anf_arg80013345) {
return $Hanf_arg113123346(anf_arg80013345,dummy_DASH_loc11796,s_DASH_array3822065);
}};
$e33333334.stack[R.EXN_STACKHEIGHT++] = $ss33373338;
}
if(R.isPyretException($e33333334)) {
$e33333334.pyretStack.push(L[474]);
}
throw $e33333334;
}
var $ret33393340 = $Hanf_arg113123346($z33353336,dummy_DASH_loc11796,s_DASH_array3822065);
++R.GAS;
return $ret33393340;
});
};
},{"length":3});
var anf_obj80082450 = R.makeMethod(function(self23183327) {
return function(l23193332,expr23203331,typ23213329) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[473],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Name66133],[l23193332,expr23203331,typ23213329],[L[470],L[471],L[472]],function() {
var anf_fun80043326 = G(expr23203331,"visit",L[469]);
var $z33183319 = D;
var $f33243325 = function(_) {
return R.isFunction(anf_fun80043326)?anf_fun80043326.app(self23183327):R.ffi.throwNonFunApp(L[468],anf_fun80043326,[self23183327]);
};
try {
if(--R.GAS > 0) {
$z33183319 = $f33243325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33243325,
"from":L[468]});
}
} catch($e33163317) {
if(R.isCont($e33163317)) {
var $ss33203321 = {"from":L[468],
"go":function(anf_arg80053328) {
return $Hanf_arg113153330(anf_arg80053328,dummy_DASH_loc11796,s_DASH_bless3882077,self23183327,typ23213329);
}};
$e33163317.stack[R.EXN_STACKHEIGHT++] = $ss33203321;
}
if(R.isPyretException($e33163317)) {
$e33163317.pyretStack.push(L[468]);
}
throw $e33163317;
}
var $ret33223323 = $Hanf_arg113153330($z33183319,dummy_DASH_loc11796,s_DASH_bless3882077,self23183327,typ23213329);
++R.GAS;
return $ret33223323;
});
};
},{"length":4});
var anf_obj80142451 = R.makeMethod(function(self23223310) {
return function(l23233315,expr23243314,typ23253312) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[467],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Name66133],[l23233315,expr23243314,typ23253312],[L[464],L[465],L[466]],function() {
var anf_fun80103309 = G(expr23243314,"visit",L[463]);
var $z33013302 = D;
var $f33073308 = function(_) {
return R.isFunction(anf_fun80103309)?anf_fun80103309.app(self23223310):R.ffi.throwNonFunApp(L[462],anf_fun80103309,[self23223310]);
};
try {
if(--R.GAS > 0) {
$z33013302 = $f33073308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33073308,
"from":L[462]});
}
} catch($e32993300) {
if(R.isCont($e32993300)) {
var $ss33033304 = {"from":L[462],
"go":function(anf_arg80113311) {
return $Hanf_arg113183313(anf_arg80113311,dummy_DASH_loc11796,s_DASH_confirm3862073,self23223310,typ23253312);
}};
$e32993300.stack[R.EXN_STACKHEIGHT++] = $ss33033304;
}
if(R.isPyretException($e32993300)) {
$e32993300.pyretStack.push(L[462]);
}
throw $e32993300;
}
var $ret33053306 = $Hanf_arg113183313($z33013302,dummy_DASH_loc11796,s_DASH_confirm3862073,self23223310,typ23253312);
++R.GAS;
return $ret33053306;
});
};
},{"length":4});
var anf_obj80232452 = R.makeMethod(function(self23263292) {
return function(l23273298,mod23283294,constructor23293297,values23303295) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[461],4,arguments);
}
return R.checkAnnArgs([Loc116130,ConstructModifier88105,Expr86111,List17129],[l23273298,mod23283294,constructor23293297,values23303295],[L[457],L[458],L[459],L[460]],function() {
var anf_fun80163291 = G(constructor23293297,"visit",L[456]);
var $z32833284 = D;
var $f32893290 = function(_) {
return R.isFunction(anf_fun80163291)?anf_fun80163291.app(self23263292):R.ffi.throwNonFunApp(L[455],anf_fun80163291,[self23263292]);
};
try {
if(--R.GAS > 0) {
$z32833284 = $f32893290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32893290,
"from":L[455]});
}
} catch($e32813282) {
if(R.isCont($e32813282)) {
var $ss32853286 = {"from":L[455],
"go":function(anf_arg80173293) {
return $Hanf_arg113223296(anf_arg80173293,dummy_DASH_loc11796,mod23283294,s_DASH_construct3842069,self23263292,values23303295);
}};
$e32813282.stack[R.EXN_STACKHEIGHT++] = $ss32853286;
}
if(R.isPyretException($e32813282)) {
$e32813282.pyretStack.push(L[455]);
}
throw $e32813282;
}
var $ret32873288 = $Hanf_arg113223296($z32833284,dummy_DASH_loc11796,mod23283294,s_DASH_construct3842069,self23263292,values23303295);
++R.GAS;
return $ret32873288;
});
};
},{"length":5});
var anf_obj80322453 = R.makeMethod(function(self23313275) {
return function(l23323280,_fun23333279,args23343277) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[454],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129],[l23323280,_fun23333279,args23343277],[L[451],L[452],L[453]],function() {
var anf_fun80253274 = G(_fun23333279,"visit",L[450]);
var $z32663267 = D;
var $f32723273 = function(_) {
return R.isFunction(anf_fun80253274)?anf_fun80253274.app(self23313275):R.ffi.throwNonFunApp(L[449],anf_fun80253274,[self23313275]);
};
try {
if(--R.GAS > 0) {
$z32663267 = $f32723273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32723273,
"from":L[449]});
}
} catch($e32643265) {
if(R.isCont($e32643265)) {
var $ss32683269 = {"from":L[449],
"go":function(anf_arg80263276) {
return $Hanf_arg113263278(anf_arg80263276,args23343277,dummy_DASH_loc11796,s_DASH_app3902081,self23313275);
}};
$e32643265.stack[R.EXN_STACKHEIGHT++] = $ss32683269;
}
if(R.isPyretException($e32643265)) {
$e32643265.pyretStack.push(L[449]);
}
throw $e32643265;
}
var $ret32703271 = $Hanf_arg113263278($z32663267,args23343277,dummy_DASH_loc11796,s_DASH_app3902081,self23313275);
++R.GAS;
return $ret32703271;
});
};
},{"length":4});
var anf_obj80392454 = R.makeMethod(function(self23353259) {
return function(l23363263,_fun23373245,args23383262) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[448],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129],[l23363263,_fun23373245,args23383262],[L[445],L[446],L[447]],function() {
var anf_fun80343242 = G(args23383262,"map",L[444]);
var anf_arg80373243 = R.makeFunction(function(recv_DASH_9803247) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[443],1,arguments);
}
var anf_fun80363258 = G(recv_DASH_9803247,"visit",L[443]);
var $z32503251 = D;
var $f32563257 = function(_) {
return R.isFunction(anf_fun80363258)?anf_fun80363258.app(self23353259):R.ffi.throwNonFunApp(L[443],anf_fun80363258,[self23353259]);
};
try {
if(--R.GAS > 0) {
$z32503251 = $f32563257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32563257,
"from":L[443]});
}
} catch($e32483249) {
if(R.isCont($e32483249)) {
var $ss32523253 = {"from":L[443],
"go":function(ann_DASH_check_DASH_temp80353260) {
return $Hann_DASH_check_DASH_temp113273261(ann_DASH_check_DASH_temp80353260);
}};
$e32483249.stack[R.EXN_STACKHEIGHT++] = $ss32523253;
}
if(R.isPyretException($e32483249)) {
$e32483249.pyretStack.push(L[443]);
}
throw $e32483249;
}
var $ret32543255 = $Hann_DASH_check_DASH_temp113273261($z32503251);
++R.GAS;
return $ret32543255;
});
var $z32343235 = D;
var $f32403241 = function(_) {
return R.isFunction(anf_fun80343242)?anf_fun80343242.app(anf_arg80373243):R.ffi.throwNonFunApp(L[442],anf_fun80343242,[anf_arg80373243]);
};
try {
if(--R.GAS > 0) {
$z32343235 = $f32403241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32403241,
"from":L[442]});
}
} catch($e32323233) {
if(R.isCont($e32323233)) {
var $ss32363237 = {"from":L[442],
"go":function(anf_arg80383244) {
return $Hanf_arg113293246(anf_arg80383244,_fun23373245,dummy_DASH_loc11796,s_DASH_prim_DASH_app3922085);
}};
$e32323233.stack[R.EXN_STACKHEIGHT++] = $ss32363237;
}
if(R.isPyretException($e32323233)) {
$e32323233.pyretStack.push(L[442]);
}
throw $e32323233;
}
var $ret32383239 = $Hanf_arg113293246($z32343235,_fun23373245,dummy_DASH_loc11796,s_DASH_prim_DASH_app3922085);
++R.GAS;
return $ret32383239;
});
};
},{"length":4});
var anf_obj80412455 = R.makeMethod(function(self23393231) {
return function(l23403230,name23413227) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[439],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l23403230,name23413227],[L[440],L[441]],function() {
var $z32193220 = D;
var $f32253226 = function(_) {
return R.isFunction(s_DASH_prim_DASH_val3942089.$var)?s_DASH_prim_DASH_val3942089.$var.app(dummy_DASH_loc11796,name23413227):R.ffi.throwNonFunApp(L[439],s_DASH_prim_DASH_val3942089.$var,[dummy_DASH_loc11796,name23413227]);
};
try {
if(--R.GAS > 0) {
$z32193220 = $f32253226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32253226,
"from":L[439]});
}
} catch($e32173218) {
if(R.isCont($e32173218)) {
var $ss32213222 = {"from":L[439],
"go":function(ann_DASH_check_DASH_temp80403228) {
return $Hann_DASH_check_DASH_temp113303229(ann_DASH_check_DASH_temp80403228);
}};
$e32173218.stack[R.EXN_STACKHEIGHT++] = $ss32213222;
}
if(R.isPyretException($e32173218)) {
$e32173218.pyretStack.push(L[439]);
}
throw $e32173218;
}
var $ret32233224 = $Hann_DASH_check_DASH_temp113303229($z32193220);
++R.GAS;
return $ret32233224;
});
};
},{"length":3});
var anf_obj80452456 = R.makeMethod(function(self23423212) {
return function(l23433216,id23443215) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[438],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l23433216,id23443215],[L[436],L[437]],function() {
var anf_fun80433211 = G(id23443215,"visit",L[435]);
var $z32033204 = D;
var $f32093210 = function(_) {
return R.isFunction(anf_fun80433211)?anf_fun80433211.app(self23423212):R.ffi.throwNonFunApp(L[434],anf_fun80433211,[self23423212]);
};
try {
if(--R.GAS > 0) {
$z32033204 = $f32093210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32093210,
"from":L[434]});
}
} catch($e32013202) {
if(R.isCont($e32013202)) {
var $ss32053206 = {"from":L[434],
"go":function(anf_arg80443213) {
return $Hanf_arg113323214(anf_arg80443213,dummy_DASH_loc11796,s_DASH_id3962093);
}};
$e32013202.stack[R.EXN_STACKHEIGHT++] = $ss32053206;
}
if(R.isPyretException($e32013202)) {
$e32013202.pyretStack.push(L[434]);
}
throw $e32013202;
}
var $ret32073208 = $Hanf_arg113323214($z32033204,dummy_DASH_loc11796,s_DASH_id3962093);
++R.GAS;
return $ret32073208;
});
};
},{"length":3});
var anf_obj80492457 = R.makeMethod(function(self23453196) {
return function(l23463200,id23473199) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[433],2,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133],[l23463200,id23473199],[L[431],L[432]],function() {
var anf_fun80473195 = G(id23473199,"visit",L[430]);
var $z31873188 = D;
var $f31933194 = function(_) {
return R.isFunction(anf_fun80473195)?anf_fun80473195.app(self23453196):R.ffi.throwNonFunApp(L[429],anf_fun80473195,[self23453196]);
};
try {
if(--R.GAS > 0) {
$z31873188 = $f31933194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31933194,
"from":L[429]});
}
} catch($e31853186) {
if(R.isCont($e31853186)) {
var $ss31893190 = {"from":L[429],
"go":function(anf_arg80483197) {
return $Hanf_arg113343198(anf_arg80483197,dummy_DASH_loc11796,s_DASH_id_DASH_var3982097);
}};
$e31853186.stack[R.EXN_STACKHEIGHT++] = $ss31893190;
}
if(R.isPyretException($e31853186)) {
$e31853186.pyretStack.push(L[429]);
}
throw $e31853186;
}
var $ret31913192 = $Hanf_arg113343198($z31873188,dummy_DASH_loc11796,s_DASH_id_DASH_var3982097);
++R.GAS;
return $ret31913192;
});
};
},{"length":3});
var anf_obj80532458 = R.makeMethod(function(self23483179) {
return function(l23493184,id23503183,safe23513181) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[428],3,arguments);
}
return R.checkAnnArgs([Loc116130,Name66133,$type$Boolean67],[l23493184,id23503183,safe23513181],[L[425],L[426],L[427]],function() {
var anf_fun80513178 = G(id23503183,"visit",L[424]);
var $z31703171 = D;
var $f31763177 = function(_) {
return R.isFunction(anf_fun80513178)?anf_fun80513178.app(self23483179):R.ffi.throwNonFunApp(L[423],anf_fun80513178,[self23483179]);
};
try {
if(--R.GAS > 0) {
$z31703171 = $f31763177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31763177,
"from":L[423]});
}
} catch($e31683169) {
if(R.isCont($e31683169)) {
var $ss31723173 = {"from":L[423],
"go":function(anf_arg80523180) {
return $Hanf_arg113363182(anf_arg80523180,dummy_DASH_loc11796,s_DASH_id_DASH_letrec4002101,safe23513181);
}};
$e31683169.stack[R.EXN_STACKHEIGHT++] = $ss31723173;
}
if(R.isPyretException($e31683169)) {
$e31683169.pyretStack.push(L[423]);
}
throw $e31683169;
}
var $ret31743175 = $Hanf_arg113363182($z31703171,dummy_DASH_loc11796,s_DASH_id_DASH_letrec4002101,safe23513181);
++R.GAS;
return $ret31743175;
});
};
},{"length":4});
var anf_obj80552459 = R.makeMethod(function(self23523164) {
return function(l23533167) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[421],1,arguments);
}
return R.checkAnnArgs([Loc116130],[l23533167],[L[422]],function() {
var $z31563157 = D;
var $f31623163 = function(_) {
return R.isFunction(s_DASH_undefined4022105.$var)?s_DASH_undefined4022105.$var.app(self23523164):R.ffi.throwNonFunApp(L[421],s_DASH_undefined4022105.$var,[self23523164]);
};
try {
if(--R.GAS > 0) {
$z31563157 = $f31623163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31623163,
"from":L[421]});
}
} catch($e31543155) {
if(R.isCont($e31543155)) {
var $ss31583159 = {"from":L[421],
"go":function(ann_DASH_check_DASH_temp80543165) {
return $Hann_DASH_check_DASH_temp113373166(ann_DASH_check_DASH_temp80543165);
}};
$e31543155.stack[R.EXN_STACKHEIGHT++] = $ss31583159;
}
if(R.isPyretException($e31543155)) {
$e31543155.pyretStack.push(L[421]);
}
throw $e31543155;
}
var $ret31603161 = $Hann_DASH_check_DASH_temp113373166($z31563157);
++R.GAS;
return $ret31603161;
});
};
},{"length":2});
var anf_obj80572460 = R.makeMethod(function(self23543152) {
return function(l23553153,loc23563149) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[420],2,arguments);
}
var $z31413142 = D;
var $f31473148 = function(_) {
return R.isFunction(s_DASH_srcloc4042109.$var)?s_DASH_srcloc4042109.$var.app(dummy_DASH_loc11796,loc23563149):R.ffi.throwNonFunApp(L[420],s_DASH_srcloc4042109.$var,[dummy_DASH_loc11796,loc23563149]);
};
try {
if(--R.GAS > 0) {
$z31413142 = $f31473148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31473148,
"from":L[420]});
}
} catch($e31393140) {
if(R.isCont($e31393140)) {
var $ss31433144 = {"from":L[420],
"go":function(ann_DASH_check_DASH_temp80563150) {
return $Hann_DASH_check_DASH_temp113383151(ann_DASH_check_DASH_temp80563150);
}};
$e31393140.stack[R.EXN_STACKHEIGHT++] = $ss31433144;
}
if(R.isPyretException($e31393140)) {
$e31393140.pyretStack.push(L[420]);
}
throw $e31393140;
}
var $ret31453146 = $Hann_DASH_check_DASH_temp113383151($z31413142);
++R.GAS;
return $ret31453146;
};
},{"length":3});
var anf_obj80592461 = R.makeMethod(function(self23573138) {
return function(l23583137,n23593134) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[417],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Number68],[l23583137,n23593134],[L[418],L[419]],function() {
var $z31263127 = D;
var $f31323133 = function(_) {
return R.isFunction(s_DASH_num4062113.$var)?s_DASH_num4062113.$var.app(dummy_DASH_loc11796,n23593134):R.ffi.throwNonFunApp(L[417],s_DASH_num4062113.$var,[dummy_DASH_loc11796,n23593134]);
};
try {
if(--R.GAS > 0) {
$z31263127 = $f31323133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31323133,
"from":L[417]});
}
} catch($e31243125) {
if(R.isCont($e31243125)) {
var $ss31283129 = {"from":L[417],
"go":function(ann_DASH_check_DASH_temp80583135) {
return $Hann_DASH_check_DASH_temp113393136(ann_DASH_check_DASH_temp80583135);
}};
$e31243125.stack[R.EXN_STACKHEIGHT++] = $ss31283129;
}
if(R.isPyretException($e31243125)) {
$e31243125.pyretStack.push(L[417]);
}
throw $e31243125;
}
var $ret31303131 = $Hann_DASH_check_DASH_temp113393136($z31263127);
++R.GAS;
return $ret31303131;
});
};
},{"length":3});
var anf_obj80612462 = R.makeMethod(function(self23603123) {
return function(l23613122,num23623118,den23633119) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[413],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Number68,$type$Number68],[l23613122,num23623118,den23633119],[L[414],L[415],L[416]],function() {
var $z31103111 = D;
var $f31163117 = function(_) {
return R.isFunction(s_DASH_frac4082117.$var)?s_DASH_frac4082117.$var.app(dummy_DASH_loc11796,num23623118,den23633119):R.ffi.throwNonFunApp(L[413],s_DASH_frac4082117.$var,[dummy_DASH_loc11796,num23623118,den23633119]);
};
try {
if(--R.GAS > 0) {
$z31103111 = $f31163117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31163117,
"from":L[413]});
}
} catch($e31083109) {
if(R.isCont($e31083109)) {
var $ss31123113 = {"from":L[413],
"go":function(ann_DASH_check_DASH_temp80603120) {
return $Hann_DASH_check_DASH_temp113403121(ann_DASH_check_DASH_temp80603120);
}};
$e31083109.stack[R.EXN_STACKHEIGHT++] = $ss31123113;
}
if(R.isPyretException($e31083109)) {
$e31083109.pyretStack.push(L[413]);
}
throw $e31083109;
}
var $ret31143115 = $Hann_DASH_check_DASH_temp113403121($z31103111);
++R.GAS;
return $ret31143115;
});
};
},{"length":4});
var anf_obj80632463 = R.makeMethod(function(self23643107) {
return function(l23653106,b23663103) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[410],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$Boolean67],[l23653106,b23663103],[L[411],L[412]],function() {
var $z30953096 = D;
var $f31013102 = function(_) {
return R.isFunction(s_DASH_bool4102121.$var)?s_DASH_bool4102121.$var.app(dummy_DASH_loc11796,b23663103):R.ffi.throwNonFunApp(L[410],s_DASH_bool4102121.$var,[dummy_DASH_loc11796,b23663103]);
};
try {
if(--R.GAS > 0) {
$z30953096 = $f31013102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31013102,
"from":L[410]});
}
} catch($e30933094) {
if(R.isCont($e30933094)) {
var $ss30973098 = {"from":L[410],
"go":function(ann_DASH_check_DASH_temp80623104) {
return $Hann_DASH_check_DASH_temp113413105(ann_DASH_check_DASH_temp80623104);
}};
$e30933094.stack[R.EXN_STACKHEIGHT++] = $ss30973098;
}
if(R.isPyretException($e30933094)) {
$e30933094.pyretStack.push(L[410]);
}
throw $e30933094;
}
var $ret30993100 = $Hann_DASH_check_DASH_temp113413105($z30953096);
++R.GAS;
return $ret30993100;
});
};
},{"length":3});
var anf_obj80652464 = R.makeMethod(function(self23673092) {
return function(l23683091,s23693088) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[407],2,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69],[l23683091,s23693088],[L[408],L[409]],function() {
var $z30803081 = D;
var $f30863087 = function(_) {
return R.isFunction(s_DASH_str4122125.$var)?s_DASH_str4122125.$var.app(dummy_DASH_loc11796,s23693088):R.ffi.throwNonFunApp(L[407],s_DASH_str4122125.$var,[dummy_DASH_loc11796,s23693088]);
};
try {
if(--R.GAS > 0) {
$z30803081 = $f30863087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30863087,
"from":L[407]});
}
} catch($e30783079) {
if(R.isCont($e30783079)) {
var $ss30823083 = {"from":L[407],
"go":function(ann_DASH_check_DASH_temp80643089) {
return $Hann_DASH_check_DASH_temp113423090(ann_DASH_check_DASH_temp80643089);
}};
$e30783079.stack[R.EXN_STACKHEIGHT++] = $ss30823083;
}
if(R.isPyretException($e30783079)) {
$e30783079.pyretStack.push(L[407]);
}
throw $e30783079;
}
var $ret30843085 = $Hann_DASH_check_DASH_temp113423090($z30803081);
++R.GAS;
return $ret30843085;
});
};
},{"length":3});
var anf_obj80692465 = R.makeMethod(function(self23703072) {
return function(l23713077,obj23723076,field23733074) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[406],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,$type$String69],[l23713077,obj23723076,field23733074],[L[403],L[404],L[405]],function() {
var anf_fun80673071 = G(obj23723076,"visit",L[402]);
var $z30633064 = D;
var $f30693070 = function(_) {
return R.isFunction(anf_fun80673071)?anf_fun80673071.app(self23703072):R.ffi.throwNonFunApp(L[401],anf_fun80673071,[self23703072]);
};
try {
if(--R.GAS > 0) {
$z30633064 = $f30693070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30693070,
"from":L[401]});
}
} catch($e30613062) {
if(R.isCont($e30613062)) {
var $ss30653066 = {"from":L[401],
"go":function(anf_arg80683073) {
return $Hanf_arg113443075(anf_arg80683073,dummy_DASH_loc11796,field23733074,s_DASH_dot4142129);
}};
$e30613062.stack[R.EXN_STACKHEIGHT++] = $ss30653066;
}
if(R.isPyretException($e30613062)) {
$e30613062.pyretStack.push(L[401]);
}
throw $e30613062;
}
var $ret30673068 = $Hanf_arg113443075($z30633064,dummy_DASH_loc11796,field23733074,s_DASH_dot4142129);
++R.GAS;
return $ret30673068;
});
};
},{"length":4});
var anf_obj80732466 = R.makeMethod(function(self23743055) {
return function(l23753060,obj23763059,field23773057) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[400],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,$type$String69],[l23753060,obj23763059,field23773057],[L[397],L[398],L[399]],function() {
var anf_fun80713054 = G(obj23763059,"visit",L[396]);
var $z30463047 = D;
var $f30523053 = function(_) {
return R.isFunction(anf_fun80713054)?anf_fun80713054.app(self23743055):R.ffi.throwNonFunApp(L[395],anf_fun80713054,[self23743055]);
};
try {
if(--R.GAS > 0) {
$z30463047 = $f30523053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30523053,
"from":L[395]});
}
} catch($e30443045) {
if(R.isCont($e30443045)) {
var $ss30483049 = {"from":L[395],
"go":function(anf_arg80723056) {
return $Hanf_arg113463058(anf_arg80723056,dummy_DASH_loc11796,field23773057,s_DASH_get_DASH_bang4162133);
}};
$e30443045.stack[R.EXN_STACKHEIGHT++] = $ss30483049;
}
if(R.isPyretException($e30443045)) {
$e30443045.pyretStack.push(L[395]);
}
throw $e30443045;
}
var $ret30503051 = $Hanf_arg113463058($z30463047,dummy_DASH_loc11796,field23773057,s_DASH_get_DASH_bang4162133);
++R.GAS;
return $ret30503051;
});
};
},{"length":4});
var anf_obj80792467 = R.makeMethod(function(self23783038) {
return function(l23793043,obj23803042,field23813040) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[394],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l23793043,obj23803042,field23813040],[L[391],L[392],L[393]],function() {
var anf_fun80753037 = G(obj23803042,"visit",L[390]);
var $z30293030 = D;
var $f30353036 = function(_) {
return R.isFunction(anf_fun80753037)?anf_fun80753037.app(self23783038):R.ffi.throwNonFunApp(L[389],anf_fun80753037,[self23783038]);
};
try {
if(--R.GAS > 0) {
$z30293030 = $f30353036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30353036,
"from":L[389]});
}
} catch($e30273028) {
if(R.isCont($e30273028)) {
var $ss30313032 = {"from":L[389],
"go":function(anf_arg80763039) {
return $Hanf_arg113493041(anf_arg80763039,dummy_DASH_loc11796,field23813040,s_DASH_bracket4182137,self23783038);
}};
$e30273028.stack[R.EXN_STACKHEIGHT++] = $ss30313032;
}
if(R.isPyretException($e30273028)) {
$e30273028.pyretStack.push(L[389]);
}
throw $e30273028;
}
var $ret30333034 = $Hanf_arg113493041($z30293030,dummy_DASH_loc11796,field23813040,s_DASH_bracket4182137,self23783038);
++R.GAS;
return $ret30333034;
});
};
},{"length":4});
var anf_obj81032468 = R.makeMethod(function(self23823007) {
return function(l23833026,name23843006,params23853025,mixins23863005,variants23873009,shared_DASH_members23883008,_check23893004) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[388],7,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,List17129,List17129,List17129,Option18135],[l23833026,name23843006,params23853025,mixins23863005,variants23873009,shared_DASH_members23883008,_check23893004],[L[381],L[382],L[383],L[384],L[385],L[386],L[387]],function() {
var anf_fun80813001 = G(params23853025,"map",L[380]);
var anf_arg80843002 = R.makeFunction(function(recv_DASH_9813011) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[379],1,arguments);
}
var anf_fun80833022 = G(recv_DASH_9813011,"visit",L[379]);
var $z30143015 = D;
var $f30203021 = function(_) {
return R.isFunction(anf_fun80833022)?anf_fun80833022.app(self23823007):R.ffi.throwNonFunApp(L[379],anf_fun80833022,[self23823007]);
};
try {
if(--R.GAS > 0) {
$z30143015 = $f30203021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30203021,
"from":L[379]});
}
} catch($e30123013) {
if(R.isCont($e30123013)) {
var $ss30163017 = {"from":L[379],
"go":function(ann_DASH_check_DASH_temp80823023) {
return $Hann_DASH_check_DASH_temp113503024(ann_DASH_check_DASH_temp80823023);
}};
$e30123013.stack[R.EXN_STACKHEIGHT++] = $ss30163017;
}
if(R.isPyretException($e30123013)) {
$e30123013.pyretStack.push(L[379]);
}
throw $e30123013;
}
var $ret30183019 = $Hann_DASH_check_DASH_temp113503024($z30143015);
++R.GAS;
return $ret30183019;
});
var $z29932994 = D;
var $f29993000 = function(_) {
return R.isFunction(anf_fun80813001)?anf_fun80813001.app(anf_arg80843002):R.ffi.throwNonFunApp(L[378],anf_fun80813001,[anf_arg80843002]);
};
try {
if(--R.GAS > 0) {
$z29932994 = $f29993000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29993000,
"from":L[378]});
}
} catch($e29912992) {
if(R.isCont($e29912992)) {
var $ss29952996 = {"from":L[378],
"go":function(anf_arg80853003) {
return $Hanf_arg113593010(anf_arg80853003,_check23893004,dummy_DASH_loc11796,mixins23863005,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008,variants23873009);
}};
$e29912992.stack[R.EXN_STACKHEIGHT++] = $ss29952996;
}
if(R.isPyretException($e29912992)) {
$e29912992.pyretStack.push(L[378]);
}
throw $e29912992;
}
var $ret29972998 = $Hanf_arg113593010($z29932994,_check23893004,dummy_DASH_loc11796,mixins23863005,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008,variants23873009);
++R.GAS;
return $ret29972998;
});
};
},{"length":8});
var anf_obj81292469 = R.makeMethod(function(self23902980) {
return function(l23912990,name23922984,namet23932989,params23942985,mixins23952983,variants23962987,shared_DASH_members23972986,_check23982982) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[377],8,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,$type$String69,List17129,List17129,List17129,List17129,Option18135],[l23912990,name23922984,namet23932989,params23942985,mixins23952983,variants23962987,shared_DASH_members23972986,_check23982982],[L[369],L[370],L[371],L[372],L[373],L[374],L[375],L[376]],function() {
var anf_fun81052979 = G(namet23932989,"visit",L[368]);
var $z29712972 = D;
var $f29772978 = function(_) {
return R.isFunction(anf_fun81052979)?anf_fun81052979.app(self23902980):R.ffi.throwNonFunApp(L[367],anf_fun81052979,[self23902980]);
};
try {
if(--R.GAS > 0) {
$z29712972 = $f29772978();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29772978,
"from":L[367]});
}
} catch($e29692970) {
if(R.isCont($e29692970)) {
var $ss29732974 = {"from":L[367],
"go":function(anf_arg81062981) {
return $Hanf_arg113702988(anf_arg81062981,_check23982982,dummy_DASH_loc11796,mixins23952983,name23922984,params23942985,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987);
}};
$e29692970.stack[R.EXN_STACKHEIGHT++] = $ss29732974;
}
if(R.isPyretException($e29692970)) {
$e29692970.pyretStack.push(L[367]);
}
throw $e29692970;
}
var $ret29752976 = $Hanf_arg113702988($z29712972,_check23982982,dummy_DASH_loc11796,mixins23952983,name23922984,params23942985,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987);
++R.GAS;
return $ret29752976;
});
};
},{"length":9});
var anf_obj81422470 = R.makeMethod(function(self23992961) {
return function(l24002968,iterator24012967,bindings24022964,ann24032963,body24042965) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[366],5,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129,Ann11299,Expr86111],[l24002968,iterator24012967,bindings24022964,ann24032963,body24042965],[L[361],L[362],L[363],L[364],L[365]],function() {
var anf_fun81312960 = G(iterator24012967,"visit",L[360]);
var $z29522953 = D;
var $f29582959 = function(_) {
return R.isFunction(anf_fun81312960)?anf_fun81312960.app(self23992961):R.ffi.throwNonFunApp(L[359],anf_fun81312960,[self23992961]);
};
try {
if(--R.GAS > 0) {
$z29522953 = $f29582959();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29582959,
"from":L[359]});
}
} catch($e29502951) {
if(R.isCont($e29502951)) {
var $ss29542955 = {"from":L[359],
"go":function(anf_arg81322962) {
return $Hanf_arg113762966(anf_arg81322962,ann24032963,bindings24022964,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961);
}};
$e29502951.stack[R.EXN_STACKHEIGHT++] = $ss29542955;
}
if(R.isPyretException($e29502951)) {
$e29502951.pyretStack.push(L[359]);
}
throw $e29502951;
}
var $ret29562957 = $Hanf_arg113762966($z29522953,ann24032963,bindings24022964,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961);
++R.GAS;
return $ret29562957;
});
};
},{"length":6});
var anf_obj81462471 = R.makeMethod(function(self24052943) {
return function(l24062949,name24072946,body24082948,keyword_DASH_check24092945) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[358],4,arguments);
}
return R.checkAnnArgs([Loc116130,Option18135,Expr86111,$type$Boolean67],[l24062949,name24072946,body24082948,keyword_DASH_check24092945],[L[354],L[355],L[356],L[357]],function() {
var anf_fun81442942 = G(body24082948,"visit",L[353]);
var $z29342935 = D;
var $f29402941 = function(_) {
return R.isFunction(anf_fun81442942)?anf_fun81442942.app(self24052943):R.ffi.throwNonFunApp(L[352],anf_fun81442942,[self24052943]);
};
try {
if(--R.GAS > 0) {
$z29342935 = $f29402941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29402941,
"from":L[352]});
}
} catch($e29322933) {
if(R.isCont($e29322933)) {
var $ss29362937 = {"from":L[352],
"go":function(anf_arg81452944) {
return $Hanf_arg113782947(anf_arg81452944,dummy_DASH_loc11796,keyword_DASH_check24092945,name24072946,s_DASH_check4262153);
}};
$e29322933.stack[R.EXN_STACKHEIGHT++] = $ss29362937;
}
if(R.isPyretException($e29322933)) {
$e29322933.pyretStack.push(L[352]);
}
throw $e29322933;
}
var $ret29382939 = $Hanf_arg113782947($z29342935,dummy_DASH_loc11796,keyword_DASH_check24092945,name24072946,s_DASH_check4262153);
++R.GAS;
return $ret29382939;
});
};
},{"length":5});
var anf_obj81522472 = R.makeMethod(function(self24102926) {
return function(l24112931,name24122930,value24132928) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[351],3,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Expr86111],[l24112931,name24122930,value24132928],[L[348],L[349],L[350]],function() {
var anf_fun81482925 = G(name24122930,"visit",L[347]);
var $z29172918 = D;
var $f29232924 = function(_) {
return R.isFunction(anf_fun81482925)?anf_fun81482925.app(self24102926):R.ffi.throwNonFunApp(L[346],anf_fun81482925,[self24102926]);
};
try {
if(--R.GAS > 0) {
$z29172918 = $f29232924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29232924,
"from":L[346]});
}
} catch($e29152916) {
if(R.isCont($e29152916)) {
var $ss29192920 = {"from":L[346],
"go":function(anf_arg81492927) {
return $Hanf_arg113812929(anf_arg81492927,dummy_DASH_loc11796,s_DASH_data_DASH_field4432187,self24102926,value24132928);
}};
$e29152916.stack[R.EXN_STACKHEIGHT++] = $ss29192920;
}
if(R.isPyretException($e29152916)) {
$e29152916.pyretStack.push(L[346]);
}
throw $e29152916;
}
var $ret29212922 = $Hanf_arg113812929($z29172918,dummy_DASH_loc11796,s_DASH_data_DASH_field4432187,self24102926,value24132928);
++R.GAS;
return $ret29212922;
});
};
},{"length":4});
var anf_obj81602473 = R.makeMethod(function(self24142908) {
return function(l24152914,name24162913,ann24172910,value24182911) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[345],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Ann11299,Expr86111],[l24152914,name24162913,ann24172910,value24182911],[L[341],L[342],L[343],L[344]],function() {
var anf_fun81542907 = G(name24162913,"visit",L[340]);
var $z28992900 = D;
var $f29052906 = function(_) {
return R.isFunction(anf_fun81542907)?anf_fun81542907.app(self24142908):R.ffi.throwNonFunApp(L[339],anf_fun81542907,[self24142908]);
};
try {
if(--R.GAS > 0) {
$z28992900 = $f29052906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29052906,
"from":L[339]});
}
} catch($e28972898) {
if(R.isCont($e28972898)) {
var $ss29012902 = {"from":L[339],
"go":function(anf_arg81552909) {
return $Hanf_arg113852912(anf_arg81552909,ann24172910,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191,self24142908,value24182911);
}};
$e28972898.stack[R.EXN_STACKHEIGHT++] = $ss29012902;
}
if(R.isPyretException($e28972898)) {
$e28972898.pyretStack.push(L[339]);
}
throw $e28972898;
}
var $ret29032904 = $Hanf_arg113852912($z28992900,ann24172910,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191,self24142908,value24182911);
++R.GAS;
return $ret29032904;
});
};
},{"length":5});
var anf_obj81682474 = R.makeMethod(function(self24192890) {
return function(l24202896,name24212895,ann24222892,value24232893) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[338],4,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,Ann11299,Expr86111],[l24202896,name24212895,ann24222892,value24232893],[L[334],L[335],L[336],L[337]],function() {
var anf_fun81622889 = G(name24212895,"visit",L[333]);
var $z28812882 = D;
var $f28872888 = function(_) {
return R.isFunction(anf_fun81622889)?anf_fun81622889.app(self24192890):R.ffi.throwNonFunApp(L[332],anf_fun81622889,[self24192890]);
};
try {
if(--R.GAS > 0) {
$z28812882 = $f28872888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28872888,
"from":L[332]});
}
} catch($e28792880) {
if(R.isCont($e28792880)) {
var $ss28832884 = {"from":L[332],
"go":function(anf_arg81632891) {
return $Hanf_arg113892894(anf_arg81632891,ann24222892,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195,self24192890,value24232893);
}};
$e28792880.stack[R.EXN_STACKHEIGHT++] = $ss28832884;
}
if(R.isPyretException($e28792880)) {
$e28792880.pyretStack.push(L[332]);
}
throw $e28792880;
}
var $ret28852886 = $Hanf_arg113892894($z28812882,ann24222892,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195,self24192890,value24232893);
++R.GAS;
return $ret28852886;
});
};
},{"length":5});
var anf_obj81812475 = R.makeMethod(function(self24242861) {
return function(l24252878,name24262860,args24272877,ann24282857,doc24292859,body24302858,_check24312856) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[331],7,arguments);
}
return R.checkAnnArgs([Loc116130,Expr86111,List17129,Ann11299,$type$String69,Expr86111,Option18135],[l24252878,name24262860,args24272877,ann24282857,doc24292859,body24302858,_check24312856],[L[324],L[325],L[326],L[327],L[328],L[329],L[330]],function() {
var anf_fun81702853 = G(args24272877,"map",L[323]);
var anf_arg81732854 = R.makeFunction(function(recv_DASH_9902863) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[322],1,arguments);
}
var anf_fun81722874 = G(recv_DASH_9902863,"visit",L[322]);
var $z28662867 = D;
var $f28722873 = function(_) {
return R.isFunction(anf_fun81722874)?anf_fun81722874.app(self24242861):R.ffi.throwNonFunApp(L[322],anf_fun81722874,[self24242861]);
};
try {
if(--R.GAS > 0) {
$z28662867 = $f28722873();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28722873,
"from":L[322]});
}
} catch($e28642865) {
if(R.isCont($e28642865)) {
var $ss28682869 = {"from":L[322],
"go":function(ann_DASH_check_DASH_temp81712875) {
return $Hann_DASH_check_DASH_temp113902876(ann_DASH_check_DASH_temp81712875);
}};
$e28642865.stack[R.EXN_STACKHEIGHT++] = $ss28682869;
}
if(R.isPyretException($e28642865)) {
$e28642865.pyretStack.push(L[322]);
}
throw $e28642865;
}
var $ret28702871 = $Hann_DASH_check_DASH_temp113902876($z28662867);
++R.GAS;
return $ret28702871;
});
var $z28452846 = D;
var $f28512852 = function(_) {
return R.isFunction(anf_fun81702853)?anf_fun81702853.app(anf_arg81732854):R.ffi.throwNonFunApp(L[321],anf_fun81702853,[anf_arg81732854]);
};
try {
if(--R.GAS > 0) {
$z28452846 = $f28512852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28512852,
"from":L[321]});
}
} catch($e28432844) {
if(R.isCont($e28432844)) {
var $ss28472848 = {"from":L[321],
"go":function(anf_arg81742855) {
return $Hanf_arg113952862(anf_arg81742855,_check24312856,ann24282857,body24302858,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861);
}};
$e28432844.stack[R.EXN_STACKHEIGHT++] = $ss28472848;
}
if(R.isPyretException($e28432844)) {
$e28432844.pyretStack.push(L[321]);
}
throw $e28432844;
}
var $ret28492850 = $Hanf_arg113952862($z28452846,_check24312856,ann24282857,body24302858,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861);
++R.GAS;
return $ret28492850;
});
};
},{"length":8});
var anf_obj81872476 = R.makeMethod(function(self24322837) {
return function(l24332842,bind24342841,value24352839) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[320],3,arguments);
}
return R.checkAnnArgs([Loc116130,Bind90101,Expr86111],[l24332842,bind24342841,value24352839],[L[317],L[318],L[319]],function() {
var anf_fun81832836 = G(bind24342841,"visit",L[316]);
var $z28282829 = D;
var $f28342835 = function(_) {
return R.isFunction(anf_fun81832836)?anf_fun81832836.app(self24322837):R.ffi.throwNonFunApp(L[315],anf_fun81832836,[self24322837]);
};
try {
if(--R.GAS > 0) {
$z28282829 = $f28342835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28342835,
"from":L[315]});
}
} catch($e28262827) {
if(R.isCont($e28262827)) {
var $ss28302831 = {"from":L[315],
"go":function(anf_arg81842838) {
return $Hanf_arg113982840(anf_arg81842838,dummy_DASH_loc11796,s_DASH_for_DASH_bind4542209,self24322837,value24352839);
}};
$e28262827.stack[R.EXN_STACKHEIGHT++] = $ss28302831;
}
if(R.isPyretException($e28262827)) {
$e28262827.pyretStack.push(L[315]);
}
throw $e28262827;
}
var $ret28322833 = $Hanf_arg113982840($z28282829,dummy_DASH_loc11796,s_DASH_for_DASH_bind4542209,self24322837,value24352839);
++R.GAS;
return $ret28322833;
});
};
},{"length":4});
var anf_obj81912477 = R.makeMethod(function(self24362820) {
return function(l24372825,member_DASH_type24382822,bind24392824) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[314],3,arguments);
}
return R.checkAnnArgs([Loc116130,VariantMemberType96147,Bind90101],[l24372825,member_DASH_type24382822,bind24392824],[L[311],L[312],L[313]],function() {
var anf_fun81892819 = G(bind24392824,"visit",L[310]);
var $z28112812 = D;
var $f28172818 = function(_) {
return R.isFunction(anf_fun81892819)?anf_fun81892819.app(self24362820):R.ffi.throwNonFunApp(L[309],anf_fun81892819,[self24362820]);
};
try {
if(--R.GAS > 0) {
$z28112812 = $f28172818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28172818,
"from":L[309]});
}
} catch($e28092810) {
if(R.isCont($e28092810)) {
var $ss28132814 = {"from":L[309],
"go":function(anf_arg81902821) {
return $Hanf_arg114002823(anf_arg81902821,dummy_DASH_loc11796,member_DASH_type24382822,s_DASH_variant_DASH_member4682237);
}};
$e28092810.stack[R.EXN_STACKHEIGHT++] = $ss28132814;
}
if(R.isPyretException($e28092810)) {
$e28092810.pyretStack.push(L[309]);
}
throw $e28092810;
}
var $ret28152816 = $Hanf_arg114002823($z28112812,dummy_DASH_loc11796,member_DASH_type24382822,s_DASH_variant_DASH_member4682237);
++R.GAS;
return $ret28152816;
});
};
},{"length":4});
var anf_obj82032478 = R.makeMethod(function(self24402789) {
return function(l24412807,constr_DASH_loc24422808,name24432788,members24442806,with_DASH_members24452790) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[308],5,arguments);
}
return R.checkAnnArgs([Loc116130,Loc116130,$type$String69,List17129,List17129],[l24412807,constr_DASH_loc24422808,name24432788,members24442806,with_DASH_members24452790],[L[303],L[304],L[305],L[306],L[307]],function() {
var anf_fun81932785 = G(members24442806,"map",L[302]);
var anf_arg81962786 = R.makeFunction(function(recv_DASH_9912792) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[301],1,arguments);
}
var anf_fun81952803 = G(recv_DASH_9912792,"visit",L[301]);
var $z27952796 = D;
var $f28012802 = function(_) {
return R.isFunction(anf_fun81952803)?anf_fun81952803.app(self24402789):R.ffi.throwNonFunApp(L[301],anf_fun81952803,[self24402789]);
};
try {
if(--R.GAS > 0) {
$z27952796 = $f28012802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28012802,
"from":L[301]});
}
} catch($e27932794) {
if(R.isCont($e27932794)) {
var $ss27972798 = {"from":L[301],
"go":function(ann_DASH_check_DASH_temp81942804) {
return $Hann_DASH_check_DASH_temp114012805(ann_DASH_check_DASH_temp81942804);
}};
$e27932794.stack[R.EXN_STACKHEIGHT++] = $ss27972798;
}
if(R.isPyretException($e27932794)) {
$e27932794.pyretStack.push(L[301]);
}
throw $e27932794;
}
var $ret27992800 = $Hann_DASH_check_DASH_temp114012805($z27952796);
++R.GAS;
return $ret27992800;
});
var $z27772778 = D;
var $f27832784 = function(_) {
return R.isFunction(anf_fun81932785)?anf_fun81932785.app(anf_arg81962786):R.ffi.throwNonFunApp(L[300],anf_fun81932785,[anf_arg81962786]);
};
try {
if(--R.GAS > 0) {
$z27772778 = $f27832784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27832784,
"from":L[300]});
}
} catch($e27752776) {
if(R.isCont($e27752776)) {
var $ss27792780 = {"from":L[300],
"go":function(anf_arg81972787) {
return $Hanf_arg114052791(anf_arg81972787,dummy_DASH_loc11796,name24432788,s_DASH_variant4732247,self24402789,with_DASH_members24452790);
}};
$e27752776.stack[R.EXN_STACKHEIGHT++] = $ss27792780;
}
if(R.isPyretException($e27752776)) {
$e27752776.pyretStack.push(L[300]);
}
throw $e27752776;
}
var $ret27812782 = $Hanf_arg114052791($z27772778,dummy_DASH_loc11796,name24432788,s_DASH_variant4732247,self24402789,with_DASH_members24452790);
++R.GAS;
return $ret27812782;
});
};
},{"length":6});
var anf_obj82102479 = R.makeMethod(function(self24462770) {
return function(l24472774,name24482756,with_DASH_members24492773) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[299],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129],[l24472774,name24482756,with_DASH_members24492773],[L[296],L[297],L[298]],function() {
var anf_fun82052753 = G(with_DASH_members24492773,"map",L[295]);
var anf_arg82082754 = R.makeFunction(function(recv_DASH_9932758) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[294],1,arguments);
}
var anf_fun82072769 = G(recv_DASH_9932758,"visit",L[294]);
var $z27612762 = D;
var $f27672768 = function(_) {
return R.isFunction(anf_fun82072769)?anf_fun82072769.app(self24462770):R.ffi.throwNonFunApp(L[294],anf_fun82072769,[self24462770]);
};
try {
if(--R.GAS > 0) {
$z27612762 = $f27672768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27672768,
"from":L[294]});
}
} catch($e27592760) {
if(R.isCont($e27592760)) {
var $ss27632764 = {"from":L[294],
"go":function(ann_DASH_check_DASH_temp82062771) {
return $Hann_DASH_check_DASH_temp114062772(ann_DASH_check_DASH_temp82062771);
}};
$e27592760.stack[R.EXN_STACKHEIGHT++] = $ss27632764;
}
if(R.isPyretException($e27592760)) {
$e27592760.pyretStack.push(L[294]);
}
throw $e27592760;
}
var $ret27652766 = $Hann_DASH_check_DASH_temp114062772($z27612762);
++R.GAS;
return $ret27652766;
});
var $z27452746 = D;
var $f27512752 = function(_) {
return R.isFunction(anf_fun82052753)?anf_fun82052753.app(anf_arg82082754):R.ffi.throwNonFunApp(L[293],anf_fun82052753,[anf_arg82082754]);
};
try {
if(--R.GAS > 0) {
$z27452746 = $f27512752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27512752,
"from":L[293]});
}
} catch($e27432744) {
if(R.isCont($e27432744)) {
var $ss27472748 = {"from":L[293],
"go":function(anf_arg82092755) {
return $Hanf_arg114082757(anf_arg82092755,dummy_DASH_loc11796,name24482756,s_DASH_singleton_DASH_variant4752251);
}};
$e27432744.stack[R.EXN_STACKHEIGHT++] = $ss27472748;
}
if(R.isPyretException($e27432744)) {
$e27432744.pyretStack.push(L[293]);
}
throw $e27432744;
}
var $ret27492750 = $Hanf_arg114082757($z27452746,dummy_DASH_loc11796,name24482756,s_DASH_singleton_DASH_variant4752251);
++R.GAS;
return $ret27492750;
});
};
},{"length":4});
var anf_obj82192480 = R.makeMethod(function(self24502725) {
return function(l24512742,name24522724,members24532741,constructor24542723) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[292],4,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,List17129,Constructor104107],[l24512742,name24522724,members24532741,constructor24542723],[L[288],L[289],L[290],L[291]],function() {
var anf_fun82122720 = G(members24532741,"map",L[287]);
var anf_arg82152721 = R.makeFunction(function(recv_DASH_9942727) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[286],1,arguments);
}
var anf_fun82142738 = G(recv_DASH_9942727,"visit",L[286]);
var $z27302731 = D;
var $f27362737 = function(_) {
return R.isFunction(anf_fun82142738)?anf_fun82142738.app(self24502725):R.ffi.throwNonFunApp(L[286],anf_fun82142738,[self24502725]);
};
try {
if(--R.GAS > 0) {
$z27302731 = $f27362737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27362737,
"from":L[286]});
}
} catch($e27282729) {
if(R.isCont($e27282729)) {
var $ss27322733 = {"from":L[286],
"go":function(ann_DASH_check_DASH_temp82132739) {
return $Hann_DASH_check_DASH_temp114092740(ann_DASH_check_DASH_temp82132739);
}};
$e27282729.stack[R.EXN_STACKHEIGHT++] = $ss27322733;
}
if(R.isPyretException($e27282729)) {
$e27282729.pyretStack.push(L[286]);
}
throw $e27282729;
}
var $ret27342735 = $Hann_DASH_check_DASH_temp114092740($z27302731);
++R.GAS;
return $ret27342735;
});
var $z27122713 = D;
var $f27182719 = function(_) {
return R.isFunction(anf_fun82122720)?anf_fun82122720.app(anf_arg82152721):R.ffi.throwNonFunApp(L[285],anf_fun82122720,[anf_arg82152721]);
};
try {
if(--R.GAS > 0) {
$z27122713 = $f27182719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27182719,
"from":L[285]});
}
} catch($e27102711) {
if(R.isCont($e27102711)) {
var $ss27142715 = {"from":L[285],
"go":function(anf_arg82162722) {
return $Hanf_arg114122726(anf_arg82162722,constructor24542723,dummy_DASH_loc11796,name24522724,s_DASH_datatype_DASH_variant4802261,self24502725);
}};
$e27102711.stack[R.EXN_STACKHEIGHT++] = $ss27142715;
}
if(R.isPyretException($e27102711)) {
$e27102711.pyretStack.push(L[285]);
}
throw $e27102711;
}
var $ret27162717 = $Hanf_arg114122726($z27122713,constructor24542723,dummy_DASH_loc11796,name24522724,s_DASH_datatype_DASH_variant4802261,self24502725);
++R.GAS;
return $ret27162717;
});
};
},{"length":5});
var anf_obj82232481 = R.makeMethod(function(self24552704) {
return function(l24562709,name24572706,constructor24582708) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[284],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Constructor104107],[l24562709,name24572706,constructor24582708],[L[281],L[282],L[283]],function() {
var anf_fun82212703 = G(constructor24582708,"visit",L[280]);
var $z26952696 = D;
var $f27012702 = function(_) {
return R.isFunction(anf_fun82212703)?anf_fun82212703.app(self24552704):R.ffi.throwNonFunApp(L[279],anf_fun82212703,[self24552704]);
};
try {
if(--R.GAS > 0) {
$z26952696 = $f27012702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27012702,
"from":L[279]});
}
} catch($e26932694) {
if(R.isCont($e26932694)) {
var $ss26972698 = {"from":L[279],
"go":function(anf_arg82222705) {
return $Hanf_arg114142707(anf_arg82222705,dummy_DASH_loc11796,name24572706,s_DASH_datatype_DASH_singleton_DASH_variant4822265);
}};
$e26932694.stack[R.EXN_STACKHEIGHT++] = $ss26972698;
}
if(R.isPyretException($e26932694)) {
$e26932694.pyretStack.push(L[279]);
}
throw $e26932694;
}
var $ret26992700 = $Hanf_arg114142707($z26952696,dummy_DASH_loc11796,name24572706,s_DASH_datatype_DASH_singleton_DASH_variant4822265);
++R.GAS;
return $ret26992700;
});
};
},{"length":4});
var anf_obj82272482 = R.makeMethod(function(self24592687) {
return function(l24602692,self_DASH_arg24612689,body24622691) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[278],3,arguments);
}
return R.checkAnnArgs([Loc116130,$type$String69,Expr86111],[l24602692,self_DASH_arg24612689,body24622691],[L[275],L[276],L[277]],function() {
var anf_fun82252686 = G(body24622691,"visit",L[274]);
var $z26782679 = D;
var $f26842685 = function(_) {
return R.isFunction(anf_fun82252686)?anf_fun82252686.app(self24592687):R.ffi.throwNonFunApp(L[273],anf_fun82252686,[self24592687]);
};
try {
if(--R.GAS > 0) {
$z26782679 = $f26842685();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26842685,
"from":L[273]});
}
} catch($e26762677) {
if(R.isCont($e26762677)) {
var $ss26802681 = {"from":L[273],
"go":function(anf_arg82262688) {
return $Hanf_arg114162690(anf_arg82262688,dummy_DASH_loc11796,s_DASH_datatype_DASH_constructor4872275,self_DASH_arg24612689);
}};
$e26762677.stack[R.EXN_STACKHEIGHT++] = $ss26802681;
}
if(R.isPyretException($e26762677)) {
$e26762677.pyretStack.push(L[273]);
}
throw $e26762677;
}
var $ret26822683 = $Hanf_arg114162690($z26782679,dummy_DASH_loc11796,s_DASH_datatype_DASH_constructor4872275,self_DASH_arg24612689);
++R.GAS;
return $ret26822683;
});
};
},{"length":4});
var anf_obj82292483 = R.makeMethod(function(self24632675) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[272],0,arguments);
}
var ann_DASH_check_DASH_temp82282674 = a_DASH_blank5072315.$var;
return ann_DASH_check_DASH_temp82282674;
};
},{"length":1});
var anf_obj82312484 = R.makeMethod(function(self24642673) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[271],0,arguments);
}
var ann_DASH_check_DASH_temp82302672 = a_DASH_any5092319.$var;
return ann_DASH_check_DASH_temp82302672;
};
},{"length":1});
var anf_obj82352485 = R.makeMethod(function(self24652667) {
return function(l24662671,id24672670) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[270],2,arguments);
}
var anf_fun82332666 = G(id24672670,"visit",L[269]);
var $z26582659 = D;
var $f26642665 = function(_) {
return R.isFunction(anf_fun82332666)?anf_fun82332666.app(self24652667):R.ffi.throwNonFunApp(L[268],anf_fun82332666,[self24652667]);
};
try {
if(--R.GAS > 0) {
$z26582659 = $f26642665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26642665,
"from":L[268]});
}
} catch($e26562657) {
if(R.isCont($e26562657)) {
var $ss26602661 = {"from":L[268],
"go":function(anf_arg82342668) {
return $Hanf_arg114182669(anf_arg82342668,a_DASH_name5112323,dummy_DASH_loc11796);
}};
$e26562657.stack[R.EXN_STACKHEIGHT++] = $ss26602661;
}
if(R.isPyretException($e26562657)) {
$e26562657.pyretStack.push(L[268]);
}
throw $e26562657;
}
var $ret26622663 = $Hanf_arg114182669($z26582659,a_DASH_name5112323,dummy_DASH_loc11796);
++R.GAS;
return $ret26622663;
};
},{"length":3});
var anf_obj82442486 = R.makeMethod(function(self24682637) {
return function(l24692655,args24702654,ret24712636,use_DASH_parens24722638) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[267],4,arguments);
}
var anf_fun82372633 = G(args24702654,"map",L[266]);
var anf_arg82402634 = R.makeFunction(function(recv_DASH_9952640) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[265],1,arguments);
}
var anf_fun82392651 = G(recv_DASH_9952640,"visit",L[265]);
var $z26432644 = D;
var $f26492650 = function(_) {
return R.isFunction(anf_fun82392651)?anf_fun82392651.app(self24682637):R.ffi.throwNonFunApp(L[265],anf_fun82392651,[self24682637]);
};
try {
if(--R.GAS > 0) {
$z26432644 = $f26492650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26492650,
"from":L[265]});
}
} catch($e26412642) {
if(R.isCont($e26412642)) {
var $ss26452646 = {"from":L[265],
"go":function(ann_DASH_check_DASH_temp82382652) {
return $Hann_DASH_check_DASH_temp114192653(ann_DASH_check_DASH_temp82382652);
}};
$e26412642.stack[R.EXN_STACKHEIGHT++] = $ss26452646;
}
if(R.isPyretException($e26412642)) {
$e26412642.pyretStack.push(L[265]);
}
throw $e26412642;
}
var $ret26472648 = $Hann_DASH_check_DASH_temp114192653($z26432644);
++R.GAS;
return $ret26472648;
});
var $z26252626 = D;
var $f26312632 = function(_) {
return R.isFunction(anf_fun82372633)?anf_fun82372633.app(anf_arg82402634):R.ffi.throwNonFunApp(L[264],anf_fun82372633,[anf_arg82402634]);
};
try {
if(--R.GAS > 0) {
$z26252626 = $f26312632();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26312632,
"from":L[264]});
}
} catch($e26232624) {
if(R.isCont($e26232624)) {
var $ss26272628 = {"from":L[264],
"go":function(anf_arg82412635) {
return $Hanf_arg114222639(anf_arg82412635,a_DASH_arrow5132327,dummy_DASH_loc11796,ret24712636,self24682637,use_DASH_parens24722638);
}};
$e26232624.stack[R.EXN_STACKHEIGHT++] = $ss26272628;
}
if(R.isPyretException($e26232624)) {
$e26232624.pyretStack.push(L[264]);
}
throw $e26232624;
}
var $ret26292630 = $Hanf_arg114222639($z26252626,a_DASH_arrow5132327,dummy_DASH_loc11796,ret24712636,self24682637,use_DASH_parens24722638);
++R.GAS;
return $ret26292630;
};
},{"length":5});
var anf_obj82532487 = R.makeMethod(function(self24732605) {
return function(l24742622,args24752621,ret24762604) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[263],3,arguments);
}
var anf_fun82462601 = G(args24752621,"map",L[262]);
var anf_arg82492602 = R.makeFunction(function(recv_DASH_9962607) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[261],1,arguments);
}
var anf_fun82482618 = G(recv_DASH_9962607,"visit",L[261]);
var $z26102611 = D;
var $f26162617 = function(_) {
return R.isFunction(anf_fun82482618)?anf_fun82482618.app(self24732605):R.ffi.throwNonFunApp(L[261],anf_fun82482618,[self24732605]);
};
try {
if(--R.GAS > 0) {
$z26102611 = $f26162617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26162617,
"from":L[261]});
}
} catch($e26082609) {
if(R.isCont($e26082609)) {
var $ss26122613 = {"from":L[261],
"go":function(ann_DASH_check_DASH_temp82472619) {
return $Hann_DASH_check_DASH_temp114232620(ann_DASH_check_DASH_temp82472619);
}};
$e26082609.stack[R.EXN_STACKHEIGHT++] = $ss26122613;
}
if(R.isPyretException($e26082609)) {
$e26082609.pyretStack.push(L[261]);
}
throw $e26082609;
}
var $ret26142615 = $Hann_DASH_check_DASH_temp114232620($z26102611);
++R.GAS;
return $ret26142615;
});
var $z25932594 = D;
var $f25992600 = function(_) {
return R.isFunction(anf_fun82462601)?anf_fun82462601.app(anf_arg82492602):R.ffi.throwNonFunApp(L[260],anf_fun82462601,[anf_arg82492602]);
};
try {
if(--R.GAS > 0) {
$z25932594 = $f25992600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25992600,
"from":L[260]});
}
} catch($e25912592) {
if(R.isCont($e25912592)) {
var $ss25952596 = {"from":L[260],
"go":function(anf_arg82502603) {
return $Hanf_arg114262606(anf_arg82502603,a_DASH_method5152331,dummy_DASH_loc11796,ret24762604,self24732605);
}};
$e25912592.stack[R.EXN_STACKHEIGHT++] = $ss25952596;
}
if(R.isPyretException($e25912592)) {
$e25912592.pyretStack.push(L[260]);
}
throw $e25912592;
}
var $ret25972598 = $Hanf_arg114262606($z25932594,a_DASH_method5152331,dummy_DASH_loc11796,ret24762604,self24732605);
++R.GAS;
return $ret25972598;
};
},{"length":4});
var anf_obj82602488 = R.makeMethod(function(self24772586) {
return function(l24782590,fields24792589) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[259],2,arguments);
}
var anf_fun82552570 = G(fields24792589,"map",L[258]);
var anf_arg82582571 = R.makeFunction(function(recv_DASH_9972574) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[257],1,arguments);
}
var anf_fun82572585 = G(recv_DASH_9972574,"visit",L[257]);
var $z25772578 = D;
var $f25832584 = function(_) {
return R.isFunction(anf_fun82572585)?anf_fun82572585.app(self24772586):R.ffi.throwNonFunApp(L[257],anf_fun82572585,[self24772586]);
};
try {
if(--R.GAS > 0) {
$z25772578 = $f25832584();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25832584,
"from":L[257]});
}
} catch($e25752576) {
if(R.isCont($e25752576)) {
var $ss25792580 = {"from":L[257],
"go":function(ann_DASH_check_DASH_temp82562587) {
return $Hann_DASH_check_DASH_temp114272588(ann_DASH_check_DASH_temp82562587);
}};
$e25752576.stack[R.EXN_STACKHEIGHT++] = $ss25792580;
}
if(R.isPyretException($e25752576)) {
$e25752576.pyretStack.push(L[257]);
}
throw $e25752576;
}
var $ret25812582 = $Hann_DASH_check_DASH_temp114272588($z25772578);
++R.GAS;
return $ret25812582;
});
var $z25622563 = D;
var $f25682569 = function(_) {
return R.isFunction(anf_fun82552570)?anf_fun82552570.app(anf_arg82582571):R.ffi.throwNonFunApp(L[256],anf_fun82552570,[anf_arg82582571]);
};
try {
if(--R.GAS > 0) {
$z25622563 = $f25682569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25682569,
"from":L[256]});
}
} catch($e25602561) {
if(R.isCont($e25602561)) {
var $ss25642565 = {"from":L[256],
"go":function(anf_arg82592572) {
return $Hanf_arg114292573(anf_arg82592572,a_DASH_record5172335,dummy_DASH_loc11796);
}};
$e25602561.stack[R.EXN_STACKHEIGHT++] = $ss25642565;
}
if(R.isPyretException($e25602561)) {
$e25602561.pyretStack.push(L[256]);
}
throw $e25602561;
}
var $ret25662567 = $Hanf_arg114292573($z25622563,a_DASH_record5172335,dummy_DASH_loc11796);
++R.GAS;
return $ret25662567;
};
},{"length":3});
var anf_obj82692489 = R.makeMethod(function(self24802554) {
return function(l24812559,ann24822558,args24832556) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[255],3,arguments);
}
var anf_fun82622553 = G(ann24822558,"visit",L[254]);
var $z25452546 = D;
var $f25512552 = function(_) {
return R.isFunction(anf_fun82622553)?anf_fun82622553.app(self24802554):R.ffi.throwNonFunApp(L[253],anf_fun82622553,[self24802554]);
};
try {
if(--R.GAS > 0) {
$z25452546 = $f25512552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25512552,
"from":L[253]});
}
} catch($e25432544) {
if(R.isCont($e25432544)) {
var $ss25472548 = {"from":L[253],
"go":function(anf_arg82632555) {
return $Hanf_arg114332557(anf_arg82632555,a_DASH_app5192339,args24832556,dummy_DASH_loc11796,self24802554);
}};
$e25432544.stack[R.EXN_STACKHEIGHT++] = $ss25472548;
}
if(R.isPyretException($e25432544)) {
$e25432544.pyretStack.push(L[253]);
}
throw $e25432544;
}
var $ret25492550 = $Hanf_arg114332557($z25452546,a_DASH_app5192339,args24832556,dummy_DASH_loc11796,self24802554);
++R.GAS;
return $ret25492550;
};
},{"length":4});
var anf_obj82752490 = R.makeMethod(function(self24842537) {
return function(l24852542,ann24862541,exp24872539) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[252],3,arguments);
}
var anf_fun82712536 = G(ann24862541,"visit",L[251]);
var $z25282529 = D;
var $f25342535 = function(_) {
return R.isFunction(anf_fun82712536)?anf_fun82712536.app(self24842537):R.ffi.throwNonFunApp(L[250],anf_fun82712536,[self24842537]);
};
try {
if(--R.GAS > 0) {
$z25282529 = $f25342535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25342535,
"from":L[250]});
}
} catch($e25262527) {
if(R.isCont($e25262527)) {
var $ss25302531 = {"from":L[250],
"go":function(anf_arg82722538) {
return $Hanf_arg114362540(anf_arg82722538,a_DASH_pred5212343,dummy_DASH_loc11796,exp24872539,self24842537);
}};
$e25262527.stack[R.EXN_STACKHEIGHT++] = $ss25302531;
}
if(R.isPyretException($e25262527)) {
$e25262527.pyretStack.push(L[250]);
}
throw $e25262527;
}
var $ret25322533 = $Hanf_arg114362540($z25282529,a_DASH_pred5212343,dummy_DASH_loc11796,exp24872539,self24842537);
++R.GAS;
return $ret25322533;
};
},{"length":4});
var anf_obj82772491 = R.makeMethod(function(self24882524) {
return function(l24892525,obj24902520,field24912521) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[249],3,arguments);
}
var $z25122513 = D;
var $f25182519 = function(_) {
return R.isFunction(a_DASH_dot5232347.$var)?a_DASH_dot5232347.$var.app(dummy_DASH_loc11796,obj24902520,field24912521):R.ffi.throwNonFunApp(L[249],a_DASH_dot5232347.$var,[dummy_DASH_loc11796,obj24902520,field24912521]);
};
try {
if(--R.GAS > 0) {
$z25122513 = $f25182519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25182519,
"from":L[249]});
}
} catch($e25102511) {
if(R.isCont($e25102511)) {
var $ss25142515 = {"from":L[249],
"go":function(ann_DASH_check_DASH_temp82762522) {
return $Hann_DASH_check_DASH_temp114372523(ann_DASH_check_DASH_temp82762522);
}};
$e25102511.stack[R.EXN_STACKHEIGHT++] = $ss25142515;
}
if(R.isPyretException($e25102511)) {
$e25102511.pyretStack.push(L[249]);
}
throw $e25102511;
}
var $ret25162517 = $Hann_DASH_check_DASH_temp114372523($z25122513);
++R.GAS;
return $ret25162517;
};
},{"length":4});
var anf_obj82832492 = R.makeMethod(function(self24922504) {
return function(l24932509,name24942508,ann24952506) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[248],3,arguments);
}
var anf_fun82792503 = G(name24942508,"visit",L[247]);
var $z24952496 = D;
var $f25012502 = function(_) {
return R.isFunction(anf_fun82792503)?anf_fun82792503.app(self24922504):R.ffi.throwNonFunApp(L[246],anf_fun82792503,[self24922504]);
};
try {
if(--R.GAS > 0) {
$z24952496 = $f25012502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25012502,
"from":L[246]});
}
} catch($e24932494) {
if(R.isCont($e24932494)) {
var $ss24972498 = {"from":L[246],
"go":function(anf_arg82802505) {
return $Hanf_arg114402507(anf_arg82802505,a_DASH_field5282357,ann24952506,dummy_DASH_loc11796,self24922504);
}};
$e24932494.stack[R.EXN_STACKHEIGHT++] = $ss24972498;
}
if(R.isPyretException($e24932494)) {
$e24932494.pyretStack.push(L[246]);
}
throw $e24932494;
}
var $ret24992500 = $Hanf_arg114402507($z24952496,a_DASH_field5282357,ann24952506,dummy_DASH_loc11796,self24922504);
++R.GAS;
return $ret24992500;
};
},{"length":4});
var dummy_DASH_loc_DASH_visitor20802389 = R.makeObject({"option":anf_obj76062390,
"s-underscore":anf_obj76082391,
"s-name":anf_obj76102392,
"s-global":anf_obj76122393,
"s-type-global":anf_obj76142394,
"s-atom":anf_obj76162395,
"s-module":anf_obj76292396,
"s-program":anf_obj76422397,
"s-file-import":anf_obj76442398,
"s-const-import":anf_obj76462399,
"s-import":anf_obj76522400,
"s-import-types":anf_obj76602401,
"s-import-fields":anf_obj76692402,
"s-provide":anf_obj76732403,
"s-provide-all":anf_obj76752404,
"s-provide-none":anf_obj76772405,
"s-provide-types":anf_obj76842406,
"s-provide-types-all":anf_obj76862407,
"s-provide-types-none":anf_obj76882408,
"s-bind":anf_obj76942409,
"s-var-bind":anf_obj77002410,
"s-let-bind":anf_obj77062411,
"s-type-bind":anf_obj77082412,
"s-newtype-bind":anf_obj77142413,
"s-type-let-expr":anf_obj77232414,
"s-let-expr":anf_obj77322415,
"s-letrec-bind":anf_obj77382416,
"s-letrec":anf_obj77472417,
"s-hint-exp":anf_obj77512418,
"s-instantiate":anf_obj77602419,
"s-block":anf_obj77672420,
"s-user-block":anf_obj77712421,
"s-fun":anf_obj77892422,
"s-type":anf_obj77952423,
"s-newtype":anf_obj78012424,
"s-var":anf_obj78072425,
"s-let":anf_obj78132426,
"s-graph":anf_obj78202427,
"s-when":anf_obj78262428,
"s-contract":anf_obj78322429,
"s-assign":anf_obj78382430,
"s-if-branch":anf_obj78442431,
"s-if-pipe-branch":anf_obj78502432,
"s-if":anf_obj78572433,
"s-if-else":anf_obj78662434,
"s-if-pipe":anf_obj78732435,
"s-if-pipe-else":anf_obj78822436,
"s-cases-branch":anf_obj78912437,
"s-cases":anf_obj79022438,
"s-cases-else":anf_obj79152439,
"s-try":anf_obj79232440,
"s-op":anf_obj79292441,
"s-check-test":anf_obj79352442,
"s-paren":anf_obj79392443,
"s-lam":anf_obj79572444,
"s-method":anf_obj79702445,
"s-extend":anf_obj79792446,
"s-update":anf_obj79882447,
"s-obj":anf_obj79952448,
"s-array":anf_obj80022449,
"s-bless":anf_obj80082450,
"s-confirm":anf_obj80142451,
"s-construct":anf_obj80232452,
"s-app":anf_obj80322453,
"s-prim-app":anf_obj80392454,
"s-prim-val":anf_obj80412455,
"s-id":anf_obj80452456,
"s-id-var":anf_obj80492457,
"s-id-letrec":anf_obj80532458,
"s-undefined":anf_obj80552459,
"s-srcloc":anf_obj80572460,
"s-num":anf_obj80592461,
"s-frac":anf_obj80612462,
"s-bool":anf_obj80632463,
"s-str":anf_obj80652464,
"s-dot":anf_obj80692465,
"s-get-bang":anf_obj80732466,
"s-bracket":anf_obj80792467,
"s-data":anf_obj81032468,
"s-data-expr":anf_obj81292469,
"s-for":anf_obj81422470,
"s-check":anf_obj81462471,
"s-data-field":anf_obj81522472,
"s-mutable-field":anf_obj81602473,
"s-once-field":anf_obj81682474,
"s-method-field":anf_obj81812475,
"s-for-bind":anf_obj81872476,
"s-variant-member":anf_obj81912477,
"s-variant":anf_obj82032478,
"s-singleton-variant":anf_obj82102479,
"s-datatype-variant":anf_obj82192480,
"s-datatype-singleton-variant":anf_obj82232481,
"s-datatype-constructor":anf_obj82272482,
"a-blank":anf_obj82292483,
"a-any":anf_obj82312484,
"a-name":anf_obj82352485,
"a-arrow":anf_obj82442486,
"a-method":anf_obj82532487,
"a-record":anf_obj82602488,
"a-app":anf_obj82692489,
"a-pred":anf_obj82752490,
"a-dot":anf_obj82772491,
"a-field":anf_obj82832492});
var provides82842385 = R.makeObject({"dummy-loc":dummy_DASH_loc11796,
"INDENT":INDENT118169,
"break-one":break_DASH_one119168,
"str-any":str_DASH_any120182,
"str-arrow":str_DASH_arrow121195,
"str-arrowspace":str_DASH_arrowspace122208,
"str-as":str_DASH_as123221,
"str-blank":str_DASH_blank124234,
"str-let":str_DASH_let125247,
"str-type-let":str_DASH_type_DASH_let126260,
"str-letrec":str_DASH_letrec127273,
"str-block":str_DASH_block128286,
"str-brackets":str_DASH_brackets129299,
"str-cases":str_DASH_cases130312,
"str-caret":str_DASH_caret131325,
"str-checkcolon":str_DASH_checkcolon132338,
"str-examplescolon":str_DASH_examplescolon133351,
"str-colon":str_DASH_colon134364,
"str-coloncolon":str_DASH_coloncolon135377,
"str-colonspace":str_DASH_colonspace136390,
"str-comment":str_DASH_comment137403,
"str-constructor":str_DASH_constructor138416,
"str-data":str_DASH_data139429,
"str-data-expr":str_DASH_data_DASH_expr140442,
"str-datatype":str_DASH_datatype141455,
"str-deriving":str_DASH_deriving142468,
"str-doc":str_DASH_doc143481,
"str-elsebranch":str_DASH_elsebranch144494,
"str-elsecolon":str_DASH_elsecolon145507,
"str-otherwisecolon":str_DASH_otherwisecolon146520,
"str-elsespace":str_DASH_elsespace147533,
"str-end":str_DASH_end148546,
"str-except":str_DASH_except149559,
"str-for":str_DASH_for150572,
"str-from":str_DASH_from151585,
"str-fun":str_DASH_fun152598,
"str-lam":str_DASH_lam153611,
"str-graph":str_DASH_graph154624,
"str-if":str_DASH_if155637,
"str-askcolon":str_DASH_askcolon156650,
"str-import":str_DASH_import157663,
"str-method":str_DASH_method158676,
"str-mutable":str_DASH_mutable159689,
"str-period":str_DASH_period160702,
"str-bang":str_DASH_bang161715,
"str-pipespace":str_DASH_pipespace162728,
"str-provide":str_DASH_provide163741,
"str-provide-types":str_DASH_provide_DASH_types164754,
"str-provide-star":str_DASH_provide_DASH_star165767,
"str-provide-types-star":str_DASH_provide_DASH_types_DASH_star166780,
"str-sharing":str_DASH_sharing167793,
"str-space":str_DASH_space168806,
"str-spacecolonequal":str_DASH_spacecolonequal169819,
"str-spaceequal":str_DASH_spaceequal170832,
"str-thencolon":str_DASH_thencolon171845,
"str-thickarrow":str_DASH_thickarrow172858,
"str-try":str_DASH_try173871,
"str-use-loc":str_DASH_use_DASH_loc174884,
"str-var":str_DASH_var175897,
"str-newtype":str_DASH_newtype176910,
"str-type":str_DASH_type177923,
"str-bless":str_DASH_bless178936,
"str-confirm":str_DASH_confirm179949,
"str-val":str_DASH_val180962,
"str-when":str_DASH_when181975,
"str-where":str_DASH_where182988,
"str-with":str_DASH_with1831001,
"Name":Name1851005.$var,
"is-Name":is_DASH_Name1861007.$var,
"s-underscore":s_DASH_underscore1881011.$var,
"is-s-underscore":is_DASH_s_DASH_underscore1871009.$var,
"s-name":s_DASH_name1901015.$var,
"is-s-name":is_DASH_s_DASH_name1891013.$var,
"s-global":s_DASH_global1921019.$var,
"is-s-global":is_DASH_s_DASH_global1911017.$var,
"s-type-global":s_DASH_type_DASH_global1941023.$var,
"is-s-type-global":is_DASH_s_DASH_type_DASH_global1931021.$var,
"s-atom":s_DASH_atom1961027.$var,
"is-s-atom":is_DASH_s_DASH_atom1951025.$var,
"MakeName":MakeName1971029.$var,
"global-names":global_DASH_names2491041,
"funlam-tosource":funlam_DASH_tosource2501801.$var,
"Program":Program2521805.$var,
"is-Program":is_DASH_Program2531807.$var,
"s-program":s_DASH_program2551811.$var,
"is-s-program":is_DASH_s_DASH_program2541809.$var,
"Import":Import2571815.$var,
"is-Import":is_DASH_Import2581817.$var,
"s-import":s_DASH_import2601821.$var,
"is-s-import":is_DASH_s_DASH_import2591819.$var,
"s-import-types":s_DASH_import_DASH_types2621825.$var,
"is-s-import-types":is_DASH_s_DASH_import_DASH_types2611823.$var,
"s-import-fields":s_DASH_import_DASH_fields2641829.$var,
"is-s-import-fields":is_DASH_s_DASH_import_DASH_fields2631827.$var,
"Provide":Provide2661833.$var,
"is-Provide":is_DASH_Provide2671835.$var,
"s-provide":s_DASH_provide2691839.$var,
"is-s-provide":is_DASH_s_DASH_provide2681837.$var,
"s-provide-all":s_DASH_provide_DASH_all2711843.$var,
"is-s-provide-all":is_DASH_s_DASH_provide_DASH_all2701841.$var,
"s-provide-none":s_DASH_provide_DASH_none2731847.$var,
"is-s-provide-none":is_DASH_s_DASH_provide_DASH_none2721845.$var,
"ProvideTypes":ProvideTypes2751851.$var,
"is-ProvideTypes":is_DASH_ProvideTypes2761853.$var,
"s-provide-types":s_DASH_provide_DASH_types2781857.$var,
"is-s-provide-types":is_DASH_s_DASH_provide_DASH_types2771855.$var,
"s-provide-types-all":s_DASH_provide_DASH_types_DASH_all2801861.$var,
"is-s-provide-types-all":is_DASH_s_DASH_provide_DASH_types_DASH_all2791859.$var,
"s-provide-types-none":s_DASH_provide_DASH_types_DASH_none2821865.$var,
"is-s-provide-types-none":is_DASH_s_DASH_provide_DASH_types_DASH_none2811863.$var,
"ImportType":ImportType2841869.$var,
"is-ImportType":is_DASH_ImportType2851871.$var,
"s-file-import":s_DASH_file_DASH_import2871875.$var,
"is-s-file-import":is_DASH_s_DASH_file_DASH_import2861873.$var,
"s-const-import":s_DASH_const_DASH_import2891879.$var,
"is-s-const-import":is_DASH_s_DASH_const_DASH_import2881877.$var,
"Hint":Hint2911883.$var,
"is-Hint":is_DASH_Hint2921885.$var,
"h-use-loc":h_DASH_use_DASH_loc2941889.$var,
"is-h-use-loc":is_DASH_h_DASH_use_DASH_loc2931887.$var,
"LetBind":LetBind2961893.$var,
"is-LetBind":is_DASH_LetBind2971895.$var,
"s-let-bind":s_DASH_let_DASH_bind2991899.$var,
"is-s-let-bind":is_DASH_s_DASH_let_DASH_bind2981897.$var,
"s-var-bind":s_DASH_var_DASH_bind3011903.$var,
"is-s-var-bind":is_DASH_s_DASH_var_DASH_bind3001901.$var,
"LetrecBind":LetrecBind3031907.$var,
"is-LetrecBind":is_DASH_LetrecBind3041909.$var,
"s-letrec-bind":s_DASH_letrec_DASH_bind3061913.$var,
"is-s-letrec-bind":is_DASH_s_DASH_letrec_DASH_bind3051911.$var,
"TypeLetBind":TypeLetBind3081917.$var,
"is-TypeLetBind":is_DASH_TypeLetBind3091919.$var,
"s-type-bind":s_DASH_type_DASH_bind3111923.$var,
"is-s-type-bind":is_DASH_s_DASH_type_DASH_bind3101921.$var,
"s-newtype-bind":s_DASH_newtype_DASH_bind3131927.$var,
"is-s-newtype-bind":is_DASH_s_DASH_newtype_DASH_bind3121925.$var,
"Expr":Expr3151931.$var,
"is-Expr":is_DASH_Expr3161933.$var,
"s-module":s_DASH_module3181937.$var,
"is-s-module":is_DASH_s_DASH_module3171935.$var,
"s-type-let-expr":s_DASH_type_DASH_let_DASH_expr3201941.$var,
"is-s-type-let-expr":is_DASH_s_DASH_type_DASH_let_DASH_expr3191939.$var,
"s-let-expr":s_DASH_let_DASH_expr3221945.$var,
"is-s-let-expr":is_DASH_s_DASH_let_DASH_expr3211943.$var,
"s-letrec":s_DASH_letrec3241949.$var,
"is-s-letrec":is_DASH_s_DASH_letrec3231947.$var,
"s-hint-exp":s_DASH_hint_DASH_exp3261953.$var,
"is-s-hint-exp":is_DASH_s_DASH_hint_DASH_exp3251951.$var,
"s-instantiate":s_DASH_instantiate3281957.$var,
"is-s-instantiate":is_DASH_s_DASH_instantiate3271955.$var,
"s-block":s_DASH_block3301961.$var,
"is-s-block":is_DASH_s_DASH_block3291959.$var,
"s-user-block":s_DASH_user_DASH_block3321965.$var,
"is-s-user-block":is_DASH_s_DASH_user_DASH_block3311963.$var,
"s-fun":s_DASH_fun3341969.$var,
"is-s-fun":is_DASH_s_DASH_fun3331967.$var,
"s-type":s_DASH_type3361973.$var,
"is-s-type":is_DASH_s_DASH_type3351971.$var,
"s-newtype":s_DASH_newtype3381977.$var,
"is-s-newtype":is_DASH_s_DASH_newtype3371975.$var,
"s-var":s_DASH_var3401981.$var,
"is-s-var":is_DASH_s_DASH_var3391979.$var,
"s-let":s_DASH_let3421985.$var,
"is-s-let":is_DASH_s_DASH_let3411983.$var,
"s-graph":s_DASH_graph3441989.$var,
"is-s-graph":is_DASH_s_DASH_graph3431987.$var,
"s-contract":s_DASH_contract3461993.$var,
"is-s-contract":is_DASH_s_DASH_contract3451991.$var,
"s-when":s_DASH_when3481997.$var,
"is-s-when":is_DASH_s_DASH_when3471995.$var,
"s-assign":s_DASH_assign3502001.$var,
"is-s-assign":is_DASH_s_DASH_assign3491999.$var,
"s-if-pipe":s_DASH_if_DASH_pipe3522005.$var,
"is-s-if-pipe":is_DASH_s_DASH_if_DASH_pipe3512003.$var,
"s-if-pipe-else":s_DASH_if_DASH_pipe_DASH_else3542009.$var,
"is-s-if-pipe-else":is_DASH_s_DASH_if_DASH_pipe_DASH_else3532007.$var,
"s-if":s_DASH_if3562013.$var,
"is-s-if":is_DASH_s_DASH_if3552011.$var,
"s-if-else":s_DASH_if_DASH_else3582017.$var,
"is-s-if-else":is_DASH_s_DASH_if_DASH_else3572015.$var,
"s-cases":s_DASH_cases3602021.$var,
"is-s-cases":is_DASH_s_DASH_cases3592019.$var,
"s-cases-else":s_DASH_cases_DASH_else3622025.$var,
"is-s-cases-else":is_DASH_s_DASH_cases_DASH_else3612023.$var,
"s-try":s_DASH_try3642029.$var,
"is-s-try":is_DASH_s_DASH_try3632027.$var,
"s-op":s_DASH_op3662033.$var,
"is-s-op":is_DASH_s_DASH_op3652031.$var,
"s-check-test":s_DASH_check_DASH_test3682037.$var,
"is-s-check-test":is_DASH_s_DASH_check_DASH_test3672035.$var,
"s-paren":s_DASH_paren3702041.$var,
"is-s-paren":is_DASH_s_DASH_paren3692039.$var,
"s-lam":s_DASH_lam3722045.$var,
"is-s-lam":is_DASH_s_DASH_lam3712043.$var,
"s-method":s_DASH_method3742049.$var,
"is-s-method":is_DASH_s_DASH_method3732047.$var,
"s-extend":s_DASH_extend3762053.$var,
"is-s-extend":is_DASH_s_DASH_extend3752051.$var,
"s-update":s_DASH_update3782057.$var,
"is-s-update":is_DASH_s_DASH_update3772055.$var,
"s-obj":s_DASH_obj3802061.$var,
"is-s-obj":is_DASH_s_DASH_obj3792059.$var,
"s-array":s_DASH_array3822065.$var,
"is-s-array":is_DASH_s_DASH_array3812063.$var,
"s-construct":s_DASH_construct3842069.$var,
"is-s-construct":is_DASH_s_DASH_construct3832067.$var,
"s-confirm":s_DASH_confirm3862073.$var,
"is-s-confirm":is_DASH_s_DASH_confirm3852071.$var,
"s-bless":s_DASH_bless3882077.$var,
"is-s-bless":is_DASH_s_DASH_bless3872075.$var,
"s-app":s_DASH_app3902081.$var,
"is-s-app":is_DASH_s_DASH_app3892079.$var,
"s-prim-app":s_DASH_prim_DASH_app3922085.$var,
"is-s-prim-app":is_DASH_s_DASH_prim_DASH_app3912083.$var,
"s-prim-val":s_DASH_prim_DASH_val3942089.$var,
"is-s-prim-val":is_DASH_s_DASH_prim_DASH_val3932087.$var,
"s-id":s_DASH_id3962093.$var,
"is-s-id":is_DASH_s_DASH_id3952091.$var,
"s-id-var":s_DASH_id_DASH_var3982097.$var,
"is-s-id-var":is_DASH_s_DASH_id_DASH_var3972095.$var,
"s-id-letrec":s_DASH_id_DASH_letrec4002101.$var,
"is-s-id-letrec":is_DASH_s_DASH_id_DASH_letrec3992099.$var,
"s-undefined":s_DASH_undefined4022105.$var,
"is-s-undefined":is_DASH_s_DASH_undefined4012103.$var,
"s-srcloc":s_DASH_srcloc4042109.$var,
"is-s-srcloc":is_DASH_s_DASH_srcloc4032107.$var,
"s-num":s_DASH_num4062113.$var,
"is-s-num":is_DASH_s_DASH_num4052111.$var,
"s-frac":s_DASH_frac4082117.$var,
"is-s-frac":is_DASH_s_DASH_frac4072115.$var,
"s-bool":s_DASH_bool4102121.$var,
"is-s-bool":is_DASH_s_DASH_bool4092119.$var,
"s-str":s_DASH_str4122125.$var,
"is-s-str":is_DASH_s_DASH_str4112123.$var,
"s-dot":s_DASH_dot4142129.$var,
"is-s-dot":is_DASH_s_DASH_dot4132127.$var,
"s-get-bang":s_DASH_get_DASH_bang4162133.$var,
"is-s-get-bang":is_DASH_s_DASH_get_DASH_bang4152131.$var,
"s-bracket":s_DASH_bracket4182137.$var,
"is-s-bracket":is_DASH_s_DASH_bracket4172135.$var,
"s-data":s_DASH_data4202141.$var,
"is-s-data":is_DASH_s_DASH_data4192139.$var,
"s-data-expr":s_DASH_data_DASH_expr4222145.$var,
"is-s-data-expr":is_DASH_s_DASH_data_DASH_expr4212143.$var,
"s-for":s_DASH_for4242149.$var,
"is-s-for":is_DASH_s_DASH_for4232147.$var,
"s-check":s_DASH_check4262153.$var,
"is-s-check":is_DASH_s_DASH_check4252151.$var,
"ConstructModifier":ConstructModifier4282157.$var,
"is-ConstructModifier":is_DASH_ConstructModifier4292159.$var,
"s-construct-normal":s_DASH_construct_DASH_normal4312163.$var,
"is-s-construct-normal":is_DASH_s_DASH_construct_DASH_normal4302161.$var,
"s-construct-lazy":s_DASH_construct_DASH_lazy4332167.$var,
"is-s-construct-lazy":is_DASH_s_DASH_construct_DASH_lazy4322165.$var,
"Bind":Bind4352171.$var,
"is-Bind":is_DASH_Bind4362173.$var,
"s-bind":s_DASH_bind4382177.$var,
"is-s-bind":is_DASH_s_DASH_bind4372175.$var,
"Member":Member4402181.$var,
"is-Member":is_DASH_Member4412183.$var,
"s-data-field":s_DASH_data_DASH_field4432187.$var,
"is-s-data-field":is_DASH_s_DASH_data_DASH_field4422185.$var,
"s-mutable-field":s_DASH_mutable_DASH_field4452191.$var,
"is-s-mutable-field":is_DASH_s_DASH_mutable_DASH_field4442189.$var,
"s-once-field":s_DASH_once_DASH_field4472195.$var,
"is-s-once-field":is_DASH_s_DASH_once_DASH_field4462193.$var,
"s-method-field":s_DASH_method_DASH_field4492199.$var,
"is-s-method-field":is_DASH_s_DASH_method_DASH_field4482197.$var,
"ForBind":ForBind4512203.$var,
"is-ForBind":is_DASH_ForBind4522205.$var,
"s-for-bind":s_DASH_for_DASH_bind4542209.$var,
"is-s-for-bind":is_DASH_s_DASH_for_DASH_bind4532207.$var,
"VariantMemberType":VariantMemberType4562213.$var,
"is-VariantMemberType":is_DASH_VariantMemberType4572215.$var,
"s-normal":s_DASH_normal4592219.$var,
"is-s-normal":is_DASH_s_DASH_normal4582217.$var,
"s-cyclic":s_DASH_cyclic4612223.$var,
"is-s-cyclic":is_DASH_s_DASH_cyclic4602221.$var,
"s-mutable":s_DASH_mutable4632227.$var,
"is-s-mutable":is_DASH_s_DASH_mutable4622225.$var,
"VariantMember":VariantMember4652231.$var,
"is-VariantMember":is_DASH_VariantMember4662233.$var,
"s-variant-member":s_DASH_variant_DASH_member4682237.$var,
"is-s-variant-member":is_DASH_s_DASH_variant_DASH_member4672235.$var,
"Variant":Variant4702241.$var,
"is-Variant":is_DASH_Variant4712243.$var,
"s-variant":s_DASH_variant4732247.$var,
"is-s-variant":is_DASH_s_DASH_variant4722245.$var,
"s-singleton-variant":s_DASH_singleton_DASH_variant4752251.$var,
"is-s-singleton-variant":is_DASH_s_DASH_singleton_DASH_variant4742249.$var,
"DatatypeVariant":DatatypeVariant4772255.$var,
"is-DatatypeVariant":is_DASH_DatatypeVariant4782257.$var,
"s-datatype-variant":s_DASH_datatype_DASH_variant4802261.$var,
"is-s-datatype-variant":is_DASH_s_DASH_datatype_DASH_variant4792259.$var,
"s-datatype-singleton-variant":s_DASH_datatype_DASH_singleton_DASH_variant4822265.$var,
"is-s-datatype-singleton-variant":is_DASH_s_DASH_datatype_DASH_singleton_DASH_variant4812263.$var,
"Constructor":Constructor4842269.$var,
"is-Constructor":is_DASH_Constructor4852271.$var,
"s-datatype-constructor":s_DASH_datatype_DASH_constructor4872275.$var,
"is-s-datatype-constructor":is_DASH_s_DASH_datatype_DASH_constructor4862273.$var,
"IfBranch":IfBranch4892279.$var,
"is-IfBranch":is_DASH_IfBranch4902281.$var,
"s-if-branch":s_DASH_if_DASH_branch4922285.$var,
"is-s-if-branch":is_DASH_s_DASH_if_DASH_branch4912283.$var,
"IfPipeBranch":IfPipeBranch4942289.$var,
"is-IfPipeBranch":is_DASH_IfPipeBranch4952291.$var,
"s-if-pipe-branch":s_DASH_if_DASH_pipe_DASH_branch4972295.$var,
"is-s-if-pipe-branch":is_DASH_s_DASH_if_DASH_pipe_DASH_branch4962293.$var,
"CasesBranch":CasesBranch4992299.$var,
"is-CasesBranch":is_DASH_CasesBranch5002301.$var,
"s-cases-branch":s_DASH_cases_DASH_branch5022305.$var,
"is-s-cases-branch":is_DASH_s_DASH_cases_DASH_branch5012303.$var,
"Ann":Ann5042309.$var,
"is-Ann":is_DASH_Ann5052311.$var,
"a-blank":a_DASH_blank5072315.$var,
"is-a-blank":is_DASH_a_DASH_blank5062313.$var,
"a-any":a_DASH_any5092319.$var,
"is-a-any":is_DASH_a_DASH_any5082317.$var,
"a-name":a_DASH_name5112323.$var,
"is-a-name":is_DASH_a_DASH_name5102321.$var,
"a-arrow":a_DASH_arrow5132327.$var,
"is-a-arrow":is_DASH_a_DASH_arrow5122325.$var,
"a-method":a_DASH_method5152331.$var,
"is-a-method":is_DASH_a_DASH_method5142329.$var,
"a-record":a_DASH_record5172335.$var,
"is-a-record":is_DASH_a_DASH_record5162333.$var,
"a-app":a_DASH_app5192339.$var,
"is-a-app":is_DASH_a_DASH_app5182337.$var,
"a-pred":a_DASH_pred5212343.$var,
"is-a-pred":is_DASH_a_DASH_pred5202341.$var,
"a-dot":a_DASH_dot5232347.$var,
"is-a-dot":is_DASH_a_DASH_dot5222345.$var,
"AField":AField5252351.$var,
"is-AField":is_DASH_AField5262353.$var,
"a-field":a_DASH_field5282357.$var,
"is-a-field":is_DASH_a_DASH_field5272355.$var,
"make-checker-name":make_DASH_checker_DASH_name5292359.$var,
"flatten":flatten5302361.$var,
"binding-type-ids":binding_DASH_type_DASH_ids5312363.$var,
"block-type-ids":block_DASH_type_DASH_ids5322365.$var,
"binding-ids":binding_DASH_ids5332367.$var,
"block-ids":block_DASH_ids5342369.$var,
"toplevel-ids":toplevel_DASH_ids5352371.$var,
"default-map-visitor":default_DASH_map_DASH_visitor12482387,
"default-iter-visitor":default_DASH_iter_DASH_visitor16642388,
"dummy-loc-visitor":dummy_DASH_loc_DASH_visitor20802389});
var anf_fun82852383 = G(builtins57,"current-checker",L[139]);
var $z23752376 = D;
var $f23812382 = function(_) {
return R.isFunction(anf_fun82852383)?anf_fun82852383.app():R.ffi.throwNonFunApp(L[139],anf_fun82852383,[]);
};
try {
if(--R.GAS > 0) {
$z23752376 = $f23812382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23812382,
"from":L[139]});
}
} catch($e23732374) {
if(R.isCont($e23732374)) {
var $ss23772378 = {"from":L[139],
"go":function(anf_bracket82862384) {
return $Hanf_bracket114422386(anf_bracket82862384,AField11497,Ann11299,Bind90101,CasesBranch110103,ConstructModifier88105,Constructor104107,DatatypeVariant102109,Expr86111,ForBind94113,Hint78115,IfBranch106117,IfPipeBranch108119,Import70121,ImportType76123,LetBind80125,LetrecBind82127,Loc116130,Member92131,Name66133,Program68136,Provide72138,ProvideTypes74140,TypeLetBind84142,Variant100144,VariantMember98145,VariantMemberType96147,provides82842385,nothing61);
}};
$e23732374.stack[R.EXN_STACKHEIGHT++] = $ss23772378;
}
if(R.isPyretException($e23732374)) {
$e23732374.pyretStack.push(L[139]);
}
throw $e23732374;
}
var $ret23792380 = $Hanf_bracket114422386($z23752376,AField11497,Ann11299,Bind90101,CasesBranch110103,ConstructModifier88105,Constructor104107,DatatypeVariant102109,Expr86111,ForBind94113,Hint78115,IfBranch106117,IfPipeBranch108119,Import70121,ImportType76123,LetBind80125,LetrecBind82127,Loc116130,Member92131,Name66133,Program68136,Provide72138,ProvideTypes74140,TypeLetBind84142,Variant100144,VariantMember98145,VariantMemberType96147,provides82842385,nothing61);
++R.GAS;
return $ret23792380;
};
var $Hanf_bracket114422386 = function(anf_bracket82862384,AField11497,Ann11299,Bind90101,CasesBranch110103,ConstructModifier88105,Constructor104107,DatatypeVariant102109,Expr86111,ForBind94113,Hint78115,IfBranch106117,IfPipeBranch108119,Import70121,ImportType76123,LetBind80125,LetrecBind82127,Loc116130,Member92131,Name66133,Program68136,Provide72138,ProvideTypes74140,TypeLetBind84142,Variant100144,VariantMember98145,VariantMemberType96147,provides82842385,nothing61) {
var anf_fun828718559 = G(anf_bracket82862384,"results",L[139]);
var $z1855118552 = D;
var $f1855718558 = function(_) {
return R.isFunction(anf_fun828718559)?anf_fun828718559.app():R.ffi.throwNonFunApp(L[139],anf_fun828718559,[]);
};
try {
if(--R.GAS > 0) {
$z1855118552 = $f1855718558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1855718558,
"from":L[139]});
}
} catch($e1854918550) {
if(R.isCont($e1854918550)) {
var $ss1855318554 = {"from":L[139],
"go":function(checks828818560) {
return $Hchecks1144118561(checks828818560,AField11497,Ann11299,Bind90101,CasesBranch110103,ConstructModifier88105,Constructor104107,DatatypeVariant102109,Expr86111,ForBind94113,Hint78115,IfBranch106117,IfPipeBranch108119,Import70121,ImportType76123,LetBind80125,LetrecBind82127,Loc116130,Member92131,Name66133,Program68136,Provide72138,ProvideTypes74140,TypeLetBind84142,Variant100144,VariantMember98145,VariantMemberType96147,provides82842385,nothing61);
}};
$e1854918550.stack[R.EXN_STACKHEIGHT++] = $ss1855318554;
}
if(R.isPyretException($e1854918550)) {
$e1854918550.pyretStack.push(L[139]);
}
throw $e1854918550;
}
var $ret1855518556 = $Hchecks1144118561($z1855118552,AField11497,Ann11299,Bind90101,CasesBranch110103,ConstructModifier88105,Constructor104107,DatatypeVariant102109,Expr86111,ForBind94113,Hint78115,IfBranch106117,IfPipeBranch108119,Import70121,ImportType76123,LetBind80125,LetrecBind82127,Loc116130,Member92131,Name66133,Program68136,Provide72138,ProvideTypes74140,TypeLetBind84142,Variant100144,VariantMember98145,VariantMemberType96147,provides82842385,nothing61);
++R.GAS;
return $ret1855518556;
};
var $Hchecks1144118561 = function(checks828818560,AField11497,Ann11299,Bind90101,CasesBranch110103,ConstructModifier88105,Constructor104107,DatatypeVariant102109,Expr86111,ForBind94113,Hint78115,IfBranch106117,IfPipeBranch108119,Import70121,ImportType76123,LetBind80125,LetrecBind82127,Loc116130,Member92131,Name66133,Program68136,Provide72138,ProvideTypes74140,TypeLetBind84142,Variant100144,VariantMember98145,VariantMemberType96147,provides82842385,nothing61) {
return R.makeObject({"answer":nothing61,
"provide-plus-types":R.makeObject({"values":provides82842385,
"types":{"Loc":Loc116130,
"Name":Name66133,
"Program":Program68136,
"Import":Import70121,
"Provide":Provide72138,
"ProvideTypes":ProvideTypes74140,
"ImportType":ImportType76123,
"Hint":Hint78115,
"LetBind":LetBind80125,
"LetrecBind":LetrecBind82127,
"TypeLetBind":TypeLetBind84142,
"Expr":Expr86111,
"ConstructModifier":ConstructModifier88105,
"Bind":Bind90101,
"Member":Member92131,
"ForBind":ForBind94113,
"VariantMemberType":VariantMemberType96147,
"VariantMember":VariantMember98145,
"Variant":Variant100144,
"DatatypeVariant":DatatypeVariant102109,
"Constructor":Constructor104107,
"IfBranch":IfBranch106117,
"IfPipeBranch":IfPipeBranch108119,
"CasesBranch":CasesBranch110103,
"Ann":Ann11299,
"AField":AField11497}}),
"checks":checks828818560});
};
var $Hanf_arg114402507 = function(anf_arg82802505,a_DASH_field5282357,ann24952506,dummy_DASH_loc11796,self24922504) {
var anf_fun828118572 = G(ann24952506,"visit",L[3311]);
var $z1856418565 = D;
var $f1857018571 = function(_) {
return R.isFunction(anf_fun828118572)?anf_fun828118572.app(self24922504):R.ffi.throwNonFunApp(L[3310],anf_fun828118572,[self24922504]);
};
try {
if(--R.GAS > 0) {
$z1856418565 = $f1857018571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1857018571,
"from":L[3310]});
}
} catch($e1856218563) {
if(R.isCont($e1856218563)) {
var $ss1856618567 = {"from":L[3310],
"go":function(anf_arg828218573) {
return $Hanf_arg1143918574(anf_arg828218573,a_DASH_field5282357,anf_arg82802505,dummy_DASH_loc11796);
}};
$e1856218563.stack[R.EXN_STACKHEIGHT++] = $ss1856618567;
}
if(R.isPyretException($e1856218563)) {
$e1856218563.pyretStack.push(L[3310]);
}
throw $e1856218563;
}
var $ret1856818569 = $Hanf_arg1143918574($z1856418565,a_DASH_field5282357,anf_arg82802505,dummy_DASH_loc11796);
++R.GAS;
return $ret1856818569;
};
var $Hanf_arg1143918574 = function(anf_arg828218573,a_DASH_field5282357,anf_arg82802505,dummy_DASH_loc11796) {
var $z1857718578 = D;
var $f1858318584 = function(_) {
return R.isFunction(a_DASH_field5282357.$var)?a_DASH_field5282357.$var.app(dummy_DASH_loc11796,anf_arg82802505,anf_arg828218573):R.ffi.throwNonFunApp(L[248],a_DASH_field5282357.$var,[dummy_DASH_loc11796,anf_arg82802505,anf_arg828218573]);
};
try {
if(--R.GAS > 0) {
$z1857718578 = $f1858318584();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1858318584,
"from":L[248]});
}
} catch($e1857518576) {
if(R.isCont($e1857518576)) {
var $ss1857918580 = {"from":L[248],
"go":function(ann_DASH_check_DASH_temp827818585) {
return $Hann_DASH_check_DASH_temp1143818586(ann_DASH_check_DASH_temp827818585);
}};
$e1857518576.stack[R.EXN_STACKHEIGHT++] = $ss1857918580;
}
if(R.isPyretException($e1857518576)) {
$e1857518576.pyretStack.push(L[248]);
}
throw $e1857518576;
}
var $ret1858118582 = $Hann_DASH_check_DASH_temp1143818586($z1857718578);
++R.GAS;
return $ret1858118582;
};
var $Hann_DASH_check_DASH_temp1143818586 = function(ann_DASH_check_DASH_temp827818585) {
return ann_DASH_check_DASH_temp827818585;
};
var $Hann_DASH_check_DASH_temp114372523 = function(ann_DASH_check_DASH_temp82762522) {
return ann_DASH_check_DASH_temp82762522;
};
var $Hanf_arg114362540 = function(anf_arg82722538,a_DASH_pred5212343,dummy_DASH_loc11796,exp24872539,self24842537) {
var anf_fun827318597 = G(exp24872539,"visit",L[3313]);
var $z1858918590 = D;
var $f1859518596 = function(_) {
return R.isFunction(anf_fun827318597)?anf_fun827318597.app(self24842537):R.ffi.throwNonFunApp(L[3312],anf_fun827318597,[self24842537]);
};
try {
if(--R.GAS > 0) {
$z1858918590 = $f1859518596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1859518596,
"from":L[3312]});
}
} catch($e1858718588) {
if(R.isCont($e1858718588)) {
var $ss1859118592 = {"from":L[3312],
"go":function(anf_arg827418598) {
return $Hanf_arg1143518599(anf_arg827418598,a_DASH_pred5212343,anf_arg82722538,dummy_DASH_loc11796);
}};
$e1858718588.stack[R.EXN_STACKHEIGHT++] = $ss1859118592;
}
if(R.isPyretException($e1858718588)) {
$e1858718588.pyretStack.push(L[3312]);
}
throw $e1858718588;
}
var $ret1859318594 = $Hanf_arg1143518599($z1858918590,a_DASH_pred5212343,anf_arg82722538,dummy_DASH_loc11796);
++R.GAS;
return $ret1859318594;
};
var $Hanf_arg1143518599 = function(anf_arg827418598,a_DASH_pred5212343,anf_arg82722538,dummy_DASH_loc11796) {
var $z1860218603 = D;
var $f1860818609 = function(_) {
return R.isFunction(a_DASH_pred5212343.$var)?a_DASH_pred5212343.$var.app(dummy_DASH_loc11796,anf_arg82722538,anf_arg827418598):R.ffi.throwNonFunApp(L[252],a_DASH_pred5212343.$var,[dummy_DASH_loc11796,anf_arg82722538,anf_arg827418598]);
};
try {
if(--R.GAS > 0) {
$z1860218603 = $f1860818609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1860818609,
"from":L[252]});
}
} catch($e1860018601) {
if(R.isCont($e1860018601)) {
var $ss1860418605 = {"from":L[252],
"go":function(ann_DASH_check_DASH_temp827018610) {
return $Hann_DASH_check_DASH_temp1143418611(ann_DASH_check_DASH_temp827018610);
}};
$e1860018601.stack[R.EXN_STACKHEIGHT++] = $ss1860418605;
}
if(R.isPyretException($e1860018601)) {
$e1860018601.pyretStack.push(L[252]);
}
throw $e1860018601;
}
var $ret1860618607 = $Hann_DASH_check_DASH_temp1143418611($z1860218603);
++R.GAS;
return $ret1860618607;
};
var $Hann_DASH_check_DASH_temp1143418611 = function(ann_DASH_check_DASH_temp827018610) {
return ann_DASH_check_DASH_temp827018610;
};
var $Hanf_arg114332557 = function(anf_arg82632555,a_DASH_app5192339,args24832556,dummy_DASH_loc11796,self24802554) {
var anf_fun826418622 = G(args24832556,"map",L[3316]);
var anf_arg826718623 = R.makeFunction(function(recv_DASH_99818626) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3315],1,arguments);
}
var anf_fun826618637 = G(recv_DASH_99818626,"visit",L[3315]);
var $z1862918630 = D;
var $f1863518636 = function(_) {
return R.isFunction(anf_fun826618637)?anf_fun826618637.app(self24802554):R.ffi.throwNonFunApp(L[3315],anf_fun826618637,[self24802554]);
};
try {
if(--R.GAS > 0) {
$z1862918630 = $f1863518636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1863518636,
"from":L[3315]});
}
} catch($e1862718628) {
if(R.isCont($e1862718628)) {
var $ss1863118632 = {"from":L[3315],
"go":function(ann_DASH_check_DASH_temp826518638) {
return $Hann_DASH_check_DASH_temp1143018639(ann_DASH_check_DASH_temp826518638);
}};
$e1862718628.stack[R.EXN_STACKHEIGHT++] = $ss1863118632;
}
if(R.isPyretException($e1862718628)) {
$e1862718628.pyretStack.push(L[3315]);
}
throw $e1862718628;
}
var $ret1863318634 = $Hann_DASH_check_DASH_temp1143018639($z1862918630);
++R.GAS;
return $ret1863318634;
});
var $z1861418615 = D;
var $f1862018621 = function(_) {
return R.isFunction(anf_fun826418622)?anf_fun826418622.app(anf_arg826718623):R.ffi.throwNonFunApp(L[3314],anf_fun826418622,[anf_arg826718623]);
};
try {
if(--R.GAS > 0) {
$z1861418615 = $f1862018621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1862018621,
"from":L[3314]});
}
} catch($e1861218613) {
if(R.isCont($e1861218613)) {
var $ss1861618617 = {"from":L[3314],
"go":function(anf_arg826818624) {
return $Hanf_arg1143218625(anf_arg826818624,a_DASH_app5192339,anf_arg82632555,dummy_DASH_loc11796);
}};
$e1861218613.stack[R.EXN_STACKHEIGHT++] = $ss1861618617;
}
if(R.isPyretException($e1861218613)) {
$e1861218613.pyretStack.push(L[3314]);
}
throw $e1861218613;
}
var $ret1861818619 = $Hanf_arg1143218625($z1861418615,a_DASH_app5192339,anf_arg82632555,dummy_DASH_loc11796);
++R.GAS;
return $ret1861818619;
};
var $Hanf_arg1143218625 = function(anf_arg826818624,a_DASH_app5192339,anf_arg82632555,dummy_DASH_loc11796) {
var $z1864218643 = D;
var $f1864818649 = function(_) {
return R.isFunction(a_DASH_app5192339.$var)?a_DASH_app5192339.$var.app(dummy_DASH_loc11796,anf_arg82632555,anf_arg826818624):R.ffi.throwNonFunApp(L[255],a_DASH_app5192339.$var,[dummy_DASH_loc11796,anf_arg82632555,anf_arg826818624]);
};
try {
if(--R.GAS > 0) {
$z1864218643 = $f1864818649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1864818649,
"from":L[255]});
}
} catch($e1864018641) {
if(R.isCont($e1864018641)) {
var $ss1864418645 = {"from":L[255],
"go":function(ann_DASH_check_DASH_temp826118650) {
return $Hann_DASH_check_DASH_temp1143118651(ann_DASH_check_DASH_temp826118650);
}};
$e1864018641.stack[R.EXN_STACKHEIGHT++] = $ss1864418645;
}
if(R.isPyretException($e1864018641)) {
$e1864018641.pyretStack.push(L[255]);
}
throw $e1864018641;
}
var $ret1864618647 = $Hann_DASH_check_DASH_temp1143118651($z1864218643);
++R.GAS;
return $ret1864618647;
};
var $Hann_DASH_check_DASH_temp1143118651 = function(ann_DASH_check_DASH_temp826118650) {
return ann_DASH_check_DASH_temp826118650;
};
var $Hann_DASH_check_DASH_temp1143018639 = function(ann_DASH_check_DASH_temp826518638) {
return ann_DASH_check_DASH_temp826518638;
};
var $Hanf_arg114292573 = function(anf_arg82592572,a_DASH_record5172335,dummy_DASH_loc11796) {
var $z1865418655 = D;
var $f1866018661 = function(_) {
return R.isFunction(a_DASH_record5172335.$var)?a_DASH_record5172335.$var.app(dummy_DASH_loc11796,anf_arg82592572):R.ffi.throwNonFunApp(L[259],a_DASH_record5172335.$var,[dummy_DASH_loc11796,anf_arg82592572]);
};
try {
if(--R.GAS > 0) {
$z1865418655 = $f1866018661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1866018661,
"from":L[259]});
}
} catch($e1865218653) {
if(R.isCont($e1865218653)) {
var $ss1865618657 = {"from":L[259],
"go":function(ann_DASH_check_DASH_temp825418662) {
return $Hann_DASH_check_DASH_temp1142818663(ann_DASH_check_DASH_temp825418662);
}};
$e1865218653.stack[R.EXN_STACKHEIGHT++] = $ss1865618657;
}
if(R.isPyretException($e1865218653)) {
$e1865218653.pyretStack.push(L[259]);
}
throw $e1865218653;
}
var $ret1865818659 = $Hann_DASH_check_DASH_temp1142818663($z1865418655);
++R.GAS;
return $ret1865818659;
};
var $Hann_DASH_check_DASH_temp1142818663 = function(ann_DASH_check_DASH_temp825418662) {
return ann_DASH_check_DASH_temp825418662;
};
var $Hann_DASH_check_DASH_temp114272588 = function(ann_DASH_check_DASH_temp82562587) {
return ann_DASH_check_DASH_temp82562587;
};
var $Hanf_arg114262606 = function(anf_arg82502603,a_DASH_method5152331,dummy_DASH_loc11796,ret24762604,self24732605) {
var anf_fun825118674 = G(ret24762604,"visit",L[3318]);
var $z1866618667 = D;
var $f1867218673 = function(_) {
return R.isFunction(anf_fun825118674)?anf_fun825118674.app(self24732605):R.ffi.throwNonFunApp(L[3317],anf_fun825118674,[self24732605]);
};
try {
if(--R.GAS > 0) {
$z1866618667 = $f1867218673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1867218673,
"from":L[3317]});
}
} catch($e1866418665) {
if(R.isCont($e1866418665)) {
var $ss1866818669 = {"from":L[3317],
"go":function(anf_arg825218675) {
return $Hanf_arg1142518676(anf_arg825218675,a_DASH_method5152331,anf_arg82502603,dummy_DASH_loc11796);
}};
$e1866418665.stack[R.EXN_STACKHEIGHT++] = $ss1866818669;
}
if(R.isPyretException($e1866418665)) {
$e1866418665.pyretStack.push(L[3317]);
}
throw $e1866418665;
}
var $ret1867018671 = $Hanf_arg1142518676($z1866618667,a_DASH_method5152331,anf_arg82502603,dummy_DASH_loc11796);
++R.GAS;
return $ret1867018671;
};
var $Hanf_arg1142518676 = function(anf_arg825218675,a_DASH_method5152331,anf_arg82502603,dummy_DASH_loc11796) {
var $z1867918680 = D;
var $f1868518686 = function(_) {
return R.isFunction(a_DASH_method5152331.$var)?a_DASH_method5152331.$var.app(dummy_DASH_loc11796,anf_arg82502603,anf_arg825218675):R.ffi.throwNonFunApp(L[263],a_DASH_method5152331.$var,[dummy_DASH_loc11796,anf_arg82502603,anf_arg825218675]);
};
try {
if(--R.GAS > 0) {
$z1867918680 = $f1868518686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1868518686,
"from":L[263]});
}
} catch($e1867718678) {
if(R.isCont($e1867718678)) {
var $ss1868118682 = {"from":L[263],
"go":function(ann_DASH_check_DASH_temp824518687) {
return $Hann_DASH_check_DASH_temp1142418688(ann_DASH_check_DASH_temp824518687);
}};
$e1867718678.stack[R.EXN_STACKHEIGHT++] = $ss1868118682;
}
if(R.isPyretException($e1867718678)) {
$e1867718678.pyretStack.push(L[263]);
}
throw $e1867718678;
}
var $ret1868318684 = $Hann_DASH_check_DASH_temp1142418688($z1867918680);
++R.GAS;
return $ret1868318684;
};
var $Hann_DASH_check_DASH_temp1142418688 = function(ann_DASH_check_DASH_temp824518687) {
return ann_DASH_check_DASH_temp824518687;
};
var $Hann_DASH_check_DASH_temp114232620 = function(ann_DASH_check_DASH_temp82472619) {
return ann_DASH_check_DASH_temp82472619;
};
var $Hanf_arg114222639 = function(anf_arg82412635,a_DASH_arrow5132327,dummy_DASH_loc11796,ret24712636,self24682637,use_DASH_parens24722638) {
var anf_fun824218699 = G(ret24712636,"visit",L[3320]);
var $z1869118692 = D;
var $f1869718698 = function(_) {
return R.isFunction(anf_fun824218699)?anf_fun824218699.app(self24682637):R.ffi.throwNonFunApp(L[3319],anf_fun824218699,[self24682637]);
};
try {
if(--R.GAS > 0) {
$z1869118692 = $f1869718698();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1869718698,
"from":L[3319]});
}
} catch($e1868918690) {
if(R.isCont($e1868918690)) {
var $ss1869318694 = {"from":L[3319],
"go":function(anf_arg824318700) {
return $Hanf_arg1142118701(anf_arg824318700,a_DASH_arrow5132327,anf_arg82412635,dummy_DASH_loc11796,use_DASH_parens24722638);
}};
$e1868918690.stack[R.EXN_STACKHEIGHT++] = $ss1869318694;
}
if(R.isPyretException($e1868918690)) {
$e1868918690.pyretStack.push(L[3319]);
}
throw $e1868918690;
}
var $ret1869518696 = $Hanf_arg1142118701($z1869118692,a_DASH_arrow5132327,anf_arg82412635,dummy_DASH_loc11796,use_DASH_parens24722638);
++R.GAS;
return $ret1869518696;
};
var $Hanf_arg1142118701 = function(anf_arg824318700,a_DASH_arrow5132327,anf_arg82412635,dummy_DASH_loc11796,use_DASH_parens24722638) {
var $z1870418705 = D;
var $f1871018711 = function(_) {
return R.isFunction(a_DASH_arrow5132327.$var)?a_DASH_arrow5132327.$var.app(dummy_DASH_loc11796,anf_arg82412635,anf_arg824318700,use_DASH_parens24722638):R.ffi.throwNonFunApp(L[267],a_DASH_arrow5132327.$var,[dummy_DASH_loc11796,anf_arg82412635,anf_arg824318700,use_DASH_parens24722638]);
};
try {
if(--R.GAS > 0) {
$z1870418705 = $f1871018711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1871018711,
"from":L[267]});
}
} catch($e1870218703) {
if(R.isCont($e1870218703)) {
var $ss1870618707 = {"from":L[267],
"go":function(ann_DASH_check_DASH_temp823618712) {
return $Hann_DASH_check_DASH_temp1142018713(ann_DASH_check_DASH_temp823618712);
}};
$e1870218703.stack[R.EXN_STACKHEIGHT++] = $ss1870618707;
}
if(R.isPyretException($e1870218703)) {
$e1870218703.pyretStack.push(L[267]);
}
throw $e1870218703;
}
var $ret1870818709 = $Hann_DASH_check_DASH_temp1142018713($z1870418705);
++R.GAS;
return $ret1870818709;
};
var $Hann_DASH_check_DASH_temp1142018713 = function(ann_DASH_check_DASH_temp823618712) {
return ann_DASH_check_DASH_temp823618712;
};
var $Hann_DASH_check_DASH_temp114192653 = function(ann_DASH_check_DASH_temp82382652) {
return ann_DASH_check_DASH_temp82382652;
};
var $Hanf_arg114182669 = function(anf_arg82342668,a_DASH_name5112323,dummy_DASH_loc11796) {
var $z1871618717 = D;
var $f1872218723 = function(_) {
return R.isFunction(a_DASH_name5112323.$var)?a_DASH_name5112323.$var.app(dummy_DASH_loc11796,anf_arg82342668):R.ffi.throwNonFunApp(L[270],a_DASH_name5112323.$var,[dummy_DASH_loc11796,anf_arg82342668]);
};
try {
if(--R.GAS > 0) {
$z1871618717 = $f1872218723();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1872218723,
"from":L[270]});
}
} catch($e1871418715) {
if(R.isCont($e1871418715)) {
var $ss1871818719 = {"from":L[270],
"go":function(ann_DASH_check_DASH_temp823218724) {
return $Hann_DASH_check_DASH_temp1141718725(ann_DASH_check_DASH_temp823218724);
}};
$e1871418715.stack[R.EXN_STACKHEIGHT++] = $ss1871818719;
}
if(R.isPyretException($e1871418715)) {
$e1871418715.pyretStack.push(L[270]);
}
throw $e1871418715;
}
var $ret1872018721 = $Hann_DASH_check_DASH_temp1141718725($z1871618717);
++R.GAS;
return $ret1872018721;
};
var $Hann_DASH_check_DASH_temp1141718725 = function(ann_DASH_check_DASH_temp823218724) {
return ann_DASH_check_DASH_temp823218724;
};
var $Hanf_arg114162690 = function(anf_arg82262688,dummy_DASH_loc11796,s_DASH_datatype_DASH_constructor4872275,self_DASH_arg24612689) {
var $z1872818729 = D;
var $f1873418735 = function(_) {
return R.isFunction(s_DASH_datatype_DASH_constructor4872275.$var)?s_DASH_datatype_DASH_constructor4872275.$var.app(dummy_DASH_loc11796,self_DASH_arg24612689,anf_arg82262688):R.ffi.throwNonFunApp(L[278],s_DASH_datatype_DASH_constructor4872275.$var,[dummy_DASH_loc11796,self_DASH_arg24612689,anf_arg82262688]);
};
try {
if(--R.GAS > 0) {
$z1872818729 = $f1873418735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1873418735,
"from":L[278]});
}
} catch($e1872618727) {
if(R.isCont($e1872618727)) {
var $ss1873018731 = {"from":L[278],
"go":function(ann_DASH_check_DASH_temp822418736) {
return $Hann_DASH_check_DASH_temp1141518737(ann_DASH_check_DASH_temp822418736);
}};
$e1872618727.stack[R.EXN_STACKHEIGHT++] = $ss1873018731;
}
if(R.isPyretException($e1872618727)) {
$e1872618727.pyretStack.push(L[278]);
}
throw $e1872618727;
}
var $ret1873218733 = $Hann_DASH_check_DASH_temp1141518737($z1872818729);
++R.GAS;
return $ret1873218733;
};
var $Hann_DASH_check_DASH_temp1141518737 = function(ann_DASH_check_DASH_temp822418736) {
return ann_DASH_check_DASH_temp822418736;
};
var $Hanf_arg114142707 = function(anf_arg82222705,dummy_DASH_loc11796,name24572706,s_DASH_datatype_DASH_singleton_DASH_variant4822265) {
var $z1874018741 = D;
var $f1874618747 = function(_) {
return R.isFunction(s_DASH_datatype_DASH_singleton_DASH_variant4822265.$var)?s_DASH_datatype_DASH_singleton_DASH_variant4822265.$var.app(dummy_DASH_loc11796,name24572706,anf_arg82222705):R.ffi.throwNonFunApp(L[284],s_DASH_datatype_DASH_singleton_DASH_variant4822265.$var,[dummy_DASH_loc11796,name24572706,anf_arg82222705]);
};
try {
if(--R.GAS > 0) {
$z1874018741 = $f1874618747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1874618747,
"from":L[284]});
}
} catch($e1873818739) {
if(R.isCont($e1873818739)) {
var $ss1874218743 = {"from":L[284],
"go":function(ann_DASH_check_DASH_temp822018748) {
return $Hann_DASH_check_DASH_temp1141318749(ann_DASH_check_DASH_temp822018748);
}};
$e1873818739.stack[R.EXN_STACKHEIGHT++] = $ss1874218743;
}
if(R.isPyretException($e1873818739)) {
$e1873818739.pyretStack.push(L[284]);
}
throw $e1873818739;
}
var $ret1874418745 = $Hann_DASH_check_DASH_temp1141318749($z1874018741);
++R.GAS;
return $ret1874418745;
};
var $Hann_DASH_check_DASH_temp1141318749 = function(ann_DASH_check_DASH_temp822018748) {
return ann_DASH_check_DASH_temp822018748;
};
var $Hanf_arg114122726 = function(anf_arg82162722,constructor24542723,dummy_DASH_loc11796,name24522724,s_DASH_datatype_DASH_variant4802261,self24502725) {
var anf_fun821718760 = G(constructor24542723,"visit",L[3322]);
var $z1875218753 = D;
var $f1875818759 = function(_) {
return R.isFunction(anf_fun821718760)?anf_fun821718760.app(self24502725):R.ffi.throwNonFunApp(L[3321],anf_fun821718760,[self24502725]);
};
try {
if(--R.GAS > 0) {
$z1875218753 = $f1875818759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1875818759,
"from":L[3321]});
}
} catch($e1875018751) {
if(R.isCont($e1875018751)) {
var $ss1875418755 = {"from":L[3321],
"go":function(anf_arg821818761) {
return $Hanf_arg1141118762(anf_arg821818761,anf_arg82162722,dummy_DASH_loc11796,name24522724,s_DASH_datatype_DASH_variant4802261);
}};
$e1875018751.stack[R.EXN_STACKHEIGHT++] = $ss1875418755;
}
if(R.isPyretException($e1875018751)) {
$e1875018751.pyretStack.push(L[3321]);
}
throw $e1875018751;
}
var $ret1875618757 = $Hanf_arg1141118762($z1875218753,anf_arg82162722,dummy_DASH_loc11796,name24522724,s_DASH_datatype_DASH_variant4802261);
++R.GAS;
return $ret1875618757;
};
var $Hanf_arg1141118762 = function(anf_arg821818761,anf_arg82162722,dummy_DASH_loc11796,name24522724,s_DASH_datatype_DASH_variant4802261) {
var $z1876518766 = D;
var $f1877118772 = function(_) {
return R.isFunction(s_DASH_datatype_DASH_variant4802261.$var)?s_DASH_datatype_DASH_variant4802261.$var.app(dummy_DASH_loc11796,name24522724,anf_arg82162722,anf_arg821818761):R.ffi.throwNonFunApp(L[292],s_DASH_datatype_DASH_variant4802261.$var,[dummy_DASH_loc11796,name24522724,anf_arg82162722,anf_arg821818761]);
};
try {
if(--R.GAS > 0) {
$z1876518766 = $f1877118772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1877118772,
"from":L[292]});
}
} catch($e1876318764) {
if(R.isCont($e1876318764)) {
var $ss1876718768 = {"from":L[292],
"go":function(ann_DASH_check_DASH_temp821118773) {
return $Hann_DASH_check_DASH_temp1141018774(ann_DASH_check_DASH_temp821118773);
}};
$e1876318764.stack[R.EXN_STACKHEIGHT++] = $ss1876718768;
}
if(R.isPyretException($e1876318764)) {
$e1876318764.pyretStack.push(L[292]);
}
throw $e1876318764;
}
var $ret1876918770 = $Hann_DASH_check_DASH_temp1141018774($z1876518766);
++R.GAS;
return $ret1876918770;
};
var $Hann_DASH_check_DASH_temp1141018774 = function(ann_DASH_check_DASH_temp821118773) {
return ann_DASH_check_DASH_temp821118773;
};
var $Hann_DASH_check_DASH_temp114092740 = function(ann_DASH_check_DASH_temp82132739) {
return ann_DASH_check_DASH_temp82132739;
};
var $Hanf_arg114082757 = function(anf_arg82092755,dummy_DASH_loc11796,name24482756,s_DASH_singleton_DASH_variant4752251) {
var $z1877718778 = D;
var $f1878318784 = function(_) {
return R.isFunction(s_DASH_singleton_DASH_variant4752251.$var)?s_DASH_singleton_DASH_variant4752251.$var.app(dummy_DASH_loc11796,name24482756,anf_arg82092755):R.ffi.throwNonFunApp(L[299],s_DASH_singleton_DASH_variant4752251.$var,[dummy_DASH_loc11796,name24482756,anf_arg82092755]);
};
try {
if(--R.GAS > 0) {
$z1877718778 = $f1878318784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1878318784,
"from":L[299]});
}
} catch($e1877518776) {
if(R.isCont($e1877518776)) {
var $ss1877918780 = {"from":L[299],
"go":function(ann_DASH_check_DASH_temp820418785) {
return $Hann_DASH_check_DASH_temp1140718786(ann_DASH_check_DASH_temp820418785);
}};
$e1877518776.stack[R.EXN_STACKHEIGHT++] = $ss1877918780;
}
if(R.isPyretException($e1877518776)) {
$e1877518776.pyretStack.push(L[299]);
}
throw $e1877518776;
}
var $ret1878118782 = $Hann_DASH_check_DASH_temp1140718786($z1877718778);
++R.GAS;
return $ret1878118782;
};
var $Hann_DASH_check_DASH_temp1140718786 = function(ann_DASH_check_DASH_temp820418785) {
return ann_DASH_check_DASH_temp820418785;
};
var $Hann_DASH_check_DASH_temp114062772 = function(ann_DASH_check_DASH_temp82062771) {
return ann_DASH_check_DASH_temp82062771;
};
var $Hanf_arg114052791 = function(anf_arg81972787,dummy_DASH_loc11796,name24432788,s_DASH_variant4732247,self24402789,with_DASH_members24452790) {
var anf_fun819818797 = G(with_DASH_members24452790,"map",L[3325]);
var anf_arg820118798 = R.makeFunction(function(recv_DASH_99218801) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3324],1,arguments);
}
var anf_fun820018812 = G(recv_DASH_99218801,"visit",L[3324]);
var $z1880418805 = D;
var $f1881018811 = function(_) {
return R.isFunction(anf_fun820018812)?anf_fun820018812.app(self24402789):R.ffi.throwNonFunApp(L[3324],anf_fun820018812,[self24402789]);
};
try {
if(--R.GAS > 0) {
$z1880418805 = $f1881018811();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1881018811,
"from":L[3324]});
}
} catch($e1880218803) {
if(R.isCont($e1880218803)) {
var $ss1880618807 = {"from":L[3324],
"go":function(ann_DASH_check_DASH_temp819918813) {
return $Hann_DASH_check_DASH_temp1140218814(ann_DASH_check_DASH_temp819918813);
}};
$e1880218803.stack[R.EXN_STACKHEIGHT++] = $ss1880618807;
}
if(R.isPyretException($e1880218803)) {
$e1880218803.pyretStack.push(L[3324]);
}
throw $e1880218803;
}
var $ret1880818809 = $Hann_DASH_check_DASH_temp1140218814($z1880418805);
++R.GAS;
return $ret1880818809;
});
var $z1878918790 = D;
var $f1879518796 = function(_) {
return R.isFunction(anf_fun819818797)?anf_fun819818797.app(anf_arg820118798):R.ffi.throwNonFunApp(L[3323],anf_fun819818797,[anf_arg820118798]);
};
try {
if(--R.GAS > 0) {
$z1878918790 = $f1879518796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1879518796,
"from":L[3323]});
}
} catch($e1878718788) {
if(R.isCont($e1878718788)) {
var $ss1879118792 = {"from":L[3323],
"go":function(anf_arg820218799) {
return $Hanf_arg1140418800(anf_arg820218799,anf_arg81972787,dummy_DASH_loc11796,name24432788,s_DASH_variant4732247);
}};
$e1878718788.stack[R.EXN_STACKHEIGHT++] = $ss1879118792;
}
if(R.isPyretException($e1878718788)) {
$e1878718788.pyretStack.push(L[3323]);
}
throw $e1878718788;
}
var $ret1879318794 = $Hanf_arg1140418800($z1878918790,anf_arg81972787,dummy_DASH_loc11796,name24432788,s_DASH_variant4732247);
++R.GAS;
return $ret1879318794;
};
var $Hanf_arg1140418800 = function(anf_arg820218799,anf_arg81972787,dummy_DASH_loc11796,name24432788,s_DASH_variant4732247) {
var $z1881718818 = D;
var $f1882318824 = function(_) {
return R.isFunction(s_DASH_variant4732247.$var)?s_DASH_variant4732247.$var.app(dummy_DASH_loc11796,dummy_DASH_loc11796,name24432788,anf_arg81972787,anf_arg820218799):R.ffi.throwNonFunApp(L[308],s_DASH_variant4732247.$var,[dummy_DASH_loc11796,dummy_DASH_loc11796,name24432788,anf_arg81972787,anf_arg820218799]);
};
try {
if(--R.GAS > 0) {
$z1881718818 = $f1882318824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1882318824,
"from":L[308]});
}
} catch($e1881518816) {
if(R.isCont($e1881518816)) {
var $ss1881918820 = {"from":L[308],
"go":function(ann_DASH_check_DASH_temp819218825) {
return $Hann_DASH_check_DASH_temp1140318826(ann_DASH_check_DASH_temp819218825);
}};
$e1881518816.stack[R.EXN_STACKHEIGHT++] = $ss1881918820;
}
if(R.isPyretException($e1881518816)) {
$e1881518816.pyretStack.push(L[308]);
}
throw $e1881518816;
}
var $ret1882118822 = $Hann_DASH_check_DASH_temp1140318826($z1881718818);
++R.GAS;
return $ret1882118822;
};
var $Hann_DASH_check_DASH_temp1140318826 = function(ann_DASH_check_DASH_temp819218825) {
return ann_DASH_check_DASH_temp819218825;
};
var $Hann_DASH_check_DASH_temp1140218814 = function(ann_DASH_check_DASH_temp819918813) {
return ann_DASH_check_DASH_temp819918813;
};
var $Hann_DASH_check_DASH_temp114012805 = function(ann_DASH_check_DASH_temp81942804) {
return ann_DASH_check_DASH_temp81942804;
};
var $Hanf_arg114002823 = function(anf_arg81902821,dummy_DASH_loc11796,member_DASH_type24382822,s_DASH_variant_DASH_member4682237) {
var $z1882918830 = D;
var $f1883518836 = function(_) {
return R.isFunction(s_DASH_variant_DASH_member4682237.$var)?s_DASH_variant_DASH_member4682237.$var.app(dummy_DASH_loc11796,member_DASH_type24382822,anf_arg81902821):R.ffi.throwNonFunApp(L[314],s_DASH_variant_DASH_member4682237.$var,[dummy_DASH_loc11796,member_DASH_type24382822,anf_arg81902821]);
};
try {
if(--R.GAS > 0) {
$z1882918830 = $f1883518836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1883518836,
"from":L[314]});
}
} catch($e1882718828) {
if(R.isCont($e1882718828)) {
var $ss1883118832 = {"from":L[314],
"go":function(ann_DASH_check_DASH_temp818818837) {
return $Hann_DASH_check_DASH_temp1139918838(ann_DASH_check_DASH_temp818818837);
}};
$e1882718828.stack[R.EXN_STACKHEIGHT++] = $ss1883118832;
}
if(R.isPyretException($e1882718828)) {
$e1882718828.pyretStack.push(L[314]);
}
throw $e1882718828;
}
var $ret1883318834 = $Hann_DASH_check_DASH_temp1139918838($z1882918830);
++R.GAS;
return $ret1883318834;
};
var $Hann_DASH_check_DASH_temp1139918838 = function(ann_DASH_check_DASH_temp818818837) {
return ann_DASH_check_DASH_temp818818837;
};
var $Hanf_arg113982840 = function(anf_arg81842838,dummy_DASH_loc11796,s_DASH_for_DASH_bind4542209,self24322837,value24352839) {
var anf_fun818518849 = G(value24352839,"visit",L[3327]);
var $z1884118842 = D;
var $f1884718848 = function(_) {
return R.isFunction(anf_fun818518849)?anf_fun818518849.app(self24322837):R.ffi.throwNonFunApp(L[3326],anf_fun818518849,[self24322837]);
};
try {
if(--R.GAS > 0) {
$z1884118842 = $f1884718848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1884718848,
"from":L[3326]});
}
} catch($e1883918840) {
if(R.isCont($e1883918840)) {
var $ss1884318844 = {"from":L[3326],
"go":function(anf_arg818618850) {
return $Hanf_arg1139718851(anf_arg818618850,anf_arg81842838,dummy_DASH_loc11796,s_DASH_for_DASH_bind4542209);
}};
$e1883918840.stack[R.EXN_STACKHEIGHT++] = $ss1884318844;
}
if(R.isPyretException($e1883918840)) {
$e1883918840.pyretStack.push(L[3326]);
}
throw $e1883918840;
}
var $ret1884518846 = $Hanf_arg1139718851($z1884118842,anf_arg81842838,dummy_DASH_loc11796,s_DASH_for_DASH_bind4542209);
++R.GAS;
return $ret1884518846;
};
var $Hanf_arg1139718851 = function(anf_arg818618850,anf_arg81842838,dummy_DASH_loc11796,s_DASH_for_DASH_bind4542209) {
var $z1885418855 = D;
var $f1886018861 = function(_) {
return R.isFunction(s_DASH_for_DASH_bind4542209.$var)?s_DASH_for_DASH_bind4542209.$var.app(dummy_DASH_loc11796,anf_arg81842838,anf_arg818618850):R.ffi.throwNonFunApp(L[320],s_DASH_for_DASH_bind4542209.$var,[dummy_DASH_loc11796,anf_arg81842838,anf_arg818618850]);
};
try {
if(--R.GAS > 0) {
$z1885418855 = $f1886018861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1886018861,
"from":L[320]});
}
} catch($e1885218853) {
if(R.isCont($e1885218853)) {
var $ss1885618857 = {"from":L[320],
"go":function(ann_DASH_check_DASH_temp818218862) {
return $Hann_DASH_check_DASH_temp1139618863(ann_DASH_check_DASH_temp818218862);
}};
$e1885218853.stack[R.EXN_STACKHEIGHT++] = $ss1885618857;
}
if(R.isPyretException($e1885218853)) {
$e1885218853.pyretStack.push(L[320]);
}
throw $e1885218853;
}
var $ret1885818859 = $Hann_DASH_check_DASH_temp1139618863($z1885418855);
++R.GAS;
return $ret1885818859;
};
var $Hann_DASH_check_DASH_temp1139618863 = function(ann_DASH_check_DASH_temp818218862) {
return ann_DASH_check_DASH_temp818218862;
};
var $Hanf_arg113952862 = function(anf_arg81742855,_check24312856,ann24282857,body24302858,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861) {
var anf_fun817518874 = G(ann24282857,"visit",L[3329]);
var $z1886618867 = D;
var $f1887218873 = function(_) {
return R.isFunction(anf_fun817518874)?anf_fun817518874.app(self24242861):R.ffi.throwNonFunApp(L[3328],anf_fun817518874,[self24242861]);
};
try {
if(--R.GAS > 0) {
$z1886618867 = $f1887218873();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1887218873,
"from":L[3328]});
}
} catch($e1886418865) {
if(R.isCont($e1886418865)) {
var $ss1886818869 = {"from":L[3328],
"go":function(anf_arg817618875) {
return $Hanf_arg1139418876(anf_arg817618875,_check24312856,anf_arg81742855,body24302858,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861);
}};
$e1886418865.stack[R.EXN_STACKHEIGHT++] = $ss1886818869;
}
if(R.isPyretException($e1886418865)) {
$e1886418865.pyretStack.push(L[3328]);
}
throw $e1886418865;
}
var $ret1887018871 = $Hanf_arg1139418876($z1886618867,_check24312856,anf_arg81742855,body24302858,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861);
++R.GAS;
return $ret1887018871;
};
var $Hanf_arg1139418876 = function(anf_arg817618875,_check24312856,anf_arg81742855,body24302858,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861) {
var anf_fun817718887 = G(body24302858,"visit",L[3331]);
var $z1887918880 = D;
var $f1888518886 = function(_) {
return R.isFunction(anf_fun817718887)?anf_fun817718887.app(self24242861):R.ffi.throwNonFunApp(L[3330],anf_fun817718887,[self24242861]);
};
try {
if(--R.GAS > 0) {
$z1887918880 = $f1888518886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1888518886,
"from":L[3330]});
}
} catch($e1887718878) {
if(R.isCont($e1887718878)) {
var $ss1888118882 = {"from":L[3330],
"go":function(anf_arg817818888) {
return $Hanf_arg1139318889(anf_arg817818888,_check24312856,anf_arg81742855,anf_arg817618875,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861);
}};
$e1887718878.stack[R.EXN_STACKHEIGHT++] = $ss1888118882;
}
if(R.isPyretException($e1887718878)) {
$e1887718878.pyretStack.push(L[3330]);
}
throw $e1887718878;
}
var $ret1888318884 = $Hanf_arg1139318889($z1887918880,_check24312856,anf_arg81742855,anf_arg817618875,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861);
++R.GAS;
return $ret1888318884;
};
var $Hanf_arg1139318889 = function(anf_arg817818888,_check24312856,anf_arg81742855,anf_arg817618875,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199,self24242861) {
var anf_fun817918900 = G(self24242861,"option",L[3333]);
var $z1889218893 = D;
var $f1889818899 = function(_) {
return R.isFunction(anf_fun817918900)?anf_fun817918900.app(_check24312856):R.ffi.throwNonFunApp(L[3332],anf_fun817918900,[_check24312856]);
};
try {
if(--R.GAS > 0) {
$z1889218893 = $f1889818899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1889818899,
"from":L[3332]});
}
} catch($e1889018891) {
if(R.isCont($e1889018891)) {
var $ss1889418895 = {"from":L[3332],
"go":function(anf_arg818018901) {
return $Hanf_arg1139218902(anf_arg818018901,anf_arg81742855,anf_arg817618875,anf_arg817818888,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199);
}};
$e1889018891.stack[R.EXN_STACKHEIGHT++] = $ss1889418895;
}
if(R.isPyretException($e1889018891)) {
$e1889018891.pyretStack.push(L[3332]);
}
throw $e1889018891;
}
var $ret1889618897 = $Hanf_arg1139218902($z1889218893,anf_arg81742855,anf_arg817618875,anf_arg817818888,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199);
++R.GAS;
return $ret1889618897;
};
var $Hanf_arg1139218902 = function(anf_arg818018901,anf_arg81742855,anf_arg817618875,anf_arg817818888,doc24292859,dummy_DASH_loc11796,name24262860,s_DASH_method_DASH_field4492199) {
var $z1890518906 = D;
var $f1891118912 = function(_) {
return R.isFunction(s_DASH_method_DASH_field4492199.$var)?s_DASH_method_DASH_field4492199.$var.app(dummy_DASH_loc11796,name24262860,anf_arg81742855,anf_arg817618875,doc24292859,anf_arg817818888,anf_arg818018901):R.ffi.throwNonFunApp(L[331],s_DASH_method_DASH_field4492199.$var,[dummy_DASH_loc11796,name24262860,anf_arg81742855,anf_arg817618875,doc24292859,anf_arg817818888,anf_arg818018901]);
};
try {
if(--R.GAS > 0) {
$z1890518906 = $f1891118912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1891118912,
"from":L[331]});
}
} catch($e1890318904) {
if(R.isCont($e1890318904)) {
var $ss1890718908 = {"from":L[331],
"go":function(ann_DASH_check_DASH_temp816918913) {
return $Hann_DASH_check_DASH_temp1139118914(ann_DASH_check_DASH_temp816918913);
}};
$e1890318904.stack[R.EXN_STACKHEIGHT++] = $ss1890718908;
}
if(R.isPyretException($e1890318904)) {
$e1890318904.pyretStack.push(L[331]);
}
throw $e1890318904;
}
var $ret1890918910 = $Hann_DASH_check_DASH_temp1139118914($z1890518906);
++R.GAS;
return $ret1890918910;
};
var $Hann_DASH_check_DASH_temp1139118914 = function(ann_DASH_check_DASH_temp816918913) {
return ann_DASH_check_DASH_temp816918913;
};
var $Hann_DASH_check_DASH_temp113902876 = function(ann_DASH_check_DASH_temp81712875) {
return ann_DASH_check_DASH_temp81712875;
};
var $Hanf_arg113892894 = function(anf_arg81632891,ann24222892,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195,self24192890,value24232893) {
var anf_fun816418925 = G(ann24222892,"visit",L[3335]);
var $z1891718918 = D;
var $f1892318924 = function(_) {
return R.isFunction(anf_fun816418925)?anf_fun816418925.app(self24192890):R.ffi.throwNonFunApp(L[3334],anf_fun816418925,[self24192890]);
};
try {
if(--R.GAS > 0) {
$z1891718918 = $f1892318924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1892318924,
"from":L[3334]});
}
} catch($e1891518916) {
if(R.isCont($e1891518916)) {
var $ss1891918920 = {"from":L[3334],
"go":function(anf_arg816518926) {
return $Hanf_arg1138818927(anf_arg816518926,anf_arg81632891,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195,self24192890,value24232893);
}};
$e1891518916.stack[R.EXN_STACKHEIGHT++] = $ss1891918920;
}
if(R.isPyretException($e1891518916)) {
$e1891518916.pyretStack.push(L[3334]);
}
throw $e1891518916;
}
var $ret1892118922 = $Hanf_arg1138818927($z1891718918,anf_arg81632891,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195,self24192890,value24232893);
++R.GAS;
return $ret1892118922;
};
var $Hanf_arg1138818927 = function(anf_arg816518926,anf_arg81632891,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195,self24192890,value24232893) {
var anf_fun816618938 = G(value24232893,"visit",L[3337]);
var $z1893018931 = D;
var $f1893618937 = function(_) {
return R.isFunction(anf_fun816618938)?anf_fun816618938.app(self24192890):R.ffi.throwNonFunApp(L[3336],anf_fun816618938,[self24192890]);
};
try {
if(--R.GAS > 0) {
$z1893018931 = $f1893618937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1893618937,
"from":L[3336]});
}
} catch($e1892818929) {
if(R.isCont($e1892818929)) {
var $ss1893218933 = {"from":L[3336],
"go":function(anf_arg816718939) {
return $Hanf_arg1138718940(anf_arg816718939,anf_arg81632891,anf_arg816518926,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195);
}};
$e1892818929.stack[R.EXN_STACKHEIGHT++] = $ss1893218933;
}
if(R.isPyretException($e1892818929)) {
$e1892818929.pyretStack.push(L[3336]);
}
throw $e1892818929;
}
var $ret1893418935 = $Hanf_arg1138718940($z1893018931,anf_arg81632891,anf_arg816518926,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195);
++R.GAS;
return $ret1893418935;
};
var $Hanf_arg1138718940 = function(anf_arg816718939,anf_arg81632891,anf_arg816518926,dummy_DASH_loc11796,s_DASH_once_DASH_field4472195) {
var $z1894318944 = D;
var $f1894918950 = function(_) {
return R.isFunction(s_DASH_once_DASH_field4472195.$var)?s_DASH_once_DASH_field4472195.$var.app(dummy_DASH_loc11796,anf_arg81632891,anf_arg816518926,anf_arg816718939):R.ffi.throwNonFunApp(L[338],s_DASH_once_DASH_field4472195.$var,[dummy_DASH_loc11796,anf_arg81632891,anf_arg816518926,anf_arg816718939]);
};
try {
if(--R.GAS > 0) {
$z1894318944 = $f1894918950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1894918950,
"from":L[338]});
}
} catch($e1894118942) {
if(R.isCont($e1894118942)) {
var $ss1894518946 = {"from":L[338],
"go":function(ann_DASH_check_DASH_temp816118951) {
return $Hann_DASH_check_DASH_temp1138618952(ann_DASH_check_DASH_temp816118951);
}};
$e1894118942.stack[R.EXN_STACKHEIGHT++] = $ss1894518946;
}
if(R.isPyretException($e1894118942)) {
$e1894118942.pyretStack.push(L[338]);
}
throw $e1894118942;
}
var $ret1894718948 = $Hann_DASH_check_DASH_temp1138618952($z1894318944);
++R.GAS;
return $ret1894718948;
};
var $Hann_DASH_check_DASH_temp1138618952 = function(ann_DASH_check_DASH_temp816118951) {
return ann_DASH_check_DASH_temp816118951;
};
var $Hanf_arg113852912 = function(anf_arg81552909,ann24172910,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191,self24142908,value24182911) {
var anf_fun815618963 = G(ann24172910,"visit",L[3339]);
var $z1895518956 = D;
var $f1896118962 = function(_) {
return R.isFunction(anf_fun815618963)?anf_fun815618963.app(self24142908):R.ffi.throwNonFunApp(L[3338],anf_fun815618963,[self24142908]);
};
try {
if(--R.GAS > 0) {
$z1895518956 = $f1896118962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1896118962,
"from":L[3338]});
}
} catch($e1895318954) {
if(R.isCont($e1895318954)) {
var $ss1895718958 = {"from":L[3338],
"go":function(anf_arg815718964) {
return $Hanf_arg1138418965(anf_arg815718964,anf_arg81552909,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191,self24142908,value24182911);
}};
$e1895318954.stack[R.EXN_STACKHEIGHT++] = $ss1895718958;
}
if(R.isPyretException($e1895318954)) {
$e1895318954.pyretStack.push(L[3338]);
}
throw $e1895318954;
}
var $ret1895918960 = $Hanf_arg1138418965($z1895518956,anf_arg81552909,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191,self24142908,value24182911);
++R.GAS;
return $ret1895918960;
};
var $Hanf_arg1138418965 = function(anf_arg815718964,anf_arg81552909,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191,self24142908,value24182911) {
var anf_fun815818976 = G(value24182911,"visit",L[3341]);
var $z1896818969 = D;
var $f1897418975 = function(_) {
return R.isFunction(anf_fun815818976)?anf_fun815818976.app(self24142908):R.ffi.throwNonFunApp(L[3340],anf_fun815818976,[self24142908]);
};
try {
if(--R.GAS > 0) {
$z1896818969 = $f1897418975();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1897418975,
"from":L[3340]});
}
} catch($e1896618967) {
if(R.isCont($e1896618967)) {
var $ss1897018971 = {"from":L[3340],
"go":function(anf_arg815918977) {
return $Hanf_arg1138318978(anf_arg815918977,anf_arg81552909,anf_arg815718964,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191);
}};
$e1896618967.stack[R.EXN_STACKHEIGHT++] = $ss1897018971;
}
if(R.isPyretException($e1896618967)) {
$e1896618967.pyretStack.push(L[3340]);
}
throw $e1896618967;
}
var $ret1897218973 = $Hanf_arg1138318978($z1896818969,anf_arg81552909,anf_arg815718964,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191);
++R.GAS;
return $ret1897218973;
};
var $Hanf_arg1138318978 = function(anf_arg815918977,anf_arg81552909,anf_arg815718964,dummy_DASH_loc11796,s_DASH_mutable_DASH_field4452191) {
var $z1898118982 = D;
var $f1898718988 = function(_) {
return R.isFunction(s_DASH_mutable_DASH_field4452191.$var)?s_DASH_mutable_DASH_field4452191.$var.app(dummy_DASH_loc11796,anf_arg81552909,anf_arg815718964,anf_arg815918977):R.ffi.throwNonFunApp(L[345],s_DASH_mutable_DASH_field4452191.$var,[dummy_DASH_loc11796,anf_arg81552909,anf_arg815718964,anf_arg815918977]);
};
try {
if(--R.GAS > 0) {
$z1898118982 = $f1898718988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1898718988,
"from":L[345]});
}
} catch($e1897918980) {
if(R.isCont($e1897918980)) {
var $ss1898318984 = {"from":L[345],
"go":function(ann_DASH_check_DASH_temp815318989) {
return $Hann_DASH_check_DASH_temp1138218990(ann_DASH_check_DASH_temp815318989);
}};
$e1897918980.stack[R.EXN_STACKHEIGHT++] = $ss1898318984;
}
if(R.isPyretException($e1897918980)) {
$e1897918980.pyretStack.push(L[345]);
}
throw $e1897918980;
}
var $ret1898518986 = $Hann_DASH_check_DASH_temp1138218990($z1898118982);
++R.GAS;
return $ret1898518986;
};
var $Hann_DASH_check_DASH_temp1138218990 = function(ann_DASH_check_DASH_temp815318989) {
return ann_DASH_check_DASH_temp815318989;
};
var $Hanf_arg113812929 = function(anf_arg81492927,dummy_DASH_loc11796,s_DASH_data_DASH_field4432187,self24102926,value24132928) {
var anf_fun815019001 = G(value24132928,"visit",L[3343]);
var $z1899318994 = D;
var $f1899919000 = function(_) {
return R.isFunction(anf_fun815019001)?anf_fun815019001.app(self24102926):R.ffi.throwNonFunApp(L[3342],anf_fun815019001,[self24102926]);
};
try {
if(--R.GAS > 0) {
$z1899318994 = $f1899919000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1899919000,
"from":L[3342]});
}
} catch($e1899118992) {
if(R.isCont($e1899118992)) {
var $ss1899518996 = {"from":L[3342],
"go":function(anf_arg815119002) {
return $Hanf_arg1138019003(anf_arg815119002,anf_arg81492927,dummy_DASH_loc11796,s_DASH_data_DASH_field4432187);
}};
$e1899118992.stack[R.EXN_STACKHEIGHT++] = $ss1899518996;
}
if(R.isPyretException($e1899118992)) {
$e1899118992.pyretStack.push(L[3342]);
}
throw $e1899118992;
}
var $ret1899718998 = $Hanf_arg1138019003($z1899318994,anf_arg81492927,dummy_DASH_loc11796,s_DASH_data_DASH_field4432187);
++R.GAS;
return $ret1899718998;
};
var $Hanf_arg1138019003 = function(anf_arg815119002,anf_arg81492927,dummy_DASH_loc11796,s_DASH_data_DASH_field4432187) {
var $z1900619007 = D;
var $f1901219013 = function(_) {
return R.isFunction(s_DASH_data_DASH_field4432187.$var)?s_DASH_data_DASH_field4432187.$var.app(dummy_DASH_loc11796,anf_arg81492927,anf_arg815119002):R.ffi.throwNonFunApp(L[351],s_DASH_data_DASH_field4432187.$var,[dummy_DASH_loc11796,anf_arg81492927,anf_arg815119002]);
};
try {
if(--R.GAS > 0) {
$z1900619007 = $f1901219013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1901219013,
"from":L[351]});
}
} catch($e1900419005) {
if(R.isCont($e1900419005)) {
var $ss1900819009 = {"from":L[351],
"go":function(ann_DASH_check_DASH_temp814719014) {
return $Hann_DASH_check_DASH_temp1137919015(ann_DASH_check_DASH_temp814719014);
}};
$e1900419005.stack[R.EXN_STACKHEIGHT++] = $ss1900819009;
}
if(R.isPyretException($e1900419005)) {
$e1900419005.pyretStack.push(L[351]);
}
throw $e1900419005;
}
var $ret1901019011 = $Hann_DASH_check_DASH_temp1137919015($z1900619007);
++R.GAS;
return $ret1901019011;
};
var $Hann_DASH_check_DASH_temp1137919015 = function(ann_DASH_check_DASH_temp814719014) {
return ann_DASH_check_DASH_temp814719014;
};
var $Hanf_arg113782947 = function(anf_arg81452944,dummy_DASH_loc11796,keyword_DASH_check24092945,name24072946,s_DASH_check4262153) {
var $z1901819019 = D;
var $f1902419025 = function(_) {
return R.isFunction(s_DASH_check4262153.$var)?s_DASH_check4262153.$var.app(dummy_DASH_loc11796,name24072946,anf_arg81452944,keyword_DASH_check24092945):R.ffi.throwNonFunApp(L[358],s_DASH_check4262153.$var,[dummy_DASH_loc11796,name24072946,anf_arg81452944,keyword_DASH_check24092945]);
};
try {
if(--R.GAS > 0) {
$z1901819019 = $f1902419025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1902419025,
"from":L[358]});
}
} catch($e1901619017) {
if(R.isCont($e1901619017)) {
var $ss1902019021 = {"from":L[358],
"go":function(ann_DASH_check_DASH_temp814319026) {
return $Hann_DASH_check_DASH_temp1137719027(ann_DASH_check_DASH_temp814319026);
}};
$e1901619017.stack[R.EXN_STACKHEIGHT++] = $ss1902019021;
}
if(R.isPyretException($e1901619017)) {
$e1901619017.pyretStack.push(L[358]);
}
throw $e1901619017;
}
var $ret1902219023 = $Hann_DASH_check_DASH_temp1137719027($z1901819019);
++R.GAS;
return $ret1902219023;
};
var $Hann_DASH_check_DASH_temp1137719027 = function(ann_DASH_check_DASH_temp814319026) {
return ann_DASH_check_DASH_temp814319026;
};
var $Hanf_arg113762966 = function(anf_arg81322962,ann24032963,bindings24022964,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961) {
var anf_fun813319038 = G(bindings24022964,"map",L[3346]);
var anf_arg813619039 = R.makeFunction(function(recv_DASH_98919042) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3345],1,arguments);
}
var anf_fun813519053 = G(recv_DASH_98919042,"visit",L[3345]);
var $z1904519046 = D;
var $f1905119052 = function(_) {
return R.isFunction(anf_fun813519053)?anf_fun813519053.app(self23992961):R.ffi.throwNonFunApp(L[3345],anf_fun813519053,[self23992961]);
};
try {
if(--R.GAS > 0) {
$z1904519046 = $f1905119052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1905119052,
"from":L[3345]});
}
} catch($e1904319044) {
if(R.isCont($e1904319044)) {
var $ss1904719048 = {"from":L[3345],
"go":function(ann_DASH_check_DASH_temp813419054) {
return $Hann_DASH_check_DASH_temp1137119055(ann_DASH_check_DASH_temp813419054);
}};
$e1904319044.stack[R.EXN_STACKHEIGHT++] = $ss1904719048;
}
if(R.isPyretException($e1904319044)) {
$e1904319044.pyretStack.push(L[3345]);
}
throw $e1904319044;
}
var $ret1904919050 = $Hann_DASH_check_DASH_temp1137119055($z1904519046);
++R.GAS;
return $ret1904919050;
});
var $z1903019031 = D;
var $f1903619037 = function(_) {
return R.isFunction(anf_fun813319038)?anf_fun813319038.app(anf_arg813619039):R.ffi.throwNonFunApp(L[3344],anf_fun813319038,[anf_arg813619039]);
};
try {
if(--R.GAS > 0) {
$z1903019031 = $f1903619037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1903619037,
"from":L[3344]});
}
} catch($e1902819029) {
if(R.isCont($e1902819029)) {
var $ss1903219033 = {"from":L[3344],
"go":function(anf_arg813719040) {
return $Hanf_arg1137519041(anf_arg813719040,anf_arg81322962,ann24032963,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961);
}};
$e1902819029.stack[R.EXN_STACKHEIGHT++] = $ss1903219033;
}
if(R.isPyretException($e1902819029)) {
$e1902819029.pyretStack.push(L[3344]);
}
throw $e1902819029;
}
var $ret1903419035 = $Hanf_arg1137519041($z1903019031,anf_arg81322962,ann24032963,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961);
++R.GAS;
return $ret1903419035;
};
var $Hanf_arg1137519041 = function(anf_arg813719040,anf_arg81322962,ann24032963,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961) {
var anf_fun813819066 = G(ann24032963,"visit",L[3348]);
var $z1905819059 = D;
var $f1906419065 = function(_) {
return R.isFunction(anf_fun813819066)?anf_fun813819066.app(self23992961):R.ffi.throwNonFunApp(L[3347],anf_fun813819066,[self23992961]);
};
try {
if(--R.GAS > 0) {
$z1905819059 = $f1906419065();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1906419065,
"from":L[3347]});
}
} catch($e1905619057) {
if(R.isCont($e1905619057)) {
var $ss1906019061 = {"from":L[3347],
"go":function(anf_arg813919067) {
return $Hanf_arg1137419068(anf_arg813919067,anf_arg81322962,anf_arg813719040,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961);
}};
$e1905619057.stack[R.EXN_STACKHEIGHT++] = $ss1906019061;
}
if(R.isPyretException($e1905619057)) {
$e1905619057.pyretStack.push(L[3347]);
}
throw $e1905619057;
}
var $ret1906219063 = $Hanf_arg1137419068($z1905819059,anf_arg81322962,anf_arg813719040,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961);
++R.GAS;
return $ret1906219063;
};
var $Hanf_arg1137419068 = function(anf_arg813919067,anf_arg81322962,anf_arg813719040,body24042965,dummy_DASH_loc11796,s_DASH_for4242149,self23992961) {
var anf_fun814019079 = G(body24042965,"visit",L[3350]);
var $z1907119072 = D;
var $f1907719078 = function(_) {
return R.isFunction(anf_fun814019079)?anf_fun814019079.app(self23992961):R.ffi.throwNonFunApp(L[3349],anf_fun814019079,[self23992961]);
};
try {
if(--R.GAS > 0) {
$z1907119072 = $f1907719078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1907719078,
"from":L[3349]});
}
} catch($e1906919070) {
if(R.isCont($e1906919070)) {
var $ss1907319074 = {"from":L[3349],
"go":function(anf_arg814119080) {
return $Hanf_arg1137319081(anf_arg814119080,anf_arg81322962,anf_arg813719040,anf_arg813919067,dummy_DASH_loc11796,s_DASH_for4242149);
}};
$e1906919070.stack[R.EXN_STACKHEIGHT++] = $ss1907319074;
}
if(R.isPyretException($e1906919070)) {
$e1906919070.pyretStack.push(L[3349]);
}
throw $e1906919070;
}
var $ret1907519076 = $Hanf_arg1137319081($z1907119072,anf_arg81322962,anf_arg813719040,anf_arg813919067,dummy_DASH_loc11796,s_DASH_for4242149);
++R.GAS;
return $ret1907519076;
};
var $Hanf_arg1137319081 = function(anf_arg814119080,anf_arg81322962,anf_arg813719040,anf_arg813919067,dummy_DASH_loc11796,s_DASH_for4242149) {
var $z1908419085 = D;
var $f1909019091 = function(_) {
return R.isFunction(s_DASH_for4242149.$var)?s_DASH_for4242149.$var.app(dummy_DASH_loc11796,anf_arg81322962,anf_arg813719040,anf_arg813919067,anf_arg814119080):R.ffi.throwNonFunApp(L[366],s_DASH_for4242149.$var,[dummy_DASH_loc11796,anf_arg81322962,anf_arg813719040,anf_arg813919067,anf_arg814119080]);
};
try {
if(--R.GAS > 0) {
$z1908419085 = $f1909019091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1909019091,
"from":L[366]});
}
} catch($e1908219083) {
if(R.isCont($e1908219083)) {
var $ss1908619087 = {"from":L[366],
"go":function(ann_DASH_check_DASH_temp813019092) {
return $Hann_DASH_check_DASH_temp1137219093(ann_DASH_check_DASH_temp813019092);
}};
$e1908219083.stack[R.EXN_STACKHEIGHT++] = $ss1908619087;
}
if(R.isPyretException($e1908219083)) {
$e1908219083.pyretStack.push(L[366]);
}
throw $e1908219083;
}
var $ret1908819089 = $Hann_DASH_check_DASH_temp1137219093($z1908419085);
++R.GAS;
return $ret1908819089;
};
var $Hann_DASH_check_DASH_temp1137219093 = function(ann_DASH_check_DASH_temp813019092) {
return ann_DASH_check_DASH_temp813019092;
};
var $Hann_DASH_check_DASH_temp1137119055 = function(ann_DASH_check_DASH_temp813419054) {
return ann_DASH_check_DASH_temp813419054;
};
var $Hanf_arg113702988 = function(anf_arg81062981,_check23982982,dummy_DASH_loc11796,mixins23952983,name23922984,params23942985,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987) {
var anf_fun810719104 = G(params23942985,"map",L[3353]);
var anf_arg811019105 = R.makeFunction(function(recv_DASH_98519108) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3352],1,arguments);
}
var anf_fun810919119 = G(recv_DASH_98519108,"visit",L[3352]);
var $z1911119112 = D;
var $f1911719118 = function(_) {
return R.isFunction(anf_fun810919119)?anf_fun810919119.app(self23902980):R.ffi.throwNonFunApp(L[3352],anf_fun810919119,[self23902980]);
};
try {
if(--R.GAS > 0) {
$z1911119112 = $f1911719118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1911719118,
"from":L[3352]});
}
} catch($e1910919110) {
if(R.isCont($e1910919110)) {
var $ss1911319114 = {"from":L[3352],
"go":function(ann_DASH_check_DASH_temp810819120) {
return $Hann_DASH_check_DASH_temp1136019121(ann_DASH_check_DASH_temp810819120);
}};
$e1910919110.stack[R.EXN_STACKHEIGHT++] = $ss1911319114;
}
if(R.isPyretException($e1910919110)) {
$e1910919110.pyretStack.push(L[3352]);
}
throw $e1910919110;
}
var $ret1911519116 = $Hann_DASH_check_DASH_temp1136019121($z1911119112);
++R.GAS;
return $ret1911519116;
});
var $z1909619097 = D;
var $f1910219103 = function(_) {
return R.isFunction(anf_fun810719104)?anf_fun810719104.app(anf_arg811019105):R.ffi.throwNonFunApp(L[3351],anf_fun810719104,[anf_arg811019105]);
};
try {
if(--R.GAS > 0) {
$z1909619097 = $f1910219103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1910219103,
"from":L[3351]});
}
} catch($e1909419095) {
if(R.isCont($e1909419095)) {
var $ss1909819099 = {"from":L[3351],
"go":function(anf_arg811119106) {
return $Hanf_arg1136919107(anf_arg811119106,_check23982982,anf_arg81062981,dummy_DASH_loc11796,mixins23952983,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987);
}};
$e1909419095.stack[R.EXN_STACKHEIGHT++] = $ss1909819099;
}
if(R.isPyretException($e1909419095)) {
$e1909419095.pyretStack.push(L[3351]);
}
throw $e1909419095;
}
var $ret1910019101 = $Hanf_arg1136919107($z1909619097,_check23982982,anf_arg81062981,dummy_DASH_loc11796,mixins23952983,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987);
++R.GAS;
return $ret1910019101;
};
var $Hanf_arg1136919107 = function(anf_arg811119106,_check23982982,anf_arg81062981,dummy_DASH_loc11796,mixins23952983,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987) {
var anf_fun811219132 = G(mixins23952983,"map",L[3356]);
var anf_arg811519133 = R.makeFunction(function(recv_DASH_98619136) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3355],1,arguments);
}
var anf_fun811419147 = G(recv_DASH_98619136,"visit",L[3355]);
var $z1913919140 = D;
var $f1914519146 = function(_) {
return R.isFunction(anf_fun811419147)?anf_fun811419147.app(self23902980):R.ffi.throwNonFunApp(L[3355],anf_fun811419147,[self23902980]);
};
try {
if(--R.GAS > 0) {
$z1913919140 = $f1914519146();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1914519146,
"from":L[3355]});
}
} catch($e1913719138) {
if(R.isCont($e1913719138)) {
var $ss1914119142 = {"from":L[3355],
"go":function(ann_DASH_check_DASH_temp811319148) {
return $Hann_DASH_check_DASH_temp1136119149(ann_DASH_check_DASH_temp811319148);
}};
$e1913719138.stack[R.EXN_STACKHEIGHT++] = $ss1914119142;
}
if(R.isPyretException($e1913719138)) {
$e1913719138.pyretStack.push(L[3355]);
}
throw $e1913719138;
}
var $ret1914319144 = $Hann_DASH_check_DASH_temp1136119149($z1913919140);
++R.GAS;
return $ret1914319144;
});
var $z1912419125 = D;
var $f1913019131 = function(_) {
return R.isFunction(anf_fun811219132)?anf_fun811219132.app(anf_arg811519133):R.ffi.throwNonFunApp(L[3354],anf_fun811219132,[anf_arg811519133]);
};
try {
if(--R.GAS > 0) {
$z1912419125 = $f1913019131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1913019131,
"from":L[3354]});
}
} catch($e1912219123) {
if(R.isCont($e1912219123)) {
var $ss1912619127 = {"from":L[3354],
"go":function(anf_arg811619134) {
return $Hanf_arg1136819135(anf_arg811619134,_check23982982,anf_arg81062981,anf_arg811119106,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987);
}};
$e1912219123.stack[R.EXN_STACKHEIGHT++] = $ss1912619127;
}
if(R.isPyretException($e1912219123)) {
$e1912219123.pyretStack.push(L[3354]);
}
throw $e1912219123;
}
var $ret1912819129 = $Hanf_arg1136819135($z1912419125,_check23982982,anf_arg81062981,anf_arg811119106,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987);
++R.GAS;
return $ret1912819129;
};
var $Hanf_arg1136819135 = function(anf_arg811619134,_check23982982,anf_arg81062981,anf_arg811119106,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986,variants23962987) {
var anf_fun811719160 = G(variants23962987,"map",L[3359]);
var anf_arg812019161 = R.makeFunction(function(recv_DASH_98719164) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3358],1,arguments);
}
var anf_fun811919175 = G(recv_DASH_98719164,"visit",L[3358]);
var $z1916719168 = D;
var $f1917319174 = function(_) {
return R.isFunction(anf_fun811919175)?anf_fun811919175.app(self23902980):R.ffi.throwNonFunApp(L[3358],anf_fun811919175,[self23902980]);
};
try {
if(--R.GAS > 0) {
$z1916719168 = $f1917319174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1917319174,
"from":L[3358]});
}
} catch($e1916519166) {
if(R.isCont($e1916519166)) {
var $ss1916919170 = {"from":L[3358],
"go":function(ann_DASH_check_DASH_temp811819176) {
return $Hann_DASH_check_DASH_temp1136219177(ann_DASH_check_DASH_temp811819176);
}};
$e1916519166.stack[R.EXN_STACKHEIGHT++] = $ss1916919170;
}
if(R.isPyretException($e1916519166)) {
$e1916519166.pyretStack.push(L[3358]);
}
throw $e1916519166;
}
var $ret1917119172 = $Hann_DASH_check_DASH_temp1136219177($z1916719168);
++R.GAS;
return $ret1917119172;
});
var $z1915219153 = D;
var $f1915819159 = function(_) {
return R.isFunction(anf_fun811719160)?anf_fun811719160.app(anf_arg812019161):R.ffi.throwNonFunApp(L[3357],anf_fun811719160,[anf_arg812019161]);
};
try {
if(--R.GAS > 0) {
$z1915219153 = $f1915819159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1915819159,
"from":L[3357]});
}
} catch($e1915019151) {
if(R.isCont($e1915019151)) {
var $ss1915419155 = {"from":L[3357],
"go":function(anf_arg812119162) {
return $Hanf_arg1136719163(anf_arg812119162,_check23982982,anf_arg81062981,anf_arg811119106,anf_arg811619134,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986);
}};
$e1915019151.stack[R.EXN_STACKHEIGHT++] = $ss1915419155;
}
if(R.isPyretException($e1915019151)) {
$e1915019151.pyretStack.push(L[3357]);
}
throw $e1915019151;
}
var $ret1915619157 = $Hanf_arg1136719163($z1915219153,_check23982982,anf_arg81062981,anf_arg811119106,anf_arg811619134,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986);
++R.GAS;
return $ret1915619157;
};
var $Hanf_arg1136719163 = function(anf_arg812119162,_check23982982,anf_arg81062981,anf_arg811119106,anf_arg811619134,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980,shared_DASH_members23972986) {
var anf_fun812219188 = G(shared_DASH_members23972986,"map",L[3362]);
var anf_arg812519189 = R.makeFunction(function(recv_DASH_98819192) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3361],1,arguments);
}
var anf_fun812419203 = G(recv_DASH_98819192,"visit",L[3361]);
var $z1919519196 = D;
var $f1920119202 = function(_) {
return R.isFunction(anf_fun812419203)?anf_fun812419203.app(self23902980):R.ffi.throwNonFunApp(L[3361],anf_fun812419203,[self23902980]);
};
try {
if(--R.GAS > 0) {
$z1919519196 = $f1920119202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1920119202,
"from":L[3361]});
}
} catch($e1919319194) {
if(R.isCont($e1919319194)) {
var $ss1919719198 = {"from":L[3361],
"go":function(ann_DASH_check_DASH_temp812319204) {
return $Hann_DASH_check_DASH_temp1136319205(ann_DASH_check_DASH_temp812319204);
}};
$e1919319194.stack[R.EXN_STACKHEIGHT++] = $ss1919719198;
}
if(R.isPyretException($e1919319194)) {
$e1919319194.pyretStack.push(L[3361]);
}
throw $e1919319194;
}
var $ret1919919200 = $Hann_DASH_check_DASH_temp1136319205($z1919519196);
++R.GAS;
return $ret1919919200;
});
var $z1918019181 = D;
var $f1918619187 = function(_) {
return R.isFunction(anf_fun812219188)?anf_fun812219188.app(anf_arg812519189):R.ffi.throwNonFunApp(L[3360],anf_fun812219188,[anf_arg812519189]);
};
try {
if(--R.GAS > 0) {
$z1918019181 = $f1918619187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1918619187,
"from":L[3360]});
}
} catch($e1917819179) {
if(R.isCont($e1917819179)) {
var $ss1918219183 = {"from":L[3360],
"go":function(anf_arg812619190) {
return $Hanf_arg1136619191(anf_arg812619190,_check23982982,anf_arg81062981,anf_arg811119106,anf_arg811619134,anf_arg812119162,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980);
}};
$e1917819179.stack[R.EXN_STACKHEIGHT++] = $ss1918219183;
}
if(R.isPyretException($e1917819179)) {
$e1917819179.pyretStack.push(L[3360]);
}
throw $e1917819179;
}
var $ret1918419185 = $Hanf_arg1136619191($z1918019181,_check23982982,anf_arg81062981,anf_arg811119106,anf_arg811619134,anf_arg812119162,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980);
++R.GAS;
return $ret1918419185;
};
var $Hanf_arg1136619191 = function(anf_arg812619190,_check23982982,anf_arg81062981,anf_arg811119106,anf_arg811619134,anf_arg812119162,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145,self23902980) {
var anf_fun812719216 = G(self23902980,"option",L[3364]);
var $z1920819209 = D;
var $f1921419215 = function(_) {
return R.isFunction(anf_fun812719216)?anf_fun812719216.app(_check23982982):R.ffi.throwNonFunApp(L[3363],anf_fun812719216,[_check23982982]);
};
try {
if(--R.GAS > 0) {
$z1920819209 = $f1921419215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1921419215,
"from":L[3363]});
}
} catch($e1920619207) {
if(R.isCont($e1920619207)) {
var $ss1921019211 = {"from":L[3363],
"go":function(anf_arg812819217) {
return $Hanf_arg1136519218(anf_arg812819217,anf_arg81062981,anf_arg811119106,anf_arg811619134,anf_arg812119162,anf_arg812619190,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145);
}};
$e1920619207.stack[R.EXN_STACKHEIGHT++] = $ss1921019211;
}
if(R.isPyretException($e1920619207)) {
$e1920619207.pyretStack.push(L[3363]);
}
throw $e1920619207;
}
var $ret1921219213 = $Hanf_arg1136519218($z1920819209,anf_arg81062981,anf_arg811119106,anf_arg811619134,anf_arg812119162,anf_arg812619190,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145);
++R.GAS;
return $ret1921219213;
};
var $Hanf_arg1136519218 = function(anf_arg812819217,anf_arg81062981,anf_arg811119106,anf_arg811619134,anf_arg812119162,anf_arg812619190,dummy_DASH_loc11796,name23922984,s_DASH_data_DASH_expr4222145) {
var $z1922119222 = D;
var $f1922719228 = function(_) {
return R.isFunction(s_DASH_data_DASH_expr4222145.$var)?s_DASH_data_DASH_expr4222145.$var.app(dummy_DASH_loc11796,name23922984,anf_arg81062981,anf_arg811119106,anf_arg811619134,anf_arg812119162,anf_arg812619190,anf_arg812819217):R.ffi.throwNonFunApp(L[377],s_DASH_data_DASH_expr4222145.$var,[dummy_DASH_loc11796,name23922984,anf_arg81062981,anf_arg811119106,anf_arg811619134,anf_arg812119162,anf_arg812619190,anf_arg812819217]);
};
try {
if(--R.GAS > 0) {
$z1922119222 = $f1922719228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1922719228,
"from":L[377]});
}
} catch($e1921919220) {
if(R.isCont($e1921919220)) {
var $ss1922319224 = {"from":L[377],
"go":function(ann_DASH_check_DASH_temp810419229) {
return $Hann_DASH_check_DASH_temp1136419230(ann_DASH_check_DASH_temp810419229);
}};
$e1921919220.stack[R.EXN_STACKHEIGHT++] = $ss1922319224;
}
if(R.isPyretException($e1921919220)) {
$e1921919220.pyretStack.push(L[377]);
}
throw $e1921919220;
}
var $ret1922519226 = $Hann_DASH_check_DASH_temp1136419230($z1922119222);
++R.GAS;
return $ret1922519226;
};
var $Hann_DASH_check_DASH_temp1136419230 = function(ann_DASH_check_DASH_temp810419229) {
return ann_DASH_check_DASH_temp810419229;
};
var $Hann_DASH_check_DASH_temp1136319205 = function(ann_DASH_check_DASH_temp812319204) {
return ann_DASH_check_DASH_temp812319204;
};
var $Hann_DASH_check_DASH_temp1136219177 = function(ann_DASH_check_DASH_temp811819176) {
return ann_DASH_check_DASH_temp811819176;
};
var $Hann_DASH_check_DASH_temp1136119149 = function(ann_DASH_check_DASH_temp811319148) {
return ann_DASH_check_DASH_temp811319148;
};
var $Hann_DASH_check_DASH_temp1136019121 = function(ann_DASH_check_DASH_temp810819120) {
return ann_DASH_check_DASH_temp810819120;
};
var $Hanf_arg113593010 = function(anf_arg80853003,_check23893004,dummy_DASH_loc11796,mixins23863005,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008,variants23873009) {
var anf_fun808619241 = G(mixins23863005,"map",L[3367]);
var anf_arg808919242 = R.makeFunction(function(recv_DASH_98219245) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3366],1,arguments);
}
var anf_fun808819256 = G(recv_DASH_98219245,"visit",L[3366]);
var $z1924819249 = D;
var $f1925419255 = function(_) {
return R.isFunction(anf_fun808819256)?anf_fun808819256.app(self23823007):R.ffi.throwNonFunApp(L[3366],anf_fun808819256,[self23823007]);
};
try {
if(--R.GAS > 0) {
$z1924819249 = $f1925419255();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1925419255,
"from":L[3366]});
}
} catch($e1924619247) {
if(R.isCont($e1924619247)) {
var $ss1925019251 = {"from":L[3366],
"go":function(ann_DASH_check_DASH_temp808719257) {
return $Hann_DASH_check_DASH_temp1135119258(ann_DASH_check_DASH_temp808719257);
}};
$e1924619247.stack[R.EXN_STACKHEIGHT++] = $ss1925019251;
}
if(R.isPyretException($e1924619247)) {
$e1924619247.pyretStack.push(L[3366]);
}
throw $e1924619247;
}
var $ret1925219253 = $Hann_DASH_check_DASH_temp1135119258($z1924819249);
++R.GAS;
return $ret1925219253;
});
var $z1923319234 = D;
var $f1923919240 = function(_) {
return R.isFunction(anf_fun808619241)?anf_fun808619241.app(anf_arg808919242):R.ffi.throwNonFunApp(L[3365],anf_fun808619241,[anf_arg808919242]);
};
try {
if(--R.GAS > 0) {
$z1923319234 = $f1923919240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1923919240,
"from":L[3365]});
}
} catch($e1923119232) {
if(R.isCont($e1923119232)) {
var $ss1923519236 = {"from":L[3365],
"go":function(anf_arg809019243) {
return $Hanf_arg1135819244(anf_arg809019243,_check23893004,anf_arg80853003,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008,variants23873009);
}};
$e1923119232.stack[R.EXN_STACKHEIGHT++] = $ss1923519236;
}
if(R.isPyretException($e1923119232)) {
$e1923119232.pyretStack.push(L[3365]);
}
throw $e1923119232;
}
var $ret1923719238 = $Hanf_arg1135819244($z1923319234,_check23893004,anf_arg80853003,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008,variants23873009);
++R.GAS;
return $ret1923719238;
};
var $Hanf_arg1135819244 = function(anf_arg809019243,_check23893004,anf_arg80853003,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008,variants23873009) {
var anf_fun809119269 = G(variants23873009,"map",L[3370]);
var anf_arg809419270 = R.makeFunction(function(recv_DASH_98319273) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3369],1,arguments);
}
var anf_fun809319284 = G(recv_DASH_98319273,"visit",L[3369]);
var $z1927619277 = D;
var $f1928219283 = function(_) {
return R.isFunction(anf_fun809319284)?anf_fun809319284.app(self23823007):R.ffi.throwNonFunApp(L[3369],anf_fun809319284,[self23823007]);
};
try {
if(--R.GAS > 0) {
$z1927619277 = $f1928219283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1928219283,
"from":L[3369]});
}
} catch($e1927419275) {
if(R.isCont($e1927419275)) {
var $ss1927819279 = {"from":L[3369],
"go":function(ann_DASH_check_DASH_temp809219285) {
return $Hann_DASH_check_DASH_temp1135219286(ann_DASH_check_DASH_temp809219285);
}};
$e1927419275.stack[R.EXN_STACKHEIGHT++] = $ss1927819279;
}
if(R.isPyretException($e1927419275)) {
$e1927419275.pyretStack.push(L[3369]);
}
throw $e1927419275;
}
var $ret1928019281 = $Hann_DASH_check_DASH_temp1135219286($z1927619277);
++R.GAS;
return $ret1928019281;
});
var $z1926119262 = D;
var $f1926719268 = function(_) {
return R.isFunction(anf_fun809119269)?anf_fun809119269.app(anf_arg809419270):R.ffi.throwNonFunApp(L[3368],anf_fun809119269,[anf_arg809419270]);
};
try {
if(--R.GAS > 0) {
$z1926119262 = $f1926719268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1926719268,
"from":L[3368]});
}
} catch($e1925919260) {
if(R.isCont($e1925919260)) {
var $ss1926319264 = {"from":L[3368],
"go":function(anf_arg809519271) {
return $Hanf_arg1135719272(anf_arg809519271,_check23893004,anf_arg80853003,anf_arg809019243,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008);
}};
$e1925919260.stack[R.EXN_STACKHEIGHT++] = $ss1926319264;
}
if(R.isPyretException($e1925919260)) {
$e1925919260.pyretStack.push(L[3368]);
}
throw $e1925919260;
}
var $ret1926519266 = $Hanf_arg1135719272($z1926119262,_check23893004,anf_arg80853003,anf_arg809019243,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008);
++R.GAS;
return $ret1926519266;
};
var $Hanf_arg1135719272 = function(anf_arg809519271,_check23893004,anf_arg80853003,anf_arg809019243,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007,shared_DASH_members23883008) {
var anf_fun809619297 = G(shared_DASH_members23883008,"map",L[3373]);
var anf_arg809919298 = R.makeFunction(function(recv_DASH_98419301) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3372],1,arguments);
}
var anf_fun809819312 = G(recv_DASH_98419301,"visit",L[3372]);
var $z1930419305 = D;
var $f1931019311 = function(_) {
return R.isFunction(anf_fun809819312)?anf_fun809819312.app(self23823007):R.ffi.throwNonFunApp(L[3372],anf_fun809819312,[self23823007]);
};
try {
if(--R.GAS > 0) {
$z1930419305 = $f1931019311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1931019311,
"from":L[3372]});
}
} catch($e1930219303) {
if(R.isCont($e1930219303)) {
var $ss1930619307 = {"from":L[3372],
"go":function(ann_DASH_check_DASH_temp809719313) {
return $Hann_DASH_check_DASH_temp1135319314(ann_DASH_check_DASH_temp809719313);
}};
$e1930219303.stack[R.EXN_STACKHEIGHT++] = $ss1930619307;
}
if(R.isPyretException($e1930219303)) {
$e1930219303.pyretStack.push(L[3372]);
}
throw $e1930219303;
}
var $ret1930819309 = $Hann_DASH_check_DASH_temp1135319314($z1930419305);
++R.GAS;
return $ret1930819309;
});
var $z1928919290 = D;
var $f1929519296 = function(_) {
return R.isFunction(anf_fun809619297)?anf_fun809619297.app(anf_arg809919298):R.ffi.throwNonFunApp(L[3371],anf_fun809619297,[anf_arg809919298]);
};
try {
if(--R.GAS > 0) {
$z1928919290 = $f1929519296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1929519296,
"from":L[3371]});
}
} catch($e1928719288) {
if(R.isCont($e1928719288)) {
var $ss1929119292 = {"from":L[3371],
"go":function(anf_arg810019299) {
return $Hanf_arg1135619300(anf_arg810019299,_check23893004,anf_arg80853003,anf_arg809019243,anf_arg809519271,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007);
}};
$e1928719288.stack[R.EXN_STACKHEIGHT++] = $ss1929119292;
}
if(R.isPyretException($e1928719288)) {
$e1928719288.pyretStack.push(L[3371]);
}
throw $e1928719288;
}
var $ret1929319294 = $Hanf_arg1135619300($z1928919290,_check23893004,anf_arg80853003,anf_arg809019243,anf_arg809519271,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007);
++R.GAS;
return $ret1929319294;
};
var $Hanf_arg1135619300 = function(anf_arg810019299,_check23893004,anf_arg80853003,anf_arg809019243,anf_arg809519271,dummy_DASH_loc11796,name23843006,s_DASH_data4202141,self23823007) {
var anf_fun810119325 = G(self23823007,"option",L[3375]);
var $z1931719318 = D;
var $f1932319324 = function(_) {
return R.isFunction(anf_fun810119325)?anf_fun810119325.app(_check23893004):R.ffi.throwNonFunApp(L[3374],anf_fun810119325,[_check23893004]);
};
try {
if(--R.GAS > 0) {
$z1931719318 = $f1932319324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1932319324,
"from":L[3374]});
}
} catch($e1931519316) {
if(R.isCont($e1931519316)) {
var $ss1931919320 = {"from":L[3374],
"go":function(anf_arg810219326) {
return $Hanf_arg1135519327(anf_arg810219326,anf_arg80853003,anf_arg809019243,anf_arg809519271,anf_arg810019299,dummy_DASH_loc11796,name23843006,s_DASH_data4202141);
}};
$e1931519316.stack[R.EXN_STACKHEIGHT++] = $ss1931919320;
}
if(R.isPyretException($e1931519316)) {
$e1931519316.pyretStack.push(L[3374]);
}
throw $e1931519316;
}
var $ret1932119322 = $Hanf_arg1135519327($z1931719318,anf_arg80853003,anf_arg809019243,anf_arg809519271,anf_arg810019299,dummy_DASH_loc11796,name23843006,s_DASH_data4202141);
++R.GAS;
return $ret1932119322;
};
var $Hanf_arg1135519327 = function(anf_arg810219326,anf_arg80853003,anf_arg809019243,anf_arg809519271,anf_arg810019299,dummy_DASH_loc11796,name23843006,s_DASH_data4202141) {
var $z1933019331 = D;
var $f1933619337 = function(_) {
return R.isFunction(s_DASH_data4202141.$var)?s_DASH_data4202141.$var.app(dummy_DASH_loc11796,name23843006,anf_arg80853003,anf_arg809019243,anf_arg809519271,anf_arg810019299,anf_arg810219326):R.ffi.throwNonFunApp(L[388],s_DASH_data4202141.$var,[dummy_DASH_loc11796,name23843006,anf_arg80853003,anf_arg809019243,anf_arg809519271,anf_arg810019299,anf_arg810219326]);
};
try {
if(--R.GAS > 0) {
$z1933019331 = $f1933619337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1933619337,
"from":L[388]});
}
} catch($e1932819329) {
if(R.isCont($e1932819329)) {
var $ss1933219333 = {"from":L[388],
"go":function(ann_DASH_check_DASH_temp808019338) {
return $Hann_DASH_check_DASH_temp1135419339(ann_DASH_check_DASH_temp808019338);
}};
$e1932819329.stack[R.EXN_STACKHEIGHT++] = $ss1933219333;
}
if(R.isPyretException($e1932819329)) {
$e1932819329.pyretStack.push(L[388]);
}
throw $e1932819329;
}
var $ret1933419335 = $Hann_DASH_check_DASH_temp1135419339($z1933019331);
++R.GAS;
return $ret1933419335;
};
var $Hann_DASH_check_DASH_temp1135419339 = function(ann_DASH_check_DASH_temp808019338) {
return ann_DASH_check_DASH_temp808019338;
};
var $Hann_DASH_check_DASH_temp1135319314 = function(ann_DASH_check_DASH_temp809719313) {
return ann_DASH_check_DASH_temp809719313;
};
var $Hann_DASH_check_DASH_temp1135219286 = function(ann_DASH_check_DASH_temp809219285) {
return ann_DASH_check_DASH_temp809219285;
};
var $Hann_DASH_check_DASH_temp1135119258 = function(ann_DASH_check_DASH_temp808719257) {
return ann_DASH_check_DASH_temp808719257;
};
var $Hann_DASH_check_DASH_temp113503024 = function(ann_DASH_check_DASH_temp80823023) {
return ann_DASH_check_DASH_temp80823023;
};
var $Hanf_arg113493041 = function(anf_arg80763039,dummy_DASH_loc11796,field23813040,s_DASH_bracket4182137,self23783038) {
var anf_fun807719350 = G(field23813040,"visit",L[3377]);
var $z1934219343 = D;
var $f1934819349 = function(_) {
return R.isFunction(anf_fun807719350)?anf_fun807719350.app(self23783038):R.ffi.throwNonFunApp(L[3376],anf_fun807719350,[self23783038]);
};
try {
if(--R.GAS > 0) {
$z1934219343 = $f1934819349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1934819349,
"from":L[3376]});
}
} catch($e1934019341) {
if(R.isCont($e1934019341)) {
var $ss1934419345 = {"from":L[3376],
"go":function(anf_arg807819351) {
return $Hanf_arg1134819352(anf_arg807819351,anf_arg80763039,dummy_DASH_loc11796,s_DASH_bracket4182137);
}};
$e1934019341.stack[R.EXN_STACKHEIGHT++] = $ss1934419345;
}
if(R.isPyretException($e1934019341)) {
$e1934019341.pyretStack.push(L[3376]);
}
throw $e1934019341;
}
var $ret1934619347 = $Hanf_arg1134819352($z1934219343,anf_arg80763039,dummy_DASH_loc11796,s_DASH_bracket4182137);
++R.GAS;
return $ret1934619347;
};
var $Hanf_arg1134819352 = function(anf_arg807819351,anf_arg80763039,dummy_DASH_loc11796,s_DASH_bracket4182137) {
var $z1935519356 = D;
var $f1936119362 = function(_) {
return R.isFunction(s_DASH_bracket4182137.$var)?s_DASH_bracket4182137.$var.app(dummy_DASH_loc11796,anf_arg80763039,anf_arg807819351):R.ffi.throwNonFunApp(L[394],s_DASH_bracket4182137.$var,[dummy_DASH_loc11796,anf_arg80763039,anf_arg807819351]);
};
try {
if(--R.GAS > 0) {
$z1935519356 = $f1936119362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1936119362,
"from":L[394]});
}
} catch($e1935319354) {
if(R.isCont($e1935319354)) {
var $ss1935719358 = {"from":L[394],
"go":function(ann_DASH_check_DASH_temp807419363) {
return $Hann_DASH_check_DASH_temp1134719364(ann_DASH_check_DASH_temp807419363);
}};
$e1935319354.stack[R.EXN_STACKHEIGHT++] = $ss1935719358;
}
if(R.isPyretException($e1935319354)) {
$e1935319354.pyretStack.push(L[394]);
}
throw $e1935319354;
}
var $ret1935919360 = $Hann_DASH_check_DASH_temp1134719364($z1935519356);
++R.GAS;
return $ret1935919360;
};
var $Hann_DASH_check_DASH_temp1134719364 = function(ann_DASH_check_DASH_temp807419363) {
return ann_DASH_check_DASH_temp807419363;
};
var $Hanf_arg113463058 = function(anf_arg80723056,dummy_DASH_loc11796,field23773057,s_DASH_get_DASH_bang4162133) {
var $z1936719368 = D;
var $f1937319374 = function(_) {
return R.isFunction(s_DASH_get_DASH_bang4162133.$var)?s_DASH_get_DASH_bang4162133.$var.app(dummy_DASH_loc11796,anf_arg80723056,field23773057):R.ffi.throwNonFunApp(L[400],s_DASH_get_DASH_bang4162133.$var,[dummy_DASH_loc11796,anf_arg80723056,field23773057]);
};
try {
if(--R.GAS > 0) {
$z1936719368 = $f1937319374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1937319374,
"from":L[400]});
}
} catch($e1936519366) {
if(R.isCont($e1936519366)) {
var $ss1936919370 = {"from":L[400],
"go":function(ann_DASH_check_DASH_temp807019375) {
return $Hann_DASH_check_DASH_temp1134519376(ann_DASH_check_DASH_temp807019375);
}};
$e1936519366.stack[R.EXN_STACKHEIGHT++] = $ss1936919370;
}
if(R.isPyretException($e1936519366)) {
$e1936519366.pyretStack.push(L[400]);
}
throw $e1936519366;
}
var $ret1937119372 = $Hann_DASH_check_DASH_temp1134519376($z1936719368);
++R.GAS;
return $ret1937119372;
};
var $Hann_DASH_check_DASH_temp1134519376 = function(ann_DASH_check_DASH_temp807019375) {
return ann_DASH_check_DASH_temp807019375;
};
var $Hanf_arg113443075 = function(anf_arg80683073,dummy_DASH_loc11796,field23733074,s_DASH_dot4142129) {
var $z1937919380 = D;
var $f1938519386 = function(_) {
return R.isFunction(s_DASH_dot4142129.$var)?s_DASH_dot4142129.$var.app(dummy_DASH_loc11796,anf_arg80683073,field23733074):R.ffi.throwNonFunApp(L[406],s_DASH_dot4142129.$var,[dummy_DASH_loc11796,anf_arg80683073,field23733074]);
};
try {
if(--R.GAS > 0) {
$z1937919380 = $f1938519386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1938519386,
"from":L[406]});
}
} catch($e1937719378) {
if(R.isCont($e1937719378)) {
var $ss1938119382 = {"from":L[406],
"go":function(ann_DASH_check_DASH_temp806619387) {
return $Hann_DASH_check_DASH_temp1134319388(ann_DASH_check_DASH_temp806619387);
}};
$e1937719378.stack[R.EXN_STACKHEIGHT++] = $ss1938119382;
}
if(R.isPyretException($e1937719378)) {
$e1937719378.pyretStack.push(L[406]);
}
throw $e1937719378;
}
var $ret1938319384 = $Hann_DASH_check_DASH_temp1134319388($z1937919380);
++R.GAS;
return $ret1938319384;
};
var $Hann_DASH_check_DASH_temp1134319388 = function(ann_DASH_check_DASH_temp806619387) {
return ann_DASH_check_DASH_temp806619387;
};
var $Hann_DASH_check_DASH_temp113423090 = function(ann_DASH_check_DASH_temp80643089) {
return ann_DASH_check_DASH_temp80643089;
};
var $Hann_DASH_check_DASH_temp113413105 = function(ann_DASH_check_DASH_temp80623104) {
return ann_DASH_check_DASH_temp80623104;
};
var $Hann_DASH_check_DASH_temp113403121 = function(ann_DASH_check_DASH_temp80603120) {
return ann_DASH_check_DASH_temp80603120;
};
var $Hann_DASH_check_DASH_temp113393136 = function(ann_DASH_check_DASH_temp80583135) {
return ann_DASH_check_DASH_temp80583135;
};
var $Hann_DASH_check_DASH_temp113383151 = function(ann_DASH_check_DASH_temp80563150) {
return ann_DASH_check_DASH_temp80563150;
};
var $Hann_DASH_check_DASH_temp113373166 = function(ann_DASH_check_DASH_temp80543165) {
return ann_DASH_check_DASH_temp80543165;
};
var $Hanf_arg113363182 = function(anf_arg80523180,dummy_DASH_loc11796,s_DASH_id_DASH_letrec4002101,safe23513181) {
var $z1939119392 = D;
var $f1939719398 = function(_) {
return R.isFunction(s_DASH_id_DASH_letrec4002101.$var)?s_DASH_id_DASH_letrec4002101.$var.app(dummy_DASH_loc11796,anf_arg80523180,safe23513181):R.ffi.throwNonFunApp(L[428],s_DASH_id_DASH_letrec4002101.$var,[dummy_DASH_loc11796,anf_arg80523180,safe23513181]);
};
try {
if(--R.GAS > 0) {
$z1939119392 = $f1939719398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1939719398,
"from":L[428]});
}
} catch($e1938919390) {
if(R.isCont($e1938919390)) {
var $ss1939319394 = {"from":L[428],
"go":function(ann_DASH_check_DASH_temp805019399) {
return $Hann_DASH_check_DASH_temp1133519400(ann_DASH_check_DASH_temp805019399);
}};
$e1938919390.stack[R.EXN_STACKHEIGHT++] = $ss1939319394;
}
if(R.isPyretException($e1938919390)) {
$e1938919390.pyretStack.push(L[428]);
}
throw $e1938919390;
}
var $ret1939519396 = $Hann_DASH_check_DASH_temp1133519400($z1939119392);
++R.GAS;
return $ret1939519396;
};
var $Hann_DASH_check_DASH_temp1133519400 = function(ann_DASH_check_DASH_temp805019399) {
return ann_DASH_check_DASH_temp805019399;
};
var $Hanf_arg113343198 = function(anf_arg80483197,dummy_DASH_loc11796,s_DASH_id_DASH_var3982097) {
var $z1940319404 = D;
var $f1940919410 = function(_) {
return R.isFunction(s_DASH_id_DASH_var3982097.$var)?s_DASH_id_DASH_var3982097.$var.app(dummy_DASH_loc11796,anf_arg80483197):R.ffi.throwNonFunApp(L[433],s_DASH_id_DASH_var3982097.$var,[dummy_DASH_loc11796,anf_arg80483197]);
};
try {
if(--R.GAS > 0) {
$z1940319404 = $f1940919410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1940919410,
"from":L[433]});
}
} catch($e1940119402) {
if(R.isCont($e1940119402)) {
var $ss1940519406 = {"from":L[433],
"go":function(ann_DASH_check_DASH_temp804619411) {
return $Hann_DASH_check_DASH_temp1133319412(ann_DASH_check_DASH_temp804619411);
}};
$e1940119402.stack[R.EXN_STACKHEIGHT++] = $ss1940519406;
}
if(R.isPyretException($e1940119402)) {
$e1940119402.pyretStack.push(L[433]);
}
throw $e1940119402;
}
var $ret1940719408 = $Hann_DASH_check_DASH_temp1133319412($z1940319404);
++R.GAS;
return $ret1940719408;
};
var $Hann_DASH_check_DASH_temp1133319412 = function(ann_DASH_check_DASH_temp804619411) {
return ann_DASH_check_DASH_temp804619411;
};
var $Hanf_arg113323214 = function(anf_arg80443213,dummy_DASH_loc11796,s_DASH_id3962093) {
var $z1941519416 = D;
var $f1942119422 = function(_) {
return R.isFunction(s_DASH_id3962093.$var)?s_DASH_id3962093.$var.app(dummy_DASH_loc11796,anf_arg80443213):R.ffi.throwNonFunApp(L[438],s_DASH_id3962093.$var,[dummy_DASH_loc11796,anf_arg80443213]);
};
try {
if(--R.GAS > 0) {
$z1941519416 = $f1942119422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1942119422,
"from":L[438]});
}
} catch($e1941319414) {
if(R.isCont($e1941319414)) {
var $ss1941719418 = {"from":L[438],
"go":function(ann_DASH_check_DASH_temp804219423) {
return $Hann_DASH_check_DASH_temp1133119424(ann_DASH_check_DASH_temp804219423);
}};
$e1941319414.stack[R.EXN_STACKHEIGHT++] = $ss1941719418;
}
if(R.isPyretException($e1941319414)) {
$e1941319414.pyretStack.push(L[438]);
}
throw $e1941319414;
}
var $ret1941919420 = $Hann_DASH_check_DASH_temp1133119424($z1941519416);
++R.GAS;
return $ret1941919420;
};
var $Hann_DASH_check_DASH_temp1133119424 = function(ann_DASH_check_DASH_temp804219423) {
return ann_DASH_check_DASH_temp804219423;
};
var $Hann_DASH_check_DASH_temp113303229 = function(ann_DASH_check_DASH_temp80403228) {
return ann_DASH_check_DASH_temp80403228;
};
var $Hanf_arg113293246 = function(anf_arg80383244,_fun23373245,dummy_DASH_loc11796,s_DASH_prim_DASH_app3922085) {
var $z1942719428 = D;
var $f1943319434 = function(_) {
return R.isFunction(s_DASH_prim_DASH_app3922085.$var)?s_DASH_prim_DASH_app3922085.$var.app(dummy_DASH_loc11796,_fun23373245,anf_arg80383244):R.ffi.throwNonFunApp(L[448],s_DASH_prim_DASH_app3922085.$var,[dummy_DASH_loc11796,_fun23373245,anf_arg80383244]);
};
try {
if(--R.GAS > 0) {
$z1942719428 = $f1943319434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1943319434,
"from":L[448]});
}
} catch($e1942519426) {
if(R.isCont($e1942519426)) {
var $ss1942919430 = {"from":L[448],
"go":function(ann_DASH_check_DASH_temp803319435) {
return $Hann_DASH_check_DASH_temp1132819436(ann_DASH_check_DASH_temp803319435);
}};
$e1942519426.stack[R.EXN_STACKHEIGHT++] = $ss1942919430;
}
if(R.isPyretException($e1942519426)) {
$e1942519426.pyretStack.push(L[448]);
}
throw $e1942519426;
}
var $ret1943119432 = $Hann_DASH_check_DASH_temp1132819436($z1942719428);
++R.GAS;
return $ret1943119432;
};
var $Hann_DASH_check_DASH_temp1132819436 = function(ann_DASH_check_DASH_temp803319435) {
return ann_DASH_check_DASH_temp803319435;
};
var $Hann_DASH_check_DASH_temp113273261 = function(ann_DASH_check_DASH_temp80353260) {
return ann_DASH_check_DASH_temp80353260;
};
var $Hanf_arg113263278 = function(anf_arg80263276,args23343277,dummy_DASH_loc11796,s_DASH_app3902081,self23313275) {
var anf_fun802719447 = G(args23343277,"map",L[3380]);
var anf_arg803019448 = R.makeFunction(function(recv_DASH_97919451) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3379],1,arguments);
}
var anf_fun802919462 = G(recv_DASH_97919451,"visit",L[3379]);
var $z1945419455 = D;
var $f1946019461 = function(_) {
return R.isFunction(anf_fun802919462)?anf_fun802919462.app(self23313275):R.ffi.throwNonFunApp(L[3379],anf_fun802919462,[self23313275]);
};
try {
if(--R.GAS > 0) {
$z1945419455 = $f1946019461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1946019461,
"from":L[3379]});
}
} catch($e1945219453) {
if(R.isCont($e1945219453)) {
var $ss1945619457 = {"from":L[3379],
"go":function(ann_DASH_check_DASH_temp802819463) {
return $Hann_DASH_check_DASH_temp1132319464(ann_DASH_check_DASH_temp802819463);
}};
$e1945219453.stack[R.EXN_STACKHEIGHT++] = $ss1945619457;
}
if(R.isPyretException($e1945219453)) {
$e1945219453.pyretStack.push(L[3379]);
}
throw $e1945219453;
}
var $ret1945819459 = $Hann_DASH_check_DASH_temp1132319464($z1945419455);
++R.GAS;
return $ret1945819459;
});
var $z1943919440 = D;
var $f1944519446 = function(_) {
return R.isFunction(anf_fun802719447)?anf_fun802719447.app(anf_arg803019448):R.ffi.throwNonFunApp(L[3378],anf_fun802719447,[anf_arg803019448]);
};
try {
if(--R.GAS > 0) {
$z1943919440 = $f1944519446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1944519446,
"from":L[3378]});
}
} catch($e1943719438) {
if(R.isCont($e1943719438)) {
var $ss1944119442 = {"from":L[3378],
"go":function(anf_arg803119449) {
return $Hanf_arg1132519450(anf_arg803119449,anf_arg80263276,dummy_DASH_loc11796,s_DASH_app3902081);
}};
$e1943719438.stack[R.EXN_STACKHEIGHT++] = $ss1944119442;
}
if(R.isPyretException($e1943719438)) {
$e1943719438.pyretStack.push(L[3378]);
}
throw $e1943719438;
}
var $ret1944319444 = $Hanf_arg1132519450($z1943919440,anf_arg80263276,dummy_DASH_loc11796,s_DASH_app3902081);
++R.GAS;
return $ret1944319444;
};
var $Hanf_arg1132519450 = function(anf_arg803119449,anf_arg80263276,dummy_DASH_loc11796,s_DASH_app3902081) {
var $z1946719468 = D;
var $f1947319474 = function(_) {
return R.isFunction(s_DASH_app3902081.$var)?s_DASH_app3902081.$var.app(dummy_DASH_loc11796,anf_arg80263276,anf_arg803119449):R.ffi.throwNonFunApp(L[454],s_DASH_app3902081.$var,[dummy_DASH_loc11796,anf_arg80263276,anf_arg803119449]);
};
try {
if(--R.GAS > 0) {
$z1946719468 = $f1947319474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1947319474,
"from":L[454]});
}
} catch($e1946519466) {
if(R.isCont($e1946519466)) {
var $ss1946919470 = {"from":L[454],
"go":function(ann_DASH_check_DASH_temp802419475) {
return $Hann_DASH_check_DASH_temp1132419476(ann_DASH_check_DASH_temp802419475);
}};
$e1946519466.stack[R.EXN_STACKHEIGHT++] = $ss1946919470;
}
if(R.isPyretException($e1946519466)) {
$e1946519466.pyretStack.push(L[454]);
}
throw $e1946519466;
}
var $ret1947119472 = $Hann_DASH_check_DASH_temp1132419476($z1946719468);
++R.GAS;
return $ret1947119472;
};
var $Hann_DASH_check_DASH_temp1132419476 = function(ann_DASH_check_DASH_temp802419475) {
return ann_DASH_check_DASH_temp802419475;
};
var $Hann_DASH_check_DASH_temp1132319464 = function(ann_DASH_check_DASH_temp802819463) {
return ann_DASH_check_DASH_temp802819463;
};
var $Hanf_arg113223296 = function(anf_arg80173293,dummy_DASH_loc11796,mod23283294,s_DASH_construct3842069,self23263292,values23303295) {
var anf_fun801819487 = G(values23303295,"map",L[3383]);
var anf_arg802119488 = R.makeFunction(function(recv_DASH_97819491) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3382],1,arguments);
}
var anf_fun802019502 = G(recv_DASH_97819491,"visit",L[3382]);
var $z1949419495 = D;
var $f1950019501 = function(_) {
return R.isFunction(anf_fun802019502)?anf_fun802019502.app(self23263292):R.ffi.throwNonFunApp(L[3382],anf_fun802019502,[self23263292]);
};
try {
if(--R.GAS > 0) {
$z1949419495 = $f1950019501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1950019501,
"from":L[3382]});
}
} catch($e1949219493) {
if(R.isCont($e1949219493)) {
var $ss1949619497 = {"from":L[3382],
"go":function(ann_DASH_check_DASH_temp801919503) {
return $Hann_DASH_check_DASH_temp1131919504(ann_DASH_check_DASH_temp801919503);
}};
$e1949219493.stack[R.EXN_STACKHEIGHT++] = $ss1949619497;
}
if(R.isPyretException($e1949219493)) {
$e1949219493.pyretStack.push(L[3382]);
}
throw $e1949219493;
}
var $ret1949819499 = $Hann_DASH_check_DASH_temp1131919504($z1949419495);
++R.GAS;
return $ret1949819499;
});
var $z1947919480 = D;
var $f1948519486 = function(_) {
return R.isFunction(anf_fun801819487)?anf_fun801819487.app(anf_arg802119488):R.ffi.throwNonFunApp(L[3381],anf_fun801819487,[anf_arg802119488]);
};
try {
if(--R.GAS > 0) {
$z1947919480 = $f1948519486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1948519486,
"from":L[3381]});
}
} catch($e1947719478) {
if(R.isCont($e1947719478)) {
var $ss1948119482 = {"from":L[3381],
"go":function(anf_arg802219489) {
return $Hanf_arg1132119490(anf_arg802219489,anf_arg80173293,dummy_DASH_loc11796,mod23283294,s_DASH_construct3842069);
}};
$e1947719478.stack[R.EXN_STACKHEIGHT++] = $ss1948119482;
}
if(R.isPyretException($e1947719478)) {
$e1947719478.pyretStack.push(L[3381]);
}
throw $e1947719478;
}
var $ret1948319484 = $Hanf_arg1132119490($z1947919480,anf_arg80173293,dummy_DASH_loc11796,mod23283294,s_DASH_construct3842069);
++R.GAS;
return $ret1948319484;
};
var $Hanf_arg1132119490 = function(anf_arg802219489,anf_arg80173293,dummy_DASH_loc11796,mod23283294,s_DASH_construct3842069) {
var $z1950719508 = D;
var $f1951319514 = function(_) {
return R.isFunction(s_DASH_construct3842069.$var)?s_DASH_construct3842069.$var.app(dummy_DASH_loc11796,mod23283294,anf_arg80173293,anf_arg802219489):R.ffi.throwNonFunApp(L[461],s_DASH_construct3842069.$var,[dummy_DASH_loc11796,mod23283294,anf_arg80173293,anf_arg802219489]);
};
try {
if(--R.GAS > 0) {
$z1950719508 = $f1951319514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1951319514,
"from":L[461]});
}
} catch($e1950519506) {
if(R.isCont($e1950519506)) {
var $ss1950919510 = {"from":L[461],
"go":function(ann_DASH_check_DASH_temp801519515) {
return $Hann_DASH_check_DASH_temp1132019516(ann_DASH_check_DASH_temp801519515);
}};
$e1950519506.stack[R.EXN_STACKHEIGHT++] = $ss1950919510;
}
if(R.isPyretException($e1950519506)) {
$e1950519506.pyretStack.push(L[461]);
}
throw $e1950519506;
}
var $ret1951119512 = $Hann_DASH_check_DASH_temp1132019516($z1950719508);
++R.GAS;
return $ret1951119512;
};
var $Hann_DASH_check_DASH_temp1132019516 = function(ann_DASH_check_DASH_temp801519515) {
return ann_DASH_check_DASH_temp801519515;
};
var $Hann_DASH_check_DASH_temp1131919504 = function(ann_DASH_check_DASH_temp801919503) {
return ann_DASH_check_DASH_temp801919503;
};
var $Hanf_arg113183313 = function(anf_arg80113311,dummy_DASH_loc11796,s_DASH_confirm3862073,self23223310,typ23253312) {
var anf_fun801219527 = G(typ23253312,"visit",L[3385]);
var $z1951919520 = D;
var $f1952519526 = function(_) {
return R.isFunction(anf_fun801219527)?anf_fun801219527.app(self23223310):R.ffi.throwNonFunApp(L[3384],anf_fun801219527,[self23223310]);
};
try {
if(--R.GAS > 0) {
$z1951919520 = $f1952519526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1952519526,
"from":L[3384]});
}
} catch($e1951719518) {
if(R.isCont($e1951719518)) {
var $ss1952119522 = {"from":L[3384],
"go":function(anf_arg801319528) {
return $Hanf_arg1131719529(anf_arg801319528,anf_arg80113311,dummy_DASH_loc11796,s_DASH_confirm3862073);
}};
$e1951719518.stack[R.EXN_STACKHEIGHT++] = $ss1952119522;
}
if(R.isPyretException($e1951719518)) {
$e1951719518.pyretStack.push(L[3384]);
}
throw $e1951719518;
}
var $ret1952319524 = $Hanf_arg1131719529($z1951919520,anf_arg80113311,dummy_DASH_loc11796,s_DASH_confirm3862073);
++R.GAS;
return $ret1952319524;
};
var $Hanf_arg1131719529 = function(anf_arg801319528,anf_arg80113311,dummy_DASH_loc11796,s_DASH_confirm3862073) {
var $z1953219533 = D;
var $f1953819539 = function(_) {
return R.isFunction(s_DASH_confirm3862073.$var)?s_DASH_confirm3862073.$var.app(dummy_DASH_loc11796,anf_arg80113311,anf_arg801319528):R.ffi.throwNonFunApp(L[467],s_DASH_confirm3862073.$var,[dummy_DASH_loc11796,anf_arg80113311,anf_arg801319528]);
};
try {
if(--R.GAS > 0) {
$z1953219533 = $f1953819539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1953819539,
"from":L[467]});
}
} catch($e1953019531) {
if(R.isCont($e1953019531)) {
var $ss1953419535 = {"from":L[467],
"go":function(ann_DASH_check_DASH_temp800919540) {
return $Hann_DASH_check_DASH_temp1131619541(ann_DASH_check_DASH_temp800919540);
}};
$e1953019531.stack[R.EXN_STACKHEIGHT++] = $ss1953419535;
}
if(R.isPyretException($e1953019531)) {
$e1953019531.pyretStack.push(L[467]);
}
throw $e1953019531;
}
var $ret1953619537 = $Hann_DASH_check_DASH_temp1131619541($z1953219533);
++R.GAS;
return $ret1953619537;
};
var $Hann_DASH_check_DASH_temp1131619541 = function(ann_DASH_check_DASH_temp800919540) {
return ann_DASH_check_DASH_temp800919540;
};
var $Hanf_arg113153330 = function(anf_arg80053328,dummy_DASH_loc11796,s_DASH_bless3882077,self23183327,typ23213329) {
var anf_fun800619552 = G(typ23213329,"visit",L[3387]);
var $z1954419545 = D;
var $f1955019551 = function(_) {
return R.isFunction(anf_fun800619552)?anf_fun800619552.app(self23183327):R.ffi.throwNonFunApp(L[3386],anf_fun800619552,[self23183327]);
};
try {
if(--R.GAS > 0) {
$z1954419545 = $f1955019551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1955019551,
"from":L[3386]});
}
} catch($e1954219543) {
if(R.isCont($e1954219543)) {
var $ss1954619547 = {"from":L[3386],
"go":function(anf_arg800719553) {
return $Hanf_arg1131419554(anf_arg800719553,anf_arg80053328,dummy_DASH_loc11796,s_DASH_bless3882077);
}};
$e1954219543.stack[R.EXN_STACKHEIGHT++] = $ss1954619547;
}
if(R.isPyretException($e1954219543)) {
$e1954219543.pyretStack.push(L[3386]);
}
throw $e1954219543;
}
var $ret1954819549 = $Hanf_arg1131419554($z1954419545,anf_arg80053328,dummy_DASH_loc11796,s_DASH_bless3882077);
++R.GAS;
return $ret1954819549;
};
var $Hanf_arg1131419554 = function(anf_arg800719553,anf_arg80053328,dummy_DASH_loc11796,s_DASH_bless3882077) {
var $z1955719558 = D;
var $f1956319564 = function(_) {
return R.isFunction(s_DASH_bless3882077.$var)?s_DASH_bless3882077.$var.app(dummy_DASH_loc11796,anf_arg80053328,anf_arg800719553):R.ffi.throwNonFunApp(L[473],s_DASH_bless3882077.$var,[dummy_DASH_loc11796,anf_arg80053328,anf_arg800719553]);
};
try {
if(--R.GAS > 0) {
$z1955719558 = $f1956319564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1956319564,
"from":L[473]});
}
} catch($e1955519556) {
if(R.isCont($e1955519556)) {
var $ss1955919560 = {"from":L[473],
"go":function(ann_DASH_check_DASH_temp800319565) {
return $Hann_DASH_check_DASH_temp1131319566(ann_DASH_check_DASH_temp800319565);
}};
$e1955519556.stack[R.EXN_STACKHEIGHT++] = $ss1955919560;
}
if(R.isPyretException($e1955519556)) {
$e1955519556.pyretStack.push(L[473]);
}
throw $e1955519556;
}
var $ret1956119562 = $Hann_DASH_check_DASH_temp1131319566($z1955719558);
++R.GAS;
return $ret1956119562;
};
var $Hann_DASH_check_DASH_temp1131319566 = function(ann_DASH_check_DASH_temp800319565) {
return ann_DASH_check_DASH_temp800319565;
};
var $Hanf_arg113123346 = function(anf_arg80013345,dummy_DASH_loc11796,s_DASH_array3822065) {
var $z1956919570 = D;
var $f1957519576 = function(_) {
return R.isFunction(s_DASH_array3822065.$var)?s_DASH_array3822065.$var.app(dummy_DASH_loc11796,anf_arg80013345):R.ffi.throwNonFunApp(L[479],s_DASH_array3822065.$var,[dummy_DASH_loc11796,anf_arg80013345]);
};
try {
if(--R.GAS > 0) {
$z1956919570 = $f1957519576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1957519576,
"from":L[479]});
}
} catch($e1956719568) {
if(R.isCont($e1956719568)) {
var $ss1957119572 = {"from":L[479],
"go":function(ann_DASH_check_DASH_temp799619577) {
return $Hann_DASH_check_DASH_temp1131119578(ann_DASH_check_DASH_temp799619577);
}};
$e1956719568.stack[R.EXN_STACKHEIGHT++] = $ss1957119572;
}
if(R.isPyretException($e1956719568)) {
$e1956719568.pyretStack.push(L[479]);
}
throw $e1956719568;
}
var $ret1957319574 = $Hann_DASH_check_DASH_temp1131119578($z1956919570);
++R.GAS;
return $ret1957319574;
};
var $Hann_DASH_check_DASH_temp1131119578 = function(ann_DASH_check_DASH_temp799619577) {
return ann_DASH_check_DASH_temp799619577;
};
var $Hann_DASH_check_DASH_temp113103361 = function(ann_DASH_check_DASH_temp79983360) {
return ann_DASH_check_DASH_temp79983360;
};
var $Hanf_arg113093377 = function(anf_arg79943376,dummy_DASH_loc11796,s_DASH_obj3802061) {
var $z1958119582 = D;
var $f1958719588 = function(_) {
return R.isFunction(s_DASH_obj3802061.$var)?s_DASH_obj3802061.$var.app(dummy_DASH_loc11796,anf_arg79943376):R.ffi.throwNonFunApp(L[485],s_DASH_obj3802061.$var,[dummy_DASH_loc11796,anf_arg79943376]);
};
try {
if(--R.GAS > 0) {
$z1958119582 = $f1958719588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1958719588,
"from":L[485]});
}
} catch($e1957919580) {
if(R.isCont($e1957919580)) {
var $ss1958319584 = {"from":L[485],
"go":function(ann_DASH_check_DASH_temp798919589) {
return $Hann_DASH_check_DASH_temp1130819590(ann_DASH_check_DASH_temp798919589);
}};
$e1957919580.stack[R.EXN_STACKHEIGHT++] = $ss1958319584;
}
if(R.isPyretException($e1957919580)) {
$e1957919580.pyretStack.push(L[485]);
}
throw $e1957919580;
}
var $ret1958519586 = $Hann_DASH_check_DASH_temp1130819590($z1958119582);
++R.GAS;
return $ret1958519586;
};
var $Hann_DASH_check_DASH_temp1130819590 = function(ann_DASH_check_DASH_temp798919589) {
return ann_DASH_check_DASH_temp798919589;
};
var $Hann_DASH_check_DASH_temp113073392 = function(ann_DASH_check_DASH_temp79913391) {
return ann_DASH_check_DASH_temp79913391;
};
var $Hanf_arg113063409 = function(anf_arg79823407,dummy_DASH_loc11796,fields23113408,s_DASH_update3782057,self23083406) {
var anf_fun798319601 = G(fields23113408,"map",L[3390]);
var anf_arg798619602 = R.makeFunction(function(recv_DASH_97519605) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3389],1,arguments);
}
var anf_fun798519616 = G(recv_DASH_97519605,"visit",L[3389]);
var $z1960819609 = D;
var $f1961419615 = function(_) {
return R.isFunction(anf_fun798519616)?anf_fun798519616.app(self23083406):R.ffi.throwNonFunApp(L[3389],anf_fun798519616,[self23083406]);
};
try {
if(--R.GAS > 0) {
$z1960819609 = $f1961419615();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1961419615,
"from":L[3389]});
}
} catch($e1960619607) {
if(R.isCont($e1960619607)) {
var $ss1961019611 = {"from":L[3389],
"go":function(ann_DASH_check_DASH_temp798419617) {
return $Hann_DASH_check_DASH_temp1130319618(ann_DASH_check_DASH_temp798419617);
}};
$e1960619607.stack[R.EXN_STACKHEIGHT++] = $ss1961019611;
}
if(R.isPyretException($e1960619607)) {
$e1960619607.pyretStack.push(L[3389]);
}
throw $e1960619607;
}
var $ret1961219613 = $Hann_DASH_check_DASH_temp1130319618($z1960819609);
++R.GAS;
return $ret1961219613;
});
var $z1959319594 = D;
var $f1959919600 = function(_) {
return R.isFunction(anf_fun798319601)?anf_fun798319601.app(anf_arg798619602):R.ffi.throwNonFunApp(L[3388],anf_fun798319601,[anf_arg798619602]);
};
try {
if(--R.GAS > 0) {
$z1959319594 = $f1959919600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1959919600,
"from":L[3388]});
}
} catch($e1959119592) {
if(R.isCont($e1959119592)) {
var $ss1959519596 = {"from":L[3388],
"go":function(anf_arg798719603) {
return $Hanf_arg1130519604(anf_arg798719603,anf_arg79823407,dummy_DASH_loc11796,s_DASH_update3782057);
}};
$e1959119592.stack[R.EXN_STACKHEIGHT++] = $ss1959519596;
}
if(R.isPyretException($e1959119592)) {
$e1959119592.pyretStack.push(L[3388]);
}
throw $e1959119592;
}
var $ret1959719598 = $Hanf_arg1130519604($z1959319594,anf_arg79823407,dummy_DASH_loc11796,s_DASH_update3782057);
++R.GAS;
return $ret1959719598;
};
var $Hanf_arg1130519604 = function(anf_arg798719603,anf_arg79823407,dummy_DASH_loc11796,s_DASH_update3782057) {
var $z1962119622 = D;
var $f1962719628 = function(_) {
return R.isFunction(s_DASH_update3782057.$var)?s_DASH_update3782057.$var.app(dummy_DASH_loc11796,anf_arg79823407,anf_arg798719603):R.ffi.throwNonFunApp(L[491],s_DASH_update3782057.$var,[dummy_DASH_loc11796,anf_arg79823407,anf_arg798719603]);
};
try {
if(--R.GAS > 0) {
$z1962119622 = $f1962719628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1962719628,
"from":L[491]});
}
} catch($e1961919620) {
if(R.isCont($e1961919620)) {
var $ss1962319624 = {"from":L[491],
"go":function(ann_DASH_check_DASH_temp798019629) {
return $Hann_DASH_check_DASH_temp1130419630(ann_DASH_check_DASH_temp798019629);
}};
$e1961919620.stack[R.EXN_STACKHEIGHT++] = $ss1962319624;
}
if(R.isPyretException($e1961919620)) {
$e1961919620.pyretStack.push(L[491]);
}
throw $e1961919620;
}
var $ret1962519626 = $Hann_DASH_check_DASH_temp1130419630($z1962119622);
++R.GAS;
return $ret1962519626;
};
var $Hann_DASH_check_DASH_temp1130419630 = function(ann_DASH_check_DASH_temp798019629) {
return ann_DASH_check_DASH_temp798019629;
};
var $Hann_DASH_check_DASH_temp1130319618 = function(ann_DASH_check_DASH_temp798419617) {
return ann_DASH_check_DASH_temp798419617;
};
var $Hanf_arg113023426 = function(anf_arg79733424,dummy_DASH_loc11796,fields23073425,s_DASH_extend3762053,self23043423) {
var anf_fun797419641 = G(fields23073425,"map",L[3393]);
var anf_arg797719642 = R.makeFunction(function(recv_DASH_97419645) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3392],1,arguments);
}
var anf_fun797619656 = G(recv_DASH_97419645,"visit",L[3392]);
var $z1964819649 = D;
var $f1965419655 = function(_) {
return R.isFunction(anf_fun797619656)?anf_fun797619656.app(self23043423):R.ffi.throwNonFunApp(L[3392],anf_fun797619656,[self23043423]);
};
try {
if(--R.GAS > 0) {
$z1964819649 = $f1965419655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1965419655,
"from":L[3392]});
}
} catch($e1964619647) {
if(R.isCont($e1964619647)) {
var $ss1965019651 = {"from":L[3392],
"go":function(ann_DASH_check_DASH_temp797519657) {
return $Hann_DASH_check_DASH_temp1129919658(ann_DASH_check_DASH_temp797519657);
}};
$e1964619647.stack[R.EXN_STACKHEIGHT++] = $ss1965019651;
}
if(R.isPyretException($e1964619647)) {
$e1964619647.pyretStack.push(L[3392]);
}
throw $e1964619647;
}
var $ret1965219653 = $Hann_DASH_check_DASH_temp1129919658($z1964819649);
++R.GAS;
return $ret1965219653;
});
var $z1963319634 = D;
var $f1963919640 = function(_) {
return R.isFunction(anf_fun797419641)?anf_fun797419641.app(anf_arg797719642):R.ffi.throwNonFunApp(L[3391],anf_fun797419641,[anf_arg797719642]);
};
try {
if(--R.GAS > 0) {
$z1963319634 = $f1963919640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1963919640,
"from":L[3391]});
}
} catch($e1963119632) {
if(R.isCont($e1963119632)) {
var $ss1963519636 = {"from":L[3391],
"go":function(anf_arg797819643) {
return $Hanf_arg1130119644(anf_arg797819643,anf_arg79733424,dummy_DASH_loc11796,s_DASH_extend3762053);
}};
$e1963119632.stack[R.EXN_STACKHEIGHT++] = $ss1963519636;
}
if(R.isPyretException($e1963119632)) {
$e1963119632.pyretStack.push(L[3391]);
}
throw $e1963119632;
}
var $ret1963719638 = $Hanf_arg1130119644($z1963319634,anf_arg79733424,dummy_DASH_loc11796,s_DASH_extend3762053);
++R.GAS;
return $ret1963719638;
};
var $Hanf_arg1130119644 = function(anf_arg797819643,anf_arg79733424,dummy_DASH_loc11796,s_DASH_extend3762053) {
var $z1966119662 = D;
var $f1966719668 = function(_) {
return R.isFunction(s_DASH_extend3762053.$var)?s_DASH_extend3762053.$var.app(dummy_DASH_loc11796,anf_arg79733424,anf_arg797819643):R.ffi.throwNonFunApp(L[497],s_DASH_extend3762053.$var,[dummy_DASH_loc11796,anf_arg79733424,anf_arg797819643]);
};
try {
if(--R.GAS > 0) {
$z1966119662 = $f1966719668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1966719668,
"from":L[497]});
}
} catch($e1965919660) {
if(R.isCont($e1965919660)) {
var $ss1966319664 = {"from":L[497],
"go":function(ann_DASH_check_DASH_temp797119669) {
return $Hann_DASH_check_DASH_temp1130019670(ann_DASH_check_DASH_temp797119669);
}};
$e1965919660.stack[R.EXN_STACKHEIGHT++] = $ss1966319664;
}
if(R.isPyretException($e1965919660)) {
$e1965919660.pyretStack.push(L[497]);
}
throw $e1965919660;
}
var $ret1966519666 = $Hann_DASH_check_DASH_temp1130019670($z1966119662);
++R.GAS;
return $ret1966519666;
};
var $Hann_DASH_check_DASH_temp1130019670 = function(ann_DASH_check_DASH_temp797119669) {
return ann_DASH_check_DASH_temp797119669;
};
var $Hann_DASH_check_DASH_temp1129919658 = function(ann_DASH_check_DASH_temp797519657) {
return ann_DASH_check_DASH_temp797519657;
};
var $Hanf_arg112983447 = function(anf_arg79633441,_check23033442,ann23003443,body23023444,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446) {
var anf_fun796419681 = G(ann23003443,"visit",L[3395]);
var $z1967319674 = D;
var $f1967919680 = function(_) {
return R.isFunction(anf_fun796419681)?anf_fun796419681.app(self22973446):R.ffi.throwNonFunApp(L[3394],anf_fun796419681,[self22973446]);
};
try {
if(--R.GAS > 0) {
$z1967319674 = $f1967919680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1967919680,
"from":L[3394]});
}
} catch($e1967119672) {
if(R.isCont($e1967119672)) {
var $ss1967519676 = {"from":L[3394],
"go":function(anf_arg796519682) {
return $Hanf_arg1129719683(anf_arg796519682,_check23033442,anf_arg79633441,body23023444,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446);
}};
$e1967119672.stack[R.EXN_STACKHEIGHT++] = $ss1967519676;
}
if(R.isPyretException($e1967119672)) {
$e1967119672.pyretStack.push(L[3394]);
}
throw $e1967119672;
}
var $ret1967719678 = $Hanf_arg1129719683($z1967319674,_check23033442,anf_arg79633441,body23023444,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446);
++R.GAS;
return $ret1967719678;
};
var $Hanf_arg1129719683 = function(anf_arg796519682,_check23033442,anf_arg79633441,body23023444,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446) {
var anf_fun796619694 = G(body23023444,"visit",L[3397]);
var $z1968619687 = D;
var $f1969219693 = function(_) {
return R.isFunction(anf_fun796619694)?anf_fun796619694.app(self22973446):R.ffi.throwNonFunApp(L[3396],anf_fun796619694,[self22973446]);
};
try {
if(--R.GAS > 0) {
$z1968619687 = $f1969219693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1969219693,
"from":L[3396]});
}
} catch($e1968419685) {
if(R.isCont($e1968419685)) {
var $ss1968819689 = {"from":L[3396],
"go":function(anf_arg796719695) {
return $Hanf_arg1129619696(anf_arg796719695,_check23033442,anf_arg79633441,anf_arg796519682,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446);
}};
$e1968419685.stack[R.EXN_STACKHEIGHT++] = $ss1968819689;
}
if(R.isPyretException($e1968419685)) {
$e1968419685.pyretStack.push(L[3396]);
}
throw $e1968419685;
}
var $ret1969019691 = $Hanf_arg1129619696($z1968619687,_check23033442,anf_arg79633441,anf_arg796519682,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446);
++R.GAS;
return $ret1969019691;
};
var $Hanf_arg1129619696 = function(anf_arg796719695,_check23033442,anf_arg79633441,anf_arg796519682,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049,self22973446) {
var anf_fun796819707 = G(self22973446,"option",L[3399]);
var $z1969919700 = D;
var $f1970519706 = function(_) {
return R.isFunction(anf_fun796819707)?anf_fun796819707.app(_check23033442):R.ffi.throwNonFunApp(L[3398],anf_fun796819707,[_check23033442]);
};
try {
if(--R.GAS > 0) {
$z1969919700 = $f1970519706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1970519706,
"from":L[3398]});
}
} catch($e1969719698) {
if(R.isCont($e1969719698)) {
var $ss1970119702 = {"from":L[3398],
"go":function(anf_arg796919708) {
return $Hanf_arg1129519709(anf_arg796919708,anf_arg79633441,anf_arg796519682,anf_arg796719695,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049);
}};
$e1969719698.stack[R.EXN_STACKHEIGHT++] = $ss1970119702;
}
if(R.isPyretException($e1969719698)) {
$e1969719698.pyretStack.push(L[3398]);
}
throw $e1969719698;
}
var $ret1970319704 = $Hanf_arg1129519709($z1969919700,anf_arg79633441,anf_arg796519682,anf_arg796719695,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049);
++R.GAS;
return $ret1970319704;
};
var $Hanf_arg1129519709 = function(anf_arg796919708,anf_arg79633441,anf_arg796519682,anf_arg796719695,doc23013445,dummy_DASH_loc11796,s_DASH_method3742049) {
var $z1971219713 = D;
var $f1971819719 = function(_) {
return R.isFunction(s_DASH_method3742049.$var)?s_DASH_method3742049.$var.app(dummy_DASH_loc11796,anf_arg79633441,anf_arg796519682,doc23013445,anf_arg796719695,anf_arg796919708):R.ffi.throwNonFunApp(L[507],s_DASH_method3742049.$var,[dummy_DASH_loc11796,anf_arg79633441,anf_arg796519682,doc23013445,anf_arg796719695,anf_arg796919708]);
};
try {
if(--R.GAS > 0) {
$z1971219713 = $f1971819719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1971819719,
"from":L[507]});
}
} catch($e1971019711) {
if(R.isCont($e1971019711)) {
var $ss1971419715 = {"from":L[507],
"go":function(ann_DASH_check_DASH_temp795819720) {
return $Hann_DASH_check_DASH_temp1129419721(ann_DASH_check_DASH_temp795819720);
}};
$e1971019711.stack[R.EXN_STACKHEIGHT++] = $ss1971419715;
}
if(R.isPyretException($e1971019711)) {
$e1971019711.pyretStack.push(L[507]);
}
throw $e1971019711;
}
var $ret1971619717 = $Hann_DASH_check_DASH_temp1129419721($z1971219713);
++R.GAS;
return $ret1971619717;
};
var $Hann_DASH_check_DASH_temp1129419721 = function(ann_DASH_check_DASH_temp795819720) {
return ann_DASH_check_DASH_temp795819720;
};
var $Hann_DASH_check_DASH_temp112933461 = function(ann_DASH_check_DASH_temp79603460) {
return ann_DASH_check_DASH_temp79603460;
};
var $Hanf_arg112923483 = function(anf_arg79453476,_check22963477,ann22933478,args22923479,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482) {
var anf_fun794619732 = G(args22923479,"map",L[3402]);
var anf_arg794919733 = R.makeFunction(function(recv_DASH_97219736) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3401],1,arguments);
}
var anf_fun794819747 = G(recv_DASH_97219736,"visit",L[3401]);
var $z1973919740 = D;
var $f1974519746 = function(_) {
return R.isFunction(anf_fun794819747)?anf_fun794819747.app(self22893482):R.ffi.throwNonFunApp(L[3401],anf_fun794819747,[self22893482]);
};
try {
if(--R.GAS > 0) {
$z1973919740 = $f1974519746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1974519746,
"from":L[3401]});
}
} catch($e1973719738) {
if(R.isCont($e1973719738)) {
var $ss1974119742 = {"from":L[3401],
"go":function(ann_DASH_check_DASH_temp794719748) {
return $Hann_DASH_check_DASH_temp1128619749(ann_DASH_check_DASH_temp794719748);
}};
$e1973719738.stack[R.EXN_STACKHEIGHT++] = $ss1974119742;
}
if(R.isPyretException($e1973719738)) {
$e1973719738.pyretStack.push(L[3401]);
}
throw $e1973719738;
}
var $ret1974319744 = $Hann_DASH_check_DASH_temp1128619749($z1973919740);
++R.GAS;
return $ret1974319744;
});
var $z1972419725 = D;
var $f1973019731 = function(_) {
return R.isFunction(anf_fun794619732)?anf_fun794619732.app(anf_arg794919733):R.ffi.throwNonFunApp(L[3400],anf_fun794619732,[anf_arg794919733]);
};
try {
if(--R.GAS > 0) {
$z1972419725 = $f1973019731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1973019731,
"from":L[3400]});
}
} catch($e1972219723) {
if(R.isCont($e1972219723)) {
var $ss1972619727 = {"from":L[3400],
"go":function(anf_arg795019734) {
return $Hanf_arg1129119735(anf_arg795019734,_check22963477,anf_arg79453476,ann22933478,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482);
}};
$e1972219723.stack[R.EXN_STACKHEIGHT++] = $ss1972619727;
}
if(R.isPyretException($e1972219723)) {
$e1972219723.pyretStack.push(L[3400]);
}
throw $e1972219723;
}
var $ret1972819729 = $Hanf_arg1129119735($z1972419725,_check22963477,anf_arg79453476,ann22933478,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482);
++R.GAS;
return $ret1972819729;
};
var $Hanf_arg1129119735 = function(anf_arg795019734,_check22963477,anf_arg79453476,ann22933478,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482) {
var anf_fun795119760 = G(ann22933478,"visit",L[3404]);
var $z1975219753 = D;
var $f1975819759 = function(_) {
return R.isFunction(anf_fun795119760)?anf_fun795119760.app(self22893482):R.ffi.throwNonFunApp(L[3403],anf_fun795119760,[self22893482]);
};
try {
if(--R.GAS > 0) {
$z1975219753 = $f1975819759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1975819759,
"from":L[3403]});
}
} catch($e1975019751) {
if(R.isCont($e1975019751)) {
var $ss1975419755 = {"from":L[3403],
"go":function(anf_arg795219761) {
return $Hanf_arg1129019762(anf_arg795219761,_check22963477,anf_arg79453476,anf_arg795019734,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482);
}};
$e1975019751.stack[R.EXN_STACKHEIGHT++] = $ss1975419755;
}
if(R.isPyretException($e1975019751)) {
$e1975019751.pyretStack.push(L[3403]);
}
throw $e1975019751;
}
var $ret1975619757 = $Hanf_arg1129019762($z1975219753,_check22963477,anf_arg79453476,anf_arg795019734,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482);
++R.GAS;
return $ret1975619757;
};
var $Hanf_arg1129019762 = function(anf_arg795219761,_check22963477,anf_arg79453476,anf_arg795019734,body22953480,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482) {
var anf_fun795319773 = G(body22953480,"visit",L[3406]);
var $z1976519766 = D;
var $f1977119772 = function(_) {
return R.isFunction(anf_fun795319773)?anf_fun795319773.app(self22893482):R.ffi.throwNonFunApp(L[3405],anf_fun795319773,[self22893482]);
};
try {
if(--R.GAS > 0) {
$z1976519766 = $f1977119772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1977119772,
"from":L[3405]});
}
} catch($e1976319764) {
if(R.isCont($e1976319764)) {
var $ss1976719768 = {"from":L[3405],
"go":function(anf_arg795419774) {
return $Hanf_arg1128919775(anf_arg795419774,_check22963477,anf_arg79453476,anf_arg795019734,anf_arg795219761,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482);
}};
$e1976319764.stack[R.EXN_STACKHEIGHT++] = $ss1976719768;
}
if(R.isPyretException($e1976319764)) {
$e1976319764.pyretStack.push(L[3405]);
}
throw $e1976319764;
}
var $ret1976919770 = $Hanf_arg1128919775($z1976519766,_check22963477,anf_arg79453476,anf_arg795019734,anf_arg795219761,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482);
++R.GAS;
return $ret1976919770;
};
var $Hanf_arg1128919775 = function(anf_arg795419774,_check22963477,anf_arg79453476,anf_arg795019734,anf_arg795219761,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045,self22893482) {
var anf_fun795519786 = G(self22893482,"option",L[3408]);
var $z1977819779 = D;
var $f1978419785 = function(_) {
return R.isFunction(anf_fun795519786)?anf_fun795519786.app(_check22963477):R.ffi.throwNonFunApp(L[3407],anf_fun795519786,[_check22963477]);
};
try {
if(--R.GAS > 0) {
$z1977819779 = $f1978419785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1978419785,
"from":L[3407]});
}
} catch($e1977619777) {
if(R.isCont($e1977619777)) {
var $ss1978019781 = {"from":L[3407],
"go":function(anf_arg795619787) {
return $Hanf_arg1128819788(anf_arg795619787,anf_arg79453476,anf_arg795019734,anf_arg795219761,anf_arg795419774,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045);
}};
$e1977619777.stack[R.EXN_STACKHEIGHT++] = $ss1978019781;
}
if(R.isPyretException($e1977619777)) {
$e1977619777.pyretStack.push(L[3407]);
}
throw $e1977619777;
}
var $ret1978219783 = $Hanf_arg1128819788($z1977819779,anf_arg79453476,anf_arg795019734,anf_arg795219761,anf_arg795419774,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045);
++R.GAS;
return $ret1978219783;
};
var $Hanf_arg1128819788 = function(anf_arg795619787,anf_arg79453476,anf_arg795019734,anf_arg795219761,anf_arg795419774,doc22943481,dummy_DASH_loc11796,s_DASH_lam3722045) {
var $z1979119792 = D;
var $f1979719798 = function(_) {
return R.isFunction(s_DASH_lam3722045.$var)?s_DASH_lam3722045.$var.app(dummy_DASH_loc11796,anf_arg79453476,anf_arg795019734,anf_arg795219761,doc22943481,anf_arg795419774,anf_arg795619787):R.ffi.throwNonFunApp(L[518],s_DASH_lam3722045.$var,[dummy_DASH_loc11796,anf_arg79453476,anf_arg795019734,anf_arg795219761,doc22943481,anf_arg795419774,anf_arg795619787]);
};
try {
if(--R.GAS > 0) {
$z1979119792 = $f1979719798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1979719798,
"from":L[518]});
}
} catch($e1978919790) {
if(R.isCont($e1978919790)) {
var $ss1979319794 = {"from":L[518],
"go":function(ann_DASH_check_DASH_temp794019799) {
return $Hann_DASH_check_DASH_temp1128719800(ann_DASH_check_DASH_temp794019799);
}};
$e1978919790.stack[R.EXN_STACKHEIGHT++] = $ss1979319794;
}
if(R.isPyretException($e1978919790)) {
$e1978919790.pyretStack.push(L[518]);
}
throw $e1978919790;
}
var $ret1979519796 = $Hann_DASH_check_DASH_temp1128719800($z1979119792);
++R.GAS;
return $ret1979519796;
};
var $Hann_DASH_check_DASH_temp1128719800 = function(ann_DASH_check_DASH_temp794019799) {
return ann_DASH_check_DASH_temp794019799;
};
var $Hann_DASH_check_DASH_temp1128619749 = function(ann_DASH_check_DASH_temp794719748) {
return ann_DASH_check_DASH_temp794719748;
};
var $Hann_DASH_check_DASH_temp112853497 = function(ann_DASH_check_DASH_temp79423496) {
return ann_DASH_check_DASH_temp79423496;
};
var $Hanf_arg112843513 = function(anf_arg79383512,dummy_DASH_loc11796,s_DASH_paren3702041) {
var $z1980319804 = D;
var $f1980919810 = function(_) {
return R.isFunction(s_DASH_paren3702041.$var)?s_DASH_paren3702041.$var.app(dummy_DASH_loc11796,anf_arg79383512):R.ffi.throwNonFunApp(L[523],s_DASH_paren3702041.$var,[dummy_DASH_loc11796,anf_arg79383512]);
};
try {
if(--R.GAS > 0) {
$z1980319804 = $f1980919810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1980919810,
"from":L[523]});
}
} catch($e1980119802) {
if(R.isCont($e1980119802)) {
var $ss1980519806 = {"from":L[523],
"go":function(ann_DASH_check_DASH_temp793619811) {
return $Hann_DASH_check_DASH_temp1128319812(ann_DASH_check_DASH_temp793619811);
}};
$e1980119802.stack[R.EXN_STACKHEIGHT++] = $ss1980519806;
}
if(R.isPyretException($e1980119802)) {
$e1980119802.pyretStack.push(L[523]);
}
throw $e1980119802;
}
var $ret1980719808 = $Hann_DASH_check_DASH_temp1128319812($z1980319804);
++R.GAS;
return $ret1980719808;
};
var $Hann_DASH_check_DASH_temp1128319812 = function(ann_DASH_check_DASH_temp793619811) {
return ann_DASH_check_DASH_temp793619811;
};
var $Hanf_arg112823531 = function(anf_arg79323528,dummy_DASH_loc11796,op22833529,right22853530,s_DASH_check_DASH_test3682037,self22813527) {
var anf_fun793319823 = G(right22853530,"visit",L[3410]);
var $z1981519816 = D;
var $f1982119822 = function(_) {
return R.isFunction(anf_fun793319823)?anf_fun793319823.app(self22813527):R.ffi.throwNonFunApp(L[3409],anf_fun793319823,[self22813527]);
};
try {
if(--R.GAS > 0) {
$z1981519816 = $f1982119822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1982119822,
"from":L[3409]});
}
} catch($e1981319814) {
if(R.isCont($e1981319814)) {
var $ss1981719818 = {"from":L[3409],
"go":function(anf_arg793419824) {
return $Hanf_arg1128119825(anf_arg793419824,anf_arg79323528,dummy_DASH_loc11796,op22833529,s_DASH_check_DASH_test3682037);
}};
$e1981319814.stack[R.EXN_STACKHEIGHT++] = $ss1981719818;
}
if(R.isPyretException($e1981319814)) {
$e1981319814.pyretStack.push(L[3409]);
}
throw $e1981319814;
}
var $ret1981919820 = $Hanf_arg1128119825($z1981519816,anf_arg79323528,dummy_DASH_loc11796,op22833529,s_DASH_check_DASH_test3682037);
++R.GAS;
return $ret1981919820;
};
var $Hanf_arg1128119825 = function(anf_arg793419824,anf_arg79323528,dummy_DASH_loc11796,op22833529,s_DASH_check_DASH_test3682037) {
var $z1982819829 = D;
var $f1983419835 = function(_) {
return R.isFunction(s_DASH_check_DASH_test3682037.$var)?s_DASH_check_DASH_test3682037.$var.app(dummy_DASH_loc11796,op22833529,anf_arg79323528,anf_arg793419824):R.ffi.throwNonFunApp(L[530],s_DASH_check_DASH_test3682037.$var,[dummy_DASH_loc11796,op22833529,anf_arg79323528,anf_arg793419824]);
};
try {
if(--R.GAS > 0) {
$z1982819829 = $f1983419835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1983419835,
"from":L[530]});
}
} catch($e1982619827) {
if(R.isCont($e1982619827)) {
var $ss1983019831 = {"from":L[530],
"go":function(ann_DASH_check_DASH_temp793019836) {
return $Hann_DASH_check_DASH_temp1128019837(ann_DASH_check_DASH_temp793019836);
}};
$e1982619827.stack[R.EXN_STACKHEIGHT++] = $ss1983019831;
}
if(R.isPyretException($e1982619827)) {
$e1982619827.pyretStack.push(L[530]);
}
throw $e1982619827;
}
var $ret1983219833 = $Hann_DASH_check_DASH_temp1128019837($z1982819829);
++R.GAS;
return $ret1983219833;
};
var $Hann_DASH_check_DASH_temp1128019837 = function(ann_DASH_check_DASH_temp793019836) {
return ann_DASH_check_DASH_temp793019836;
};
var $Hanf_arg112793549 = function(anf_arg79263546,dummy_DASH_loc11796,op22783547,right22803548,s_DASH_op3662033,self22763545) {
var anf_fun792719848 = G(right22803548,"visit",L[3412]);
var $z1984019841 = D;
var $f1984619847 = function(_) {
return R.isFunction(anf_fun792719848)?anf_fun792719848.app(self22763545):R.ffi.throwNonFunApp(L[3411],anf_fun792719848,[self22763545]);
};
try {
if(--R.GAS > 0) {
$z1984019841 = $f1984619847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1984619847,
"from":L[3411]});
}
} catch($e1983819839) {
if(R.isCont($e1983819839)) {
var $ss1984219843 = {"from":L[3411],
"go":function(anf_arg792819849) {
return $Hanf_arg1127819850(anf_arg792819849,anf_arg79263546,dummy_DASH_loc11796,op22783547,s_DASH_op3662033);
}};
$e1983819839.stack[R.EXN_STACKHEIGHT++] = $ss1984219843;
}
if(R.isPyretException($e1983819839)) {
$e1983819839.pyretStack.push(L[3411]);
}
throw $e1983819839;
}
var $ret1984419845 = $Hanf_arg1127819850($z1984019841,anf_arg79263546,dummy_DASH_loc11796,op22783547,s_DASH_op3662033);
++R.GAS;
return $ret1984419845;
};
var $Hanf_arg1127819850 = function(anf_arg792819849,anf_arg79263546,dummy_DASH_loc11796,op22783547,s_DASH_op3662033) {
var $z1985319854 = D;
var $f1985919860 = function(_) {
return R.isFunction(s_DASH_op3662033.$var)?s_DASH_op3662033.$var.app(dummy_DASH_loc11796,op22783547,anf_arg79263546,anf_arg792819849):R.ffi.throwNonFunApp(L[537],s_DASH_op3662033.$var,[dummy_DASH_loc11796,op22783547,anf_arg79263546,anf_arg792819849]);
};
try {
if(--R.GAS > 0) {
$z1985319854 = $f1985919860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1985919860,
"from":L[537]});
}
} catch($e1985119852) {
if(R.isCont($e1985119852)) {
var $ss1985519856 = {"from":L[537],
"go":function(ann_DASH_check_DASH_temp792419861) {
return $Hann_DASH_check_DASH_temp1127719862(ann_DASH_check_DASH_temp792419861);
}};
$e1985119852.stack[R.EXN_STACKHEIGHT++] = $ss1985519856;
}
if(R.isPyretException($e1985119852)) {
$e1985119852.pyretStack.push(L[537]);
}
throw $e1985119852;
}
var $ret1985719858 = $Hann_DASH_check_DASH_temp1127719862($z1985319854);
++R.GAS;
return $ret1985719858;
};
var $Hann_DASH_check_DASH_temp1127719862 = function(ann_DASH_check_DASH_temp792419861) {
return ann_DASH_check_DASH_temp792419861;
};
var $Hanf_arg112763567 = function(anf_arg79183564,_except22753565,dummy_DASH_loc11796,id22743566,s_DASH_try3642029,self22713563) {
var anf_fun791919873 = G(id22743566,"visit",L[3414]);
var $z1986519866 = D;
var $f1987119872 = function(_) {
return R.isFunction(anf_fun791919873)?anf_fun791919873.app(self22713563):R.ffi.throwNonFunApp(L[3413],anf_fun791919873,[self22713563]);
};
try {
if(--R.GAS > 0) {
$z1986519866 = $f1987119872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1987119872,
"from":L[3413]});
}
} catch($e1986319864) {
if(R.isCont($e1986319864)) {
var $ss1986719868 = {"from":L[3413],
"go":function(anf_arg792019874) {
return $Hanf_arg1127519875(anf_arg792019874,_except22753565,anf_arg79183564,dummy_DASH_loc11796,s_DASH_try3642029,self22713563);
}};
$e1986319864.stack[R.EXN_STACKHEIGHT++] = $ss1986719868;
}
if(R.isPyretException($e1986319864)) {
$e1986319864.pyretStack.push(L[3413]);
}
throw $e1986319864;
}
var $ret1986919870 = $Hanf_arg1127519875($z1986519866,_except22753565,anf_arg79183564,dummy_DASH_loc11796,s_DASH_try3642029,self22713563);
++R.GAS;
return $ret1986919870;
};
var $Hanf_arg1127519875 = function(anf_arg792019874,_except22753565,anf_arg79183564,dummy_DASH_loc11796,s_DASH_try3642029,self22713563) {
var anf_fun792119886 = G(_except22753565,"visit",L[3416]);
var $z1987819879 = D;
var $f1988419885 = function(_) {
return R.isFunction(anf_fun792119886)?anf_fun792119886.app(self22713563):R.ffi.throwNonFunApp(L[3415],anf_fun792119886,[self22713563]);
};
try {
if(--R.GAS > 0) {
$z1987819879 = $f1988419885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1988419885,
"from":L[3415]});
}
} catch($e1987619877) {
if(R.isCont($e1987619877)) {
var $ss1988019881 = {"from":L[3415],
"go":function(anf_arg792219887) {
return $Hanf_arg1127419888(anf_arg792219887,anf_arg79183564,anf_arg792019874,dummy_DASH_loc11796,s_DASH_try3642029);
}};
$e1987619877.stack[R.EXN_STACKHEIGHT++] = $ss1988019881;
}
if(R.isPyretException($e1987619877)) {
$e1987619877.pyretStack.push(L[3415]);
}
throw $e1987619877;
}
var $ret1988219883 = $Hanf_arg1127419888($z1987819879,anf_arg79183564,anf_arg792019874,dummy_DASH_loc11796,s_DASH_try3642029);
++R.GAS;
return $ret1988219883;
};
var $Hanf_arg1127419888 = function(anf_arg792219887,anf_arg79183564,anf_arg792019874,dummy_DASH_loc11796,s_DASH_try3642029) {
var $z1989119892 = D;
var $f1989719898 = function(_) {
return R.isFunction(s_DASH_try3642029.$var)?s_DASH_try3642029.$var.app(dummy_DASH_loc11796,anf_arg79183564,anf_arg792019874,anf_arg792219887):R.ffi.throwNonFunApp(L[544],s_DASH_try3642029.$var,[dummy_DASH_loc11796,anf_arg79183564,anf_arg792019874,anf_arg792219887]);
};
try {
if(--R.GAS > 0) {
$z1989119892 = $f1989719898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1989719898,
"from":L[544]});
}
} catch($e1988919890) {
if(R.isCont($e1988919890)) {
var $ss1989319894 = {"from":L[544],
"go":function(ann_DASH_check_DASH_temp791619899) {
return $Hann_DASH_check_DASH_temp1127319900(ann_DASH_check_DASH_temp791619899);
}};
$e1988919890.stack[R.EXN_STACKHEIGHT++] = $ss1989319894;
}
if(R.isPyretException($e1988919890)) {
$e1988919890.pyretStack.push(L[544]);
}
throw $e1988919890;
}
var $ret1989519896 = $Hann_DASH_check_DASH_temp1127319900($z1989119892);
++R.GAS;
return $ret1989519896;
};
var $Hann_DASH_check_DASH_temp1127319900 = function(ann_DASH_check_DASH_temp791619899) {
return ann_DASH_check_DASH_temp791619899;
};
var $Hanf_arg112723586 = function(anf_arg79053582,_else22703583,branches22693584,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581,val22683585) {
var anf_fun790619911 = G(val22683585,"visit",L[3418]);
var $z1990319904 = D;
var $f1990919910 = function(_) {
return R.isFunction(anf_fun790619911)?anf_fun790619911.app(self22653581):R.ffi.throwNonFunApp(L[3417],anf_fun790619911,[self22653581]);
};
try {
if(--R.GAS > 0) {
$z1990319904 = $f1990919910();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1990919910,
"from":L[3417]});
}
} catch($e1990119902) {
if(R.isCont($e1990119902)) {
var $ss1990519906 = {"from":L[3417],
"go":function(anf_arg790719912) {
return $Hanf_arg1127119913(anf_arg790719912,_else22703583,anf_arg79053582,branches22693584,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581);
}};
$e1990119902.stack[R.EXN_STACKHEIGHT++] = $ss1990519906;
}
if(R.isPyretException($e1990119902)) {
$e1990119902.pyretStack.push(L[3417]);
}
throw $e1990119902;
}
var $ret1990719908 = $Hanf_arg1127119913($z1990319904,_else22703583,anf_arg79053582,branches22693584,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581);
++R.GAS;
return $ret1990719908;
};
var $Hanf_arg1127119913 = function(anf_arg790719912,_else22703583,anf_arg79053582,branches22693584,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581) {
var anf_fun790819924 = G(branches22693584,"map",L[3421]);
var anf_arg791119925 = R.makeFunction(function(recv_DASH_97019928) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3420],1,arguments);
}
var anf_fun791019939 = G(recv_DASH_97019928,"visit",L[3420]);
var $z1993119932 = D;
var $f1993719938 = function(_) {
return R.isFunction(anf_fun791019939)?anf_fun791019939.app(self22653581):R.ffi.throwNonFunApp(L[3420],anf_fun791019939,[self22653581]);
};
try {
if(--R.GAS > 0) {
$z1993119932 = $f1993719938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1993719938,
"from":L[3420]});
}
} catch($e1992919930) {
if(R.isCont($e1992919930)) {
var $ss1993319934 = {"from":L[3420],
"go":function(ann_DASH_check_DASH_temp790919940) {
return $Hann_DASH_check_DASH_temp1126719941(ann_DASH_check_DASH_temp790919940);
}};
$e1992919930.stack[R.EXN_STACKHEIGHT++] = $ss1993319934;
}
if(R.isPyretException($e1992919930)) {
$e1992919930.pyretStack.push(L[3420]);
}
throw $e1992919930;
}
var $ret1993519936 = $Hann_DASH_check_DASH_temp1126719941($z1993119932);
++R.GAS;
return $ret1993519936;
});
var $z1991619917 = D;
var $f1992219923 = function(_) {
return R.isFunction(anf_fun790819924)?anf_fun790819924.app(anf_arg791119925):R.ffi.throwNonFunApp(L[3419],anf_fun790819924,[anf_arg791119925]);
};
try {
if(--R.GAS > 0) {
$z1991619917 = $f1992219923();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1992219923,
"from":L[3419]});
}
} catch($e1991419915) {
if(R.isCont($e1991419915)) {
var $ss1991819919 = {"from":L[3419],
"go":function(anf_arg791219926) {
return $Hanf_arg1127019927(anf_arg791219926,_else22703583,anf_arg79053582,anf_arg790719912,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581);
}};
$e1991419915.stack[R.EXN_STACKHEIGHT++] = $ss1991819919;
}
if(R.isPyretException($e1991419915)) {
$e1991419915.pyretStack.push(L[3419]);
}
throw $e1991419915;
}
var $ret1992019921 = $Hanf_arg1127019927($z1991619917,_else22703583,anf_arg79053582,anf_arg790719912,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581);
++R.GAS;
return $ret1992019921;
};
var $Hanf_arg1127019927 = function(anf_arg791219926,_else22703583,anf_arg79053582,anf_arg790719912,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025,self22653581) {
var anf_fun791319952 = G(_else22703583,"visit",L[3423]);
var $z1994419945 = D;
var $f1995019951 = function(_) {
return R.isFunction(anf_fun791319952)?anf_fun791319952.app(self22653581):R.ffi.throwNonFunApp(L[3422],anf_fun791319952,[self22653581]);
};
try {
if(--R.GAS > 0) {
$z1994419945 = $f1995019951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1995019951,
"from":L[3422]});
}
} catch($e1994219943) {
if(R.isCont($e1994219943)) {
var $ss1994619947 = {"from":L[3422],
"go":function(anf_arg791419953) {
return $Hanf_arg1126919954(anf_arg791419953,anf_arg79053582,anf_arg790719912,anf_arg791219926,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025);
}};
$e1994219943.stack[R.EXN_STACKHEIGHT++] = $ss1994619947;
}
if(R.isPyretException($e1994219943)) {
$e1994219943.pyretStack.push(L[3422]);
}
throw $e1994219943;
}
var $ret1994819949 = $Hanf_arg1126919954($z1994419945,anf_arg79053582,anf_arg790719912,anf_arg791219926,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025);
++R.GAS;
return $ret1994819949;
};
var $Hanf_arg1126919954 = function(anf_arg791419953,anf_arg79053582,anf_arg790719912,anf_arg791219926,dummy_DASH_loc11796,s_DASH_cases_DASH_else3622025) {
var $z1995719958 = D;
var $f1996319964 = function(_) {
return R.isFunction(s_DASH_cases_DASH_else3622025.$var)?s_DASH_cases_DASH_else3622025.$var.app(dummy_DASH_loc11796,anf_arg79053582,anf_arg790719912,anf_arg791219926,anf_arg791419953):R.ffi.throwNonFunApp(L[552],s_DASH_cases_DASH_else3622025.$var,[dummy_DASH_loc11796,anf_arg79053582,anf_arg790719912,anf_arg791219926,anf_arg791419953]);
};
try {
if(--R.GAS > 0) {
$z1995719958 = $f1996319964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1996319964,
"from":L[552]});
}
} catch($e1995519956) {
if(R.isCont($e1995519956)) {
var $ss1995919960 = {"from":L[552],
"go":function(ann_DASH_check_DASH_temp790319965) {
return $Hann_DASH_check_DASH_temp1126819966(ann_DASH_check_DASH_temp790319965);
}};
$e1995519956.stack[R.EXN_STACKHEIGHT++] = $ss1995919960;
}
if(R.isPyretException($e1995519956)) {
$e1995519956.pyretStack.push(L[552]);
}
throw $e1995519956;
}
var $ret1996119962 = $Hann_DASH_check_DASH_temp1126819966($z1995719958);
++R.GAS;
return $ret1996119962;
};
var $Hann_DASH_check_DASH_temp1126819966 = function(ann_DASH_check_DASH_temp790319965) {
return ann_DASH_check_DASH_temp790319965;
};
var $Hann_DASH_check_DASH_temp1126719941 = function(ann_DASH_check_DASH_temp790919940) {
return ann_DASH_check_DASH_temp790919940;
};
var $Hanf_arg112663604 = function(anf_arg78943601,branches22643602,dummy_DASH_loc11796,s_DASH_cases3602021,self22603600,val22633603) {
var anf_fun789519977 = G(val22633603,"visit",L[3425]);
var $z1996919970 = D;
var $f1997519976 = function(_) {
return R.isFunction(anf_fun789519977)?anf_fun789519977.app(self22603600):R.ffi.throwNonFunApp(L[3424],anf_fun789519977,[self22603600]);
};
try {
if(--R.GAS > 0) {
$z1996919970 = $f1997519976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1997519976,
"from":L[3424]});
}
} catch($e1996719968) {
if(R.isCont($e1996719968)) {
var $ss1997119972 = {"from":L[3424],
"go":function(anf_arg789619978) {
return $Hanf_arg1126519979(anf_arg789619978,anf_arg78943601,branches22643602,dummy_DASH_loc11796,s_DASH_cases3602021,self22603600);
}};
$e1996719968.stack[R.EXN_STACKHEIGHT++] = $ss1997119972;
}
if(R.isPyretException($e1996719968)) {
$e1996719968.pyretStack.push(L[3424]);
}
throw $e1996719968;
}
var $ret1997319974 = $Hanf_arg1126519979($z1996919970,anf_arg78943601,branches22643602,dummy_DASH_loc11796,s_DASH_cases3602021,self22603600);
++R.GAS;
return $ret1997319974;
};
var $Hanf_arg1126519979 = function(anf_arg789619978,anf_arg78943601,branches22643602,dummy_DASH_loc11796,s_DASH_cases3602021,self22603600) {
var anf_fun789719990 = G(branches22643602,"map",L[3428]);
var anf_arg790019991 = R.makeFunction(function(recv_DASH_96919994) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3427],1,arguments);
}
var anf_fun789920005 = G(recv_DASH_96919994,"visit",L[3427]);
var $z1999719998 = D;
var $f2000320004 = function(_) {
return R.isFunction(anf_fun789920005)?anf_fun789920005.app(self22603600):R.ffi.throwNonFunApp(L[3427],anf_fun789920005,[self22603600]);
};
try {
if(--R.GAS > 0) {
$z1999719998 = $f2000320004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2000320004,
"from":L[3427]});
}
} catch($e1999519996) {
if(R.isCont($e1999519996)) {
var $ss1999920000 = {"from":L[3427],
"go":function(ann_DASH_check_DASH_temp789820006) {
return $Hann_DASH_check_DASH_temp1126220007(ann_DASH_check_DASH_temp789820006);
}};
$e1999519996.stack[R.EXN_STACKHEIGHT++] = $ss1999920000;
}
if(R.isPyretException($e1999519996)) {
$e1999519996.pyretStack.push(L[3427]);
}
throw $e1999519996;
}
var $ret2000120002 = $Hann_DASH_check_DASH_temp1126220007($z1999719998);
++R.GAS;
return $ret2000120002;
});
var $z1998219983 = D;
var $f1998819989 = function(_) {
return R.isFunction(anf_fun789719990)?anf_fun789719990.app(anf_arg790019991):R.ffi.throwNonFunApp(L[3426],anf_fun789719990,[anf_arg790019991]);
};
try {
if(--R.GAS > 0) {
$z1998219983 = $f1998819989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1998819989,
"from":L[3426]});
}
} catch($e1998019981) {
if(R.isCont($e1998019981)) {
var $ss1998419985 = {"from":L[3426],
"go":function(anf_arg790119992) {
return $Hanf_arg1126419993(anf_arg790119992,anf_arg78943601,anf_arg789619978,dummy_DASH_loc11796,s_DASH_cases3602021);
}};
$e1998019981.stack[R.EXN_STACKHEIGHT++] = $ss1998419985;
}
if(R.isPyretException($e1998019981)) {
$e1998019981.pyretStack.push(L[3426]);
}
throw $e1998019981;
}
var $ret1998619987 = $Hanf_arg1126419993($z1998219983,anf_arg78943601,anf_arg789619978,dummy_DASH_loc11796,s_DASH_cases3602021);
++R.GAS;
return $ret1998619987;
};
var $Hanf_arg1126419993 = function(anf_arg790119992,anf_arg78943601,anf_arg789619978,dummy_DASH_loc11796,s_DASH_cases3602021) {
var $z2001020011 = D;
var $f2001620017 = function(_) {
return R.isFunction(s_DASH_cases3602021.$var)?s_DASH_cases3602021.$var.app(dummy_DASH_loc11796,anf_arg78943601,anf_arg789619978,anf_arg790119992):R.ffi.throwNonFunApp(L[559],s_DASH_cases3602021.$var,[dummy_DASH_loc11796,anf_arg78943601,anf_arg789619978,anf_arg790119992]);
};
try {
if(--R.GAS > 0) {
$z2001020011 = $f2001620017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2001620017,
"from":L[559]});
}
} catch($e2000820009) {
if(R.isCont($e2000820009)) {
var $ss2001220013 = {"from":L[559],
"go":function(ann_DASH_check_DASH_temp789220018) {
return $Hann_DASH_check_DASH_temp1126320019(ann_DASH_check_DASH_temp789220018);
}};
$e2000820009.stack[R.EXN_STACKHEIGHT++] = $ss2001220013;
}
if(R.isPyretException($e2000820009)) {
$e2000820009.pyretStack.push(L[559]);
}
throw $e2000820009;
}
var $ret2001420015 = $Hann_DASH_check_DASH_temp1126320019($z2001020011);
++R.GAS;
return $ret2001420015;
};
var $Hann_DASH_check_DASH_temp1126320019 = function(ann_DASH_check_DASH_temp789220018) {
return ann_DASH_check_DASH_temp789220018;
};
var $Hann_DASH_check_DASH_temp1126220007 = function(ann_DASH_check_DASH_temp789820006) {
return ann_DASH_check_DASH_temp789820006;
};
var $Hanf_arg112613623 = function(anf_arg78883619,body22593620,dummy_DASH_loc11796,name22573621,s_DASH_cases_DASH_branch5022305,self22553622) {
var anf_fun788920030 = G(body22593620,"visit",L[3430]);
var $z2002220023 = D;
var $f2002820029 = function(_) {
return R.isFunction(anf_fun788920030)?anf_fun788920030.app(self22553622):R.ffi.throwNonFunApp(L[3429],anf_fun788920030,[self22553622]);
};
try {
if(--R.GAS > 0) {
$z2002220023 = $f2002820029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2002820029,
"from":L[3429]});
}
} catch($e2002020021) {
if(R.isCont($e2002020021)) {
var $ss2002420025 = {"from":L[3429],
"go":function(anf_arg789020031) {
return $Hanf_arg1126020032(anf_arg789020031,anf_arg78883619,dummy_DASH_loc11796,name22573621,s_DASH_cases_DASH_branch5022305);
}};
$e2002020021.stack[R.EXN_STACKHEIGHT++] = $ss2002420025;
}
if(R.isPyretException($e2002020021)) {
$e2002020021.pyretStack.push(L[3429]);
}
throw $e2002020021;
}
var $ret2002620027 = $Hanf_arg1126020032($z2002220023,anf_arg78883619,dummy_DASH_loc11796,name22573621,s_DASH_cases_DASH_branch5022305);
++R.GAS;
return $ret2002620027;
};
var $Hanf_arg1126020032 = function(anf_arg789020031,anf_arg78883619,dummy_DASH_loc11796,name22573621,s_DASH_cases_DASH_branch5022305) {
var $z2003520036 = D;
var $f2004120042 = function(_) {
return R.isFunction(s_DASH_cases_DASH_branch5022305.$var)?s_DASH_cases_DASH_branch5022305.$var.app(dummy_DASH_loc11796,name22573621,anf_arg78883619,anf_arg789020031):R.ffi.throwNonFunApp(L[567],s_DASH_cases_DASH_branch5022305.$var,[dummy_DASH_loc11796,name22573621,anf_arg78883619,anf_arg789020031]);
};
try {
if(--R.GAS > 0) {
$z2003520036 = $f2004120042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2004120042,
"from":L[567]});
}
} catch($e2003320034) {
if(R.isCont($e2003320034)) {
var $ss2003720038 = {"from":L[567],
"go":function(ann_DASH_check_DASH_temp788320043) {
return $Hann_DASH_check_DASH_temp1125920044(ann_DASH_check_DASH_temp788320043);
}};
$e2003320034.stack[R.EXN_STACKHEIGHT++] = $ss2003720038;
}
if(R.isPyretException($e2003320034)) {
$e2003320034.pyretStack.push(L[567]);
}
throw $e2003320034;
}
var $ret2003920040 = $Hann_DASH_check_DASH_temp1125920044($z2003520036);
++R.GAS;
return $ret2003920040;
};
var $Hann_DASH_check_DASH_temp1125920044 = function(ann_DASH_check_DASH_temp788320043) {
return ann_DASH_check_DASH_temp788320043;
};
var $Hann_DASH_check_DASH_temp112583637 = function(ann_DASH_check_DASH_temp78853636) {
return ann_DASH_check_DASH_temp78853636;
};
var $Hanf_arg112573655 = function(anf_arg78793652,_else22543653,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_else3542009,self22513654) {
var anf_fun788020055 = G(_else22543653,"visit",L[3432]);
var $z2004720048 = D;
var $f2005320054 = function(_) {
return R.isFunction(anf_fun788020055)?anf_fun788020055.app(self22513654):R.ffi.throwNonFunApp(L[3431],anf_fun788020055,[self22513654]);
};
try {
if(--R.GAS > 0) {
$z2004720048 = $f2005320054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2005320054,
"from":L[3431]});
}
} catch($e2004520046) {
if(R.isCont($e2004520046)) {
var $ss2004920050 = {"from":L[3431],
"go":function(anf_arg788120056) {
return $Hanf_arg1125620057(anf_arg788120056,anf_arg78793652,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_else3542009);
}};
$e2004520046.stack[R.EXN_STACKHEIGHT++] = $ss2004920050;
}
if(R.isPyretException($e2004520046)) {
$e2004520046.pyretStack.push(L[3431]);
}
throw $e2004520046;
}
var $ret2005120052 = $Hanf_arg1125620057($z2004720048,anf_arg78793652,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_else3542009);
++R.GAS;
return $ret2005120052;
};
var $Hanf_arg1125620057 = function(anf_arg788120056,anf_arg78793652,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_else3542009) {
var $z2006020061 = D;
var $f2006620067 = function(_) {
return R.isFunction(s_DASH_if_DASH_pipe_DASH_else3542009.$var)?s_DASH_if_DASH_pipe_DASH_else3542009.$var.app(dummy_DASH_loc11796,anf_arg78793652,anf_arg788120056):R.ffi.throwNonFunApp(L[574],s_DASH_if_DASH_pipe_DASH_else3542009.$var,[dummy_DASH_loc11796,anf_arg78793652,anf_arg788120056]);
};
try {
if(--R.GAS > 0) {
$z2006020061 = $f2006620067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2006620067,
"from":L[574]});
}
} catch($e2005820059) {
if(R.isCont($e2005820059)) {
var $ss2006220063 = {"from":L[574],
"go":function(ann_DASH_check_DASH_temp787420068) {
return $Hann_DASH_check_DASH_temp1125520069(ann_DASH_check_DASH_temp787420068);
}};
$e2005820059.stack[R.EXN_STACKHEIGHT++] = $ss2006220063;
}
if(R.isPyretException($e2005820059)) {
$e2005820059.pyretStack.push(L[574]);
}
throw $e2005820059;
}
var $ret2006420065 = $Hann_DASH_check_DASH_temp1125520069($z2006020061);
++R.GAS;
return $ret2006420065;
};
var $Hann_DASH_check_DASH_temp1125520069 = function(ann_DASH_check_DASH_temp787420068) {
return ann_DASH_check_DASH_temp787420068;
};
var $Hann_DASH_check_DASH_temp112543669 = function(ann_DASH_check_DASH_temp78763668) {
return ann_DASH_check_DASH_temp78763668;
};
var $Hanf_arg112533685 = function(anf_arg78723684,dummy_DASH_loc11796,s_DASH_if_DASH_pipe3522005) {
var $z2007220073 = D;
var $f2007820079 = function(_) {
return R.isFunction(s_DASH_if_DASH_pipe3522005.$var)?s_DASH_if_DASH_pipe3522005.$var.app(dummy_DASH_loc11796,anf_arg78723684):R.ffi.throwNonFunApp(L[580],s_DASH_if_DASH_pipe3522005.$var,[dummy_DASH_loc11796,anf_arg78723684]);
};
try {
if(--R.GAS > 0) {
$z2007220073 = $f2007820079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2007820079,
"from":L[580]});
}
} catch($e2007020071) {
if(R.isCont($e2007020071)) {
var $ss2007420075 = {"from":L[580],
"go":function(ann_DASH_check_DASH_temp786720080) {
return $Hann_DASH_check_DASH_temp1125220081(ann_DASH_check_DASH_temp786720080);
}};
$e2007020071.stack[R.EXN_STACKHEIGHT++] = $ss2007420075;
}
if(R.isPyretException($e2007020071)) {
$e2007020071.pyretStack.push(L[580]);
}
throw $e2007020071;
}
var $ret2007620077 = $Hann_DASH_check_DASH_temp1125220081($z2007220073);
++R.GAS;
return $ret2007620077;
};
var $Hann_DASH_check_DASH_temp1125220081 = function(ann_DASH_check_DASH_temp786720080) {
return ann_DASH_check_DASH_temp786720080;
};
var $Hann_DASH_check_DASH_temp112513700 = function(ann_DASH_check_DASH_temp78693699) {
return ann_DASH_check_DASH_temp78693699;
};
var $Hanf_arg112503718 = function(anf_arg78633715,_else22473716,dummy_DASH_loc11796,s_DASH_if_DASH_else3582017,self22443717) {
var anf_fun786420092 = G(_else22473716,"visit",L[3434]);
var $z2008420085 = D;
var $f2009020091 = function(_) {
return R.isFunction(anf_fun786420092)?anf_fun786420092.app(self22443717):R.ffi.throwNonFunApp(L[3433],anf_fun786420092,[self22443717]);
};
try {
if(--R.GAS > 0) {
$z2008420085 = $f2009020091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2009020091,
"from":L[3433]});
}
} catch($e2008220083) {
if(R.isCont($e2008220083)) {
var $ss2008620087 = {"from":L[3433],
"go":function(anf_arg786520093) {
return $Hanf_arg1124920094(anf_arg786520093,anf_arg78633715,dummy_DASH_loc11796,s_DASH_if_DASH_else3582017);
}};
$e2008220083.stack[R.EXN_STACKHEIGHT++] = $ss2008620087;
}
if(R.isPyretException($e2008220083)) {
$e2008220083.pyretStack.push(L[3433]);
}
throw $e2008220083;
}
var $ret2008820089 = $Hanf_arg1124920094($z2008420085,anf_arg78633715,dummy_DASH_loc11796,s_DASH_if_DASH_else3582017);
++R.GAS;
return $ret2008820089;
};
var $Hanf_arg1124920094 = function(anf_arg786520093,anf_arg78633715,dummy_DASH_loc11796,s_DASH_if_DASH_else3582017) {
var $z2009720098 = D;
var $f2010320104 = function(_) {
return R.isFunction(s_DASH_if_DASH_else3582017.$var)?s_DASH_if_DASH_else3582017.$var.app(dummy_DASH_loc11796,anf_arg78633715,anf_arg786520093):R.ffi.throwNonFunApp(L[587],s_DASH_if_DASH_else3582017.$var,[dummy_DASH_loc11796,anf_arg78633715,anf_arg786520093]);
};
try {
if(--R.GAS > 0) {
$z2009720098 = $f2010320104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2010320104,
"from":L[587]});
}
} catch($e2009520096) {
if(R.isCont($e2009520096)) {
var $ss2009920100 = {"from":L[587],
"go":function(ann_DASH_check_DASH_temp785820105) {
return $Hann_DASH_check_DASH_temp1124820106(ann_DASH_check_DASH_temp785820105);
}};
$e2009520096.stack[R.EXN_STACKHEIGHT++] = $ss2009920100;
}
if(R.isPyretException($e2009520096)) {
$e2009520096.pyretStack.push(L[587]);
}
throw $e2009520096;
}
var $ret2010120102 = $Hann_DASH_check_DASH_temp1124820106($z2009720098);
++R.GAS;
return $ret2010120102;
};
var $Hann_DASH_check_DASH_temp1124820106 = function(ann_DASH_check_DASH_temp785820105) {
return ann_DASH_check_DASH_temp785820105;
};
var $Hann_DASH_check_DASH_temp112473732 = function(ann_DASH_check_DASH_temp78603731) {
return ann_DASH_check_DASH_temp78603731;
};
var $Hanf_arg112463748 = function(anf_arg78563747,dummy_DASH_loc11796,s_DASH_if3562013) {
var $z2010920110 = D;
var $f2011520116 = function(_) {
return R.isFunction(s_DASH_if3562013.$var)?s_DASH_if3562013.$var.app(dummy_DASH_loc11796,anf_arg78563747):R.ffi.throwNonFunApp(L[593],s_DASH_if3562013.$var,[dummy_DASH_loc11796,anf_arg78563747]);
};
try {
if(--R.GAS > 0) {
$z2010920110 = $f2011520116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2011520116,
"from":L[593]});
}
} catch($e2010720108) {
if(R.isCont($e2010720108)) {
var $ss2011120112 = {"from":L[593],
"go":function(ann_DASH_check_DASH_temp785120117) {
return $Hann_DASH_check_DASH_temp1124520118(ann_DASH_check_DASH_temp785120117);
}};
$e2010720108.stack[R.EXN_STACKHEIGHT++] = $ss2011120112;
}
if(R.isPyretException($e2010720108)) {
$e2010720108.pyretStack.push(L[593]);
}
throw $e2010720108;
}
var $ret2011320114 = $Hann_DASH_check_DASH_temp1124520118($z2010920110);
++R.GAS;
return $ret2011320114;
};
var $Hann_DASH_check_DASH_temp1124520118 = function(ann_DASH_check_DASH_temp785120117) {
return ann_DASH_check_DASH_temp785120117;
};
var $Hann_DASH_check_DASH_temp112443763 = function(ann_DASH_check_DASH_temp78533762) {
return ann_DASH_check_DASH_temp78533762;
};
var $Hanf_arg112433780 = function(anf_arg78473778,body22403779,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_branch4972295,self22373777) {
var anf_fun784820129 = G(body22403779,"visit",L[3436]);
var $z2012120122 = D;
var $f2012720128 = function(_) {
return R.isFunction(anf_fun784820129)?anf_fun784820129.app(self22373777):R.ffi.throwNonFunApp(L[3435],anf_fun784820129,[self22373777]);
};
try {
if(--R.GAS > 0) {
$z2012120122 = $f2012720128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2012720128,
"from":L[3435]});
}
} catch($e2011920120) {
if(R.isCont($e2011920120)) {
var $ss2012320124 = {"from":L[3435],
"go":function(anf_arg784920130) {
return $Hanf_arg1124220131(anf_arg784920130,anf_arg78473778,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_branch4972295);
}};
$e2011920120.stack[R.EXN_STACKHEIGHT++] = $ss2012320124;
}
if(R.isPyretException($e2011920120)) {
$e2011920120.pyretStack.push(L[3435]);
}
throw $e2011920120;
}
var $ret2012520126 = $Hanf_arg1124220131($z2012120122,anf_arg78473778,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_branch4972295);
++R.GAS;
return $ret2012520126;
};
var $Hanf_arg1124220131 = function(anf_arg784920130,anf_arg78473778,dummy_DASH_loc11796,s_DASH_if_DASH_pipe_DASH_branch4972295) {
var $z2013420135 = D;
var $f2014020141 = function(_) {
return R.isFunction(s_DASH_if_DASH_pipe_DASH_branch4972295.$var)?s_DASH_if_DASH_pipe_DASH_branch4972295.$var.app(dummy_DASH_loc11796,anf_arg78473778,anf_arg784920130):R.ffi.throwNonFunApp(L[599],s_DASH_if_DASH_pipe_DASH_branch4972295.$var,[dummy_DASH_loc11796,anf_arg78473778,anf_arg784920130]);
};
try {
if(--R.GAS > 0) {
$z2013420135 = $f2014020141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2014020141,
"from":L[599]});
}
} catch($e2013220133) {
if(R.isCont($e2013220133)) {
var $ss2013620137 = {"from":L[599],
"go":function(ann_DASH_check_DASH_temp784520142) {
return $Hann_DASH_check_DASH_temp1124120143(ann_DASH_check_DASH_temp784520142);
}};
$e2013220133.stack[R.EXN_STACKHEIGHT++] = $ss2013620137;
}
if(R.isPyretException($e2013220133)) {
$e2013220133.pyretStack.push(L[599]);
}
throw $e2013220133;
}
var $ret2013820139 = $Hann_DASH_check_DASH_temp1124120143($z2013420135);
++R.GAS;
return $ret2013820139;
};
var $Hann_DASH_check_DASH_temp1124120143 = function(ann_DASH_check_DASH_temp784520142) {
return ann_DASH_check_DASH_temp784520142;
};
var $Hanf_arg112403797 = function(anf_arg78413795,body22363796,dummy_DASH_loc11796,s_DASH_if_DASH_branch4922285,self22333794) {
var anf_fun784220154 = G(body22363796,"visit",L[3438]);
var $z2014620147 = D;
var $f2015220153 = function(_) {
return R.isFunction(anf_fun784220154)?anf_fun784220154.app(self22333794):R.ffi.throwNonFunApp(L[3437],anf_fun784220154,[self22333794]);
};
try {
if(--R.GAS > 0) {
$z2014620147 = $f2015220153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2015220153,
"from":L[3437]});
}
} catch($e2014420145) {
if(R.isCont($e2014420145)) {
var $ss2014820149 = {"from":L[3437],
"go":function(anf_arg784320155) {
return $Hanf_arg1123920156(anf_arg784320155,anf_arg78413795,dummy_DASH_loc11796,s_DASH_if_DASH_branch4922285);
}};
$e2014420145.stack[R.EXN_STACKHEIGHT++] = $ss2014820149;
}
if(R.isPyretException($e2014420145)) {
$e2014420145.pyretStack.push(L[3437]);
}
throw $e2014420145;
}
var $ret2015020151 = $Hanf_arg1123920156($z2014620147,anf_arg78413795,dummy_DASH_loc11796,s_DASH_if_DASH_branch4922285);
++R.GAS;
return $ret2015020151;
};
var $Hanf_arg1123920156 = function(anf_arg784320155,anf_arg78413795,dummy_DASH_loc11796,s_DASH_if_DASH_branch4922285) {
var $z2015920160 = D;
var $f2016520166 = function(_) {
return R.isFunction(s_DASH_if_DASH_branch4922285.$var)?s_DASH_if_DASH_branch4922285.$var.app(dummy_DASH_loc11796,anf_arg78413795,anf_arg784320155):R.ffi.throwNonFunApp(L[605],s_DASH_if_DASH_branch4922285.$var,[dummy_DASH_loc11796,anf_arg78413795,anf_arg784320155]);
};
try {
if(--R.GAS > 0) {
$z2015920160 = $f2016520166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2016520166,
"from":L[605]});
}
} catch($e2015720158) {
if(R.isCont($e2015720158)) {
var $ss2016120162 = {"from":L[605],
"go":function(ann_DASH_check_DASH_temp783920167) {
return $Hann_DASH_check_DASH_temp1123820168(ann_DASH_check_DASH_temp783920167);
}};
$e2015720158.stack[R.EXN_STACKHEIGHT++] = $ss2016120162;
}
if(R.isPyretException($e2015720158)) {
$e2015720158.pyretStack.push(L[605]);
}
throw $e2015720158;
}
var $ret2016320164 = $Hann_DASH_check_DASH_temp1123820168($z2015920160);
++R.GAS;
return $ret2016320164;
};
var $Hann_DASH_check_DASH_temp1123820168 = function(ann_DASH_check_DASH_temp783920167) {
return ann_DASH_check_DASH_temp783920167;
};
var $Hanf_arg112373814 = function(anf_arg78353812,dummy_DASH_loc11796,s_DASH_assign3502001,self22293811,value22323813) {
var anf_fun783620179 = G(value22323813,"visit",L[3440]);
var $z2017120172 = D;
var $f2017720178 = function(_) {
return R.isFunction(anf_fun783620179)?anf_fun783620179.app(self22293811):R.ffi.throwNonFunApp(L[3439],anf_fun783620179,[self22293811]);
};
try {
if(--R.GAS > 0) {
$z2017120172 = $f2017720178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2017720178,
"from":L[3439]});
}
} catch($e2016920170) {
if(R.isCont($e2016920170)) {
var $ss2017320174 = {"from":L[3439],
"go":function(anf_arg783720180) {
return $Hanf_arg1123620181(anf_arg783720180,anf_arg78353812,dummy_DASH_loc11796,s_DASH_assign3502001);
}};
$e2016920170.stack[R.EXN_STACKHEIGHT++] = $ss2017320174;
}
if(R.isPyretException($e2016920170)) {
$e2016920170.pyretStack.push(L[3439]);
}
throw $e2016920170;
}
var $ret2017520176 = $Hanf_arg1123620181($z2017120172,anf_arg78353812,dummy_DASH_loc11796,s_DASH_assign3502001);
++R.GAS;
return $ret2017520176;
};
var $Hanf_arg1123620181 = function(anf_arg783720180,anf_arg78353812,dummy_DASH_loc11796,s_DASH_assign3502001) {
var $z2018420185 = D;
var $f2019020191 = function(_) {
return R.isFunction(s_DASH_assign3502001.$var)?s_DASH_assign3502001.$var.app(dummy_DASH_loc11796,anf_arg78353812,anf_arg783720180):R.ffi.throwNonFunApp(L[611],s_DASH_assign3502001.$var,[dummy_DASH_loc11796,anf_arg78353812,anf_arg783720180]);
};
try {
if(--R.GAS > 0) {
$z2018420185 = $f2019020191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2019020191,
"from":L[611]});
}
} catch($e2018220183) {
if(R.isCont($e2018220183)) {
var $ss2018620187 = {"from":L[611],
"go":function(ann_DASH_check_DASH_temp783320192) {
return $Hann_DASH_check_DASH_temp1123520193(ann_DASH_check_DASH_temp783320192);
}};
$e2018220183.stack[R.EXN_STACKHEIGHT++] = $ss2018620187;
}
if(R.isPyretException($e2018220183)) {
$e2018220183.pyretStack.push(L[611]);
}
throw $e2018220183;
}
var $ret2018820189 = $Hann_DASH_check_DASH_temp1123520193($z2018420185);
++R.GAS;
return $ret2018820189;
};
var $Hann_DASH_check_DASH_temp1123520193 = function(ann_DASH_check_DASH_temp783320192) {
return ann_DASH_check_DASH_temp783320192;
};
var $Hanf_arg112343831 = function(anf_arg78293829,ann22283830,dummy_DASH_loc11796,s_DASH_contract3461993,self22253828) {
var anf_fun783020204 = G(ann22283830,"visit",L[3442]);
var $z2019620197 = D;
var $f2020220203 = function(_) {
return R.isFunction(anf_fun783020204)?anf_fun783020204.app(self22253828):R.ffi.throwNonFunApp(L[3441],anf_fun783020204,[self22253828]);
};
try {
if(--R.GAS > 0) {
$z2019620197 = $f2020220203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2020220203,
"from":L[3441]});
}
} catch($e2019420195) {
if(R.isCont($e2019420195)) {
var $ss2019820199 = {"from":L[3441],
"go":function(anf_arg783120205) {
return $Hanf_arg1123320206(anf_arg783120205,anf_arg78293829,dummy_DASH_loc11796,s_DASH_contract3461993);
}};
$e2019420195.stack[R.EXN_STACKHEIGHT++] = $ss2019820199;
}
if(R.isPyretException($e2019420195)) {
$e2019420195.pyretStack.push(L[3441]);
}
throw $e2019420195;
}
var $ret2020020201 = $Hanf_arg1123320206($z2019620197,anf_arg78293829,dummy_DASH_loc11796,s_DASH_contract3461993);
++R.GAS;
return $ret2020020201;
};
var $Hanf_arg1123320206 = function(anf_arg783120205,anf_arg78293829,dummy_DASH_loc11796,s_DASH_contract3461993) {
var $z2020920210 = D;
var $f2021520216 = function(_) {
return R.isFunction(s_DASH_contract3461993.$var)?s_DASH_contract3461993.$var.app(dummy_DASH_loc11796,anf_arg78293829,anf_arg783120205):R.ffi.throwNonFunApp(L[614],s_DASH_contract3461993.$var,[dummy_DASH_loc11796,anf_arg78293829,anf_arg783120205]);
};
try {
if(--R.GAS > 0) {
$z2020920210 = $f2021520216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2021520216,
"from":L[614]});
}
} catch($e2020720208) {
if(R.isCont($e2020720208)) {
var $ss2021120212 = {"from":L[614],
"go":function(ann_DASH_check_DASH_temp782720217) {
return $Hann_DASH_check_DASH_temp1123220218(ann_DASH_check_DASH_temp782720217);
}};
$e2020720208.stack[R.EXN_STACKHEIGHT++] = $ss2021120212;
}
if(R.isPyretException($e2020720208)) {
$e2020720208.pyretStack.push(L[614]);
}
throw $e2020720208;
}
var $ret2021320214 = $Hann_DASH_check_DASH_temp1123220218($z2020920210);
++R.GAS;
return $ret2021320214;
};
var $Hann_DASH_check_DASH_temp1123220218 = function(ann_DASH_check_DASH_temp782720217) {
return ann_DASH_check_DASH_temp782720217;
};
var $Hanf_arg112313848 = function(anf_arg78233846,block22243847,dummy_DASH_loc11796,s_DASH_when3481997,self22213845) {
var anf_fun782420229 = G(block22243847,"visit",L[3444]);
var $z2022120222 = D;
var $f2022720228 = function(_) {
return R.isFunction(anf_fun782420229)?anf_fun782420229.app(self22213845):R.ffi.throwNonFunApp(L[3443],anf_fun782420229,[self22213845]);
};
try {
if(--R.GAS > 0) {
$z2022120222 = $f2022720228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2022720228,
"from":L[3443]});
}
} catch($e2021920220) {
if(R.isCont($e2021920220)) {
var $ss2022320224 = {"from":L[3443],
"go":function(anf_arg782520230) {
return $Hanf_arg1123020231(anf_arg782520230,anf_arg78233846,dummy_DASH_loc11796,s_DASH_when3481997);
}};
$e2021920220.stack[R.EXN_STACKHEIGHT++] = $ss2022320224;
}
if(R.isPyretException($e2021920220)) {
$e2021920220.pyretStack.push(L[3443]);
}
throw $e2021920220;
}
var $ret2022520226 = $Hanf_arg1123020231($z2022120222,anf_arg78233846,dummy_DASH_loc11796,s_DASH_when3481997);
++R.GAS;
return $ret2022520226;
};
var $Hanf_arg1123020231 = function(anf_arg782520230,anf_arg78233846,dummy_DASH_loc11796,s_DASH_when3481997) {
var $z2023420235 = D;
var $f2024020241 = function(_) {
return R.isFunction(s_DASH_when3481997.$var)?s_DASH_when3481997.$var.app(dummy_DASH_loc11796,anf_arg78233846,anf_arg782520230):R.ffi.throwNonFunApp(L[620],s_DASH_when3481997.$var,[dummy_DASH_loc11796,anf_arg78233846,anf_arg782520230]);
};
try {
if(--R.GAS > 0) {
$z2023420235 = $f2024020241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2024020241,
"from":L[620]});
}
} catch($e2023220233) {
if(R.isCont($e2023220233)) {
var $ss2023620237 = {"from":L[620],
"go":function(ann_DASH_check_DASH_temp782120242) {
return $Hann_DASH_check_DASH_temp1122920243(ann_DASH_check_DASH_temp782120242);
}};
$e2023220233.stack[R.EXN_STACKHEIGHT++] = $ss2023620237;
}
if(R.isPyretException($e2023220233)) {
$e2023220233.pyretStack.push(L[620]);
}
throw $e2023220233;
}
var $ret2023820239 = $Hann_DASH_check_DASH_temp1122920243($z2023420235);
++R.GAS;
return $ret2023820239;
};
var $Hann_DASH_check_DASH_temp1122920243 = function(ann_DASH_check_DASH_temp782120242) {
return ann_DASH_check_DASH_temp782120242;
};
var $Hanf_arg112283864 = function(anf_arg78193863,dummy_DASH_loc11796,s_DASH_graph3441989) {
var $z2024620247 = D;
var $f2025220253 = function(_) {
return R.isFunction(s_DASH_graph3441989.$var)?s_DASH_graph3441989.$var.app(dummy_DASH_loc11796,anf_arg78193863):R.ffi.throwNonFunApp(L[626],s_DASH_graph3441989.$var,[dummy_DASH_loc11796,anf_arg78193863]);
};
try {
if(--R.GAS > 0) {
$z2024620247 = $f2025220253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2025220253,
"from":L[626]});
}
} catch($e2024420245) {
if(R.isCont($e2024420245)) {
var $ss2024820249 = {"from":L[626],
"go":function(ann_DASH_check_DASH_temp781420254) {
return $Hann_DASH_check_DASH_temp1122720255(ann_DASH_check_DASH_temp781420254);
}};
$e2024420245.stack[R.EXN_STACKHEIGHT++] = $ss2024820249;
}
if(R.isPyretException($e2024420245)) {
$e2024420245.pyretStack.push(L[626]);
}
throw $e2024420245;
}
var $ret2025020251 = $Hann_DASH_check_DASH_temp1122720255($z2024620247);
++R.GAS;
return $ret2025020251;
};
var $Hann_DASH_check_DASH_temp1122720255 = function(ann_DASH_check_DASH_temp781420254) {
return ann_DASH_check_DASH_temp781420254;
};
var $Hann_DASH_check_DASH_temp112263879 = function(ann_DASH_check_DASH_temp78163878) {
return ann_DASH_check_DASH_temp78163878;
};
var $Hanf_arg112253897 = function(anf_arg78103894,dummy_DASH_loc11796,keyword_DASH_val22173895,s_DASH_let3421985,self22133893,value22163896) {
var anf_fun781120266 = G(value22163896,"visit",L[3446]);
var $z2025820259 = D;
var $f2026420265 = function(_) {
return R.isFunction(anf_fun781120266)?anf_fun781120266.app(self22133893):R.ffi.throwNonFunApp(L[3445],anf_fun781120266,[self22133893]);
};
try {
if(--R.GAS > 0) {
$z2025820259 = $f2026420265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2026420265,
"from":L[3445]});
}
} catch($e2025620257) {
if(R.isCont($e2025620257)) {
var $ss2026020261 = {"from":L[3445],
"go":function(anf_arg781220267) {
return $Hanf_arg1122420268(anf_arg781220267,anf_arg78103894,dummy_DASH_loc11796,keyword_DASH_val22173895,s_DASH_let3421985);
}};
$e2025620257.stack[R.EXN_STACKHEIGHT++] = $ss2026020261;
}
if(R.isPyretException($e2025620257)) {
$e2025620257.pyretStack.push(L[3445]);
}
throw $e2025620257;
}
var $ret2026220263 = $Hanf_arg1122420268($z2025820259,anf_arg78103894,dummy_DASH_loc11796,keyword_DASH_val22173895,s_DASH_let3421985);
++R.GAS;
return $ret2026220263;
};
var $Hanf_arg1122420268 = function(anf_arg781220267,anf_arg78103894,dummy_DASH_loc11796,keyword_DASH_val22173895,s_DASH_let3421985) {
var $z2027120272 = D;
var $f2027720278 = function(_) {
return R.isFunction(s_DASH_let3421985.$var)?s_DASH_let3421985.$var.app(dummy_DASH_loc11796,anf_arg78103894,anf_arg781220267,keyword_DASH_val22173895):R.ffi.throwNonFunApp(L[633],s_DASH_let3421985.$var,[dummy_DASH_loc11796,anf_arg78103894,anf_arg781220267,keyword_DASH_val22173895]);
};
try {
if(--R.GAS > 0) {
$z2027120272 = $f2027720278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2027720278,
"from":L[633]});
}
} catch($e2026920270) {
if(R.isCont($e2026920270)) {
var $ss2027320274 = {"from":L[633],
"go":function(ann_DASH_check_DASH_temp780820279) {
return $Hann_DASH_check_DASH_temp1122320280(ann_DASH_check_DASH_temp780820279);
}};
$e2026920270.stack[R.EXN_STACKHEIGHT++] = $ss2027320274;
}
if(R.isPyretException($e2026920270)) {
$e2026920270.pyretStack.push(L[633]);
}
throw $e2026920270;
}
var $ret2027520276 = $Hann_DASH_check_DASH_temp1122320280($z2027120272);
++R.GAS;
return $ret2027520276;
};
var $Hann_DASH_check_DASH_temp1122320280 = function(ann_DASH_check_DASH_temp780820279) {
return ann_DASH_check_DASH_temp780820279;
};
var $Hanf_arg112223914 = function(anf_arg78043912,dummy_DASH_loc11796,s_DASH_var3401981,self22093911,value22123913) {
var anf_fun780520291 = G(value22123913,"visit",L[3448]);
var $z2028320284 = D;
var $f2028920290 = function(_) {
return R.isFunction(anf_fun780520291)?anf_fun780520291.app(self22093911):R.ffi.throwNonFunApp(L[3447],anf_fun780520291,[self22093911]);
};
try {
if(--R.GAS > 0) {
$z2028320284 = $f2028920290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2028920290,
"from":L[3447]});
}
} catch($e2028120282) {
if(R.isCont($e2028120282)) {
var $ss2028520286 = {"from":L[3447],
"go":function(anf_arg780620292) {
return $Hanf_arg1122120293(anf_arg780620292,anf_arg78043912,dummy_DASH_loc11796,s_DASH_var3401981);
}};
$e2028120282.stack[R.EXN_STACKHEIGHT++] = $ss2028520286;
}
if(R.isPyretException($e2028120282)) {
$e2028120282.pyretStack.push(L[3447]);
}
throw $e2028120282;
}
var $ret2028720288 = $Hanf_arg1122120293($z2028320284,anf_arg78043912,dummy_DASH_loc11796,s_DASH_var3401981);
++R.GAS;
return $ret2028720288;
};
var $Hanf_arg1122120293 = function(anf_arg780620292,anf_arg78043912,dummy_DASH_loc11796,s_DASH_var3401981) {
var $z2029620297 = D;
var $f2030220303 = function(_) {
return R.isFunction(s_DASH_var3401981.$var)?s_DASH_var3401981.$var.app(dummy_DASH_loc11796,anf_arg78043912,anf_arg780620292):R.ffi.throwNonFunApp(L[639],s_DASH_var3401981.$var,[dummy_DASH_loc11796,anf_arg78043912,anf_arg780620292]);
};
try {
if(--R.GAS > 0) {
$z2029620297 = $f2030220303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2030220303,
"from":L[639]});
}
} catch($e2029420295) {
if(R.isCont($e2029420295)) {
var $ss2029820299 = {"from":L[639],
"go":function(ann_DASH_check_DASH_temp780220304) {
return $Hann_DASH_check_DASH_temp1122020305(ann_DASH_check_DASH_temp780220304);
}};
$e2029420295.stack[R.EXN_STACKHEIGHT++] = $ss2029820299;
}
if(R.isPyretException($e2029420295)) {
$e2029420295.pyretStack.push(L[639]);
}
throw $e2029420295;
}
var $ret2030020301 = $Hann_DASH_check_DASH_temp1122020305($z2029620297);
++R.GAS;
return $ret2030020301;
};
var $Hann_DASH_check_DASH_temp1122020305 = function(ann_DASH_check_DASH_temp780220304) {
return ann_DASH_check_DASH_temp780220304;
};
var $Hanf_arg112193931 = function(anf_arg77983929,dummy_DASH_loc11796,namet22083930,s_DASH_newtype3381977,self22053928) {
var anf_fun779920316 = G(namet22083930,"visit",L[3450]);
var $z2030820309 = D;
var $f2031420315 = function(_) {
return R.isFunction(anf_fun779920316)?anf_fun779920316.app(self22053928):R.ffi.throwNonFunApp(L[3449],anf_fun779920316,[self22053928]);
};
try {
if(--R.GAS > 0) {
$z2030820309 = $f2031420315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2031420315,
"from":L[3449]});
}
} catch($e2030620307) {
if(R.isCont($e2030620307)) {
var $ss2031020311 = {"from":L[3449],
"go":function(anf_arg780020317) {
return $Hanf_arg1121820318(anf_arg780020317,anf_arg77983929,dummy_DASH_loc11796,s_DASH_newtype3381977);
}};
$e2030620307.stack[R.EXN_STACKHEIGHT++] = $ss2031020311;
}
if(R.isPyretException($e2030620307)) {
$e2030620307.pyretStack.push(L[3449]);
}
throw $e2030620307;
}
var $ret2031220313 = $Hanf_arg1121820318($z2030820309,anf_arg77983929,dummy_DASH_loc11796,s_DASH_newtype3381977);
++R.GAS;
return $ret2031220313;
};
var $Hanf_arg1121820318 = function(anf_arg780020317,anf_arg77983929,dummy_DASH_loc11796,s_DASH_newtype3381977) {
var $z2032120322 = D;
var $f2032720328 = function(_) {
return R.isFunction(s_DASH_newtype3381977.$var)?s_DASH_newtype3381977.$var.app(dummy_DASH_loc11796,anf_arg77983929,anf_arg780020317):R.ffi.throwNonFunApp(L[645],s_DASH_newtype3381977.$var,[dummy_DASH_loc11796,anf_arg77983929,anf_arg780020317]);
};
try {
if(--R.GAS > 0) {
$z2032120322 = $f2032720328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2032720328,
"from":L[645]});
}
} catch($e2031920320) {
if(R.isCont($e2031920320)) {
var $ss2032320324 = {"from":L[645],
"go":function(ann_DASH_check_DASH_temp779620329) {
return $Hann_DASH_check_DASH_temp1121720330(ann_DASH_check_DASH_temp779620329);
}};
$e2031920320.stack[R.EXN_STACKHEIGHT++] = $ss2032320324;
}
if(R.isPyretException($e2031920320)) {
$e2031920320.pyretStack.push(L[645]);
}
throw $e2031920320;
}
var $ret2032520326 = $Hann_DASH_check_DASH_temp1121720330($z2032120322);
++R.GAS;
return $ret2032520326;
};
var $Hann_DASH_check_DASH_temp1121720330 = function(ann_DASH_check_DASH_temp779620329) {
return ann_DASH_check_DASH_temp779620329;
};
var $Hanf_arg112163948 = function(anf_arg77923946,ann22043947,dummy_DASH_loc11796,s_DASH_type3361973,self22013945) {
var anf_fun779320341 = G(ann22043947,"visit",L[3452]);
var $z2033320334 = D;
var $f2033920340 = function(_) {
return R.isFunction(anf_fun779320341)?anf_fun779320341.app(self22013945):R.ffi.throwNonFunApp(L[3451],anf_fun779320341,[self22013945]);
};
try {
if(--R.GAS > 0) {
$z2033320334 = $f2033920340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2033920340,
"from":L[3451]});
}
} catch($e2033120332) {
if(R.isCont($e2033120332)) {
var $ss2033520336 = {"from":L[3451],
"go":function(anf_arg779420342) {
return $Hanf_arg1121520343(anf_arg779420342,anf_arg77923946,dummy_DASH_loc11796,s_DASH_type3361973);
}};
$e2033120332.stack[R.EXN_STACKHEIGHT++] = $ss2033520336;
}
if(R.isPyretException($e2033120332)) {
$e2033120332.pyretStack.push(L[3451]);
}
throw $e2033120332;
}
var $ret2033720338 = $Hanf_arg1121520343($z2033320334,anf_arg77923946,dummy_DASH_loc11796,s_DASH_type3361973);
++R.GAS;
return $ret2033720338;
};
var $Hanf_arg1121520343 = function(anf_arg779420342,anf_arg77923946,dummy_DASH_loc11796,s_DASH_type3361973) {
var $z2034620347 = D;
var $f2035220353 = function(_) {
return R.isFunction(s_DASH_type3361973.$var)?s_DASH_type3361973.$var.app(dummy_DASH_loc11796,anf_arg77923946,anf_arg779420342):R.ffi.throwNonFunApp(L[651],s_DASH_type3361973.$var,[dummy_DASH_loc11796,anf_arg77923946,anf_arg779420342]);
};
try {
if(--R.GAS > 0) {
$z2034620347 = $f2035220353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2035220353,
"from":L[651]});
}
} catch($e2034420345) {
if(R.isCont($e2034420345)) {
var $ss2034820349 = {"from":L[651],
"go":function(ann_DASH_check_DASH_temp779020354) {
return $Hann_DASH_check_DASH_temp1121420355(ann_DASH_check_DASH_temp779020354);
}};
$e2034420345.stack[R.EXN_STACKHEIGHT++] = $ss2034820349;
}
if(R.isPyretException($e2034420345)) {
$e2034420345.pyretStack.push(L[651]);
}
throw $e2034420345;
}
var $ret2035020351 = $Hann_DASH_check_DASH_temp1121420355($z2034620347);
++R.GAS;
return $ret2035020351;
};
var $Hann_DASH_check_DASH_temp1121420355 = function(ann_DASH_check_DASH_temp779020354) {
return ann_DASH_check_DASH_temp779020354;
};
var $Hanf_arg112133971 = function(anf_arg77773963,_check22003964,ann21973965,args21963966,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970) {
var anf_fun777820366 = G(args21963966,"map",L[3455]);
var anf_arg778120367 = R.makeFunction(function(recv_DASH_96220370) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3454],1,arguments);
}
var anf_fun778020381 = G(recv_DASH_96220370,"visit",L[3454]);
var $z2037320374 = D;
var $f2037920380 = function(_) {
return R.isFunction(anf_fun778020381)?anf_fun778020381.app(self21923970):R.ffi.throwNonFunApp(L[3454],anf_fun778020381,[self21923970]);
};
try {
if(--R.GAS > 0) {
$z2037320374 = $f2037920380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2037920380,
"from":L[3454]});
}
} catch($e2037120372) {
if(R.isCont($e2037120372)) {
var $ss2037520376 = {"from":L[3454],
"go":function(ann_DASH_check_DASH_temp777920382) {
return $Hann_DASH_check_DASH_temp1120720383(ann_DASH_check_DASH_temp777920382);
}};
$e2037120372.stack[R.EXN_STACKHEIGHT++] = $ss2037520376;
}
if(R.isPyretException($e2037120372)) {
$e2037120372.pyretStack.push(L[3454]);
}
throw $e2037120372;
}
var $ret2037720378 = $Hann_DASH_check_DASH_temp1120720383($z2037320374);
++R.GAS;
return $ret2037720378;
});
var $z2035820359 = D;
var $f2036420365 = function(_) {
return R.isFunction(anf_fun777820366)?anf_fun777820366.app(anf_arg778120367):R.ffi.throwNonFunApp(L[3453],anf_fun777820366,[anf_arg778120367]);
};
try {
if(--R.GAS > 0) {
$z2035820359 = $f2036420365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2036420365,
"from":L[3453]});
}
} catch($e2035620357) {
if(R.isCont($e2035620357)) {
var $ss2036020361 = {"from":L[3453],
"go":function(anf_arg778220368) {
return $Hanf_arg1121220369(anf_arg778220368,_check22003964,anf_arg77773963,ann21973965,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970);
}};
$e2035620357.stack[R.EXN_STACKHEIGHT++] = $ss2036020361;
}
if(R.isPyretException($e2035620357)) {
$e2035620357.pyretStack.push(L[3453]);
}
throw $e2035620357;
}
var $ret2036220363 = $Hanf_arg1121220369($z2035820359,_check22003964,anf_arg77773963,ann21973965,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970);
++R.GAS;
return $ret2036220363;
};
var $Hanf_arg1121220369 = function(anf_arg778220368,_check22003964,anf_arg77773963,ann21973965,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970) {
var anf_fun778320394 = G(ann21973965,"visit",L[3457]);
var $z2038620387 = D;
var $f2039220393 = function(_) {
return R.isFunction(anf_fun778320394)?anf_fun778320394.app(self21923970):R.ffi.throwNonFunApp(L[3456],anf_fun778320394,[self21923970]);
};
try {
if(--R.GAS > 0) {
$z2038620387 = $f2039220393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2039220393,
"from":L[3456]});
}
} catch($e2038420385) {
if(R.isCont($e2038420385)) {
var $ss2038820389 = {"from":L[3456],
"go":function(anf_arg778420395) {
return $Hanf_arg1121120396(anf_arg778420395,_check22003964,anf_arg77773963,anf_arg778220368,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970);
}};
$e2038420385.stack[R.EXN_STACKHEIGHT++] = $ss2038820389;
}
if(R.isPyretException($e2038420385)) {
$e2038420385.pyretStack.push(L[3456]);
}
throw $e2038420385;
}
var $ret2039020391 = $Hanf_arg1121120396($z2038620387,_check22003964,anf_arg77773963,anf_arg778220368,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970);
++R.GAS;
return $ret2039020391;
};
var $Hanf_arg1121120396 = function(anf_arg778420395,_check22003964,anf_arg77773963,anf_arg778220368,body21993967,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970) {
var anf_fun778520407 = G(body21993967,"visit",L[3459]);
var $z2039920400 = D;
var $f2040520406 = function(_) {
return R.isFunction(anf_fun778520407)?anf_fun778520407.app(self21923970):R.ffi.throwNonFunApp(L[3458],anf_fun778520407,[self21923970]);
};
try {
if(--R.GAS > 0) {
$z2039920400 = $f2040520406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2040520406,
"from":L[3458]});
}
} catch($e2039720398) {
if(R.isCont($e2039720398)) {
var $ss2040120402 = {"from":L[3458],
"go":function(anf_arg778620408) {
return $Hanf_arg1121020409(anf_arg778620408,_check22003964,anf_arg77773963,anf_arg778220368,anf_arg778420395,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970);
}};
$e2039720398.stack[R.EXN_STACKHEIGHT++] = $ss2040120402;
}
if(R.isPyretException($e2039720398)) {
$e2039720398.pyretStack.push(L[3458]);
}
throw $e2039720398;
}
var $ret2040320404 = $Hanf_arg1121020409($z2039920400,_check22003964,anf_arg77773963,anf_arg778220368,anf_arg778420395,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970);
++R.GAS;
return $ret2040320404;
};
var $Hanf_arg1121020409 = function(anf_arg778620408,_check22003964,anf_arg77773963,anf_arg778220368,anf_arg778420395,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969,self21923970) {
var anf_fun778720420 = G(self21923970,"option",L[3461]);
var $z2041220413 = D;
var $f2041820419 = function(_) {
return R.isFunction(anf_fun778720420)?anf_fun778720420.app(_check22003964):R.ffi.throwNonFunApp(L[3460],anf_fun778720420,[_check22003964]);
};
try {
if(--R.GAS > 0) {
$z2041220413 = $f2041820419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2041820419,
"from":L[3460]});
}
} catch($e2041020411) {
if(R.isCont($e2041020411)) {
var $ss2041420415 = {"from":L[3460],
"go":function(anf_arg778820421) {
return $Hanf_arg1120920422(anf_arg778820421,anf_arg77773963,anf_arg778220368,anf_arg778420395,anf_arg778620408,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969);
}};
$e2041020411.stack[R.EXN_STACKHEIGHT++] = $ss2041420415;
}
if(R.isPyretException($e2041020411)) {
$e2041020411.pyretStack.push(L[3460]);
}
throw $e2041020411;
}
var $ret2041620417 = $Hanf_arg1120920422($z2041220413,anf_arg77773963,anf_arg778220368,anf_arg778420395,anf_arg778620408,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969);
++R.GAS;
return $ret2041620417;
};
var $Hanf_arg1120920422 = function(anf_arg778820421,anf_arg77773963,anf_arg778220368,anf_arg778420395,anf_arg778620408,doc21983968,dummy_DASH_loc11796,name21943969,s_DASH_fun3341969) {
var $z2042520426 = D;
var $f2043120432 = function(_) {
return R.isFunction(s_DASH_fun3341969.$var)?s_DASH_fun3341969.$var.app(dummy_DASH_loc11796,name21943969,anf_arg77773963,anf_arg778220368,anf_arg778420395,doc21983968,anf_arg778620408,anf_arg778820421):R.ffi.throwNonFunApp(L[655],s_DASH_fun3341969.$var,[dummy_DASH_loc11796,name21943969,anf_arg77773963,anf_arg778220368,anf_arg778420395,doc21983968,anf_arg778620408,anf_arg778820421]);
};
try {
if(--R.GAS > 0) {
$z2042520426 = $f2043120432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2043120432,
"from":L[655]});
}
} catch($e2042320424) {
if(R.isCont($e2042320424)) {
var $ss2042720428 = {"from":L[655],
"go":function(ann_DASH_check_DASH_temp777220433) {
return $Hann_DASH_check_DASH_temp1120820434(ann_DASH_check_DASH_temp777220433);
}};
$e2042320424.stack[R.EXN_STACKHEIGHT++] = $ss2042720428;
}
if(R.isPyretException($e2042320424)) {
$e2042320424.pyretStack.push(L[655]);
}
throw $e2042320424;
}
var $ret2042920430 = $Hann_DASH_check_DASH_temp1120820434($z2042520426);
++R.GAS;
return $ret2042920430;
};
var $Hann_DASH_check_DASH_temp1120820434 = function(ann_DASH_check_DASH_temp777220433) {
return ann_DASH_check_DASH_temp777220433;
};
var $Hann_DASH_check_DASH_temp1120720383 = function(ann_DASH_check_DASH_temp777920382) {
return ann_DASH_check_DASH_temp777920382;
};
var $Hann_DASH_check_DASH_temp112063985 = function(ann_DASH_check_DASH_temp77743984) {
return ann_DASH_check_DASH_temp77743984;
};
var $Hanf_arg112054001 = function(anf_arg77704000,dummy_DASH_loc11796,s_DASH_user_DASH_block3321965) {
var $z2043720438 = D;
var $f2044320444 = function(_) {
return R.isFunction(s_DASH_user_DASH_block3321965.$var)?s_DASH_user_DASH_block3321965.$var.app(dummy_DASH_loc11796,anf_arg77704000):R.ffi.throwNonFunApp(L[660],s_DASH_user_DASH_block3321965.$var,[dummy_DASH_loc11796,anf_arg77704000]);
};
try {
if(--R.GAS > 0) {
$z2043720438 = $f2044320444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2044320444,
"from":L[660]});
}
} catch($e2043520436) {
if(R.isCont($e2043520436)) {
var $ss2043920440 = {"from":L[660],
"go":function(ann_DASH_check_DASH_temp776820445) {
return $Hann_DASH_check_DASH_temp1120420446(ann_DASH_check_DASH_temp776820445);
}};
$e2043520436.stack[R.EXN_STACKHEIGHT++] = $ss2043920440;
}
if(R.isPyretException($e2043520436)) {
$e2043520436.pyretStack.push(L[660]);
}
throw $e2043520436;
}
var $ret2044120442 = $Hann_DASH_check_DASH_temp1120420446($z2043720438);
++R.GAS;
return $ret2044120442;
};
var $Hann_DASH_check_DASH_temp1120420446 = function(ann_DASH_check_DASH_temp776820445) {
return ann_DASH_check_DASH_temp776820445;
};
var $Hanf_arg112034017 = function(anf_arg77664016,dummy_DASH_loc11796,s_DASH_block3301961) {
var $z2044920450 = D;
var $f2045520456 = function(_) {
return R.isFunction(s_DASH_block3301961.$var)?s_DASH_block3301961.$var.app(dummy_DASH_loc11796,anf_arg77664016):R.ffi.throwNonFunApp(L[664],s_DASH_block3301961.$var,[dummy_DASH_loc11796,anf_arg77664016]);
};
try {
if(--R.GAS > 0) {
$z2044920450 = $f2045520456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2045520456,
"from":L[664]});
}
} catch($e2044720448) {
if(R.isCont($e2044720448)) {
var $ss2045120452 = {"from":L[664],
"go":function(ann_DASH_check_DASH_temp776120457) {
return $Hann_DASH_check_DASH_temp1120220458(ann_DASH_check_DASH_temp776120457);
}};
$e2044720448.stack[R.EXN_STACKHEIGHT++] = $ss2045120452;
}
if(R.isPyretException($e2044720448)) {
$e2044720448.pyretStack.push(L[664]);
}
throw $e2044720448;
}
var $ret2045320454 = $Hann_DASH_check_DASH_temp1120220458($z2044920450);
++R.GAS;
return $ret2045320454;
};
var $Hann_DASH_check_DASH_temp1120220458 = function(ann_DASH_check_DASH_temp776120457) {
return ann_DASH_check_DASH_temp776120457;
};
var $Hann_DASH_check_DASH_temp112014032 = function(ann_DASH_check_DASH_temp77634031) {
return ann_DASH_check_DASH_temp77634031;
};
var $Hanf_arg112004049 = function(anf_arg77544047,dummy_DASH_loc11796,params21854048,s_DASH_instantiate3281957,self21824046) {
var anf_fun775520469 = G(params21854048,"map",L[3464]);
var anf_arg775820470 = R.makeFunction(function(recv_DASH_95920473) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3463],1,arguments);
}
var anf_fun775720484 = G(recv_DASH_95920473,"visit",L[3463]);
var $z2047620477 = D;
var $f2048220483 = function(_) {
return R.isFunction(anf_fun775720484)?anf_fun775720484.app(self21824046):R.ffi.throwNonFunApp(L[3463],anf_fun775720484,[self21824046]);
};
try {
if(--R.GAS > 0) {
$z2047620477 = $f2048220483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2048220483,
"from":L[3463]});
}
} catch($e2047420475) {
if(R.isCont($e2047420475)) {
var $ss2047820479 = {"from":L[3463],
"go":function(ann_DASH_check_DASH_temp775620485) {
return $Hann_DASH_check_DASH_temp1119720486(ann_DASH_check_DASH_temp775620485);
}};
$e2047420475.stack[R.EXN_STACKHEIGHT++] = $ss2047820479;
}
if(R.isPyretException($e2047420475)) {
$e2047420475.pyretStack.push(L[3463]);
}
throw $e2047420475;
}
var $ret2048020481 = $Hann_DASH_check_DASH_temp1119720486($z2047620477);
++R.GAS;
return $ret2048020481;
});
var $z2046120462 = D;
var $f2046720468 = function(_) {
return R.isFunction(anf_fun775520469)?anf_fun775520469.app(anf_arg775820470):R.ffi.throwNonFunApp(L[3462],anf_fun775520469,[anf_arg775820470]);
};
try {
if(--R.GAS > 0) {
$z2046120462 = $f2046720468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2046720468,
"from":L[3462]});
}
} catch($e2045920460) {
if(R.isCont($e2045920460)) {
var $ss2046320464 = {"from":L[3462],
"go":function(anf_arg775920471) {
return $Hanf_arg1119920472(anf_arg775920471,anf_arg77544047,dummy_DASH_loc11796,s_DASH_instantiate3281957);
}};
$e2045920460.stack[R.EXN_STACKHEIGHT++] = $ss2046320464;
}
if(R.isPyretException($e2045920460)) {
$e2045920460.pyretStack.push(L[3462]);
}
throw $e2045920460;
}
var $ret2046520466 = $Hanf_arg1119920472($z2046120462,anf_arg77544047,dummy_DASH_loc11796,s_DASH_instantiate3281957);
++R.GAS;
return $ret2046520466;
};
var $Hanf_arg1119920472 = function(anf_arg775920471,anf_arg77544047,dummy_DASH_loc11796,s_DASH_instantiate3281957) {
var $z2048920490 = D;
var $f2049520496 = function(_) {
return R.isFunction(s_DASH_instantiate3281957.$var)?s_DASH_instantiate3281957.$var.app(dummy_DASH_loc11796,anf_arg77544047,anf_arg775920471):R.ffi.throwNonFunApp(L[670],s_DASH_instantiate3281957.$var,[dummy_DASH_loc11796,anf_arg77544047,anf_arg775920471]);
};
try {
if(--R.GAS > 0) {
$z2048920490 = $f2049520496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2049520496,
"from":L[670]});
}
} catch($e2048720488) {
if(R.isCont($e2048720488)) {
var $ss2049120492 = {"from":L[670],
"go":function(ann_DASH_check_DASH_temp775220497) {
return $Hann_DASH_check_DASH_temp1119820498(ann_DASH_check_DASH_temp775220497);
}};
$e2048720488.stack[R.EXN_STACKHEIGHT++] = $ss2049120492;
}
if(R.isPyretException($e2048720488)) {
$e2048720488.pyretStack.push(L[670]);
}
throw $e2048720488;
}
var $ret2049320494 = $Hann_DASH_check_DASH_temp1119820498($z2048920490);
++R.GAS;
return $ret2049320494;
};
var $Hann_DASH_check_DASH_temp1119820498 = function(ann_DASH_check_DASH_temp775220497) {
return ann_DASH_check_DASH_temp775220497;
};
var $Hann_DASH_check_DASH_temp1119720486 = function(ann_DASH_check_DASH_temp775620485) {
return ann_DASH_check_DASH_temp775620485;
};
var $Hanf_arg111964066 = function(anf_arg77504064,dummy_DASH_loc11796,hints21804065,s_DASH_hint_DASH_exp3261953) {
var $z2050120502 = D;
var $f2050720508 = function(_) {
return R.isFunction(s_DASH_hint_DASH_exp3261953.$var)?s_DASH_hint_DASH_exp3261953.$var.app(dummy_DASH_loc11796,hints21804065,anf_arg77504064):R.ffi.throwNonFunApp(L[676],s_DASH_hint_DASH_exp3261953.$var,[dummy_DASH_loc11796,hints21804065,anf_arg77504064]);
};
try {
if(--R.GAS > 0) {
$z2050120502 = $f2050720508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2050720508,
"from":L[676]});
}
} catch($e2049920500) {
if(R.isCont($e2049920500)) {
var $ss2050320504 = {"from":L[676],
"go":function(ann_DASH_check_DASH_temp774820509) {
return $Hann_DASH_check_DASH_temp1119520510(ann_DASH_check_DASH_temp774820509);
}};
$e2049920500.stack[R.EXN_STACKHEIGHT++] = $ss2050320504;
}
if(R.isPyretException($e2049920500)) {
$e2049920500.pyretStack.push(L[676]);
}
throw $e2049920500;
}
var $ret2050520506 = $Hann_DASH_check_DASH_temp1119520510($z2050120502);
++R.GAS;
return $ret2050520506;
};
var $Hann_DASH_check_DASH_temp1119520510 = function(ann_DASH_check_DASH_temp774820509) {
return ann_DASH_check_DASH_temp774820509;
};
var $Hanf_arg111944084 = function(anf_arg77444081,body21774082,dummy_DASH_loc11796,s_DASH_letrec3241949,self21744083) {
var anf_fun774520521 = G(body21774082,"visit",L[3466]);
var $z2051320514 = D;
var $f2051920520 = function(_) {
return R.isFunction(anf_fun774520521)?anf_fun774520521.app(self21744083):R.ffi.throwNonFunApp(L[3465],anf_fun774520521,[self21744083]);
};
try {
if(--R.GAS > 0) {
$z2051320514 = $f2051920520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2051920520,
"from":L[3465]});
}
} catch($e2051120512) {
if(R.isCont($e2051120512)) {
var $ss2051520516 = {"from":L[3465],
"go":function(anf_arg774620522) {
return $Hanf_arg1119320523(anf_arg774620522,anf_arg77444081,dummy_DASH_loc11796,s_DASH_letrec3241949);
}};
$e2051120512.stack[R.EXN_STACKHEIGHT++] = $ss2051520516;
}
if(R.isPyretException($e2051120512)) {
$e2051120512.pyretStack.push(L[3465]);
}
throw $e2051120512;
}
var $ret2051720518 = $Hanf_arg1119320523($z2051320514,anf_arg77444081,dummy_DASH_loc11796,s_DASH_letrec3241949);
++R.GAS;
return $ret2051720518;
};
var $Hanf_arg1119320523 = function(anf_arg774620522,anf_arg77444081,dummy_DASH_loc11796,s_DASH_letrec3241949) {
var $z2052620527 = D;
var $f2053220533 = function(_) {
return R.isFunction(s_DASH_letrec3241949.$var)?s_DASH_letrec3241949.$var.app(dummy_DASH_loc11796,anf_arg77444081,anf_arg774620522):R.ffi.throwNonFunApp(L[680],s_DASH_letrec3241949.$var,[dummy_DASH_loc11796,anf_arg77444081,anf_arg774620522]);
};
try {
if(--R.GAS > 0) {
$z2052620527 = $f2053220533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2053220533,
"from":L[680]});
}
} catch($e2052420525) {
if(R.isCont($e2052420525)) {
var $ss2052820529 = {"from":L[680],
"go":function(ann_DASH_check_DASH_temp773920534) {
return $Hann_DASH_check_DASH_temp1119220535(ann_DASH_check_DASH_temp773920534);
}};
$e2052420525.stack[R.EXN_STACKHEIGHT++] = $ss2052820529;
}
if(R.isPyretException($e2052420525)) {
$e2052420525.pyretStack.push(L[680]);
}
throw $e2052420525;
}
var $ret2053020531 = $Hann_DASH_check_DASH_temp1119220535($z2052620527);
++R.GAS;
return $ret2053020531;
};
var $Hann_DASH_check_DASH_temp1119220535 = function(ann_DASH_check_DASH_temp773920534) {
return ann_DASH_check_DASH_temp773920534;
};
var $Hann_DASH_check_DASH_temp111914098 = function(ann_DASH_check_DASH_temp77414097) {
return ann_DASH_check_DASH_temp77414097;
};
var $Hanf_arg111904115 = function(anf_arg77354113,dummy_DASH_loc11796,expr21734114,s_DASH_letrec_DASH_bind3061913,self21704112) {
var anf_fun773620546 = G(expr21734114,"visit",L[3468]);
var $z2053820539 = D;
var $f2054420545 = function(_) {
return R.isFunction(anf_fun773620546)?anf_fun773620546.app(self21704112):R.ffi.throwNonFunApp(L[3467],anf_fun773620546,[self21704112]);
};
try {
if(--R.GAS > 0) {
$z2053820539 = $f2054420545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2054420545,
"from":L[3467]});
}
} catch($e2053620537) {
if(R.isCont($e2053620537)) {
var $ss2054020541 = {"from":L[3467],
"go":function(anf_arg773720547) {
return $Hanf_arg1118920548(anf_arg773720547,anf_arg77354113,dummy_DASH_loc11796,s_DASH_letrec_DASH_bind3061913);
}};
$e2053620537.stack[R.EXN_STACKHEIGHT++] = $ss2054020541;
}
if(R.isPyretException($e2053620537)) {
$e2053620537.pyretStack.push(L[3467]);
}
throw $e2053620537;
}
var $ret2054220543 = $Hanf_arg1118920548($z2053820539,anf_arg77354113,dummy_DASH_loc11796,s_DASH_letrec_DASH_bind3061913);
++R.GAS;
return $ret2054220543;
};
var $Hanf_arg1118920548 = function(anf_arg773720547,anf_arg77354113,dummy_DASH_loc11796,s_DASH_letrec_DASH_bind3061913) {
var $z2055120552 = D;
var $f2055720558 = function(_) {
return R.isFunction(s_DASH_letrec_DASH_bind3061913.$var)?s_DASH_letrec_DASH_bind3061913.$var.app(dummy_DASH_loc11796,anf_arg77354113,anf_arg773720547):R.ffi.throwNonFunApp(L[683],s_DASH_letrec_DASH_bind3061913.$var,[dummy_DASH_loc11796,anf_arg77354113,anf_arg773720547]);
};
try {
if(--R.GAS > 0) {
$z2055120552 = $f2055720558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2055720558,
"from":L[683]});
}
} catch($e2054920550) {
if(R.isCont($e2054920550)) {
var $ss2055320554 = {"from":L[683],
"go":function(ann_DASH_check_DASH_temp773320559) {
return $Hann_DASH_check_DASH_temp1118820560(ann_DASH_check_DASH_temp773320559);
}};
$e2054920550.stack[R.EXN_STACKHEIGHT++] = $ss2055320554;
}
if(R.isPyretException($e2054920550)) {
$e2054920550.pyretStack.push(L[683]);
}
throw $e2054920550;
}
var $ret2055520556 = $Hann_DASH_check_DASH_temp1118820560($z2055120552);
++R.GAS;
return $ret2055520556;
};
var $Hann_DASH_check_DASH_temp1118820560 = function(ann_DASH_check_DASH_temp773320559) {
return ann_DASH_check_DASH_temp773320559;
};
var $Hanf_arg111874133 = function(anf_arg77294130,body21694131,dummy_DASH_loc11796,s_DASH_let_DASH_expr3221945,self21664132) {
var anf_fun773020571 = G(body21694131,"visit",L[3470]);
var $z2056320564 = D;
var $f2056920570 = function(_) {
return R.isFunction(anf_fun773020571)?anf_fun773020571.app(self21664132):R.ffi.throwNonFunApp(L[3469],anf_fun773020571,[self21664132]);
};
try {
if(--R.GAS > 0) {
$z2056320564 = $f2056920570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2056920570,
"from":L[3469]});
}
} catch($e2056120562) {
if(R.isCont($e2056120562)) {
var $ss2056520566 = {"from":L[3469],
"go":function(anf_arg773120572) {
return $Hanf_arg1118620573(anf_arg773120572,anf_arg77294130,dummy_DASH_loc11796,s_DASH_let_DASH_expr3221945);
}};
$e2056120562.stack[R.EXN_STACKHEIGHT++] = $ss2056520566;
}
if(R.isPyretException($e2056120562)) {
$e2056120562.pyretStack.push(L[3469]);
}
throw $e2056120562;
}
var $ret2056720568 = $Hanf_arg1118620573($z2056320564,anf_arg77294130,dummy_DASH_loc11796,s_DASH_let_DASH_expr3221945);
++R.GAS;
return $ret2056720568;
};
var $Hanf_arg1118620573 = function(anf_arg773120572,anf_arg77294130,dummy_DASH_loc11796,s_DASH_let_DASH_expr3221945) {
var $z2057620577 = D;
var $f2058220583 = function(_) {
return R.isFunction(s_DASH_let_DASH_expr3221945.$var)?s_DASH_let_DASH_expr3221945.$var.app(dummy_DASH_loc11796,anf_arg77294130,anf_arg773120572):R.ffi.throwNonFunApp(L[687],s_DASH_let_DASH_expr3221945.$var,[dummy_DASH_loc11796,anf_arg77294130,anf_arg773120572]);
};
try {
if(--R.GAS > 0) {
$z2057620577 = $f2058220583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2058220583,
"from":L[687]});
}
} catch($e2057420575) {
if(R.isCont($e2057420575)) {
var $ss2057820579 = {"from":L[687],
"go":function(ann_DASH_check_DASH_temp772420584) {
return $Hann_DASH_check_DASH_temp1118520585(ann_DASH_check_DASH_temp772420584);
}};
$e2057420575.stack[R.EXN_STACKHEIGHT++] = $ss2057820579;
}
if(R.isPyretException($e2057420575)) {
$e2057420575.pyretStack.push(L[687]);
}
throw $e2057420575;
}
var $ret2058020581 = $Hann_DASH_check_DASH_temp1118520585($z2057620577);
++R.GAS;
return $ret2058020581;
};
var $Hann_DASH_check_DASH_temp1118520585 = function(ann_DASH_check_DASH_temp772420584) {
return ann_DASH_check_DASH_temp772420584;
};
var $Hann_DASH_check_DASH_temp111844147 = function(ann_DASH_check_DASH_temp77264146) {
return ann_DASH_check_DASH_temp77264146;
};
var $Hanf_arg111834165 = function(anf_arg77204162,body21654163,dummy_DASH_loc11796,s_DASH_type_DASH_let_DASH_expr3201941,self21624164) {
var anf_fun772120596 = G(body21654163,"visit",L[3472]);
var $z2058820589 = D;
var $f2059420595 = function(_) {
return R.isFunction(anf_fun772120596)?anf_fun772120596.app(self21624164):R.ffi.throwNonFunApp(L[3471],anf_fun772120596,[self21624164]);
};
try {
if(--R.GAS > 0) {
$z2058820589 = $f2059420595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2059420595,
"from":L[3471]});
}
} catch($e2058620587) {
if(R.isCont($e2058620587)) {
var $ss2059020591 = {"from":L[3471],
"go":function(anf_arg772220597) {
return $Hanf_arg1118220598(anf_arg772220597,anf_arg77204162,dummy_DASH_loc11796,s_DASH_type_DASH_let_DASH_expr3201941);
}};
$e2058620587.stack[R.EXN_STACKHEIGHT++] = $ss2059020591;
}
if(R.isPyretException($e2058620587)) {
$e2058620587.pyretStack.push(L[3471]);
}
throw $e2058620587;
}
var $ret2059220593 = $Hanf_arg1118220598($z2058820589,anf_arg77204162,dummy_DASH_loc11796,s_DASH_type_DASH_let_DASH_expr3201941);
++R.GAS;
return $ret2059220593;
};
var $Hanf_arg1118220598 = function(anf_arg772220597,anf_arg77204162,dummy_DASH_loc11796,s_DASH_type_DASH_let_DASH_expr3201941) {
var $z2060120602 = D;
var $f2060720608 = function(_) {
return R.isFunction(s_DASH_type_DASH_let_DASH_expr3201941.$var)?s_DASH_type_DASH_let_DASH_expr3201941.$var.app(dummy_DASH_loc11796,anf_arg77204162,anf_arg772220597):R.ffi.throwNonFunApp(L[691],s_DASH_type_DASH_let_DASH_expr3201941.$var,[dummy_DASH_loc11796,anf_arg77204162,anf_arg772220597]);
};
try {
if(--R.GAS > 0) {
$z2060120602 = $f2060720608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2060720608,
"from":L[691]});
}
} catch($e2059920600) {
if(R.isCont($e2059920600)) {
var $ss2060320604 = {"from":L[691],
"go":function(ann_DASH_check_DASH_temp771520609) {
return $Hann_DASH_check_DASH_temp1118120610(ann_DASH_check_DASH_temp771520609);
}};
$e2059920600.stack[R.EXN_STACKHEIGHT++] = $ss2060320604;
}
if(R.isPyretException($e2059920600)) {
$e2059920600.pyretStack.push(L[691]);
}
throw $e2059920600;
}
var $ret2060520606 = $Hann_DASH_check_DASH_temp1118120610($z2060120602);
++R.GAS;
return $ret2060520606;
};
var $Hann_DASH_check_DASH_temp1118120610 = function(ann_DASH_check_DASH_temp771520609) {
return ann_DASH_check_DASH_temp771520609;
};
var $Hann_DASH_check_DASH_temp111804179 = function(ann_DASH_check_DASH_temp77174178) {
return ann_DASH_check_DASH_temp77174178;
};
var $Hanf_arg111794197 = function(anf_arg77114194,l21594195,namet21614196,s_DASH_newtype_DASH_bind3131927,self21584193) {
var anf_fun771220621 = G(namet21614196,"visit",L[3474]);
var $z2061320614 = D;
var $f2061920620 = function(_) {
return R.isFunction(anf_fun771220621)?anf_fun771220621.app(self21584193):R.ffi.throwNonFunApp(L[3473],anf_fun771220621,[self21584193]);
};
try {
if(--R.GAS > 0) {
$z2061320614 = $f2061920620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2061920620,
"from":L[3473]});
}
} catch($e2061120612) {
if(R.isCont($e2061120612)) {
var $ss2061520616 = {"from":L[3473],
"go":function(anf_arg771320622) {
return $Hanf_arg1117820623(anf_arg771320622,anf_arg77114194,l21594195,s_DASH_newtype_DASH_bind3131927);
}};
$e2061120612.stack[R.EXN_STACKHEIGHT++] = $ss2061520616;
}
if(R.isPyretException($e2061120612)) {
$e2061120612.pyretStack.push(L[3473]);
}
throw $e2061120612;
}
var $ret2061720618 = $Hanf_arg1117820623($z2061320614,anf_arg77114194,l21594195,s_DASH_newtype_DASH_bind3131927);
++R.GAS;
return $ret2061720618;
};
var $Hanf_arg1117820623 = function(anf_arg771320622,anf_arg77114194,l21594195,s_DASH_newtype_DASH_bind3131927) {
var $z2062620627 = D;
var $f2063220633 = function(_) {
return R.isFunction(s_DASH_newtype_DASH_bind3131927.$var)?s_DASH_newtype_DASH_bind3131927.$var.app(l21594195,anf_arg77114194,anf_arg771320622):R.ffi.throwNonFunApp(L[694],s_DASH_newtype_DASH_bind3131927.$var,[l21594195,anf_arg77114194,anf_arg771320622]);
};
try {
if(--R.GAS > 0) {
$z2062620627 = $f2063220633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2063220633,
"from":L[694]});
}
} catch($e2062420625) {
if(R.isCont($e2062420625)) {
var $ss2062820629 = {"from":L[694],
"go":function(ann_DASH_check_DASH_temp770920634) {
return $Hann_DASH_check_DASH_temp1117720635(ann_DASH_check_DASH_temp770920634);
}};
$e2062420625.stack[R.EXN_STACKHEIGHT++] = $ss2062820629;
}
if(R.isPyretException($e2062420625)) {
$e2062420625.pyretStack.push(L[694]);
}
throw $e2062420625;
}
var $ret2063020631 = $Hann_DASH_check_DASH_temp1117720635($z2062620627);
++R.GAS;
return $ret2063020631;
};
var $Hann_DASH_check_DASH_temp1117720635 = function(ann_DASH_check_DASH_temp770920634) {
return ann_DASH_check_DASH_temp770920634;
};
var $Hann_DASH_check_DASH_temp111764212 = function(ann_DASH_check_DASH_temp77074211) {
return ann_DASH_check_DASH_temp77074211;
};
var $Hanf_arg111754229 = function(anf_arg77034227,dummy_DASH_loc11796,expr21534228,s_DASH_let_DASH_bind2991899,self21504226) {
var anf_fun770420646 = G(expr21534228,"visit",L[3476]);
var $z2063820639 = D;
var $f2064420645 = function(_) {
return R.isFunction(anf_fun770420646)?anf_fun770420646.app(self21504226):R.ffi.throwNonFunApp(L[3475],anf_fun770420646,[self21504226]);
};
try {
if(--R.GAS > 0) {
$z2063820639 = $f2064420645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2064420645,
"from":L[3475]});
}
} catch($e2063620637) {
if(R.isCont($e2063620637)) {
var $ss2064020641 = {"from":L[3475],
"go":function(anf_arg770520647) {
return $Hanf_arg1117420648(anf_arg770520647,anf_arg77034227,dummy_DASH_loc11796,s_DASH_let_DASH_bind2991899);
}};
$e2063620637.stack[R.EXN_STACKHEIGHT++] = $ss2064020641;
}
if(R.isPyretException($e2063620637)) {
$e2063620637.pyretStack.push(L[3475]);
}
throw $e2063620637;
}
var $ret2064220643 = $Hanf_arg1117420648($z2063820639,anf_arg77034227,dummy_DASH_loc11796,s_DASH_let_DASH_bind2991899);
++R.GAS;
return $ret2064220643;
};
var $Hanf_arg1117420648 = function(anf_arg770520647,anf_arg77034227,dummy_DASH_loc11796,s_DASH_let_DASH_bind2991899) {
var $z2065120652 = D;
var $f2065720658 = function(_) {
return R.isFunction(s_DASH_let_DASH_bind2991899.$var)?s_DASH_let_DASH_bind2991899.$var.app(dummy_DASH_loc11796,anf_arg77034227,anf_arg770520647):R.ffi.throwNonFunApp(L[698],s_DASH_let_DASH_bind2991899.$var,[dummy_DASH_loc11796,anf_arg77034227,anf_arg770520647]);
};
try {
if(--R.GAS > 0) {
$z2065120652 = $f2065720658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2065720658,
"from":L[698]});
}
} catch($e2064920650) {
if(R.isCont($e2064920650)) {
var $ss2065320654 = {"from":L[698],
"go":function(ann_DASH_check_DASH_temp770120659) {
return $Hann_DASH_check_DASH_temp1117320660(ann_DASH_check_DASH_temp770120659);
}};
$e2064920650.stack[R.EXN_STACKHEIGHT++] = $ss2065320654;
}
if(R.isPyretException($e2064920650)) {
$e2064920650.pyretStack.push(L[698]);
}
throw $e2064920650;
}
var $ret2065520656 = $Hann_DASH_check_DASH_temp1117320660($z2065120652);
++R.GAS;
return $ret2065520656;
};
var $Hann_DASH_check_DASH_temp1117320660 = function(ann_DASH_check_DASH_temp770120659) {
return ann_DASH_check_DASH_temp770120659;
};
var $Hanf_arg111724246 = function(anf_arg76974244,dummy_DASH_loc11796,expr21494245,s_DASH_var_DASH_bind3011903,self21464243) {
var anf_fun769820671 = G(expr21494245,"visit",L[3478]);
var $z2066320664 = D;
var $f2066920670 = function(_) {
return R.isFunction(anf_fun769820671)?anf_fun769820671.app(self21464243):R.ffi.throwNonFunApp(L[3477],anf_fun769820671,[self21464243]);
};
try {
if(--R.GAS > 0) {
$z2066320664 = $f2066920670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2066920670,
"from":L[3477]});
}
} catch($e2066120662) {
if(R.isCont($e2066120662)) {
var $ss2066520666 = {"from":L[3477],
"go":function(anf_arg769920672) {
return $Hanf_arg1117120673(anf_arg769920672,anf_arg76974244,dummy_DASH_loc11796,s_DASH_var_DASH_bind3011903);
}};
$e2066120662.stack[R.EXN_STACKHEIGHT++] = $ss2066520666;
}
if(R.isPyretException($e2066120662)) {
$e2066120662.pyretStack.push(L[3477]);
}
throw $e2066120662;
}
var $ret2066720668 = $Hanf_arg1117120673($z2066320664,anf_arg76974244,dummy_DASH_loc11796,s_DASH_var_DASH_bind3011903);
++R.GAS;
return $ret2066720668;
};
var $Hanf_arg1117120673 = function(anf_arg769920672,anf_arg76974244,dummy_DASH_loc11796,s_DASH_var_DASH_bind3011903) {
var $z2067620677 = D;
var $f2068220683 = function(_) {
return R.isFunction(s_DASH_var_DASH_bind3011903.$var)?s_DASH_var_DASH_bind3011903.$var.app(dummy_DASH_loc11796,anf_arg76974244,anf_arg769920672):R.ffi.throwNonFunApp(L[701],s_DASH_var_DASH_bind3011903.$var,[dummy_DASH_loc11796,anf_arg76974244,anf_arg769920672]);
};
try {
if(--R.GAS > 0) {
$z2067620677 = $f2068220683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2068220683,
"from":L[701]});
}
} catch($e2067420675) {
if(R.isCont($e2067420675)) {
var $ss2067820679 = {"from":L[701],
"go":function(ann_DASH_check_DASH_temp769520684) {
return $Hann_DASH_check_DASH_temp1117020685(ann_DASH_check_DASH_temp769520684);
}};
$e2067420675.stack[R.EXN_STACKHEIGHT++] = $ss2067820679;
}
if(R.isPyretException($e2067420675)) {
$e2067420675.pyretStack.push(L[701]);
}
throw $e2067420675;
}
var $ret2068020681 = $Hann_DASH_check_DASH_temp1117020685($z2067620677);
++R.GAS;
return $ret2068020681;
};
var $Hann_DASH_check_DASH_temp1117020685 = function(ann_DASH_check_DASH_temp769520684) {
return ann_DASH_check_DASH_temp769520684;
};
var $Hanf_arg111694264 = function(anf_arg76914261,ann21454262,dummy_DASH_loc11796,s_DASH_bind4382177,self21414260,shadows21434263) {
var anf_fun769220696 = G(ann21454262,"visit",L[3480]);
var $z2068820689 = D;
var $f2069420695 = function(_) {
return R.isFunction(anf_fun769220696)?anf_fun769220696.app(self21414260):R.ffi.throwNonFunApp(L[3479],anf_fun769220696,[self21414260]);
};
try {
if(--R.GAS > 0) {
$z2068820689 = $f2069420695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2069420695,
"from":L[3479]});
}
} catch($e2068620687) {
if(R.isCont($e2068620687)) {
var $ss2069020691 = {"from":L[3479],
"go":function(anf_arg769320697) {
return $Hanf_arg1116820698(anf_arg769320697,anf_arg76914261,dummy_DASH_loc11796,s_DASH_bind4382177,shadows21434263);
}};
$e2068620687.stack[R.EXN_STACKHEIGHT++] = $ss2069020691;
}
if(R.isPyretException($e2068620687)) {
$e2068620687.pyretStack.push(L[3479]);
}
throw $e2068620687;
}
var $ret2069220693 = $Hanf_arg1116820698($z2068820689,anf_arg76914261,dummy_DASH_loc11796,s_DASH_bind4382177,shadows21434263);
++R.GAS;
return $ret2069220693;
};
var $Hanf_arg1116820698 = function(anf_arg769320697,anf_arg76914261,dummy_DASH_loc11796,s_DASH_bind4382177,shadows21434263) {
var $z2070120702 = D;
var $f2070720708 = function(_) {
return R.isFunction(s_DASH_bind4382177.$var)?s_DASH_bind4382177.$var.app(dummy_DASH_loc11796,shadows21434263,anf_arg76914261,anf_arg769320697):R.ffi.throwNonFunApp(L[704],s_DASH_bind4382177.$var,[dummy_DASH_loc11796,shadows21434263,anf_arg76914261,anf_arg769320697]);
};
try {
if(--R.GAS > 0) {
$z2070120702 = $f2070720708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2070720708,
"from":L[704]});
}
} catch($e2069920700) {
if(R.isCont($e2069920700)) {
var $ss2070320704 = {"from":L[704],
"go":function(ann_DASH_check_DASH_temp768920709) {
return $Hann_DASH_check_DASH_temp1116720710(ann_DASH_check_DASH_temp768920709);
}};
$e2069920700.stack[R.EXN_STACKHEIGHT++] = $ss2070320704;
}
if(R.isPyretException($e2069920700)) {
$e2069920700.pyretStack.push(L[704]);
}
throw $e2069920700;
}
var $ret2070520706 = $Hann_DASH_check_DASH_temp1116720710($z2070120702);
++R.GAS;
return $ret2070520706;
};
var $Hann_DASH_check_DASH_temp1116720710 = function(ann_DASH_check_DASH_temp768920709) {
return ann_DASH_check_DASH_temp768920709;
};
var $Hann_DASH_check_DASH_temp111664278 = function(ann_DASH_check_DASH_temp76874277) {
return ann_DASH_check_DASH_temp76874277;
};
var $Hann_DASH_check_DASH_temp111654292 = function(ann_DASH_check_DASH_temp76854291) {
return ann_DASH_check_DASH_temp76854291;
};
var $Hanf_arg111644308 = function(anf_arg76834307,dummy_DASH_loc11796,s_DASH_provide2691839) {
var $z2071320714 = D;
var $f2071920720 = function(_) {
return R.isFunction(s_DASH_provide2691839.$var)?s_DASH_provide2691839.$var.app(dummy_DASH_loc11796,anf_arg76834307):R.ffi.throwNonFunApp(L[710],s_DASH_provide2691839.$var,[dummy_DASH_loc11796,anf_arg76834307]);
};
try {
if(--R.GAS > 0) {
$z2071320714 = $f2071920720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2071920720,
"from":L[710]});
}
} catch($e2071120712) {
if(R.isCont($e2071120712)) {
var $ss2071520716 = {"from":L[710],
"go":function(ann_DASH_check_DASH_temp767820721) {
return $Hann_DASH_check_DASH_temp1116320722(ann_DASH_check_DASH_temp767820721);
}};
$e2071120712.stack[R.EXN_STACKHEIGHT++] = $ss2071520716;
}
if(R.isPyretException($e2071120712)) {
$e2071120712.pyretStack.push(L[710]);
}
throw $e2071120712;
}
var $ret2071720718 = $Hann_DASH_check_DASH_temp1116320722($z2071320714);
++R.GAS;
return $ret2071720718;
};
var $Hann_DASH_check_DASH_temp1116320722 = function(ann_DASH_check_DASH_temp767820721) {
return ann_DASH_check_DASH_temp767820721;
};
var $Hann_DASH_check_DASH_temp111624323 = function(ann_DASH_check_DASH_temp76804322) {
return ann_DASH_check_DASH_temp76804322;
};
var $Hann_DASH_check_DASH_temp111614337 = function(ann_DASH_check_DASH_temp76764336) {
return ann_DASH_check_DASH_temp76764336;
};
var $Hann_DASH_check_DASH_temp111604351 = function(ann_DASH_check_DASH_temp76744350) {
return ann_DASH_check_DASH_temp76744350;
};
var $Hanf_arg111594367 = function(anf_arg76724366,dummy_DASH_loc11796,s_DASH_provide2691839) {
var $z2072520726 = D;
var $f2073120732 = function(_) {
return R.isFunction(s_DASH_provide2691839.$var)?s_DASH_provide2691839.$var.app(dummy_DASH_loc11796,anf_arg76724366):R.ffi.throwNonFunApp(L[715],s_DASH_provide2691839.$var,[dummy_DASH_loc11796,anf_arg76724366]);
};
try {
if(--R.GAS > 0) {
$z2072520726 = $f2073120732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2073120732,
"from":L[715]});
}
} catch($e2072320724) {
if(R.isCont($e2072320724)) {
var $ss2072720728 = {"from":L[715],
"go":function(ann_DASH_check_DASH_temp767020733) {
return $Hann_DASH_check_DASH_temp1115820734(ann_DASH_check_DASH_temp767020733);
}};
$e2072320724.stack[R.EXN_STACKHEIGHT++] = $ss2072720728;
}
if(R.isPyretException($e2072320724)) {
$e2072320724.pyretStack.push(L[715]);
}
throw $e2072320724;
}
var $ret2072920730 = $Hann_DASH_check_DASH_temp1115820734($z2072520726);
++R.GAS;
return $ret2072920730;
};
var $Hann_DASH_check_DASH_temp1115820734 = function(ann_DASH_check_DASH_temp767020733) {
return ann_DASH_check_DASH_temp767020733;
};
var $Hanf_arg111574385 = function(anf_arg76664382,dummy_DASH_loc11796,import_DASH_type21264383,s_DASH_import_DASH_fields2641829,self21234384) {
var anf_fun766720745 = G(import_DASH_type21264383,"visit",L[3482]);
var $z2073720738 = D;
var $f2074320744 = function(_) {
return R.isFunction(anf_fun766720745)?anf_fun766720745.app(self21234384):R.ffi.throwNonFunApp(L[3481],anf_fun766720745,[self21234384]);
};
try {
if(--R.GAS > 0) {
$z2073720738 = $f2074320744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2074320744,
"from":L[3481]});
}
} catch($e2073520736) {
if(R.isCont($e2073520736)) {
var $ss2073920740 = {"from":L[3481],
"go":function(anf_arg766820746) {
return $Hanf_arg1115620747(anf_arg766820746,anf_arg76664382,dummy_DASH_loc11796,s_DASH_import_DASH_fields2641829);
}};
$e2073520736.stack[R.EXN_STACKHEIGHT++] = $ss2073920740;
}
if(R.isPyretException($e2073520736)) {
$e2073520736.pyretStack.push(L[3481]);
}
throw $e2073520736;
}
var $ret2074120742 = $Hanf_arg1115620747($z2073720738,anf_arg76664382,dummy_DASH_loc11796,s_DASH_import_DASH_fields2641829);
++R.GAS;
return $ret2074120742;
};
var $Hanf_arg1115620747 = function(anf_arg766820746,anf_arg76664382,dummy_DASH_loc11796,s_DASH_import_DASH_fields2641829) {
var $z2075020751 = D;
var $f2075620757 = function(_) {
return R.isFunction(s_DASH_import_DASH_fields2641829.$var)?s_DASH_import_DASH_fields2641829.$var.app(dummy_DASH_loc11796,anf_arg76664382,anf_arg766820746):R.ffi.throwNonFunApp(L[719],s_DASH_import_DASH_fields2641829.$var,[dummy_DASH_loc11796,anf_arg76664382,anf_arg766820746]);
};
try {
if(--R.GAS > 0) {
$z2075020751 = $f2075620757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2075620757,
"from":L[719]});
}
} catch($e2074820749) {
if(R.isCont($e2074820749)) {
var $ss2075220753 = {"from":L[719],
"go":function(ann_DASH_check_DASH_temp766120758) {
return $Hann_DASH_check_DASH_temp1115520759(ann_DASH_check_DASH_temp766120758);
}};
$e2074820749.stack[R.EXN_STACKHEIGHT++] = $ss2075220753;
}
if(R.isPyretException($e2074820749)) {
$e2074820749.pyretStack.push(L[719]);
}
throw $e2074820749;
}
var $ret2075420755 = $Hann_DASH_check_DASH_temp1115520759($z2075020751);
++R.GAS;
return $ret2075420755;
};
var $Hann_DASH_check_DASH_temp1115520759 = function(ann_DASH_check_DASH_temp766120758) {
return ann_DASH_check_DASH_temp766120758;
};
var $Hann_DASH_check_DASH_temp111544399 = function(ann_DASH_check_DASH_temp76634398) {
return ann_DASH_check_DASH_temp76634398;
};
var $Hanf_arg111534417 = function(anf_arg76554414,dummy_DASH_loc11796,name21214415,s_DASH_import_DASH_types2621825,self21184413,types21224416) {
var anf_fun765620770 = G(name21214415,"visit",L[3484]);
var $z2076220763 = D;
var $f2076820769 = function(_) {
return R.isFunction(anf_fun765620770)?anf_fun765620770.app(self21184413):R.ffi.throwNonFunApp(L[3483],anf_fun765620770,[self21184413]);
};
try {
if(--R.GAS > 0) {
$z2076220763 = $f2076820769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2076820769,
"from":L[3483]});
}
} catch($e2076020761) {
if(R.isCont($e2076020761)) {
var $ss2076420765 = {"from":L[3483],
"go":function(anf_arg765720771) {
return $Hanf_arg1115220772(anf_arg765720771,anf_arg76554414,dummy_DASH_loc11796,s_DASH_import_DASH_types2621825,self21184413,types21224416);
}};
$e2076020761.stack[R.EXN_STACKHEIGHT++] = $ss2076420765;
}
if(R.isPyretException($e2076020761)) {
$e2076020761.pyretStack.push(L[3483]);
}
throw $e2076020761;
}
var $ret2076620767 = $Hanf_arg1115220772($z2076220763,anf_arg76554414,dummy_DASH_loc11796,s_DASH_import_DASH_types2621825,self21184413,types21224416);
++R.GAS;
return $ret2076620767;
};
var $Hanf_arg1115220772 = function(anf_arg765720771,anf_arg76554414,dummy_DASH_loc11796,s_DASH_import_DASH_types2621825,self21184413,types21224416) {
var anf_fun765820783 = G(types21224416,"visit",L[3486]);
var $z2077520776 = D;
var $f2078120782 = function(_) {
return R.isFunction(anf_fun765820783)?anf_fun765820783.app(self21184413):R.ffi.throwNonFunApp(L[3485],anf_fun765820783,[self21184413]);
};
try {
if(--R.GAS > 0) {
$z2077520776 = $f2078120782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2078120782,
"from":L[3485]});
}
} catch($e2077320774) {
if(R.isCont($e2077320774)) {
var $ss2077720778 = {"from":L[3485],
"go":function(anf_arg765920784) {
return $Hanf_arg1115120785(anf_arg765920784,anf_arg76554414,anf_arg765720771,dummy_DASH_loc11796,s_DASH_import_DASH_types2621825);
}};
$e2077320774.stack[R.EXN_STACKHEIGHT++] = $ss2077720778;
}
if(R.isPyretException($e2077320774)) {
$e2077320774.pyretStack.push(L[3485]);
}
throw $e2077320774;
}
var $ret2077920780 = $Hanf_arg1115120785($z2077520776,anf_arg76554414,anf_arg765720771,dummy_DASH_loc11796,s_DASH_import_DASH_types2621825);
++R.GAS;
return $ret2077920780;
};
var $Hanf_arg1115120785 = function(anf_arg765920784,anf_arg76554414,anf_arg765720771,dummy_DASH_loc11796,s_DASH_import_DASH_types2621825) {
var $z2078820789 = D;
var $f2079420795 = function(_) {
return R.isFunction(s_DASH_import_DASH_types2621825.$var)?s_DASH_import_DASH_types2621825.$var.app(dummy_DASH_loc11796,anf_arg76554414,anf_arg765720771,anf_arg765920784):R.ffi.throwNonFunApp(L[722],s_DASH_import_DASH_types2621825.$var,[dummy_DASH_loc11796,anf_arg76554414,anf_arg765720771,anf_arg765920784]);
};
try {
if(--R.GAS > 0) {
$z2078820789 = $f2079420795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2079420795,
"from":L[722]});
}
} catch($e2078620787) {
if(R.isCont($e2078620787)) {
var $ss2079020791 = {"from":L[722],
"go":function(ann_DASH_check_DASH_temp765320796) {
return $Hann_DASH_check_DASH_temp1115020797(ann_DASH_check_DASH_temp765320796);
}};
$e2078620787.stack[R.EXN_STACKHEIGHT++] = $ss2079020791;
}
if(R.isPyretException($e2078620787)) {
$e2078620787.pyretStack.push(L[722]);
}
throw $e2078620787;
}
var $ret2079220793 = $Hann_DASH_check_DASH_temp1115020797($z2078820789);
++R.GAS;
return $ret2079220793;
};
var $Hann_DASH_check_DASH_temp1115020797 = function(ann_DASH_check_DASH_temp765320796) {
return ann_DASH_check_DASH_temp765320796;
};
var $Hanf_arg111494434 = function(anf_arg76494432,dummy_DASH_loc11796,name21174433,s_DASH_import2601821,self21144431) {
var anf_fun765020808 = G(name21174433,"visit",L[3488]);
var $z2080020801 = D;
var $f2080620807 = function(_) {
return R.isFunction(anf_fun765020808)?anf_fun765020808.app(self21144431):R.ffi.throwNonFunApp(L[3487],anf_fun765020808,[self21144431]);
};
try {
if(--R.GAS > 0) {
$z2080020801 = $f2080620807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2080620807,
"from":L[3487]});
}
} catch($e2079820799) {
if(R.isCont($e2079820799)) {
var $ss2080220803 = {"from":L[3487],
"go":function(anf_arg765120809) {
return $Hanf_arg1114820810(anf_arg765120809,anf_arg76494432,dummy_DASH_loc11796,s_DASH_import2601821);
}};
$e2079820799.stack[R.EXN_STACKHEIGHT++] = $ss2080220803;
}
if(R.isPyretException($e2079820799)) {
$e2079820799.pyretStack.push(L[3487]);
}
throw $e2079820799;
}
var $ret2080420805 = $Hanf_arg1114820810($z2080020801,anf_arg76494432,dummy_DASH_loc11796,s_DASH_import2601821);
++R.GAS;
return $ret2080420805;
};
var $Hanf_arg1114820810 = function(anf_arg765120809,anf_arg76494432,dummy_DASH_loc11796,s_DASH_import2601821) {
var $z2081320814 = D;
var $f2081920820 = function(_) {
return R.isFunction(s_DASH_import2601821.$var)?s_DASH_import2601821.$var.app(dummy_DASH_loc11796,anf_arg76494432,anf_arg765120809):R.ffi.throwNonFunApp(L[725],s_DASH_import2601821.$var,[dummy_DASH_loc11796,anf_arg76494432,anf_arg765120809]);
};
try {
if(--R.GAS > 0) {
$z2081320814 = $f2081920820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2081920820,
"from":L[725]});
}
} catch($e2081120812) {
if(R.isCont($e2081120812)) {
var $ss2081520816 = {"from":L[725],
"go":function(ann_DASH_check_DASH_temp764720821) {
return $Hann_DASH_check_DASH_temp1114720822(ann_DASH_check_DASH_temp764720821);
}};
$e2081120812.stack[R.EXN_STACKHEIGHT++] = $ss2081520816;
}
if(R.isPyretException($e2081120812)) {
$e2081120812.pyretStack.push(L[725]);
}
throw $e2081120812;
}
var $ret2081720818 = $Hann_DASH_check_DASH_temp1114720822($z2081320814);
++R.GAS;
return $ret2081720818;
};
var $Hann_DASH_check_DASH_temp1114720822 = function(ann_DASH_check_DASH_temp764720821) {
return ann_DASH_check_DASH_temp764720821;
};
var $Hann_DASH_check_DASH_temp111464449 = function(ann_DASH_check_DASH_temp76454448) {
return ann_DASH_check_DASH_temp76454448;
};
var $Hann_DASH_check_DASH_temp111454464 = function(ann_DASH_check_DASH_temp76434463) {
return ann_DASH_check_DASH_temp76434463;
};
var $Hanf_arg111444483 = function(anf_arg76324479,body21074480,dummy_DASH_loc11796,imports21064481,provided_DASH_types21054482,s_DASH_program2551811,self21024478) {
var anf_fun763320833 = G(provided_DASH_types21054482,"visit",L[3490]);
var $z2082520826 = D;
var $f2083120832 = function(_) {
return R.isFunction(anf_fun763320833)?anf_fun763320833.app(self21024478):R.ffi.throwNonFunApp(L[3489],anf_fun763320833,[self21024478]);
};
try {
if(--R.GAS > 0) {
$z2082520826 = $f2083120832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2083120832,
"from":L[3489]});
}
} catch($e2082320824) {
if(R.isCont($e2082320824)) {
var $ss2082720828 = {"from":L[3489],
"go":function(anf_arg763420834) {
return $Hanf_arg1114320835(anf_arg763420834,anf_arg76324479,body21074480,dummy_DASH_loc11796,imports21064481,s_DASH_program2551811,self21024478);
}};
$e2082320824.stack[R.EXN_STACKHEIGHT++] = $ss2082720828;
}
if(R.isPyretException($e2082320824)) {
$e2082320824.pyretStack.push(L[3489]);
}
throw $e2082320824;
}
var $ret2082920830 = $Hanf_arg1114320835($z2082520826,anf_arg76324479,body21074480,dummy_DASH_loc11796,imports21064481,s_DASH_program2551811,self21024478);
++R.GAS;
return $ret2082920830;
};
var $Hanf_arg1114320835 = function(anf_arg763420834,anf_arg76324479,body21074480,dummy_DASH_loc11796,imports21064481,s_DASH_program2551811,self21024478) {
var anf_fun763520846 = G(imports21064481,"map",L[3493]);
var anf_arg763820847 = R.makeFunction(function(recv_DASH_95320850) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3492],1,arguments);
}
var anf_fun763720861 = G(recv_DASH_95320850,"visit",L[3492]);
var $z2085320854 = D;
var $f2085920860 = function(_) {
return R.isFunction(anf_fun763720861)?anf_fun763720861.app(self21024478):R.ffi.throwNonFunApp(L[3492],anf_fun763720861,[self21024478]);
};
try {
if(--R.GAS > 0) {
$z2085320854 = $f2085920860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2085920860,
"from":L[3492]});
}
} catch($e2085120852) {
if(R.isCont($e2085120852)) {
var $ss2085520856 = {"from":L[3492],
"go":function(ann_DASH_check_DASH_temp763620862) {
return $Hann_DASH_check_DASH_temp1113920863(ann_DASH_check_DASH_temp763620862);
}};
$e2085120852.stack[R.EXN_STACKHEIGHT++] = $ss2085520856;
}
if(R.isPyretException($e2085120852)) {
$e2085120852.pyretStack.push(L[3492]);
}
throw $e2085120852;
}
var $ret2085720858 = $Hann_DASH_check_DASH_temp1113920863($z2085320854);
++R.GAS;
return $ret2085720858;
});
var $z2083820839 = D;
var $f2084420845 = function(_) {
return R.isFunction(anf_fun763520846)?anf_fun763520846.app(anf_arg763820847):R.ffi.throwNonFunApp(L[3491],anf_fun763520846,[anf_arg763820847]);
};
try {
if(--R.GAS > 0) {
$z2083820839 = $f2084420845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2084420845,
"from":L[3491]});
}
} catch($e2083620837) {
if(R.isCont($e2083620837)) {
var $ss2084020841 = {"from":L[3491],
"go":function(anf_arg763920848) {
return $Hanf_arg1114220849(anf_arg763920848,anf_arg76324479,anf_arg763420834,body21074480,dummy_DASH_loc11796,s_DASH_program2551811,self21024478);
}};
$e2083620837.stack[R.EXN_STACKHEIGHT++] = $ss2084020841;
}
if(R.isPyretException($e2083620837)) {
$e2083620837.pyretStack.push(L[3491]);
}
throw $e2083620837;
}
var $ret2084220843 = $Hanf_arg1114220849($z2083820839,anf_arg76324479,anf_arg763420834,body21074480,dummy_DASH_loc11796,s_DASH_program2551811,self21024478);
++R.GAS;
return $ret2084220843;
};
var $Hanf_arg1114220849 = function(anf_arg763920848,anf_arg76324479,anf_arg763420834,body21074480,dummy_DASH_loc11796,s_DASH_program2551811,self21024478) {
var anf_fun764020874 = G(body21074480,"visit",L[3495]);
var $z2086620867 = D;
var $f2087220873 = function(_) {
return R.isFunction(anf_fun764020874)?anf_fun764020874.app(self21024478):R.ffi.throwNonFunApp(L[3494],anf_fun764020874,[self21024478]);
};
try {
if(--R.GAS > 0) {
$z2086620867 = $f2087220873();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2087220873,
"from":L[3494]});
}
} catch($e2086420865) {
if(R.isCont($e2086420865)) {
var $ss2086820869 = {"from":L[3494],
"go":function(anf_arg764120875) {
return $Hanf_arg1114120876(anf_arg764120875,anf_arg76324479,anf_arg763420834,anf_arg763920848,dummy_DASH_loc11796,s_DASH_program2551811);
}};
$e2086420865.stack[R.EXN_STACKHEIGHT++] = $ss2086820869;
}
if(R.isPyretException($e2086420865)) {
$e2086420865.pyretStack.push(L[3494]);
}
throw $e2086420865;
}
var $ret2087020871 = $Hanf_arg1114120876($z2086620867,anf_arg76324479,anf_arg763420834,anf_arg763920848,dummy_DASH_loc11796,s_DASH_program2551811);
++R.GAS;
return $ret2087020871;
};
var $Hanf_arg1114120876 = function(anf_arg764120875,anf_arg76324479,anf_arg763420834,anf_arg763920848,dummy_DASH_loc11796,s_DASH_program2551811) {
var $z2087920880 = D;
var $f2088520886 = function(_) {
return R.isFunction(s_DASH_program2551811.$var)?s_DASH_program2551811.$var.app(dummy_DASH_loc11796,anf_arg76324479,anf_arg763420834,anf_arg763920848,anf_arg764120875):R.ffi.throwNonFunApp(L[734],s_DASH_program2551811.$var,[dummy_DASH_loc11796,anf_arg76324479,anf_arg763420834,anf_arg763920848,anf_arg764120875]);
};
try {
if(--R.GAS > 0) {
$z2087920880 = $f2088520886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2088520886,
"from":L[734]});
}
} catch($e2087720878) {
if(R.isCont($e2087720878)) {
var $ss2088120882 = {"from":L[734],
"go":function(ann_DASH_check_DASH_temp763020887) {
return $Hann_DASH_check_DASH_temp1114020888(ann_DASH_check_DASH_temp763020887);
}};
$e2087720878.stack[R.EXN_STACKHEIGHT++] = $ss2088120882;
}
if(R.isPyretException($e2087720878)) {
$e2087720878.pyretStack.push(L[734]);
}
throw $e2087720878;
}
var $ret2088320884 = $Hann_DASH_check_DASH_temp1114020888($z2087920880);
++R.GAS;
return $ret2088320884;
};
var $Hann_DASH_check_DASH_temp1114020888 = function(ann_DASH_check_DASH_temp763020887) {
return ann_DASH_check_DASH_temp763020887;
};
var $Hann_DASH_check_DASH_temp1113920863 = function(ann_DASH_check_DASH_temp763620862) {
return ann_DASH_check_DASH_temp763620862;
};
var $Hanf_arg111384502 = function(anf_arg76194498,checks21014499,dummy_DASH_loc11796,lists974,provides20994500,s_DASH_module3181937,self20964497,types21004501) {
var anf_fun762020899 = G(provides20994500,"visit",L[3497]);
var $z2089120892 = D;
var $f2089720898 = function(_) {
return R.isFunction(anf_fun762020899)?anf_fun762020899.app(self20964497):R.ffi.throwNonFunApp(L[3496],anf_fun762020899,[self20964497]);
};
try {
if(--R.GAS > 0) {
$z2089120892 = $f2089720898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2089720898,
"from":L[3496]});
}
} catch($e2088920890) {
if(R.isCont($e2088920890)) {
var $ss2089320894 = {"from":L[3496],
"go":function(anf_arg762120900) {
return $Hanf_arg1113720901(anf_arg762120900,anf_arg76194498,checks21014499,dummy_DASH_loc11796,lists974,s_DASH_module3181937,self20964497,types21004501);
}};
$e2088920890.stack[R.EXN_STACKHEIGHT++] = $ss2089320894;
}
if(R.isPyretException($e2088920890)) {
$e2088920890.pyretStack.push(L[3496]);
}
throw $e2088920890;
}
var $ret2089520896 = $Hanf_arg1113720901($z2089120892,anf_arg76194498,checks21014499,dummy_DASH_loc11796,lists974,s_DASH_module3181937,self20964497,types21004501);
++R.GAS;
return $ret2089520896;
};
var $Hanf_arg1113720901 = function(anf_arg762120900,anf_arg76194498,checks21014499,dummy_DASH_loc11796,lists974,s_DASH_module3181937,self20964497,types21004501) {
var anf_fun762220912 = G(lists974,"map",L[3500]);
var anf_arg762520913 = R.makeFunction(function(recv_DASH_95220916) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3499],1,arguments);
}
var anf_fun762420927 = G(recv_DASH_95220916,"visit",L[3499]);
var $z2091920920 = D;
var $f2092520926 = function(_) {
return R.isFunction(anf_fun762420927)?anf_fun762420927.app(self20964497):R.ffi.throwNonFunApp(L[3499],anf_fun762420927,[self20964497]);
};
try {
if(--R.GAS > 0) {
$z2091920920 = $f2092520926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2092520926,
"from":L[3499]});
}
} catch($e2091720918) {
if(R.isCont($e2091720918)) {
var $ss2092120922 = {"from":L[3499],
"go":function(ann_DASH_check_DASH_temp762320928) {
return $Hann_DASH_check_DASH_temp1113320929(ann_DASH_check_DASH_temp762320928);
}};
$e2091720918.stack[R.EXN_STACKHEIGHT++] = $ss2092120922;
}
if(R.isPyretException($e2091720918)) {
$e2091720918.pyretStack.push(L[3499]);
}
throw $e2091720918;
}
var $ret2092320924 = $Hann_DASH_check_DASH_temp1113320929($z2091920920);
++R.GAS;
return $ret2092320924;
});
var $z2090420905 = D;
var $f2091020911 = function(_) {
return R.isFunction(anf_fun762220912)?anf_fun762220912.app(anf_arg762520913,types21004501):R.ffi.throwNonFunApp(L[3498],anf_fun762220912,[anf_arg762520913,types21004501]);
};
try {
if(--R.GAS > 0) {
$z2090420905 = $f2091020911();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2091020911,
"from":L[3498]});
}
} catch($e2090220903) {
if(R.isCont($e2090220903)) {
var $ss2090620907 = {"from":L[3498],
"go":function(anf_arg762620914) {
return $Hanf_arg1113620915(anf_arg762620914,anf_arg76194498,anf_arg762120900,checks21014499,dummy_DASH_loc11796,s_DASH_module3181937,self20964497);
}};
$e2090220903.stack[R.EXN_STACKHEIGHT++] = $ss2090620907;
}
if(R.isPyretException($e2090220903)) {
$e2090220903.pyretStack.push(L[3498]);
}
throw $e2090220903;
}
var $ret2090820909 = $Hanf_arg1113620915($z2090420905,anf_arg76194498,anf_arg762120900,checks21014499,dummy_DASH_loc11796,s_DASH_module3181937,self20964497);
++R.GAS;
return $ret2090820909;
};
var $Hanf_arg1113620915 = function(anf_arg762620914,anf_arg76194498,anf_arg762120900,checks21014499,dummy_DASH_loc11796,s_DASH_module3181937,self20964497) {
var anf_fun762720940 = G(checks21014499,"visit",L[3502]);
var $z2093220933 = D;
var $f2093820939 = function(_) {
return R.isFunction(anf_fun762720940)?anf_fun762720940.app(self20964497):R.ffi.throwNonFunApp(L[3501],anf_fun762720940,[self20964497]);
};
try {
if(--R.GAS > 0) {
$z2093220933 = $f2093820939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2093820939,
"from":L[3501]});
}
} catch($e2093020931) {
if(R.isCont($e2093020931)) {
var $ss2093420935 = {"from":L[3501],
"go":function(anf_arg762820941) {
return $Hanf_arg1113520942(anf_arg762820941,anf_arg76194498,anf_arg762120900,anf_arg762620914,dummy_DASH_loc11796,s_DASH_module3181937);
}};
$e2093020931.stack[R.EXN_STACKHEIGHT++] = $ss2093420935;
}
if(R.isPyretException($e2093020931)) {
$e2093020931.pyretStack.push(L[3501]);
}
throw $e2093020931;
}
var $ret2093620937 = $Hanf_arg1113520942($z2093220933,anf_arg76194498,anf_arg762120900,anf_arg762620914,dummy_DASH_loc11796,s_DASH_module3181937);
++R.GAS;
return $ret2093620937;
};
var $Hanf_arg1113520942 = function(anf_arg762820941,anf_arg76194498,anf_arg762120900,anf_arg762620914,dummy_DASH_loc11796,s_DASH_module3181937) {
var $z2094520946 = D;
var $f2095120952 = function(_) {
return R.isFunction(s_DASH_module3181937.$var)?s_DASH_module3181937.$var.app(dummy_DASH_loc11796,anf_arg76194498,anf_arg762120900,anf_arg762620914,anf_arg762820941):R.ffi.throwNonFunApp(L[737],s_DASH_module3181937.$var,[dummy_DASH_loc11796,anf_arg76194498,anf_arg762120900,anf_arg762620914,anf_arg762820941]);
};
try {
if(--R.GAS > 0) {
$z2094520946 = $f2095120952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2095120952,
"from":L[737]});
}
} catch($e2094320944) {
if(R.isCont($e2094320944)) {
var $ss2094720948 = {"from":L[737],
"go":function(ann_DASH_check_DASH_temp761720953) {
return $Hann_DASH_check_DASH_temp1113420954(ann_DASH_check_DASH_temp761720953);
}};
$e2094320944.stack[R.EXN_STACKHEIGHT++] = $ss2094720948;
}
if(R.isPyretException($e2094320944)) {
$e2094320944.pyretStack.push(L[737]);
}
throw $e2094320944;
}
var $ret2094920950 = $Hann_DASH_check_DASH_temp1113420954($z2094520946);
++R.GAS;
return $ret2094920950;
};
var $Hann_DASH_check_DASH_temp1113420954 = function(ann_DASH_check_DASH_temp761720953) {
return ann_DASH_check_DASH_temp761720953;
};
var $Hann_DASH_check_DASH_temp1113320929 = function(ann_DASH_check_DASH_temp762320928) {
return ann_DASH_check_DASH_temp762320928;
};
var $Hann_DASH_check_DASH_temp111324518 = function(ann_DASH_check_DASH_temp76154517) {
return ann_DASH_check_DASH_temp76154517;
};
var $Hann_DASH_check_DASH_temp111314532 = function(ann_DASH_check_DASH_temp76134531) {
return ann_DASH_check_DASH_temp76134531;
};
var $Hann_DASH_check_DASH_temp111304546 = function(ann_DASH_check_DASH_temp76114545) {
return ann_DASH_check_DASH_temp76114545;
};
var $Hann_DASH_check_DASH_temp111294560 = function(ann_DASH_check_DASH_temp76094559) {
return ann_DASH_check_DASH_temp76094559;
};
var $Hann_DASH_check_DASH_temp111284574 = function(ann_DASH_check_DASH_temp76074573) {
return ann_DASH_check_DASH_temp76074573;
};
var $Hann_DASH_check_DASH_temp111274591 = function(ann_DASH_check_DASH_temp75954590) {
return ann_DASH_check_DASH_temp75954590;
};
var $Hanf_arg111264609 = function(anf_arg76014608,some62156) {
var $z2095720958 = D;
var $f2096320964 = function(_) {
return R.isFunction(some62156)?some62156.app(anf_arg76014608):R.ffi.throwNonFunApp(L[745],some62156,[anf_arg76014608]);
};
try {
if(--R.GAS > 0) {
$z2095720958 = $f2096320964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2096320964,
"from":L[745]});
}
} catch($e2095520956) {
if(R.isCont($e2095520956)) {
var $ss2095920960 = {"from":L[745],
"go":function(ann_DASH_check_DASH_temp759920965) {
return $Hann_DASH_check_DASH_temp1112520966(ann_DASH_check_DASH_temp759920965);
}};
$e2095520956.stack[R.EXN_STACKHEIGHT++] = $ss2095920960;
}
if(R.isPyretException($e2095520956)) {
$e2095520956.pyretStack.push(L[745]);
}
throw $e2095520956;
}
var $ret2096120962 = $Hann_DASH_check_DASH_temp1112520966($z2095720958);
++R.GAS;
return $ret2096120962;
};
var $Hann_DASH_check_DASH_temp1112520966 = function(ann_DASH_check_DASH_temp759920965) {
return ann_DASH_check_DASH_temp759920965;
};
var $Hann_DASH_check_DASH_temp111244729 = function(ann_DASH_check_DASH_temp75924728) {
return ann_DASH_check_DASH_temp75924728;
};
var $Hann_DASH_check_DASH_temp111234746 = function(ann_DASH_check_DASH_temp75894745) {
return ann_DASH_check_DASH_temp75894745;
};
var $Hand_DASH_oper_DASH_111224764 = function(and_DASH_oper_DASH_9494762,exp20714763,self20684761) {
var if_helper757720979 = R.makeFunction(function(if_helper_arg757820997) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[753],1,arguments);
}
var ann_DASH_check_DASH_temp757520998 = if_helper_arg757820997;
return ann_DASH_check_DASH_temp757520998;
});
var anf_if758120996 = R.isBoolean(and_DASH_oper_DASH_9494762);
if(R.isPyretTrue(anf_if758120996)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9494762)) {
var anf_fun758320977 = G(exp20714763,"visit",L[3503]);
var $z2096920970 = D;
var $f2097520976 = function(_) {
return R.isFunction(anf_fun758320977)?anf_fun758320977.app(self20684761):R.ffi.throwNonFunApp(L[753],anf_fun758320977,[self20684761]);
};
try {
if(--R.GAS > 0) {
$z2096920970 = $f2097520976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2097520976,
"from":L[753]});
}
} catch($e2096720968) {
if(R.isCont($e2096720968)) {
var $ss2097120972 = {"from":L[753],
"go":function(and_DASH_oper_DASH_95020978) {
return $Hand_DASH_oper_DASH_1112020980(and_DASH_oper_DASH_95020978,if_helper757720979);
}};
$e2096720968.stack[R.EXN_STACKHEIGHT++] = $ss2097120972;
}
if(R.isPyretException($e2096720968)) {
$e2096720968.pyretStack.push(L[753]);
}
throw $e2096720968;
}
var $ret2097320974 = $Hand_DASH_oper_DASH_1112020980($z2096920970,if_helper757720979);
++R.GAS;
return $ret2097320974;
} else {
var $z2098320984 = D;
var $f2098920990 = function(_) {
return R.isFunction(if_helper757720979)?if_helper757720979.app((false)):R.ffi.throwNonFunApp(L[753],if_helper757720979,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2098320984 = $f2098920990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2098920990,
"from":L[753]});
}
} catch($e2098120982) {
if(R.isCont($e2098120982)) {
var $ss2098520986 = {"from":L[753],
"go":function(cont_tail_app758220991) {
return $Hcont_tail_app1112120992(cont_tail_app758220991);
}};
$e2098120982.stack[R.EXN_STACKHEIGHT++] = $ss2098520986;
}
if(R.isPyretException($e2098120982)) {
$e2098120982.pyretStack.push(L[753]);
}
throw $e2098120982;
}
var $ret2098720988 = $Hcont_tail_app1112120992($z2098320984);
++R.GAS;
return $ret2098720988;
}
} else {
var cont_tail_arg757920995 = R.throwNonBooleanOp(L[3504],("first"),("and"),and_DASH_oper_DASH_9494762);
if(--R.GAS > 0) {
$z2099320994 = R.isFunction(if_helper757720979)?if_helper757720979.app(cont_tail_arg757920995):R.ffi.throwNonFunApp(L[3504],if_helper757720979,[cont_tail_arg757920995]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper757720979)?if_helper757720979.app(cont_tail_arg757920995):R.ffi.throwNonFunApp(L[3504],if_helper757720979,[cont_tail_arg757920995]);
},
"from":L[3504]});
}
++R.GAS;
return $z2099320994;
}
};
var $Hand_DASH_oper_DASH_1112020980 = function(and_DASH_oper_DASH_95020978,if_helper757720979) {
var anf_if758621014 = R.isBoolean(and_DASH_oper_DASH_95020978);
if(R.isPyretTrue(anf_if758621014)) {
var $z2100121002 = D;
var $f2100721008 = function(_) {
return R.isFunction(if_helper757720979)?if_helper757720979.app(and_DASH_oper_DASH_95020978):R.ffi.throwNonFunApp(L[753],if_helper757720979,[and_DASH_oper_DASH_95020978]);
};
try {
if(--R.GAS > 0) {
$z2100121002 = $f2100721008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2100721008,
"from":L[753]});
}
} catch($e2099921000) {
if(R.isCont($e2099921000)) {
var $ss2100321004 = {"from":L[753],
"go":function(cont_tail_app758721009) {
return $Hcont_tail_app1111921010(cont_tail_app758721009);
}};
$e2099921000.stack[R.EXN_STACKHEIGHT++] = $ss2100321004;
}
if(R.isPyretException($e2099921000)) {
$e2099921000.pyretStack.push(L[753]);
}
throw $e2099921000;
}
var $ret2100521006 = $Hcont_tail_app1111921010($z2100121002);
++R.GAS;
return $ret2100521006;
} else {
var cont_tail_arg758421013 = R.throwNonBooleanOp(L[3505],("second"),("and"),and_DASH_oper_DASH_95020978);
if(--R.GAS > 0) {
$z2101121012 = R.isFunction(if_helper757720979)?if_helper757720979.app(cont_tail_arg758421013):R.ffi.throwNonFunApp(L[3505],if_helper757720979,[cont_tail_arg758421013]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper757720979)?if_helper757720979.app(cont_tail_arg758421013):R.ffi.throwNonFunApp(L[3505],if_helper757720979,[cont_tail_arg758421013]);
},
"from":L[3505]});
}
++R.GAS;
return $z2101121012;
}
};
var $Hcont_tail_app1111921010 = function(cont_tail_app758721009) {
return cont_tail_app758721009;
};
var $Hcont_tail_app1112120992 = function(cont_tail_app758220991) {
return cont_tail_app758220991;
};
var $Hand_DASH_oper_DASH_111184781 = function(and_DASH_oper_DASH_9464779,args20674780,lists974,self20644778) {
var if_helper756021028 = R.makeFunction(function(if_helper_arg756121060) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[756],1,arguments);
}
var ann_DASH_check_DASH_temp755821061 = if_helper_arg756121060;
return ann_DASH_check_DASH_temp755821061;
});
var anf_if756421059 = R.isBoolean(and_DASH_oper_DASH_9464779);
if(R.isPyretTrue(anf_if756421059)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9464779)) {
var anf_fun756621025 = G(lists974,"all",L[3507]);
var anf_arg756921026 = R.makeFunction(function(recv_DASH_94821030) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3506],1,arguments);
}
var anf_fun756821041 = G(recv_DASH_94821030,"visit",L[3506]);
var $z2103321034 = D;
var $f2103921040 = function(_) {
return R.isFunction(anf_fun756821041)?anf_fun756821041.app(self20644778):R.ffi.throwNonFunApp(L[3506],anf_fun756821041,[self20644778]);
};
try {
if(--R.GAS > 0) {
$z2103321034 = $f2103921040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2103921040,
"from":L[3506]});
}
} catch($e2103121032) {
if(R.isCont($e2103121032)) {
var $ss2103521036 = {"from":L[3506],
"go":function(ann_DASH_check_DASH_temp756721042) {
return $Hann_DASH_check_DASH_temp1111421043(ann_DASH_check_DASH_temp756721042);
}};
$e2103121032.stack[R.EXN_STACKHEIGHT++] = $ss2103521036;
}
if(R.isPyretException($e2103121032)) {
$e2103121032.pyretStack.push(L[3506]);
}
throw $e2103121032;
}
var $ret2103721038 = $Hann_DASH_check_DASH_temp1111421043($z2103321034);
++R.GAS;
return $ret2103721038;
});
var $z2101721018 = D;
var $f2102321024 = function(_) {
return R.isFunction(anf_fun756621025)?anf_fun756621025.app(anf_arg756921026,args20674780):R.ffi.throwNonFunApp(L[756],anf_fun756621025,[anf_arg756921026,args20674780]);
};
try {
if(--R.GAS > 0) {
$z2101721018 = $f2102321024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2102321024,
"from":L[756]});
}
} catch($e2101521016) {
if(R.isCont($e2101521016)) {
var $ss2101921020 = {"from":L[756],
"go":function(and_DASH_oper_DASH_94721027) {
return $Hand_DASH_oper_DASH_1111621029(and_DASH_oper_DASH_94721027,if_helper756021028);
}};
$e2101521016.stack[R.EXN_STACKHEIGHT++] = $ss2101921020;
}
if(R.isPyretException($e2101521016)) {
$e2101521016.pyretStack.push(L[756]);
}
throw $e2101521016;
}
var $ret2102121022 = $Hand_DASH_oper_DASH_1111621029($z2101721018,if_helper756021028);
++R.GAS;
return $ret2102121022;
} else {
var $z2104621047 = D;
var $f2105221053 = function(_) {
return R.isFunction(if_helper756021028)?if_helper756021028.app((false)):R.ffi.throwNonFunApp(L[756],if_helper756021028,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2104621047 = $f2105221053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2105221053,
"from":L[756]});
}
} catch($e2104421045) {
if(R.isCont($e2104421045)) {
var $ss2104821049 = {"from":L[756],
"go":function(cont_tail_app756521054) {
return $Hcont_tail_app1111721055(cont_tail_app756521054);
}};
$e2104421045.stack[R.EXN_STACKHEIGHT++] = $ss2104821049;
}
if(R.isPyretException($e2104421045)) {
$e2104421045.pyretStack.push(L[756]);
}
throw $e2104421045;
}
var $ret2105021051 = $Hcont_tail_app1111721055($z2104621047);
++R.GAS;
return $ret2105021051;
}
} else {
var cont_tail_arg756221058 = R.throwNonBooleanOp(L[3508],("first"),("and"),and_DASH_oper_DASH_9464779);
if(--R.GAS > 0) {
$z2105621057 = R.isFunction(if_helper756021028)?if_helper756021028.app(cont_tail_arg756221058):R.ffi.throwNonFunApp(L[3508],if_helper756021028,[cont_tail_arg756221058]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper756021028)?if_helper756021028.app(cont_tail_arg756221058):R.ffi.throwNonFunApp(L[3508],if_helper756021028,[cont_tail_arg756221058]);
},
"from":L[3508]});
}
++R.GAS;
return $z2105621057;
}
};
var $Hand_DASH_oper_DASH_1111621029 = function(and_DASH_oper_DASH_94721027,if_helper756021028) {
var anf_if757221077 = R.isBoolean(and_DASH_oper_DASH_94721027);
if(R.isPyretTrue(anf_if757221077)) {
var $z2106421065 = D;
var $f2107021071 = function(_) {
return R.isFunction(if_helper756021028)?if_helper756021028.app(and_DASH_oper_DASH_94721027):R.ffi.throwNonFunApp(L[756],if_helper756021028,[and_DASH_oper_DASH_94721027]);
};
try {
if(--R.GAS > 0) {
$z2106421065 = $f2107021071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2107021071,
"from":L[756]});
}
} catch($e2106221063) {
if(R.isCont($e2106221063)) {
var $ss2106621067 = {"from":L[756],
"go":function(cont_tail_app757321072) {
return $Hcont_tail_app1111521073(cont_tail_app757321072);
}};
$e2106221063.stack[R.EXN_STACKHEIGHT++] = $ss2106621067;
}
if(R.isPyretException($e2106221063)) {
$e2106221063.pyretStack.push(L[756]);
}
throw $e2106221063;
}
var $ret2106821069 = $Hcont_tail_app1111521073($z2106421065);
++R.GAS;
return $ret2106821069;
} else {
var cont_tail_arg757021076 = R.throwNonBooleanOp(L[3509],("second"),("and"),and_DASH_oper_DASH_94721027);
if(--R.GAS > 0) {
$z2107421075 = R.isFunction(if_helper756021028)?if_helper756021028.app(cont_tail_arg757021076):R.ffi.throwNonFunApp(L[3509],if_helper756021028,[cont_tail_arg757021076]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper756021028)?if_helper756021028.app(cont_tail_arg757021076):R.ffi.throwNonFunApp(L[3509],if_helper756021028,[cont_tail_arg757021076]);
},
"from":L[3509]});
}
++R.GAS;
return $z2107421075;
}
};
var $Hcont_tail_app1111521073 = function(cont_tail_app757321072) {
return cont_tail_app757321072;
};
var $Hann_DASH_check_DASH_temp1111421043 = function(ann_DASH_check_DASH_temp756721042) {
return ann_DASH_check_DASH_temp756721042;
};
var $Hcont_tail_app1111721055 = function(cont_tail_app756521054) {
return cont_tail_app756521054;
};
var $Hann_DASH_check_DASH_temp111134798 = function(ann_DASH_check_DASH_temp75524797) {
return ann_DASH_check_DASH_temp75524797;
};
var $Hann_DASH_check_DASH_temp111124813 = function(ann_DASH_check_DASH_temp75544812) {
return ann_DASH_check_DASH_temp75544812;
};
var $Hand_DASH_oper_DASH_111114831 = function(and_DASH_oper_DASH_9424828,ret20604829,self20574830) {
var if_helper754021090 = R.makeFunction(function(if_helper_arg754121108) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[762],1,arguments);
}
var ann_DASH_check_DASH_temp753521109 = if_helper_arg754121108;
return ann_DASH_check_DASH_temp753521109;
});
var anf_if754421107 = R.isBoolean(and_DASH_oper_DASH_9424828);
if(R.isPyretTrue(anf_if754421107)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9424828)) {
var anf_fun754621088 = G(ret20604829,"visit",L[3510]);
var $z2108021081 = D;
var $f2108621087 = function(_) {
return R.isFunction(anf_fun754621088)?anf_fun754621088.app(self20574830):R.ffi.throwNonFunApp(L[762],anf_fun754621088,[self20574830]);
};
try {
if(--R.GAS > 0) {
$z2108021081 = $f2108621087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2108621087,
"from":L[762]});
}
} catch($e2107821079) {
if(R.isCont($e2107821079)) {
var $ss2108221083 = {"from":L[762],
"go":function(and_DASH_oper_DASH_94421089) {
return $Hand_DASH_oper_DASH_1110921091(and_DASH_oper_DASH_94421089,if_helper754021090);
}};
$e2107821079.stack[R.EXN_STACKHEIGHT++] = $ss2108221083;
}
if(R.isPyretException($e2107821079)) {
$e2107821079.pyretStack.push(L[762]);
}
throw $e2107821079;
}
var $ret2108421085 = $Hand_DASH_oper_DASH_1110921091($z2108021081,if_helper754021090);
++R.GAS;
return $ret2108421085;
} else {
var $z2109421095 = D;
var $f2110021101 = function(_) {
return R.isFunction(if_helper754021090)?if_helper754021090.app((false)):R.ffi.throwNonFunApp(L[762],if_helper754021090,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2109421095 = $f2110021101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2110021101,
"from":L[762]});
}
} catch($e2109221093) {
if(R.isCont($e2109221093)) {
var $ss2109621097 = {"from":L[762],
"go":function(cont_tail_app754521102) {
return $Hcont_tail_app1111021103(cont_tail_app754521102);
}};
$e2109221093.stack[R.EXN_STACKHEIGHT++] = $ss2109621097;
}
if(R.isPyretException($e2109221093)) {
$e2109221093.pyretStack.push(L[762]);
}
throw $e2109221093;
}
var $ret2109821099 = $Hcont_tail_app1111021103($z2109421095);
++R.GAS;
return $ret2109821099;
}
} else {
var cont_tail_arg754221106 = R.throwNonBooleanOp(L[3511],("first"),("and"),and_DASH_oper_DASH_9424828);
if(--R.GAS > 0) {
$z2110421105 = R.isFunction(if_helper754021090)?if_helper754021090.app(cont_tail_arg754221106):R.ffi.throwNonFunApp(L[3511],if_helper754021090,[cont_tail_arg754221106]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper754021090)?if_helper754021090.app(cont_tail_arg754221106):R.ffi.throwNonFunApp(L[3511],if_helper754021090,[cont_tail_arg754221106]);
},
"from":L[3511]});
}
++R.GAS;
return $z2110421105;
}
};
var $Hand_DASH_oper_DASH_1110921091 = function(and_DASH_oper_DASH_94421089,if_helper754021090) {
var anf_if754921125 = R.isBoolean(and_DASH_oper_DASH_94421089);
if(R.isPyretTrue(anf_if754921125)) {
var $z2111221113 = D;
var $f2111821119 = function(_) {
return R.isFunction(if_helper754021090)?if_helper754021090.app(and_DASH_oper_DASH_94421089):R.ffi.throwNonFunApp(L[762],if_helper754021090,[and_DASH_oper_DASH_94421089]);
};
try {
if(--R.GAS > 0) {
$z2111221113 = $f2111821119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2111821119,
"from":L[762]});
}
} catch($e2111021111) {
if(R.isCont($e2111021111)) {
var $ss2111421115 = {"from":L[762],
"go":function(cont_tail_app755021120) {
return $Hcont_tail_app1110821121(cont_tail_app755021120);
}};
$e2111021111.stack[R.EXN_STACKHEIGHT++] = $ss2111421115;
}
if(R.isPyretException($e2111021111)) {
$e2111021111.pyretStack.push(L[762]);
}
throw $e2111021111;
}
var $ret2111621117 = $Hcont_tail_app1110821121($z2111221113);
++R.GAS;
return $ret2111621117;
} else {
var cont_tail_arg754721124 = R.throwNonBooleanOp(L[3512],("second"),("and"),and_DASH_oper_DASH_94421089);
if(--R.GAS > 0) {
$z2112221123 = R.isFunction(if_helper754021090)?if_helper754021090.app(cont_tail_arg754721124):R.ffi.throwNonFunApp(L[3512],if_helper754021090,[cont_tail_arg754721124]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper754021090)?if_helper754021090.app(cont_tail_arg754721124):R.ffi.throwNonFunApp(L[3512],if_helper754021090,[cont_tail_arg754721124]);
},
"from":L[3512]});
}
++R.GAS;
return $z2112221123;
}
};
var $Hcont_tail_app1110821121 = function(cont_tail_app755021120) {
return cont_tail_app755021120;
};
var $Hcont_tail_app1111021103 = function(cont_tail_app754521102) {
return cont_tail_app754521102;
};
var $Hann_DASH_check_DASH_temp111074845 = function(ann_DASH_check_DASH_temp75374844) {
return ann_DASH_check_DASH_temp75374844;
};
var $Hand_DASH_oper_DASH_111064863 = function(and_DASH_oper_DASH_9394860,ret20554861,self20524862) {
var if_helper752321138 = R.makeFunction(function(if_helper_arg752421156) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[766],1,arguments);
}
var ann_DASH_check_DASH_temp751821157 = if_helper_arg752421156;
return ann_DASH_check_DASH_temp751821157;
});
var anf_if752721155 = R.isBoolean(and_DASH_oper_DASH_9394860);
if(R.isPyretTrue(anf_if752721155)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9394860)) {
var anf_fun752921136 = G(ret20554861,"visit",L[3513]);
var $z2112821129 = D;
var $f2113421135 = function(_) {
return R.isFunction(anf_fun752921136)?anf_fun752921136.app(self20524862):R.ffi.throwNonFunApp(L[766],anf_fun752921136,[self20524862]);
};
try {
if(--R.GAS > 0) {
$z2112821129 = $f2113421135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2113421135,
"from":L[766]});
}
} catch($e2112621127) {
if(R.isCont($e2112621127)) {
var $ss2113021131 = {"from":L[766],
"go":function(and_DASH_oper_DASH_94121137) {
return $Hand_DASH_oper_DASH_1110421139(and_DASH_oper_DASH_94121137,if_helper752321138);
}};
$e2112621127.stack[R.EXN_STACKHEIGHT++] = $ss2113021131;
}
if(R.isPyretException($e2112621127)) {
$e2112621127.pyretStack.push(L[766]);
}
throw $e2112621127;
}
var $ret2113221133 = $Hand_DASH_oper_DASH_1110421139($z2112821129,if_helper752321138);
++R.GAS;
return $ret2113221133;
} else {
var $z2114221143 = D;
var $f2114821149 = function(_) {
return R.isFunction(if_helper752321138)?if_helper752321138.app((false)):R.ffi.throwNonFunApp(L[766],if_helper752321138,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2114221143 = $f2114821149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2114821149,
"from":L[766]});
}
} catch($e2114021141) {
if(R.isCont($e2114021141)) {
var $ss2114421145 = {"from":L[766],
"go":function(cont_tail_app752821150) {
return $Hcont_tail_app1110521151(cont_tail_app752821150);
}};
$e2114021141.stack[R.EXN_STACKHEIGHT++] = $ss2114421145;
}
if(R.isPyretException($e2114021141)) {
$e2114021141.pyretStack.push(L[766]);
}
throw $e2114021141;
}
var $ret2114621147 = $Hcont_tail_app1110521151($z2114221143);
++R.GAS;
return $ret2114621147;
}
} else {
var cont_tail_arg752521154 = R.throwNonBooleanOp(L[3514],("first"),("and"),and_DASH_oper_DASH_9394860);
if(--R.GAS > 0) {
$z2115221153 = R.isFunction(if_helper752321138)?if_helper752321138.app(cont_tail_arg752521154):R.ffi.throwNonFunApp(L[3514],if_helper752321138,[cont_tail_arg752521154]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper752321138)?if_helper752321138.app(cont_tail_arg752521154):R.ffi.throwNonFunApp(L[3514],if_helper752321138,[cont_tail_arg752521154]);
},
"from":L[3514]});
}
++R.GAS;
return $z2115221153;
}
};
var $Hand_DASH_oper_DASH_1110421139 = function(and_DASH_oper_DASH_94121137,if_helper752321138) {
var anf_if753221173 = R.isBoolean(and_DASH_oper_DASH_94121137);
if(R.isPyretTrue(anf_if753221173)) {
var $z2116021161 = D;
var $f2116621167 = function(_) {
return R.isFunction(if_helper752321138)?if_helper752321138.app(and_DASH_oper_DASH_94121137):R.ffi.throwNonFunApp(L[766],if_helper752321138,[and_DASH_oper_DASH_94121137]);
};
try {
if(--R.GAS > 0) {
$z2116021161 = $f2116621167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2116621167,
"from":L[766]});
}
} catch($e2115821159) {
if(R.isCont($e2115821159)) {
var $ss2116221163 = {"from":L[766],
"go":function(cont_tail_app753321168) {
return $Hcont_tail_app1110321169(cont_tail_app753321168);
}};
$e2115821159.stack[R.EXN_STACKHEIGHT++] = $ss2116221163;
}
if(R.isPyretException($e2115821159)) {
$e2115821159.pyretStack.push(L[766]);
}
throw $e2115821159;
}
var $ret2116421165 = $Hcont_tail_app1110321169($z2116021161);
++R.GAS;
return $ret2116421165;
} else {
var cont_tail_arg753021172 = R.throwNonBooleanOp(L[3515],("second"),("and"),and_DASH_oper_DASH_94121137);
if(--R.GAS > 0) {
$z2117021171 = R.isFunction(if_helper752321138)?if_helper752321138.app(cont_tail_arg753021172):R.ffi.throwNonFunApp(L[3515],if_helper752321138,[cont_tail_arg753021172]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper752321138)?if_helper752321138.app(cont_tail_arg753021172):R.ffi.throwNonFunApp(L[3515],if_helper752321138,[cont_tail_arg753021172]);
},
"from":L[3515]});
}
++R.GAS;
return $z2117021171;
}
};
var $Hcont_tail_app1110321169 = function(cont_tail_app753321168) {
return cont_tail_app753321168;
};
var $Hcont_tail_app1110521151 = function(cont_tail_app752821150) {
return cont_tail_app752821150;
};
var $Hann_DASH_check_DASH_temp111024877 = function(ann_DASH_check_DASH_temp75204876) {
return ann_DASH_check_DASH_temp75204876;
};
var $Hann_DASH_check_DASH_temp111014901 = function(ann_DASH_check_DASH_temp75094900) {
return ann_DASH_check_DASH_temp75094900;
};
var $Hann_DASH_check_DASH_temp111004918 = function(ann_DASH_check_DASH_temp75064917) {
return ann_DASH_check_DASH_temp75064917;
};
var $Hand_DASH_oper_DASH_110994938 = function(and_DASH_oper_DASH_9364935,constructor20384936,self20344937) {
var if_helper749421186 = R.makeFunction(function(if_helper_arg749521204) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[783],1,arguments);
}
var ann_DASH_check_DASH_temp748921205 = if_helper_arg749521204;
return ann_DASH_check_DASH_temp748921205;
});
var anf_if749821203 = R.isBoolean(and_DASH_oper_DASH_9364935);
if(R.isPyretTrue(anf_if749821203)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9364935)) {
var anf_fun750021184 = G(constructor20384936,"visit",L[3516]);
var $z2117621177 = D;
var $f2118221183 = function(_) {
return R.isFunction(anf_fun750021184)?anf_fun750021184.app(self20344937):R.ffi.throwNonFunApp(L[783],anf_fun750021184,[self20344937]);
};
try {
if(--R.GAS > 0) {
$z2117621177 = $f2118221183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2118221183,
"from":L[783]});
}
} catch($e2117421175) {
if(R.isCont($e2117421175)) {
var $ss2117821179 = {"from":L[783],
"go":function(and_DASH_oper_DASH_93821185) {
return $Hand_DASH_oper_DASH_1109721187(and_DASH_oper_DASH_93821185,if_helper749421186);
}};
$e2117421175.stack[R.EXN_STACKHEIGHT++] = $ss2117821179;
}
if(R.isPyretException($e2117421175)) {
$e2117421175.pyretStack.push(L[783]);
}
throw $e2117421175;
}
var $ret2118021181 = $Hand_DASH_oper_DASH_1109721187($z2117621177,if_helper749421186);
++R.GAS;
return $ret2118021181;
} else {
var $z2119021191 = D;
var $f2119621197 = function(_) {
return R.isFunction(if_helper749421186)?if_helper749421186.app((false)):R.ffi.throwNonFunApp(L[783],if_helper749421186,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2119021191 = $f2119621197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2119621197,
"from":L[783]});
}
} catch($e2118821189) {
if(R.isCont($e2118821189)) {
var $ss2119221193 = {"from":L[783],
"go":function(cont_tail_app749921198) {
return $Hcont_tail_app1109821199(cont_tail_app749921198);
}};
$e2118821189.stack[R.EXN_STACKHEIGHT++] = $ss2119221193;
}
if(R.isPyretException($e2118821189)) {
$e2118821189.pyretStack.push(L[783]);
}
throw $e2118821189;
}
var $ret2119421195 = $Hcont_tail_app1109821199($z2119021191);
++R.GAS;
return $ret2119421195;
}
} else {
var cont_tail_arg749621202 = R.throwNonBooleanOp(L[3517],("first"),("and"),and_DASH_oper_DASH_9364935);
if(--R.GAS > 0) {
$z2120021201 = R.isFunction(if_helper749421186)?if_helper749421186.app(cont_tail_arg749621202):R.ffi.throwNonFunApp(L[3517],if_helper749421186,[cont_tail_arg749621202]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper749421186)?if_helper749421186.app(cont_tail_arg749621202):R.ffi.throwNonFunApp(L[3517],if_helper749421186,[cont_tail_arg749621202]);
},
"from":L[3517]});
}
++R.GAS;
return $z2120021201;
}
};
var $Hand_DASH_oper_DASH_1109721187 = function(and_DASH_oper_DASH_93821185,if_helper749421186) {
var anf_if750321221 = R.isBoolean(and_DASH_oper_DASH_93821185);
if(R.isPyretTrue(anf_if750321221)) {
var $z2120821209 = D;
var $f2121421215 = function(_) {
return R.isFunction(if_helper749421186)?if_helper749421186.app(and_DASH_oper_DASH_93821185):R.ffi.throwNonFunApp(L[783],if_helper749421186,[and_DASH_oper_DASH_93821185]);
};
try {
if(--R.GAS > 0) {
$z2120821209 = $f2121421215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2121421215,
"from":L[783]});
}
} catch($e2120621207) {
if(R.isCont($e2120621207)) {
var $ss2121021211 = {"from":L[783],
"go":function(cont_tail_app750421216) {
return $Hcont_tail_app1109621217(cont_tail_app750421216);
}};
$e2120621207.stack[R.EXN_STACKHEIGHT++] = $ss2121021211;
}
if(R.isPyretException($e2120621207)) {
$e2120621207.pyretStack.push(L[783]);
}
throw $e2120621207;
}
var $ret2121221213 = $Hcont_tail_app1109621217($z2120821209);
++R.GAS;
return $ret2121221213;
} else {
var cont_tail_arg750121220 = R.throwNonBooleanOp(L[3518],("second"),("and"),and_DASH_oper_DASH_93821185);
if(--R.GAS > 0) {
$z2121821219 = R.isFunction(if_helper749421186)?if_helper749421186.app(cont_tail_arg750121220):R.ffi.throwNonFunApp(L[3518],if_helper749421186,[cont_tail_arg750121220]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper749421186)?if_helper749421186.app(cont_tail_arg750121220):R.ffi.throwNonFunApp(L[3518],if_helper749421186,[cont_tail_arg750121220]);
},
"from":L[3518]});
}
++R.GAS;
return $z2121821219;
}
};
var $Hcont_tail_app1109621217 = function(cont_tail_app750421216) {
return cont_tail_app750421216;
};
var $Hcont_tail_app1109821199 = function(cont_tail_app749921198) {
return cont_tail_app749921198;
};
var $Hann_DASH_check_DASH_temp110954952 = function(ann_DASH_check_DASH_temp74914951) {
return ann_DASH_check_DASH_temp74914951;
};
var $Hann_DASH_check_DASH_temp110944969 = function(ann_DASH_check_DASH_temp74834968) {
return ann_DASH_check_DASH_temp74834968;
};
var $Hann_DASH_check_DASH_temp110934984 = function(ann_DASH_check_DASH_temp74854983) {
return ann_DASH_check_DASH_temp74854983;
};
var $Hand_DASH_oper_DASH_110925003 = function(and_DASH_oper_DASH_9315000,lists974,self20245001,with_DASH_members20295002) {
var if_helper746821235 = R.makeFunction(function(if_helper_arg746921267) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[797],1,arguments);
}
var ann_DASH_check_DASH_temp746321268 = if_helper_arg746921267;
return ann_DASH_check_DASH_temp746321268;
});
var anf_if747221266 = R.isBoolean(and_DASH_oper_DASH_9315000);
if(R.isPyretTrue(anf_if747221266)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9315000)) {
var anf_fun747421232 = G(lists974,"all",L[3520]);
var anf_arg747721233 = R.makeFunction(function(recv_DASH_93421237) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3519],1,arguments);
}
var anf_fun747621248 = G(recv_DASH_93421237,"visit",L[3519]);
var $z2124021241 = D;
var $f2124621247 = function(_) {
return R.isFunction(anf_fun747621248)?anf_fun747621248.app(self20245001):R.ffi.throwNonFunApp(L[3519],anf_fun747621248,[self20245001]);
};
try {
if(--R.GAS > 0) {
$z2124021241 = $f2124621247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2124621247,
"from":L[3519]});
}
} catch($e2123821239) {
if(R.isCont($e2123821239)) {
var $ss2124221243 = {"from":L[3519],
"go":function(ann_DASH_check_DASH_temp747521249) {
return $Hann_DASH_check_DASH_temp1108821250(ann_DASH_check_DASH_temp747521249);
}};
$e2123821239.stack[R.EXN_STACKHEIGHT++] = $ss2124221243;
}
if(R.isPyretException($e2123821239)) {
$e2123821239.pyretStack.push(L[3519]);
}
throw $e2123821239;
}
var $ret2124421245 = $Hann_DASH_check_DASH_temp1108821250($z2124021241);
++R.GAS;
return $ret2124421245;
});
var $z2122421225 = D;
var $f2123021231 = function(_) {
return R.isFunction(anf_fun747421232)?anf_fun747421232.app(anf_arg747721233,with_DASH_members20295002):R.ffi.throwNonFunApp(L[797],anf_fun747421232,[anf_arg747721233,with_DASH_members20295002]);
};
try {
if(--R.GAS > 0) {
$z2122421225 = $f2123021231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2123021231,
"from":L[797]});
}
} catch($e2122221223) {
if(R.isCont($e2122221223)) {
var $ss2122621227 = {"from":L[797],
"go":function(and_DASH_oper_DASH_93321234) {
return $Hand_DASH_oper_DASH_1109021236(and_DASH_oper_DASH_93321234,if_helper746821235);
}};
$e2122221223.stack[R.EXN_STACKHEIGHT++] = $ss2122621227;
}
if(R.isPyretException($e2122221223)) {
$e2122221223.pyretStack.push(L[797]);
}
throw $e2122221223;
}
var $ret2122821229 = $Hand_DASH_oper_DASH_1109021236($z2122421225,if_helper746821235);
++R.GAS;
return $ret2122821229;
} else {
var $z2125321254 = D;
var $f2125921260 = function(_) {
return R.isFunction(if_helper746821235)?if_helper746821235.app((false)):R.ffi.throwNonFunApp(L[797],if_helper746821235,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2125321254 = $f2125921260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2125921260,
"from":L[797]});
}
} catch($e2125121252) {
if(R.isCont($e2125121252)) {
var $ss2125521256 = {"from":L[797],
"go":function(cont_tail_app747321261) {
return $Hcont_tail_app1109121262(cont_tail_app747321261);
}};
$e2125121252.stack[R.EXN_STACKHEIGHT++] = $ss2125521256;
}
if(R.isPyretException($e2125121252)) {
$e2125121252.pyretStack.push(L[797]);
}
throw $e2125121252;
}
var $ret2125721258 = $Hcont_tail_app1109121262($z2125321254);
++R.GAS;
return $ret2125721258;
}
} else {
var cont_tail_arg747021265 = R.throwNonBooleanOp(L[3521],("first"),("and"),and_DASH_oper_DASH_9315000);
if(--R.GAS > 0) {
$z2126321264 = R.isFunction(if_helper746821235)?if_helper746821235.app(cont_tail_arg747021265):R.ffi.throwNonFunApp(L[3521],if_helper746821235,[cont_tail_arg747021265]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper746821235)?if_helper746821235.app(cont_tail_arg747021265):R.ffi.throwNonFunApp(L[3521],if_helper746821235,[cont_tail_arg747021265]);
},
"from":L[3521]});
}
++R.GAS;
return $z2126321264;
}
};
var $Hand_DASH_oper_DASH_1109021236 = function(and_DASH_oper_DASH_93321234,if_helper746821235) {
var anf_if748021284 = R.isBoolean(and_DASH_oper_DASH_93321234);
if(R.isPyretTrue(anf_if748021284)) {
var $z2127121272 = D;
var $f2127721278 = function(_) {
return R.isFunction(if_helper746821235)?if_helper746821235.app(and_DASH_oper_DASH_93321234):R.ffi.throwNonFunApp(L[797],if_helper746821235,[and_DASH_oper_DASH_93321234]);
};
try {
if(--R.GAS > 0) {
$z2127121272 = $f2127721278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2127721278,
"from":L[797]});
}
} catch($e2126921270) {
if(R.isCont($e2126921270)) {
var $ss2127321274 = {"from":L[797],
"go":function(cont_tail_app748121279) {
return $Hcont_tail_app1108921280(cont_tail_app748121279);
}};
$e2126921270.stack[R.EXN_STACKHEIGHT++] = $ss2127321274;
}
if(R.isPyretException($e2126921270)) {
$e2126921270.pyretStack.push(L[797]);
}
throw $e2126921270;
}
var $ret2127521276 = $Hcont_tail_app1108921280($z2127121272);
++R.GAS;
return $ret2127521276;
} else {
var cont_tail_arg747821283 = R.throwNonBooleanOp(L[3522],("second"),("and"),and_DASH_oper_DASH_93321234);
if(--R.GAS > 0) {
$z2128121282 = R.isFunction(if_helper746821235)?if_helper746821235.app(cont_tail_arg747821283):R.ffi.throwNonFunApp(L[3522],if_helper746821235,[cont_tail_arg747821283]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper746821235)?if_helper746821235.app(cont_tail_arg747821283):R.ffi.throwNonFunApp(L[3522],if_helper746821235,[cont_tail_arg747821283]);
},
"from":L[3522]});
}
++R.GAS;
return $z2128121282;
}
};
var $Hcont_tail_app1108921280 = function(cont_tail_app748121279) {
return cont_tail_app748121279;
};
var $Hann_DASH_check_DASH_temp1108821250 = function(ann_DASH_check_DASH_temp747521249) {
return ann_DASH_check_DASH_temp747521249;
};
var $Hcont_tail_app1109121262 = function(cont_tail_app747321261) {
return cont_tail_app747321261;
};
var $Hann_DASH_check_DASH_temp110875017 = function(ann_DASH_check_DASH_temp74655016) {
return ann_DASH_check_DASH_temp74655016;
};
var $Hann_DASH_check_DASH_temp110865034 = function(ann_DASH_check_DASH_temp74605033) {
return ann_DASH_check_DASH_temp74605033;
};
var $Hand_DASH_oper_DASH_110855052 = function(and_DASH_oper_DASH_9295050,self20165049,value20195051) {
var if_helper744821297 = R.makeFunction(function(if_helper_arg744921315) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[811],1,arguments);
}
var ann_DASH_check_DASH_temp744621316 = if_helper_arg744921315;
return ann_DASH_check_DASH_temp744621316;
});
var anf_if745221314 = R.isBoolean(and_DASH_oper_DASH_9295050);
if(R.isPyretTrue(anf_if745221314)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9295050)) {
var anf_fun745421295 = G(value20195051,"visit",L[3523]);
var $z2128721288 = D;
var $f2129321294 = function(_) {
return R.isFunction(anf_fun745421295)?anf_fun745421295.app(self20165049):R.ffi.throwNonFunApp(L[811],anf_fun745421295,[self20165049]);
};
try {
if(--R.GAS > 0) {
$z2128721288 = $f2129321294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2129321294,
"from":L[811]});
}
} catch($e2128521286) {
if(R.isCont($e2128521286)) {
var $ss2128921290 = {"from":L[811],
"go":function(and_DASH_oper_DASH_93021296) {
return $Hand_DASH_oper_DASH_1108321298(and_DASH_oper_DASH_93021296,if_helper744821297);
}};
$e2128521286.stack[R.EXN_STACKHEIGHT++] = $ss2128921290;
}
if(R.isPyretException($e2128521286)) {
$e2128521286.pyretStack.push(L[811]);
}
throw $e2128521286;
}
var $ret2129121292 = $Hand_DASH_oper_DASH_1108321298($z2128721288,if_helper744821297);
++R.GAS;
return $ret2129121292;
} else {
var $z2130121302 = D;
var $f2130721308 = function(_) {
return R.isFunction(if_helper744821297)?if_helper744821297.app((false)):R.ffi.throwNonFunApp(L[811],if_helper744821297,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2130121302 = $f2130721308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2130721308,
"from":L[811]});
}
} catch($e2129921300) {
if(R.isCont($e2129921300)) {
var $ss2130321304 = {"from":L[811],
"go":function(cont_tail_app745321309) {
return $Hcont_tail_app1108421310(cont_tail_app745321309);
}};
$e2129921300.stack[R.EXN_STACKHEIGHT++] = $ss2130321304;
}
if(R.isPyretException($e2129921300)) {
$e2129921300.pyretStack.push(L[811]);
}
throw $e2129921300;
}
var $ret2130521306 = $Hcont_tail_app1108421310($z2130121302);
++R.GAS;
return $ret2130521306;
}
} else {
var cont_tail_arg745021313 = R.throwNonBooleanOp(L[3524],("first"),("and"),and_DASH_oper_DASH_9295050);
if(--R.GAS > 0) {
$z2131121312 = R.isFunction(if_helper744821297)?if_helper744821297.app(cont_tail_arg745021313):R.ffi.throwNonFunApp(L[3524],if_helper744821297,[cont_tail_arg745021313]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper744821297)?if_helper744821297.app(cont_tail_arg745021313):R.ffi.throwNonFunApp(L[3524],if_helper744821297,[cont_tail_arg745021313]);
},
"from":L[3524]});
}
++R.GAS;
return $z2131121312;
}
};
var $Hand_DASH_oper_DASH_1108321298 = function(and_DASH_oper_DASH_93021296,if_helper744821297) {
var anf_if745721332 = R.isBoolean(and_DASH_oper_DASH_93021296);
if(R.isPyretTrue(anf_if745721332)) {
var $z2131921320 = D;
var $f2132521326 = function(_) {
return R.isFunction(if_helper744821297)?if_helper744821297.app(and_DASH_oper_DASH_93021296):R.ffi.throwNonFunApp(L[811],if_helper744821297,[and_DASH_oper_DASH_93021296]);
};
try {
if(--R.GAS > 0) {
$z2131921320 = $f2132521326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2132521326,
"from":L[811]});
}
} catch($e2131721318) {
if(R.isCont($e2131721318)) {
var $ss2132121322 = {"from":L[811],
"go":function(cont_tail_app745821327) {
return $Hcont_tail_app1108221328(cont_tail_app745821327);
}};
$e2131721318.stack[R.EXN_STACKHEIGHT++] = $ss2132121322;
}
if(R.isPyretException($e2131721318)) {
$e2131721318.pyretStack.push(L[811]);
}
throw $e2131721318;
}
var $ret2132321324 = $Hcont_tail_app1108221328($z2131921320);
++R.GAS;
return $ret2132321324;
} else {
var cont_tail_arg745521331 = R.throwNonBooleanOp(L[3525],("second"),("and"),and_DASH_oper_DASH_93021296);
if(--R.GAS > 0) {
$z2132921330 = R.isFunction(if_helper744821297)?if_helper744821297.app(cont_tail_arg745521331):R.ffi.throwNonFunApp(L[3525],if_helper744821297,[cont_tail_arg745521331]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper744821297)?if_helper744821297.app(cont_tail_arg745521331):R.ffi.throwNonFunApp(L[3525],if_helper744821297,[cont_tail_arg745521331]);
},
"from":L[3525]});
}
++R.GAS;
return $z2132921330;
}
};
var $Hcont_tail_app1108221328 = function(cont_tail_app745821327) {
return cont_tail_app745821327;
};
var $Hcont_tail_app1108421310 = function(cont_tail_app745321309) {
return cont_tail_app745321309;
};
var $Hand_DASH_oper_DASH_110815072 = function(and_DASH_oper_DASH_9235067,_check20155068,ann20125069,args20115070,body20145071,lists974,self20085066) {
var if_helper741621346 = R.makeFunction(function(if_helper_arg741721378) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[817],1,arguments);
}
var ann_DASH_check_DASH_temp741421379 = if_helper_arg741721378;
return ann_DASH_check_DASH_temp741421379;
});
var anf_if742021377 = R.isBoolean(and_DASH_oper_DASH_9235067);
if(R.isPyretTrue(anf_if742021377)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9235067)) {
var anf_fun742221343 = G(lists974,"all",L[3527]);
var anf_arg742521344 = R.makeFunction(function(recv_DASH_92521348) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3526],1,arguments);
}
var anf_fun742421359 = G(recv_DASH_92521348,"visit",L[3526]);
var $z2135121352 = D;
var $f2135721358 = function(_) {
return R.isFunction(anf_fun742421359)?anf_fun742421359.app(self20085066):R.ffi.throwNonFunApp(L[3526],anf_fun742421359,[self20085066]);
};
try {
if(--R.GAS > 0) {
$z2135121352 = $f2135721358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2135721358,
"from":L[3526]});
}
} catch($e2134921350) {
if(R.isCont($e2134921350)) {
var $ss2135321354 = {"from":L[3526],
"go":function(ann_DASH_check_DASH_temp742321360) {
return $Hann_DASH_check_DASH_temp1107121361(ann_DASH_check_DASH_temp742321360);
}};
$e2134921350.stack[R.EXN_STACKHEIGHT++] = $ss2135321354;
}
if(R.isPyretException($e2134921350)) {
$e2134921350.pyretStack.push(L[3526]);
}
throw $e2134921350;
}
var $ret2135521356 = $Hann_DASH_check_DASH_temp1107121361($z2135121352);
++R.GAS;
return $ret2135521356;
});
var $z2133521336 = D;
var $f2134121342 = function(_) {
return R.isFunction(anf_fun742221343)?anf_fun742221343.app(anf_arg742521344,args20115070):R.ffi.throwNonFunApp(L[817],anf_fun742221343,[anf_arg742521344,args20115070]);
};
try {
if(--R.GAS > 0) {
$z2133521336 = $f2134121342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2134121342,
"from":L[817]});
}
} catch($e2133321334) {
if(R.isCont($e2133321334)) {
var $ss2133721338 = {"from":L[817],
"go":function(and_DASH_oper_DASH_92421345) {
return $Hand_DASH_oper_DASH_1107921347(and_DASH_oper_DASH_92421345,_check20155068,ann20125069,body20145071,if_helper741621346,self20085066);
}};
$e2133321334.stack[R.EXN_STACKHEIGHT++] = $ss2133721338;
}
if(R.isPyretException($e2133321334)) {
$e2133321334.pyretStack.push(L[817]);
}
throw $e2133321334;
}
var $ret2133921340 = $Hand_DASH_oper_DASH_1107921347($z2133521336,_check20155068,ann20125069,body20145071,if_helper741621346,self20085066);
++R.GAS;
return $ret2133921340;
} else {
var $z2136421365 = D;
var $f2137021371 = function(_) {
return R.isFunction(if_helper741621346)?if_helper741621346.app((false)):R.ffi.throwNonFunApp(L[817],if_helper741621346,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2136421365 = $f2137021371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2137021371,
"from":L[817]});
}
} catch($e2136221363) {
if(R.isCont($e2136221363)) {
var $ss2136621367 = {"from":L[817],
"go":function(cont_tail_app742121372) {
return $Hcont_tail_app1108021373(cont_tail_app742121372);
}};
$e2136221363.stack[R.EXN_STACKHEIGHT++] = $ss2136621367;
}
if(R.isPyretException($e2136221363)) {
$e2136221363.pyretStack.push(L[817]);
}
throw $e2136221363;
}
var $ret2136821369 = $Hcont_tail_app1108021373($z2136421365);
++R.GAS;
return $ret2136821369;
}
} else {
var cont_tail_arg741821376 = R.throwNonBooleanOp(L[3528],("first"),("and"),and_DASH_oper_DASH_9235067);
if(--R.GAS > 0) {
$z2137421375 = R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg741821376):R.ffi.throwNonFunApp(L[3528],if_helper741621346,[cont_tail_arg741821376]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg741821376):R.ffi.throwNonFunApp(L[3528],if_helper741621346,[cont_tail_arg741821376]);
},
"from":L[3528]});
}
++R.GAS;
return $z2137421375;
}
};
var $Hand_DASH_oper_DASH_1107921347 = function(and_DASH_oper_DASH_92421345,_check20155068,ann20125069,body20145071,if_helper741621346,self20085066) {
var anf_if742821408 = R.isBoolean(and_DASH_oper_DASH_92421345);
if(R.isPyretTrue(anf_if742821408)) {
if(R.isPyretTrue(and_DASH_oper_DASH_92421345)) {
var anf_fun743021390 = G(ann20125069,"visit",L[3529]);
var $z2138221383 = D;
var $f2138821389 = function(_) {
return R.isFunction(anf_fun743021390)?anf_fun743021390.app(self20085066):R.ffi.throwNonFunApp(L[817],anf_fun743021390,[self20085066]);
};
try {
if(--R.GAS > 0) {
$z2138221383 = $f2138821389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2138821389,
"from":L[817]});
}
} catch($e2138021381) {
if(R.isCont($e2138021381)) {
var $ss2138421385 = {"from":L[817],
"go":function(and_DASH_oper_DASH_92621391) {
return $Hand_DASH_oper_DASH_1107721392(and_DASH_oper_DASH_92621391,_check20155068,body20145071,if_helper741621346,self20085066);
}};
$e2138021381.stack[R.EXN_STACKHEIGHT++] = $ss2138421385;
}
if(R.isPyretException($e2138021381)) {
$e2138021381.pyretStack.push(L[817]);
}
throw $e2138021381;
}
var $ret2138621387 = $Hand_DASH_oper_DASH_1107721392($z2138221383,_check20155068,body20145071,if_helper741621346,self20085066);
++R.GAS;
return $ret2138621387;
} else {
var $z2139521396 = D;
var $f2140121402 = function(_) {
return R.isFunction(if_helper741621346)?if_helper741621346.app((false)):R.ffi.throwNonFunApp(L[817],if_helper741621346,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2139521396 = $f2140121402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2140121402,
"from":L[817]});
}
} catch($e2139321394) {
if(R.isCont($e2139321394)) {
var $ss2139721398 = {"from":L[817],
"go":function(cont_tail_app742921403) {
return $Hcont_tail_app1107821404(cont_tail_app742921403);
}};
$e2139321394.stack[R.EXN_STACKHEIGHT++] = $ss2139721398;
}
if(R.isPyretException($e2139321394)) {
$e2139321394.pyretStack.push(L[817]);
}
throw $e2139321394;
}
var $ret2139921400 = $Hcont_tail_app1107821404($z2139521396);
++R.GAS;
return $ret2139921400;
}
} else {
var cont_tail_arg742621407 = R.throwNonBooleanOp(L[3530],("first"),("and"),and_DASH_oper_DASH_92421345);
if(--R.GAS > 0) {
$z2140521406 = R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg742621407):R.ffi.throwNonFunApp(L[3530],if_helper741621346,[cont_tail_arg742621407]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg742621407):R.ffi.throwNonFunApp(L[3530],if_helper741621346,[cont_tail_arg742621407]);
},
"from":L[3530]});
}
++R.GAS;
return $z2140521406;
}
};
var $Hand_DASH_oper_DASH_1107721392 = function(and_DASH_oper_DASH_92621391,_check20155068,body20145071,if_helper741621346,self20085066) {
var anf_if743321437 = R.isBoolean(and_DASH_oper_DASH_92621391);
if(R.isPyretTrue(anf_if743321437)) {
if(R.isPyretTrue(and_DASH_oper_DASH_92621391)) {
var anf_fun743521419 = G(body20145071,"visit",L[3531]);
var $z2141121412 = D;
var $f2141721418 = function(_) {
return R.isFunction(anf_fun743521419)?anf_fun743521419.app(self20085066):R.ffi.throwNonFunApp(L[817],anf_fun743521419,[self20085066]);
};
try {
if(--R.GAS > 0) {
$z2141121412 = $f2141721418();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2141721418,
"from":L[817]});
}
} catch($e2140921410) {
if(R.isCont($e2140921410)) {
var $ss2141321414 = {"from":L[817],
"go":function(and_DASH_oper_DASH_92721420) {
return $Hand_DASH_oper_DASH_1107521421(and_DASH_oper_DASH_92721420,_check20155068,if_helper741621346,self20085066);
}};
$e2140921410.stack[R.EXN_STACKHEIGHT++] = $ss2141321414;
}
if(R.isPyretException($e2140921410)) {
$e2140921410.pyretStack.push(L[817]);
}
throw $e2140921410;
}
var $ret2141521416 = $Hand_DASH_oper_DASH_1107521421($z2141121412,_check20155068,if_helper741621346,self20085066);
++R.GAS;
return $ret2141521416;
} else {
var $z2142421425 = D;
var $f2143021431 = function(_) {
return R.isFunction(if_helper741621346)?if_helper741621346.app((false)):R.ffi.throwNonFunApp(L[817],if_helper741621346,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2142421425 = $f2143021431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2143021431,
"from":L[817]});
}
} catch($e2142221423) {
if(R.isCont($e2142221423)) {
var $ss2142621427 = {"from":L[817],
"go":function(cont_tail_app743421432) {
return $Hcont_tail_app1107621433(cont_tail_app743421432);
}};
$e2142221423.stack[R.EXN_STACKHEIGHT++] = $ss2142621427;
}
if(R.isPyretException($e2142221423)) {
$e2142221423.pyretStack.push(L[817]);
}
throw $e2142221423;
}
var $ret2142821429 = $Hcont_tail_app1107621433($z2142421425);
++R.GAS;
return $ret2142821429;
}
} else {
var cont_tail_arg743121436 = R.throwNonBooleanOp(L[3532],("first"),("and"),and_DASH_oper_DASH_92621391);
if(--R.GAS > 0) {
$z2143421435 = R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg743121436):R.ffi.throwNonFunApp(L[3532],if_helper741621346,[cont_tail_arg743121436]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg743121436):R.ffi.throwNonFunApp(L[3532],if_helper741621346,[cont_tail_arg743121436]);
},
"from":L[3532]});
}
++R.GAS;
return $z2143421435;
}
};
var $Hand_DASH_oper_DASH_1107521421 = function(and_DASH_oper_DASH_92721420,_check20155068,if_helper741621346,self20085066) {
var anf_if743821466 = R.isBoolean(and_DASH_oper_DASH_92721420);
if(R.isPyretTrue(anf_if743821466)) {
if(R.isPyretTrue(and_DASH_oper_DASH_92721420)) {
var anf_fun744021448 = G(self20085066,"option",L[3533]);
var $z2144021441 = D;
var $f2144621447 = function(_) {
return R.isFunction(anf_fun744021448)?anf_fun744021448.app(_check20155068):R.ffi.throwNonFunApp(L[817],anf_fun744021448,[_check20155068]);
};
try {
if(--R.GAS > 0) {
$z2144021441 = $f2144621447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2144621447,
"from":L[817]});
}
} catch($e2143821439) {
if(R.isCont($e2143821439)) {
var $ss2144221443 = {"from":L[817],
"go":function(and_DASH_oper_DASH_92821449) {
return $Hand_DASH_oper_DASH_1107321450(and_DASH_oper_DASH_92821449,if_helper741621346);
}};
$e2143821439.stack[R.EXN_STACKHEIGHT++] = $ss2144221443;
}
if(R.isPyretException($e2143821439)) {
$e2143821439.pyretStack.push(L[817]);
}
throw $e2143821439;
}
var $ret2144421445 = $Hand_DASH_oper_DASH_1107321450($z2144021441,if_helper741621346);
++R.GAS;
return $ret2144421445;
} else {
var $z2145321454 = D;
var $f2145921460 = function(_) {
return R.isFunction(if_helper741621346)?if_helper741621346.app((false)):R.ffi.throwNonFunApp(L[817],if_helper741621346,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2145321454 = $f2145921460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2145921460,
"from":L[817]});
}
} catch($e2145121452) {
if(R.isCont($e2145121452)) {
var $ss2145521456 = {"from":L[817],
"go":function(cont_tail_app743921461) {
return $Hcont_tail_app1107421462(cont_tail_app743921461);
}};
$e2145121452.stack[R.EXN_STACKHEIGHT++] = $ss2145521456;
}
if(R.isPyretException($e2145121452)) {
$e2145121452.pyretStack.push(L[817]);
}
throw $e2145121452;
}
var $ret2145721458 = $Hcont_tail_app1107421462($z2145321454);
++R.GAS;
return $ret2145721458;
}
} else {
var cont_tail_arg743621465 = R.throwNonBooleanOp(L[3534],("first"),("and"),and_DASH_oper_DASH_92721420);
if(--R.GAS > 0) {
$z2146321464 = R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg743621465):R.ffi.throwNonFunApp(L[3534],if_helper741621346,[cont_tail_arg743621465]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg743621465):R.ffi.throwNonFunApp(L[3534],if_helper741621346,[cont_tail_arg743621465]);
},
"from":L[3534]});
}
++R.GAS;
return $z2146321464;
}
};
var $Hand_DASH_oper_DASH_1107321450 = function(and_DASH_oper_DASH_92821449,if_helper741621346) {
var anf_if744321482 = R.isBoolean(and_DASH_oper_DASH_92821449);
if(R.isPyretTrue(anf_if744321482)) {
var $z2146921470 = D;
var $f2147521476 = function(_) {
return R.isFunction(if_helper741621346)?if_helper741621346.app(and_DASH_oper_DASH_92821449):R.ffi.throwNonFunApp(L[817],if_helper741621346,[and_DASH_oper_DASH_92821449]);
};
try {
if(--R.GAS > 0) {
$z2146921470 = $f2147521476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2147521476,
"from":L[817]});
}
} catch($e2146721468) {
if(R.isCont($e2146721468)) {
var $ss2147121472 = {"from":L[817],
"go":function(cont_tail_app744421477) {
return $Hcont_tail_app1107221478(cont_tail_app744421477);
}};
$e2146721468.stack[R.EXN_STACKHEIGHT++] = $ss2147121472;
}
if(R.isPyretException($e2146721468)) {
$e2146721468.pyretStack.push(L[817]);
}
throw $e2146721468;
}
var $ret2147321474 = $Hcont_tail_app1107221478($z2146921470);
++R.GAS;
return $ret2147321474;
} else {
var cont_tail_arg744121481 = R.throwNonBooleanOp(L[3535],("second"),("and"),and_DASH_oper_DASH_92821449);
if(--R.GAS > 0) {
$z2147921480 = R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg744121481):R.ffi.throwNonFunApp(L[3535],if_helper741621346,[cont_tail_arg744121481]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper741621346)?if_helper741621346.app(cont_tail_arg744121481):R.ffi.throwNonFunApp(L[3535],if_helper741621346,[cont_tail_arg744121481]);
},
"from":L[3535]});
}
++R.GAS;
return $z2147921480;
}
};
var $Hcont_tail_app1107221478 = function(cont_tail_app744421477) {
return cont_tail_app744421477;
};
var $Hcont_tail_app1107421462 = function(cont_tail_app743921461) {
return cont_tail_app743921461;
};
var $Hcont_tail_app1107621433 = function(cont_tail_app743421432) {
return cont_tail_app743421432;
};
var $Hcont_tail_app1107821404 = function(cont_tail_app742921403) {
return cont_tail_app742921403;
};
var $Hann_DASH_check_DASH_temp1107121361 = function(ann_DASH_check_DASH_temp742321360) {
return ann_DASH_check_DASH_temp742321360;
};
var $Hcont_tail_app1108021373 = function(cont_tail_app742121372) {
return cont_tail_app742121372;
};
var $Hand_DASH_oper_DASH_110705091 = function(and_DASH_oper_DASH_9205088,ann20065089,self20035087,value20075090) {
var if_helper739721495 = R.makeFunction(function(if_helper_arg739821513) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[827],1,arguments);
}
var ann_DASH_check_DASH_temp739521514 = if_helper_arg739821513;
return ann_DASH_check_DASH_temp739521514;
});
var anf_if740121512 = R.isBoolean(and_DASH_oper_DASH_9205088);
if(R.isPyretTrue(anf_if740121512)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9205088)) {
var anf_fun740321493 = G(ann20065089,"visit",L[3536]);
var $z2148521486 = D;
var $f2149121492 = function(_) {
return R.isFunction(anf_fun740321493)?anf_fun740321493.app(self20035087):R.ffi.throwNonFunApp(L[827],anf_fun740321493,[self20035087]);
};
try {
if(--R.GAS > 0) {
$z2148521486 = $f2149121492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2149121492,
"from":L[827]});
}
} catch($e2148321484) {
if(R.isCont($e2148321484)) {
var $ss2148721488 = {"from":L[827],
"go":function(and_DASH_oper_DASH_92121494) {
return $Hand_DASH_oper_DASH_1106821496(and_DASH_oper_DASH_92121494,if_helper739721495,self20035087,value20075090);
}};
$e2148321484.stack[R.EXN_STACKHEIGHT++] = $ss2148721488;
}
if(R.isPyretException($e2148321484)) {
$e2148321484.pyretStack.push(L[827]);
}
throw $e2148321484;
}
var $ret2148921490 = $Hand_DASH_oper_DASH_1106821496($z2148521486,if_helper739721495,self20035087,value20075090);
++R.GAS;
return $ret2148921490;
} else {
var $z2149921500 = D;
var $f2150521506 = function(_) {
return R.isFunction(if_helper739721495)?if_helper739721495.app((false)):R.ffi.throwNonFunApp(L[827],if_helper739721495,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2149921500 = $f2150521506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2150521506,
"from":L[827]});
}
} catch($e2149721498) {
if(R.isCont($e2149721498)) {
var $ss2150121502 = {"from":L[827],
"go":function(cont_tail_app740221507) {
return $Hcont_tail_app1106921508(cont_tail_app740221507);
}};
$e2149721498.stack[R.EXN_STACKHEIGHT++] = $ss2150121502;
}
if(R.isPyretException($e2149721498)) {
$e2149721498.pyretStack.push(L[827]);
}
throw $e2149721498;
}
var $ret2150321504 = $Hcont_tail_app1106921508($z2149921500);
++R.GAS;
return $ret2150321504;
}
} else {
var cont_tail_arg739921511 = R.throwNonBooleanOp(L[3537],("first"),("and"),and_DASH_oper_DASH_9205088);
if(--R.GAS > 0) {
$z2150921510 = R.isFunction(if_helper739721495)?if_helper739721495.app(cont_tail_arg739921511):R.ffi.throwNonFunApp(L[3537],if_helper739721495,[cont_tail_arg739921511]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper739721495)?if_helper739721495.app(cont_tail_arg739921511):R.ffi.throwNonFunApp(L[3537],if_helper739721495,[cont_tail_arg739921511]);
},
"from":L[3537]});
}
++R.GAS;
return $z2150921510;
}
};
var $Hand_DASH_oper_DASH_1106821496 = function(and_DASH_oper_DASH_92121494,if_helper739721495,self20035087,value20075090) {
var anf_if740621543 = R.isBoolean(and_DASH_oper_DASH_92121494);
if(R.isPyretTrue(anf_if740621543)) {
if(R.isPyretTrue(and_DASH_oper_DASH_92121494)) {
var anf_fun740821525 = G(value20075090,"visit",L[3538]);
var $z2151721518 = D;
var $f2152321524 = function(_) {
return R.isFunction(anf_fun740821525)?anf_fun740821525.app(self20035087):R.ffi.throwNonFunApp(L[827],anf_fun740821525,[self20035087]);
};
try {
if(--R.GAS > 0) {
$z2151721518 = $f2152321524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2152321524,
"from":L[827]});
}
} catch($e2151521516) {
if(R.isCont($e2151521516)) {
var $ss2151921520 = {"from":L[827],
"go":function(and_DASH_oper_DASH_92221526) {
return $Hand_DASH_oper_DASH_1106621527(and_DASH_oper_DASH_92221526,if_helper739721495);
}};
$e2151521516.stack[R.EXN_STACKHEIGHT++] = $ss2151921520;
}
if(R.isPyretException($e2151521516)) {
$e2151521516.pyretStack.push(L[827]);
}
throw $e2151521516;
}
var $ret2152121522 = $Hand_DASH_oper_DASH_1106621527($z2151721518,if_helper739721495);
++R.GAS;
return $ret2152121522;
} else {
var $z2153021531 = D;
var $f2153621537 = function(_) {
return R.isFunction(if_helper739721495)?if_helper739721495.app((false)):R.ffi.throwNonFunApp(L[827],if_helper739721495,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2153021531 = $f2153621537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2153621537,
"from":L[827]});
}
} catch($e2152821529) {
if(R.isCont($e2152821529)) {
var $ss2153221533 = {"from":L[827],
"go":function(cont_tail_app740721538) {
return $Hcont_tail_app1106721539(cont_tail_app740721538);
}};
$e2152821529.stack[R.EXN_STACKHEIGHT++] = $ss2153221533;
}
if(R.isPyretException($e2152821529)) {
$e2152821529.pyretStack.push(L[827]);
}
throw $e2152821529;
}
var $ret2153421535 = $Hcont_tail_app1106721539($z2153021531);
++R.GAS;
return $ret2153421535;
}
} else {
var cont_tail_arg740421542 = R.throwNonBooleanOp(L[3539],("first"),("and"),and_DASH_oper_DASH_92121494);
if(--R.GAS > 0) {
$z2154021541 = R.isFunction(if_helper739721495)?if_helper739721495.app(cont_tail_arg740421542):R.ffi.throwNonFunApp(L[3539],if_helper739721495,[cont_tail_arg740421542]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper739721495)?if_helper739721495.app(cont_tail_arg740421542):R.ffi.throwNonFunApp(L[3539],if_helper739721495,[cont_tail_arg740421542]);
},
"from":L[3539]});
}
++R.GAS;
return $z2154021541;
}
};
var $Hand_DASH_oper_DASH_1106621527 = function(and_DASH_oper_DASH_92221526,if_helper739721495) {
var anf_if741121559 = R.isBoolean(and_DASH_oper_DASH_92221526);
if(R.isPyretTrue(anf_if741121559)) {
var $z2154621547 = D;
var $f2155221553 = function(_) {
return R.isFunction(if_helper739721495)?if_helper739721495.app(and_DASH_oper_DASH_92221526):R.ffi.throwNonFunApp(L[827],if_helper739721495,[and_DASH_oper_DASH_92221526]);
};
try {
if(--R.GAS > 0) {
$z2154621547 = $f2155221553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2155221553,
"from":L[827]});
}
} catch($e2154421545) {
if(R.isCont($e2154421545)) {
var $ss2154821549 = {"from":L[827],
"go":function(cont_tail_app741221554) {
return $Hcont_tail_app1106521555(cont_tail_app741221554);
}};
$e2154421545.stack[R.EXN_STACKHEIGHT++] = $ss2154821549;
}
if(R.isPyretException($e2154421545)) {
$e2154421545.pyretStack.push(L[827]);
}
throw $e2154421545;
}
var $ret2155021551 = $Hcont_tail_app1106521555($z2154621547);
++R.GAS;
return $ret2155021551;
} else {
var cont_tail_arg740921558 = R.throwNonBooleanOp(L[3540],("second"),("and"),and_DASH_oper_DASH_92221526);
if(--R.GAS > 0) {
$z2155621557 = R.isFunction(if_helper739721495)?if_helper739721495.app(cont_tail_arg740921558):R.ffi.throwNonFunApp(L[3540],if_helper739721495,[cont_tail_arg740921558]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper739721495)?if_helper739721495.app(cont_tail_arg740921558):R.ffi.throwNonFunApp(L[3540],if_helper739721495,[cont_tail_arg740921558]);
},
"from":L[3540]});
}
++R.GAS;
return $z2155621557;
}
};
var $Hcont_tail_app1106521555 = function(cont_tail_app741221554) {
return cont_tail_app741221554;
};
var $Hcont_tail_app1106721539 = function(cont_tail_app740721538) {
return cont_tail_app740721538;
};
var $Hcont_tail_app1106921508 = function(cont_tail_app740221507) {
return cont_tail_app740221507;
};
var $Hand_DASH_oper_DASH_110645109 = function(and_DASH_oper_DASH_9175106,ann20015107,self19985105,value20025108) {
var if_helper737821572 = R.makeFunction(function(if_helper_arg737921590) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[834],1,arguments);
}
var ann_DASH_check_DASH_temp737621591 = if_helper_arg737921590;
return ann_DASH_check_DASH_temp737621591;
});
var anf_if738221589 = R.isBoolean(and_DASH_oper_DASH_9175106);
if(R.isPyretTrue(anf_if738221589)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9175106)) {
var anf_fun738421570 = G(ann20015107,"visit",L[3541]);
var $z2156221563 = D;
var $f2156821569 = function(_) {
return R.isFunction(anf_fun738421570)?anf_fun738421570.app(self19985105):R.ffi.throwNonFunApp(L[834],anf_fun738421570,[self19985105]);
};
try {
if(--R.GAS > 0) {
$z2156221563 = $f2156821569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2156821569,
"from":L[834]});
}
} catch($e2156021561) {
if(R.isCont($e2156021561)) {
var $ss2156421565 = {"from":L[834],
"go":function(and_DASH_oper_DASH_91821571) {
return $Hand_DASH_oper_DASH_1106221573(and_DASH_oper_DASH_91821571,if_helper737821572,self19985105,value20025108);
}};
$e2156021561.stack[R.EXN_STACKHEIGHT++] = $ss2156421565;
}
if(R.isPyretException($e2156021561)) {
$e2156021561.pyretStack.push(L[834]);
}
throw $e2156021561;
}
var $ret2156621567 = $Hand_DASH_oper_DASH_1106221573($z2156221563,if_helper737821572,self19985105,value20025108);
++R.GAS;
return $ret2156621567;
} else {
var $z2157621577 = D;
var $f2158221583 = function(_) {
return R.isFunction(if_helper737821572)?if_helper737821572.app((false)):R.ffi.throwNonFunApp(L[834],if_helper737821572,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2157621577 = $f2158221583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2158221583,
"from":L[834]});
}
} catch($e2157421575) {
if(R.isCont($e2157421575)) {
var $ss2157821579 = {"from":L[834],
"go":function(cont_tail_app738321584) {
return $Hcont_tail_app1106321585(cont_tail_app738321584);
}};
$e2157421575.stack[R.EXN_STACKHEIGHT++] = $ss2157821579;
}
if(R.isPyretException($e2157421575)) {
$e2157421575.pyretStack.push(L[834]);
}
throw $e2157421575;
}
var $ret2158021581 = $Hcont_tail_app1106321585($z2157621577);
++R.GAS;
return $ret2158021581;
}
} else {
var cont_tail_arg738021588 = R.throwNonBooleanOp(L[3542],("first"),("and"),and_DASH_oper_DASH_9175106);
if(--R.GAS > 0) {
$z2158621587 = R.isFunction(if_helper737821572)?if_helper737821572.app(cont_tail_arg738021588):R.ffi.throwNonFunApp(L[3542],if_helper737821572,[cont_tail_arg738021588]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper737821572)?if_helper737821572.app(cont_tail_arg738021588):R.ffi.throwNonFunApp(L[3542],if_helper737821572,[cont_tail_arg738021588]);
},
"from":L[3542]});
}
++R.GAS;
return $z2158621587;
}
};
var $Hand_DASH_oper_DASH_1106221573 = function(and_DASH_oper_DASH_91821571,if_helper737821572,self19985105,value20025108) {
var anf_if738721620 = R.isBoolean(and_DASH_oper_DASH_91821571);
if(R.isPyretTrue(anf_if738721620)) {
if(R.isPyretTrue(and_DASH_oper_DASH_91821571)) {
var anf_fun738921602 = G(value20025108,"visit",L[3543]);
var $z2159421595 = D;
var $f2160021601 = function(_) {
return R.isFunction(anf_fun738921602)?anf_fun738921602.app(self19985105):R.ffi.throwNonFunApp(L[834],anf_fun738921602,[self19985105]);
};
try {
if(--R.GAS > 0) {
$z2159421595 = $f2160021601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2160021601,
"from":L[834]});
}
} catch($e2159221593) {
if(R.isCont($e2159221593)) {
var $ss2159621597 = {"from":L[834],
"go":function(and_DASH_oper_DASH_91921603) {
return $Hand_DASH_oper_DASH_1106021604(and_DASH_oper_DASH_91921603,if_helper737821572);
}};
$e2159221593.stack[R.EXN_STACKHEIGHT++] = $ss2159621597;
}
if(R.isPyretException($e2159221593)) {
$e2159221593.pyretStack.push(L[834]);
}
throw $e2159221593;
}
var $ret2159821599 = $Hand_DASH_oper_DASH_1106021604($z2159421595,if_helper737821572);
++R.GAS;
return $ret2159821599;
} else {
var $z2160721608 = D;
var $f2161321614 = function(_) {
return R.isFunction(if_helper737821572)?if_helper737821572.app((false)):R.ffi.throwNonFunApp(L[834],if_helper737821572,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2160721608 = $f2161321614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2161321614,
"from":L[834]});
}
} catch($e2160521606) {
if(R.isCont($e2160521606)) {
var $ss2160921610 = {"from":L[834],
"go":function(cont_tail_app738821615) {
return $Hcont_tail_app1106121616(cont_tail_app738821615);
}};
$e2160521606.stack[R.EXN_STACKHEIGHT++] = $ss2160921610;
}
if(R.isPyretException($e2160521606)) {
$e2160521606.pyretStack.push(L[834]);
}
throw $e2160521606;
}
var $ret2161121612 = $Hcont_tail_app1106121616($z2160721608);
++R.GAS;
return $ret2161121612;
}
} else {
var cont_tail_arg738521619 = R.throwNonBooleanOp(L[3544],("first"),("and"),and_DASH_oper_DASH_91821571);
if(--R.GAS > 0) {
$z2161721618 = R.isFunction(if_helper737821572)?if_helper737821572.app(cont_tail_arg738521619):R.ffi.throwNonFunApp(L[3544],if_helper737821572,[cont_tail_arg738521619]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper737821572)?if_helper737821572.app(cont_tail_arg738521619):R.ffi.throwNonFunApp(L[3544],if_helper737821572,[cont_tail_arg738521619]);
},
"from":L[3544]});
}
++R.GAS;
return $z2161721618;
}
};
var $Hand_DASH_oper_DASH_1106021604 = function(and_DASH_oper_DASH_91921603,if_helper737821572) {
var anf_if739221636 = R.isBoolean(and_DASH_oper_DASH_91921603);
if(R.isPyretTrue(anf_if739221636)) {
var $z2162321624 = D;
var $f2162921630 = function(_) {
return R.isFunction(if_helper737821572)?if_helper737821572.app(and_DASH_oper_DASH_91921603):R.ffi.throwNonFunApp(L[834],if_helper737821572,[and_DASH_oper_DASH_91921603]);
};
try {
if(--R.GAS > 0) {
$z2162321624 = $f2162921630();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2162921630,
"from":L[834]});
}
} catch($e2162121622) {
if(R.isCont($e2162121622)) {
var $ss2162521626 = {"from":L[834],
"go":function(cont_tail_app739321631) {
return $Hcont_tail_app1105921632(cont_tail_app739321631);
}};
$e2162121622.stack[R.EXN_STACKHEIGHT++] = $ss2162521626;
}
if(R.isPyretException($e2162121622)) {
$e2162121622.pyretStack.push(L[834]);
}
throw $e2162121622;
}
var $ret2162721628 = $Hcont_tail_app1105921632($z2162321624);
++R.GAS;
return $ret2162721628;
} else {
var cont_tail_arg739021635 = R.throwNonBooleanOp(L[3545],("second"),("and"),and_DASH_oper_DASH_91921603);
if(--R.GAS > 0) {
$z2163321634 = R.isFunction(if_helper737821572)?if_helper737821572.app(cont_tail_arg739021635):R.ffi.throwNonFunApp(L[3545],if_helper737821572,[cont_tail_arg739021635]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper737821572)?if_helper737821572.app(cont_tail_arg739021635):R.ffi.throwNonFunApp(L[3545],if_helper737821572,[cont_tail_arg739021635]);
},
"from":L[3545]});
}
++R.GAS;
return $z2163321634;
}
};
var $Hcont_tail_app1105921632 = function(cont_tail_app739321631) {
return cont_tail_app739321631;
};
var $Hcont_tail_app1106121616 = function(cont_tail_app738821615) {
return cont_tail_app738821615;
};
var $Hcont_tail_app1106321585 = function(cont_tail_app738321584) {
return cont_tail_app738321584;
};
var $Hand_DASH_oper_DASH_110585126 = function(and_DASH_oper_DASH_9155124,self19945123,value19975125) {
var if_helper736421649 = R.makeFunction(function(if_helper_arg736521667) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[841],1,arguments);
}
var ann_DASH_check_DASH_temp736221668 = if_helper_arg736521667;
return ann_DASH_check_DASH_temp736221668;
});
var anf_if736821666 = R.isBoolean(and_DASH_oper_DASH_9155124);
if(R.isPyretTrue(anf_if736821666)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9155124)) {
var anf_fun737021647 = G(value19975125,"visit",L[3546]);
var $z2163921640 = D;
var $f2164521646 = function(_) {
return R.isFunction(anf_fun737021647)?anf_fun737021647.app(self19945123):R.ffi.throwNonFunApp(L[841],anf_fun737021647,[self19945123]);
};
try {
if(--R.GAS > 0) {
$z2163921640 = $f2164521646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2164521646,
"from":L[841]});
}
} catch($e2163721638) {
if(R.isCont($e2163721638)) {
var $ss2164121642 = {"from":L[841],
"go":function(and_DASH_oper_DASH_91621648) {
return $Hand_DASH_oper_DASH_1105621650(and_DASH_oper_DASH_91621648,if_helper736421649);
}};
$e2163721638.stack[R.EXN_STACKHEIGHT++] = $ss2164121642;
}
if(R.isPyretException($e2163721638)) {
$e2163721638.pyretStack.push(L[841]);
}
throw $e2163721638;
}
var $ret2164321644 = $Hand_DASH_oper_DASH_1105621650($z2163921640,if_helper736421649);
++R.GAS;
return $ret2164321644;
} else {
var $z2165321654 = D;
var $f2165921660 = function(_) {
return R.isFunction(if_helper736421649)?if_helper736421649.app((false)):R.ffi.throwNonFunApp(L[841],if_helper736421649,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2165321654 = $f2165921660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2165921660,
"from":L[841]});
}
} catch($e2165121652) {
if(R.isCont($e2165121652)) {
var $ss2165521656 = {"from":L[841],
"go":function(cont_tail_app736921661) {
return $Hcont_tail_app1105721662(cont_tail_app736921661);
}};
$e2165121652.stack[R.EXN_STACKHEIGHT++] = $ss2165521656;
}
if(R.isPyretException($e2165121652)) {
$e2165121652.pyretStack.push(L[841]);
}
throw $e2165121652;
}
var $ret2165721658 = $Hcont_tail_app1105721662($z2165321654);
++R.GAS;
return $ret2165721658;
}
} else {
var cont_tail_arg736621665 = R.throwNonBooleanOp(L[3547],("first"),("and"),and_DASH_oper_DASH_9155124);
if(--R.GAS > 0) {
$z2166321664 = R.isFunction(if_helper736421649)?if_helper736421649.app(cont_tail_arg736621665):R.ffi.throwNonFunApp(L[3547],if_helper736421649,[cont_tail_arg736621665]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper736421649)?if_helper736421649.app(cont_tail_arg736621665):R.ffi.throwNonFunApp(L[3547],if_helper736421649,[cont_tail_arg736621665]);
},
"from":L[3547]});
}
++R.GAS;
return $z2166321664;
}
};
var $Hand_DASH_oper_DASH_1105621650 = function(and_DASH_oper_DASH_91621648,if_helper736421649) {
var anf_if737321684 = R.isBoolean(and_DASH_oper_DASH_91621648);
if(R.isPyretTrue(anf_if737321684)) {
var $z2167121672 = D;
var $f2167721678 = function(_) {
return R.isFunction(if_helper736421649)?if_helper736421649.app(and_DASH_oper_DASH_91621648):R.ffi.throwNonFunApp(L[841],if_helper736421649,[and_DASH_oper_DASH_91621648]);
};
try {
if(--R.GAS > 0) {
$z2167121672 = $f2167721678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2167721678,
"from":L[841]});
}
} catch($e2166921670) {
if(R.isCont($e2166921670)) {
var $ss2167321674 = {"from":L[841],
"go":function(cont_tail_app737421679) {
return $Hcont_tail_app1105521680(cont_tail_app737421679);
}};
$e2166921670.stack[R.EXN_STACKHEIGHT++] = $ss2167321674;
}
if(R.isPyretException($e2166921670)) {
$e2166921670.pyretStack.push(L[841]);
}
throw $e2166921670;
}
var $ret2167521676 = $Hcont_tail_app1105521680($z2167121672);
++R.GAS;
return $ret2167521676;
} else {
var cont_tail_arg737121683 = R.throwNonBooleanOp(L[3548],("second"),("and"),and_DASH_oper_DASH_91621648);
if(--R.GAS > 0) {
$z2168121682 = R.isFunction(if_helper736421649)?if_helper736421649.app(cont_tail_arg737121683):R.ffi.throwNonFunApp(L[3548],if_helper736421649,[cont_tail_arg737121683]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper736421649)?if_helper736421649.app(cont_tail_arg737121683):R.ffi.throwNonFunApp(L[3548],if_helper736421649,[cont_tail_arg737121683]);
},
"from":L[3548]});
}
++R.GAS;
return $z2168121682;
}
};
var $Hcont_tail_app1105521680 = function(cont_tail_app737421679) {
return cont_tail_app737421679;
};
var $Hcont_tail_app1105721662 = function(cont_tail_app736921661) {
return cont_tail_app736921661;
};
var $Hann_DASH_check_DASH_temp110545142 = function(ann_DASH_check_DASH_temp73595141) {
return ann_DASH_check_DASH_temp73595141;
};
var $Hand_DASH_oper_DASH_110535163 = function(and_DASH_oper_DASH_9105159,ann19875160,bindings19865161,body19885162,lists974,self19835158) {
var if_helper733421698 = R.makeFunction(function(if_helper_arg733521730) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[853],1,arguments);
}
var ann_DASH_check_DASH_temp733221731 = if_helper_arg733521730;
return ann_DASH_check_DASH_temp733221731;
});
var anf_if733821729 = R.isBoolean(and_DASH_oper_DASH_9105159);
if(R.isPyretTrue(anf_if733821729)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9105159)) {
var anf_fun734021695 = G(lists974,"all",L[3550]);
var anf_arg734321696 = R.makeFunction(function(recv_DASH_91221700) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3549],1,arguments);
}
var anf_fun734221711 = G(recv_DASH_91221700,"visit",L[3549]);
var $z2170321704 = D;
var $f2170921710 = function(_) {
return R.isFunction(anf_fun734221711)?anf_fun734221711.app(self19835158):R.ffi.throwNonFunApp(L[3549],anf_fun734221711,[self19835158]);
};
try {
if(--R.GAS > 0) {
$z2170321704 = $f2170921710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2170921710,
"from":L[3549]});
}
} catch($e2170121702) {
if(R.isCont($e2170121702)) {
var $ss2170521706 = {"from":L[3549],
"go":function(ann_DASH_check_DASH_temp734121712) {
return $Hann_DASH_check_DASH_temp1104521713(ann_DASH_check_DASH_temp734121712);
}};
$e2170121702.stack[R.EXN_STACKHEIGHT++] = $ss2170521706;
}
if(R.isPyretException($e2170121702)) {
$e2170121702.pyretStack.push(L[3549]);
}
throw $e2170121702;
}
var $ret2170721708 = $Hann_DASH_check_DASH_temp1104521713($z2170321704);
++R.GAS;
return $ret2170721708;
});
var $z2168721688 = D;
var $f2169321694 = function(_) {
return R.isFunction(anf_fun734021695)?anf_fun734021695.app(anf_arg734321696,bindings19865161):R.ffi.throwNonFunApp(L[853],anf_fun734021695,[anf_arg734321696,bindings19865161]);
};
try {
if(--R.GAS > 0) {
$z2168721688 = $f2169321694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2169321694,
"from":L[853]});
}
} catch($e2168521686) {
if(R.isCont($e2168521686)) {
var $ss2168921690 = {"from":L[853],
"go":function(and_DASH_oper_DASH_91121697) {
return $Hand_DASH_oper_DASH_1105121699(and_DASH_oper_DASH_91121697,ann19875160,body19885162,if_helper733421698,self19835158);
}};
$e2168521686.stack[R.EXN_STACKHEIGHT++] = $ss2168921690;
}
if(R.isPyretException($e2168521686)) {
$e2168521686.pyretStack.push(L[853]);
}
throw $e2168521686;
}
var $ret2169121692 = $Hand_DASH_oper_DASH_1105121699($z2168721688,ann19875160,body19885162,if_helper733421698,self19835158);
++R.GAS;
return $ret2169121692;
} else {
var $z2171621717 = D;
var $f2172221723 = function(_) {
return R.isFunction(if_helper733421698)?if_helper733421698.app((false)):R.ffi.throwNonFunApp(L[853],if_helper733421698,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2171621717 = $f2172221723();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2172221723,
"from":L[853]});
}
} catch($e2171421715) {
if(R.isCont($e2171421715)) {
var $ss2171821719 = {"from":L[853],
"go":function(cont_tail_app733921724) {
return $Hcont_tail_app1105221725(cont_tail_app733921724);
}};
$e2171421715.stack[R.EXN_STACKHEIGHT++] = $ss2171821719;
}
if(R.isPyretException($e2171421715)) {
$e2171421715.pyretStack.push(L[853]);
}
throw $e2171421715;
}
var $ret2172021721 = $Hcont_tail_app1105221725($z2171621717);
++R.GAS;
return $ret2172021721;
}
} else {
var cont_tail_arg733621728 = R.throwNonBooleanOp(L[3551],("first"),("and"),and_DASH_oper_DASH_9105159);
if(--R.GAS > 0) {
$z2172621727 = R.isFunction(if_helper733421698)?if_helper733421698.app(cont_tail_arg733621728):R.ffi.throwNonFunApp(L[3551],if_helper733421698,[cont_tail_arg733621728]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper733421698)?if_helper733421698.app(cont_tail_arg733621728):R.ffi.throwNonFunApp(L[3551],if_helper733421698,[cont_tail_arg733621728]);
},
"from":L[3551]});
}
++R.GAS;
return $z2172621727;
}
};
var $Hand_DASH_oper_DASH_1105121699 = function(and_DASH_oper_DASH_91121697,ann19875160,body19885162,if_helper733421698,self19835158) {
var anf_if734621760 = R.isBoolean(and_DASH_oper_DASH_91121697);
if(R.isPyretTrue(anf_if734621760)) {
if(R.isPyretTrue(and_DASH_oper_DASH_91121697)) {
var anf_fun734821742 = G(ann19875160,"visit",L[3552]);
var $z2173421735 = D;
var $f2174021741 = function(_) {
return R.isFunction(anf_fun734821742)?anf_fun734821742.app(self19835158):R.ffi.throwNonFunApp(L[853],anf_fun734821742,[self19835158]);
};
try {
if(--R.GAS > 0) {
$z2173421735 = $f2174021741();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2174021741,
"from":L[853]});
}
} catch($e2173221733) {
if(R.isCont($e2173221733)) {
var $ss2173621737 = {"from":L[853],
"go":function(and_DASH_oper_DASH_91321743) {
return $Hand_DASH_oper_DASH_1104921744(and_DASH_oper_DASH_91321743,body19885162,if_helper733421698,self19835158);
}};
$e2173221733.stack[R.EXN_STACKHEIGHT++] = $ss2173621737;
}
if(R.isPyretException($e2173221733)) {
$e2173221733.pyretStack.push(L[853]);
}
throw $e2173221733;
}
var $ret2173821739 = $Hand_DASH_oper_DASH_1104921744($z2173421735,body19885162,if_helper733421698,self19835158);
++R.GAS;
return $ret2173821739;
} else {
var $z2174721748 = D;
var $f2175321754 = function(_) {
return R.isFunction(if_helper733421698)?if_helper733421698.app((false)):R.ffi.throwNonFunApp(L[853],if_helper733421698,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2174721748 = $f2175321754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2175321754,
"from":L[853]});
}
} catch($e2174521746) {
if(R.isCont($e2174521746)) {
var $ss2174921750 = {"from":L[853],
"go":function(cont_tail_app734721755) {
return $Hcont_tail_app1105021756(cont_tail_app734721755);
}};
$e2174521746.stack[R.EXN_STACKHEIGHT++] = $ss2174921750;
}
if(R.isPyretException($e2174521746)) {
$e2174521746.pyretStack.push(L[853]);
}
throw $e2174521746;
}
var $ret2175121752 = $Hcont_tail_app1105021756($z2174721748);
++R.GAS;
return $ret2175121752;
}
} else {
var cont_tail_arg734421759 = R.throwNonBooleanOp(L[3553],("first"),("and"),and_DASH_oper_DASH_91121697);
if(--R.GAS > 0) {
$z2175721758 = R.isFunction(if_helper733421698)?if_helper733421698.app(cont_tail_arg734421759):R.ffi.throwNonFunApp(L[3553],if_helper733421698,[cont_tail_arg734421759]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper733421698)?if_helper733421698.app(cont_tail_arg734421759):R.ffi.throwNonFunApp(L[3553],if_helper733421698,[cont_tail_arg734421759]);
},
"from":L[3553]});
}
++R.GAS;
return $z2175721758;
}
};
var $Hand_DASH_oper_DASH_1104921744 = function(and_DASH_oper_DASH_91321743,body19885162,if_helper733421698,self19835158) {
var anf_if735121789 = R.isBoolean(and_DASH_oper_DASH_91321743);
if(R.isPyretTrue(anf_if735121789)) {
if(R.isPyretTrue(and_DASH_oper_DASH_91321743)) {
var anf_fun735321771 = G(body19885162,"visit",L[3554]);
var $z2176321764 = D;
var $f2176921770 = function(_) {
return R.isFunction(anf_fun735321771)?anf_fun735321771.app(self19835158):R.ffi.throwNonFunApp(L[853],anf_fun735321771,[self19835158]);
};
try {
if(--R.GAS > 0) {
$z2176321764 = $f2176921770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2176921770,
"from":L[853]});
}
} catch($e2176121762) {
if(R.isCont($e2176121762)) {
var $ss2176521766 = {"from":L[853],
"go":function(and_DASH_oper_DASH_91421772) {
return $Hand_DASH_oper_DASH_1104721773(and_DASH_oper_DASH_91421772,if_helper733421698);
}};
$e2176121762.stack[R.EXN_STACKHEIGHT++] = $ss2176521766;
}
if(R.isPyretException($e2176121762)) {
$e2176121762.pyretStack.push(L[853]);
}
throw $e2176121762;
}
var $ret2176721768 = $Hand_DASH_oper_DASH_1104721773($z2176321764,if_helper733421698);
++R.GAS;
return $ret2176721768;
} else {
var $z2177621777 = D;
var $f2178221783 = function(_) {
return R.isFunction(if_helper733421698)?if_helper733421698.app((false)):R.ffi.throwNonFunApp(L[853],if_helper733421698,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2177621777 = $f2178221783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2178221783,
"from":L[853]});
}
} catch($e2177421775) {
if(R.isCont($e2177421775)) {
var $ss2177821779 = {"from":L[853],
"go":function(cont_tail_app735221784) {
return $Hcont_tail_app1104821785(cont_tail_app735221784);
}};
$e2177421775.stack[R.EXN_STACKHEIGHT++] = $ss2177821779;
}
if(R.isPyretException($e2177421775)) {
$e2177421775.pyretStack.push(L[853]);
}
throw $e2177421775;
}
var $ret2178021781 = $Hcont_tail_app1104821785($z2177621777);
++R.GAS;
return $ret2178021781;
}
} else {
var cont_tail_arg734921788 = R.throwNonBooleanOp(L[3555],("first"),("and"),and_DASH_oper_DASH_91321743);
if(--R.GAS > 0) {
$z2178621787 = R.isFunction(if_helper733421698)?if_helper733421698.app(cont_tail_arg734921788):R.ffi.throwNonFunApp(L[3555],if_helper733421698,[cont_tail_arg734921788]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper733421698)?if_helper733421698.app(cont_tail_arg734921788):R.ffi.throwNonFunApp(L[3555],if_helper733421698,[cont_tail_arg734921788]);
},
"from":L[3555]});
}
++R.GAS;
return $z2178621787;
}
};
var $Hand_DASH_oper_DASH_1104721773 = function(and_DASH_oper_DASH_91421772,if_helper733421698) {
var anf_if735621805 = R.isBoolean(and_DASH_oper_DASH_91421772);
if(R.isPyretTrue(anf_if735621805)) {
var $z2179221793 = D;
var $f2179821799 = function(_) {
return R.isFunction(if_helper733421698)?if_helper733421698.app(and_DASH_oper_DASH_91421772):R.ffi.throwNonFunApp(L[853],if_helper733421698,[and_DASH_oper_DASH_91421772]);
};
try {
if(--R.GAS > 0) {
$z2179221793 = $f2179821799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2179821799,
"from":L[853]});
}
} catch($e2179021791) {
if(R.isCont($e2179021791)) {
var $ss2179421795 = {"from":L[853],
"go":function(cont_tail_app735721800) {
return $Hcont_tail_app1104621801(cont_tail_app735721800);
}};
$e2179021791.stack[R.EXN_STACKHEIGHT++] = $ss2179421795;
}
if(R.isPyretException($e2179021791)) {
$e2179021791.pyretStack.push(L[853]);
}
throw $e2179021791;
}
var $ret2179621797 = $Hcont_tail_app1104621801($z2179221793);
++R.GAS;
return $ret2179621797;
} else {
var cont_tail_arg735421804 = R.throwNonBooleanOp(L[3556],("second"),("and"),and_DASH_oper_DASH_91421772);
if(--R.GAS > 0) {
$z2180221803 = R.isFunction(if_helper733421698)?if_helper733421698.app(cont_tail_arg735421804):R.ffi.throwNonFunApp(L[3556],if_helper733421698,[cont_tail_arg735421804]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper733421698)?if_helper733421698.app(cont_tail_arg735421804):R.ffi.throwNonFunApp(L[3556],if_helper733421698,[cont_tail_arg735421804]);
},
"from":L[3556]});
}
++R.GAS;
return $z2180221803;
}
};
var $Hcont_tail_app1104621801 = function(cont_tail_app735721800) {
return cont_tail_app735721800;
};
var $Hcont_tail_app1104821785 = function(cont_tail_app735221784) {
return cont_tail_app735221784;
};
var $Hcont_tail_app1105021756 = function(cont_tail_app734721755) {
return cont_tail_app734721755;
};
var $Hann_DASH_check_DASH_temp1104521713 = function(ann_DASH_check_DASH_temp734121712) {
return ann_DASH_check_DASH_temp734121712;
};
var $Hcont_tail_app1105221725 = function(cont_tail_app733921724) {
return cont_tail_app733921724;
};
var $Hand_DASH_oper_DASH_110445184 = function(and_DASH_oper_DASH_9005178,_check19825179,lists974,mixins19795180,params19785181,self19745177,shared_DASH_members19815182,variants19805183) {
var if_helper728821819 = R.makeFunction(function(if_helper_arg728921851) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[861],1,arguments);
}
var ann_DASH_check_DASH_temp728621852 = if_helper_arg728921851;
return ann_DASH_check_DASH_temp728621852;
});
var anf_if729221850 = R.isBoolean(and_DASH_oper_DASH_9005178);
if(R.isPyretTrue(anf_if729221850)) {
if(R.isPyretTrue(and_DASH_oper_DASH_9005178)) {
var anf_fun729421816 = G(lists974,"all",L[3558]);
var anf_arg729721817 = R.makeFunction(function(recv_DASH_90221821) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3557],1,arguments);
}
var anf_fun729621832 = G(recv_DASH_90221821,"visit",L[3557]);
var $z2182421825 = D;
var $f2183021831 = function(_) {
return R.isFunction(anf_fun729621832)?anf_fun729621832.app(self19745177):R.ffi.throwNonFunApp(L[3557],anf_fun729621832,[self19745177]);
};
try {
if(--R.GAS > 0) {
$z2182421825 = $f2183021831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2183021831,
"from":L[3557]});
}
} catch($e2182221823) {
if(R.isCont($e2182221823)) {
var $ss2182621827 = {"from":L[3557],
"go":function(ann_DASH_check_DASH_temp729521833) {
return $Hann_DASH_check_DASH_temp1102921834(ann_DASH_check_DASH_temp729521833);
}};
$e2182221823.stack[R.EXN_STACKHEIGHT++] = $ss2182621827;
}
if(R.isPyretException($e2182221823)) {
$e2182221823.pyretStack.push(L[3557]);
}
throw $e2182221823;
}
var $ret2182821829 = $Hann_DASH_check_DASH_temp1102921834($z2182421825);
++R.GAS;
return $ret2182821829;
});
var $z2180821809 = D;
var $f2181421815 = function(_) {
return R.isFunction(anf_fun729421816)?anf_fun729421816.app(anf_arg729721817,params19785181):R.ffi.throwNonFunApp(L[861],anf_fun729421816,[anf_arg729721817,params19785181]);
};
try {
if(--R.GAS > 0) {
$z2180821809 = $f2181421815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2181421815,
"from":L[861]});
}
} catch($e2180621807) {
if(R.isCont($e2180621807)) {
var $ss2181021811 = {"from":L[861],
"go":function(and_DASH_oper_DASH_90121818) {
return $Hand_DASH_oper_DASH_1104221820(and_DASH_oper_DASH_90121818,_check19825179,if_helper728821819,lists974,mixins19795180,self19745177,shared_DASH_members19815182,variants19805183);
}};
$e2180621807.stack[R.EXN_STACKHEIGHT++] = $ss2181021811;
}
if(R.isPyretException($e2180621807)) {
$e2180621807.pyretStack.push(L[861]);
}
throw $e2180621807;
}
var $ret2181221813 = $Hand_DASH_oper_DASH_1104221820($z2180821809,_check19825179,if_helper728821819,lists974,mixins19795180,self19745177,shared_DASH_members19815182,variants19805183);
++R.GAS;
return $ret2181221813;
} else {
var $z2183721838 = D;
var $f2184321844 = function(_) {
return R.isFunction(if_helper728821819)?if_helper728821819.app((false)):R.ffi.throwNonFunApp(L[861],if_helper728821819,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2183721838 = $f2184321844();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2184321844,
"from":L[861]});
}
} catch($e2183521836) {
if(R.isCont($e2183521836)) {
var $ss2183921840 = {"from":L[861],
"go":function(cont_tail_app729321845) {
return $Hcont_tail_app1104321846(cont_tail_app729321845);
}};
$e2183521836.stack[R.EXN_STACKHEIGHT++] = $ss2183921840;
}
if(R.isPyretException($e2183521836)) {
$e2183521836.pyretStack.push(L[861]);
}
throw $e2183521836;
}
var $ret2184121842 = $Hcont_tail_app1104321846($z2183721838);
++R.GAS;
return $ret2184121842;
}
} else {
var cont_tail_arg729021849 = R.throwNonBooleanOp(L[3559],("first"),("and"),and_DASH_oper_DASH_9005178);
if(--R.GAS > 0) {
$z2184721848 = R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg729021849):R.ffi.throwNonFunApp(L[3559],if_helper728821819,[cont_tail_arg729021849]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg729021849):R.ffi.throwNonFunApp(L[3559],if_helper728821819,[cont_tail_arg729021849]);
},
"from":L[3559]});
}
++R.GAS;
return $z2184721848;
}
};
var $Hand_DASH_oper_DASH_1104221820 = function(and_DASH_oper_DASH_90121818,_check19825179,if_helper728821819,lists974,mixins19795180,self19745177,shared_DASH_members19815182,variants19805183) {
var anf_if730021896 = R.isBoolean(and_DASH_oper_DASH_90121818);
if(R.isPyretTrue(anf_if730021896)) {
if(R.isPyretTrue(and_DASH_oper_DASH_90121818)) {
var anf_fun730221863 = G(lists974,"all",L[3561]);
var anf_arg730521864 = R.makeFunction(function(recv_DASH_90421867) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3560],1,arguments);
}
var anf_fun730421878 = G(recv_DASH_90421867,"visit",L[3560]);
var $z2187021871 = D;
var $f2187621877 = function(_) {
return R.isFunction(anf_fun730421878)?anf_fun730421878.app(self19745177):R.ffi.throwNonFunApp(L[3560],anf_fun730421878,[self19745177]);
};
try {
if(--R.GAS > 0) {
$z2187021871 = $f2187621877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2187621877,
"from":L[3560]});
}
} catch($e2186821869) {
if(R.isCont($e2186821869)) {
var $ss2187221873 = {"from":L[3560],
"go":function(ann_DASH_check_DASH_temp730321879) {
return $Hann_DASH_check_DASH_temp1103021880(ann_DASH_check_DASH_temp730321879);
}};
$e2186821869.stack[R.EXN_STACKHEIGHT++] = $ss2187221873;
}
if(R.isPyretException($e2186821869)) {
$e2186821869.pyretStack.push(L[3560]);
}
throw $e2186821869;
}
var $ret2187421875 = $Hann_DASH_check_DASH_temp1103021880($z2187021871);
++R.GAS;
return $ret2187421875;
});
var $z2185521856 = D;
var $f2186121862 = function(_) {
return R.isFunction(anf_fun730221863)?anf_fun730221863.app(anf_arg730521864,mixins19795180):R.ffi.throwNonFunApp(L[861],anf_fun730221863,[anf_arg730521864,mixins19795180]);
};
try {
if(--R.GAS > 0) {
$z2185521856 = $f2186121862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2186121862,
"from":L[861]});
}
} catch($e2185321854) {
if(R.isCont($e2185321854)) {
var $ss2185721858 = {"from":L[861],
"go":function(and_DASH_oper_DASH_90321865) {
return $Hand_DASH_oper_DASH_1104021866(and_DASH_oper_DASH_90321865,_check19825179,if_helper728821819,lists974,self19745177,shared_DASH_members19815182,variants19805183);
}};
$e2185321854.stack[R.EXN_STACKHEIGHT++] = $ss2185721858;
}
if(R.isPyretException($e2185321854)) {
$e2185321854.pyretStack.push(L[861]);
}
throw $e2185321854;
}
var $ret2185921860 = $Hand_DASH_oper_DASH_1104021866($z2185521856,_check19825179,if_helper728821819,lists974,self19745177,shared_DASH_members19815182,variants19805183);
++R.GAS;
return $ret2185921860;
} else {
var $z2188321884 = D;
var $f2188921890 = function(_) {
return R.isFunction(if_helper728821819)?if_helper728821819.app((false)):R.ffi.throwNonFunApp(L[861],if_helper728821819,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2188321884 = $f2188921890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2188921890,
"from":L[861]});
}
} catch($e2188121882) {
if(R.isCont($e2188121882)) {
var $ss2188521886 = {"from":L[861],
"go":function(cont_tail_app730121891) {
return $Hcont_tail_app1104121892(cont_tail_app730121891);
}};
$e2188121882.stack[R.EXN_STACKHEIGHT++] = $ss2188521886;
}
if(R.isPyretException($e2188121882)) {
$e2188121882.pyretStack.push(L[861]);
}
throw $e2188121882;
}
var $ret2188721888 = $Hcont_tail_app1104121892($z2188321884);
++R.GAS;
return $ret2188721888;
}
} else {
var cont_tail_arg729821895 = R.throwNonBooleanOp(L[3562],("first"),("and"),and_DASH_oper_DASH_90121818);
if(--R.GAS > 0) {
$z2189321894 = R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg729821895):R.ffi.throwNonFunApp(L[3562],if_helper728821819,[cont_tail_arg729821895]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg729821895):R.ffi.throwNonFunApp(L[3562],if_helper728821819,[cont_tail_arg729821895]);
},
"from":L[3562]});
}
++R.GAS;
return $z2189321894;
}
};
var $Hand_DASH_oper_DASH_1104021866 = function(and_DASH_oper_DASH_90321865,_check19825179,if_helper728821819,lists974,self19745177,shared_DASH_members19815182,variants19805183) {
var anf_if730821940 = R.isBoolean(and_DASH_oper_DASH_90321865);
if(R.isPyretTrue(anf_if730821940)) {
if(R.isPyretTrue(and_DASH_oper_DASH_90321865)) {
var anf_fun731021907 = G(lists974,"all",L[3564]);
var anf_arg731321908 = R.makeFunction(function(recv_DASH_90621911) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3563],1,arguments);
}
var anf_fun731221922 = G(recv_DASH_90621911,"visit",L[3563]);
var $z2191421915 = D;
var $f2192021921 = function(_) {
return R.isFunction(anf_fun731221922)?anf_fun731221922.app(self19745177):R.ffi.throwNonFunApp(L[3563],anf_fun731221922,[self19745177]);
};
try {
if(--R.GAS > 0) {
$z2191421915 = $f2192021921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2192021921,
"from":L[3563]});
}
} catch($e2191221913) {
if(R.isCont($e2191221913)) {
var $ss2191621917 = {"from":L[3563],
"go":function(ann_DASH_check_DASH_temp731121923) {
return $Hann_DASH_check_DASH_temp1103121924(ann_DASH_check_DASH_temp731121923);
}};
$e2191221913.stack[R.EXN_STACKHEIGHT++] = $ss2191621917;
}
if(R.isPyretException($e2191221913)) {
$e2191221913.pyretStack.push(L[3563]);
}
throw $e2191221913;
}
var $ret2191821919 = $Hann_DASH_check_DASH_temp1103121924($z2191421915);
++R.GAS;
return $ret2191821919;
});
var $z2189921900 = D;
var $f2190521906 = function(_) {
return R.isFunction(anf_fun731021907)?anf_fun731021907.app(anf_arg731321908,variants19805183):R.ffi.throwNonFunApp(L[861],anf_fun731021907,[anf_arg731321908,variants19805183]);
};
try {
if(--R.GAS > 0) {
$z2189921900 = $f2190521906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2190521906,
"from":L[861]});
}
} catch($e2189721898) {
if(R.isCont($e2189721898)) {
var $ss2190121902 = {"from":L[861],
"go":function(and_DASH_oper_DASH_90521909) {
return $Hand_DASH_oper_DASH_1103821910(and_DASH_oper_DASH_90521909,_check19825179,if_helper728821819,lists974,self19745177,shared_DASH_members19815182);
}};
$e2189721898.stack[R.EXN_STACKHEIGHT++] = $ss2190121902;
}
if(R.isPyretException($e2189721898)) {
$e2189721898.pyretStack.push(L[861]);
}
throw $e2189721898;
}
var $ret2190321904 = $Hand_DASH_oper_DASH_1103821910($z2189921900,_check19825179,if_helper728821819,lists974,self19745177,shared_DASH_members19815182);
++R.GAS;
return $ret2190321904;
} else {
var $z2192721928 = D;
var $f2193321934 = function(_) {
return R.isFunction(if_helper728821819)?if_helper728821819.app((false)):R.ffi.throwNonFunApp(L[861],if_helper728821819,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2192721928 = $f2193321934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2193321934,
"from":L[861]});
}
} catch($e2192521926) {
if(R.isCont($e2192521926)) {
var $ss2192921930 = {"from":L[861],
"go":function(cont_tail_app730921935) {
return $Hcont_tail_app1103921936(cont_tail_app730921935);
}};
$e2192521926.stack[R.EXN_STACKHEIGHT++] = $ss2192921930;
}
if(R.isPyretException($e2192521926)) {
$e2192521926.pyretStack.push(L[861]);
}
throw $e2192521926;
}
var $ret2193121932 = $Hcont_tail_app1103921936($z2192721928);
++R.GAS;
return $ret2193121932;
}
} else {
var cont_tail_arg730621939 = R.throwNonBooleanOp(L[3565],("first"),("and"),and_DASH_oper_DASH_90321865);
if(--R.GAS > 0) {
$z2193721938 = R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg730621939):R.ffi.throwNonFunApp(L[3565],if_helper728821819,[cont_tail_arg730621939]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg730621939):R.ffi.throwNonFunApp(L[3565],if_helper728821819,[cont_tail_arg730621939]);
},
"from":L[3565]});
}
++R.GAS;
return $z2193721938;
}
};
var $Hand_DASH_oper_DASH_1103821910 = function(and_DASH_oper_DASH_90521909,_check19825179,if_helper728821819,lists974,self19745177,shared_DASH_members19815182) {
var anf_if731621984 = R.isBoolean(and_DASH_oper_DASH_90521909);
if(R.isPyretTrue(anf_if731621984)) {
if(R.isPyretTrue(and_DASH_oper_DASH_90521909)) {
var anf_fun731821951 = G(lists974,"all",L[3567]);
var anf_arg732121952 = R.makeFunction(function(recv_DASH_90821955) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3566],1,arguments);
}
var anf_fun732021966 = G(recv_DASH_90821955,"visit",L[3566]);
var $z2195821959 = D;
var $f2196421965 = function(_) {
return R.isFunction(anf_fun732021966)?anf_fun732021966.app(self19745177):R.ffi.throwNonFunApp(L[3566],anf_fun732021966,[self19745177]);
};
try {
if(--R.GAS > 0) {
$z2195821959 = $f2196421965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2196421965,
"from":L[3566]});
}
} catch($e2195621957) {
if(R.isCont($e2195621957)) {
var $ss2196021961 = {"from":L[3566],
"go":function(ann_DASH_check_DASH_temp731921967) {
return $Hann_DASH_check_DASH_temp1103221968(ann_DASH_check_DASH_temp731921967);
}};
$e2195621957.stack[R.EXN_STACKHEIGHT++] = $ss2196021961;
}
if(R.isPyretException($e2195621957)) {
$e2195621957.pyretStack.push(L[3566]);
}
throw $e2195621957;
}
var $ret2196221963 = $Hann_DASH_check_DASH_temp1103221968($z2195821959);
++R.GAS;
return $ret2196221963;
});
var $z2194321944 = D;
var $f2194921950 = function(_) {
return R.isFunction(anf_fun731821951)?anf_fun731821951.app(anf_arg732121952,shared_DASH_members19815182):R.ffi.throwNonFunApp(L[861],anf_fun731821951,[anf_arg732121952,shared_DASH_members19815182]);
};
try {
if(--R.GAS > 0) {
$z2194321944 = $f2194921950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2194921950,
"from":L[861]});
}
} catch($e2194121942) {
if(R.isCont($e2194121942)) {
var $ss2194521946 = {"from":L[861],
"go":function(and_DASH_oper_DASH_90721953) {
return $Hand_DASH_oper_DASH_1103621954(and_DASH_oper_DASH_90721953,_check19825179,if_helper728821819,self19745177);
}};
$e2194121942.stack[R.EXN_STACKHEIGHT++] = $ss2194521946;
}
if(R.isPyretException($e2194121942)) {
$e2194121942.pyretStack.push(L[861]);
}
throw $e2194121942;
}
var $ret2194721948 = $Hand_DASH_oper_DASH_1103621954($z2194321944,_check19825179,if_helper728821819,self19745177);
++R.GAS;
return $ret2194721948;
} else {
var $z2197121972 = D;
var $f2197721978 = function(_) {
return R.isFunction(if_helper728821819)?if_helper728821819.app((false)):R.ffi.throwNonFunApp(L[861],if_helper728821819,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2197121972 = $f2197721978();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2197721978,
"from":L[861]});
}
} catch($e2196921970) {
if(R.isCont($e2196921970)) {
var $ss2197321974 = {"from":L[861],
"go":function(cont_tail_app731721979) {
return $Hcont_tail_app1103721980(cont_tail_app731721979);
}};
$e2196921970.stack[R.EXN_STACKHEIGHT++] = $ss2197321974;
}
if(R.isPyretException($e2196921970)) {
$e2196921970.pyretStack.push(L[861]);
}
throw $e2196921970;
}
var $ret2197521976 = $Hcont_tail_app1103721980($z2197121972);
++R.GAS;
return $ret2197521976;
}
} else {
var cont_tail_arg731421983 = R.throwNonBooleanOp(L[3568],("first"),("and"),and_DASH_oper_DASH_90521909);
if(--R.GAS > 0) {
$z2198121982 = R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg731421983):R.ffi.throwNonFunApp(L[3568],if_helper728821819,[cont_tail_arg731421983]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg731421983):R.ffi.throwNonFunApp(L[3568],if_helper728821819,[cont_tail_arg731421983]);
},
"from":L[3568]});
}
++R.GAS;
return $z2198121982;
}
};
var $Hand_DASH_oper_DASH_1103621954 = function(and_DASH_oper_DASH_90721953,_check19825179,if_helper728821819,self19745177) {
var anf_if732422013 = R.isBoolean(and_DASH_oper_DASH_90721953);
if(R.isPyretTrue(anf_if732422013)) {
if(R.isPyretTrue(and_DASH_oper_DASH_90721953)) {
var anf_fun732621995 = G(self19745177,"option",L[3569]);
var $z2198721988 = D;
var $f2199321994 = function(_) {
return R.isFunction(anf_fun732621995)?anf_fun732621995.app(_check19825179):R.ffi.throwNonFunApp(L[861],anf_fun732621995,[_check19825179]);
};
try {
if(--R.GAS > 0) {
$z2198721988 = $f2199321994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2199321994,
"from":L[861]});
}
} catch($e2198521986) {
if(R.isCont($e2198521986)) {
var $ss2198921990 = {"from":L[861],
"go":function(and_DASH_oper_DASH_90921996) {
return $Hand_DASH_oper_DASH_1103421997(and_DASH_oper_DASH_90921996,if_helper728821819);
}};
$e2198521986.stack[R.EXN_STACKHEIGHT++] = $ss2198921990;
}
if(R.isPyretException($e2198521986)) {
$e2198521986.pyretStack.push(L[861]);
}
throw $e2198521986;
}
var $ret2199121992 = $Hand_DASH_oper_DASH_1103421997($z2198721988,if_helper728821819);
++R.GAS;
return $ret2199121992;
} else {
var $z2200022001 = D;
var $f2200622007 = function(_) {
return R.isFunction(if_helper728821819)?if_helper728821819.app((false)):R.ffi.throwNonFunApp(L[861],if_helper728821819,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2200022001 = $f2200622007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2200622007,
"from":L[861]});
}
} catch($e2199821999) {
if(R.isCont($e2199821999)) {
var $ss2200222003 = {"from":L[861],
"go":function(cont_tail_app732522008) {
return $Hcont_tail_app1103522009(cont_tail_app732522008);
}};
$e2199821999.stack[R.EXN_STACKHEIGHT++] = $ss2200222003;
}
if(R.isPyretException($e2199821999)) {
$e2199821999.pyretStack.push(L[861]);
}
throw $e2199821999;
}
var $ret2200422005 = $Hcont_tail_app1103522009($z2200022001);
++R.GAS;
return $ret2200422005;
}
} else {
var cont_tail_arg732222012 = R.throwNonBooleanOp(L[3570],("first"),("and"),and_DASH_oper_DASH_90721953);
if(--R.GAS > 0) {
$z2201022011 = R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg732222012):R.ffi.throwNonFunApp(L[3570],if_helper728821819,[cont_tail_arg732222012]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg732222012):R.ffi.throwNonFunApp(L[3570],if_helper728821819,[cont_tail_arg732222012]);
},
"from":L[3570]});
}
++R.GAS;
return $z2201022011;
}
};
var $Hand_DASH_oper_DASH_1103421997 = function(and_DASH_oper_DASH_90921996,if_helper728821819) {
var anf_if732922029 = R.isBoolean(and_DASH_oper_DASH_90921996);
if(R.isPyretTrue(anf_if732922029)) {
var $z2201622017 = D;
var $f2202222023 = function(_) {
return R.isFunction(if_helper728821819)?if_helper728821819.app(and_DASH_oper_DASH_90921996):R.ffi.throwNonFunApp(L[861],if_helper728821819,[and_DASH_oper_DASH_90921996]);
};
try {
if(--R.GAS > 0) {
$z2201622017 = $f2202222023();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2202222023,
"from":L[861]});
}
} catch($e2201422015) {
if(R.isCont($e2201422015)) {
var $ss2201822019 = {"from":L[861],
"go":function(cont_tail_app733022024) {
return $Hcont_tail_app1103322025(cont_tail_app733022024);
}};
$e2201422015.stack[R.EXN_STACKHEIGHT++] = $ss2201822019;
}
if(R.isPyretException($e2201422015)) {
$e2201422015.pyretStack.push(L[861]);
}
throw $e2201422015;
}
var $ret2202022021 = $Hcont_tail_app1103322025($z2201622017);
++R.GAS;
return $ret2202022021;
} else {
var cont_tail_arg732722028 = R.throwNonBooleanOp(L[3571],("second"),("and"),and_DASH_oper_DASH_90921996);
if(--R.GAS > 0) {
$z2202622027 = R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg732722028):R.ffi.throwNonFunApp(L[3571],if_helper728821819,[cont_tail_arg732722028]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper728821819)?if_helper728821819.app(cont_tail_arg732722028):R.ffi.throwNonFunApp(L[3571],if_helper728821819,[cont_tail_arg732722028]);
},
"from":L[3571]});
}
++R.GAS;
return $z2202622027;
}
};
var $Hcont_tail_app1103322025 = function(cont_tail_app733022024) {
return cont_tail_app733022024;
};
var $Hcont_tail_app1103522009 = function(cont_tail_app732522008) {
return cont_tail_app732522008;
};
var $Hann_DASH_check_DASH_temp1103221968 = function(ann_DASH_check_DASH_temp731921967) {
return ann_DASH_check_DASH_temp731921967;
};
var $Hcont_tail_app1103721980 = function(cont_tail_app731721979) {
return cont_tail_app731721979;
};
var $Hann_DASH_check_DASH_temp1103121924 = function(ann_DASH_check_DASH_temp731121923) {
return ann_DASH_check_DASH_temp731121923;
};
var $Hcont_tail_app1103921936 = function(cont_tail_app730921935) {
return cont_tail_app730921935;
};
var $Hann_DASH_check_DASH_temp1103021880 = function(ann_DASH_check_DASH_temp730321879) {
return ann_DASH_check_DASH_temp730321879;
};
var $Hcont_tail_app1104121892 = function(cont_tail_app730121891) {
return cont_tail_app730121891;
};
var $Hann_DASH_check_DASH_temp1102921834 = function(ann_DASH_check_DASH_temp729521833) {
return ann_DASH_check_DASH_temp729521833;
};
var $Hcont_tail_app1104321846 = function(cont_tail_app729321845) {
return cont_tail_app729321845;
};
var $Hand_DASH_oper_DASH_110285207 = function(and_DASH_oper_DASH_8915201,_check19735202,lists974,mixins19705203,self19665204,shared_DASH_members19725205,variants19715206) {
var if_helper725022043 = R.makeFunction(function(if_helper_arg725122075) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[872],1,arguments);
}
var ann_DASH_check_DASH_temp724522076 = if_helper_arg725122075;
return ann_DASH_check_DASH_temp724522076;
});
var anf_if725422074 = R.isBoolean(and_DASH_oper_DASH_8915201);
if(R.isPyretTrue(anf_if725422074)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8915201)) {
var anf_fun725622040 = G(lists974,"all",L[3573]);
var anf_arg725922041 = R.makeFunction(function(recv_DASH_89422045) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3572],1,arguments);
}
var anf_fun725822056 = G(recv_DASH_89422045,"visit",L[3572]);
var $z2204822049 = D;
var $f2205422055 = function(_) {
return R.isFunction(anf_fun725822056)?anf_fun725822056.app(self19665204):R.ffi.throwNonFunApp(L[3572],anf_fun725822056,[self19665204]);
};
try {
if(--R.GAS > 0) {
$z2204822049 = $f2205422055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2205422055,
"from":L[3572]});
}
} catch($e2204622047) {
if(R.isCont($e2204622047)) {
var $ss2205022051 = {"from":L[3572],
"go":function(ann_DASH_check_DASH_temp725722057) {
return $Hann_DASH_check_DASH_temp1101622058(ann_DASH_check_DASH_temp725722057);
}};
$e2204622047.stack[R.EXN_STACKHEIGHT++] = $ss2205022051;
}
if(R.isPyretException($e2204622047)) {
$e2204622047.pyretStack.push(L[3572]);
}
throw $e2204622047;
}
var $ret2205222053 = $Hann_DASH_check_DASH_temp1101622058($z2204822049);
++R.GAS;
return $ret2205222053;
});
var $z2203222033 = D;
var $f2203822039 = function(_) {
return R.isFunction(anf_fun725622040)?anf_fun725622040.app(anf_arg725922041,mixins19705203):R.ffi.throwNonFunApp(L[872],anf_fun725622040,[anf_arg725922041,mixins19705203]);
};
try {
if(--R.GAS > 0) {
$z2203222033 = $f2203822039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2203822039,
"from":L[872]});
}
} catch($e2203022031) {
if(R.isCont($e2203022031)) {
var $ss2203422035 = {"from":L[872],
"go":function(and_DASH_oper_DASH_89322042) {
return $Hand_DASH_oper_DASH_1102622044(and_DASH_oper_DASH_89322042,_check19735202,if_helper725022043,lists974,self19665204,shared_DASH_members19725205,variants19715206);
}};
$e2203022031.stack[R.EXN_STACKHEIGHT++] = $ss2203422035;
}
if(R.isPyretException($e2203022031)) {
$e2203022031.pyretStack.push(L[872]);
}
throw $e2203022031;
}
var $ret2203622037 = $Hand_DASH_oper_DASH_1102622044($z2203222033,_check19735202,if_helper725022043,lists974,self19665204,shared_DASH_members19725205,variants19715206);
++R.GAS;
return $ret2203622037;
} else {
var $z2206122062 = D;
var $f2206722068 = function(_) {
return R.isFunction(if_helper725022043)?if_helper725022043.app((false)):R.ffi.throwNonFunApp(L[872],if_helper725022043,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2206122062 = $f2206722068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2206722068,
"from":L[872]});
}
} catch($e2205922060) {
if(R.isCont($e2205922060)) {
var $ss2206322064 = {"from":L[872],
"go":function(cont_tail_app725522069) {
return $Hcont_tail_app1102722070(cont_tail_app725522069);
}};
$e2205922060.stack[R.EXN_STACKHEIGHT++] = $ss2206322064;
}
if(R.isPyretException($e2205922060)) {
$e2205922060.pyretStack.push(L[872]);
}
throw $e2205922060;
}
var $ret2206522066 = $Hcont_tail_app1102722070($z2206122062);
++R.GAS;
return $ret2206522066;
}
} else {
var cont_tail_arg725222073 = R.throwNonBooleanOp(L[3574],("first"),("and"),and_DASH_oper_DASH_8915201);
if(--R.GAS > 0) {
$z2207122072 = R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg725222073):R.ffi.throwNonFunApp(L[3574],if_helper725022043,[cont_tail_arg725222073]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg725222073):R.ffi.throwNonFunApp(L[3574],if_helper725022043,[cont_tail_arg725222073]);
},
"from":L[3574]});
}
++R.GAS;
return $z2207122072;
}
};
var $Hand_DASH_oper_DASH_1102622044 = function(and_DASH_oper_DASH_89322042,_check19735202,if_helper725022043,lists974,self19665204,shared_DASH_members19725205,variants19715206) {
var anf_if726222120 = R.isBoolean(and_DASH_oper_DASH_89322042);
if(R.isPyretTrue(anf_if726222120)) {
if(R.isPyretTrue(and_DASH_oper_DASH_89322042)) {
var anf_fun726422087 = G(lists974,"all",L[3576]);
var anf_arg726722088 = R.makeFunction(function(recv_DASH_89622091) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3575],1,arguments);
}
var anf_fun726622102 = G(recv_DASH_89622091,"visit",L[3575]);
var $z2209422095 = D;
var $f2210022101 = function(_) {
return R.isFunction(anf_fun726622102)?anf_fun726622102.app(self19665204):R.ffi.throwNonFunApp(L[3575],anf_fun726622102,[self19665204]);
};
try {
if(--R.GAS > 0) {
$z2209422095 = $f2210022101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2210022101,
"from":L[3575]});
}
} catch($e2209222093) {
if(R.isCont($e2209222093)) {
var $ss2209622097 = {"from":L[3575],
"go":function(ann_DASH_check_DASH_temp726522103) {
return $Hann_DASH_check_DASH_temp1101722104(ann_DASH_check_DASH_temp726522103);
}};
$e2209222093.stack[R.EXN_STACKHEIGHT++] = $ss2209622097;
}
if(R.isPyretException($e2209222093)) {
$e2209222093.pyretStack.push(L[3575]);
}
throw $e2209222093;
}
var $ret2209822099 = $Hann_DASH_check_DASH_temp1101722104($z2209422095);
++R.GAS;
return $ret2209822099;
});
var $z2207922080 = D;
var $f2208522086 = function(_) {
return R.isFunction(anf_fun726422087)?anf_fun726422087.app(anf_arg726722088,variants19715206):R.ffi.throwNonFunApp(L[872],anf_fun726422087,[anf_arg726722088,variants19715206]);
};
try {
if(--R.GAS > 0) {
$z2207922080 = $f2208522086();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2208522086,
"from":L[872]});
}
} catch($e2207722078) {
if(R.isCont($e2207722078)) {
var $ss2208122082 = {"from":L[872],
"go":function(and_DASH_oper_DASH_89522089) {
return $Hand_DASH_oper_DASH_1102422090(and_DASH_oper_DASH_89522089,_check19735202,if_helper725022043,lists974,self19665204,shared_DASH_members19725205);
}};
$e2207722078.stack[R.EXN_STACKHEIGHT++] = $ss2208122082;
}
if(R.isPyretException($e2207722078)) {
$e2207722078.pyretStack.push(L[872]);
}
throw $e2207722078;
}
var $ret2208322084 = $Hand_DASH_oper_DASH_1102422090($z2207922080,_check19735202,if_helper725022043,lists974,self19665204,shared_DASH_members19725205);
++R.GAS;
return $ret2208322084;
} else {
var $z2210722108 = D;
var $f2211322114 = function(_) {
return R.isFunction(if_helper725022043)?if_helper725022043.app((false)):R.ffi.throwNonFunApp(L[872],if_helper725022043,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2210722108 = $f2211322114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2211322114,
"from":L[872]});
}
} catch($e2210522106) {
if(R.isCont($e2210522106)) {
var $ss2210922110 = {"from":L[872],
"go":function(cont_tail_app726322115) {
return $Hcont_tail_app1102522116(cont_tail_app726322115);
}};
$e2210522106.stack[R.EXN_STACKHEIGHT++] = $ss2210922110;
}
if(R.isPyretException($e2210522106)) {
$e2210522106.pyretStack.push(L[872]);
}
throw $e2210522106;
}
var $ret2211122112 = $Hcont_tail_app1102522116($z2210722108);
++R.GAS;
return $ret2211122112;
}
} else {
var cont_tail_arg726022119 = R.throwNonBooleanOp(L[3577],("first"),("and"),and_DASH_oper_DASH_89322042);
if(--R.GAS > 0) {
$z2211722118 = R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg726022119):R.ffi.throwNonFunApp(L[3577],if_helper725022043,[cont_tail_arg726022119]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg726022119):R.ffi.throwNonFunApp(L[3577],if_helper725022043,[cont_tail_arg726022119]);
},
"from":L[3577]});
}
++R.GAS;
return $z2211722118;
}
};
var $Hand_DASH_oper_DASH_1102422090 = function(and_DASH_oper_DASH_89522089,_check19735202,if_helper725022043,lists974,self19665204,shared_DASH_members19725205) {
var anf_if727022164 = R.isBoolean(and_DASH_oper_DASH_89522089);
if(R.isPyretTrue(anf_if727022164)) {
if(R.isPyretTrue(and_DASH_oper_DASH_89522089)) {
var anf_fun727222131 = G(lists974,"all",L[3579]);
var anf_arg727522132 = R.makeFunction(function(recv_DASH_89822135) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3578],1,arguments);
}
var anf_fun727422146 = G(recv_DASH_89822135,"visit",L[3578]);
var $z2213822139 = D;
var $f2214422145 = function(_) {
return R.isFunction(anf_fun727422146)?anf_fun727422146.app(self19665204):R.ffi.throwNonFunApp(L[3578],anf_fun727422146,[self19665204]);
};
try {
if(--R.GAS > 0) {
$z2213822139 = $f2214422145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2214422145,
"from":L[3578]});
}
} catch($e2213622137) {
if(R.isCont($e2213622137)) {
var $ss2214022141 = {"from":L[3578],
"go":function(ann_DASH_check_DASH_temp727322147) {
return $Hann_DASH_check_DASH_temp1101822148(ann_DASH_check_DASH_temp727322147);
}};
$e2213622137.stack[R.EXN_STACKHEIGHT++] = $ss2214022141;
}
if(R.isPyretException($e2213622137)) {
$e2213622137.pyretStack.push(L[3578]);
}
throw $e2213622137;
}
var $ret2214222143 = $Hann_DASH_check_DASH_temp1101822148($z2213822139);
++R.GAS;
return $ret2214222143;
});
var $z2212322124 = D;
var $f2212922130 = function(_) {
return R.isFunction(anf_fun727222131)?anf_fun727222131.app(anf_arg727522132,shared_DASH_members19725205):R.ffi.throwNonFunApp(L[872],anf_fun727222131,[anf_arg727522132,shared_DASH_members19725205]);
};
try {
if(--R.GAS > 0) {
$z2212322124 = $f2212922130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2212922130,
"from":L[872]});
}
} catch($e2212122122) {
if(R.isCont($e2212122122)) {
var $ss2212522126 = {"from":L[872],
"go":function(and_DASH_oper_DASH_89722133) {
return $Hand_DASH_oper_DASH_1102222134(and_DASH_oper_DASH_89722133,_check19735202,if_helper725022043,self19665204);
}};
$e2212122122.stack[R.EXN_STACKHEIGHT++] = $ss2212522126;
}
if(R.isPyretException($e2212122122)) {
$e2212122122.pyretStack.push(L[872]);
}
throw $e2212122122;
}
var $ret2212722128 = $Hand_DASH_oper_DASH_1102222134($z2212322124,_check19735202,if_helper725022043,self19665204);
++R.GAS;
return $ret2212722128;
} else {
var $z2215122152 = D;
var $f2215722158 = function(_) {
return R.isFunction(if_helper725022043)?if_helper725022043.app((false)):R.ffi.throwNonFunApp(L[872],if_helper725022043,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2215122152 = $f2215722158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2215722158,
"from":L[872]});
}
} catch($e2214922150) {
if(R.isCont($e2214922150)) {
var $ss2215322154 = {"from":L[872],
"go":function(cont_tail_app727122159) {
return $Hcont_tail_app1102322160(cont_tail_app727122159);
}};
$e2214922150.stack[R.EXN_STACKHEIGHT++] = $ss2215322154;
}
if(R.isPyretException($e2214922150)) {
$e2214922150.pyretStack.push(L[872]);
}
throw $e2214922150;
}
var $ret2215522156 = $Hcont_tail_app1102322160($z2215122152);
++R.GAS;
return $ret2215522156;
}
} else {
var cont_tail_arg726822163 = R.throwNonBooleanOp(L[3580],("first"),("and"),and_DASH_oper_DASH_89522089);
if(--R.GAS > 0) {
$z2216122162 = R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg726822163):R.ffi.throwNonFunApp(L[3580],if_helper725022043,[cont_tail_arg726822163]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg726822163):R.ffi.throwNonFunApp(L[3580],if_helper725022043,[cont_tail_arg726822163]);
},
"from":L[3580]});
}
++R.GAS;
return $z2216122162;
}
};
var $Hand_DASH_oper_DASH_1102222134 = function(and_DASH_oper_DASH_89722133,_check19735202,if_helper725022043,self19665204) {
var anf_if727822193 = R.isBoolean(and_DASH_oper_DASH_89722133);
if(R.isPyretTrue(anf_if727822193)) {
if(R.isPyretTrue(and_DASH_oper_DASH_89722133)) {
var anf_fun728022175 = G(self19665204,"option",L[3581]);
var $z2216722168 = D;
var $f2217322174 = function(_) {
return R.isFunction(anf_fun728022175)?anf_fun728022175.app(_check19735202):R.ffi.throwNonFunApp(L[872],anf_fun728022175,[_check19735202]);
};
try {
if(--R.GAS > 0) {
$z2216722168 = $f2217322174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2217322174,
"from":L[872]});
}
} catch($e2216522166) {
if(R.isCont($e2216522166)) {
var $ss2216922170 = {"from":L[872],
"go":function(and_DASH_oper_DASH_89922176) {
return $Hand_DASH_oper_DASH_1102022177(and_DASH_oper_DASH_89922176,if_helper725022043);
}};
$e2216522166.stack[R.EXN_STACKHEIGHT++] = $ss2216922170;
}
if(R.isPyretException($e2216522166)) {
$e2216522166.pyretStack.push(L[872]);
}
throw $e2216522166;
}
var $ret2217122172 = $Hand_DASH_oper_DASH_1102022177($z2216722168,if_helper725022043);
++R.GAS;
return $ret2217122172;
} else {
var $z2218022181 = D;
var $f2218622187 = function(_) {
return R.isFunction(if_helper725022043)?if_helper725022043.app((false)):R.ffi.throwNonFunApp(L[872],if_helper725022043,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2218022181 = $f2218622187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2218622187,
"from":L[872]});
}
} catch($e2217822179) {
if(R.isCont($e2217822179)) {
var $ss2218222183 = {"from":L[872],
"go":function(cont_tail_app727922188) {
return $Hcont_tail_app1102122189(cont_tail_app727922188);
}};
$e2217822179.stack[R.EXN_STACKHEIGHT++] = $ss2218222183;
}
if(R.isPyretException($e2217822179)) {
$e2217822179.pyretStack.push(L[872]);
}
throw $e2217822179;
}
var $ret2218422185 = $Hcont_tail_app1102122189($z2218022181);
++R.GAS;
return $ret2218422185;
}
} else {
var cont_tail_arg727622192 = R.throwNonBooleanOp(L[3582],("first"),("and"),and_DASH_oper_DASH_89722133);
if(--R.GAS > 0) {
$z2219022191 = R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg727622192):R.ffi.throwNonFunApp(L[3582],if_helper725022043,[cont_tail_arg727622192]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg727622192):R.ffi.throwNonFunApp(L[3582],if_helper725022043,[cont_tail_arg727622192]);
},
"from":L[3582]});
}
++R.GAS;
return $z2219022191;
}
};
var $Hand_DASH_oper_DASH_1102022177 = function(and_DASH_oper_DASH_89922176,if_helper725022043) {
var anf_if728322209 = R.isBoolean(and_DASH_oper_DASH_89922176);
if(R.isPyretTrue(anf_if728322209)) {
var $z2219622197 = D;
var $f2220222203 = function(_) {
return R.isFunction(if_helper725022043)?if_helper725022043.app(and_DASH_oper_DASH_89922176):R.ffi.throwNonFunApp(L[872],if_helper725022043,[and_DASH_oper_DASH_89922176]);
};
try {
if(--R.GAS > 0) {
$z2219622197 = $f2220222203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2220222203,
"from":L[872]});
}
} catch($e2219422195) {
if(R.isCont($e2219422195)) {
var $ss2219822199 = {"from":L[872],
"go":function(cont_tail_app728422204) {
return $Hcont_tail_app1101922205(cont_tail_app728422204);
}};
$e2219422195.stack[R.EXN_STACKHEIGHT++] = $ss2219822199;
}
if(R.isPyretException($e2219422195)) {
$e2219422195.pyretStack.push(L[872]);
}
throw $e2219422195;
}
var $ret2220022201 = $Hcont_tail_app1101922205($z2219622197);
++R.GAS;
return $ret2220022201;
} else {
var cont_tail_arg728122208 = R.throwNonBooleanOp(L[3583],("second"),("and"),and_DASH_oper_DASH_89922176);
if(--R.GAS > 0) {
$z2220622207 = R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg728122208):R.ffi.throwNonFunApp(L[3583],if_helper725022043,[cont_tail_arg728122208]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper725022043)?if_helper725022043.app(cont_tail_arg728122208):R.ffi.throwNonFunApp(L[3583],if_helper725022043,[cont_tail_arg728122208]);
},
"from":L[3583]});
}
++R.GAS;
return $z2220622207;
}
};
var $Hcont_tail_app1101922205 = function(cont_tail_app728422204) {
return cont_tail_app728422204;
};
var $Hcont_tail_app1102122189 = function(cont_tail_app727922188) {
return cont_tail_app727922188;
};
var $Hann_DASH_check_DASH_temp1101822148 = function(ann_DASH_check_DASH_temp727322147) {
return ann_DASH_check_DASH_temp727322147;
};
var $Hcont_tail_app1102322160 = function(cont_tail_app727122159) {
return cont_tail_app727122159;
};
var $Hann_DASH_check_DASH_temp1101722104 = function(ann_DASH_check_DASH_temp726522103) {
return ann_DASH_check_DASH_temp726522103;
};
var $Hcont_tail_app1102522116 = function(cont_tail_app726322115) {
return cont_tail_app726322115;
};
var $Hann_DASH_check_DASH_temp1101622058 = function(ann_DASH_check_DASH_temp725722057) {
return ann_DASH_check_DASH_temp725722057;
};
var $Hcont_tail_app1102722070 = function(cont_tail_app725522069) {
return cont_tail_app725522069;
};
var $Hann_DASH_check_DASH_temp110155221 = function(ann_DASH_check_DASH_temp72475220) {
return ann_DASH_check_DASH_temp72475220;
};
var $Hand_DASH_oper_DASH_110145238 = function(and_DASH_oper_DASH_8895236,field19655237,self19625235) {
var if_helper723322222 = R.makeFunction(function(if_helper_arg723422240) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[883],1,arguments);
}
var ann_DASH_check_DASH_temp723122241 = if_helper_arg723422240;
return ann_DASH_check_DASH_temp723122241;
});
var anf_if723722239 = R.isBoolean(and_DASH_oper_DASH_8895236);
if(R.isPyretTrue(anf_if723722239)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8895236)) {
var anf_fun723922220 = G(field19655237,"visit",L[3584]);
var $z2221222213 = D;
var $f2221822219 = function(_) {
return R.isFunction(anf_fun723922220)?anf_fun723922220.app(self19625235):R.ffi.throwNonFunApp(L[883],anf_fun723922220,[self19625235]);
};
try {
if(--R.GAS > 0) {
$z2221222213 = $f2221822219();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2221822219,
"from":L[883]});
}
} catch($e2221022211) {
if(R.isCont($e2221022211)) {
var $ss2221422215 = {"from":L[883],
"go":function(and_DASH_oper_DASH_89022221) {
return $Hand_DASH_oper_DASH_1101222223(and_DASH_oper_DASH_89022221,if_helper723322222);
}};
$e2221022211.stack[R.EXN_STACKHEIGHT++] = $ss2221422215;
}
if(R.isPyretException($e2221022211)) {
$e2221022211.pyretStack.push(L[883]);
}
throw $e2221022211;
}
var $ret2221622217 = $Hand_DASH_oper_DASH_1101222223($z2221222213,if_helper723322222);
++R.GAS;
return $ret2221622217;
} else {
var $z2222622227 = D;
var $f2223222233 = function(_) {
return R.isFunction(if_helper723322222)?if_helper723322222.app((false)):R.ffi.throwNonFunApp(L[883],if_helper723322222,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2222622227 = $f2223222233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2223222233,
"from":L[883]});
}
} catch($e2222422225) {
if(R.isCont($e2222422225)) {
var $ss2222822229 = {"from":L[883],
"go":function(cont_tail_app723822234) {
return $Hcont_tail_app1101322235(cont_tail_app723822234);
}};
$e2222422225.stack[R.EXN_STACKHEIGHT++] = $ss2222822229;
}
if(R.isPyretException($e2222422225)) {
$e2222422225.pyretStack.push(L[883]);
}
throw $e2222422225;
}
var $ret2223022231 = $Hcont_tail_app1101322235($z2222622227);
++R.GAS;
return $ret2223022231;
}
} else {
var cont_tail_arg723522238 = R.throwNonBooleanOp(L[3585],("first"),("and"),and_DASH_oper_DASH_8895236);
if(--R.GAS > 0) {
$z2223622237 = R.isFunction(if_helper723322222)?if_helper723322222.app(cont_tail_arg723522238):R.ffi.throwNonFunApp(L[3585],if_helper723322222,[cont_tail_arg723522238]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper723322222)?if_helper723322222.app(cont_tail_arg723522238):R.ffi.throwNonFunApp(L[3585],if_helper723322222,[cont_tail_arg723522238]);
},
"from":L[3585]});
}
++R.GAS;
return $z2223622237;
}
};
var $Hand_DASH_oper_DASH_1101222223 = function(and_DASH_oper_DASH_89022221,if_helper723322222) {
var anf_if724222257 = R.isBoolean(and_DASH_oper_DASH_89022221);
if(R.isPyretTrue(anf_if724222257)) {
var $z2224422245 = D;
var $f2225022251 = function(_) {
return R.isFunction(if_helper723322222)?if_helper723322222.app(and_DASH_oper_DASH_89022221):R.ffi.throwNonFunApp(L[883],if_helper723322222,[and_DASH_oper_DASH_89022221]);
};
try {
if(--R.GAS > 0) {
$z2224422245 = $f2225022251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2225022251,
"from":L[883]});
}
} catch($e2224222243) {
if(R.isCont($e2224222243)) {
var $ss2224622247 = {"from":L[883],
"go":function(cont_tail_app724322252) {
return $Hcont_tail_app1101122253(cont_tail_app724322252);
}};
$e2224222243.stack[R.EXN_STACKHEIGHT++] = $ss2224622247;
}
if(R.isPyretException($e2224222243)) {
$e2224222243.pyretStack.push(L[883]);
}
throw $e2224222243;
}
var $ret2224822249 = $Hcont_tail_app1101122253($z2224422245);
++R.GAS;
return $ret2224822249;
} else {
var cont_tail_arg724022256 = R.throwNonBooleanOp(L[3586],("second"),("and"),and_DASH_oper_DASH_89022221);
if(--R.GAS > 0) {
$z2225422255 = R.isFunction(if_helper723322222)?if_helper723322222.app(cont_tail_arg724022256):R.ffi.throwNonFunApp(L[3586],if_helper723322222,[cont_tail_arg724022256]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper723322222)?if_helper723322222.app(cont_tail_arg724022256):R.ffi.throwNonFunApp(L[3586],if_helper723322222,[cont_tail_arg724022256]);
},
"from":L[3586]});
}
++R.GAS;
return $z2225422255;
}
};
var $Hcont_tail_app1101122253 = function(cont_tail_app724322252) {
return cont_tail_app724322252;
};
var $Hcont_tail_app1101322235 = function(cont_tail_app723822234) {
return cont_tail_app723822234;
};
var $Hann_DASH_check_DASH_temp110105254 = function(ann_DASH_check_DASH_temp72285253) {
return ann_DASH_check_DASH_temp72285253;
};
var $Hann_DASH_check_DASH_temp110095271 = function(ann_DASH_check_DASH_temp72255270) {
return ann_DASH_check_DASH_temp72255270;
};
var $Hann_DASH_check_DASH_temp110085312 = function(ann_DASH_check_DASH_temp72105311) {
return ann_DASH_check_DASH_temp72105311;
};
var $Hann_DASH_check_DASH_temp110075329 = function(ann_DASH_check_DASH_temp72075328) {
return ann_DASH_check_DASH_temp72075328;
};
var $Hann_DASH_check_DASH_temp110065345 = function(ann_DASH_check_DASH_temp72045344) {
return ann_DASH_check_DASH_temp72045344;
};
var $Hann_DASH_check_DASH_temp110055366 = function(ann_DASH_check_DASH_temp71965365) {
return ann_DASH_check_DASH_temp71965365;
};
var $Hann_DASH_check_DASH_temp110045381 = function(ann_DASH_check_DASH_temp71985380) {
return ann_DASH_check_DASH_temp71985380;
};
var $Hand_DASH_oper_DASH_110035398 = function(and_DASH_oper_DASH_8855396,args19185397,lists974,self19155395) {
var if_helper718122271 = R.makeFunction(function(if_helper_arg718222303) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[937],1,arguments);
}
var ann_DASH_check_DASH_temp717922304 = if_helper_arg718222303;
return ann_DASH_check_DASH_temp717922304;
});
var anf_if718522302 = R.isBoolean(and_DASH_oper_DASH_8855396);
if(R.isPyretTrue(anf_if718522302)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8855396)) {
var anf_fun718722268 = G(lists974,"all",L[3588]);
var anf_arg719022269 = R.makeFunction(function(recv_DASH_88722273) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3587],1,arguments);
}
var anf_fun718922284 = G(recv_DASH_88722273,"visit",L[3587]);
var $z2227622277 = D;
var $f2228222283 = function(_) {
return R.isFunction(anf_fun718922284)?anf_fun718922284.app(self19155395):R.ffi.throwNonFunApp(L[3587],anf_fun718922284,[self19155395]);
};
try {
if(--R.GAS > 0) {
$z2227622277 = $f2228222283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2228222283,
"from":L[3587]});
}
} catch($e2227422275) {
if(R.isCont($e2227422275)) {
var $ss2227822279 = {"from":L[3587],
"go":function(ann_DASH_check_DASH_temp718822285) {
return $Hann_DASH_check_DASH_temp1099922286(ann_DASH_check_DASH_temp718822285);
}};
$e2227422275.stack[R.EXN_STACKHEIGHT++] = $ss2227822279;
}
if(R.isPyretException($e2227422275)) {
$e2227422275.pyretStack.push(L[3587]);
}
throw $e2227422275;
}
var $ret2228022281 = $Hann_DASH_check_DASH_temp1099922286($z2227622277);
++R.GAS;
return $ret2228022281;
});
var $z2226022261 = D;
var $f2226622267 = function(_) {
return R.isFunction(anf_fun718722268)?anf_fun718722268.app(anf_arg719022269,args19185397):R.ffi.throwNonFunApp(L[937],anf_fun718722268,[anf_arg719022269,args19185397]);
};
try {
if(--R.GAS > 0) {
$z2226022261 = $f2226622267();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2226622267,
"from":L[937]});
}
} catch($e2225822259) {
if(R.isCont($e2225822259)) {
var $ss2226222263 = {"from":L[937],
"go":function(and_DASH_oper_DASH_88622270) {
return $Hand_DASH_oper_DASH_1100122272(and_DASH_oper_DASH_88622270,if_helper718122271);
}};
$e2225822259.stack[R.EXN_STACKHEIGHT++] = $ss2226222263;
}
if(R.isPyretException($e2225822259)) {
$e2225822259.pyretStack.push(L[937]);
}
throw $e2225822259;
}
var $ret2226422265 = $Hand_DASH_oper_DASH_1100122272($z2226022261,if_helper718122271);
++R.GAS;
return $ret2226422265;
} else {
var $z2228922290 = D;
var $f2229522296 = function(_) {
return R.isFunction(if_helper718122271)?if_helper718122271.app((false)):R.ffi.throwNonFunApp(L[937],if_helper718122271,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2228922290 = $f2229522296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2229522296,
"from":L[937]});
}
} catch($e2228722288) {
if(R.isCont($e2228722288)) {
var $ss2229122292 = {"from":L[937],
"go":function(cont_tail_app718622297) {
return $Hcont_tail_app1100222298(cont_tail_app718622297);
}};
$e2228722288.stack[R.EXN_STACKHEIGHT++] = $ss2229122292;
}
if(R.isPyretException($e2228722288)) {
$e2228722288.pyretStack.push(L[937]);
}
throw $e2228722288;
}
var $ret2229322294 = $Hcont_tail_app1100222298($z2228922290);
++R.GAS;
return $ret2229322294;
}
} else {
var cont_tail_arg718322301 = R.throwNonBooleanOp(L[3589],("first"),("and"),and_DASH_oper_DASH_8855396);
if(--R.GAS > 0) {
$z2229922300 = R.isFunction(if_helper718122271)?if_helper718122271.app(cont_tail_arg718322301):R.ffi.throwNonFunApp(L[3589],if_helper718122271,[cont_tail_arg718322301]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper718122271)?if_helper718122271.app(cont_tail_arg718322301):R.ffi.throwNonFunApp(L[3589],if_helper718122271,[cont_tail_arg718322301]);
},
"from":L[3589]});
}
++R.GAS;
return $z2229922300;
}
};
var $Hand_DASH_oper_DASH_1100122272 = function(and_DASH_oper_DASH_88622270,if_helper718122271) {
var anf_if719322320 = R.isBoolean(and_DASH_oper_DASH_88622270);
if(R.isPyretTrue(anf_if719322320)) {
var $z2230722308 = D;
var $f2231322314 = function(_) {
return R.isFunction(if_helper718122271)?if_helper718122271.app(and_DASH_oper_DASH_88622270):R.ffi.throwNonFunApp(L[937],if_helper718122271,[and_DASH_oper_DASH_88622270]);
};
try {
if(--R.GAS > 0) {
$z2230722308 = $f2231322314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2231322314,
"from":L[937]});
}
} catch($e2230522306) {
if(R.isCont($e2230522306)) {
var $ss2230922310 = {"from":L[937],
"go":function(cont_tail_app719422315) {
return $Hcont_tail_app1100022316(cont_tail_app719422315);
}};
$e2230522306.stack[R.EXN_STACKHEIGHT++] = $ss2230922310;
}
if(R.isPyretException($e2230522306)) {
$e2230522306.pyretStack.push(L[937]);
}
throw $e2230522306;
}
var $ret2231122312 = $Hcont_tail_app1100022316($z2230722308);
++R.GAS;
return $ret2231122312;
} else {
var cont_tail_arg719122319 = R.throwNonBooleanOp(L[3590],("second"),("and"),and_DASH_oper_DASH_88622270);
if(--R.GAS > 0) {
$z2231722318 = R.isFunction(if_helper718122271)?if_helper718122271.app(cont_tail_arg719122319):R.ffi.throwNonFunApp(L[3590],if_helper718122271,[cont_tail_arg719122319]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper718122271)?if_helper718122271.app(cont_tail_arg719122319):R.ffi.throwNonFunApp(L[3590],if_helper718122271,[cont_tail_arg719122319]);
},
"from":L[3590]});
}
++R.GAS;
return $z2231722318;
}
};
var $Hcont_tail_app1100022316 = function(cont_tail_app719422315) {
return cont_tail_app719422315;
};
var $Hann_DASH_check_DASH_temp1099922286 = function(ann_DASH_check_DASH_temp718822285) {
return ann_DASH_check_DASH_temp718822285;
};
var $Hcont_tail_app1100222298 = function(cont_tail_app718622297) {
return cont_tail_app718622297;
};
var $Hand_DASH_oper_DASH_109985415 = function(and_DASH_oper_DASH_8825413,lists974,self19105412,values19145414) {
var if_helper716422334 = R.makeFunction(function(if_helper_arg716522366) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[943],1,arguments);
}
var ann_DASH_check_DASH_temp716222367 = if_helper_arg716522366;
return ann_DASH_check_DASH_temp716222367;
});
var anf_if716822365 = R.isBoolean(and_DASH_oper_DASH_8825413);
if(R.isPyretTrue(anf_if716822365)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8825413)) {
var anf_fun717022331 = G(lists974,"all",L[3592]);
var anf_arg717322332 = R.makeFunction(function(recv_DASH_88422336) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3591],1,arguments);
}
var anf_fun717222347 = G(recv_DASH_88422336,"visit",L[3591]);
var $z2233922340 = D;
var $f2234522346 = function(_) {
return R.isFunction(anf_fun717222347)?anf_fun717222347.app(self19105412):R.ffi.throwNonFunApp(L[3591],anf_fun717222347,[self19105412]);
};
try {
if(--R.GAS > 0) {
$z2233922340 = $f2234522346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2234522346,
"from":L[3591]});
}
} catch($e2233722338) {
if(R.isCont($e2233722338)) {
var $ss2234122342 = {"from":L[3591],
"go":function(ann_DASH_check_DASH_temp717122348) {
return $Hann_DASH_check_DASH_temp1099422349(ann_DASH_check_DASH_temp717122348);
}};
$e2233722338.stack[R.EXN_STACKHEIGHT++] = $ss2234122342;
}
if(R.isPyretException($e2233722338)) {
$e2233722338.pyretStack.push(L[3591]);
}
throw $e2233722338;
}
var $ret2234322344 = $Hann_DASH_check_DASH_temp1099422349($z2233922340);
++R.GAS;
return $ret2234322344;
});
var $z2232322324 = D;
var $f2232922330 = function(_) {
return R.isFunction(anf_fun717022331)?anf_fun717022331.app(anf_arg717322332,values19145414):R.ffi.throwNonFunApp(L[943],anf_fun717022331,[anf_arg717322332,values19145414]);
};
try {
if(--R.GAS > 0) {
$z2232322324 = $f2232922330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2232922330,
"from":L[943]});
}
} catch($e2232122322) {
if(R.isCont($e2232122322)) {
var $ss2232522326 = {"from":L[943],
"go":function(and_DASH_oper_DASH_88322333) {
return $Hand_DASH_oper_DASH_1099622335(and_DASH_oper_DASH_88322333,if_helper716422334);
}};
$e2232122322.stack[R.EXN_STACKHEIGHT++] = $ss2232522326;
}
if(R.isPyretException($e2232122322)) {
$e2232122322.pyretStack.push(L[943]);
}
throw $e2232122322;
}
var $ret2232722328 = $Hand_DASH_oper_DASH_1099622335($z2232322324,if_helper716422334);
++R.GAS;
return $ret2232722328;
} else {
var $z2235222353 = D;
var $f2235822359 = function(_) {
return R.isFunction(if_helper716422334)?if_helper716422334.app((false)):R.ffi.throwNonFunApp(L[943],if_helper716422334,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2235222353 = $f2235822359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2235822359,
"from":L[943]});
}
} catch($e2235022351) {
if(R.isCont($e2235022351)) {
var $ss2235422355 = {"from":L[943],
"go":function(cont_tail_app716922360) {
return $Hcont_tail_app1099722361(cont_tail_app716922360);
}};
$e2235022351.stack[R.EXN_STACKHEIGHT++] = $ss2235422355;
}
if(R.isPyretException($e2235022351)) {
$e2235022351.pyretStack.push(L[943]);
}
throw $e2235022351;
}
var $ret2235622357 = $Hcont_tail_app1099722361($z2235222353);
++R.GAS;
return $ret2235622357;
}
} else {
var cont_tail_arg716622364 = R.throwNonBooleanOp(L[3593],("first"),("and"),and_DASH_oper_DASH_8825413);
if(--R.GAS > 0) {
$z2236222363 = R.isFunction(if_helper716422334)?if_helper716422334.app(cont_tail_arg716622364):R.ffi.throwNonFunApp(L[3593],if_helper716422334,[cont_tail_arg716622364]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper716422334)?if_helper716422334.app(cont_tail_arg716622364):R.ffi.throwNonFunApp(L[3593],if_helper716422334,[cont_tail_arg716622364]);
},
"from":L[3593]});
}
++R.GAS;
return $z2236222363;
}
};
var $Hand_DASH_oper_DASH_1099622335 = function(and_DASH_oper_DASH_88322333,if_helper716422334) {
var anf_if717622383 = R.isBoolean(and_DASH_oper_DASH_88322333);
if(R.isPyretTrue(anf_if717622383)) {
var $z2237022371 = D;
var $f2237622377 = function(_) {
return R.isFunction(if_helper716422334)?if_helper716422334.app(and_DASH_oper_DASH_88322333):R.ffi.throwNonFunApp(L[943],if_helper716422334,[and_DASH_oper_DASH_88322333]);
};
try {
if(--R.GAS > 0) {
$z2237022371 = $f2237622377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2237622377,
"from":L[943]});
}
} catch($e2236822369) {
if(R.isCont($e2236822369)) {
var $ss2237222373 = {"from":L[943],
"go":function(cont_tail_app717722378) {
return $Hcont_tail_app1099522379(cont_tail_app717722378);
}};
$e2236822369.stack[R.EXN_STACKHEIGHT++] = $ss2237222373;
}
if(R.isPyretException($e2236822369)) {
$e2236822369.pyretStack.push(L[943]);
}
throw $e2236822369;
}
var $ret2237422375 = $Hcont_tail_app1099522379($z2237022371);
++R.GAS;
return $ret2237422375;
} else {
var cont_tail_arg717422382 = R.throwNonBooleanOp(L[3594],("second"),("and"),and_DASH_oper_DASH_88322333);
if(--R.GAS > 0) {
$z2238022381 = R.isFunction(if_helper716422334)?if_helper716422334.app(cont_tail_arg717422382):R.ffi.throwNonFunApp(L[3594],if_helper716422334,[cont_tail_arg717422382]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper716422334)?if_helper716422334.app(cont_tail_arg717422382):R.ffi.throwNonFunApp(L[3594],if_helper716422334,[cont_tail_arg717422382]);
},
"from":L[3594]});
}
++R.GAS;
return $z2238022381;
}
};
var $Hcont_tail_app1099522379 = function(cont_tail_app717722378) {
return cont_tail_app717722378;
};
var $Hann_DASH_check_DASH_temp1099422349 = function(ann_DASH_check_DASH_temp717122348) {
return ann_DASH_check_DASH_temp717122348;
};
var $Hcont_tail_app1099722361 = function(cont_tail_app716922360) {
return cont_tail_app716922360;
};
var $Hand_DASH_oper_DASH_109935433 = function(and_DASH_oper_DASH_8805431,self19065430,typ19095432) {
var if_helper715022396 = R.makeFunction(function(if_helper_arg715122414) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[950],1,arguments);
}
var ann_DASH_check_DASH_temp714822415 = if_helper_arg715122414;
return ann_DASH_check_DASH_temp714822415;
});
var anf_if715422413 = R.isBoolean(and_DASH_oper_DASH_8805431);
if(R.isPyretTrue(anf_if715422413)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8805431)) {
var anf_fun715622394 = G(typ19095432,"visit",L[3595]);
var $z2238622387 = D;
var $f2239222393 = function(_) {
return R.isFunction(anf_fun715622394)?anf_fun715622394.app(self19065430):R.ffi.throwNonFunApp(L[950],anf_fun715622394,[self19065430]);
};
try {
if(--R.GAS > 0) {
$z2238622387 = $f2239222393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2239222393,
"from":L[950]});
}
} catch($e2238422385) {
if(R.isCont($e2238422385)) {
var $ss2238822389 = {"from":L[950],
"go":function(and_DASH_oper_DASH_88122395) {
return $Hand_DASH_oper_DASH_1099122397(and_DASH_oper_DASH_88122395,if_helper715022396);
}};
$e2238422385.stack[R.EXN_STACKHEIGHT++] = $ss2238822389;
}
if(R.isPyretException($e2238422385)) {
$e2238422385.pyretStack.push(L[950]);
}
throw $e2238422385;
}
var $ret2239022391 = $Hand_DASH_oper_DASH_1099122397($z2238622387,if_helper715022396);
++R.GAS;
return $ret2239022391;
} else {
var $z2240022401 = D;
var $f2240622407 = function(_) {
return R.isFunction(if_helper715022396)?if_helper715022396.app((false)):R.ffi.throwNonFunApp(L[950],if_helper715022396,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2240022401 = $f2240622407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2240622407,
"from":L[950]});
}
} catch($e2239822399) {
if(R.isCont($e2239822399)) {
var $ss2240222403 = {"from":L[950],
"go":function(cont_tail_app715522408) {
return $Hcont_tail_app1099222409(cont_tail_app715522408);
}};
$e2239822399.stack[R.EXN_STACKHEIGHT++] = $ss2240222403;
}
if(R.isPyretException($e2239822399)) {
$e2239822399.pyretStack.push(L[950]);
}
throw $e2239822399;
}
var $ret2240422405 = $Hcont_tail_app1099222409($z2240022401);
++R.GAS;
return $ret2240422405;
}
} else {
var cont_tail_arg715222412 = R.throwNonBooleanOp(L[3596],("first"),("and"),and_DASH_oper_DASH_8805431);
if(--R.GAS > 0) {
$z2241022411 = R.isFunction(if_helper715022396)?if_helper715022396.app(cont_tail_arg715222412):R.ffi.throwNonFunApp(L[3596],if_helper715022396,[cont_tail_arg715222412]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper715022396)?if_helper715022396.app(cont_tail_arg715222412):R.ffi.throwNonFunApp(L[3596],if_helper715022396,[cont_tail_arg715222412]);
},
"from":L[3596]});
}
++R.GAS;
return $z2241022411;
}
};
var $Hand_DASH_oper_DASH_1099122397 = function(and_DASH_oper_DASH_88122395,if_helper715022396) {
var anf_if715922431 = R.isBoolean(and_DASH_oper_DASH_88122395);
if(R.isPyretTrue(anf_if715922431)) {
var $z2241822419 = D;
var $f2242422425 = function(_) {
return R.isFunction(if_helper715022396)?if_helper715022396.app(and_DASH_oper_DASH_88122395):R.ffi.throwNonFunApp(L[950],if_helper715022396,[and_DASH_oper_DASH_88122395]);
};
try {
if(--R.GAS > 0) {
$z2241822419 = $f2242422425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2242422425,
"from":L[950]});
}
} catch($e2241622417) {
if(R.isCont($e2241622417)) {
var $ss2242022421 = {"from":L[950],
"go":function(cont_tail_app716022426) {
return $Hcont_tail_app1099022427(cont_tail_app716022426);
}};
$e2241622417.stack[R.EXN_STACKHEIGHT++] = $ss2242022421;
}
if(R.isPyretException($e2241622417)) {
$e2241622417.pyretStack.push(L[950]);
}
throw $e2241622417;
}
var $ret2242222423 = $Hcont_tail_app1099022427($z2241822419);
++R.GAS;
return $ret2242222423;
} else {
var cont_tail_arg715722430 = R.throwNonBooleanOp(L[3597],("second"),("and"),and_DASH_oper_DASH_88122395);
if(--R.GAS > 0) {
$z2242822429 = R.isFunction(if_helper715022396)?if_helper715022396.app(cont_tail_arg715722430):R.ffi.throwNonFunApp(L[3597],if_helper715022396,[cont_tail_arg715722430]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper715022396)?if_helper715022396.app(cont_tail_arg715722430):R.ffi.throwNonFunApp(L[3597],if_helper715022396,[cont_tail_arg715722430]);
},
"from":L[3597]});
}
++R.GAS;
return $z2242822429;
}
};
var $Hcont_tail_app1099022427 = function(cont_tail_app716022426) {
return cont_tail_app716022426;
};
var $Hcont_tail_app1099222409 = function(cont_tail_app715522408) {
return cont_tail_app715522408;
};
var $Hand_DASH_oper_DASH_109895450 = function(and_DASH_oper_DASH_8785448,self19025447,typ19055449) {
var if_helper713622444 = R.makeFunction(function(if_helper_arg713722462) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[956],1,arguments);
}
var ann_DASH_check_DASH_temp713422463 = if_helper_arg713722462;
return ann_DASH_check_DASH_temp713422463;
});
var anf_if714022461 = R.isBoolean(and_DASH_oper_DASH_8785448);
if(R.isPyretTrue(anf_if714022461)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8785448)) {
var anf_fun714222442 = G(typ19055449,"visit",L[3598]);
var $z2243422435 = D;
var $f2244022441 = function(_) {
return R.isFunction(anf_fun714222442)?anf_fun714222442.app(self19025447):R.ffi.throwNonFunApp(L[956],anf_fun714222442,[self19025447]);
};
try {
if(--R.GAS > 0) {
$z2243422435 = $f2244022441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2244022441,
"from":L[956]});
}
} catch($e2243222433) {
if(R.isCont($e2243222433)) {
var $ss2243622437 = {"from":L[956],
"go":function(and_DASH_oper_DASH_87922443) {
return $Hand_DASH_oper_DASH_1098722445(and_DASH_oper_DASH_87922443,if_helper713622444);
}};
$e2243222433.stack[R.EXN_STACKHEIGHT++] = $ss2243622437;
}
if(R.isPyretException($e2243222433)) {
$e2243222433.pyretStack.push(L[956]);
}
throw $e2243222433;
}
var $ret2243822439 = $Hand_DASH_oper_DASH_1098722445($z2243422435,if_helper713622444);
++R.GAS;
return $ret2243822439;
} else {
var $z2244822449 = D;
var $f2245422455 = function(_) {
return R.isFunction(if_helper713622444)?if_helper713622444.app((false)):R.ffi.throwNonFunApp(L[956],if_helper713622444,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2244822449 = $f2245422455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2245422455,
"from":L[956]});
}
} catch($e2244622447) {
if(R.isCont($e2244622447)) {
var $ss2245022451 = {"from":L[956],
"go":function(cont_tail_app714122456) {
return $Hcont_tail_app1098822457(cont_tail_app714122456);
}};
$e2244622447.stack[R.EXN_STACKHEIGHT++] = $ss2245022451;
}
if(R.isPyretException($e2244622447)) {
$e2244622447.pyretStack.push(L[956]);
}
throw $e2244622447;
}
var $ret2245222453 = $Hcont_tail_app1098822457($z2244822449);
++R.GAS;
return $ret2245222453;
}
} else {
var cont_tail_arg713822460 = R.throwNonBooleanOp(L[3599],("first"),("and"),and_DASH_oper_DASH_8785448);
if(--R.GAS > 0) {
$z2245822459 = R.isFunction(if_helper713622444)?if_helper713622444.app(cont_tail_arg713822460):R.ffi.throwNonFunApp(L[3599],if_helper713622444,[cont_tail_arg713822460]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper713622444)?if_helper713622444.app(cont_tail_arg713822460):R.ffi.throwNonFunApp(L[3599],if_helper713622444,[cont_tail_arg713822460]);
},
"from":L[3599]});
}
++R.GAS;
return $z2245822459;
}
};
var $Hand_DASH_oper_DASH_1098722445 = function(and_DASH_oper_DASH_87922443,if_helper713622444) {
var anf_if714522479 = R.isBoolean(and_DASH_oper_DASH_87922443);
if(R.isPyretTrue(anf_if714522479)) {
var $z2246622467 = D;
var $f2247222473 = function(_) {
return R.isFunction(if_helper713622444)?if_helper713622444.app(and_DASH_oper_DASH_87922443):R.ffi.throwNonFunApp(L[956],if_helper713622444,[and_DASH_oper_DASH_87922443]);
};
try {
if(--R.GAS > 0) {
$z2246622467 = $f2247222473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2247222473,
"from":L[956]});
}
} catch($e2246422465) {
if(R.isCont($e2246422465)) {
var $ss2246822469 = {"from":L[956],
"go":function(cont_tail_app714622474) {
return $Hcont_tail_app1098622475(cont_tail_app714622474);
}};
$e2246422465.stack[R.EXN_STACKHEIGHT++] = $ss2246822469;
}
if(R.isPyretException($e2246422465)) {
$e2246422465.pyretStack.push(L[956]);
}
throw $e2246422465;
}
var $ret2247022471 = $Hcont_tail_app1098622475($z2246622467);
++R.GAS;
return $ret2247022471;
} else {
var cont_tail_arg714322478 = R.throwNonBooleanOp(L[3600],("second"),("and"),and_DASH_oper_DASH_87922443);
if(--R.GAS > 0) {
$z2247622477 = R.isFunction(if_helper713622444)?if_helper713622444.app(cont_tail_arg714322478):R.ffi.throwNonFunApp(L[3600],if_helper713622444,[cont_tail_arg714322478]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper713622444)?if_helper713622444.app(cont_tail_arg714322478):R.ffi.throwNonFunApp(L[3600],if_helper713622444,[cont_tail_arg714322478]);
},
"from":L[3600]});
}
++R.GAS;
return $z2247622477;
}
};
var $Hcont_tail_app1098622475 = function(cont_tail_app714622474) {
return cont_tail_app714622474;
};
var $Hcont_tail_app1098822457 = function(cont_tail_app714122456) {
return cont_tail_app714122456;
};
var $Hann_DASH_check_DASH_temp109855467 = function(ann_DASH_check_DASH_temp71285466) {
return ann_DASH_check_DASH_temp71285466;
};
var $Hann_DASH_check_DASH_temp109845482 = function(ann_DASH_check_DASH_temp71305481) {
return ann_DASH_check_DASH_temp71305481;
};
var $Hann_DASH_check_DASH_temp109835498 = function(ann_DASH_check_DASH_temp71225497) {
return ann_DASH_check_DASH_temp71225497;
};
var $Hann_DASH_check_DASH_temp109825513 = function(ann_DASH_check_DASH_temp71245512) {
return ann_DASH_check_DASH_temp71245512;
};
var $Hand_DASH_oper_DASH_109815529 = function(and_DASH_oper_DASH_8735527,fields18955528,lists974,self18925526) {
var if_helper710722493 = R.makeFunction(function(if_helper_arg710822525) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[972],1,arguments);
}
var ann_DASH_check_DASH_temp710522526 = if_helper_arg710822525;
return ann_DASH_check_DASH_temp710522526;
});
var anf_if711122524 = R.isBoolean(and_DASH_oper_DASH_8735527);
if(R.isPyretTrue(anf_if711122524)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8735527)) {
var anf_fun711322490 = G(lists974,"all",L[3602]);
var anf_arg711622491 = R.makeFunction(function(recv_DASH_87522495) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3601],1,arguments);
}
var anf_fun711522506 = G(recv_DASH_87522495,"visit",L[3601]);
var $z2249822499 = D;
var $f2250422505 = function(_) {
return R.isFunction(anf_fun711522506)?anf_fun711522506.app(self18925526):R.ffi.throwNonFunApp(L[3601],anf_fun711522506,[self18925526]);
};
try {
if(--R.GAS > 0) {
$z2249822499 = $f2250422505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2250422505,
"from":L[3601]});
}
} catch($e2249622497) {
if(R.isCont($e2249622497)) {
var $ss2250022501 = {"from":L[3601],
"go":function(ann_DASH_check_DASH_temp711422507) {
return $Hann_DASH_check_DASH_temp1097722508(ann_DASH_check_DASH_temp711422507);
}};
$e2249622497.stack[R.EXN_STACKHEIGHT++] = $ss2250022501;
}
if(R.isPyretException($e2249622497)) {
$e2249622497.pyretStack.push(L[3601]);
}
throw $e2249622497;
}
var $ret2250222503 = $Hann_DASH_check_DASH_temp1097722508($z2249822499);
++R.GAS;
return $ret2250222503;
});
var $z2248222483 = D;
var $f2248822489 = function(_) {
return R.isFunction(anf_fun711322490)?anf_fun711322490.app(anf_arg711622491,fields18955528):R.ffi.throwNonFunApp(L[972],anf_fun711322490,[anf_arg711622491,fields18955528]);
};
try {
if(--R.GAS > 0) {
$z2248222483 = $f2248822489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2248822489,
"from":L[972]});
}
} catch($e2248022481) {
if(R.isCont($e2248022481)) {
var $ss2248422485 = {"from":L[972],
"go":function(and_DASH_oper_DASH_87422492) {
return $Hand_DASH_oper_DASH_1097922494(and_DASH_oper_DASH_87422492,if_helper710722493);
}};
$e2248022481.stack[R.EXN_STACKHEIGHT++] = $ss2248422485;
}
if(R.isPyretException($e2248022481)) {
$e2248022481.pyretStack.push(L[972]);
}
throw $e2248022481;
}
var $ret2248622487 = $Hand_DASH_oper_DASH_1097922494($z2248222483,if_helper710722493);
++R.GAS;
return $ret2248622487;
} else {
var $z2251122512 = D;
var $f2251722518 = function(_) {
return R.isFunction(if_helper710722493)?if_helper710722493.app((false)):R.ffi.throwNonFunApp(L[972],if_helper710722493,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2251122512 = $f2251722518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2251722518,
"from":L[972]});
}
} catch($e2250922510) {
if(R.isCont($e2250922510)) {
var $ss2251322514 = {"from":L[972],
"go":function(cont_tail_app711222519) {
return $Hcont_tail_app1098022520(cont_tail_app711222519);
}};
$e2250922510.stack[R.EXN_STACKHEIGHT++] = $ss2251322514;
}
if(R.isPyretException($e2250922510)) {
$e2250922510.pyretStack.push(L[972]);
}
throw $e2250922510;
}
var $ret2251522516 = $Hcont_tail_app1098022520($z2251122512);
++R.GAS;
return $ret2251522516;
}
} else {
var cont_tail_arg710922523 = R.throwNonBooleanOp(L[3603],("first"),("and"),and_DASH_oper_DASH_8735527);
if(--R.GAS > 0) {
$z2252122522 = R.isFunction(if_helper710722493)?if_helper710722493.app(cont_tail_arg710922523):R.ffi.throwNonFunApp(L[3603],if_helper710722493,[cont_tail_arg710922523]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper710722493)?if_helper710722493.app(cont_tail_arg710922523):R.ffi.throwNonFunApp(L[3603],if_helper710722493,[cont_tail_arg710922523]);
},
"from":L[3603]});
}
++R.GAS;
return $z2252122522;
}
};
var $Hand_DASH_oper_DASH_1097922494 = function(and_DASH_oper_DASH_87422492,if_helper710722493) {
var anf_if711922542 = R.isBoolean(and_DASH_oper_DASH_87422492);
if(R.isPyretTrue(anf_if711922542)) {
var $z2252922530 = D;
var $f2253522536 = function(_) {
return R.isFunction(if_helper710722493)?if_helper710722493.app(and_DASH_oper_DASH_87422492):R.ffi.throwNonFunApp(L[972],if_helper710722493,[and_DASH_oper_DASH_87422492]);
};
try {
if(--R.GAS > 0) {
$z2252922530 = $f2253522536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2253522536,
"from":L[972]});
}
} catch($e2252722528) {
if(R.isCont($e2252722528)) {
var $ss2253122532 = {"from":L[972],
"go":function(cont_tail_app712022537) {
return $Hcont_tail_app1097822538(cont_tail_app712022537);
}};
$e2252722528.stack[R.EXN_STACKHEIGHT++] = $ss2253122532;
}
if(R.isPyretException($e2252722528)) {
$e2252722528.pyretStack.push(L[972]);
}
throw $e2252722528;
}
var $ret2253322534 = $Hcont_tail_app1097822538($z2252922530);
++R.GAS;
return $ret2253322534;
} else {
var cont_tail_arg711722541 = R.throwNonBooleanOp(L[3604],("second"),("and"),and_DASH_oper_DASH_87422492);
if(--R.GAS > 0) {
$z2253922540 = R.isFunction(if_helper710722493)?if_helper710722493.app(cont_tail_arg711722541):R.ffi.throwNonFunApp(L[3604],if_helper710722493,[cont_tail_arg711722541]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper710722493)?if_helper710722493.app(cont_tail_arg711722541):R.ffi.throwNonFunApp(L[3604],if_helper710722493,[cont_tail_arg711722541]);
},
"from":L[3604]});
}
++R.GAS;
return $z2253922540;
}
};
var $Hcont_tail_app1097822538 = function(cont_tail_app712022537) {
return cont_tail_app712022537;
};
var $Hann_DASH_check_DASH_temp1097722508 = function(ann_DASH_check_DASH_temp711422507) {
return ann_DASH_check_DASH_temp711422507;
};
var $Hcont_tail_app1098022520 = function(cont_tail_app711222519) {
return cont_tail_app711222519;
};
var $Hand_DASH_oper_DASH_109765546 = function(and_DASH_oper_DASH_8705544,fields18915545,lists974,self18885543) {
var if_helper709022556 = R.makeFunction(function(if_helper_arg709122588) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[978],1,arguments);
}
var ann_DASH_check_DASH_temp708822589 = if_helper_arg709122588;
return ann_DASH_check_DASH_temp708822589;
});
var anf_if709422587 = R.isBoolean(and_DASH_oper_DASH_8705544);
if(R.isPyretTrue(anf_if709422587)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8705544)) {
var anf_fun709622553 = G(lists974,"all",L[3606]);
var anf_arg709922554 = R.makeFunction(function(recv_DASH_87222558) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3605],1,arguments);
}
var anf_fun709822569 = G(recv_DASH_87222558,"visit",L[3605]);
var $z2256122562 = D;
var $f2256722568 = function(_) {
return R.isFunction(anf_fun709822569)?anf_fun709822569.app(self18885543):R.ffi.throwNonFunApp(L[3605],anf_fun709822569,[self18885543]);
};
try {
if(--R.GAS > 0) {
$z2256122562 = $f2256722568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2256722568,
"from":L[3605]});
}
} catch($e2255922560) {
if(R.isCont($e2255922560)) {
var $ss2256322564 = {"from":L[3605],
"go":function(ann_DASH_check_DASH_temp709722570) {
return $Hann_DASH_check_DASH_temp1097222571(ann_DASH_check_DASH_temp709722570);
}};
$e2255922560.stack[R.EXN_STACKHEIGHT++] = $ss2256322564;
}
if(R.isPyretException($e2255922560)) {
$e2255922560.pyretStack.push(L[3605]);
}
throw $e2255922560;
}
var $ret2256522566 = $Hann_DASH_check_DASH_temp1097222571($z2256122562);
++R.GAS;
return $ret2256522566;
});
var $z2254522546 = D;
var $f2255122552 = function(_) {
return R.isFunction(anf_fun709622553)?anf_fun709622553.app(anf_arg709922554,fields18915545):R.ffi.throwNonFunApp(L[978],anf_fun709622553,[anf_arg709922554,fields18915545]);
};
try {
if(--R.GAS > 0) {
$z2254522546 = $f2255122552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2255122552,
"from":L[978]});
}
} catch($e2254322544) {
if(R.isCont($e2254322544)) {
var $ss2254722548 = {"from":L[978],
"go":function(and_DASH_oper_DASH_87122555) {
return $Hand_DASH_oper_DASH_1097422557(and_DASH_oper_DASH_87122555,if_helper709022556);
}};
$e2254322544.stack[R.EXN_STACKHEIGHT++] = $ss2254722548;
}
if(R.isPyretException($e2254322544)) {
$e2254322544.pyretStack.push(L[978]);
}
throw $e2254322544;
}
var $ret2254922550 = $Hand_DASH_oper_DASH_1097422557($z2254522546,if_helper709022556);
++R.GAS;
return $ret2254922550;
} else {
var $z2257422575 = D;
var $f2258022581 = function(_) {
return R.isFunction(if_helper709022556)?if_helper709022556.app((false)):R.ffi.throwNonFunApp(L[978],if_helper709022556,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2257422575 = $f2258022581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2258022581,
"from":L[978]});
}
} catch($e2257222573) {
if(R.isCont($e2257222573)) {
var $ss2257622577 = {"from":L[978],
"go":function(cont_tail_app709522582) {
return $Hcont_tail_app1097522583(cont_tail_app709522582);
}};
$e2257222573.stack[R.EXN_STACKHEIGHT++] = $ss2257622577;
}
if(R.isPyretException($e2257222573)) {
$e2257222573.pyretStack.push(L[978]);
}
throw $e2257222573;
}
var $ret2257822579 = $Hcont_tail_app1097522583($z2257422575);
++R.GAS;
return $ret2257822579;
}
} else {
var cont_tail_arg709222586 = R.throwNonBooleanOp(L[3607],("first"),("and"),and_DASH_oper_DASH_8705544);
if(--R.GAS > 0) {
$z2258422585 = R.isFunction(if_helper709022556)?if_helper709022556.app(cont_tail_arg709222586):R.ffi.throwNonFunApp(L[3607],if_helper709022556,[cont_tail_arg709222586]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper709022556)?if_helper709022556.app(cont_tail_arg709222586):R.ffi.throwNonFunApp(L[3607],if_helper709022556,[cont_tail_arg709222586]);
},
"from":L[3607]});
}
++R.GAS;
return $z2258422585;
}
};
var $Hand_DASH_oper_DASH_1097422557 = function(and_DASH_oper_DASH_87122555,if_helper709022556) {
var anf_if710222605 = R.isBoolean(and_DASH_oper_DASH_87122555);
if(R.isPyretTrue(anf_if710222605)) {
var $z2259222593 = D;
var $f2259822599 = function(_) {
return R.isFunction(if_helper709022556)?if_helper709022556.app(and_DASH_oper_DASH_87122555):R.ffi.throwNonFunApp(L[978],if_helper709022556,[and_DASH_oper_DASH_87122555]);
};
try {
if(--R.GAS > 0) {
$z2259222593 = $f2259822599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2259822599,
"from":L[978]});
}
} catch($e2259022591) {
if(R.isCont($e2259022591)) {
var $ss2259422595 = {"from":L[978],
"go":function(cont_tail_app710322600) {
return $Hcont_tail_app1097322601(cont_tail_app710322600);
}};
$e2259022591.stack[R.EXN_STACKHEIGHT++] = $ss2259422595;
}
if(R.isPyretException($e2259022591)) {
$e2259022591.pyretStack.push(L[978]);
}
throw $e2259022591;
}
var $ret2259622597 = $Hcont_tail_app1097322601($z2259222593);
++R.GAS;
return $ret2259622597;
} else {
var cont_tail_arg710022604 = R.throwNonBooleanOp(L[3608],("second"),("and"),and_DASH_oper_DASH_87122555);
if(--R.GAS > 0) {
$z2260222603 = R.isFunction(if_helper709022556)?if_helper709022556.app(cont_tail_arg710022604):R.ffi.throwNonFunApp(L[3608],if_helper709022556,[cont_tail_arg710022604]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper709022556)?if_helper709022556.app(cont_tail_arg710022604):R.ffi.throwNonFunApp(L[3608],if_helper709022556,[cont_tail_arg710022604]);
},
"from":L[3608]});
}
++R.GAS;
return $z2260222603;
}
};
var $Hcont_tail_app1097322601 = function(cont_tail_app710322600) {
return cont_tail_app710322600;
};
var $Hann_DASH_check_DASH_temp1097222571 = function(ann_DASH_check_DASH_temp709722570) {
return ann_DASH_check_DASH_temp709722570;
};
var $Hcont_tail_app1097522583 = function(cont_tail_app709522582) {
return cont_tail_app709522582;
};
var $Hand_DASH_oper_DASH_109715567 = function(and_DASH_oper_DASH_8655562,_check18875563,ann18845564,body18865565,self18815566) {
var if_helper706622618 = R.makeFunction(function(if_helper_arg706722636) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[984],1,arguments);
}
var ann_DASH_check_DASH_temp706122637 = if_helper_arg706722636;
return ann_DASH_check_DASH_temp706122637;
});
var anf_if707022635 = R.isBoolean(and_DASH_oper_DASH_8655562);
if(R.isPyretTrue(anf_if707022635)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8655562)) {
var anf_fun707222616 = G(ann18845564,"visit",L[3609]);
var $z2260822609 = D;
var $f2261422615 = function(_) {
return R.isFunction(anf_fun707222616)?anf_fun707222616.app(self18815566):R.ffi.throwNonFunApp(L[984],anf_fun707222616,[self18815566]);
};
try {
if(--R.GAS > 0) {
$z2260822609 = $f2261422615();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2261422615,
"from":L[984]});
}
} catch($e2260622607) {
if(R.isCont($e2260622607)) {
var $ss2261022611 = {"from":L[984],
"go":function(and_DASH_oper_DASH_86722617) {
return $Hand_DASH_oper_DASH_1096922619(and_DASH_oper_DASH_86722617,_check18875563,body18865565,if_helper706622618,self18815566);
}};
$e2260622607.stack[R.EXN_STACKHEIGHT++] = $ss2261022611;
}
if(R.isPyretException($e2260622607)) {
$e2260622607.pyretStack.push(L[984]);
}
throw $e2260622607;
}
var $ret2261222613 = $Hand_DASH_oper_DASH_1096922619($z2260822609,_check18875563,body18865565,if_helper706622618,self18815566);
++R.GAS;
return $ret2261222613;
} else {
var $z2262222623 = D;
var $f2262822629 = function(_) {
return R.isFunction(if_helper706622618)?if_helper706622618.app((false)):R.ffi.throwNonFunApp(L[984],if_helper706622618,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2262222623 = $f2262822629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2262822629,
"from":L[984]});
}
} catch($e2262022621) {
if(R.isCont($e2262022621)) {
var $ss2262422625 = {"from":L[984],
"go":function(cont_tail_app707122630) {
return $Hcont_tail_app1097022631(cont_tail_app707122630);
}};
$e2262022621.stack[R.EXN_STACKHEIGHT++] = $ss2262422625;
}
if(R.isPyretException($e2262022621)) {
$e2262022621.pyretStack.push(L[984]);
}
throw $e2262022621;
}
var $ret2262622627 = $Hcont_tail_app1097022631($z2262222623);
++R.GAS;
return $ret2262622627;
}
} else {
var cont_tail_arg706822634 = R.throwNonBooleanOp(L[3610],("first"),("and"),and_DASH_oper_DASH_8655562);
if(--R.GAS > 0) {
$z2263222633 = R.isFunction(if_helper706622618)?if_helper706622618.app(cont_tail_arg706822634):R.ffi.throwNonFunApp(L[3610],if_helper706622618,[cont_tail_arg706822634]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper706622618)?if_helper706622618.app(cont_tail_arg706822634):R.ffi.throwNonFunApp(L[3610],if_helper706622618,[cont_tail_arg706822634]);
},
"from":L[3610]});
}
++R.GAS;
return $z2263222633;
}
};
var $Hand_DASH_oper_DASH_1096922619 = function(and_DASH_oper_DASH_86722617,_check18875563,body18865565,if_helper706622618,self18815566) {
var anf_if707522666 = R.isBoolean(and_DASH_oper_DASH_86722617);
if(R.isPyretTrue(anf_if707522666)) {
if(R.isPyretTrue(and_DASH_oper_DASH_86722617)) {
var anf_fun707722648 = G(body18865565,"visit",L[3611]);
var $z2264022641 = D;
var $f2264622647 = function(_) {
return R.isFunction(anf_fun707722648)?anf_fun707722648.app(self18815566):R.ffi.throwNonFunApp(L[984],anf_fun707722648,[self18815566]);
};
try {
if(--R.GAS > 0) {
$z2264022641 = $f2264622647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2264622647,
"from":L[984]});
}
} catch($e2263822639) {
if(R.isCont($e2263822639)) {
var $ss2264222643 = {"from":L[984],
"go":function(and_DASH_oper_DASH_86822649) {
return $Hand_DASH_oper_DASH_1096722650(and_DASH_oper_DASH_86822649,_check18875563,if_helper706622618,self18815566);
}};
$e2263822639.stack[R.EXN_STACKHEIGHT++] = $ss2264222643;
}
if(R.isPyretException($e2263822639)) {
$e2263822639.pyretStack.push(L[984]);
}
throw $e2263822639;
}
var $ret2264422645 = $Hand_DASH_oper_DASH_1096722650($z2264022641,_check18875563,if_helper706622618,self18815566);
++R.GAS;
return $ret2264422645;
} else {
var $z2265322654 = D;
var $f2265922660 = function(_) {
return R.isFunction(if_helper706622618)?if_helper706622618.app((false)):R.ffi.throwNonFunApp(L[984],if_helper706622618,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2265322654 = $f2265922660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2265922660,
"from":L[984]});
}
} catch($e2265122652) {
if(R.isCont($e2265122652)) {
var $ss2265522656 = {"from":L[984],
"go":function(cont_tail_app707622661) {
return $Hcont_tail_app1096822662(cont_tail_app707622661);
}};
$e2265122652.stack[R.EXN_STACKHEIGHT++] = $ss2265522656;
}
if(R.isPyretException($e2265122652)) {
$e2265122652.pyretStack.push(L[984]);
}
throw $e2265122652;
}
var $ret2265722658 = $Hcont_tail_app1096822662($z2265322654);
++R.GAS;
return $ret2265722658;
}
} else {
var cont_tail_arg707322665 = R.throwNonBooleanOp(L[3612],("first"),("and"),and_DASH_oper_DASH_86722617);
if(--R.GAS > 0) {
$z2266322664 = R.isFunction(if_helper706622618)?if_helper706622618.app(cont_tail_arg707322665):R.ffi.throwNonFunApp(L[3612],if_helper706622618,[cont_tail_arg707322665]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper706622618)?if_helper706622618.app(cont_tail_arg707322665):R.ffi.throwNonFunApp(L[3612],if_helper706622618,[cont_tail_arg707322665]);
},
"from":L[3612]});
}
++R.GAS;
return $z2266322664;
}
};
var $Hand_DASH_oper_DASH_1096722650 = function(and_DASH_oper_DASH_86822649,_check18875563,if_helper706622618,self18815566) {
var anf_if708022695 = R.isBoolean(and_DASH_oper_DASH_86822649);
if(R.isPyretTrue(anf_if708022695)) {
if(R.isPyretTrue(and_DASH_oper_DASH_86822649)) {
var anf_fun708222677 = G(self18815566,"option",L[3613]);
var $z2266922670 = D;
var $f2267522676 = function(_) {
return R.isFunction(anf_fun708222677)?anf_fun708222677.app(_check18875563):R.ffi.throwNonFunApp(L[984],anf_fun708222677,[_check18875563]);
};
try {
if(--R.GAS > 0) {
$z2266922670 = $f2267522676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2267522676,
"from":L[984]});
}
} catch($e2266722668) {
if(R.isCont($e2266722668)) {
var $ss2267122672 = {"from":L[984],
"go":function(and_DASH_oper_DASH_86922678) {
return $Hand_DASH_oper_DASH_1096522679(and_DASH_oper_DASH_86922678,if_helper706622618);
}};
$e2266722668.stack[R.EXN_STACKHEIGHT++] = $ss2267122672;
}
if(R.isPyretException($e2266722668)) {
$e2266722668.pyretStack.push(L[984]);
}
throw $e2266722668;
}
var $ret2267322674 = $Hand_DASH_oper_DASH_1096522679($z2266922670,if_helper706622618);
++R.GAS;
return $ret2267322674;
} else {
var $z2268222683 = D;
var $f2268822689 = function(_) {
return R.isFunction(if_helper706622618)?if_helper706622618.app((false)):R.ffi.throwNonFunApp(L[984],if_helper706622618,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2268222683 = $f2268822689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2268822689,
"from":L[984]});
}
} catch($e2268022681) {
if(R.isCont($e2268022681)) {
var $ss2268422685 = {"from":L[984],
"go":function(cont_tail_app708122690) {
return $Hcont_tail_app1096622691(cont_tail_app708122690);
}};
$e2268022681.stack[R.EXN_STACKHEIGHT++] = $ss2268422685;
}
if(R.isPyretException($e2268022681)) {
$e2268022681.pyretStack.push(L[984]);
}
throw $e2268022681;
}
var $ret2268622687 = $Hcont_tail_app1096622691($z2268222683);
++R.GAS;
return $ret2268622687;
}
} else {
var cont_tail_arg707822694 = R.throwNonBooleanOp(L[3614],("first"),("and"),and_DASH_oper_DASH_86822649);
if(--R.GAS > 0) {
$z2269222693 = R.isFunction(if_helper706622618)?if_helper706622618.app(cont_tail_arg707822694):R.ffi.throwNonFunApp(L[3614],if_helper706622618,[cont_tail_arg707822694]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper706622618)?if_helper706622618.app(cont_tail_arg707822694):R.ffi.throwNonFunApp(L[3614],if_helper706622618,[cont_tail_arg707822694]);
},
"from":L[3614]});
}
++R.GAS;
return $z2269222693;
}
};
var $Hand_DASH_oper_DASH_1096522679 = function(and_DASH_oper_DASH_86922678,if_helper706622618) {
var anf_if708522711 = R.isBoolean(and_DASH_oper_DASH_86922678);
if(R.isPyretTrue(anf_if708522711)) {
var $z2269822699 = D;
var $f2270422705 = function(_) {
return R.isFunction(if_helper706622618)?if_helper706622618.app(and_DASH_oper_DASH_86922678):R.ffi.throwNonFunApp(L[984],if_helper706622618,[and_DASH_oper_DASH_86922678]);
};
try {
if(--R.GAS > 0) {
$z2269822699 = $f2270422705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2270422705,
"from":L[984]});
}
} catch($e2269622697) {
if(R.isCont($e2269622697)) {
var $ss2270022701 = {"from":L[984],
"go":function(cont_tail_app708622706) {
return $Hcont_tail_app1096422707(cont_tail_app708622706);
}};
$e2269622697.stack[R.EXN_STACKHEIGHT++] = $ss2270022701;
}
if(R.isPyretException($e2269622697)) {
$e2269622697.pyretStack.push(L[984]);
}
throw $e2269622697;
}
var $ret2270222703 = $Hcont_tail_app1096422707($z2269822699);
++R.GAS;
return $ret2270222703;
} else {
var cont_tail_arg708322710 = R.throwNonBooleanOp(L[3615],("second"),("and"),and_DASH_oper_DASH_86922678);
if(--R.GAS > 0) {
$z2270822709 = R.isFunction(if_helper706622618)?if_helper706622618.app(cont_tail_arg708322710):R.ffi.throwNonFunApp(L[3615],if_helper706622618,[cont_tail_arg708322710]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper706622618)?if_helper706622618.app(cont_tail_arg708322710):R.ffi.throwNonFunApp(L[3615],if_helper706622618,[cont_tail_arg708322710]);
},
"from":L[3615]});
}
++R.GAS;
return $z2270822709;
}
};
var $Hcont_tail_app1096422707 = function(cont_tail_app708622706) {
return cont_tail_app708622706;
};
var $Hcont_tail_app1096622691 = function(cont_tail_app708122690) {
return cont_tail_app708122690;
};
var $Hcont_tail_app1096822662 = function(cont_tail_app707622661) {
return cont_tail_app707622661;
};
var $Hcont_tail_app1097022631 = function(cont_tail_app707122630) {
return cont_tail_app707122630;
};
var $Hann_DASH_check_DASH_temp109635581 = function(ann_DASH_check_DASH_temp70635580) {
return ann_DASH_check_DASH_temp70635580;
};
var $Hand_DASH_oper_DASH_109625603 = function(and_DASH_oper_DASH_8585597,_check18805598,ann18775599,args18765600,body18795601,lists974,self18735602) {
var if_helper703122725 = R.makeFunction(function(if_helper_arg703222757) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[994],1,arguments);
}
var ann_DASH_check_DASH_temp702622758 = if_helper_arg703222757;
return ann_DASH_check_DASH_temp702622758;
});
var anf_if703522756 = R.isBoolean(and_DASH_oper_DASH_8585597);
if(R.isPyretTrue(anf_if703522756)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8585597)) {
var anf_fun703722722 = G(lists974,"all",L[3617]);
var anf_arg704022723 = R.makeFunction(function(recv_DASH_86122727) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3616],1,arguments);
}
var anf_fun703922738 = G(recv_DASH_86122727,"visit",L[3616]);
var $z2273022731 = D;
var $f2273622737 = function(_) {
return R.isFunction(anf_fun703922738)?anf_fun703922738.app(self18735602):R.ffi.throwNonFunApp(L[3616],anf_fun703922738,[self18735602]);
};
try {
if(--R.GAS > 0) {
$z2273022731 = $f2273622737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2273622737,
"from":L[3616]});
}
} catch($e2272822729) {
if(R.isCont($e2272822729)) {
var $ss2273222733 = {"from":L[3616],
"go":function(ann_DASH_check_DASH_temp703822739) {
return $Hann_DASH_check_DASH_temp1095222740(ann_DASH_check_DASH_temp703822739);
}};
$e2272822729.stack[R.EXN_STACKHEIGHT++] = $ss2273222733;
}
if(R.isPyretException($e2272822729)) {
$e2272822729.pyretStack.push(L[3616]);
}
throw $e2272822729;
}
var $ret2273422735 = $Hann_DASH_check_DASH_temp1095222740($z2273022731);
++R.GAS;
return $ret2273422735;
});
var $z2271422715 = D;
var $f2272022721 = function(_) {
return R.isFunction(anf_fun703722722)?anf_fun703722722.app(anf_arg704022723,args18765600):R.ffi.throwNonFunApp(L[994],anf_fun703722722,[anf_arg704022723,args18765600]);
};
try {
if(--R.GAS > 0) {
$z2271422715 = $f2272022721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2272022721,
"from":L[994]});
}
} catch($e2271222713) {
if(R.isCont($e2271222713)) {
var $ss2271622717 = {"from":L[994],
"go":function(and_DASH_oper_DASH_86022724) {
return $Hand_DASH_oper_DASH_1096022726(and_DASH_oper_DASH_86022724,_check18805598,ann18775599,body18795601,if_helper703122725,self18735602);
}};
$e2271222713.stack[R.EXN_STACKHEIGHT++] = $ss2271622717;
}
if(R.isPyretException($e2271222713)) {
$e2271222713.pyretStack.push(L[994]);
}
throw $e2271222713;
}
var $ret2271822719 = $Hand_DASH_oper_DASH_1096022726($z2271422715,_check18805598,ann18775599,body18795601,if_helper703122725,self18735602);
++R.GAS;
return $ret2271822719;
} else {
var $z2274322744 = D;
var $f2274922750 = function(_) {
return R.isFunction(if_helper703122725)?if_helper703122725.app((false)):R.ffi.throwNonFunApp(L[994],if_helper703122725,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2274322744 = $f2274922750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2274922750,
"from":L[994]});
}
} catch($e2274122742) {
if(R.isCont($e2274122742)) {
var $ss2274522746 = {"from":L[994],
"go":function(cont_tail_app703622751) {
return $Hcont_tail_app1096122752(cont_tail_app703622751);
}};
$e2274122742.stack[R.EXN_STACKHEIGHT++] = $ss2274522746;
}
if(R.isPyretException($e2274122742)) {
$e2274122742.pyretStack.push(L[994]);
}
throw $e2274122742;
}
var $ret2274722748 = $Hcont_tail_app1096122752($z2274322744);
++R.GAS;
return $ret2274722748;
}
} else {
var cont_tail_arg703322755 = R.throwNonBooleanOp(L[3618],("first"),("and"),and_DASH_oper_DASH_8585597);
if(--R.GAS > 0) {
$z2275322754 = R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg703322755):R.ffi.throwNonFunApp(L[3618],if_helper703122725,[cont_tail_arg703322755]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg703322755):R.ffi.throwNonFunApp(L[3618],if_helper703122725,[cont_tail_arg703322755]);
},
"from":L[3618]});
}
++R.GAS;
return $z2275322754;
}
};
var $Hand_DASH_oper_DASH_1096022726 = function(and_DASH_oper_DASH_86022724,_check18805598,ann18775599,body18795601,if_helper703122725,self18735602) {
var anf_if704322787 = R.isBoolean(and_DASH_oper_DASH_86022724);
if(R.isPyretTrue(anf_if704322787)) {
if(R.isPyretTrue(and_DASH_oper_DASH_86022724)) {
var anf_fun704522769 = G(ann18775599,"visit",L[3619]);
var $z2276122762 = D;
var $f2276722768 = function(_) {
return R.isFunction(anf_fun704522769)?anf_fun704522769.app(self18735602):R.ffi.throwNonFunApp(L[994],anf_fun704522769,[self18735602]);
};
try {
if(--R.GAS > 0) {
$z2276122762 = $f2276722768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2276722768,
"from":L[994]});
}
} catch($e2275922760) {
if(R.isCont($e2275922760)) {
var $ss2276322764 = {"from":L[994],
"go":function(and_DASH_oper_DASH_86222770) {
return $Hand_DASH_oper_DASH_1095822771(and_DASH_oper_DASH_86222770,_check18805598,body18795601,if_helper703122725,self18735602);
}};
$e2275922760.stack[R.EXN_STACKHEIGHT++] = $ss2276322764;
}
if(R.isPyretException($e2275922760)) {
$e2275922760.pyretStack.push(L[994]);
}
throw $e2275922760;
}
var $ret2276522766 = $Hand_DASH_oper_DASH_1095822771($z2276122762,_check18805598,body18795601,if_helper703122725,self18735602);
++R.GAS;
return $ret2276522766;
} else {
var $z2277422775 = D;
var $f2278022781 = function(_) {
return R.isFunction(if_helper703122725)?if_helper703122725.app((false)):R.ffi.throwNonFunApp(L[994],if_helper703122725,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2277422775 = $f2278022781();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2278022781,
"from":L[994]});
}
} catch($e2277222773) {
if(R.isCont($e2277222773)) {
var $ss2277622777 = {"from":L[994],
"go":function(cont_tail_app704422782) {
return $Hcont_tail_app1095922783(cont_tail_app704422782);
}};
$e2277222773.stack[R.EXN_STACKHEIGHT++] = $ss2277622777;
}
if(R.isPyretException($e2277222773)) {
$e2277222773.pyretStack.push(L[994]);
}
throw $e2277222773;
}
var $ret2277822779 = $Hcont_tail_app1095922783($z2277422775);
++R.GAS;
return $ret2277822779;
}
} else {
var cont_tail_arg704122786 = R.throwNonBooleanOp(L[3620],("first"),("and"),and_DASH_oper_DASH_86022724);
if(--R.GAS > 0) {
$z2278422785 = R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg704122786):R.ffi.throwNonFunApp(L[3620],if_helper703122725,[cont_tail_arg704122786]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg704122786):R.ffi.throwNonFunApp(L[3620],if_helper703122725,[cont_tail_arg704122786]);
},
"from":L[3620]});
}
++R.GAS;
return $z2278422785;
}
};
var $Hand_DASH_oper_DASH_1095822771 = function(and_DASH_oper_DASH_86222770,_check18805598,body18795601,if_helper703122725,self18735602) {
var anf_if704822816 = R.isBoolean(and_DASH_oper_DASH_86222770);
if(R.isPyretTrue(anf_if704822816)) {
if(R.isPyretTrue(and_DASH_oper_DASH_86222770)) {
var anf_fun705022798 = G(body18795601,"visit",L[3621]);
var $z2279022791 = D;
var $f2279622797 = function(_) {
return R.isFunction(anf_fun705022798)?anf_fun705022798.app(self18735602):R.ffi.throwNonFunApp(L[994],anf_fun705022798,[self18735602]);
};
try {
if(--R.GAS > 0) {
$z2279022791 = $f2279622797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2279622797,
"from":L[994]});
}
} catch($e2278822789) {
if(R.isCont($e2278822789)) {
var $ss2279222793 = {"from":L[994],
"go":function(and_DASH_oper_DASH_86322799) {
return $Hand_DASH_oper_DASH_1095622800(and_DASH_oper_DASH_86322799,_check18805598,if_helper703122725,self18735602);
}};
$e2278822789.stack[R.EXN_STACKHEIGHT++] = $ss2279222793;
}
if(R.isPyretException($e2278822789)) {
$e2278822789.pyretStack.push(L[994]);
}
throw $e2278822789;
}
var $ret2279422795 = $Hand_DASH_oper_DASH_1095622800($z2279022791,_check18805598,if_helper703122725,self18735602);
++R.GAS;
return $ret2279422795;
} else {
var $z2280322804 = D;
var $f2280922810 = function(_) {
return R.isFunction(if_helper703122725)?if_helper703122725.app((false)):R.ffi.throwNonFunApp(L[994],if_helper703122725,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2280322804 = $f2280922810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2280922810,
"from":L[994]});
}
} catch($e2280122802) {
if(R.isCont($e2280122802)) {
var $ss2280522806 = {"from":L[994],
"go":function(cont_tail_app704922811) {
return $Hcont_tail_app1095722812(cont_tail_app704922811);
}};
$e2280122802.stack[R.EXN_STACKHEIGHT++] = $ss2280522806;
}
if(R.isPyretException($e2280122802)) {
$e2280122802.pyretStack.push(L[994]);
}
throw $e2280122802;
}
var $ret2280722808 = $Hcont_tail_app1095722812($z2280322804);
++R.GAS;
return $ret2280722808;
}
} else {
var cont_tail_arg704622815 = R.throwNonBooleanOp(L[3622],("first"),("and"),and_DASH_oper_DASH_86222770);
if(--R.GAS > 0) {
$z2281322814 = R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg704622815):R.ffi.throwNonFunApp(L[3622],if_helper703122725,[cont_tail_arg704622815]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg704622815):R.ffi.throwNonFunApp(L[3622],if_helper703122725,[cont_tail_arg704622815]);
},
"from":L[3622]});
}
++R.GAS;
return $z2281322814;
}
};
var $Hand_DASH_oper_DASH_1095622800 = function(and_DASH_oper_DASH_86322799,_check18805598,if_helper703122725,self18735602) {
var anf_if705322845 = R.isBoolean(and_DASH_oper_DASH_86322799);
if(R.isPyretTrue(anf_if705322845)) {
if(R.isPyretTrue(and_DASH_oper_DASH_86322799)) {
var anf_fun705522827 = G(self18735602,"option",L[3623]);
var $z2281922820 = D;
var $f2282522826 = function(_) {
return R.isFunction(anf_fun705522827)?anf_fun705522827.app(_check18805598):R.ffi.throwNonFunApp(L[994],anf_fun705522827,[_check18805598]);
};
try {
if(--R.GAS > 0) {
$z2281922820 = $f2282522826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2282522826,
"from":L[994]});
}
} catch($e2281722818) {
if(R.isCont($e2281722818)) {
var $ss2282122822 = {"from":L[994],
"go":function(and_DASH_oper_DASH_86422828) {
return $Hand_DASH_oper_DASH_1095422829(and_DASH_oper_DASH_86422828,if_helper703122725);
}};
$e2281722818.stack[R.EXN_STACKHEIGHT++] = $ss2282122822;
}
if(R.isPyretException($e2281722818)) {
$e2281722818.pyretStack.push(L[994]);
}
throw $e2281722818;
}
var $ret2282322824 = $Hand_DASH_oper_DASH_1095422829($z2281922820,if_helper703122725);
++R.GAS;
return $ret2282322824;
} else {
var $z2283222833 = D;
var $f2283822839 = function(_) {
return R.isFunction(if_helper703122725)?if_helper703122725.app((false)):R.ffi.throwNonFunApp(L[994],if_helper703122725,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2283222833 = $f2283822839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2283822839,
"from":L[994]});
}
} catch($e2283022831) {
if(R.isCont($e2283022831)) {
var $ss2283422835 = {"from":L[994],
"go":function(cont_tail_app705422840) {
return $Hcont_tail_app1095522841(cont_tail_app705422840);
}};
$e2283022831.stack[R.EXN_STACKHEIGHT++] = $ss2283422835;
}
if(R.isPyretException($e2283022831)) {
$e2283022831.pyretStack.push(L[994]);
}
throw $e2283022831;
}
var $ret2283622837 = $Hcont_tail_app1095522841($z2283222833);
++R.GAS;
return $ret2283622837;
}
} else {
var cont_tail_arg705122844 = R.throwNonBooleanOp(L[3624],("first"),("and"),and_DASH_oper_DASH_86322799);
if(--R.GAS > 0) {
$z2284222843 = R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg705122844):R.ffi.throwNonFunApp(L[3624],if_helper703122725,[cont_tail_arg705122844]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg705122844):R.ffi.throwNonFunApp(L[3624],if_helper703122725,[cont_tail_arg705122844]);
},
"from":L[3624]});
}
++R.GAS;
return $z2284222843;
}
};
var $Hand_DASH_oper_DASH_1095422829 = function(and_DASH_oper_DASH_86422828,if_helper703122725) {
var anf_if705822861 = R.isBoolean(and_DASH_oper_DASH_86422828);
if(R.isPyretTrue(anf_if705822861)) {
var $z2284822849 = D;
var $f2285422855 = function(_) {
return R.isFunction(if_helper703122725)?if_helper703122725.app(and_DASH_oper_DASH_86422828):R.ffi.throwNonFunApp(L[994],if_helper703122725,[and_DASH_oper_DASH_86422828]);
};
try {
if(--R.GAS > 0) {
$z2284822849 = $f2285422855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2285422855,
"from":L[994]});
}
} catch($e2284622847) {
if(R.isCont($e2284622847)) {
var $ss2285022851 = {"from":L[994],
"go":function(cont_tail_app705922856) {
return $Hcont_tail_app1095322857(cont_tail_app705922856);
}};
$e2284622847.stack[R.EXN_STACKHEIGHT++] = $ss2285022851;
}
if(R.isPyretException($e2284622847)) {
$e2284622847.pyretStack.push(L[994]);
}
throw $e2284622847;
}
var $ret2285222853 = $Hcont_tail_app1095322857($z2284822849);
++R.GAS;
return $ret2285222853;
} else {
var cont_tail_arg705622860 = R.throwNonBooleanOp(L[3625],("second"),("and"),and_DASH_oper_DASH_86422828);
if(--R.GAS > 0) {
$z2285822859 = R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg705622860):R.ffi.throwNonFunApp(L[3625],if_helper703122725,[cont_tail_arg705622860]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper703122725)?if_helper703122725.app(cont_tail_arg705622860):R.ffi.throwNonFunApp(L[3625],if_helper703122725,[cont_tail_arg705622860]);
},
"from":L[3625]});
}
++R.GAS;
return $z2285822859;
}
};
var $Hcont_tail_app1095322857 = function(cont_tail_app705922856) {
return cont_tail_app705922856;
};
var $Hcont_tail_app1095522841 = function(cont_tail_app705422840) {
return cont_tail_app705422840;
};
var $Hcont_tail_app1095722812 = function(cont_tail_app704922811) {
return cont_tail_app704922811;
};
var $Hcont_tail_app1095922783 = function(cont_tail_app704422782) {
return cont_tail_app704422782;
};
var $Hann_DASH_check_DASH_temp1095222740 = function(ann_DASH_check_DASH_temp703822739) {
return ann_DASH_check_DASH_temp703822739;
};
var $Hcont_tail_app1096122752 = function(cont_tail_app703622751) {
return cont_tail_app703622751;
};
var $Hann_DASH_check_DASH_temp109515617 = function(ann_DASH_check_DASH_temp70285616) {
return ann_DASH_check_DASH_temp70285616;
};
var $Hann_DASH_check_DASH_temp109505633 = function(ann_DASH_check_DASH_temp70235632) {
return ann_DASH_check_DASH_temp70235632;
};
var $Hand_DASH_oper_DASH_109495650 = function(and_DASH_oper_DASH_8565648,right18695649,self18655647) {
var if_helper701122874 = R.makeFunction(function(if_helper_arg701222892) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1009],1,arguments);
}
var ann_DASH_check_DASH_temp700922893 = if_helper_arg701222892;
return ann_DASH_check_DASH_temp700922893;
});
var anf_if701522891 = R.isBoolean(and_DASH_oper_DASH_8565648);
if(R.isPyretTrue(anf_if701522891)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8565648)) {
var anf_fun701722872 = G(right18695649,"visit",L[3626]);
var $z2286422865 = D;
var $f2287022871 = function(_) {
return R.isFunction(anf_fun701722872)?anf_fun701722872.app(self18655647):R.ffi.throwNonFunApp(L[1009],anf_fun701722872,[self18655647]);
};
try {
if(--R.GAS > 0) {
$z2286422865 = $f2287022871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2287022871,
"from":L[1009]});
}
} catch($e2286222863) {
if(R.isCont($e2286222863)) {
var $ss2286622867 = {"from":L[1009],
"go":function(and_DASH_oper_DASH_85722873) {
return $Hand_DASH_oper_DASH_1094722875(and_DASH_oper_DASH_85722873,if_helper701122874);
}};
$e2286222863.stack[R.EXN_STACKHEIGHT++] = $ss2286622867;
}
if(R.isPyretException($e2286222863)) {
$e2286222863.pyretStack.push(L[1009]);
}
throw $e2286222863;
}
var $ret2286822869 = $Hand_DASH_oper_DASH_1094722875($z2286422865,if_helper701122874);
++R.GAS;
return $ret2286822869;
} else {
var $z2287822879 = D;
var $f2288422885 = function(_) {
return R.isFunction(if_helper701122874)?if_helper701122874.app((false)):R.ffi.throwNonFunApp(L[1009],if_helper701122874,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2287822879 = $f2288422885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2288422885,
"from":L[1009]});
}
} catch($e2287622877) {
if(R.isCont($e2287622877)) {
var $ss2288022881 = {"from":L[1009],
"go":function(cont_tail_app701622886) {
return $Hcont_tail_app1094822887(cont_tail_app701622886);
}};
$e2287622877.stack[R.EXN_STACKHEIGHT++] = $ss2288022881;
}
if(R.isPyretException($e2287622877)) {
$e2287622877.pyretStack.push(L[1009]);
}
throw $e2287622877;
}
var $ret2288222883 = $Hcont_tail_app1094822887($z2287822879);
++R.GAS;
return $ret2288222883;
}
} else {
var cont_tail_arg701322890 = R.throwNonBooleanOp(L[3627],("first"),("and"),and_DASH_oper_DASH_8565648);
if(--R.GAS > 0) {
$z2288822889 = R.isFunction(if_helper701122874)?if_helper701122874.app(cont_tail_arg701322890):R.ffi.throwNonFunApp(L[3627],if_helper701122874,[cont_tail_arg701322890]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper701122874)?if_helper701122874.app(cont_tail_arg701322890):R.ffi.throwNonFunApp(L[3627],if_helper701122874,[cont_tail_arg701322890]);
},
"from":L[3627]});
}
++R.GAS;
return $z2288822889;
}
};
var $Hand_DASH_oper_DASH_1094722875 = function(and_DASH_oper_DASH_85722873,if_helper701122874) {
var anf_if702022909 = R.isBoolean(and_DASH_oper_DASH_85722873);
if(R.isPyretTrue(anf_if702022909)) {
var $z2289622897 = D;
var $f2290222903 = function(_) {
return R.isFunction(if_helper701122874)?if_helper701122874.app(and_DASH_oper_DASH_85722873):R.ffi.throwNonFunApp(L[1009],if_helper701122874,[and_DASH_oper_DASH_85722873]);
};
try {
if(--R.GAS > 0) {
$z2289622897 = $f2290222903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2290222903,
"from":L[1009]});
}
} catch($e2289422895) {
if(R.isCont($e2289422895)) {
var $ss2289822899 = {"from":L[1009],
"go":function(cont_tail_app702122904) {
return $Hcont_tail_app1094622905(cont_tail_app702122904);
}};
$e2289422895.stack[R.EXN_STACKHEIGHT++] = $ss2289822899;
}
if(R.isPyretException($e2289422895)) {
$e2289422895.pyretStack.push(L[1009]);
}
throw $e2289422895;
}
var $ret2290022901 = $Hcont_tail_app1094622905($z2289622897);
++R.GAS;
return $ret2290022901;
} else {
var cont_tail_arg701822908 = R.throwNonBooleanOp(L[3628],("second"),("and"),and_DASH_oper_DASH_85722873);
if(--R.GAS > 0) {
$z2290622907 = R.isFunction(if_helper701122874)?if_helper701122874.app(cont_tail_arg701822908):R.ffi.throwNonFunApp(L[3628],if_helper701122874,[cont_tail_arg701822908]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper701122874)?if_helper701122874.app(cont_tail_arg701822908):R.ffi.throwNonFunApp(L[3628],if_helper701122874,[cont_tail_arg701822908]);
},
"from":L[3628]});
}
++R.GAS;
return $z2290622907;
}
};
var $Hcont_tail_app1094622905 = function(cont_tail_app702122904) {
return cont_tail_app702122904;
};
var $Hcont_tail_app1094822887 = function(cont_tail_app701622886) {
return cont_tail_app701622886;
};
var $Hand_DASH_oper_DASH_109455668 = function(and_DASH_oper_DASH_8545666,right18645667,self18605665) {
var if_helper699722922 = R.makeFunction(function(if_helper_arg699822940) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1016],1,arguments);
}
var ann_DASH_check_DASH_temp699522941 = if_helper_arg699822940;
return ann_DASH_check_DASH_temp699522941;
});
var anf_if700122939 = R.isBoolean(and_DASH_oper_DASH_8545666);
if(R.isPyretTrue(anf_if700122939)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8545666)) {
var anf_fun700322920 = G(right18645667,"visit",L[3629]);
var $z2291222913 = D;
var $f2291822919 = function(_) {
return R.isFunction(anf_fun700322920)?anf_fun700322920.app(self18605665):R.ffi.throwNonFunApp(L[1016],anf_fun700322920,[self18605665]);
};
try {
if(--R.GAS > 0) {
$z2291222913 = $f2291822919();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2291822919,
"from":L[1016]});
}
} catch($e2291022911) {
if(R.isCont($e2291022911)) {
var $ss2291422915 = {"from":L[1016],
"go":function(and_DASH_oper_DASH_85522921) {
return $Hand_DASH_oper_DASH_1094322923(and_DASH_oper_DASH_85522921,if_helper699722922);
}};
$e2291022911.stack[R.EXN_STACKHEIGHT++] = $ss2291422915;
}
if(R.isPyretException($e2291022911)) {
$e2291022911.pyretStack.push(L[1016]);
}
throw $e2291022911;
}
var $ret2291622917 = $Hand_DASH_oper_DASH_1094322923($z2291222913,if_helper699722922);
++R.GAS;
return $ret2291622917;
} else {
var $z2292622927 = D;
var $f2293222933 = function(_) {
return R.isFunction(if_helper699722922)?if_helper699722922.app((false)):R.ffi.throwNonFunApp(L[1016],if_helper699722922,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2292622927 = $f2293222933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2293222933,
"from":L[1016]});
}
} catch($e2292422925) {
if(R.isCont($e2292422925)) {
var $ss2292822929 = {"from":L[1016],
"go":function(cont_tail_app700222934) {
return $Hcont_tail_app1094422935(cont_tail_app700222934);
}};
$e2292422925.stack[R.EXN_STACKHEIGHT++] = $ss2292822929;
}
if(R.isPyretException($e2292422925)) {
$e2292422925.pyretStack.push(L[1016]);
}
throw $e2292422925;
}
var $ret2293022931 = $Hcont_tail_app1094422935($z2292622927);
++R.GAS;
return $ret2293022931;
}
} else {
var cont_tail_arg699922938 = R.throwNonBooleanOp(L[3630],("first"),("and"),and_DASH_oper_DASH_8545666);
if(--R.GAS > 0) {
$z2293622937 = R.isFunction(if_helper699722922)?if_helper699722922.app(cont_tail_arg699922938):R.ffi.throwNonFunApp(L[3630],if_helper699722922,[cont_tail_arg699922938]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper699722922)?if_helper699722922.app(cont_tail_arg699922938):R.ffi.throwNonFunApp(L[3630],if_helper699722922,[cont_tail_arg699922938]);
},
"from":L[3630]});
}
++R.GAS;
return $z2293622937;
}
};
var $Hand_DASH_oper_DASH_1094322923 = function(and_DASH_oper_DASH_85522921,if_helper699722922) {
var anf_if700622957 = R.isBoolean(and_DASH_oper_DASH_85522921);
if(R.isPyretTrue(anf_if700622957)) {
var $z2294422945 = D;
var $f2295022951 = function(_) {
return R.isFunction(if_helper699722922)?if_helper699722922.app(and_DASH_oper_DASH_85522921):R.ffi.throwNonFunApp(L[1016],if_helper699722922,[and_DASH_oper_DASH_85522921]);
};
try {
if(--R.GAS > 0) {
$z2294422945 = $f2295022951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2295022951,
"from":L[1016]});
}
} catch($e2294222943) {
if(R.isCont($e2294222943)) {
var $ss2294622947 = {"from":L[1016],
"go":function(cont_tail_app700722952) {
return $Hcont_tail_app1094222953(cont_tail_app700722952);
}};
$e2294222943.stack[R.EXN_STACKHEIGHT++] = $ss2294622947;
}
if(R.isPyretException($e2294222943)) {
$e2294222943.pyretStack.push(L[1016]);
}
throw $e2294222943;
}
var $ret2294822949 = $Hcont_tail_app1094222953($z2294422945);
++R.GAS;
return $ret2294822949;
} else {
var cont_tail_arg700422956 = R.throwNonBooleanOp(L[3631],("second"),("and"),and_DASH_oper_DASH_85522921);
if(--R.GAS > 0) {
$z2295422955 = R.isFunction(if_helper699722922)?if_helper699722922.app(cont_tail_arg700422956):R.ffi.throwNonFunApp(L[3631],if_helper699722922,[cont_tail_arg700422956]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper699722922)?if_helper699722922.app(cont_tail_arg700422956):R.ffi.throwNonFunApp(L[3631],if_helper699722922,[cont_tail_arg700422956]);
},
"from":L[3631]});
}
++R.GAS;
return $z2295422955;
}
};
var $Hcont_tail_app1094222953 = function(cont_tail_app700722952) {
return cont_tail_app700722952;
};
var $Hcont_tail_app1094422935 = function(cont_tail_app700222934) {
return cont_tail_app700222934;
};
var $Hand_DASH_oper_DASH_109415687 = function(and_DASH_oper_DASH_8515684,_except18595685,id18585686,self18555683) {
var if_helper697822970 = R.makeFunction(function(if_helper_arg697922988) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1023],1,arguments);
}
var ann_DASH_check_DASH_temp697622989 = if_helper_arg697922988;
return ann_DASH_check_DASH_temp697622989;
});
var anf_if698222987 = R.isBoolean(and_DASH_oper_DASH_8515684);
if(R.isPyretTrue(anf_if698222987)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8515684)) {
var anf_fun698422968 = G(id18585686,"visit",L[3632]);
var $z2296022961 = D;
var $f2296622967 = function(_) {
return R.isFunction(anf_fun698422968)?anf_fun698422968.app(self18555683):R.ffi.throwNonFunApp(L[1023],anf_fun698422968,[self18555683]);
};
try {
if(--R.GAS > 0) {
$z2296022961 = $f2296622967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2296622967,
"from":L[1023]});
}
} catch($e2295822959) {
if(R.isCont($e2295822959)) {
var $ss2296222963 = {"from":L[1023],
"go":function(and_DASH_oper_DASH_85222969) {
return $Hand_DASH_oper_DASH_1093922971(and_DASH_oper_DASH_85222969,_except18595685,if_helper697822970,self18555683);
}};
$e2295822959.stack[R.EXN_STACKHEIGHT++] = $ss2296222963;
}
if(R.isPyretException($e2295822959)) {
$e2295822959.pyretStack.push(L[1023]);
}
throw $e2295822959;
}
var $ret2296422965 = $Hand_DASH_oper_DASH_1093922971($z2296022961,_except18595685,if_helper697822970,self18555683);
++R.GAS;
return $ret2296422965;
} else {
var $z2297422975 = D;
var $f2298022981 = function(_) {
return R.isFunction(if_helper697822970)?if_helper697822970.app((false)):R.ffi.throwNonFunApp(L[1023],if_helper697822970,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2297422975 = $f2298022981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2298022981,
"from":L[1023]});
}
} catch($e2297222973) {
if(R.isCont($e2297222973)) {
var $ss2297622977 = {"from":L[1023],
"go":function(cont_tail_app698322982) {
return $Hcont_tail_app1094022983(cont_tail_app698322982);
}};
$e2297222973.stack[R.EXN_STACKHEIGHT++] = $ss2297622977;
}
if(R.isPyretException($e2297222973)) {
$e2297222973.pyretStack.push(L[1023]);
}
throw $e2297222973;
}
var $ret2297822979 = $Hcont_tail_app1094022983($z2297422975);
++R.GAS;
return $ret2297822979;
}
} else {
var cont_tail_arg698022986 = R.throwNonBooleanOp(L[3633],("first"),("and"),and_DASH_oper_DASH_8515684);
if(--R.GAS > 0) {
$z2298422985 = R.isFunction(if_helper697822970)?if_helper697822970.app(cont_tail_arg698022986):R.ffi.throwNonFunApp(L[3633],if_helper697822970,[cont_tail_arg698022986]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper697822970)?if_helper697822970.app(cont_tail_arg698022986):R.ffi.throwNonFunApp(L[3633],if_helper697822970,[cont_tail_arg698022986]);
},
"from":L[3633]});
}
++R.GAS;
return $z2298422985;
}
};
var $Hand_DASH_oper_DASH_1093922971 = function(and_DASH_oper_DASH_85222969,_except18595685,if_helper697822970,self18555683) {
var anf_if698723018 = R.isBoolean(and_DASH_oper_DASH_85222969);
if(R.isPyretTrue(anf_if698723018)) {
if(R.isPyretTrue(and_DASH_oper_DASH_85222969)) {
var anf_fun698923000 = G(_except18595685,"visit",L[3634]);
var $z2299222993 = D;
var $f2299822999 = function(_) {
return R.isFunction(anf_fun698923000)?anf_fun698923000.app(self18555683):R.ffi.throwNonFunApp(L[1023],anf_fun698923000,[self18555683]);
};
try {
if(--R.GAS > 0) {
$z2299222993 = $f2299822999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2299822999,
"from":L[1023]});
}
} catch($e2299022991) {
if(R.isCont($e2299022991)) {
var $ss2299422995 = {"from":L[1023],
"go":function(and_DASH_oper_DASH_85323001) {
return $Hand_DASH_oper_DASH_1093723002(and_DASH_oper_DASH_85323001,if_helper697822970);
}};
$e2299022991.stack[R.EXN_STACKHEIGHT++] = $ss2299422995;
}
if(R.isPyretException($e2299022991)) {
$e2299022991.pyretStack.push(L[1023]);
}
throw $e2299022991;
}
var $ret2299622997 = $Hand_DASH_oper_DASH_1093723002($z2299222993,if_helper697822970);
++R.GAS;
return $ret2299622997;
} else {
var $z2300523006 = D;
var $f2301123012 = function(_) {
return R.isFunction(if_helper697822970)?if_helper697822970.app((false)):R.ffi.throwNonFunApp(L[1023],if_helper697822970,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2300523006 = $f2301123012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2301123012,
"from":L[1023]});
}
} catch($e2300323004) {
if(R.isCont($e2300323004)) {
var $ss2300723008 = {"from":L[1023],
"go":function(cont_tail_app698823013) {
return $Hcont_tail_app1093823014(cont_tail_app698823013);
}};
$e2300323004.stack[R.EXN_STACKHEIGHT++] = $ss2300723008;
}
if(R.isPyretException($e2300323004)) {
$e2300323004.pyretStack.push(L[1023]);
}
throw $e2300323004;
}
var $ret2300923010 = $Hcont_tail_app1093823014($z2300523006);
++R.GAS;
return $ret2300923010;
}
} else {
var cont_tail_arg698523017 = R.throwNonBooleanOp(L[3635],("first"),("and"),and_DASH_oper_DASH_85222969);
if(--R.GAS > 0) {
$z2301523016 = R.isFunction(if_helper697822970)?if_helper697822970.app(cont_tail_arg698523017):R.ffi.throwNonFunApp(L[3635],if_helper697822970,[cont_tail_arg698523017]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper697822970)?if_helper697822970.app(cont_tail_arg698523017):R.ffi.throwNonFunApp(L[3635],if_helper697822970,[cont_tail_arg698523017]);
},
"from":L[3635]});
}
++R.GAS;
return $z2301523016;
}
};
var $Hand_DASH_oper_DASH_1093723002 = function(and_DASH_oper_DASH_85323001,if_helper697822970) {
var anf_if699223034 = R.isBoolean(and_DASH_oper_DASH_85323001);
if(R.isPyretTrue(anf_if699223034)) {
var $z2302123022 = D;
var $f2302723028 = function(_) {
return R.isFunction(if_helper697822970)?if_helper697822970.app(and_DASH_oper_DASH_85323001):R.ffi.throwNonFunApp(L[1023],if_helper697822970,[and_DASH_oper_DASH_85323001]);
};
try {
if(--R.GAS > 0) {
$z2302123022 = $f2302723028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2302723028,
"from":L[1023]});
}
} catch($e2301923020) {
if(R.isCont($e2301923020)) {
var $ss2302323024 = {"from":L[1023],
"go":function(cont_tail_app699323029) {
return $Hcont_tail_app1093623030(cont_tail_app699323029);
}};
$e2301923020.stack[R.EXN_STACKHEIGHT++] = $ss2302323024;
}
if(R.isPyretException($e2301923020)) {
$e2301923020.pyretStack.push(L[1023]);
}
throw $e2301923020;
}
var $ret2302523026 = $Hcont_tail_app1093623030($z2302123022);
++R.GAS;
return $ret2302523026;
} else {
var cont_tail_arg699023033 = R.throwNonBooleanOp(L[3636],("second"),("and"),and_DASH_oper_DASH_85323001);
if(--R.GAS > 0) {
$z2303123032 = R.isFunction(if_helper697822970)?if_helper697822970.app(cont_tail_arg699023033):R.ffi.throwNonFunApp(L[3636],if_helper697822970,[cont_tail_arg699023033]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper697822970)?if_helper697822970.app(cont_tail_arg699023033):R.ffi.throwNonFunApp(L[3636],if_helper697822970,[cont_tail_arg699023033]);
},
"from":L[3636]});
}
++R.GAS;
return $z2303123032;
}
};
var $Hcont_tail_app1093623030 = function(cont_tail_app699323029) {
return cont_tail_app699323029;
};
var $Hcont_tail_app1093823014 = function(cont_tail_app698823013) {
return cont_tail_app698823013;
};
var $Hcont_tail_app1094022983 = function(cont_tail_app698322982) {
return cont_tail_app698322982;
};
var $Hand_DASH_oper_DASH_109355706 = function(and_DASH_oper_DASH_8465702,_else18545703,branches18535704,lists974,self18495701,val18525705) {
var if_helper695123047 = R.makeFunction(function(if_helper_arg695223065) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1030],1,arguments);
}
var ann_DASH_check_DASH_temp694923066 = if_helper_arg695223065;
return ann_DASH_check_DASH_temp694923066;
});
var anf_if695523064 = R.isBoolean(and_DASH_oper_DASH_8465702);
if(R.isPyretTrue(anf_if695523064)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8465702)) {
var anf_fun695723045 = G(val18525705,"visit",L[3637]);
var $z2303723038 = D;
var $f2304323044 = function(_) {
return R.isFunction(anf_fun695723045)?anf_fun695723045.app(self18495701):R.ffi.throwNonFunApp(L[1030],anf_fun695723045,[self18495701]);
};
try {
if(--R.GAS > 0) {
$z2303723038 = $f2304323044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2304323044,
"from":L[1030]});
}
} catch($e2303523036) {
if(R.isCont($e2303523036)) {
var $ss2303923040 = {"from":L[1030],
"go":function(and_DASH_oper_DASH_84723046) {
return $Hand_DASH_oper_DASH_1093323048(and_DASH_oper_DASH_84723046,_else18545703,branches18535704,if_helper695123047,lists974,self18495701);
}};
$e2303523036.stack[R.EXN_STACKHEIGHT++] = $ss2303923040;
}
if(R.isPyretException($e2303523036)) {
$e2303523036.pyretStack.push(L[1030]);
}
throw $e2303523036;
}
var $ret2304123042 = $Hand_DASH_oper_DASH_1093323048($z2303723038,_else18545703,branches18535704,if_helper695123047,lists974,self18495701);
++R.GAS;
return $ret2304123042;
} else {
var $z2305123052 = D;
var $f2305723058 = function(_) {
return R.isFunction(if_helper695123047)?if_helper695123047.app((false)):R.ffi.throwNonFunApp(L[1030],if_helper695123047,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2305123052 = $f2305723058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2305723058,
"from":L[1030]});
}
} catch($e2304923050) {
if(R.isCont($e2304923050)) {
var $ss2305323054 = {"from":L[1030],
"go":function(cont_tail_app695623059) {
return $Hcont_tail_app1093423060(cont_tail_app695623059);
}};
$e2304923050.stack[R.EXN_STACKHEIGHT++] = $ss2305323054;
}
if(R.isPyretException($e2304923050)) {
$e2304923050.pyretStack.push(L[1030]);
}
throw $e2304923050;
}
var $ret2305523056 = $Hcont_tail_app1093423060($z2305123052);
++R.GAS;
return $ret2305523056;
}
} else {
var cont_tail_arg695323063 = R.throwNonBooleanOp(L[3638],("first"),("and"),and_DASH_oper_DASH_8465702);
if(--R.GAS > 0) {
$z2306123062 = R.isFunction(if_helper695123047)?if_helper695123047.app(cont_tail_arg695323063):R.ffi.throwNonFunApp(L[3638],if_helper695123047,[cont_tail_arg695323063]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper695123047)?if_helper695123047.app(cont_tail_arg695323063):R.ffi.throwNonFunApp(L[3638],if_helper695123047,[cont_tail_arg695323063]);
},
"from":L[3638]});
}
++R.GAS;
return $z2306123062;
}
};
var $Hand_DASH_oper_DASH_1093323048 = function(and_DASH_oper_DASH_84723046,_else18545703,branches18535704,if_helper695123047,lists974,self18495701) {
var anf_if696023110 = R.isBoolean(and_DASH_oper_DASH_84723046);
if(R.isPyretTrue(anf_if696023110)) {
if(R.isPyretTrue(and_DASH_oper_DASH_84723046)) {
var anf_fun696223077 = G(lists974,"all",L[3640]);
var anf_arg696523078 = R.makeFunction(function(recv_DASH_84923081) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3639],1,arguments);
}
var anf_fun696423092 = G(recv_DASH_84923081,"visit",L[3639]);
var $z2308423085 = D;
var $f2309023091 = function(_) {
return R.isFunction(anf_fun696423092)?anf_fun696423092.app(self18495701):R.ffi.throwNonFunApp(L[3639],anf_fun696423092,[self18495701]);
};
try {
if(--R.GAS > 0) {
$z2308423085 = $f2309023091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2309023091,
"from":L[3639]});
}
} catch($e2308223083) {
if(R.isCont($e2308223083)) {
var $ss2308623087 = {"from":L[3639],
"go":function(ann_DASH_check_DASH_temp696323093) {
return $Hann_DASH_check_DASH_temp1092723094(ann_DASH_check_DASH_temp696323093);
}};
$e2308223083.stack[R.EXN_STACKHEIGHT++] = $ss2308623087;
}
if(R.isPyretException($e2308223083)) {
$e2308223083.pyretStack.push(L[3639]);
}
throw $e2308223083;
}
var $ret2308823089 = $Hann_DASH_check_DASH_temp1092723094($z2308423085);
++R.GAS;
return $ret2308823089;
});
var $z2306923070 = D;
var $f2307523076 = function(_) {
return R.isFunction(anf_fun696223077)?anf_fun696223077.app(anf_arg696523078,branches18535704):R.ffi.throwNonFunApp(L[1030],anf_fun696223077,[anf_arg696523078,branches18535704]);
};
try {
if(--R.GAS > 0) {
$z2306923070 = $f2307523076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2307523076,
"from":L[1030]});
}
} catch($e2306723068) {
if(R.isCont($e2306723068)) {
var $ss2307123072 = {"from":L[1030],
"go":function(and_DASH_oper_DASH_84823079) {
return $Hand_DASH_oper_DASH_1093123080(and_DASH_oper_DASH_84823079,_else18545703,if_helper695123047,self18495701);
}};
$e2306723068.stack[R.EXN_STACKHEIGHT++] = $ss2307123072;
}
if(R.isPyretException($e2306723068)) {
$e2306723068.pyretStack.push(L[1030]);
}
throw $e2306723068;
}
var $ret2307323074 = $Hand_DASH_oper_DASH_1093123080($z2306923070,_else18545703,if_helper695123047,self18495701);
++R.GAS;
return $ret2307323074;
} else {
var $z2309723098 = D;
var $f2310323104 = function(_) {
return R.isFunction(if_helper695123047)?if_helper695123047.app((false)):R.ffi.throwNonFunApp(L[1030],if_helper695123047,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2309723098 = $f2310323104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2310323104,
"from":L[1030]});
}
} catch($e2309523096) {
if(R.isCont($e2309523096)) {
var $ss2309923100 = {"from":L[1030],
"go":function(cont_tail_app696123105) {
return $Hcont_tail_app1093223106(cont_tail_app696123105);
}};
$e2309523096.stack[R.EXN_STACKHEIGHT++] = $ss2309923100;
}
if(R.isPyretException($e2309523096)) {
$e2309523096.pyretStack.push(L[1030]);
}
throw $e2309523096;
}
var $ret2310123102 = $Hcont_tail_app1093223106($z2309723098);
++R.GAS;
return $ret2310123102;
}
} else {
var cont_tail_arg695823109 = R.throwNonBooleanOp(L[3641],("first"),("and"),and_DASH_oper_DASH_84723046);
if(--R.GAS > 0) {
$z2310723108 = R.isFunction(if_helper695123047)?if_helper695123047.app(cont_tail_arg695823109):R.ffi.throwNonFunApp(L[3641],if_helper695123047,[cont_tail_arg695823109]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper695123047)?if_helper695123047.app(cont_tail_arg695823109):R.ffi.throwNonFunApp(L[3641],if_helper695123047,[cont_tail_arg695823109]);
},
"from":L[3641]});
}
++R.GAS;
return $z2310723108;
}
};
var $Hand_DASH_oper_DASH_1093123080 = function(and_DASH_oper_DASH_84823079,_else18545703,if_helper695123047,self18495701) {
var anf_if696823139 = R.isBoolean(and_DASH_oper_DASH_84823079);
if(R.isPyretTrue(anf_if696823139)) {
if(R.isPyretTrue(and_DASH_oper_DASH_84823079)) {
var anf_fun697023121 = G(_else18545703,"visit",L[3642]);
var $z2311323114 = D;
var $f2311923120 = function(_) {
return R.isFunction(anf_fun697023121)?anf_fun697023121.app(self18495701):R.ffi.throwNonFunApp(L[1030],anf_fun697023121,[self18495701]);
};
try {
if(--R.GAS > 0) {
$z2311323114 = $f2311923120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2311923120,
"from":L[1030]});
}
} catch($e2311123112) {
if(R.isCont($e2311123112)) {
var $ss2311523116 = {"from":L[1030],
"go":function(and_DASH_oper_DASH_85023122) {
return $Hand_DASH_oper_DASH_1092923123(and_DASH_oper_DASH_85023122,if_helper695123047);
}};
$e2311123112.stack[R.EXN_STACKHEIGHT++] = $ss2311523116;
}
if(R.isPyretException($e2311123112)) {
$e2311123112.pyretStack.push(L[1030]);
}
throw $e2311123112;
}
var $ret2311723118 = $Hand_DASH_oper_DASH_1092923123($z2311323114,if_helper695123047);
++R.GAS;
return $ret2311723118;
} else {
var $z2312623127 = D;
var $f2313223133 = function(_) {
return R.isFunction(if_helper695123047)?if_helper695123047.app((false)):R.ffi.throwNonFunApp(L[1030],if_helper695123047,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2312623127 = $f2313223133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2313223133,
"from":L[1030]});
}
} catch($e2312423125) {
if(R.isCont($e2312423125)) {
var $ss2312823129 = {"from":L[1030],
"go":function(cont_tail_app696923134) {
return $Hcont_tail_app1093023135(cont_tail_app696923134);
}};
$e2312423125.stack[R.EXN_STACKHEIGHT++] = $ss2312823129;
}
if(R.isPyretException($e2312423125)) {
$e2312423125.pyretStack.push(L[1030]);
}
throw $e2312423125;
}
var $ret2313023131 = $Hcont_tail_app1093023135($z2312623127);
++R.GAS;
return $ret2313023131;
}
} else {
var cont_tail_arg696623138 = R.throwNonBooleanOp(L[3643],("first"),("and"),and_DASH_oper_DASH_84823079);
if(--R.GAS > 0) {
$z2313623137 = R.isFunction(if_helper695123047)?if_helper695123047.app(cont_tail_arg696623138):R.ffi.throwNonFunApp(L[3643],if_helper695123047,[cont_tail_arg696623138]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper695123047)?if_helper695123047.app(cont_tail_arg696623138):R.ffi.throwNonFunApp(L[3643],if_helper695123047,[cont_tail_arg696623138]);
},
"from":L[3643]});
}
++R.GAS;
return $z2313623137;
}
};
var $Hand_DASH_oper_DASH_1092923123 = function(and_DASH_oper_DASH_85023122,if_helper695123047) {
var anf_if697323155 = R.isBoolean(and_DASH_oper_DASH_85023122);
if(R.isPyretTrue(anf_if697323155)) {
var $z2314223143 = D;
var $f2314823149 = function(_) {
return R.isFunction(if_helper695123047)?if_helper695123047.app(and_DASH_oper_DASH_85023122):R.ffi.throwNonFunApp(L[1030],if_helper695123047,[and_DASH_oper_DASH_85023122]);
};
try {
if(--R.GAS > 0) {
$z2314223143 = $f2314823149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2314823149,
"from":L[1030]});
}
} catch($e2314023141) {
if(R.isCont($e2314023141)) {
var $ss2314423145 = {"from":L[1030],
"go":function(cont_tail_app697423150) {
return $Hcont_tail_app1092823151(cont_tail_app697423150);
}};
$e2314023141.stack[R.EXN_STACKHEIGHT++] = $ss2314423145;
}
if(R.isPyretException($e2314023141)) {
$e2314023141.pyretStack.push(L[1030]);
}
throw $e2314023141;
}
var $ret2314623147 = $Hcont_tail_app1092823151($z2314223143);
++R.GAS;
return $ret2314623147;
} else {
var cont_tail_arg697123154 = R.throwNonBooleanOp(L[3644],("second"),("and"),and_DASH_oper_DASH_85023122);
if(--R.GAS > 0) {
$z2315223153 = R.isFunction(if_helper695123047)?if_helper695123047.app(cont_tail_arg697123154):R.ffi.throwNonFunApp(L[3644],if_helper695123047,[cont_tail_arg697123154]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper695123047)?if_helper695123047.app(cont_tail_arg697123154):R.ffi.throwNonFunApp(L[3644],if_helper695123047,[cont_tail_arg697123154]);
},
"from":L[3644]});
}
++R.GAS;
return $z2315223153;
}
};
var $Hcont_tail_app1092823151 = function(cont_tail_app697423150) {
return cont_tail_app697423150;
};
var $Hcont_tail_app1093023135 = function(cont_tail_app696923134) {
return cont_tail_app696923134;
};
var $Hann_DASH_check_DASH_temp1092723094 = function(ann_DASH_check_DASH_temp696323093) {
return ann_DASH_check_DASH_temp696323093;
};
var $Hcont_tail_app1093223106 = function(cont_tail_app696123105) {
return cont_tail_app696123105;
};
var $Hcont_tail_app1093423060 = function(cont_tail_app695623059) {
return cont_tail_app695623059;
};
var $Hand_DASH_oper_DASH_109265724 = function(and_DASH_oper_DASH_8425721,branches18485722,lists974,self18445720,val18475723) {
var if_helper692923168 = R.makeFunction(function(if_helper_arg693023186) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1038],1,arguments);
}
var ann_DASH_check_DASH_temp692723187 = if_helper_arg693023186;
return ann_DASH_check_DASH_temp692723187;
});
var anf_if693323185 = R.isBoolean(and_DASH_oper_DASH_8425721);
if(R.isPyretTrue(anf_if693323185)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8425721)) {
var anf_fun693523166 = G(val18475723,"visit",L[3645]);
var $z2315823159 = D;
var $f2316423165 = function(_) {
return R.isFunction(anf_fun693523166)?anf_fun693523166.app(self18445720):R.ffi.throwNonFunApp(L[1038],anf_fun693523166,[self18445720]);
};
try {
if(--R.GAS > 0) {
$z2315823159 = $f2316423165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2316423165,
"from":L[1038]});
}
} catch($e2315623157) {
if(R.isCont($e2315623157)) {
var $ss2316023161 = {"from":L[1038],
"go":function(and_DASH_oper_DASH_84323167) {
return $Hand_DASH_oper_DASH_1092423169(and_DASH_oper_DASH_84323167,branches18485722,if_helper692923168,lists974,self18445720);
}};
$e2315623157.stack[R.EXN_STACKHEIGHT++] = $ss2316023161;
}
if(R.isPyretException($e2315623157)) {
$e2315623157.pyretStack.push(L[1038]);
}
throw $e2315623157;
}
var $ret2316223163 = $Hand_DASH_oper_DASH_1092423169($z2315823159,branches18485722,if_helper692923168,lists974,self18445720);
++R.GAS;
return $ret2316223163;
} else {
var $z2317223173 = D;
var $f2317823179 = function(_) {
return R.isFunction(if_helper692923168)?if_helper692923168.app((false)):R.ffi.throwNonFunApp(L[1038],if_helper692923168,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2317223173 = $f2317823179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2317823179,
"from":L[1038]});
}
} catch($e2317023171) {
if(R.isCont($e2317023171)) {
var $ss2317423175 = {"from":L[1038],
"go":function(cont_tail_app693423180) {
return $Hcont_tail_app1092523181(cont_tail_app693423180);
}};
$e2317023171.stack[R.EXN_STACKHEIGHT++] = $ss2317423175;
}
if(R.isPyretException($e2317023171)) {
$e2317023171.pyretStack.push(L[1038]);
}
throw $e2317023171;
}
var $ret2317623177 = $Hcont_tail_app1092523181($z2317223173);
++R.GAS;
return $ret2317623177;
}
} else {
var cont_tail_arg693123184 = R.throwNonBooleanOp(L[3646],("first"),("and"),and_DASH_oper_DASH_8425721);
if(--R.GAS > 0) {
$z2318223183 = R.isFunction(if_helper692923168)?if_helper692923168.app(cont_tail_arg693123184):R.ffi.throwNonFunApp(L[3646],if_helper692923168,[cont_tail_arg693123184]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper692923168)?if_helper692923168.app(cont_tail_arg693123184):R.ffi.throwNonFunApp(L[3646],if_helper692923168,[cont_tail_arg693123184]);
},
"from":L[3646]});
}
++R.GAS;
return $z2318223183;
}
};
var $Hand_DASH_oper_DASH_1092423169 = function(and_DASH_oper_DASH_84323167,branches18485722,if_helper692923168,lists974,self18445720) {
var anf_if693823231 = R.isBoolean(and_DASH_oper_DASH_84323167);
if(R.isPyretTrue(anf_if693823231)) {
if(R.isPyretTrue(and_DASH_oper_DASH_84323167)) {
var anf_fun694023198 = G(lists974,"all",L[3648]);
var anf_arg694323199 = R.makeFunction(function(recv_DASH_84523202) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3647],1,arguments);
}
var anf_fun694223213 = G(recv_DASH_84523202,"visit",L[3647]);
var $z2320523206 = D;
var $f2321123212 = function(_) {
return R.isFunction(anf_fun694223213)?anf_fun694223213.app(self18445720):R.ffi.throwNonFunApp(L[3647],anf_fun694223213,[self18445720]);
};
try {
if(--R.GAS > 0) {
$z2320523206 = $f2321123212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2321123212,
"from":L[3647]});
}
} catch($e2320323204) {
if(R.isCont($e2320323204)) {
var $ss2320723208 = {"from":L[3647],
"go":function(ann_DASH_check_DASH_temp694123214) {
return $Hann_DASH_check_DASH_temp1092023215(ann_DASH_check_DASH_temp694123214);
}};
$e2320323204.stack[R.EXN_STACKHEIGHT++] = $ss2320723208;
}
if(R.isPyretException($e2320323204)) {
$e2320323204.pyretStack.push(L[3647]);
}
throw $e2320323204;
}
var $ret2320923210 = $Hann_DASH_check_DASH_temp1092023215($z2320523206);
++R.GAS;
return $ret2320923210;
});
var $z2319023191 = D;
var $f2319623197 = function(_) {
return R.isFunction(anf_fun694023198)?anf_fun694023198.app(anf_arg694323199,branches18485722):R.ffi.throwNonFunApp(L[1038],anf_fun694023198,[anf_arg694323199,branches18485722]);
};
try {
if(--R.GAS > 0) {
$z2319023191 = $f2319623197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2319623197,
"from":L[1038]});
}
} catch($e2318823189) {
if(R.isCont($e2318823189)) {
var $ss2319223193 = {"from":L[1038],
"go":function(and_DASH_oper_DASH_84423200) {
return $Hand_DASH_oper_DASH_1092223201(and_DASH_oper_DASH_84423200,if_helper692923168);
}};
$e2318823189.stack[R.EXN_STACKHEIGHT++] = $ss2319223193;
}
if(R.isPyretException($e2318823189)) {
$e2318823189.pyretStack.push(L[1038]);
}
throw $e2318823189;
}
var $ret2319423195 = $Hand_DASH_oper_DASH_1092223201($z2319023191,if_helper692923168);
++R.GAS;
return $ret2319423195;
} else {
var $z2321823219 = D;
var $f2322423225 = function(_) {
return R.isFunction(if_helper692923168)?if_helper692923168.app((false)):R.ffi.throwNonFunApp(L[1038],if_helper692923168,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2321823219 = $f2322423225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2322423225,
"from":L[1038]});
}
} catch($e2321623217) {
if(R.isCont($e2321623217)) {
var $ss2322023221 = {"from":L[1038],
"go":function(cont_tail_app693923226) {
return $Hcont_tail_app1092323227(cont_tail_app693923226);
}};
$e2321623217.stack[R.EXN_STACKHEIGHT++] = $ss2322023221;
}
if(R.isPyretException($e2321623217)) {
$e2321623217.pyretStack.push(L[1038]);
}
throw $e2321623217;
}
var $ret2322223223 = $Hcont_tail_app1092323227($z2321823219);
++R.GAS;
return $ret2322223223;
}
} else {
var cont_tail_arg693623230 = R.throwNonBooleanOp(L[3649],("first"),("and"),and_DASH_oper_DASH_84323167);
if(--R.GAS > 0) {
$z2322823229 = R.isFunction(if_helper692923168)?if_helper692923168.app(cont_tail_arg693623230):R.ffi.throwNonFunApp(L[3649],if_helper692923168,[cont_tail_arg693623230]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper692923168)?if_helper692923168.app(cont_tail_arg693623230):R.ffi.throwNonFunApp(L[3649],if_helper692923168,[cont_tail_arg693623230]);
},
"from":L[3649]});
}
++R.GAS;
return $z2322823229;
}
};
var $Hand_DASH_oper_DASH_1092223201 = function(and_DASH_oper_DASH_84423200,if_helper692923168) {
var anf_if694623247 = R.isBoolean(and_DASH_oper_DASH_84423200);
if(R.isPyretTrue(anf_if694623247)) {
var $z2323423235 = D;
var $f2324023241 = function(_) {
return R.isFunction(if_helper692923168)?if_helper692923168.app(and_DASH_oper_DASH_84423200):R.ffi.throwNonFunApp(L[1038],if_helper692923168,[and_DASH_oper_DASH_84423200]);
};
try {
if(--R.GAS > 0) {
$z2323423235 = $f2324023241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2324023241,
"from":L[1038]});
}
} catch($e2323223233) {
if(R.isCont($e2323223233)) {
var $ss2323623237 = {"from":L[1038],
"go":function(cont_tail_app694723242) {
return $Hcont_tail_app1092123243(cont_tail_app694723242);
}};
$e2323223233.stack[R.EXN_STACKHEIGHT++] = $ss2323623237;
}
if(R.isPyretException($e2323223233)) {
$e2323223233.pyretStack.push(L[1038]);
}
throw $e2323223233;
}
var $ret2323823239 = $Hcont_tail_app1092123243($z2323423235);
++R.GAS;
return $ret2323823239;
} else {
var cont_tail_arg694423246 = R.throwNonBooleanOp(L[3650],("second"),("and"),and_DASH_oper_DASH_84423200);
if(--R.GAS > 0) {
$z2324423245 = R.isFunction(if_helper692923168)?if_helper692923168.app(cont_tail_arg694423246):R.ffi.throwNonFunApp(L[3650],if_helper692923168,[cont_tail_arg694423246]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper692923168)?if_helper692923168.app(cont_tail_arg694423246):R.ffi.throwNonFunApp(L[3650],if_helper692923168,[cont_tail_arg694423246]);
},
"from":L[3650]});
}
++R.GAS;
return $z2324423245;
}
};
var $Hcont_tail_app1092123243 = function(cont_tail_app694723242) {
return cont_tail_app694723242;
};
var $Hann_DASH_check_DASH_temp1092023215 = function(ann_DASH_check_DASH_temp694123214) {
return ann_DASH_check_DASH_temp694123214;
};
var $Hcont_tail_app1092323227 = function(cont_tail_app693923226) {
return cont_tail_app693923226;
};
var $Hcont_tail_app1092523181 = function(cont_tail_app693423180) {
return cont_tail_app693423180;
};
var $Hand_DASH_oper_DASH_109195743 = function(and_DASH_oper_DASH_8395740,body18435741,self18395742) {
var if_helper691523260 = R.makeFunction(function(if_helper_arg691623278) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1045],1,arguments);
}
var ann_DASH_check_DASH_temp691023279 = if_helper_arg691623278;
return ann_DASH_check_DASH_temp691023279;
});
var anf_if691923277 = R.isBoolean(and_DASH_oper_DASH_8395740);
if(R.isPyretTrue(anf_if691923277)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8395740)) {
var anf_fun692123258 = G(body18435741,"visit",L[3651]);
var $z2325023251 = D;
var $f2325623257 = function(_) {
return R.isFunction(anf_fun692123258)?anf_fun692123258.app(self18395742):R.ffi.throwNonFunApp(L[1045],anf_fun692123258,[self18395742]);
};
try {
if(--R.GAS > 0) {
$z2325023251 = $f2325623257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2325623257,
"from":L[1045]});
}
} catch($e2324823249) {
if(R.isCont($e2324823249)) {
var $ss2325223253 = {"from":L[1045],
"go":function(and_DASH_oper_DASH_84123259) {
return $Hand_DASH_oper_DASH_1091723261(and_DASH_oper_DASH_84123259,if_helper691523260);
}};
$e2324823249.stack[R.EXN_STACKHEIGHT++] = $ss2325223253;
}
if(R.isPyretException($e2324823249)) {
$e2324823249.pyretStack.push(L[1045]);
}
throw $e2324823249;
}
var $ret2325423255 = $Hand_DASH_oper_DASH_1091723261($z2325023251,if_helper691523260);
++R.GAS;
return $ret2325423255;
} else {
var $z2326423265 = D;
var $f2327023271 = function(_) {
return R.isFunction(if_helper691523260)?if_helper691523260.app((false)):R.ffi.throwNonFunApp(L[1045],if_helper691523260,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2326423265 = $f2327023271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2327023271,
"from":L[1045]});
}
} catch($e2326223263) {
if(R.isCont($e2326223263)) {
var $ss2326623267 = {"from":L[1045],
"go":function(cont_tail_app692023272) {
return $Hcont_tail_app1091823273(cont_tail_app692023272);
}};
$e2326223263.stack[R.EXN_STACKHEIGHT++] = $ss2326623267;
}
if(R.isPyretException($e2326223263)) {
$e2326223263.pyretStack.push(L[1045]);
}
throw $e2326223263;
}
var $ret2326823269 = $Hcont_tail_app1091823273($z2326423265);
++R.GAS;
return $ret2326823269;
}
} else {
var cont_tail_arg691723276 = R.throwNonBooleanOp(L[3652],("first"),("and"),and_DASH_oper_DASH_8395740);
if(--R.GAS > 0) {
$z2327423275 = R.isFunction(if_helper691523260)?if_helper691523260.app(cont_tail_arg691723276):R.ffi.throwNonFunApp(L[3652],if_helper691523260,[cont_tail_arg691723276]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper691523260)?if_helper691523260.app(cont_tail_arg691723276):R.ffi.throwNonFunApp(L[3652],if_helper691523260,[cont_tail_arg691723276]);
},
"from":L[3652]});
}
++R.GAS;
return $z2327423275;
}
};
var $Hand_DASH_oper_DASH_1091723261 = function(and_DASH_oper_DASH_84123259,if_helper691523260) {
var anf_if692423295 = R.isBoolean(and_DASH_oper_DASH_84123259);
if(R.isPyretTrue(anf_if692423295)) {
var $z2328223283 = D;
var $f2328823289 = function(_) {
return R.isFunction(if_helper691523260)?if_helper691523260.app(and_DASH_oper_DASH_84123259):R.ffi.throwNonFunApp(L[1045],if_helper691523260,[and_DASH_oper_DASH_84123259]);
};
try {
if(--R.GAS > 0) {
$z2328223283 = $f2328823289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2328823289,
"from":L[1045]});
}
} catch($e2328023281) {
if(R.isCont($e2328023281)) {
var $ss2328423285 = {"from":L[1045],
"go":function(cont_tail_app692523290) {
return $Hcont_tail_app1091623291(cont_tail_app692523290);
}};
$e2328023281.stack[R.EXN_STACKHEIGHT++] = $ss2328423285;
}
if(R.isPyretException($e2328023281)) {
$e2328023281.pyretStack.push(L[1045]);
}
throw $e2328023281;
}
var $ret2328623287 = $Hcont_tail_app1091623291($z2328223283);
++R.GAS;
return $ret2328623287;
} else {
var cont_tail_arg692223294 = R.throwNonBooleanOp(L[3653],("second"),("and"),and_DASH_oper_DASH_84123259);
if(--R.GAS > 0) {
$z2329223293 = R.isFunction(if_helper691523260)?if_helper691523260.app(cont_tail_arg692223294):R.ffi.throwNonFunApp(L[3653],if_helper691523260,[cont_tail_arg692223294]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper691523260)?if_helper691523260.app(cont_tail_arg692223294):R.ffi.throwNonFunApp(L[3653],if_helper691523260,[cont_tail_arg692223294]);
},
"from":L[3653]});
}
++R.GAS;
return $z2329223293;
}
};
var $Hcont_tail_app1091623291 = function(cont_tail_app692523290) {
return cont_tail_app692523290;
};
var $Hcont_tail_app1091823273 = function(cont_tail_app692023272) {
return cont_tail_app692023272;
};
var $Hann_DASH_check_DASH_temp109155757 = function(ann_DASH_check_DASH_temp69125756) {
return ann_DASH_check_DASH_temp69125756;
};
var $Hand_DASH_oper_DASH_109145776 = function(and_DASH_oper_DASH_8365773,_else18385774,self18355775) {
var if_helper689823308 = R.makeFunction(function(if_helper_arg689923326) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1053],1,arguments);
}
var ann_DASH_check_DASH_temp689323327 = if_helper_arg689923326;
return ann_DASH_check_DASH_temp689323327;
});
var anf_if690223325 = R.isBoolean(and_DASH_oper_DASH_8365773);
if(R.isPyretTrue(anf_if690223325)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8365773)) {
var anf_fun690423306 = G(_else18385774,"visit",L[3654]);
var $z2329823299 = D;
var $f2330423305 = function(_) {
return R.isFunction(anf_fun690423306)?anf_fun690423306.app(self18355775):R.ffi.throwNonFunApp(L[1053],anf_fun690423306,[self18355775]);
};
try {
if(--R.GAS > 0) {
$z2329823299 = $f2330423305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2330423305,
"from":L[1053]});
}
} catch($e2329623297) {
if(R.isCont($e2329623297)) {
var $ss2330023301 = {"from":L[1053],
"go":function(and_DASH_oper_DASH_83823307) {
return $Hand_DASH_oper_DASH_1091223309(and_DASH_oper_DASH_83823307,if_helper689823308);
}};
$e2329623297.stack[R.EXN_STACKHEIGHT++] = $ss2330023301;
}
if(R.isPyretException($e2329623297)) {
$e2329623297.pyretStack.push(L[1053]);
}
throw $e2329623297;
}
var $ret2330223303 = $Hand_DASH_oper_DASH_1091223309($z2329823299,if_helper689823308);
++R.GAS;
return $ret2330223303;
} else {
var $z2331223313 = D;
var $f2331823319 = function(_) {
return R.isFunction(if_helper689823308)?if_helper689823308.app((false)):R.ffi.throwNonFunApp(L[1053],if_helper689823308,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2331223313 = $f2331823319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2331823319,
"from":L[1053]});
}
} catch($e2331023311) {
if(R.isCont($e2331023311)) {
var $ss2331423315 = {"from":L[1053],
"go":function(cont_tail_app690323320) {
return $Hcont_tail_app1091323321(cont_tail_app690323320);
}};
$e2331023311.stack[R.EXN_STACKHEIGHT++] = $ss2331423315;
}
if(R.isPyretException($e2331023311)) {
$e2331023311.pyretStack.push(L[1053]);
}
throw $e2331023311;
}
var $ret2331623317 = $Hcont_tail_app1091323321($z2331223313);
++R.GAS;
return $ret2331623317;
}
} else {
var cont_tail_arg690023324 = R.throwNonBooleanOp(L[3655],("first"),("and"),and_DASH_oper_DASH_8365773);
if(--R.GAS > 0) {
$z2332223323 = R.isFunction(if_helper689823308)?if_helper689823308.app(cont_tail_arg690023324):R.ffi.throwNonFunApp(L[3655],if_helper689823308,[cont_tail_arg690023324]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper689823308)?if_helper689823308.app(cont_tail_arg690023324):R.ffi.throwNonFunApp(L[3655],if_helper689823308,[cont_tail_arg690023324]);
},
"from":L[3655]});
}
++R.GAS;
return $z2332223323;
}
};
var $Hand_DASH_oper_DASH_1091223309 = function(and_DASH_oper_DASH_83823307,if_helper689823308) {
var anf_if690723343 = R.isBoolean(and_DASH_oper_DASH_83823307);
if(R.isPyretTrue(anf_if690723343)) {
var $z2333023331 = D;
var $f2333623337 = function(_) {
return R.isFunction(if_helper689823308)?if_helper689823308.app(and_DASH_oper_DASH_83823307):R.ffi.throwNonFunApp(L[1053],if_helper689823308,[and_DASH_oper_DASH_83823307]);
};
try {
if(--R.GAS > 0) {
$z2333023331 = $f2333623337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2333623337,
"from":L[1053]});
}
} catch($e2332823329) {
if(R.isCont($e2332823329)) {
var $ss2333223333 = {"from":L[1053],
"go":function(cont_tail_app690823338) {
return $Hcont_tail_app1091123339(cont_tail_app690823338);
}};
$e2332823329.stack[R.EXN_STACKHEIGHT++] = $ss2333223333;
}
if(R.isPyretException($e2332823329)) {
$e2332823329.pyretStack.push(L[1053]);
}
throw $e2332823329;
}
var $ret2333423335 = $Hcont_tail_app1091123339($z2333023331);
++R.GAS;
return $ret2333423335;
} else {
var cont_tail_arg690523342 = R.throwNonBooleanOp(L[3656],("second"),("and"),and_DASH_oper_DASH_83823307);
if(--R.GAS > 0) {
$z2334023341 = R.isFunction(if_helper689823308)?if_helper689823308.app(cont_tail_arg690523342):R.ffi.throwNonFunApp(L[3656],if_helper689823308,[cont_tail_arg690523342]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper689823308)?if_helper689823308.app(cont_tail_arg690523342):R.ffi.throwNonFunApp(L[3656],if_helper689823308,[cont_tail_arg690523342]);
},
"from":L[3656]});
}
++R.GAS;
return $z2334023341;
}
};
var $Hcont_tail_app1091123339 = function(cont_tail_app690823338) {
return cont_tail_app690823338;
};
var $Hcont_tail_app1091323321 = function(cont_tail_app690323320) {
return cont_tail_app690323320;
};
var $Hann_DASH_check_DASH_temp109105790 = function(ann_DASH_check_DASH_temp68955789) {
return ann_DASH_check_DASH_temp68955789;
};
var $Hann_DASH_check_DASH_temp109095806 = function(ann_DASH_check_DASH_temp68875805) {
return ann_DASH_check_DASH_temp68875805;
};
var $Hann_DASH_check_DASH_temp109085821 = function(ann_DASH_check_DASH_temp68895820) {
return ann_DASH_check_DASH_temp68895820;
};
var $Hand_DASH_oper_DASH_109075839 = function(and_DASH_oper_DASH_8325836,_else18315837,self18285838) {
var if_helper687523356 = R.makeFunction(function(if_helper_arg687623374) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1065],1,arguments);
}
var ann_DASH_check_DASH_temp687023375 = if_helper_arg687623374;
return ann_DASH_check_DASH_temp687023375;
});
var anf_if687923373 = R.isBoolean(and_DASH_oper_DASH_8325836);
if(R.isPyretTrue(anf_if687923373)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8325836)) {
var anf_fun688123354 = G(_else18315837,"visit",L[3657]);
var $z2334623347 = D;
var $f2335223353 = function(_) {
return R.isFunction(anf_fun688123354)?anf_fun688123354.app(self18285838):R.ffi.throwNonFunApp(L[1065],anf_fun688123354,[self18285838]);
};
try {
if(--R.GAS > 0) {
$z2334623347 = $f2335223353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2335223353,
"from":L[1065]});
}
} catch($e2334423345) {
if(R.isCont($e2334423345)) {
var $ss2334823349 = {"from":L[1065],
"go":function(and_DASH_oper_DASH_83423355) {
return $Hand_DASH_oper_DASH_1090523357(and_DASH_oper_DASH_83423355,if_helper687523356);
}};
$e2334423345.stack[R.EXN_STACKHEIGHT++] = $ss2334823349;
}
if(R.isPyretException($e2334423345)) {
$e2334423345.pyretStack.push(L[1065]);
}
throw $e2334423345;
}
var $ret2335023351 = $Hand_DASH_oper_DASH_1090523357($z2334623347,if_helper687523356);
++R.GAS;
return $ret2335023351;
} else {
var $z2336023361 = D;
var $f2336623367 = function(_) {
return R.isFunction(if_helper687523356)?if_helper687523356.app((false)):R.ffi.throwNonFunApp(L[1065],if_helper687523356,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2336023361 = $f2336623367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2336623367,
"from":L[1065]});
}
} catch($e2335823359) {
if(R.isCont($e2335823359)) {
var $ss2336223363 = {"from":L[1065],
"go":function(cont_tail_app688023368) {
return $Hcont_tail_app1090623369(cont_tail_app688023368);
}};
$e2335823359.stack[R.EXN_STACKHEIGHT++] = $ss2336223363;
}
if(R.isPyretException($e2335823359)) {
$e2335823359.pyretStack.push(L[1065]);
}
throw $e2335823359;
}
var $ret2336423365 = $Hcont_tail_app1090623369($z2336023361);
++R.GAS;
return $ret2336423365;
}
} else {
var cont_tail_arg687723372 = R.throwNonBooleanOp(L[3658],("first"),("and"),and_DASH_oper_DASH_8325836);
if(--R.GAS > 0) {
$z2337023371 = R.isFunction(if_helper687523356)?if_helper687523356.app(cont_tail_arg687723372):R.ffi.throwNonFunApp(L[3658],if_helper687523356,[cont_tail_arg687723372]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper687523356)?if_helper687523356.app(cont_tail_arg687723372):R.ffi.throwNonFunApp(L[3658],if_helper687523356,[cont_tail_arg687723372]);
},
"from":L[3658]});
}
++R.GAS;
return $z2337023371;
}
};
var $Hand_DASH_oper_DASH_1090523357 = function(and_DASH_oper_DASH_83423355,if_helper687523356) {
var anf_if688423391 = R.isBoolean(and_DASH_oper_DASH_83423355);
if(R.isPyretTrue(anf_if688423391)) {
var $z2337823379 = D;
var $f2338423385 = function(_) {
return R.isFunction(if_helper687523356)?if_helper687523356.app(and_DASH_oper_DASH_83423355):R.ffi.throwNonFunApp(L[1065],if_helper687523356,[and_DASH_oper_DASH_83423355]);
};
try {
if(--R.GAS > 0) {
$z2337823379 = $f2338423385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2338423385,
"from":L[1065]});
}
} catch($e2337623377) {
if(R.isCont($e2337623377)) {
var $ss2338023381 = {"from":L[1065],
"go":function(cont_tail_app688523386) {
return $Hcont_tail_app1090423387(cont_tail_app688523386);
}};
$e2337623377.stack[R.EXN_STACKHEIGHT++] = $ss2338023381;
}
if(R.isPyretException($e2337623377)) {
$e2337623377.pyretStack.push(L[1065]);
}
throw $e2337623377;
}
var $ret2338223383 = $Hcont_tail_app1090423387($z2337823379);
++R.GAS;
return $ret2338223383;
} else {
var cont_tail_arg688223390 = R.throwNonBooleanOp(L[3659],("second"),("and"),and_DASH_oper_DASH_83423355);
if(--R.GAS > 0) {
$z2338823389 = R.isFunction(if_helper687523356)?if_helper687523356.app(cont_tail_arg688223390):R.ffi.throwNonFunApp(L[3659],if_helper687523356,[cont_tail_arg688223390]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper687523356)?if_helper687523356.app(cont_tail_arg688223390):R.ffi.throwNonFunApp(L[3659],if_helper687523356,[cont_tail_arg688223390]);
},
"from":L[3659]});
}
++R.GAS;
return $z2338823389;
}
};
var $Hcont_tail_app1090423387 = function(cont_tail_app688523386) {
return cont_tail_app688523386;
};
var $Hcont_tail_app1090623369 = function(cont_tail_app688023368) {
return cont_tail_app688023368;
};
var $Hann_DASH_check_DASH_temp109035853 = function(ann_DASH_check_DASH_temp68725852) {
return ann_DASH_check_DASH_temp68725852;
};
var $Hann_DASH_check_DASH_temp109025869 = function(ann_DASH_check_DASH_temp68645868) {
return ann_DASH_check_DASH_temp68645868;
};
var $Hann_DASH_check_DASH_temp109015884 = function(ann_DASH_check_DASH_temp68665883) {
return ann_DASH_check_DASH_temp68665883;
};
var $Hand_DASH_oper_DASH_109005900 = function(and_DASH_oper_DASH_8295898,body18245899,self18215897) {
var if_helper685223404 = R.makeFunction(function(if_helper_arg685323422) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1077],1,arguments);
}
var ann_DASH_check_DASH_temp685023423 = if_helper_arg685323422;
return ann_DASH_check_DASH_temp685023423;
});
var anf_if685623421 = R.isBoolean(and_DASH_oper_DASH_8295898);
if(R.isPyretTrue(anf_if685623421)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8295898)) {
var anf_fun685823402 = G(body18245899,"visit",L[3660]);
var $z2339423395 = D;
var $f2340023401 = function(_) {
return R.isFunction(anf_fun685823402)?anf_fun685823402.app(self18215897):R.ffi.throwNonFunApp(L[1077],anf_fun685823402,[self18215897]);
};
try {
if(--R.GAS > 0) {
$z2339423395 = $f2340023401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2340023401,
"from":L[1077]});
}
} catch($e2339223393) {
if(R.isCont($e2339223393)) {
var $ss2339623397 = {"from":L[1077],
"go":function(and_DASH_oper_DASH_83023403) {
return $Hand_DASH_oper_DASH_1089823405(and_DASH_oper_DASH_83023403,if_helper685223404);
}};
$e2339223393.stack[R.EXN_STACKHEIGHT++] = $ss2339623397;
}
if(R.isPyretException($e2339223393)) {
$e2339223393.pyretStack.push(L[1077]);
}
throw $e2339223393;
}
var $ret2339823399 = $Hand_DASH_oper_DASH_1089823405($z2339423395,if_helper685223404);
++R.GAS;
return $ret2339823399;
} else {
var $z2340823409 = D;
var $f2341423415 = function(_) {
return R.isFunction(if_helper685223404)?if_helper685223404.app((false)):R.ffi.throwNonFunApp(L[1077],if_helper685223404,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2340823409 = $f2341423415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2341423415,
"from":L[1077]});
}
} catch($e2340623407) {
if(R.isCont($e2340623407)) {
var $ss2341023411 = {"from":L[1077],
"go":function(cont_tail_app685723416) {
return $Hcont_tail_app1089923417(cont_tail_app685723416);
}};
$e2340623407.stack[R.EXN_STACKHEIGHT++] = $ss2341023411;
}
if(R.isPyretException($e2340623407)) {
$e2340623407.pyretStack.push(L[1077]);
}
throw $e2340623407;
}
var $ret2341223413 = $Hcont_tail_app1089923417($z2340823409);
++R.GAS;
return $ret2341223413;
}
} else {
var cont_tail_arg685423420 = R.throwNonBooleanOp(L[3661],("first"),("and"),and_DASH_oper_DASH_8295898);
if(--R.GAS > 0) {
$z2341823419 = R.isFunction(if_helper685223404)?if_helper685223404.app(cont_tail_arg685423420):R.ffi.throwNonFunApp(L[3661],if_helper685223404,[cont_tail_arg685423420]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper685223404)?if_helper685223404.app(cont_tail_arg685423420):R.ffi.throwNonFunApp(L[3661],if_helper685223404,[cont_tail_arg685423420]);
},
"from":L[3661]});
}
++R.GAS;
return $z2341823419;
}
};
var $Hand_DASH_oper_DASH_1089823405 = function(and_DASH_oper_DASH_83023403,if_helper685223404) {
var anf_if686123439 = R.isBoolean(and_DASH_oper_DASH_83023403);
if(R.isPyretTrue(anf_if686123439)) {
var $z2342623427 = D;
var $f2343223433 = function(_) {
return R.isFunction(if_helper685223404)?if_helper685223404.app(and_DASH_oper_DASH_83023403):R.ffi.throwNonFunApp(L[1077],if_helper685223404,[and_DASH_oper_DASH_83023403]);
};
try {
if(--R.GAS > 0) {
$z2342623427 = $f2343223433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2343223433,
"from":L[1077]});
}
} catch($e2342423425) {
if(R.isCont($e2342423425)) {
var $ss2342823429 = {"from":L[1077],
"go":function(cont_tail_app686223434) {
return $Hcont_tail_app1089723435(cont_tail_app686223434);
}};
$e2342423425.stack[R.EXN_STACKHEIGHT++] = $ss2342823429;
}
if(R.isPyretException($e2342423425)) {
$e2342423425.pyretStack.push(L[1077]);
}
throw $e2342423425;
}
var $ret2343023431 = $Hcont_tail_app1089723435($z2342623427);
++R.GAS;
return $ret2343023431;
} else {
var cont_tail_arg685923438 = R.throwNonBooleanOp(L[3662],("second"),("and"),and_DASH_oper_DASH_83023403);
if(--R.GAS > 0) {
$z2343623437 = R.isFunction(if_helper685223404)?if_helper685223404.app(cont_tail_arg685923438):R.ffi.throwNonFunApp(L[3662],if_helper685223404,[cont_tail_arg685923438]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper685223404)?if_helper685223404.app(cont_tail_arg685923438):R.ffi.throwNonFunApp(L[3662],if_helper685223404,[cont_tail_arg685923438]);
},
"from":L[3662]});
}
++R.GAS;
return $z2343623437;
}
};
var $Hcont_tail_app1089723435 = function(cont_tail_app686223434) {
return cont_tail_app686223434;
};
var $Hcont_tail_app1089923417 = function(cont_tail_app685723416) {
return cont_tail_app685723416;
};
var $Hand_DASH_oper_DASH_108965917 = function(and_DASH_oper_DASH_8275915,body18205916,self18175914) {
var if_helper683823452 = R.makeFunction(function(if_helper_arg683923470) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1083],1,arguments);
}
var ann_DASH_check_DASH_temp683623471 = if_helper_arg683923470;
return ann_DASH_check_DASH_temp683623471;
});
var anf_if684223469 = R.isBoolean(and_DASH_oper_DASH_8275915);
if(R.isPyretTrue(anf_if684223469)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8275915)) {
var anf_fun684423450 = G(body18205916,"visit",L[3663]);
var $z2344223443 = D;
var $f2344823449 = function(_) {
return R.isFunction(anf_fun684423450)?anf_fun684423450.app(self18175914):R.ffi.throwNonFunApp(L[1083],anf_fun684423450,[self18175914]);
};
try {
if(--R.GAS > 0) {
$z2344223443 = $f2344823449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2344823449,
"from":L[1083]});
}
} catch($e2344023441) {
if(R.isCont($e2344023441)) {
var $ss2344423445 = {"from":L[1083],
"go":function(and_DASH_oper_DASH_82823451) {
return $Hand_DASH_oper_DASH_1089423453(and_DASH_oper_DASH_82823451,if_helper683823452);
}};
$e2344023441.stack[R.EXN_STACKHEIGHT++] = $ss2344423445;
}
if(R.isPyretException($e2344023441)) {
$e2344023441.pyretStack.push(L[1083]);
}
throw $e2344023441;
}
var $ret2344623447 = $Hand_DASH_oper_DASH_1089423453($z2344223443,if_helper683823452);
++R.GAS;
return $ret2344623447;
} else {
var $z2345623457 = D;
var $f2346223463 = function(_) {
return R.isFunction(if_helper683823452)?if_helper683823452.app((false)):R.ffi.throwNonFunApp(L[1083],if_helper683823452,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2345623457 = $f2346223463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2346223463,
"from":L[1083]});
}
} catch($e2345423455) {
if(R.isCont($e2345423455)) {
var $ss2345823459 = {"from":L[1083],
"go":function(cont_tail_app684323464) {
return $Hcont_tail_app1089523465(cont_tail_app684323464);
}};
$e2345423455.stack[R.EXN_STACKHEIGHT++] = $ss2345823459;
}
if(R.isPyretException($e2345423455)) {
$e2345423455.pyretStack.push(L[1083]);
}
throw $e2345423455;
}
var $ret2346023461 = $Hcont_tail_app1089523465($z2345623457);
++R.GAS;
return $ret2346023461;
}
} else {
var cont_tail_arg684023468 = R.throwNonBooleanOp(L[3664],("first"),("and"),and_DASH_oper_DASH_8275915);
if(--R.GAS > 0) {
$z2346623467 = R.isFunction(if_helper683823452)?if_helper683823452.app(cont_tail_arg684023468):R.ffi.throwNonFunApp(L[3664],if_helper683823452,[cont_tail_arg684023468]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper683823452)?if_helper683823452.app(cont_tail_arg684023468):R.ffi.throwNonFunApp(L[3664],if_helper683823452,[cont_tail_arg684023468]);
},
"from":L[3664]});
}
++R.GAS;
return $z2346623467;
}
};
var $Hand_DASH_oper_DASH_1089423453 = function(and_DASH_oper_DASH_82823451,if_helper683823452) {
var anf_if684723487 = R.isBoolean(and_DASH_oper_DASH_82823451);
if(R.isPyretTrue(anf_if684723487)) {
var $z2347423475 = D;
var $f2348023481 = function(_) {
return R.isFunction(if_helper683823452)?if_helper683823452.app(and_DASH_oper_DASH_82823451):R.ffi.throwNonFunApp(L[1083],if_helper683823452,[and_DASH_oper_DASH_82823451]);
};
try {
if(--R.GAS > 0) {
$z2347423475 = $f2348023481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2348023481,
"from":L[1083]});
}
} catch($e2347223473) {
if(R.isCont($e2347223473)) {
var $ss2347623477 = {"from":L[1083],
"go":function(cont_tail_app684823482) {
return $Hcont_tail_app1089323483(cont_tail_app684823482);
}};
$e2347223473.stack[R.EXN_STACKHEIGHT++] = $ss2347623477;
}
if(R.isPyretException($e2347223473)) {
$e2347223473.pyretStack.push(L[1083]);
}
throw $e2347223473;
}
var $ret2347823479 = $Hcont_tail_app1089323483($z2347423475);
++R.GAS;
return $ret2347823479;
} else {
var cont_tail_arg684523486 = R.throwNonBooleanOp(L[3665],("second"),("and"),and_DASH_oper_DASH_82823451);
if(--R.GAS > 0) {
$z2348423485 = R.isFunction(if_helper683823452)?if_helper683823452.app(cont_tail_arg684523486):R.ffi.throwNonFunApp(L[3665],if_helper683823452,[cont_tail_arg684523486]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper683823452)?if_helper683823452.app(cont_tail_arg684523486):R.ffi.throwNonFunApp(L[3665],if_helper683823452,[cont_tail_arg684523486]);
},
"from":L[3665]});
}
++R.GAS;
return $z2348423485;
}
};
var $Hcont_tail_app1089323483 = function(cont_tail_app684823482) {
return cont_tail_app684823482;
};
var $Hcont_tail_app1089523465 = function(cont_tail_app684323464) {
return cont_tail_app684323464;
};
var $Hand_DASH_oper_DASH_108925934 = function(and_DASH_oper_DASH_8255932,self18135931,value18165933) {
var if_helper682423500 = R.makeFunction(function(if_helper_arg682523518) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1089],1,arguments);
}
var ann_DASH_check_DASH_temp682223519 = if_helper_arg682523518;
return ann_DASH_check_DASH_temp682223519;
});
var anf_if682823517 = R.isBoolean(and_DASH_oper_DASH_8255932);
if(R.isPyretTrue(anf_if682823517)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8255932)) {
var anf_fun683023498 = G(value18165933,"visit",L[3666]);
var $z2349023491 = D;
var $f2349623497 = function(_) {
return R.isFunction(anf_fun683023498)?anf_fun683023498.app(self18135931):R.ffi.throwNonFunApp(L[1089],anf_fun683023498,[self18135931]);
};
try {
if(--R.GAS > 0) {
$z2349023491 = $f2349623497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2349623497,
"from":L[1089]});
}
} catch($e2348823489) {
if(R.isCont($e2348823489)) {
var $ss2349223493 = {"from":L[1089],
"go":function(and_DASH_oper_DASH_82623499) {
return $Hand_DASH_oper_DASH_1089023501(and_DASH_oper_DASH_82623499,if_helper682423500);
}};
$e2348823489.stack[R.EXN_STACKHEIGHT++] = $ss2349223493;
}
if(R.isPyretException($e2348823489)) {
$e2348823489.pyretStack.push(L[1089]);
}
throw $e2348823489;
}
var $ret2349423495 = $Hand_DASH_oper_DASH_1089023501($z2349023491,if_helper682423500);
++R.GAS;
return $ret2349423495;
} else {
var $z2350423505 = D;
var $f2351023511 = function(_) {
return R.isFunction(if_helper682423500)?if_helper682423500.app((false)):R.ffi.throwNonFunApp(L[1089],if_helper682423500,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2350423505 = $f2351023511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2351023511,
"from":L[1089]});
}
} catch($e2350223503) {
if(R.isCont($e2350223503)) {
var $ss2350623507 = {"from":L[1089],
"go":function(cont_tail_app682923512) {
return $Hcont_tail_app1089123513(cont_tail_app682923512);
}};
$e2350223503.stack[R.EXN_STACKHEIGHT++] = $ss2350623507;
}
if(R.isPyretException($e2350223503)) {
$e2350223503.pyretStack.push(L[1089]);
}
throw $e2350223503;
}
var $ret2350823509 = $Hcont_tail_app1089123513($z2350423505);
++R.GAS;
return $ret2350823509;
}
} else {
var cont_tail_arg682623516 = R.throwNonBooleanOp(L[3667],("first"),("and"),and_DASH_oper_DASH_8255932);
if(--R.GAS > 0) {
$z2351423515 = R.isFunction(if_helper682423500)?if_helper682423500.app(cont_tail_arg682623516):R.ffi.throwNonFunApp(L[3667],if_helper682423500,[cont_tail_arg682623516]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper682423500)?if_helper682423500.app(cont_tail_arg682623516):R.ffi.throwNonFunApp(L[3667],if_helper682423500,[cont_tail_arg682623516]);
},
"from":L[3667]});
}
++R.GAS;
return $z2351423515;
}
};
var $Hand_DASH_oper_DASH_1089023501 = function(and_DASH_oper_DASH_82623499,if_helper682423500) {
var anf_if683323535 = R.isBoolean(and_DASH_oper_DASH_82623499);
if(R.isPyretTrue(anf_if683323535)) {
var $z2352223523 = D;
var $f2352823529 = function(_) {
return R.isFunction(if_helper682423500)?if_helper682423500.app(and_DASH_oper_DASH_82623499):R.ffi.throwNonFunApp(L[1089],if_helper682423500,[and_DASH_oper_DASH_82623499]);
};
try {
if(--R.GAS > 0) {
$z2352223523 = $f2352823529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2352823529,
"from":L[1089]});
}
} catch($e2352023521) {
if(R.isCont($e2352023521)) {
var $ss2352423525 = {"from":L[1089],
"go":function(cont_tail_app683423530) {
return $Hcont_tail_app1088923531(cont_tail_app683423530);
}};
$e2352023521.stack[R.EXN_STACKHEIGHT++] = $ss2352423525;
}
if(R.isPyretException($e2352023521)) {
$e2352023521.pyretStack.push(L[1089]);
}
throw $e2352023521;
}
var $ret2352623527 = $Hcont_tail_app1088923531($z2352223523);
++R.GAS;
return $ret2352623527;
} else {
var cont_tail_arg683123534 = R.throwNonBooleanOp(L[3668],("second"),("and"),and_DASH_oper_DASH_82623499);
if(--R.GAS > 0) {
$z2353223533 = R.isFunction(if_helper682423500)?if_helper682423500.app(cont_tail_arg683123534):R.ffi.throwNonFunApp(L[3668],if_helper682423500,[cont_tail_arg683123534]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper682423500)?if_helper682423500.app(cont_tail_arg683123534):R.ffi.throwNonFunApp(L[3668],if_helper682423500,[cont_tail_arg683123534]);
},
"from":L[3668]});
}
++R.GAS;
return $z2353223533;
}
};
var $Hcont_tail_app1088923531 = function(cont_tail_app683423530) {
return cont_tail_app683423530;
};
var $Hcont_tail_app1089123513 = function(cont_tail_app682923512) {
return cont_tail_app682923512;
};
var $Hand_DASH_oper_DASH_108885951 = function(and_DASH_oper_DASH_8235949,ann18125950,self18095948) {
var if_helper681023548 = R.makeFunction(function(if_helper_arg681123566) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1095],1,arguments);
}
var ann_DASH_check_DASH_temp680823567 = if_helper_arg681123566;
return ann_DASH_check_DASH_temp680823567;
});
var anf_if681423565 = R.isBoolean(and_DASH_oper_DASH_8235949);
if(R.isPyretTrue(anf_if681423565)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8235949)) {
var anf_fun681623546 = G(ann18125950,"visit",L[3669]);
var $z2353823539 = D;
var $f2354423545 = function(_) {
return R.isFunction(anf_fun681623546)?anf_fun681623546.app(self18095948):R.ffi.throwNonFunApp(L[1095],anf_fun681623546,[self18095948]);
};
try {
if(--R.GAS > 0) {
$z2353823539 = $f2354423545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2354423545,
"from":L[1095]});
}
} catch($e2353623537) {
if(R.isCont($e2353623537)) {
var $ss2354023541 = {"from":L[1095],
"go":function(and_DASH_oper_DASH_82423547) {
return $Hand_DASH_oper_DASH_1088623549(and_DASH_oper_DASH_82423547,if_helper681023548);
}};
$e2353623537.stack[R.EXN_STACKHEIGHT++] = $ss2354023541;
}
if(R.isPyretException($e2353623537)) {
$e2353623537.pyretStack.push(L[1095]);
}
throw $e2353623537;
}
var $ret2354223543 = $Hand_DASH_oper_DASH_1088623549($z2353823539,if_helper681023548);
++R.GAS;
return $ret2354223543;
} else {
var $z2355223553 = D;
var $f2355823559 = function(_) {
return R.isFunction(if_helper681023548)?if_helper681023548.app((false)):R.ffi.throwNonFunApp(L[1095],if_helper681023548,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2355223553 = $f2355823559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2355823559,
"from":L[1095]});
}
} catch($e2355023551) {
if(R.isCont($e2355023551)) {
var $ss2355423555 = {"from":L[1095],
"go":function(cont_tail_app681523560) {
return $Hcont_tail_app1088723561(cont_tail_app681523560);
}};
$e2355023551.stack[R.EXN_STACKHEIGHT++] = $ss2355423555;
}
if(R.isPyretException($e2355023551)) {
$e2355023551.pyretStack.push(L[1095]);
}
throw $e2355023551;
}
var $ret2355623557 = $Hcont_tail_app1088723561($z2355223553);
++R.GAS;
return $ret2355623557;
}
} else {
var cont_tail_arg681223564 = R.throwNonBooleanOp(L[3670],("first"),("and"),and_DASH_oper_DASH_8235949);
if(--R.GAS > 0) {
$z2356223563 = R.isFunction(if_helper681023548)?if_helper681023548.app(cont_tail_arg681223564):R.ffi.throwNonFunApp(L[3670],if_helper681023548,[cont_tail_arg681223564]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper681023548)?if_helper681023548.app(cont_tail_arg681223564):R.ffi.throwNonFunApp(L[3670],if_helper681023548,[cont_tail_arg681223564]);
},
"from":L[3670]});
}
++R.GAS;
return $z2356223563;
}
};
var $Hand_DASH_oper_DASH_1088623549 = function(and_DASH_oper_DASH_82423547,if_helper681023548) {
var anf_if681923583 = R.isBoolean(and_DASH_oper_DASH_82423547);
if(R.isPyretTrue(anf_if681923583)) {
var $z2357023571 = D;
var $f2357623577 = function(_) {
return R.isFunction(if_helper681023548)?if_helper681023548.app(and_DASH_oper_DASH_82423547):R.ffi.throwNonFunApp(L[1095],if_helper681023548,[and_DASH_oper_DASH_82423547]);
};
try {
if(--R.GAS > 0) {
$z2357023571 = $f2357623577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2357623577,
"from":L[1095]});
}
} catch($e2356823569) {
if(R.isCont($e2356823569)) {
var $ss2357223573 = {"from":L[1095],
"go":function(cont_tail_app682023578) {
return $Hcont_tail_app1088523579(cont_tail_app682023578);
}};
$e2356823569.stack[R.EXN_STACKHEIGHT++] = $ss2357223573;
}
if(R.isPyretException($e2356823569)) {
$e2356823569.pyretStack.push(L[1095]);
}
throw $e2356823569;
}
var $ret2357423575 = $Hcont_tail_app1088523579($z2357023571);
++R.GAS;
return $ret2357423575;
} else {
var cont_tail_arg681723582 = R.throwNonBooleanOp(L[3671],("second"),("and"),and_DASH_oper_DASH_82423547);
if(--R.GAS > 0) {
$z2358023581 = R.isFunction(if_helper681023548)?if_helper681023548.app(cont_tail_arg681723582):R.ffi.throwNonFunApp(L[3671],if_helper681023548,[cont_tail_arg681723582]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper681023548)?if_helper681023548.app(cont_tail_arg681723582):R.ffi.throwNonFunApp(L[3671],if_helper681023548,[cont_tail_arg681723582]);
},
"from":L[3671]});
}
++R.GAS;
return $z2358023581;
}
};
var $Hcont_tail_app1088523579 = function(cont_tail_app682023578) {
return cont_tail_app682023578;
};
var $Hcont_tail_app1088723561 = function(cont_tail_app681523560) {
return cont_tail_app681523560;
};
var $Hand_DASH_oper_DASH_108845968 = function(and_DASH_oper_DASH_8215966,block18085967,self18055965) {
var if_helper679623596 = R.makeFunction(function(if_helper_arg679723614) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1101],1,arguments);
}
var ann_DASH_check_DASH_temp679423615 = if_helper_arg679723614;
return ann_DASH_check_DASH_temp679423615;
});
var anf_if680023613 = R.isBoolean(and_DASH_oper_DASH_8215966);
if(R.isPyretTrue(anf_if680023613)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8215966)) {
var anf_fun680223594 = G(block18085967,"visit",L[3672]);
var $z2358623587 = D;
var $f2359223593 = function(_) {
return R.isFunction(anf_fun680223594)?anf_fun680223594.app(self18055965):R.ffi.throwNonFunApp(L[1101],anf_fun680223594,[self18055965]);
};
try {
if(--R.GAS > 0) {
$z2358623587 = $f2359223593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2359223593,
"from":L[1101]});
}
} catch($e2358423585) {
if(R.isCont($e2358423585)) {
var $ss2358823589 = {"from":L[1101],
"go":function(and_DASH_oper_DASH_82223595) {
return $Hand_DASH_oper_DASH_1088223597(and_DASH_oper_DASH_82223595,if_helper679623596);
}};
$e2358423585.stack[R.EXN_STACKHEIGHT++] = $ss2358823589;
}
if(R.isPyretException($e2358423585)) {
$e2358423585.pyretStack.push(L[1101]);
}
throw $e2358423585;
}
var $ret2359023591 = $Hand_DASH_oper_DASH_1088223597($z2358623587,if_helper679623596);
++R.GAS;
return $ret2359023591;
} else {
var $z2360023601 = D;
var $f2360623607 = function(_) {
return R.isFunction(if_helper679623596)?if_helper679623596.app((false)):R.ffi.throwNonFunApp(L[1101],if_helper679623596,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2360023601 = $f2360623607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2360623607,
"from":L[1101]});
}
} catch($e2359823599) {
if(R.isCont($e2359823599)) {
var $ss2360223603 = {"from":L[1101],
"go":function(cont_tail_app680123608) {
return $Hcont_tail_app1088323609(cont_tail_app680123608);
}};
$e2359823599.stack[R.EXN_STACKHEIGHT++] = $ss2360223603;
}
if(R.isPyretException($e2359823599)) {
$e2359823599.pyretStack.push(L[1101]);
}
throw $e2359823599;
}
var $ret2360423605 = $Hcont_tail_app1088323609($z2360023601);
++R.GAS;
return $ret2360423605;
}
} else {
var cont_tail_arg679823612 = R.throwNonBooleanOp(L[3673],("first"),("and"),and_DASH_oper_DASH_8215966);
if(--R.GAS > 0) {
$z2361023611 = R.isFunction(if_helper679623596)?if_helper679623596.app(cont_tail_arg679823612):R.ffi.throwNonFunApp(L[3673],if_helper679623596,[cont_tail_arg679823612]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper679623596)?if_helper679623596.app(cont_tail_arg679823612):R.ffi.throwNonFunApp(L[3673],if_helper679623596,[cont_tail_arg679823612]);
},
"from":L[3673]});
}
++R.GAS;
return $z2361023611;
}
};
var $Hand_DASH_oper_DASH_1088223597 = function(and_DASH_oper_DASH_82223595,if_helper679623596) {
var anf_if680523631 = R.isBoolean(and_DASH_oper_DASH_82223595);
if(R.isPyretTrue(anf_if680523631)) {
var $z2361823619 = D;
var $f2362423625 = function(_) {
return R.isFunction(if_helper679623596)?if_helper679623596.app(and_DASH_oper_DASH_82223595):R.ffi.throwNonFunApp(L[1101],if_helper679623596,[and_DASH_oper_DASH_82223595]);
};
try {
if(--R.GAS > 0) {
$z2361823619 = $f2362423625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2362423625,
"from":L[1101]});
}
} catch($e2361623617) {
if(R.isCont($e2361623617)) {
var $ss2362023621 = {"from":L[1101],
"go":function(cont_tail_app680623626) {
return $Hcont_tail_app1088123627(cont_tail_app680623626);
}};
$e2361623617.stack[R.EXN_STACKHEIGHT++] = $ss2362023621;
}
if(R.isPyretException($e2361623617)) {
$e2361623617.pyretStack.push(L[1101]);
}
throw $e2361623617;
}
var $ret2362223623 = $Hcont_tail_app1088123627($z2361823619);
++R.GAS;
return $ret2362223623;
} else {
var cont_tail_arg680323630 = R.throwNonBooleanOp(L[3674],("second"),("and"),and_DASH_oper_DASH_82223595);
if(--R.GAS > 0) {
$z2362823629 = R.isFunction(if_helper679623596)?if_helper679623596.app(cont_tail_arg680323630):R.ffi.throwNonFunApp(L[3674],if_helper679623596,[cont_tail_arg680323630]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper679623596)?if_helper679623596.app(cont_tail_arg680323630):R.ffi.throwNonFunApp(L[3674],if_helper679623596,[cont_tail_arg680323630]);
},
"from":L[3674]});
}
++R.GAS;
return $z2362823629;
}
};
var $Hcont_tail_app1088123627 = function(cont_tail_app680623626) {
return cont_tail_app680623626;
};
var $Hcont_tail_app1088323609 = function(cont_tail_app680123608) {
return cont_tail_app680123608;
};
var $Hann_DASH_check_DASH_temp108805985 = function(ann_DASH_check_DASH_temp67885984) {
return ann_DASH_check_DASH_temp67885984;
};
var $Hann_DASH_check_DASH_temp108796000 = function(ann_DASH_check_DASH_temp67905999) {
return ann_DASH_check_DASH_temp67905999;
};
var $Hand_DASH_oper_DASH_108786016 = function(and_DASH_oper_DASH_8186014,self17976013,value18006015) {
var if_helper677623644 = R.makeFunction(function(if_helper_arg677723662) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1112],1,arguments);
}
var ann_DASH_check_DASH_temp677423663 = if_helper_arg677723662;
return ann_DASH_check_DASH_temp677423663;
});
var anf_if678023661 = R.isBoolean(and_DASH_oper_DASH_8186014);
if(R.isPyretTrue(anf_if678023661)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8186014)) {
var anf_fun678223642 = G(value18006015,"visit",L[3675]);
var $z2363423635 = D;
var $f2364023641 = function(_) {
return R.isFunction(anf_fun678223642)?anf_fun678223642.app(self17976013):R.ffi.throwNonFunApp(L[1112],anf_fun678223642,[self17976013]);
};
try {
if(--R.GAS > 0) {
$z2363423635 = $f2364023641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2364023641,
"from":L[1112]});
}
} catch($e2363223633) {
if(R.isCont($e2363223633)) {
var $ss2363623637 = {"from":L[1112],
"go":function(and_DASH_oper_DASH_81923643) {
return $Hand_DASH_oper_DASH_1087623645(and_DASH_oper_DASH_81923643,if_helper677623644);
}};
$e2363223633.stack[R.EXN_STACKHEIGHT++] = $ss2363623637;
}
if(R.isPyretException($e2363223633)) {
$e2363223633.pyretStack.push(L[1112]);
}
throw $e2363223633;
}
var $ret2363823639 = $Hand_DASH_oper_DASH_1087623645($z2363423635,if_helper677623644);
++R.GAS;
return $ret2363823639;
} else {
var $z2364823649 = D;
var $f2365423655 = function(_) {
return R.isFunction(if_helper677623644)?if_helper677623644.app((false)):R.ffi.throwNonFunApp(L[1112],if_helper677623644,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2364823649 = $f2365423655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2365423655,
"from":L[1112]});
}
} catch($e2364623647) {
if(R.isCont($e2364623647)) {
var $ss2365023651 = {"from":L[1112],
"go":function(cont_tail_app678123656) {
return $Hcont_tail_app1087723657(cont_tail_app678123656);
}};
$e2364623647.stack[R.EXN_STACKHEIGHT++] = $ss2365023651;
}
if(R.isPyretException($e2364623647)) {
$e2364623647.pyretStack.push(L[1112]);
}
throw $e2364623647;
}
var $ret2365223653 = $Hcont_tail_app1087723657($z2364823649);
++R.GAS;
return $ret2365223653;
}
} else {
var cont_tail_arg677823660 = R.throwNonBooleanOp(L[3676],("first"),("and"),and_DASH_oper_DASH_8186014);
if(--R.GAS > 0) {
$z2365823659 = R.isFunction(if_helper677623644)?if_helper677623644.app(cont_tail_arg677823660):R.ffi.throwNonFunApp(L[3676],if_helper677623644,[cont_tail_arg677823660]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper677623644)?if_helper677623644.app(cont_tail_arg677823660):R.ffi.throwNonFunApp(L[3676],if_helper677623644,[cont_tail_arg677823660]);
},
"from":L[3676]});
}
++R.GAS;
return $z2365823659;
}
};
var $Hand_DASH_oper_DASH_1087623645 = function(and_DASH_oper_DASH_81923643,if_helper677623644) {
var anf_if678523679 = R.isBoolean(and_DASH_oper_DASH_81923643);
if(R.isPyretTrue(anf_if678523679)) {
var $z2366623667 = D;
var $f2367223673 = function(_) {
return R.isFunction(if_helper677623644)?if_helper677623644.app(and_DASH_oper_DASH_81923643):R.ffi.throwNonFunApp(L[1112],if_helper677623644,[and_DASH_oper_DASH_81923643]);
};
try {
if(--R.GAS > 0) {
$z2366623667 = $f2367223673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2367223673,
"from":L[1112]});
}
} catch($e2366423665) {
if(R.isCont($e2366423665)) {
var $ss2366823669 = {"from":L[1112],
"go":function(cont_tail_app678623674) {
return $Hcont_tail_app1087523675(cont_tail_app678623674);
}};
$e2366423665.stack[R.EXN_STACKHEIGHT++] = $ss2366823669;
}
if(R.isPyretException($e2366423665)) {
$e2366423665.pyretStack.push(L[1112]);
}
throw $e2366423665;
}
var $ret2367023671 = $Hcont_tail_app1087523675($z2366623667);
++R.GAS;
return $ret2367023671;
} else {
var cont_tail_arg678323678 = R.throwNonBooleanOp(L[3677],("second"),("and"),and_DASH_oper_DASH_81923643);
if(--R.GAS > 0) {
$z2367623677 = R.isFunction(if_helper677623644)?if_helper677623644.app(cont_tail_arg678323678):R.ffi.throwNonFunApp(L[3677],if_helper677623644,[cont_tail_arg678323678]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper677623644)?if_helper677623644.app(cont_tail_arg678323678):R.ffi.throwNonFunApp(L[3677],if_helper677623644,[cont_tail_arg678323678]);
},
"from":L[3677]});
}
++R.GAS;
return $z2367623677;
}
};
var $Hcont_tail_app1087523675 = function(cont_tail_app678623674) {
return cont_tail_app678623674;
};
var $Hcont_tail_app1087723657 = function(cont_tail_app678123656) {
return cont_tail_app678123656;
};
var $Hand_DASH_oper_DASH_108746034 = function(and_DASH_oper_DASH_8166032,self17936031,value17966033) {
var if_helper676223692 = R.makeFunction(function(if_helper_arg676323710) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1119],1,arguments);
}
var ann_DASH_check_DASH_temp676023711 = if_helper_arg676323710;
return ann_DASH_check_DASH_temp676023711;
});
var anf_if676623709 = R.isBoolean(and_DASH_oper_DASH_8166032);
if(R.isPyretTrue(anf_if676623709)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8166032)) {
var anf_fun676823690 = G(value17966033,"visit",L[3678]);
var $z2368223683 = D;
var $f2368823689 = function(_) {
return R.isFunction(anf_fun676823690)?anf_fun676823690.app(self17936031):R.ffi.throwNonFunApp(L[1119],anf_fun676823690,[self17936031]);
};
try {
if(--R.GAS > 0) {
$z2368223683 = $f2368823689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2368823689,
"from":L[1119]});
}
} catch($e2368023681) {
if(R.isCont($e2368023681)) {
var $ss2368423685 = {"from":L[1119],
"go":function(and_DASH_oper_DASH_81723691) {
return $Hand_DASH_oper_DASH_1087223693(and_DASH_oper_DASH_81723691,if_helper676223692);
}};
$e2368023681.stack[R.EXN_STACKHEIGHT++] = $ss2368423685;
}
if(R.isPyretException($e2368023681)) {
$e2368023681.pyretStack.push(L[1119]);
}
throw $e2368023681;
}
var $ret2368623687 = $Hand_DASH_oper_DASH_1087223693($z2368223683,if_helper676223692);
++R.GAS;
return $ret2368623687;
} else {
var $z2369623697 = D;
var $f2370223703 = function(_) {
return R.isFunction(if_helper676223692)?if_helper676223692.app((false)):R.ffi.throwNonFunApp(L[1119],if_helper676223692,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2369623697 = $f2370223703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2370223703,
"from":L[1119]});
}
} catch($e2369423695) {
if(R.isCont($e2369423695)) {
var $ss2369823699 = {"from":L[1119],
"go":function(cont_tail_app676723704) {
return $Hcont_tail_app1087323705(cont_tail_app676723704);
}};
$e2369423695.stack[R.EXN_STACKHEIGHT++] = $ss2369823699;
}
if(R.isPyretException($e2369423695)) {
$e2369423695.pyretStack.push(L[1119]);
}
throw $e2369423695;
}
var $ret2370023701 = $Hcont_tail_app1087323705($z2369623697);
++R.GAS;
return $ret2370023701;
}
} else {
var cont_tail_arg676423708 = R.throwNonBooleanOp(L[3679],("first"),("and"),and_DASH_oper_DASH_8166032);
if(--R.GAS > 0) {
$z2370623707 = R.isFunction(if_helper676223692)?if_helper676223692.app(cont_tail_arg676423708):R.ffi.throwNonFunApp(L[3679],if_helper676223692,[cont_tail_arg676423708]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper676223692)?if_helper676223692.app(cont_tail_arg676423708):R.ffi.throwNonFunApp(L[3679],if_helper676223692,[cont_tail_arg676423708]);
},
"from":L[3679]});
}
++R.GAS;
return $z2370623707;
}
};
var $Hand_DASH_oper_DASH_1087223693 = function(and_DASH_oper_DASH_81723691,if_helper676223692) {
var anf_if677123727 = R.isBoolean(and_DASH_oper_DASH_81723691);
if(R.isPyretTrue(anf_if677123727)) {
var $z2371423715 = D;
var $f2372023721 = function(_) {
return R.isFunction(if_helper676223692)?if_helper676223692.app(and_DASH_oper_DASH_81723691):R.ffi.throwNonFunApp(L[1119],if_helper676223692,[and_DASH_oper_DASH_81723691]);
};
try {
if(--R.GAS > 0) {
$z2371423715 = $f2372023721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2372023721,
"from":L[1119]});
}
} catch($e2371223713) {
if(R.isCont($e2371223713)) {
var $ss2371623717 = {"from":L[1119],
"go":function(cont_tail_app677223722) {
return $Hcont_tail_app1087123723(cont_tail_app677223722);
}};
$e2371223713.stack[R.EXN_STACKHEIGHT++] = $ss2371623717;
}
if(R.isPyretException($e2371223713)) {
$e2371223713.pyretStack.push(L[1119]);
}
throw $e2371223713;
}
var $ret2371823719 = $Hcont_tail_app1087123723($z2371423715);
++R.GAS;
return $ret2371823719;
} else {
var cont_tail_arg676923726 = R.throwNonBooleanOp(L[3680],("second"),("and"),and_DASH_oper_DASH_81723691);
if(--R.GAS > 0) {
$z2372423725 = R.isFunction(if_helper676223692)?if_helper676223692.app(cont_tail_arg676923726):R.ffi.throwNonFunApp(L[3680],if_helper676223692,[cont_tail_arg676923726]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper676223692)?if_helper676223692.app(cont_tail_arg676923726):R.ffi.throwNonFunApp(L[3680],if_helper676223692,[cont_tail_arg676923726]);
},
"from":L[3680]});
}
++R.GAS;
return $z2372423725;
}
};
var $Hcont_tail_app1087123723 = function(cont_tail_app677223722) {
return cont_tail_app677223722;
};
var $Hcont_tail_app1087323705 = function(cont_tail_app676723704) {
return cont_tail_app676723704;
};
var $Hand_DASH_oper_DASH_108706051 = function(and_DASH_oper_DASH_8146049,namet17926050,self17896048) {
var if_helper674823740 = R.makeFunction(function(if_helper_arg674923758) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1125],1,arguments);
}
var ann_DASH_check_DASH_temp674623759 = if_helper_arg674923758;
return ann_DASH_check_DASH_temp674623759;
});
var anf_if675223757 = R.isBoolean(and_DASH_oper_DASH_8146049);
if(R.isPyretTrue(anf_if675223757)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8146049)) {
var anf_fun675423738 = G(namet17926050,"visit",L[3681]);
var $z2373023731 = D;
var $f2373623737 = function(_) {
return R.isFunction(anf_fun675423738)?anf_fun675423738.app(self17896048):R.ffi.throwNonFunApp(L[1125],anf_fun675423738,[self17896048]);
};
try {
if(--R.GAS > 0) {
$z2373023731 = $f2373623737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2373623737,
"from":L[1125]});
}
} catch($e2372823729) {
if(R.isCont($e2372823729)) {
var $ss2373223733 = {"from":L[1125],
"go":function(and_DASH_oper_DASH_81523739) {
return $Hand_DASH_oper_DASH_1086823741(and_DASH_oper_DASH_81523739,if_helper674823740);
}};
$e2372823729.stack[R.EXN_STACKHEIGHT++] = $ss2373223733;
}
if(R.isPyretException($e2372823729)) {
$e2372823729.pyretStack.push(L[1125]);
}
throw $e2372823729;
}
var $ret2373423735 = $Hand_DASH_oper_DASH_1086823741($z2373023731,if_helper674823740);
++R.GAS;
return $ret2373423735;
} else {
var $z2374423745 = D;
var $f2375023751 = function(_) {
return R.isFunction(if_helper674823740)?if_helper674823740.app((false)):R.ffi.throwNonFunApp(L[1125],if_helper674823740,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2374423745 = $f2375023751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2375023751,
"from":L[1125]});
}
} catch($e2374223743) {
if(R.isCont($e2374223743)) {
var $ss2374623747 = {"from":L[1125],
"go":function(cont_tail_app675323752) {
return $Hcont_tail_app1086923753(cont_tail_app675323752);
}};
$e2374223743.stack[R.EXN_STACKHEIGHT++] = $ss2374623747;
}
if(R.isPyretException($e2374223743)) {
$e2374223743.pyretStack.push(L[1125]);
}
throw $e2374223743;
}
var $ret2374823749 = $Hcont_tail_app1086923753($z2374423745);
++R.GAS;
return $ret2374823749;
}
} else {
var cont_tail_arg675023756 = R.throwNonBooleanOp(L[3682],("first"),("and"),and_DASH_oper_DASH_8146049);
if(--R.GAS > 0) {
$z2375423755 = R.isFunction(if_helper674823740)?if_helper674823740.app(cont_tail_arg675023756):R.ffi.throwNonFunApp(L[3682],if_helper674823740,[cont_tail_arg675023756]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper674823740)?if_helper674823740.app(cont_tail_arg675023756):R.ffi.throwNonFunApp(L[3682],if_helper674823740,[cont_tail_arg675023756]);
},
"from":L[3682]});
}
++R.GAS;
return $z2375423755;
}
};
var $Hand_DASH_oper_DASH_1086823741 = function(and_DASH_oper_DASH_81523739,if_helper674823740) {
var anf_if675723775 = R.isBoolean(and_DASH_oper_DASH_81523739);
if(R.isPyretTrue(anf_if675723775)) {
var $z2376223763 = D;
var $f2376823769 = function(_) {
return R.isFunction(if_helper674823740)?if_helper674823740.app(and_DASH_oper_DASH_81523739):R.ffi.throwNonFunApp(L[1125],if_helper674823740,[and_DASH_oper_DASH_81523739]);
};
try {
if(--R.GAS > 0) {
$z2376223763 = $f2376823769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2376823769,
"from":L[1125]});
}
} catch($e2376023761) {
if(R.isCont($e2376023761)) {
var $ss2376423765 = {"from":L[1125],
"go":function(cont_tail_app675823770) {
return $Hcont_tail_app1086723771(cont_tail_app675823770);
}};
$e2376023761.stack[R.EXN_STACKHEIGHT++] = $ss2376423765;
}
if(R.isPyretException($e2376023761)) {
$e2376023761.pyretStack.push(L[1125]);
}
throw $e2376023761;
}
var $ret2376623767 = $Hcont_tail_app1086723771($z2376223763);
++R.GAS;
return $ret2376623767;
} else {
var cont_tail_arg675523774 = R.throwNonBooleanOp(L[3683],("second"),("and"),and_DASH_oper_DASH_81523739);
if(--R.GAS > 0) {
$z2377223773 = R.isFunction(if_helper674823740)?if_helper674823740.app(cont_tail_arg675523774):R.ffi.throwNonFunApp(L[3683],if_helper674823740,[cont_tail_arg675523774]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper674823740)?if_helper674823740.app(cont_tail_arg675523774):R.ffi.throwNonFunApp(L[3683],if_helper674823740,[cont_tail_arg675523774]);
},
"from":L[3683]});
}
++R.GAS;
return $z2377223773;
}
};
var $Hcont_tail_app1086723771 = function(cont_tail_app675823770) {
return cont_tail_app675823770;
};
var $Hcont_tail_app1086923753 = function(cont_tail_app675323752) {
return cont_tail_app675323752;
};
var $Hand_DASH_oper_DASH_108666068 = function(and_DASH_oper_DASH_8126066,ann17886067,self17856065) {
var if_helper673423788 = R.makeFunction(function(if_helper_arg673523806) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1131],1,arguments);
}
var ann_DASH_check_DASH_temp673223807 = if_helper_arg673523806;
return ann_DASH_check_DASH_temp673223807;
});
var anf_if673823805 = R.isBoolean(and_DASH_oper_DASH_8126066);
if(R.isPyretTrue(anf_if673823805)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8126066)) {
var anf_fun674023786 = G(ann17886067,"visit",L[3684]);
var $z2377823779 = D;
var $f2378423785 = function(_) {
return R.isFunction(anf_fun674023786)?anf_fun674023786.app(self17856065):R.ffi.throwNonFunApp(L[1131],anf_fun674023786,[self17856065]);
};
try {
if(--R.GAS > 0) {
$z2377823779 = $f2378423785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2378423785,
"from":L[1131]});
}
} catch($e2377623777) {
if(R.isCont($e2377623777)) {
var $ss2378023781 = {"from":L[1131],
"go":function(and_DASH_oper_DASH_81323787) {
return $Hand_DASH_oper_DASH_1086423789(and_DASH_oper_DASH_81323787,if_helper673423788);
}};
$e2377623777.stack[R.EXN_STACKHEIGHT++] = $ss2378023781;
}
if(R.isPyretException($e2377623777)) {
$e2377623777.pyretStack.push(L[1131]);
}
throw $e2377623777;
}
var $ret2378223783 = $Hand_DASH_oper_DASH_1086423789($z2377823779,if_helper673423788);
++R.GAS;
return $ret2378223783;
} else {
var $z2379223793 = D;
var $f2379823799 = function(_) {
return R.isFunction(if_helper673423788)?if_helper673423788.app((false)):R.ffi.throwNonFunApp(L[1131],if_helper673423788,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2379223793 = $f2379823799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2379823799,
"from":L[1131]});
}
} catch($e2379023791) {
if(R.isCont($e2379023791)) {
var $ss2379423795 = {"from":L[1131],
"go":function(cont_tail_app673923800) {
return $Hcont_tail_app1086523801(cont_tail_app673923800);
}};
$e2379023791.stack[R.EXN_STACKHEIGHT++] = $ss2379423795;
}
if(R.isPyretException($e2379023791)) {
$e2379023791.pyretStack.push(L[1131]);
}
throw $e2379023791;
}
var $ret2379623797 = $Hcont_tail_app1086523801($z2379223793);
++R.GAS;
return $ret2379623797;
}
} else {
var cont_tail_arg673623804 = R.throwNonBooleanOp(L[3685],("first"),("and"),and_DASH_oper_DASH_8126066);
if(--R.GAS > 0) {
$z2380223803 = R.isFunction(if_helper673423788)?if_helper673423788.app(cont_tail_arg673623804):R.ffi.throwNonFunApp(L[3685],if_helper673423788,[cont_tail_arg673623804]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper673423788)?if_helper673423788.app(cont_tail_arg673623804):R.ffi.throwNonFunApp(L[3685],if_helper673423788,[cont_tail_arg673623804]);
},
"from":L[3685]});
}
++R.GAS;
return $z2380223803;
}
};
var $Hand_DASH_oper_DASH_1086423789 = function(and_DASH_oper_DASH_81323787,if_helper673423788) {
var anf_if674323823 = R.isBoolean(and_DASH_oper_DASH_81323787);
if(R.isPyretTrue(anf_if674323823)) {
var $z2381023811 = D;
var $f2381623817 = function(_) {
return R.isFunction(if_helper673423788)?if_helper673423788.app(and_DASH_oper_DASH_81323787):R.ffi.throwNonFunApp(L[1131],if_helper673423788,[and_DASH_oper_DASH_81323787]);
};
try {
if(--R.GAS > 0) {
$z2381023811 = $f2381623817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2381623817,
"from":L[1131]});
}
} catch($e2380823809) {
if(R.isCont($e2380823809)) {
var $ss2381223813 = {"from":L[1131],
"go":function(cont_tail_app674423818) {
return $Hcont_tail_app1086323819(cont_tail_app674423818);
}};
$e2380823809.stack[R.EXN_STACKHEIGHT++] = $ss2381223813;
}
if(R.isPyretException($e2380823809)) {
$e2380823809.pyretStack.push(L[1131]);
}
throw $e2380823809;
}
var $ret2381423815 = $Hcont_tail_app1086323819($z2381023811);
++R.GAS;
return $ret2381423815;
} else {
var cont_tail_arg674123822 = R.throwNonBooleanOp(L[3686],("second"),("and"),and_DASH_oper_DASH_81323787);
if(--R.GAS > 0) {
$z2382023821 = R.isFunction(if_helper673423788)?if_helper673423788.app(cont_tail_arg674123822):R.ffi.throwNonFunApp(L[3686],if_helper673423788,[cont_tail_arg674123822]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper673423788)?if_helper673423788.app(cont_tail_arg674123822):R.ffi.throwNonFunApp(L[3686],if_helper673423788,[cont_tail_arg674123822]);
},
"from":L[3686]});
}
++R.GAS;
return $z2382023821;
}
};
var $Hcont_tail_app1086323819 = function(cont_tail_app674423818) {
return cont_tail_app674423818;
};
var $Hcont_tail_app1086523801 = function(cont_tail_app673923800) {
return cont_tail_app673923800;
};
var $Hand_DASH_oper_DASH_108626090 = function(and_DASH_oper_DASH_8056084,_check17846085,ann17816086,args17806087,body17836088,lists974,self17766089) {
var if_helper670223837 = R.makeFunction(function(if_helper_arg670323869) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1137],1,arguments);
}
var ann_DASH_check_DASH_temp669723870 = if_helper_arg670323869;
return ann_DASH_check_DASH_temp669723870;
});
var anf_if670623868 = R.isBoolean(and_DASH_oper_DASH_8056084);
if(R.isPyretTrue(anf_if670623868)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8056084)) {
var anf_fun670823834 = G(lists974,"all",L[3688]);
var anf_arg671123835 = R.makeFunction(function(recv_DASH_80823839) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3687],1,arguments);
}
var anf_fun671023850 = G(recv_DASH_80823839,"visit",L[3687]);
var $z2384223843 = D;
var $f2384823849 = function(_) {
return R.isFunction(anf_fun671023850)?anf_fun671023850.app(self17766089):R.ffi.throwNonFunApp(L[3687],anf_fun671023850,[self17766089]);
};
try {
if(--R.GAS > 0) {
$z2384223843 = $f2384823849();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2384823849,
"from":L[3687]});
}
} catch($e2384023841) {
if(R.isCont($e2384023841)) {
var $ss2384423845 = {"from":L[3687],
"go":function(ann_DASH_check_DASH_temp670923851) {
return $Hann_DASH_check_DASH_temp1085223852(ann_DASH_check_DASH_temp670923851);
}};
$e2384023841.stack[R.EXN_STACKHEIGHT++] = $ss2384423845;
}
if(R.isPyretException($e2384023841)) {
$e2384023841.pyretStack.push(L[3687]);
}
throw $e2384023841;
}
var $ret2384623847 = $Hann_DASH_check_DASH_temp1085223852($z2384223843);
++R.GAS;
return $ret2384623847;
});
var $z2382623827 = D;
var $f2383223833 = function(_) {
return R.isFunction(anf_fun670823834)?anf_fun670823834.app(anf_arg671123835,args17806087):R.ffi.throwNonFunApp(L[1137],anf_fun670823834,[anf_arg671123835,args17806087]);
};
try {
if(--R.GAS > 0) {
$z2382623827 = $f2383223833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2383223833,
"from":L[1137]});
}
} catch($e2382423825) {
if(R.isCont($e2382423825)) {
var $ss2382823829 = {"from":L[1137],
"go":function(and_DASH_oper_DASH_80723836) {
return $Hand_DASH_oper_DASH_1086023838(and_DASH_oper_DASH_80723836,_check17846085,ann17816086,body17836088,if_helper670223837,self17766089);
}};
$e2382423825.stack[R.EXN_STACKHEIGHT++] = $ss2382823829;
}
if(R.isPyretException($e2382423825)) {
$e2382423825.pyretStack.push(L[1137]);
}
throw $e2382423825;
}
var $ret2383023831 = $Hand_DASH_oper_DASH_1086023838($z2382623827,_check17846085,ann17816086,body17836088,if_helper670223837,self17766089);
++R.GAS;
return $ret2383023831;
} else {
var $z2385523856 = D;
var $f2386123862 = function(_) {
return R.isFunction(if_helper670223837)?if_helper670223837.app((false)):R.ffi.throwNonFunApp(L[1137],if_helper670223837,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2385523856 = $f2386123862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2386123862,
"from":L[1137]});
}
} catch($e2385323854) {
if(R.isCont($e2385323854)) {
var $ss2385723858 = {"from":L[1137],
"go":function(cont_tail_app670723863) {
return $Hcont_tail_app1086123864(cont_tail_app670723863);
}};
$e2385323854.stack[R.EXN_STACKHEIGHT++] = $ss2385723858;
}
if(R.isPyretException($e2385323854)) {
$e2385323854.pyretStack.push(L[1137]);
}
throw $e2385323854;
}
var $ret2385923860 = $Hcont_tail_app1086123864($z2385523856);
++R.GAS;
return $ret2385923860;
}
} else {
var cont_tail_arg670423867 = R.throwNonBooleanOp(L[3689],("first"),("and"),and_DASH_oper_DASH_8056084);
if(--R.GAS > 0) {
$z2386523866 = R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg670423867):R.ffi.throwNonFunApp(L[3689],if_helper670223837,[cont_tail_arg670423867]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg670423867):R.ffi.throwNonFunApp(L[3689],if_helper670223837,[cont_tail_arg670423867]);
},
"from":L[3689]});
}
++R.GAS;
return $z2386523866;
}
};
var $Hand_DASH_oper_DASH_1086023838 = function(and_DASH_oper_DASH_80723836,_check17846085,ann17816086,body17836088,if_helper670223837,self17766089) {
var anf_if671423899 = R.isBoolean(and_DASH_oper_DASH_80723836);
if(R.isPyretTrue(anf_if671423899)) {
if(R.isPyretTrue(and_DASH_oper_DASH_80723836)) {
var anf_fun671623881 = G(ann17816086,"visit",L[3690]);
var $z2387323874 = D;
var $f2387923880 = function(_) {
return R.isFunction(anf_fun671623881)?anf_fun671623881.app(self17766089):R.ffi.throwNonFunApp(L[1137],anf_fun671623881,[self17766089]);
};
try {
if(--R.GAS > 0) {
$z2387323874 = $f2387923880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2387923880,
"from":L[1137]});
}
} catch($e2387123872) {
if(R.isCont($e2387123872)) {
var $ss2387523876 = {"from":L[1137],
"go":function(and_DASH_oper_DASH_80923882) {
return $Hand_DASH_oper_DASH_1085823883(and_DASH_oper_DASH_80923882,_check17846085,body17836088,if_helper670223837,self17766089);
}};
$e2387123872.stack[R.EXN_STACKHEIGHT++] = $ss2387523876;
}
if(R.isPyretException($e2387123872)) {
$e2387123872.pyretStack.push(L[1137]);
}
throw $e2387123872;
}
var $ret2387723878 = $Hand_DASH_oper_DASH_1085823883($z2387323874,_check17846085,body17836088,if_helper670223837,self17766089);
++R.GAS;
return $ret2387723878;
} else {
var $z2388623887 = D;
var $f2389223893 = function(_) {
return R.isFunction(if_helper670223837)?if_helper670223837.app((false)):R.ffi.throwNonFunApp(L[1137],if_helper670223837,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2388623887 = $f2389223893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2389223893,
"from":L[1137]});
}
} catch($e2388423885) {
if(R.isCont($e2388423885)) {
var $ss2388823889 = {"from":L[1137],
"go":function(cont_tail_app671523894) {
return $Hcont_tail_app1085923895(cont_tail_app671523894);
}};
$e2388423885.stack[R.EXN_STACKHEIGHT++] = $ss2388823889;
}
if(R.isPyretException($e2388423885)) {
$e2388423885.pyretStack.push(L[1137]);
}
throw $e2388423885;
}
var $ret2389023891 = $Hcont_tail_app1085923895($z2388623887);
++R.GAS;
return $ret2389023891;
}
} else {
var cont_tail_arg671223898 = R.throwNonBooleanOp(L[3691],("first"),("and"),and_DASH_oper_DASH_80723836);
if(--R.GAS > 0) {
$z2389623897 = R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg671223898):R.ffi.throwNonFunApp(L[3691],if_helper670223837,[cont_tail_arg671223898]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg671223898):R.ffi.throwNonFunApp(L[3691],if_helper670223837,[cont_tail_arg671223898]);
},
"from":L[3691]});
}
++R.GAS;
return $z2389623897;
}
};
var $Hand_DASH_oper_DASH_1085823883 = function(and_DASH_oper_DASH_80923882,_check17846085,body17836088,if_helper670223837,self17766089) {
var anf_if671923928 = R.isBoolean(and_DASH_oper_DASH_80923882);
if(R.isPyretTrue(anf_if671923928)) {
if(R.isPyretTrue(and_DASH_oper_DASH_80923882)) {
var anf_fun672123910 = G(body17836088,"visit",L[3692]);
var $z2390223903 = D;
var $f2390823909 = function(_) {
return R.isFunction(anf_fun672123910)?anf_fun672123910.app(self17766089):R.ffi.throwNonFunApp(L[1137],anf_fun672123910,[self17766089]);
};
try {
if(--R.GAS > 0) {
$z2390223903 = $f2390823909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2390823909,
"from":L[1137]});
}
} catch($e2390023901) {
if(R.isCont($e2390023901)) {
var $ss2390423905 = {"from":L[1137],
"go":function(and_DASH_oper_DASH_81023911) {
return $Hand_DASH_oper_DASH_1085623912(and_DASH_oper_DASH_81023911,_check17846085,if_helper670223837,self17766089);
}};
$e2390023901.stack[R.EXN_STACKHEIGHT++] = $ss2390423905;
}
if(R.isPyretException($e2390023901)) {
$e2390023901.pyretStack.push(L[1137]);
}
throw $e2390023901;
}
var $ret2390623907 = $Hand_DASH_oper_DASH_1085623912($z2390223903,_check17846085,if_helper670223837,self17766089);
++R.GAS;
return $ret2390623907;
} else {
var $z2391523916 = D;
var $f2392123922 = function(_) {
return R.isFunction(if_helper670223837)?if_helper670223837.app((false)):R.ffi.throwNonFunApp(L[1137],if_helper670223837,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2391523916 = $f2392123922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2392123922,
"from":L[1137]});
}
} catch($e2391323914) {
if(R.isCont($e2391323914)) {
var $ss2391723918 = {"from":L[1137],
"go":function(cont_tail_app672023923) {
return $Hcont_tail_app1085723924(cont_tail_app672023923);
}};
$e2391323914.stack[R.EXN_STACKHEIGHT++] = $ss2391723918;
}
if(R.isPyretException($e2391323914)) {
$e2391323914.pyretStack.push(L[1137]);
}
throw $e2391323914;
}
var $ret2391923920 = $Hcont_tail_app1085723924($z2391523916);
++R.GAS;
return $ret2391923920;
}
} else {
var cont_tail_arg671723927 = R.throwNonBooleanOp(L[3693],("first"),("and"),and_DASH_oper_DASH_80923882);
if(--R.GAS > 0) {
$z2392523926 = R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg671723927):R.ffi.throwNonFunApp(L[3693],if_helper670223837,[cont_tail_arg671723927]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg671723927):R.ffi.throwNonFunApp(L[3693],if_helper670223837,[cont_tail_arg671723927]);
},
"from":L[3693]});
}
++R.GAS;
return $z2392523926;
}
};
var $Hand_DASH_oper_DASH_1085623912 = function(and_DASH_oper_DASH_81023911,_check17846085,if_helper670223837,self17766089) {
var anf_if672423957 = R.isBoolean(and_DASH_oper_DASH_81023911);
if(R.isPyretTrue(anf_if672423957)) {
if(R.isPyretTrue(and_DASH_oper_DASH_81023911)) {
var anf_fun672623939 = G(self17766089,"option",L[3694]);
var $z2393123932 = D;
var $f2393723938 = function(_) {
return R.isFunction(anf_fun672623939)?anf_fun672623939.app(_check17846085):R.ffi.throwNonFunApp(L[1137],anf_fun672623939,[_check17846085]);
};
try {
if(--R.GAS > 0) {
$z2393123932 = $f2393723938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2393723938,
"from":L[1137]});
}
} catch($e2392923930) {
if(R.isCont($e2392923930)) {
var $ss2393323934 = {"from":L[1137],
"go":function(and_DASH_oper_DASH_81123940) {
return $Hand_DASH_oper_DASH_1085423941(and_DASH_oper_DASH_81123940,if_helper670223837);
}};
$e2392923930.stack[R.EXN_STACKHEIGHT++] = $ss2393323934;
}
if(R.isPyretException($e2392923930)) {
$e2392923930.pyretStack.push(L[1137]);
}
throw $e2392923930;
}
var $ret2393523936 = $Hand_DASH_oper_DASH_1085423941($z2393123932,if_helper670223837);
++R.GAS;
return $ret2393523936;
} else {
var $z2394423945 = D;
var $f2395023951 = function(_) {
return R.isFunction(if_helper670223837)?if_helper670223837.app((false)):R.ffi.throwNonFunApp(L[1137],if_helper670223837,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2394423945 = $f2395023951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2395023951,
"from":L[1137]});
}
} catch($e2394223943) {
if(R.isCont($e2394223943)) {
var $ss2394623947 = {"from":L[1137],
"go":function(cont_tail_app672523952) {
return $Hcont_tail_app1085523953(cont_tail_app672523952);
}};
$e2394223943.stack[R.EXN_STACKHEIGHT++] = $ss2394623947;
}
if(R.isPyretException($e2394223943)) {
$e2394223943.pyretStack.push(L[1137]);
}
throw $e2394223943;
}
var $ret2394823949 = $Hcont_tail_app1085523953($z2394423945);
++R.GAS;
return $ret2394823949;
}
} else {
var cont_tail_arg672223956 = R.throwNonBooleanOp(L[3695],("first"),("and"),and_DASH_oper_DASH_81023911);
if(--R.GAS > 0) {
$z2395423955 = R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg672223956):R.ffi.throwNonFunApp(L[3695],if_helper670223837,[cont_tail_arg672223956]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg672223956):R.ffi.throwNonFunApp(L[3695],if_helper670223837,[cont_tail_arg672223956]);
},
"from":L[3695]});
}
++R.GAS;
return $z2395423955;
}
};
var $Hand_DASH_oper_DASH_1085423941 = function(and_DASH_oper_DASH_81123940,if_helper670223837) {
var anf_if672923973 = R.isBoolean(and_DASH_oper_DASH_81123940);
if(R.isPyretTrue(anf_if672923973)) {
var $z2396023961 = D;
var $f2396623967 = function(_) {
return R.isFunction(if_helper670223837)?if_helper670223837.app(and_DASH_oper_DASH_81123940):R.ffi.throwNonFunApp(L[1137],if_helper670223837,[and_DASH_oper_DASH_81123940]);
};
try {
if(--R.GAS > 0) {
$z2396023961 = $f2396623967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2396623967,
"from":L[1137]});
}
} catch($e2395823959) {
if(R.isCont($e2395823959)) {
var $ss2396223963 = {"from":L[1137],
"go":function(cont_tail_app673023968) {
return $Hcont_tail_app1085323969(cont_tail_app673023968);
}};
$e2395823959.stack[R.EXN_STACKHEIGHT++] = $ss2396223963;
}
if(R.isPyretException($e2395823959)) {
$e2395823959.pyretStack.push(L[1137]);
}
throw $e2395823959;
}
var $ret2396423965 = $Hcont_tail_app1085323969($z2396023961);
++R.GAS;
return $ret2396423965;
} else {
var cont_tail_arg672723972 = R.throwNonBooleanOp(L[3696],("second"),("and"),and_DASH_oper_DASH_81123940);
if(--R.GAS > 0) {
$z2397023971 = R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg672723972):R.ffi.throwNonFunApp(L[3696],if_helper670223837,[cont_tail_arg672723972]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper670223837)?if_helper670223837.app(cont_tail_arg672723972):R.ffi.throwNonFunApp(L[3696],if_helper670223837,[cont_tail_arg672723972]);
},
"from":L[3696]});
}
++R.GAS;
return $z2397023971;
}
};
var $Hcont_tail_app1085323969 = function(cont_tail_app673023968) {
return cont_tail_app673023968;
};
var $Hcont_tail_app1085523953 = function(cont_tail_app672523952) {
return cont_tail_app672523952;
};
var $Hcont_tail_app1085723924 = function(cont_tail_app672023923) {
return cont_tail_app672023923;
};
var $Hcont_tail_app1085923895 = function(cont_tail_app671523894) {
return cont_tail_app671523894;
};
var $Hann_DASH_check_DASH_temp1085223852 = function(ann_DASH_check_DASH_temp670923851) {
return ann_DASH_check_DASH_temp670923851;
};
var $Hcont_tail_app1086123864 = function(cont_tail_app670723863) {
return cont_tail_app670723863;
};
var $Hann_DASH_check_DASH_temp108516104 = function(ann_DASH_check_DASH_temp66996103) {
return ann_DASH_check_DASH_temp66996103;
};
var $Hann_DASH_check_DASH_temp108506121 = function(ann_DASH_check_DASH_temp66946120) {
return ann_DASH_check_DASH_temp66946120;
};
var $Hann_DASH_check_DASH_temp108496138 = function(ann_DASH_check_DASH_temp66886137) {
return ann_DASH_check_DASH_temp66886137;
};
var $Hann_DASH_check_DASH_temp108486153 = function(ann_DASH_check_DASH_temp66906152) {
return ann_DASH_check_DASH_temp66906152;
};
var $Hand_DASH_oper_DASH_108476169 = function(and_DASH_oper_DASH_8016167,lists974,params17696168,self17666166) {
var if_helper667323987 = R.makeFunction(function(if_helper_arg667424019) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1148],1,arguments);
}
var ann_DASH_check_DASH_temp667124020 = if_helper_arg667424019;
return ann_DASH_check_DASH_temp667124020;
});
var anf_if667724018 = R.isBoolean(and_DASH_oper_DASH_8016167);
if(R.isPyretTrue(anf_if667724018)) {
if(R.isPyretTrue(and_DASH_oper_DASH_8016167)) {
var anf_fun667923984 = G(lists974,"all",L[3698]);
var anf_arg668223985 = R.makeFunction(function(recv_DASH_80323989) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3697],1,arguments);
}
var anf_fun668124000 = G(recv_DASH_80323989,"visit",L[3697]);
var $z2399223993 = D;
var $f2399823999 = function(_) {
return R.isFunction(anf_fun668124000)?anf_fun668124000.app(self17666166):R.ffi.throwNonFunApp(L[3697],anf_fun668124000,[self17666166]);
};
try {
if(--R.GAS > 0) {
$z2399223993 = $f2399823999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2399823999,
"from":L[3697]});
}
} catch($e2399023991) {
if(R.isCont($e2399023991)) {
var $ss2399423995 = {"from":L[3697],
"go":function(ann_DASH_check_DASH_temp668024001) {
return $Hann_DASH_check_DASH_temp1084324002(ann_DASH_check_DASH_temp668024001);
}};
$e2399023991.stack[R.EXN_STACKHEIGHT++] = $ss2399423995;
}
if(R.isPyretException($e2399023991)) {
$e2399023991.pyretStack.push(L[3697]);
}
throw $e2399023991;
}
var $ret2399623997 = $Hann_DASH_check_DASH_temp1084324002($z2399223993);
++R.GAS;
return $ret2399623997;
});
var $z2397623977 = D;
var $f2398223983 = function(_) {
return R.isFunction(anf_fun667923984)?anf_fun667923984.app(anf_arg668223985,params17696168):R.ffi.throwNonFunApp(L[1148],anf_fun667923984,[anf_arg668223985,params17696168]);
};
try {
if(--R.GAS > 0) {
$z2397623977 = $f2398223983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2398223983,
"from":L[1148]});
}
} catch($e2397423975) {
if(R.isCont($e2397423975)) {
var $ss2397823979 = {"from":L[1148],
"go":function(and_DASH_oper_DASH_80223986) {
return $Hand_DASH_oper_DASH_1084523988(and_DASH_oper_DASH_80223986,if_helper667323987);
}};
$e2397423975.stack[R.EXN_STACKHEIGHT++] = $ss2397823979;
}
if(R.isPyretException($e2397423975)) {
$e2397423975.pyretStack.push(L[1148]);
}
throw $e2397423975;
}
var $ret2398023981 = $Hand_DASH_oper_DASH_1084523988($z2397623977,if_helper667323987);
++R.GAS;
return $ret2398023981;
} else {
var $z2400524006 = D;
var $f2401124012 = function(_) {
return R.isFunction(if_helper667323987)?if_helper667323987.app((false)):R.ffi.throwNonFunApp(L[1148],if_helper667323987,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2400524006 = $f2401124012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2401124012,
"from":L[1148]});
}
} catch($e2400324004) {
if(R.isCont($e2400324004)) {
var $ss2400724008 = {"from":L[1148],
"go":function(cont_tail_app667824013) {
return $Hcont_tail_app1084624014(cont_tail_app667824013);
}};
$e2400324004.stack[R.EXN_STACKHEIGHT++] = $ss2400724008;
}
if(R.isPyretException($e2400324004)) {
$e2400324004.pyretStack.push(L[1148]);
}
throw $e2400324004;
}
var $ret2400924010 = $Hcont_tail_app1084624014($z2400524006);
++R.GAS;
return $ret2400924010;
}
} else {
var cont_tail_arg667524017 = R.throwNonBooleanOp(L[3699],("first"),("and"),and_DASH_oper_DASH_8016167);
if(--R.GAS > 0) {
$z2401524016 = R.isFunction(if_helper667323987)?if_helper667323987.app(cont_tail_arg667524017):R.ffi.throwNonFunApp(L[3699],if_helper667323987,[cont_tail_arg667524017]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper667323987)?if_helper667323987.app(cont_tail_arg667524017):R.ffi.throwNonFunApp(L[3699],if_helper667323987,[cont_tail_arg667524017]);
},
"from":L[3699]});
}
++R.GAS;
return $z2401524016;
}
};
var $Hand_DASH_oper_DASH_1084523988 = function(and_DASH_oper_DASH_80223986,if_helper667323987) {
var anf_if668524036 = R.isBoolean(and_DASH_oper_DASH_80223986);
if(R.isPyretTrue(anf_if668524036)) {
var $z2402324024 = D;
var $f2402924030 = function(_) {
return R.isFunction(if_helper667323987)?if_helper667323987.app(and_DASH_oper_DASH_80223986):R.ffi.throwNonFunApp(L[1148],if_helper667323987,[and_DASH_oper_DASH_80223986]);
};
try {
if(--R.GAS > 0) {
$z2402324024 = $f2402924030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2402924030,
"from":L[1148]});
}
} catch($e2402124022) {
if(R.isCont($e2402124022)) {
var $ss2402524026 = {"from":L[1148],
"go":function(cont_tail_app668624031) {
return $Hcont_tail_app1084424032(cont_tail_app668624031);
}};
$e2402124022.stack[R.EXN_STACKHEIGHT++] = $ss2402524026;
}
if(R.isPyretException($e2402124022)) {
$e2402124022.pyretStack.push(L[1148]);
}
throw $e2402124022;
}
var $ret2402724028 = $Hcont_tail_app1084424032($z2402324024);
++R.GAS;
return $ret2402724028;
} else {
var cont_tail_arg668324035 = R.throwNonBooleanOp(L[3700],("second"),("and"),and_DASH_oper_DASH_80223986);
if(--R.GAS > 0) {
$z2403324034 = R.isFunction(if_helper667323987)?if_helper667323987.app(cont_tail_arg668324035):R.ffi.throwNonFunApp(L[3700],if_helper667323987,[cont_tail_arg668324035]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper667323987)?if_helper667323987.app(cont_tail_arg668324035):R.ffi.throwNonFunApp(L[3700],if_helper667323987,[cont_tail_arg668324035]);
},
"from":L[3700]});
}
++R.GAS;
return $z2403324034;
}
};
var $Hcont_tail_app1084424032 = function(cont_tail_app668624031) {
return cont_tail_app668624031;
};
var $Hann_DASH_check_DASH_temp1084324002 = function(ann_DASH_check_DASH_temp668024001) {
return ann_DASH_check_DASH_temp668024001;
};
var $Hcont_tail_app1084624014 = function(cont_tail_app667824013) {
return cont_tail_app667824013;
};
var $Hann_DASH_check_DASH_temp108426185 = function(ann_DASH_check_DASH_temp66686184) {
return ann_DASH_check_DASH_temp66686184;
};
var $Hand_DASH_oper_DASH_108416205 = function(and_DASH_oper_DASH_7986202,body17616203,self17586204) {
var if_helper665624049 = R.makeFunction(function(if_helper_arg665724067) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1159],1,arguments);
}
var ann_DASH_check_DASH_temp665124068 = if_helper_arg665724067;
return ann_DASH_check_DASH_temp665124068;
});
var anf_if666024066 = R.isBoolean(and_DASH_oper_DASH_7986202);
if(R.isPyretTrue(anf_if666024066)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7986202)) {
var anf_fun666224047 = G(body17616203,"visit",L[3701]);
var $z2403924040 = D;
var $f2404524046 = function(_) {
return R.isFunction(anf_fun666224047)?anf_fun666224047.app(self17586204):R.ffi.throwNonFunApp(L[1159],anf_fun666224047,[self17586204]);
};
try {
if(--R.GAS > 0) {
$z2403924040 = $f2404524046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2404524046,
"from":L[1159]});
}
} catch($e2403724038) {
if(R.isCont($e2403724038)) {
var $ss2404124042 = {"from":L[1159],
"go":function(and_DASH_oper_DASH_80024048) {
return $Hand_DASH_oper_DASH_1083924050(and_DASH_oper_DASH_80024048,if_helper665624049);
}};
$e2403724038.stack[R.EXN_STACKHEIGHT++] = $ss2404124042;
}
if(R.isPyretException($e2403724038)) {
$e2403724038.pyretStack.push(L[1159]);
}
throw $e2403724038;
}
var $ret2404324044 = $Hand_DASH_oper_DASH_1083924050($z2403924040,if_helper665624049);
++R.GAS;
return $ret2404324044;
} else {
var $z2405324054 = D;
var $f2405924060 = function(_) {
return R.isFunction(if_helper665624049)?if_helper665624049.app((false)):R.ffi.throwNonFunApp(L[1159],if_helper665624049,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2405324054 = $f2405924060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2405924060,
"from":L[1159]});
}
} catch($e2405124052) {
if(R.isCont($e2405124052)) {
var $ss2405524056 = {"from":L[1159],
"go":function(cont_tail_app666124061) {
return $Hcont_tail_app1084024062(cont_tail_app666124061);
}};
$e2405124052.stack[R.EXN_STACKHEIGHT++] = $ss2405524056;
}
if(R.isPyretException($e2405124052)) {
$e2405124052.pyretStack.push(L[1159]);
}
throw $e2405124052;
}
var $ret2405724058 = $Hcont_tail_app1084024062($z2405324054);
++R.GAS;
return $ret2405724058;
}
} else {
var cont_tail_arg665824065 = R.throwNonBooleanOp(L[3702],("first"),("and"),and_DASH_oper_DASH_7986202);
if(--R.GAS > 0) {
$z2406324064 = R.isFunction(if_helper665624049)?if_helper665624049.app(cont_tail_arg665824065):R.ffi.throwNonFunApp(L[3702],if_helper665624049,[cont_tail_arg665824065]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper665624049)?if_helper665624049.app(cont_tail_arg665824065):R.ffi.throwNonFunApp(L[3702],if_helper665624049,[cont_tail_arg665824065]);
},
"from":L[3702]});
}
++R.GAS;
return $z2406324064;
}
};
var $Hand_DASH_oper_DASH_1083924050 = function(and_DASH_oper_DASH_80024048,if_helper665624049) {
var anf_if666524084 = R.isBoolean(and_DASH_oper_DASH_80024048);
if(R.isPyretTrue(anf_if666524084)) {
var $z2407124072 = D;
var $f2407724078 = function(_) {
return R.isFunction(if_helper665624049)?if_helper665624049.app(and_DASH_oper_DASH_80024048):R.ffi.throwNonFunApp(L[1159],if_helper665624049,[and_DASH_oper_DASH_80024048]);
};
try {
if(--R.GAS > 0) {
$z2407124072 = $f2407724078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2407724078,
"from":L[1159]});
}
} catch($e2406924070) {
if(R.isCont($e2406924070)) {
var $ss2407324074 = {"from":L[1159],
"go":function(cont_tail_app666624079) {
return $Hcont_tail_app1083824080(cont_tail_app666624079);
}};
$e2406924070.stack[R.EXN_STACKHEIGHT++] = $ss2407324074;
}
if(R.isPyretException($e2406924070)) {
$e2406924070.pyretStack.push(L[1159]);
}
throw $e2406924070;
}
var $ret2407524076 = $Hcont_tail_app1083824080($z2407124072);
++R.GAS;
return $ret2407524076;
} else {
var cont_tail_arg666324083 = R.throwNonBooleanOp(L[3703],("second"),("and"),and_DASH_oper_DASH_80024048);
if(--R.GAS > 0) {
$z2408124082 = R.isFunction(if_helper665624049)?if_helper665624049.app(cont_tail_arg666324083):R.ffi.throwNonFunApp(L[3703],if_helper665624049,[cont_tail_arg666324083]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper665624049)?if_helper665624049.app(cont_tail_arg666324083):R.ffi.throwNonFunApp(L[3703],if_helper665624049,[cont_tail_arg666324083]);
},
"from":L[3703]});
}
++R.GAS;
return $z2408124082;
}
};
var $Hcont_tail_app1083824080 = function(cont_tail_app666624079) {
return cont_tail_app666624079;
};
var $Hcont_tail_app1084024062 = function(cont_tail_app666124061) {
return cont_tail_app666124061;
};
var $Hann_DASH_check_DASH_temp108376219 = function(ann_DASH_check_DASH_temp66536218) {
return ann_DASH_check_DASH_temp66536218;
};
var $Hand_DASH_oper_DASH_108366235 = function(and_DASH_oper_DASH_7966233,expr17576234,self17546232) {
var if_helper663924097 = R.makeFunction(function(if_helper_arg664024115) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1163],1,arguments);
}
var ann_DASH_check_DASH_temp663724116 = if_helper_arg664024115;
return ann_DASH_check_DASH_temp663724116;
});
var anf_if664324114 = R.isBoolean(and_DASH_oper_DASH_7966233);
if(R.isPyretTrue(anf_if664324114)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7966233)) {
var anf_fun664524095 = G(expr17576234,"visit",L[3704]);
var $z2408724088 = D;
var $f2409324094 = function(_) {
return R.isFunction(anf_fun664524095)?anf_fun664524095.app(self17546232):R.ffi.throwNonFunApp(L[1163],anf_fun664524095,[self17546232]);
};
try {
if(--R.GAS > 0) {
$z2408724088 = $f2409324094();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2409324094,
"from":L[1163]});
}
} catch($e2408524086) {
if(R.isCont($e2408524086)) {
var $ss2408924090 = {"from":L[1163],
"go":function(and_DASH_oper_DASH_79724096) {
return $Hand_DASH_oper_DASH_1083424098(and_DASH_oper_DASH_79724096,if_helper663924097);
}};
$e2408524086.stack[R.EXN_STACKHEIGHT++] = $ss2408924090;
}
if(R.isPyretException($e2408524086)) {
$e2408524086.pyretStack.push(L[1163]);
}
throw $e2408524086;
}
var $ret2409124092 = $Hand_DASH_oper_DASH_1083424098($z2408724088,if_helper663924097);
++R.GAS;
return $ret2409124092;
} else {
var $z2410124102 = D;
var $f2410724108 = function(_) {
return R.isFunction(if_helper663924097)?if_helper663924097.app((false)):R.ffi.throwNonFunApp(L[1163],if_helper663924097,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2410124102 = $f2410724108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2410724108,
"from":L[1163]});
}
} catch($e2409924100) {
if(R.isCont($e2409924100)) {
var $ss2410324104 = {"from":L[1163],
"go":function(cont_tail_app664424109) {
return $Hcont_tail_app1083524110(cont_tail_app664424109);
}};
$e2409924100.stack[R.EXN_STACKHEIGHT++] = $ss2410324104;
}
if(R.isPyretException($e2409924100)) {
$e2409924100.pyretStack.push(L[1163]);
}
throw $e2409924100;
}
var $ret2410524106 = $Hcont_tail_app1083524110($z2410124102);
++R.GAS;
return $ret2410524106;
}
} else {
var cont_tail_arg664124113 = R.throwNonBooleanOp(L[3705],("first"),("and"),and_DASH_oper_DASH_7966233);
if(--R.GAS > 0) {
$z2411124112 = R.isFunction(if_helper663924097)?if_helper663924097.app(cont_tail_arg664124113):R.ffi.throwNonFunApp(L[3705],if_helper663924097,[cont_tail_arg664124113]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper663924097)?if_helper663924097.app(cont_tail_arg664124113):R.ffi.throwNonFunApp(L[3705],if_helper663924097,[cont_tail_arg664124113]);
},
"from":L[3705]});
}
++R.GAS;
return $z2411124112;
}
};
var $Hand_DASH_oper_DASH_1083424098 = function(and_DASH_oper_DASH_79724096,if_helper663924097) {
var anf_if664824132 = R.isBoolean(and_DASH_oper_DASH_79724096);
if(R.isPyretTrue(anf_if664824132)) {
var $z2411924120 = D;
var $f2412524126 = function(_) {
return R.isFunction(if_helper663924097)?if_helper663924097.app(and_DASH_oper_DASH_79724096):R.ffi.throwNonFunApp(L[1163],if_helper663924097,[and_DASH_oper_DASH_79724096]);
};
try {
if(--R.GAS > 0) {
$z2411924120 = $f2412524126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2412524126,
"from":L[1163]});
}
} catch($e2411724118) {
if(R.isCont($e2411724118)) {
var $ss2412124122 = {"from":L[1163],
"go":function(cont_tail_app664924127) {
return $Hcont_tail_app1083324128(cont_tail_app664924127);
}};
$e2411724118.stack[R.EXN_STACKHEIGHT++] = $ss2412124122;
}
if(R.isPyretException($e2411724118)) {
$e2411724118.pyretStack.push(L[1163]);
}
throw $e2411724118;
}
var $ret2412324124 = $Hcont_tail_app1083324128($z2411924120);
++R.GAS;
return $ret2412324124;
} else {
var cont_tail_arg664624131 = R.throwNonBooleanOp(L[3706],("second"),("and"),and_DASH_oper_DASH_79724096);
if(--R.GAS > 0) {
$z2412924130 = R.isFunction(if_helper663924097)?if_helper663924097.app(cont_tail_arg664624131):R.ffi.throwNonFunApp(L[3706],if_helper663924097,[cont_tail_arg664624131]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper663924097)?if_helper663924097.app(cont_tail_arg664624131):R.ffi.throwNonFunApp(L[3706],if_helper663924097,[cont_tail_arg664624131]);
},
"from":L[3706]});
}
++R.GAS;
return $z2412924130;
}
};
var $Hcont_tail_app1083324128 = function(cont_tail_app664924127) {
return cont_tail_app664924127;
};
var $Hcont_tail_app1083524110 = function(cont_tail_app664424109) {
return cont_tail_app664424109;
};
var $Hand_DASH_oper_DASH_108326254 = function(and_DASH_oper_DASH_7936251,body17536252,self17506253) {
var if_helper662524145 = R.makeFunction(function(if_helper_arg662624163) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1166],1,arguments);
}
var ann_DASH_check_DASH_temp662024164 = if_helper_arg662624163;
return ann_DASH_check_DASH_temp662024164;
});
var anf_if662924162 = R.isBoolean(and_DASH_oper_DASH_7936251);
if(R.isPyretTrue(anf_if662924162)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7936251)) {
var anf_fun663124143 = G(body17536252,"visit",L[3707]);
var $z2413524136 = D;
var $f2414124142 = function(_) {
return R.isFunction(anf_fun663124143)?anf_fun663124143.app(self17506253):R.ffi.throwNonFunApp(L[1166],anf_fun663124143,[self17506253]);
};
try {
if(--R.GAS > 0) {
$z2413524136 = $f2414124142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2414124142,
"from":L[1166]});
}
} catch($e2413324134) {
if(R.isCont($e2413324134)) {
var $ss2413724138 = {"from":L[1166],
"go":function(and_DASH_oper_DASH_79524144) {
return $Hand_DASH_oper_DASH_1083024146(and_DASH_oper_DASH_79524144,if_helper662524145);
}};
$e2413324134.stack[R.EXN_STACKHEIGHT++] = $ss2413724138;
}
if(R.isPyretException($e2413324134)) {
$e2413324134.pyretStack.push(L[1166]);
}
throw $e2413324134;
}
var $ret2413924140 = $Hand_DASH_oper_DASH_1083024146($z2413524136,if_helper662524145);
++R.GAS;
return $ret2413924140;
} else {
var $z2414924150 = D;
var $f2415524156 = function(_) {
return R.isFunction(if_helper662524145)?if_helper662524145.app((false)):R.ffi.throwNonFunApp(L[1166],if_helper662524145,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2414924150 = $f2415524156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2415524156,
"from":L[1166]});
}
} catch($e2414724148) {
if(R.isCont($e2414724148)) {
var $ss2415124152 = {"from":L[1166],
"go":function(cont_tail_app663024157) {
return $Hcont_tail_app1083124158(cont_tail_app663024157);
}};
$e2414724148.stack[R.EXN_STACKHEIGHT++] = $ss2415124152;
}
if(R.isPyretException($e2414724148)) {
$e2414724148.pyretStack.push(L[1166]);
}
throw $e2414724148;
}
var $ret2415324154 = $Hcont_tail_app1083124158($z2414924150);
++R.GAS;
return $ret2415324154;
}
} else {
var cont_tail_arg662724161 = R.throwNonBooleanOp(L[3708],("first"),("and"),and_DASH_oper_DASH_7936251);
if(--R.GAS > 0) {
$z2415924160 = R.isFunction(if_helper662524145)?if_helper662524145.app(cont_tail_arg662724161):R.ffi.throwNonFunApp(L[3708],if_helper662524145,[cont_tail_arg662724161]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper662524145)?if_helper662524145.app(cont_tail_arg662724161):R.ffi.throwNonFunApp(L[3708],if_helper662524145,[cont_tail_arg662724161]);
},
"from":L[3708]});
}
++R.GAS;
return $z2415924160;
}
};
var $Hand_DASH_oper_DASH_1083024146 = function(and_DASH_oper_DASH_79524144,if_helper662524145) {
var anf_if663424180 = R.isBoolean(and_DASH_oper_DASH_79524144);
if(R.isPyretTrue(anf_if663424180)) {
var $z2416724168 = D;
var $f2417324174 = function(_) {
return R.isFunction(if_helper662524145)?if_helper662524145.app(and_DASH_oper_DASH_79524144):R.ffi.throwNonFunApp(L[1166],if_helper662524145,[and_DASH_oper_DASH_79524144]);
};
try {
if(--R.GAS > 0) {
$z2416724168 = $f2417324174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2417324174,
"from":L[1166]});
}
} catch($e2416524166) {
if(R.isCont($e2416524166)) {
var $ss2416924170 = {"from":L[1166],
"go":function(cont_tail_app663524175) {
return $Hcont_tail_app1082924176(cont_tail_app663524175);
}};
$e2416524166.stack[R.EXN_STACKHEIGHT++] = $ss2416924170;
}
if(R.isPyretException($e2416524166)) {
$e2416524166.pyretStack.push(L[1166]);
}
throw $e2416524166;
}
var $ret2417124172 = $Hcont_tail_app1082924176($z2416724168);
++R.GAS;
return $ret2417124172;
} else {
var cont_tail_arg663224179 = R.throwNonBooleanOp(L[3709],("second"),("and"),and_DASH_oper_DASH_79524144);
if(--R.GAS > 0) {
$z2417724178 = R.isFunction(if_helper662524145)?if_helper662524145.app(cont_tail_arg663224179):R.ffi.throwNonFunApp(L[3709],if_helper662524145,[cont_tail_arg663224179]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper662524145)?if_helper662524145.app(cont_tail_arg663224179):R.ffi.throwNonFunApp(L[3709],if_helper662524145,[cont_tail_arg663224179]);
},
"from":L[3709]});
}
++R.GAS;
return $z2417724178;
}
};
var $Hcont_tail_app1082924176 = function(cont_tail_app663524175) {
return cont_tail_app663524175;
};
var $Hcont_tail_app1083124158 = function(cont_tail_app663024157) {
return cont_tail_app663024157;
};
var $Hann_DASH_check_DASH_temp108286268 = function(ann_DASH_check_DASH_temp66226267) {
return ann_DASH_check_DASH_temp66226267;
};
var $Hand_DASH_oper_DASH_108276286 = function(and_DASH_oper_DASH_7906283,body17496284,self17466285) {
var if_helper660824193 = R.makeFunction(function(if_helper_arg660924211) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1170],1,arguments);
}
var ann_DASH_check_DASH_temp660324212 = if_helper_arg660924211;
return ann_DASH_check_DASH_temp660324212;
});
var anf_if661224210 = R.isBoolean(and_DASH_oper_DASH_7906283);
if(R.isPyretTrue(anf_if661224210)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7906283)) {
var anf_fun661424191 = G(body17496284,"visit",L[3710]);
var $z2418324184 = D;
var $f2418924190 = function(_) {
return R.isFunction(anf_fun661424191)?anf_fun661424191.app(self17466285):R.ffi.throwNonFunApp(L[1170],anf_fun661424191,[self17466285]);
};
try {
if(--R.GAS > 0) {
$z2418324184 = $f2418924190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2418924190,
"from":L[1170]});
}
} catch($e2418124182) {
if(R.isCont($e2418124182)) {
var $ss2418524186 = {"from":L[1170],
"go":function(and_DASH_oper_DASH_79224192) {
return $Hand_DASH_oper_DASH_1082524194(and_DASH_oper_DASH_79224192,if_helper660824193);
}};
$e2418124182.stack[R.EXN_STACKHEIGHT++] = $ss2418524186;
}
if(R.isPyretException($e2418124182)) {
$e2418124182.pyretStack.push(L[1170]);
}
throw $e2418124182;
}
var $ret2418724188 = $Hand_DASH_oper_DASH_1082524194($z2418324184,if_helper660824193);
++R.GAS;
return $ret2418724188;
} else {
var $z2419724198 = D;
var $f2420324204 = function(_) {
return R.isFunction(if_helper660824193)?if_helper660824193.app((false)):R.ffi.throwNonFunApp(L[1170],if_helper660824193,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2419724198 = $f2420324204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2420324204,
"from":L[1170]});
}
} catch($e2419524196) {
if(R.isCont($e2419524196)) {
var $ss2419924200 = {"from":L[1170],
"go":function(cont_tail_app661324205) {
return $Hcont_tail_app1082624206(cont_tail_app661324205);
}};
$e2419524196.stack[R.EXN_STACKHEIGHT++] = $ss2419924200;
}
if(R.isPyretException($e2419524196)) {
$e2419524196.pyretStack.push(L[1170]);
}
throw $e2419524196;
}
var $ret2420124202 = $Hcont_tail_app1082624206($z2419724198);
++R.GAS;
return $ret2420124202;
}
} else {
var cont_tail_arg661024209 = R.throwNonBooleanOp(L[3711],("first"),("and"),and_DASH_oper_DASH_7906283);
if(--R.GAS > 0) {
$z2420724208 = R.isFunction(if_helper660824193)?if_helper660824193.app(cont_tail_arg661024209):R.ffi.throwNonFunApp(L[3711],if_helper660824193,[cont_tail_arg661024209]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper660824193)?if_helper660824193.app(cont_tail_arg661024209):R.ffi.throwNonFunApp(L[3711],if_helper660824193,[cont_tail_arg661024209]);
},
"from":L[3711]});
}
++R.GAS;
return $z2420724208;
}
};
var $Hand_DASH_oper_DASH_1082524194 = function(and_DASH_oper_DASH_79224192,if_helper660824193) {
var anf_if661724228 = R.isBoolean(and_DASH_oper_DASH_79224192);
if(R.isPyretTrue(anf_if661724228)) {
var $z2421524216 = D;
var $f2422124222 = function(_) {
return R.isFunction(if_helper660824193)?if_helper660824193.app(and_DASH_oper_DASH_79224192):R.ffi.throwNonFunApp(L[1170],if_helper660824193,[and_DASH_oper_DASH_79224192]);
};
try {
if(--R.GAS > 0) {
$z2421524216 = $f2422124222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2422124222,
"from":L[1170]});
}
} catch($e2421324214) {
if(R.isCont($e2421324214)) {
var $ss2421724218 = {"from":L[1170],
"go":function(cont_tail_app661824223) {
return $Hcont_tail_app1082424224(cont_tail_app661824223);
}};
$e2421324214.stack[R.EXN_STACKHEIGHT++] = $ss2421724218;
}
if(R.isPyretException($e2421324214)) {
$e2421324214.pyretStack.push(L[1170]);
}
throw $e2421324214;
}
var $ret2421924220 = $Hcont_tail_app1082424224($z2421524216);
++R.GAS;
return $ret2421924220;
} else {
var cont_tail_arg661524227 = R.throwNonBooleanOp(L[3712],("second"),("and"),and_DASH_oper_DASH_79224192);
if(--R.GAS > 0) {
$z2422524226 = R.isFunction(if_helper660824193)?if_helper660824193.app(cont_tail_arg661524227):R.ffi.throwNonFunApp(L[3712],if_helper660824193,[cont_tail_arg661524227]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper660824193)?if_helper660824193.app(cont_tail_arg661524227):R.ffi.throwNonFunApp(L[3712],if_helper660824193,[cont_tail_arg661524227]);
},
"from":L[3712]});
}
++R.GAS;
return $z2422524226;
}
};
var $Hcont_tail_app1082424224 = function(cont_tail_app661824223) {
return cont_tail_app661824223;
};
var $Hcont_tail_app1082624206 = function(cont_tail_app661324205) {
return cont_tail_app661324205;
};
var $Hann_DASH_check_DASH_temp108236300 = function(ann_DASH_check_DASH_temp66056299) {
return ann_DASH_check_DASH_temp66056299;
};
var $Hand_DASH_oper_DASH_108226316 = function(and_DASH_oper_DASH_7886314,namet17456315,self17426313) {
var if_helper659124241 = R.makeFunction(function(if_helper_arg659224259) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1174],1,arguments);
}
var ann_DASH_check_DASH_temp658924260 = if_helper_arg659224259;
return ann_DASH_check_DASH_temp658924260;
});
var anf_if659524258 = R.isBoolean(and_DASH_oper_DASH_7886314);
if(R.isPyretTrue(anf_if659524258)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7886314)) {
var anf_fun659724239 = G(namet17456315,"visit",L[3713]);
var $z2423124232 = D;
var $f2423724238 = function(_) {
return R.isFunction(anf_fun659724239)?anf_fun659724239.app(self17426313):R.ffi.throwNonFunApp(L[1174],anf_fun659724239,[self17426313]);
};
try {
if(--R.GAS > 0) {
$z2423124232 = $f2423724238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2423724238,
"from":L[1174]});
}
} catch($e2422924230) {
if(R.isCont($e2422924230)) {
var $ss2423324234 = {"from":L[1174],
"go":function(and_DASH_oper_DASH_78924240) {
return $Hand_DASH_oper_DASH_1082024242(and_DASH_oper_DASH_78924240,if_helper659124241);
}};
$e2422924230.stack[R.EXN_STACKHEIGHT++] = $ss2423324234;
}
if(R.isPyretException($e2422924230)) {
$e2422924230.pyretStack.push(L[1174]);
}
throw $e2422924230;
}
var $ret2423524236 = $Hand_DASH_oper_DASH_1082024242($z2423124232,if_helper659124241);
++R.GAS;
return $ret2423524236;
} else {
var $z2424524246 = D;
var $f2425124252 = function(_) {
return R.isFunction(if_helper659124241)?if_helper659124241.app((false)):R.ffi.throwNonFunApp(L[1174],if_helper659124241,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2424524246 = $f2425124252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2425124252,
"from":L[1174]});
}
} catch($e2424324244) {
if(R.isCont($e2424324244)) {
var $ss2424724248 = {"from":L[1174],
"go":function(cont_tail_app659624253) {
return $Hcont_tail_app1082124254(cont_tail_app659624253);
}};
$e2424324244.stack[R.EXN_STACKHEIGHT++] = $ss2424724248;
}
if(R.isPyretException($e2424324244)) {
$e2424324244.pyretStack.push(L[1174]);
}
throw $e2424324244;
}
var $ret2424924250 = $Hcont_tail_app1082124254($z2424524246);
++R.GAS;
return $ret2424924250;
}
} else {
var cont_tail_arg659324257 = R.throwNonBooleanOp(L[3714],("first"),("and"),and_DASH_oper_DASH_7886314);
if(--R.GAS > 0) {
$z2425524256 = R.isFunction(if_helper659124241)?if_helper659124241.app(cont_tail_arg659324257):R.ffi.throwNonFunApp(L[3714],if_helper659124241,[cont_tail_arg659324257]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper659124241)?if_helper659124241.app(cont_tail_arg659324257):R.ffi.throwNonFunApp(L[3714],if_helper659124241,[cont_tail_arg659324257]);
},
"from":L[3714]});
}
++R.GAS;
return $z2425524256;
}
};
var $Hand_DASH_oper_DASH_1082024242 = function(and_DASH_oper_DASH_78924240,if_helper659124241) {
var anf_if660024276 = R.isBoolean(and_DASH_oper_DASH_78924240);
if(R.isPyretTrue(anf_if660024276)) {
var $z2426324264 = D;
var $f2426924270 = function(_) {
return R.isFunction(if_helper659124241)?if_helper659124241.app(and_DASH_oper_DASH_78924240):R.ffi.throwNonFunApp(L[1174],if_helper659124241,[and_DASH_oper_DASH_78924240]);
};
try {
if(--R.GAS > 0) {
$z2426324264 = $f2426924270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2426924270,
"from":L[1174]});
}
} catch($e2426124262) {
if(R.isCont($e2426124262)) {
var $ss2426524266 = {"from":L[1174],
"go":function(cont_tail_app660124271) {
return $Hcont_tail_app1081924272(cont_tail_app660124271);
}};
$e2426124262.stack[R.EXN_STACKHEIGHT++] = $ss2426524266;
}
if(R.isPyretException($e2426124262)) {
$e2426124262.pyretStack.push(L[1174]);
}
throw $e2426124262;
}
var $ret2426724268 = $Hcont_tail_app1081924272($z2426324264);
++R.GAS;
return $ret2426724268;
} else {
var cont_tail_arg659824275 = R.throwNonBooleanOp(L[3715],("second"),("and"),and_DASH_oper_DASH_78924240);
if(--R.GAS > 0) {
$z2427324274 = R.isFunction(if_helper659124241)?if_helper659124241.app(cont_tail_arg659824275):R.ffi.throwNonFunApp(L[3715],if_helper659124241,[cont_tail_arg659824275]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper659124241)?if_helper659124241.app(cont_tail_arg659824275):R.ffi.throwNonFunApp(L[3715],if_helper659124241,[cont_tail_arg659824275]);
},
"from":L[3715]});
}
++R.GAS;
return $z2427324274;
}
};
var $Hcont_tail_app1081924272 = function(cont_tail_app660124271) {
return cont_tail_app660124271;
};
var $Hcont_tail_app1082124254 = function(cont_tail_app659624253) {
return cont_tail_app659624253;
};
var $Hand_DASH_oper_DASH_108186333 = function(and_DASH_oper_DASH_7866331,ann17416332,self17386330) {
var if_helper657724289 = R.makeFunction(function(if_helper_arg657824307) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1177],1,arguments);
}
var ann_DASH_check_DASH_temp657524308 = if_helper_arg657824307;
return ann_DASH_check_DASH_temp657524308;
});
var anf_if658124306 = R.isBoolean(and_DASH_oper_DASH_7866331);
if(R.isPyretTrue(anf_if658124306)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7866331)) {
var anf_fun658324287 = G(ann17416332,"visit",L[3716]);
var $z2427924280 = D;
var $f2428524286 = function(_) {
return R.isFunction(anf_fun658324287)?anf_fun658324287.app(self17386330):R.ffi.throwNonFunApp(L[1177],anf_fun658324287,[self17386330]);
};
try {
if(--R.GAS > 0) {
$z2427924280 = $f2428524286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2428524286,
"from":L[1177]});
}
} catch($e2427724278) {
if(R.isCont($e2427724278)) {
var $ss2428124282 = {"from":L[1177],
"go":function(and_DASH_oper_DASH_78724288) {
return $Hand_DASH_oper_DASH_1081624290(and_DASH_oper_DASH_78724288,if_helper657724289);
}};
$e2427724278.stack[R.EXN_STACKHEIGHT++] = $ss2428124282;
}
if(R.isPyretException($e2427724278)) {
$e2427724278.pyretStack.push(L[1177]);
}
throw $e2427724278;
}
var $ret2428324284 = $Hand_DASH_oper_DASH_1081624290($z2427924280,if_helper657724289);
++R.GAS;
return $ret2428324284;
} else {
var $z2429324294 = D;
var $f2429924300 = function(_) {
return R.isFunction(if_helper657724289)?if_helper657724289.app((false)):R.ffi.throwNonFunApp(L[1177],if_helper657724289,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2429324294 = $f2429924300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2429924300,
"from":L[1177]});
}
} catch($e2429124292) {
if(R.isCont($e2429124292)) {
var $ss2429524296 = {"from":L[1177],
"go":function(cont_tail_app658224301) {
return $Hcont_tail_app1081724302(cont_tail_app658224301);
}};
$e2429124292.stack[R.EXN_STACKHEIGHT++] = $ss2429524296;
}
if(R.isPyretException($e2429124292)) {
$e2429124292.pyretStack.push(L[1177]);
}
throw $e2429124292;
}
var $ret2429724298 = $Hcont_tail_app1081724302($z2429324294);
++R.GAS;
return $ret2429724298;
}
} else {
var cont_tail_arg657924305 = R.throwNonBooleanOp(L[3717],("first"),("and"),and_DASH_oper_DASH_7866331);
if(--R.GAS > 0) {
$z2430324304 = R.isFunction(if_helper657724289)?if_helper657724289.app(cont_tail_arg657924305):R.ffi.throwNonFunApp(L[3717],if_helper657724289,[cont_tail_arg657924305]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper657724289)?if_helper657724289.app(cont_tail_arg657924305):R.ffi.throwNonFunApp(L[3717],if_helper657724289,[cont_tail_arg657924305]);
},
"from":L[3717]});
}
++R.GAS;
return $z2430324304;
}
};
var $Hand_DASH_oper_DASH_1081624290 = function(and_DASH_oper_DASH_78724288,if_helper657724289) {
var anf_if658624324 = R.isBoolean(and_DASH_oper_DASH_78724288);
if(R.isPyretTrue(anf_if658624324)) {
var $z2431124312 = D;
var $f2431724318 = function(_) {
return R.isFunction(if_helper657724289)?if_helper657724289.app(and_DASH_oper_DASH_78724288):R.ffi.throwNonFunApp(L[1177],if_helper657724289,[and_DASH_oper_DASH_78724288]);
};
try {
if(--R.GAS > 0) {
$z2431124312 = $f2431724318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2431724318,
"from":L[1177]});
}
} catch($e2430924310) {
if(R.isCont($e2430924310)) {
var $ss2431324314 = {"from":L[1177],
"go":function(cont_tail_app658724319) {
return $Hcont_tail_app1081524320(cont_tail_app658724319);
}};
$e2430924310.stack[R.EXN_STACKHEIGHT++] = $ss2431324314;
}
if(R.isPyretException($e2430924310)) {
$e2430924310.pyretStack.push(L[1177]);
}
throw $e2430924310;
}
var $ret2431524316 = $Hcont_tail_app1081524320($z2431124312);
++R.GAS;
return $ret2431524316;
} else {
var cont_tail_arg658424323 = R.throwNonBooleanOp(L[3718],("second"),("and"),and_DASH_oper_DASH_78724288);
if(--R.GAS > 0) {
$z2432124322 = R.isFunction(if_helper657724289)?if_helper657724289.app(cont_tail_arg658424323):R.ffi.throwNonFunApp(L[3718],if_helper657724289,[cont_tail_arg658424323]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper657724289)?if_helper657724289.app(cont_tail_arg658424323):R.ffi.throwNonFunApp(L[3718],if_helper657724289,[cont_tail_arg658424323]);
},
"from":L[3718]});
}
++R.GAS;
return $z2432124322;
}
};
var $Hcont_tail_app1081524320 = function(cont_tail_app658724319) {
return cont_tail_app658724319;
};
var $Hcont_tail_app1081724302 = function(cont_tail_app658224301) {
return cont_tail_app658224301;
};
var $Hand_DASH_oper_DASH_108146350 = function(and_DASH_oper_DASH_7846348,expr17376349,self17346347) {
var if_helper656324337 = R.makeFunction(function(if_helper_arg656424355) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1180],1,arguments);
}
var ann_DASH_check_DASH_temp656124356 = if_helper_arg656424355;
return ann_DASH_check_DASH_temp656124356;
});
var anf_if656724354 = R.isBoolean(and_DASH_oper_DASH_7846348);
if(R.isPyretTrue(anf_if656724354)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7846348)) {
var anf_fun656924335 = G(expr17376349,"visit",L[3719]);
var $z2432724328 = D;
var $f2433324334 = function(_) {
return R.isFunction(anf_fun656924335)?anf_fun656924335.app(self17346347):R.ffi.throwNonFunApp(L[1180],anf_fun656924335,[self17346347]);
};
try {
if(--R.GAS > 0) {
$z2432724328 = $f2433324334();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2433324334,
"from":L[1180]});
}
} catch($e2432524326) {
if(R.isCont($e2432524326)) {
var $ss2432924330 = {"from":L[1180],
"go":function(and_DASH_oper_DASH_78524336) {
return $Hand_DASH_oper_DASH_1081224338(and_DASH_oper_DASH_78524336,if_helper656324337);
}};
$e2432524326.stack[R.EXN_STACKHEIGHT++] = $ss2432924330;
}
if(R.isPyretException($e2432524326)) {
$e2432524326.pyretStack.push(L[1180]);
}
throw $e2432524326;
}
var $ret2433124332 = $Hand_DASH_oper_DASH_1081224338($z2432724328,if_helper656324337);
++R.GAS;
return $ret2433124332;
} else {
var $z2434124342 = D;
var $f2434724348 = function(_) {
return R.isFunction(if_helper656324337)?if_helper656324337.app((false)):R.ffi.throwNonFunApp(L[1180],if_helper656324337,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2434124342 = $f2434724348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2434724348,
"from":L[1180]});
}
} catch($e2433924340) {
if(R.isCont($e2433924340)) {
var $ss2434324344 = {"from":L[1180],
"go":function(cont_tail_app656824349) {
return $Hcont_tail_app1081324350(cont_tail_app656824349);
}};
$e2433924340.stack[R.EXN_STACKHEIGHT++] = $ss2434324344;
}
if(R.isPyretException($e2433924340)) {
$e2433924340.pyretStack.push(L[1180]);
}
throw $e2433924340;
}
var $ret2434524346 = $Hcont_tail_app1081324350($z2434124342);
++R.GAS;
return $ret2434524346;
}
} else {
var cont_tail_arg656524353 = R.throwNonBooleanOp(L[3720],("first"),("and"),and_DASH_oper_DASH_7846348);
if(--R.GAS > 0) {
$z2435124352 = R.isFunction(if_helper656324337)?if_helper656324337.app(cont_tail_arg656524353):R.ffi.throwNonFunApp(L[3720],if_helper656324337,[cont_tail_arg656524353]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper656324337)?if_helper656324337.app(cont_tail_arg656524353):R.ffi.throwNonFunApp(L[3720],if_helper656324337,[cont_tail_arg656524353]);
},
"from":L[3720]});
}
++R.GAS;
return $z2435124352;
}
};
var $Hand_DASH_oper_DASH_1081224338 = function(and_DASH_oper_DASH_78524336,if_helper656324337) {
var anf_if657224372 = R.isBoolean(and_DASH_oper_DASH_78524336);
if(R.isPyretTrue(anf_if657224372)) {
var $z2435924360 = D;
var $f2436524366 = function(_) {
return R.isFunction(if_helper656324337)?if_helper656324337.app(and_DASH_oper_DASH_78524336):R.ffi.throwNonFunApp(L[1180],if_helper656324337,[and_DASH_oper_DASH_78524336]);
};
try {
if(--R.GAS > 0) {
$z2435924360 = $f2436524366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2436524366,
"from":L[1180]});
}
} catch($e2435724358) {
if(R.isCont($e2435724358)) {
var $ss2436124362 = {"from":L[1180],
"go":function(cont_tail_app657324367) {
return $Hcont_tail_app1081124368(cont_tail_app657324367);
}};
$e2435724358.stack[R.EXN_STACKHEIGHT++] = $ss2436124362;
}
if(R.isPyretException($e2435724358)) {
$e2435724358.pyretStack.push(L[1180]);
}
throw $e2435724358;
}
var $ret2436324364 = $Hcont_tail_app1081124368($z2435924360);
++R.GAS;
return $ret2436324364;
} else {
var cont_tail_arg657024371 = R.throwNonBooleanOp(L[3721],("second"),("and"),and_DASH_oper_DASH_78524336);
if(--R.GAS > 0) {
$z2436924370 = R.isFunction(if_helper656324337)?if_helper656324337.app(cont_tail_arg657024371):R.ffi.throwNonFunApp(L[3721],if_helper656324337,[cont_tail_arg657024371]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper656324337)?if_helper656324337.app(cont_tail_arg657024371):R.ffi.throwNonFunApp(L[3721],if_helper656324337,[cont_tail_arg657024371]);
},
"from":L[3721]});
}
++R.GAS;
return $z2436924370;
}
};
var $Hcont_tail_app1081124368 = function(cont_tail_app657324367) {
return cont_tail_app657324367;
};
var $Hcont_tail_app1081324350 = function(cont_tail_app656824349) {
return cont_tail_app656824349;
};
var $Hand_DASH_oper_DASH_108106367 = function(and_DASH_oper_DASH_7826365,expr17336366,self17306364) {
var if_helper654924385 = R.makeFunction(function(if_helper_arg655024403) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1183],1,arguments);
}
var ann_DASH_check_DASH_temp654724404 = if_helper_arg655024403;
return ann_DASH_check_DASH_temp654724404;
});
var anf_if655324402 = R.isBoolean(and_DASH_oper_DASH_7826365);
if(R.isPyretTrue(anf_if655324402)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7826365)) {
var anf_fun655524383 = G(expr17336366,"visit",L[3722]);
var $z2437524376 = D;
var $f2438124382 = function(_) {
return R.isFunction(anf_fun655524383)?anf_fun655524383.app(self17306364):R.ffi.throwNonFunApp(L[1183],anf_fun655524383,[self17306364]);
};
try {
if(--R.GAS > 0) {
$z2437524376 = $f2438124382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2438124382,
"from":L[1183]});
}
} catch($e2437324374) {
if(R.isCont($e2437324374)) {
var $ss2437724378 = {"from":L[1183],
"go":function(and_DASH_oper_DASH_78324384) {
return $Hand_DASH_oper_DASH_1080824386(and_DASH_oper_DASH_78324384,if_helper654924385);
}};
$e2437324374.stack[R.EXN_STACKHEIGHT++] = $ss2437724378;
}
if(R.isPyretException($e2437324374)) {
$e2437324374.pyretStack.push(L[1183]);
}
throw $e2437324374;
}
var $ret2437924380 = $Hand_DASH_oper_DASH_1080824386($z2437524376,if_helper654924385);
++R.GAS;
return $ret2437924380;
} else {
var $z2438924390 = D;
var $f2439524396 = function(_) {
return R.isFunction(if_helper654924385)?if_helper654924385.app((false)):R.ffi.throwNonFunApp(L[1183],if_helper654924385,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2438924390 = $f2439524396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2439524396,
"from":L[1183]});
}
} catch($e2438724388) {
if(R.isCont($e2438724388)) {
var $ss2439124392 = {"from":L[1183],
"go":function(cont_tail_app655424397) {
return $Hcont_tail_app1080924398(cont_tail_app655424397);
}};
$e2438724388.stack[R.EXN_STACKHEIGHT++] = $ss2439124392;
}
if(R.isPyretException($e2438724388)) {
$e2438724388.pyretStack.push(L[1183]);
}
throw $e2438724388;
}
var $ret2439324394 = $Hcont_tail_app1080924398($z2438924390);
++R.GAS;
return $ret2439324394;
}
} else {
var cont_tail_arg655124401 = R.throwNonBooleanOp(L[3723],("first"),("and"),and_DASH_oper_DASH_7826365);
if(--R.GAS > 0) {
$z2439924400 = R.isFunction(if_helper654924385)?if_helper654924385.app(cont_tail_arg655124401):R.ffi.throwNonFunApp(L[3723],if_helper654924385,[cont_tail_arg655124401]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper654924385)?if_helper654924385.app(cont_tail_arg655124401):R.ffi.throwNonFunApp(L[3723],if_helper654924385,[cont_tail_arg655124401]);
},
"from":L[3723]});
}
++R.GAS;
return $z2439924400;
}
};
var $Hand_DASH_oper_DASH_1080824386 = function(and_DASH_oper_DASH_78324384,if_helper654924385) {
var anf_if655824420 = R.isBoolean(and_DASH_oper_DASH_78324384);
if(R.isPyretTrue(anf_if655824420)) {
var $z2440724408 = D;
var $f2441324414 = function(_) {
return R.isFunction(if_helper654924385)?if_helper654924385.app(and_DASH_oper_DASH_78324384):R.ffi.throwNonFunApp(L[1183],if_helper654924385,[and_DASH_oper_DASH_78324384]);
};
try {
if(--R.GAS > 0) {
$z2440724408 = $f2441324414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2441324414,
"from":L[1183]});
}
} catch($e2440524406) {
if(R.isCont($e2440524406)) {
var $ss2440924410 = {"from":L[1183],
"go":function(cont_tail_app655924415) {
return $Hcont_tail_app1080724416(cont_tail_app655924415);
}};
$e2440524406.stack[R.EXN_STACKHEIGHT++] = $ss2440924410;
}
if(R.isPyretException($e2440524406)) {
$e2440524406.pyretStack.push(L[1183]);
}
throw $e2440524406;
}
var $ret2441124412 = $Hcont_tail_app1080724416($z2440724408);
++R.GAS;
return $ret2441124412;
} else {
var cont_tail_arg655624419 = R.throwNonBooleanOp(L[3724],("second"),("and"),and_DASH_oper_DASH_78324384);
if(--R.GAS > 0) {
$z2441724418 = R.isFunction(if_helper654924385)?if_helper654924385.app(cont_tail_arg655624419):R.ffi.throwNonFunApp(L[3724],if_helper654924385,[cont_tail_arg655624419]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper654924385)?if_helper654924385.app(cont_tail_arg655624419):R.ffi.throwNonFunApp(L[3724],if_helper654924385,[cont_tail_arg655624419]);
},
"from":L[3724]});
}
++R.GAS;
return $z2441724418;
}
};
var $Hcont_tail_app1080724416 = function(cont_tail_app655924415) {
return cont_tail_app655924415;
};
var $Hcont_tail_app1080924398 = function(cont_tail_app655424397) {
return cont_tail_app655424397;
};
var $Hand_DASH_oper_DASH_108066384 = function(and_DASH_oper_DASH_7806382,ann17296383,self17256381) {
var if_helper653524433 = R.makeFunction(function(if_helper_arg653624451) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1186],1,arguments);
}
var ann_DASH_check_DASH_temp653324452 = if_helper_arg653624451;
return ann_DASH_check_DASH_temp653324452;
});
var anf_if653924450 = R.isBoolean(and_DASH_oper_DASH_7806382);
if(R.isPyretTrue(anf_if653924450)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7806382)) {
var anf_fun654124431 = G(ann17296383,"visit",L[3725]);
var $z2442324424 = D;
var $f2442924430 = function(_) {
return R.isFunction(anf_fun654124431)?anf_fun654124431.app(self17256381):R.ffi.throwNonFunApp(L[1186],anf_fun654124431,[self17256381]);
};
try {
if(--R.GAS > 0) {
$z2442324424 = $f2442924430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2442924430,
"from":L[1186]});
}
} catch($e2442124422) {
if(R.isCont($e2442124422)) {
var $ss2442524426 = {"from":L[1186],
"go":function(and_DASH_oper_DASH_78124432) {
return $Hand_DASH_oper_DASH_1080424434(and_DASH_oper_DASH_78124432,if_helper653524433);
}};
$e2442124422.stack[R.EXN_STACKHEIGHT++] = $ss2442524426;
}
if(R.isPyretException($e2442124422)) {
$e2442124422.pyretStack.push(L[1186]);
}
throw $e2442124422;
}
var $ret2442724428 = $Hand_DASH_oper_DASH_1080424434($z2442324424,if_helper653524433);
++R.GAS;
return $ret2442724428;
} else {
var $z2443724438 = D;
var $f2444324444 = function(_) {
return R.isFunction(if_helper653524433)?if_helper653524433.app((false)):R.ffi.throwNonFunApp(L[1186],if_helper653524433,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2443724438 = $f2444324444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2444324444,
"from":L[1186]});
}
} catch($e2443524436) {
if(R.isCont($e2443524436)) {
var $ss2443924440 = {"from":L[1186],
"go":function(cont_tail_app654024445) {
return $Hcont_tail_app1080524446(cont_tail_app654024445);
}};
$e2443524436.stack[R.EXN_STACKHEIGHT++] = $ss2443924440;
}
if(R.isPyretException($e2443524436)) {
$e2443524436.pyretStack.push(L[1186]);
}
throw $e2443524436;
}
var $ret2444124442 = $Hcont_tail_app1080524446($z2443724438);
++R.GAS;
return $ret2444124442;
}
} else {
var cont_tail_arg653724449 = R.throwNonBooleanOp(L[3726],("first"),("and"),and_DASH_oper_DASH_7806382);
if(--R.GAS > 0) {
$z2444724448 = R.isFunction(if_helper653524433)?if_helper653524433.app(cont_tail_arg653724449):R.ffi.throwNonFunApp(L[3726],if_helper653524433,[cont_tail_arg653724449]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper653524433)?if_helper653524433.app(cont_tail_arg653724449):R.ffi.throwNonFunApp(L[3726],if_helper653524433,[cont_tail_arg653724449]);
},
"from":L[3726]});
}
++R.GAS;
return $z2444724448;
}
};
var $Hand_DASH_oper_DASH_1080424434 = function(and_DASH_oper_DASH_78124432,if_helper653524433) {
var anf_if654424468 = R.isBoolean(and_DASH_oper_DASH_78124432);
if(R.isPyretTrue(anf_if654424468)) {
var $z2445524456 = D;
var $f2446124462 = function(_) {
return R.isFunction(if_helper653524433)?if_helper653524433.app(and_DASH_oper_DASH_78124432):R.ffi.throwNonFunApp(L[1186],if_helper653524433,[and_DASH_oper_DASH_78124432]);
};
try {
if(--R.GAS > 0) {
$z2445524456 = $f2446124462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2446124462,
"from":L[1186]});
}
} catch($e2445324454) {
if(R.isCont($e2445324454)) {
var $ss2445724458 = {"from":L[1186],
"go":function(cont_tail_app654524463) {
return $Hcont_tail_app1080324464(cont_tail_app654524463);
}};
$e2445324454.stack[R.EXN_STACKHEIGHT++] = $ss2445724458;
}
if(R.isPyretException($e2445324454)) {
$e2445324454.pyretStack.push(L[1186]);
}
throw $e2445324454;
}
var $ret2445924460 = $Hcont_tail_app1080324464($z2445524456);
++R.GAS;
return $ret2445924460;
} else {
var cont_tail_arg654224467 = R.throwNonBooleanOp(L[3727],("second"),("and"),and_DASH_oper_DASH_78124432);
if(--R.GAS > 0) {
$z2446524466 = R.isFunction(if_helper653524433)?if_helper653524433.app(cont_tail_arg654224467):R.ffi.throwNonFunApp(L[3727],if_helper653524433,[cont_tail_arg654224467]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper653524433)?if_helper653524433.app(cont_tail_arg654224467):R.ffi.throwNonFunApp(L[3727],if_helper653524433,[cont_tail_arg654224467]);
},
"from":L[3727]});
}
++R.GAS;
return $z2446524466;
}
};
var $Hcont_tail_app1080324464 = function(cont_tail_app654524463) {
return cont_tail_app654524463;
};
var $Hcont_tail_app1080524446 = function(cont_tail_app654024445) {
return cont_tail_app654024445;
};
var $Hann_DASH_check_DASH_temp108026408 = function(ann_DASH_check_DASH_temp65236407) {
return ann_DASH_check_DASH_temp65236407;
};
var $Hann_DASH_check_DASH_temp108016423 = function(ann_DASH_check_DASH_temp65256422) {
return ann_DASH_check_DASH_temp65256422;
};
var $Hann_DASH_check_DASH_temp108006444 = function(ann_DASH_check_DASH_temp65166443) {
return ann_DASH_check_DASH_temp65166443;
};
var $Hann_DASH_check_DASH_temp107996461 = function(ann_DASH_check_DASH_temp65106460) {
return ann_DASH_check_DASH_temp65106460;
};
var $Hann_DASH_check_DASH_temp107986476 = function(ann_DASH_check_DASH_temp65126475) {
return ann_DASH_check_DASH_temp65126475;
};
var $Hand_DASH_oper_DASH_107976493 = function(and_DASH_oper_DASH_7766491,self17026490,types17066492) {
var if_helper649824481 = R.makeFunction(function(if_helper_arg649924499) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1201],1,arguments);
}
var ann_DASH_check_DASH_temp649624500 = if_helper_arg649924499;
return ann_DASH_check_DASH_temp649624500;
});
var anf_if650224498 = R.isBoolean(and_DASH_oper_DASH_7766491);
if(R.isPyretTrue(anf_if650224498)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7766491)) {
var anf_fun650424479 = G(types17066492,"visit",L[3728]);
var $z2447124472 = D;
var $f2447724478 = function(_) {
return R.isFunction(anf_fun650424479)?anf_fun650424479.app(self17026490):R.ffi.throwNonFunApp(L[1201],anf_fun650424479,[self17026490]);
};
try {
if(--R.GAS > 0) {
$z2447124472 = $f2447724478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2447724478,
"from":L[1201]});
}
} catch($e2446924470) {
if(R.isCont($e2446924470)) {
var $ss2447324474 = {"from":L[1201],
"go":function(and_DASH_oper_DASH_77724480) {
return $Hand_DASH_oper_DASH_1079524482(and_DASH_oper_DASH_77724480,if_helper649824481);
}};
$e2446924470.stack[R.EXN_STACKHEIGHT++] = $ss2447324474;
}
if(R.isPyretException($e2446924470)) {
$e2446924470.pyretStack.push(L[1201]);
}
throw $e2446924470;
}
var $ret2447524476 = $Hand_DASH_oper_DASH_1079524482($z2447124472,if_helper649824481);
++R.GAS;
return $ret2447524476;
} else {
var $z2448524486 = D;
var $f2449124492 = function(_) {
return R.isFunction(if_helper649824481)?if_helper649824481.app((false)):R.ffi.throwNonFunApp(L[1201],if_helper649824481,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2448524486 = $f2449124492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2449124492,
"from":L[1201]});
}
} catch($e2448324484) {
if(R.isCont($e2448324484)) {
var $ss2448724488 = {"from":L[1201],
"go":function(cont_tail_app650324493) {
return $Hcont_tail_app1079624494(cont_tail_app650324493);
}};
$e2448324484.stack[R.EXN_STACKHEIGHT++] = $ss2448724488;
}
if(R.isPyretException($e2448324484)) {
$e2448324484.pyretStack.push(L[1201]);
}
throw $e2448324484;
}
var $ret2448924490 = $Hcont_tail_app1079624494($z2448524486);
++R.GAS;
return $ret2448924490;
}
} else {
var cont_tail_arg650024497 = R.throwNonBooleanOp(L[3729],("first"),("and"),and_DASH_oper_DASH_7766491);
if(--R.GAS > 0) {
$z2449524496 = R.isFunction(if_helper649824481)?if_helper649824481.app(cont_tail_arg650024497):R.ffi.throwNonFunApp(L[3729],if_helper649824481,[cont_tail_arg650024497]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper649824481)?if_helper649824481.app(cont_tail_arg650024497):R.ffi.throwNonFunApp(L[3729],if_helper649824481,[cont_tail_arg650024497]);
},
"from":L[3729]});
}
++R.GAS;
return $z2449524496;
}
};
var $Hand_DASH_oper_DASH_1079524482 = function(and_DASH_oper_DASH_77724480,if_helper649824481) {
var anf_if650724516 = R.isBoolean(and_DASH_oper_DASH_77724480);
if(R.isPyretTrue(anf_if650724516)) {
var $z2450324504 = D;
var $f2450924510 = function(_) {
return R.isFunction(if_helper649824481)?if_helper649824481.app(and_DASH_oper_DASH_77724480):R.ffi.throwNonFunApp(L[1201],if_helper649824481,[and_DASH_oper_DASH_77724480]);
};
try {
if(--R.GAS > 0) {
$z2450324504 = $f2450924510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2450924510,
"from":L[1201]});
}
} catch($e2450124502) {
if(R.isCont($e2450124502)) {
var $ss2450524506 = {"from":L[1201],
"go":function(cont_tail_app650824511) {
return $Hcont_tail_app1079424512(cont_tail_app650824511);
}};
$e2450124502.stack[R.EXN_STACKHEIGHT++] = $ss2450524506;
}
if(R.isPyretException($e2450124502)) {
$e2450124502.pyretStack.push(L[1201]);
}
throw $e2450124502;
}
var $ret2450724508 = $Hcont_tail_app1079424512($z2450324504);
++R.GAS;
return $ret2450724508;
} else {
var cont_tail_arg650524515 = R.throwNonBooleanOp(L[3730],("second"),("and"),and_DASH_oper_DASH_77724480);
if(--R.GAS > 0) {
$z2451324514 = R.isFunction(if_helper649824481)?if_helper649824481.app(cont_tail_arg650524515):R.ffi.throwNonFunApp(L[3730],if_helper649824481,[cont_tail_arg650524515]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper649824481)?if_helper649824481.app(cont_tail_arg650524515):R.ffi.throwNonFunApp(L[3730],if_helper649824481,[cont_tail_arg650524515]);
},
"from":L[3730]});
}
++R.GAS;
return $z2451324514;
}
};
var $Hcont_tail_app1079424512 = function(cont_tail_app650824511) {
return cont_tail_app650824511;
};
var $Hcont_tail_app1079624494 = function(cont_tail_app650324493) {
return cont_tail_app650324493;
};
var $Hand_DASH_oper_DASH_107936519 = function(and_DASH_oper_DASH_7746517,name16956518,self16926516) {
var if_helper648024529 = R.makeFunction(function(if_helper_arg648124547) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1206],1,arguments);
}
var ann_DASH_check_DASH_temp647824548 = if_helper_arg648124547;
return ann_DASH_check_DASH_temp647824548;
});
var anf_if648424546 = R.isBoolean(and_DASH_oper_DASH_7746517);
if(R.isPyretTrue(anf_if648424546)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7746517)) {
var anf_fun648624527 = G(name16956518,"visit",L[3731]);
var $z2451924520 = D;
var $f2452524526 = function(_) {
return R.isFunction(anf_fun648624527)?anf_fun648624527.app(self16926516):R.ffi.throwNonFunApp(L[1206],anf_fun648624527,[self16926516]);
};
try {
if(--R.GAS > 0) {
$z2451924520 = $f2452524526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2452524526,
"from":L[1206]});
}
} catch($e2451724518) {
if(R.isCont($e2451724518)) {
var $ss2452124522 = {"from":L[1206],
"go":function(and_DASH_oper_DASH_77524528) {
return $Hand_DASH_oper_DASH_1079124530(and_DASH_oper_DASH_77524528,if_helper648024529);
}};
$e2451724518.stack[R.EXN_STACKHEIGHT++] = $ss2452124522;
}
if(R.isPyretException($e2451724518)) {
$e2451724518.pyretStack.push(L[1206]);
}
throw $e2451724518;
}
var $ret2452324524 = $Hand_DASH_oper_DASH_1079124530($z2451924520,if_helper648024529);
++R.GAS;
return $ret2452324524;
} else {
var $z2453324534 = D;
var $f2453924540 = function(_) {
return R.isFunction(if_helper648024529)?if_helper648024529.app((false)):R.ffi.throwNonFunApp(L[1206],if_helper648024529,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2453324534 = $f2453924540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2453924540,
"from":L[1206]});
}
} catch($e2453124532) {
if(R.isCont($e2453124532)) {
var $ss2453524536 = {"from":L[1206],
"go":function(cont_tail_app648524541) {
return $Hcont_tail_app1079224542(cont_tail_app648524541);
}};
$e2453124532.stack[R.EXN_STACKHEIGHT++] = $ss2453524536;
}
if(R.isPyretException($e2453124532)) {
$e2453124532.pyretStack.push(L[1206]);
}
throw $e2453124532;
}
var $ret2453724538 = $Hcont_tail_app1079224542($z2453324534);
++R.GAS;
return $ret2453724538;
}
} else {
var cont_tail_arg648224545 = R.throwNonBooleanOp(L[3732],("first"),("and"),and_DASH_oper_DASH_7746517);
if(--R.GAS > 0) {
$z2454324544 = R.isFunction(if_helper648024529)?if_helper648024529.app(cont_tail_arg648224545):R.ffi.throwNonFunApp(L[3732],if_helper648024529,[cont_tail_arg648224545]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper648024529)?if_helper648024529.app(cont_tail_arg648224545):R.ffi.throwNonFunApp(L[3732],if_helper648024529,[cont_tail_arg648224545]);
},
"from":L[3732]});
}
++R.GAS;
return $z2454324544;
}
};
var $Hand_DASH_oper_DASH_1079124530 = function(and_DASH_oper_DASH_77524528,if_helper648024529) {
var anf_if648924564 = R.isBoolean(and_DASH_oper_DASH_77524528);
if(R.isPyretTrue(anf_if648924564)) {
var $z2455124552 = D;
var $f2455724558 = function(_) {
return R.isFunction(if_helper648024529)?if_helper648024529.app(and_DASH_oper_DASH_77524528):R.ffi.throwNonFunApp(L[1206],if_helper648024529,[and_DASH_oper_DASH_77524528]);
};
try {
if(--R.GAS > 0) {
$z2455124552 = $f2455724558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2455724558,
"from":L[1206]});
}
} catch($e2454924550) {
if(R.isCont($e2454924550)) {
var $ss2455324554 = {"from":L[1206],
"go":function(cont_tail_app649024559) {
return $Hcont_tail_app1079024560(cont_tail_app649024559);
}};
$e2454924550.stack[R.EXN_STACKHEIGHT++] = $ss2455324554;
}
if(R.isPyretException($e2454924550)) {
$e2454924550.pyretStack.push(L[1206]);
}
throw $e2454924550;
}
var $ret2455524556 = $Hcont_tail_app1079024560($z2455124552);
++R.GAS;
return $ret2455524556;
} else {
var cont_tail_arg648724563 = R.throwNonBooleanOp(L[3733],("second"),("and"),and_DASH_oper_DASH_77524528);
if(--R.GAS > 0) {
$z2456124562 = R.isFunction(if_helper648024529)?if_helper648024529.app(cont_tail_arg648724563):R.ffi.throwNonFunApp(L[3733],if_helper648024529,[cont_tail_arg648724563]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper648024529)?if_helper648024529.app(cont_tail_arg648724563):R.ffi.throwNonFunApp(L[3733],if_helper648024529,[cont_tail_arg648724563]);
},
"from":L[3733]});
}
++R.GAS;
return $z2456124562;
}
};
var $Hcont_tail_app1079024560 = function(cont_tail_app649024559) {
return cont_tail_app649024559;
};
var $Hcont_tail_app1079224542 = function(cont_tail_app648524541) {
return cont_tail_app648524541;
};
var $Hand_DASH_oper_DASH_107896538 = function(and_DASH_oper_DASH_7686534,body16916535,imports16906536,lists974,provided_DASH_types16896537,self16866533) {
var if_helper645024578 = R.makeFunction(function(if_helper_arg645124610) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1209],1,arguments);
}
var ann_DASH_check_DASH_temp644824611 = if_helper_arg645124610;
return ann_DASH_check_DASH_temp644824611;
});
var anf_if645424609 = R.isBoolean(and_DASH_oper_DASH_7686534);
if(R.isPyretTrue(anf_if645424609)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7686534)) {
var anf_fun645624575 = G(lists974,"all",L[3735]);
var anf_arg645924576 = R.makeFunction(function(recv_DASH_77024580) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3734],1,arguments);
}
var anf_fun645824591 = G(recv_DASH_77024580,"visit",L[3734]);
var $z2458324584 = D;
var $f2458924590 = function(_) {
return R.isFunction(anf_fun645824591)?anf_fun645824591.app(self16866533):R.ffi.throwNonFunApp(L[3734],anf_fun645824591,[self16866533]);
};
try {
if(--R.GAS > 0) {
$z2458324584 = $f2458924590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2458924590,
"from":L[3734]});
}
} catch($e2458124582) {
if(R.isCont($e2458124582)) {
var $ss2458524586 = {"from":L[3734],
"go":function(ann_DASH_check_DASH_temp645724592) {
return $Hann_DASH_check_DASH_temp1078024593(ann_DASH_check_DASH_temp645724592);
}};
$e2458124582.stack[R.EXN_STACKHEIGHT++] = $ss2458524586;
}
if(R.isPyretException($e2458124582)) {
$e2458124582.pyretStack.push(L[3734]);
}
throw $e2458124582;
}
var $ret2458724588 = $Hann_DASH_check_DASH_temp1078024593($z2458324584);
++R.GAS;
return $ret2458724588;
});
var $z2456724568 = D;
var $f2457324574 = function(_) {
return R.isFunction(anf_fun645624575)?anf_fun645624575.app(anf_arg645924576,provided_DASH_types16896537):R.ffi.throwNonFunApp(L[1209],anf_fun645624575,[anf_arg645924576,provided_DASH_types16896537]);
};
try {
if(--R.GAS > 0) {
$z2456724568 = $f2457324574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2457324574,
"from":L[1209]});
}
} catch($e2456524566) {
if(R.isCont($e2456524566)) {
var $ss2456924570 = {"from":L[1209],
"go":function(and_DASH_oper_DASH_76924577) {
return $Hand_DASH_oper_DASH_1078724579(and_DASH_oper_DASH_76924577,body16916535,if_helper645024578,imports16906536,lists974,self16866533);
}};
$e2456524566.stack[R.EXN_STACKHEIGHT++] = $ss2456924570;
}
if(R.isPyretException($e2456524566)) {
$e2456524566.pyretStack.push(L[1209]);
}
throw $e2456524566;
}
var $ret2457124572 = $Hand_DASH_oper_DASH_1078724579($z2456724568,body16916535,if_helper645024578,imports16906536,lists974,self16866533);
++R.GAS;
return $ret2457124572;
} else {
var $z2459624597 = D;
var $f2460224603 = function(_) {
return R.isFunction(if_helper645024578)?if_helper645024578.app((false)):R.ffi.throwNonFunApp(L[1209],if_helper645024578,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2459624597 = $f2460224603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2460224603,
"from":L[1209]});
}
} catch($e2459424595) {
if(R.isCont($e2459424595)) {
var $ss2459824599 = {"from":L[1209],
"go":function(cont_tail_app645524604) {
return $Hcont_tail_app1078824605(cont_tail_app645524604);
}};
$e2459424595.stack[R.EXN_STACKHEIGHT++] = $ss2459824599;
}
if(R.isPyretException($e2459424595)) {
$e2459424595.pyretStack.push(L[1209]);
}
throw $e2459424595;
}
var $ret2460024601 = $Hcont_tail_app1078824605($z2459624597);
++R.GAS;
return $ret2460024601;
}
} else {
var cont_tail_arg645224608 = R.throwNonBooleanOp(L[3736],("first"),("and"),and_DASH_oper_DASH_7686534);
if(--R.GAS > 0) {
$z2460624607 = R.isFunction(if_helper645024578)?if_helper645024578.app(cont_tail_arg645224608):R.ffi.throwNonFunApp(L[3736],if_helper645024578,[cont_tail_arg645224608]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper645024578)?if_helper645024578.app(cont_tail_arg645224608):R.ffi.throwNonFunApp(L[3736],if_helper645024578,[cont_tail_arg645224608]);
},
"from":L[3736]});
}
++R.GAS;
return $z2460624607;
}
};
var $Hand_DASH_oper_DASH_1078724579 = function(and_DASH_oper_DASH_76924577,body16916535,if_helper645024578,imports16906536,lists974,self16866533) {
var anf_if646224655 = R.isBoolean(and_DASH_oper_DASH_76924577);
if(R.isPyretTrue(anf_if646224655)) {
if(R.isPyretTrue(and_DASH_oper_DASH_76924577)) {
var anf_fun646424622 = G(lists974,"all",L[3738]);
var anf_arg646724623 = R.makeFunction(function(recv_DASH_77224626) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3737],1,arguments);
}
var anf_fun646624637 = G(recv_DASH_77224626,"visit",L[3737]);
var $z2462924630 = D;
var $f2463524636 = function(_) {
return R.isFunction(anf_fun646624637)?anf_fun646624637.app(self16866533):R.ffi.throwNonFunApp(L[3737],anf_fun646624637,[self16866533]);
};
try {
if(--R.GAS > 0) {
$z2462924630 = $f2463524636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2463524636,
"from":L[3737]});
}
} catch($e2462724628) {
if(R.isCont($e2462724628)) {
var $ss2463124632 = {"from":L[3737],
"go":function(ann_DASH_check_DASH_temp646524638) {
return $Hann_DASH_check_DASH_temp1078124639(ann_DASH_check_DASH_temp646524638);
}};
$e2462724628.stack[R.EXN_STACKHEIGHT++] = $ss2463124632;
}
if(R.isPyretException($e2462724628)) {
$e2462724628.pyretStack.push(L[3737]);
}
throw $e2462724628;
}
var $ret2463324634 = $Hann_DASH_check_DASH_temp1078124639($z2462924630);
++R.GAS;
return $ret2463324634;
});
var $z2461424615 = D;
var $f2462024621 = function(_) {
return R.isFunction(anf_fun646424622)?anf_fun646424622.app(anf_arg646724623,imports16906536):R.ffi.throwNonFunApp(L[1209],anf_fun646424622,[anf_arg646724623,imports16906536]);
};
try {
if(--R.GAS > 0) {
$z2461424615 = $f2462024621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2462024621,
"from":L[1209]});
}
} catch($e2461224613) {
if(R.isCont($e2461224613)) {
var $ss2461624617 = {"from":L[1209],
"go":function(and_DASH_oper_DASH_77124624) {
return $Hand_DASH_oper_DASH_1078524625(and_DASH_oper_DASH_77124624,body16916535,if_helper645024578,self16866533);
}};
$e2461224613.stack[R.EXN_STACKHEIGHT++] = $ss2461624617;
}
if(R.isPyretException($e2461224613)) {
$e2461224613.pyretStack.push(L[1209]);
}
throw $e2461224613;
}
var $ret2461824619 = $Hand_DASH_oper_DASH_1078524625($z2461424615,body16916535,if_helper645024578,self16866533);
++R.GAS;
return $ret2461824619;
} else {
var $z2464224643 = D;
var $f2464824649 = function(_) {
return R.isFunction(if_helper645024578)?if_helper645024578.app((false)):R.ffi.throwNonFunApp(L[1209],if_helper645024578,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2464224643 = $f2464824649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2464824649,
"from":L[1209]});
}
} catch($e2464024641) {
if(R.isCont($e2464024641)) {
var $ss2464424645 = {"from":L[1209],
"go":function(cont_tail_app646324650) {
return $Hcont_tail_app1078624651(cont_tail_app646324650);
}};
$e2464024641.stack[R.EXN_STACKHEIGHT++] = $ss2464424645;
}
if(R.isPyretException($e2464024641)) {
$e2464024641.pyretStack.push(L[1209]);
}
throw $e2464024641;
}
var $ret2464624647 = $Hcont_tail_app1078624651($z2464224643);
++R.GAS;
return $ret2464624647;
}
} else {
var cont_tail_arg646024654 = R.throwNonBooleanOp(L[3739],("first"),("and"),and_DASH_oper_DASH_76924577);
if(--R.GAS > 0) {
$z2465224653 = R.isFunction(if_helper645024578)?if_helper645024578.app(cont_tail_arg646024654):R.ffi.throwNonFunApp(L[3739],if_helper645024578,[cont_tail_arg646024654]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper645024578)?if_helper645024578.app(cont_tail_arg646024654):R.ffi.throwNonFunApp(L[3739],if_helper645024578,[cont_tail_arg646024654]);
},
"from":L[3739]});
}
++R.GAS;
return $z2465224653;
}
};
var $Hand_DASH_oper_DASH_1078524625 = function(and_DASH_oper_DASH_77124624,body16916535,if_helper645024578,self16866533) {
var anf_if647024684 = R.isBoolean(and_DASH_oper_DASH_77124624);
if(R.isPyretTrue(anf_if647024684)) {
if(R.isPyretTrue(and_DASH_oper_DASH_77124624)) {
var anf_fun647224666 = G(body16916535,"visit",L[3740]);
var $z2465824659 = D;
var $f2466424665 = function(_) {
return R.isFunction(anf_fun647224666)?anf_fun647224666.app(self16866533):R.ffi.throwNonFunApp(L[1209],anf_fun647224666,[self16866533]);
};
try {
if(--R.GAS > 0) {
$z2465824659 = $f2466424665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2466424665,
"from":L[1209]});
}
} catch($e2465624657) {
if(R.isCont($e2465624657)) {
var $ss2466024661 = {"from":L[1209],
"go":function(and_DASH_oper_DASH_77324667) {
return $Hand_DASH_oper_DASH_1078324668(and_DASH_oper_DASH_77324667,if_helper645024578);
}};
$e2465624657.stack[R.EXN_STACKHEIGHT++] = $ss2466024661;
}
if(R.isPyretException($e2465624657)) {
$e2465624657.pyretStack.push(L[1209]);
}
throw $e2465624657;
}
var $ret2466224663 = $Hand_DASH_oper_DASH_1078324668($z2465824659,if_helper645024578);
++R.GAS;
return $ret2466224663;
} else {
var $z2467124672 = D;
var $f2467724678 = function(_) {
return R.isFunction(if_helper645024578)?if_helper645024578.app((false)):R.ffi.throwNonFunApp(L[1209],if_helper645024578,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2467124672 = $f2467724678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2467724678,
"from":L[1209]});
}
} catch($e2466924670) {
if(R.isCont($e2466924670)) {
var $ss2467324674 = {"from":L[1209],
"go":function(cont_tail_app647124679) {
return $Hcont_tail_app1078424680(cont_tail_app647124679);
}};
$e2466924670.stack[R.EXN_STACKHEIGHT++] = $ss2467324674;
}
if(R.isPyretException($e2466924670)) {
$e2466924670.pyretStack.push(L[1209]);
}
throw $e2466924670;
}
var $ret2467524676 = $Hcont_tail_app1078424680($z2467124672);
++R.GAS;
return $ret2467524676;
}
} else {
var cont_tail_arg646824683 = R.throwNonBooleanOp(L[3741],("first"),("and"),and_DASH_oper_DASH_77124624);
if(--R.GAS > 0) {
$z2468124682 = R.isFunction(if_helper645024578)?if_helper645024578.app(cont_tail_arg646824683):R.ffi.throwNonFunApp(L[3741],if_helper645024578,[cont_tail_arg646824683]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper645024578)?if_helper645024578.app(cont_tail_arg646824683):R.ffi.throwNonFunApp(L[3741],if_helper645024578,[cont_tail_arg646824683]);
},
"from":L[3741]});
}
++R.GAS;
return $z2468124682;
}
};
var $Hand_DASH_oper_DASH_1078324668 = function(and_DASH_oper_DASH_77324667,if_helper645024578) {
var anf_if647524700 = R.isBoolean(and_DASH_oper_DASH_77324667);
if(R.isPyretTrue(anf_if647524700)) {
var $z2468724688 = D;
var $f2469324694 = function(_) {
return R.isFunction(if_helper645024578)?if_helper645024578.app(and_DASH_oper_DASH_77324667):R.ffi.throwNonFunApp(L[1209],if_helper645024578,[and_DASH_oper_DASH_77324667]);
};
try {
if(--R.GAS > 0) {
$z2468724688 = $f2469324694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2469324694,
"from":L[1209]});
}
} catch($e2468524686) {
if(R.isCont($e2468524686)) {
var $ss2468924690 = {"from":L[1209],
"go":function(cont_tail_app647624695) {
return $Hcont_tail_app1078224696(cont_tail_app647624695);
}};
$e2468524686.stack[R.EXN_STACKHEIGHT++] = $ss2468924690;
}
if(R.isPyretException($e2468524686)) {
$e2468524686.pyretStack.push(L[1209]);
}
throw $e2468524686;
}
var $ret2469124692 = $Hcont_tail_app1078224696($z2468724688);
++R.GAS;
return $ret2469124692;
} else {
var cont_tail_arg647324699 = R.throwNonBooleanOp(L[3742],("second"),("and"),and_DASH_oper_DASH_77324667);
if(--R.GAS > 0) {
$z2469724698 = R.isFunction(if_helper645024578)?if_helper645024578.app(cont_tail_arg647324699):R.ffi.throwNonFunApp(L[3742],if_helper645024578,[cont_tail_arg647324699]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper645024578)?if_helper645024578.app(cont_tail_arg647324699):R.ffi.throwNonFunApp(L[3742],if_helper645024578,[cont_tail_arg647324699]);
},
"from":L[3742]});
}
++R.GAS;
return $z2469724698;
}
};
var $Hcont_tail_app1078224696 = function(cont_tail_app647624695) {
return cont_tail_app647624695;
};
var $Hcont_tail_app1078424680 = function(cont_tail_app647124679) {
return cont_tail_app647124679;
};
var $Hann_DASH_check_DASH_temp1078124639 = function(ann_DASH_check_DASH_temp646524638) {
return ann_DASH_check_DASH_temp646524638;
};
var $Hcont_tail_app1078624651 = function(cont_tail_app646324650) {
return cont_tail_app646324650;
};
var $Hann_DASH_check_DASH_temp1078024593 = function(ann_DASH_check_DASH_temp645724592) {
return ann_DASH_check_DASH_temp645724592;
};
var $Hcont_tail_app1078824605 = function(cont_tail_app645524604) {
return cont_tail_app645524604;
};
var $Hand_DASH_oper_DASH_107796557 = function(and_DASH_oper_DASH_7636553,checks16856554,lists974,provides16836555,self16806552,types16846556) {
var if_helper642324713 = R.makeFunction(function(if_helper_arg642424731) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1212],1,arguments);
}
var ann_DASH_check_DASH_temp642124732 = if_helper_arg642424731;
return ann_DASH_check_DASH_temp642124732;
});
var anf_if642724730 = R.isBoolean(and_DASH_oper_DASH_7636553);
if(R.isPyretTrue(anf_if642724730)) {
if(R.isPyretTrue(and_DASH_oper_DASH_7636553)) {
var anf_fun642924711 = G(provides16836555,"visit",L[3743]);
var $z2470324704 = D;
var $f2470924710 = function(_) {
return R.isFunction(anf_fun642924711)?anf_fun642924711.app(self16806552):R.ffi.throwNonFunApp(L[1212],anf_fun642924711,[self16806552]);
};
try {
if(--R.GAS > 0) {
$z2470324704 = $f2470924710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2470924710,
"from":L[1212]});
}
} catch($e2470124702) {
if(R.isCont($e2470124702)) {
var $ss2470524706 = {"from":L[1212],
"go":function(and_DASH_oper_DASH_76424712) {
return $Hand_DASH_oper_DASH_1077724714(and_DASH_oper_DASH_76424712,checks16856554,if_helper642324713,lists974,self16806552,types16846556);
}};
$e2470124702.stack[R.EXN_STACKHEIGHT++] = $ss2470524706;
}
if(R.isPyretException($e2470124702)) {
$e2470124702.pyretStack.push(L[1212]);
}
throw $e2470124702;
}
var $ret2470724708 = $Hand_DASH_oper_DASH_1077724714($z2470324704,checks16856554,if_helper642324713,lists974,self16806552,types16846556);
++R.GAS;
return $ret2470724708;
} else {
var $z2471724718 = D;
var $f2472324724 = function(_) {
return R.isFunction(if_helper642324713)?if_helper642324713.app((false)):R.ffi.throwNonFunApp(L[1212],if_helper642324713,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2471724718 = $f2472324724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2472324724,
"from":L[1212]});
}
} catch($e2471524716) {
if(R.isCont($e2471524716)) {
var $ss2471924720 = {"from":L[1212],
"go":function(cont_tail_app642824725) {
return $Hcont_tail_app1077824726(cont_tail_app642824725);
}};
$e2471524716.stack[R.EXN_STACKHEIGHT++] = $ss2471924720;
}
if(R.isPyretException($e2471524716)) {
$e2471524716.pyretStack.push(L[1212]);
}
throw $e2471524716;
}
var $ret2472124722 = $Hcont_tail_app1077824726($z2471724718);
++R.GAS;
return $ret2472124722;
}
} else {
var cont_tail_arg642524729 = R.throwNonBooleanOp(L[3744],("first"),("and"),and_DASH_oper_DASH_7636553);
if(--R.GAS > 0) {
$z2472724728 = R.isFunction(if_helper642324713)?if_helper642324713.app(cont_tail_arg642524729):R.ffi.throwNonFunApp(L[3744],if_helper642324713,[cont_tail_arg642524729]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper642324713)?if_helper642324713.app(cont_tail_arg642524729):R.ffi.throwNonFunApp(L[3744],if_helper642324713,[cont_tail_arg642524729]);
},
"from":L[3744]});
}
++R.GAS;
return $z2472724728;
}
};
var $Hand_DASH_oper_DASH_1077724714 = function(and_DASH_oper_DASH_76424712,checks16856554,if_helper642324713,lists974,self16806552,types16846556) {
var anf_if643224776 = R.isBoolean(and_DASH_oper_DASH_76424712);
if(R.isPyretTrue(anf_if643224776)) {
if(R.isPyretTrue(and_DASH_oper_DASH_76424712)) {
var anf_fun643424743 = G(lists974,"all",L[3746]);
var anf_arg643724744 = R.makeFunction(function(recv_DASH_76624747) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3745],1,arguments);
}
var anf_fun643624758 = G(recv_DASH_76624747,"visit",L[3745]);
var $z2475024751 = D;
var $f2475624757 = function(_) {
return R.isFunction(anf_fun643624758)?anf_fun643624758.app(self16806552):R.ffi.throwNonFunApp(L[3745],anf_fun643624758,[self16806552]);
};
try {
if(--R.GAS > 0) {
$z2475024751 = $f2475624757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2475624757,
"from":L[3745]});
}
} catch($e2474824749) {
if(R.isCont($e2474824749)) {
var $ss2475224753 = {"from":L[3745],
"go":function(ann_DASH_check_DASH_temp643524759) {
return $Hann_DASH_check_DASH_temp1077124760(ann_DASH_check_DASH_temp643524759);
}};
$e2474824749.stack[R.EXN_STACKHEIGHT++] = $ss2475224753;
}
if(R.isPyretException($e2474824749)) {
$e2474824749.pyretStack.push(L[3745]);
}
throw $e2474824749;
}
var $ret2475424755 = $Hann_DASH_check_DASH_temp1077124760($z2475024751);
++R.GAS;
return $ret2475424755;
});
var $z2473524736 = D;
var $f2474124742 = function(_) {
return R.isFunction(anf_fun643424743)?anf_fun643424743.app(anf_arg643724744,types16846556):R.ffi.throwNonFunApp(L[1212],anf_fun643424743,[anf_arg643724744,types16846556]);
};
try {
if(--R.GAS > 0) {
$z2473524736 = $f2474124742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2474124742,
"from":L[1212]});
}
} catch($e2473324734) {
if(R.isCont($e2473324734)) {
var $ss2473724738 = {"from":L[1212],
"go":function(and_DASH_oper_DASH_76524745) {
return $Hand_DASH_oper_DASH_1077524746(and_DASH_oper_DASH_76524745,checks16856554,if_helper642324713,self16806552);
}};
$e2473324734.stack[R.EXN_STACKHEIGHT++] = $ss2473724738;
}
if(R.isPyretException($e2473324734)) {
$e2473324734.pyretStack.push(L[1212]);
}
throw $e2473324734;
}
var $ret2473924740 = $Hand_DASH_oper_DASH_1077524746($z2473524736,checks16856554,if_helper642324713,self16806552);
++R.GAS;
return $ret2473924740;
} else {
var $z2476324764 = D;
var $f2476924770 = function(_) {
return R.isFunction(if_helper642324713)?if_helper642324713.app((false)):R.ffi.throwNonFunApp(L[1212],if_helper642324713,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2476324764 = $f2476924770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2476924770,
"from":L[1212]});
}
} catch($e2476124762) {
if(R.isCont($e2476124762)) {
var $ss2476524766 = {"from":L[1212],
"go":function(cont_tail_app643324771) {
return $Hcont_tail_app1077624772(cont_tail_app643324771);
}};
$e2476124762.stack[R.EXN_STACKHEIGHT++] = $ss2476524766;
}
if(R.isPyretException($e2476124762)) {
$e2476124762.pyretStack.push(L[1212]);
}
throw $e2476124762;
}
var $ret2476724768 = $Hcont_tail_app1077624772($z2476324764);
++R.GAS;
return $ret2476724768;
}
} else {
var cont_tail_arg643024775 = R.throwNonBooleanOp(L[3747],("first"),("and"),and_DASH_oper_DASH_76424712);
if(--R.GAS > 0) {
$z2477324774 = R.isFunction(if_helper642324713)?if_helper642324713.app(cont_tail_arg643024775):R.ffi.throwNonFunApp(L[3747],if_helper642324713,[cont_tail_arg643024775]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper642324713)?if_helper642324713.app(cont_tail_arg643024775):R.ffi.throwNonFunApp(L[3747],if_helper642324713,[cont_tail_arg643024775]);
},
"from":L[3747]});
}
++R.GAS;
return $z2477324774;
}
};
var $Hand_DASH_oper_DASH_1077524746 = function(and_DASH_oper_DASH_76524745,checks16856554,if_helper642324713,self16806552) {
var anf_if644024805 = R.isBoolean(and_DASH_oper_DASH_76524745);
if(R.isPyretTrue(anf_if644024805)) {
if(R.isPyretTrue(and_DASH_oper_DASH_76524745)) {
var anf_fun644224787 = G(checks16856554,"visit",L[3748]);
var $z2477924780 = D;
var $f2478524786 = function(_) {
return R.isFunction(anf_fun644224787)?anf_fun644224787.app(self16806552):R.ffi.throwNonFunApp(L[1212],anf_fun644224787,[self16806552]);
};
try {
if(--R.GAS > 0) {
$z2477924780 = $f2478524786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2478524786,
"from":L[1212]});
}
} catch($e2477724778) {
if(R.isCont($e2477724778)) {
var $ss2478124782 = {"from":L[1212],
"go":function(and_DASH_oper_DASH_76724788) {
return $Hand_DASH_oper_DASH_1077324789(and_DASH_oper_DASH_76724788,if_helper642324713);
}};
$e2477724778.stack[R.EXN_STACKHEIGHT++] = $ss2478124782;
}
if(R.isPyretException($e2477724778)) {
$e2477724778.pyretStack.push(L[1212]);
}
throw $e2477724778;
}
var $ret2478324784 = $Hand_DASH_oper_DASH_1077324789($z2477924780,if_helper642324713);
++R.GAS;
return $ret2478324784;
} else {
var $z2479224793 = D;
var $f2479824799 = function(_) {
return R.isFunction(if_helper642324713)?if_helper642324713.app((false)):R.ffi.throwNonFunApp(L[1212],if_helper642324713,[(false)]);
};
try {
if(--R.GAS > 0) {
$z2479224793 = $f2479824799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2479824799,
"from":L[1212]});
}
} catch($e2479024791) {
if(R.isCont($e2479024791)) {
var $ss2479424795 = {"from":L[1212],
"go":function(cont_tail_app644124800) {
return $Hcont_tail_app1077424801(cont_tail_app644124800);
}};
$e2479024791.stack[R.EXN_STACKHEIGHT++] = $ss2479424795;
}
if(R.isPyretException($e2479024791)) {
$e2479024791.pyretStack.push(L[1212]);
}
throw $e2479024791;
}
var $ret2479624797 = $Hcont_tail_app1077424801($z2479224793);
++R.GAS;
return $ret2479624797;
}
} else {
var cont_tail_arg643824804 = R.throwNonBooleanOp(L[3749],("first"),("and"),and_DASH_oper_DASH_76524745);
if(--R.GAS > 0) {
$z2480224803 = R.isFunction(if_helper642324713)?if_helper642324713.app(cont_tail_arg643824804):R.ffi.throwNonFunApp(L[3749],if_helper642324713,[cont_tail_arg643824804]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper642324713)?if_helper642324713.app(cont_tail_arg643824804):R.ffi.throwNonFunApp(L[3749],if_helper642324713,[cont_tail_arg643824804]);
},
"from":L[3749]});
}
++R.GAS;
return $z2480224803;
}
};
var $Hand_DASH_oper_DASH_1077324789 = function(and_DASH_oper_DASH_76724788,if_helper642324713) {
var anf_if644524821 = R.isBoolean(and_DASH_oper_DASH_76724788);
if(R.isPyretTrue(anf_if644524821)) {
var $z2480824809 = D;
var $f2481424815 = function(_) {
return R.isFunction(if_helper642324713)?if_helper642324713.app(and_DASH_oper_DASH_76724788):R.ffi.throwNonFunApp(L[1212],if_helper642324713,[and_DASH_oper_DASH_76724788]);
};
try {
if(--R.GAS > 0) {
$z2480824809 = $f2481424815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2481424815,
"from":L[1212]});
}
} catch($e2480624807) {
if(R.isCont($e2480624807)) {
var $ss2481024811 = {"from":L[1212],
"go":function(cont_tail_app644624816) {
return $Hcont_tail_app1077224817(cont_tail_app644624816);
}};
$e2480624807.stack[R.EXN_STACKHEIGHT++] = $ss2481024811;
}
if(R.isPyretException($e2480624807)) {
$e2480624807.pyretStack.push(L[1212]);
}
throw $e2480624807;
}
var $ret2481224813 = $Hcont_tail_app1077224817($z2480824809);
++R.GAS;
return $ret2481224813;
} else {
var cont_tail_arg644324820 = R.throwNonBooleanOp(L[3750],("second"),("and"),and_DASH_oper_DASH_76724788);
if(--R.GAS > 0) {
$z2481824819 = R.isFunction(if_helper642324713)?if_helper642324713.app(cont_tail_arg644324820):R.ffi.throwNonFunApp(L[3750],if_helper642324713,[cont_tail_arg644324820]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper642324713)?if_helper642324713.app(cont_tail_arg644324820):R.ffi.throwNonFunApp(L[3750],if_helper642324713,[cont_tail_arg644324820]);
},
"from":L[3750]});
}
++R.GAS;
return $z2481824819;
}
};
var $Hcont_tail_app1077224817 = function(cont_tail_app644624816) {
return cont_tail_app644624816;
};
var $Hcont_tail_app1077424801 = function(cont_tail_app644124800) {
return cont_tail_app644124800;
};
var $Hann_DASH_check_DASH_temp1077124760 = function(ann_DASH_check_DASH_temp643524759) {
return ann_DASH_check_DASH_temp643524759;
};
var $Hcont_tail_app1077624772 = function(cont_tail_app643324771) {
return cont_tail_app643324771;
};
var $Hcont_tail_app1077824726 = function(cont_tail_app642824725) {
return cont_tail_app642824725;
};
var $Hann_DASH_check_DASH_temp107706591 = function(ann_DASH_check_DASH_temp64006590) {
return ann_DASH_check_DASH_temp64006590;
};
var $Hann_DASH_check_DASH_temp107696609 = function(ann_DASH_check_DASH_temp64046608) {
return ann_DASH_check_DASH_temp64046608;
};
var $Hanf_arg107686731 = function(anf_arg63986728,a_DASH_field5282357,l16616729,name16626730) {
var $z2482424825 = D;
var $f2483024831 = function(_) {
return R.isFunction(a_DASH_field5282357.$var)?a_DASH_field5282357.$var.app(l16616729,name16626730,anf_arg63986728):R.ffi.throwNonFunApp(L[1227],a_DASH_field5282357.$var,[l16616729,name16626730,anf_arg63986728]);
};
try {
if(--R.GAS > 0) {
$z2482424825 = $f2483024831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2483024831,
"from":L[1227]});
}
} catch($e2482224823) {
if(R.isCont($e2482224823)) {
var $ss2482624827 = {"from":L[1227],
"go":function(ann_DASH_check_DASH_temp639624832) {
return $Hann_DASH_check_DASH_temp1076724833(ann_DASH_check_DASH_temp639624832);
}};
$e2482224823.stack[R.EXN_STACKHEIGHT++] = $ss2482624827;
}
if(R.isPyretException($e2482224823)) {
$e2482224823.pyretStack.push(L[1227]);
}
throw $e2482224823;
}
var $ret2482824829 = $Hann_DASH_check_DASH_temp1076724833($z2482424825);
++R.GAS;
return $ret2482824829;
};
var $Hann_DASH_check_DASH_temp1076724833 = function(ann_DASH_check_DASH_temp639624832) {
return ann_DASH_check_DASH_temp639624832;
};
var $Hanf_arg107666748 = function(anf_arg63946745,a_DASH_dot5232347,field16596746,l16576747) {
var $z2483624837 = D;
var $f2484224843 = function(_) {
return R.isFunction(a_DASH_dot5232347.$var)?a_DASH_dot5232347.$var.app(l16576747,anf_arg63946745,field16596746):R.ffi.throwNonFunApp(L[1230],a_DASH_dot5232347.$var,[l16576747,anf_arg63946745,field16596746]);
};
try {
if(--R.GAS > 0) {
$z2483624837 = $f2484224843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2484224843,
"from":L[1230]});
}
} catch($e2483424835) {
if(R.isCont($e2483424835)) {
var $ss2483824839 = {"from":L[1230],
"go":function(ann_DASH_check_DASH_temp639224844) {
return $Hann_DASH_check_DASH_temp1076524845(ann_DASH_check_DASH_temp639224844);
}};
$e2483424835.stack[R.EXN_STACKHEIGHT++] = $ss2483824839;
}
if(R.isPyretException($e2483424835)) {
$e2483424835.pyretStack.push(L[1230]);
}
throw $e2483424835;
}
var $ret2484024841 = $Hann_DASH_check_DASH_temp1076524845($z2483624837);
++R.GAS;
return $ret2484024841;
};
var $Hann_DASH_check_DASH_temp1076524845 = function(ann_DASH_check_DASH_temp639224844) {
return ann_DASH_check_DASH_temp639224844;
};
var $Hanf_arg107646765 = function(anf_arg63886762,a_DASH_pred5212343,exp16556763,l16536764,self16526761) {
var anf_fun638924856 = G(exp16556763,"visit",L[3752]);
var $z2484824849 = D;
var $f2485424855 = function(_) {
return R.isFunction(anf_fun638924856)?anf_fun638924856.app(self16526761):R.ffi.throwNonFunApp(L[3751],anf_fun638924856,[self16526761]);
};
try {
if(--R.GAS > 0) {
$z2484824849 = $f2485424855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2485424855,
"from":L[3751]});
}
} catch($e2484624847) {
if(R.isCont($e2484624847)) {
var $ss2485024851 = {"from":L[3751],
"go":function(anf_arg639024857) {
return $Hanf_arg1076324858(anf_arg639024857,a_DASH_pred5212343,anf_arg63886762,l16536764);
}};
$e2484624847.stack[R.EXN_STACKHEIGHT++] = $ss2485024851;
}
if(R.isPyretException($e2484624847)) {
$e2484624847.pyretStack.push(L[3751]);
}
throw $e2484624847;
}
var $ret2485224853 = $Hanf_arg1076324858($z2484824849,a_DASH_pred5212343,anf_arg63886762,l16536764);
++R.GAS;
return $ret2485224853;
};
var $Hanf_arg1076324858 = function(anf_arg639024857,a_DASH_pred5212343,anf_arg63886762,l16536764) {
var $z2486124862 = D;
var $f2486724868 = function(_) {
return R.isFunction(a_DASH_pred5212343.$var)?a_DASH_pred5212343.$var.app(l16536764,anf_arg63886762,anf_arg639024857):R.ffi.throwNonFunApp(L[1233],a_DASH_pred5212343.$var,[l16536764,anf_arg63886762,anf_arg639024857]);
};
try {
if(--R.GAS > 0) {
$z2486124862 = $f2486724868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2486724868,
"from":L[1233]});
}
} catch($e2485924860) {
if(R.isCont($e2485924860)) {
var $ss2486324864 = {"from":L[1233],
"go":function(ann_DASH_check_DASH_temp638624869) {
return $Hann_DASH_check_DASH_temp1076224870(ann_DASH_check_DASH_temp638624869);
}};
$e2485924860.stack[R.EXN_STACKHEIGHT++] = $ss2486324864;
}
if(R.isPyretException($e2485924860)) {
$e2485924860.pyretStack.push(L[1233]);
}
throw $e2485924860;
}
var $ret2486524866 = $Hann_DASH_check_DASH_temp1076224870($z2486124862);
++R.GAS;
return $ret2486524866;
};
var $Hann_DASH_check_DASH_temp1076224870 = function(ann_DASH_check_DASH_temp638624869) {
return ann_DASH_check_DASH_temp638624869;
};
var $Hanf_arg107616782 = function(anf_arg63796779,a_DASH_app5192339,args16516780,l16496781,self16486778) {
var anf_fun638024881 = G(args16516780,"map",L[3755]);
var anf_arg638324882 = R.makeFunction(function(recv_DASH_76124885) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3754],1,arguments);
}
var anf_fun638224896 = G(recv_DASH_76124885,"visit",L[3754]);
var $z2488824889 = D;
var $f2489424895 = function(_) {
return R.isFunction(anf_fun638224896)?anf_fun638224896.app(self16486778):R.ffi.throwNonFunApp(L[3754],anf_fun638224896,[self16486778]);
};
try {
if(--R.GAS > 0) {
$z2488824889 = $f2489424895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2489424895,
"from":L[3754]});
}
} catch($e2488624887) {
if(R.isCont($e2488624887)) {
var $ss2489024891 = {"from":L[3754],
"go":function(ann_DASH_check_DASH_temp638124897) {
return $Hann_DASH_check_DASH_temp1075824898(ann_DASH_check_DASH_temp638124897);
}};
$e2488624887.stack[R.EXN_STACKHEIGHT++] = $ss2489024891;
}
if(R.isPyretException($e2488624887)) {
$e2488624887.pyretStack.push(L[3754]);
}
throw $e2488624887;
}
var $ret2489224893 = $Hann_DASH_check_DASH_temp1075824898($z2488824889);
++R.GAS;
return $ret2489224893;
});
var $z2487324874 = D;
var $f2487924880 = function(_) {
return R.isFunction(anf_fun638024881)?anf_fun638024881.app(anf_arg638324882):R.ffi.throwNonFunApp(L[3753],anf_fun638024881,[anf_arg638324882]);
};
try {
if(--R.GAS > 0) {
$z2487324874 = $f2487924880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2487924880,
"from":L[3753]});
}
} catch($e2487124872) {
if(R.isCont($e2487124872)) {
var $ss2487524876 = {"from":L[3753],
"go":function(anf_arg638424883) {
return $Hanf_arg1076024884(anf_arg638424883,a_DASH_app5192339,anf_arg63796779,l16496781);
}};
$e2487124872.stack[R.EXN_STACKHEIGHT++] = $ss2487524876;
}
if(R.isPyretException($e2487124872)) {
$e2487124872.pyretStack.push(L[3753]);
}
throw $e2487124872;
}
var $ret2487724878 = $Hanf_arg1076024884($z2487324874,a_DASH_app5192339,anf_arg63796779,l16496781);
++R.GAS;
return $ret2487724878;
};
var $Hanf_arg1076024884 = function(anf_arg638424883,a_DASH_app5192339,anf_arg63796779,l16496781) {
var $z2490124902 = D;
var $f2490724908 = function(_) {
return R.isFunction(a_DASH_app5192339.$var)?a_DASH_app5192339.$var.app(l16496781,anf_arg63796779,anf_arg638424883):R.ffi.throwNonFunApp(L[1236],a_DASH_app5192339.$var,[l16496781,anf_arg63796779,anf_arg638424883]);
};
try {
if(--R.GAS > 0) {
$z2490124902 = $f2490724908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2490724908,
"from":L[1236]});
}
} catch($e2489924900) {
if(R.isCont($e2489924900)) {
var $ss2490324904 = {"from":L[1236],
"go":function(ann_DASH_check_DASH_temp637724909) {
return $Hann_DASH_check_DASH_temp1075924910(ann_DASH_check_DASH_temp637724909);
}};
$e2489924900.stack[R.EXN_STACKHEIGHT++] = $ss2490324904;
}
if(R.isPyretException($e2489924900)) {
$e2489924900.pyretStack.push(L[1236]);
}
throw $e2489924900;
}
var $ret2490524906 = $Hann_DASH_check_DASH_temp1075924910($z2490124902);
++R.GAS;
return $ret2490524906;
};
var $Hann_DASH_check_DASH_temp1075924910 = function(ann_DASH_check_DASH_temp637724909) {
return ann_DASH_check_DASH_temp637724909;
};
var $Hann_DASH_check_DASH_temp1075824898 = function(ann_DASH_check_DASH_temp638124897) {
return ann_DASH_check_DASH_temp638124897;
};
var $Hanf_arg107576798 = function(anf_arg63756796,a_DASH_record5172335,l16466797) {
var $z2491324914 = D;
var $f2491924920 = function(_) {
return R.isFunction(a_DASH_record5172335.$var)?a_DASH_record5172335.$var.app(l16466797,anf_arg63756796):R.ffi.throwNonFunApp(L[1240],a_DASH_record5172335.$var,[l16466797,anf_arg63756796]);
};
try {
if(--R.GAS > 0) {
$z2491324914 = $f2491924920();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2491924920,
"from":L[1240]});
}
} catch($e2491124912) {
if(R.isCont($e2491124912)) {
var $ss2491524916 = {"from":L[1240],
"go":function(ann_DASH_check_DASH_temp637024921) {
return $Hann_DASH_check_DASH_temp1075624922(ann_DASH_check_DASH_temp637024921);
}};
$e2491124912.stack[R.EXN_STACKHEIGHT++] = $ss2491524916;
}
if(R.isPyretException($e2491124912)) {
$e2491124912.pyretStack.push(L[1240]);
}
throw $e2491124912;
}
var $ret2491724918 = $Hann_DASH_check_DASH_temp1075624922($z2491324914);
++R.GAS;
return $ret2491724918;
};
var $Hann_DASH_check_DASH_temp1075624922 = function(ann_DASH_check_DASH_temp637024921) {
return ann_DASH_check_DASH_temp637024921;
};
var $Hann_DASH_check_DASH_temp107556813 = function(ann_DASH_check_DASH_temp63726812) {
return ann_DASH_check_DASH_temp63726812;
};
var $Hanf_arg107546831 = function(anf_arg63666827,a_DASH_method5152331,l16426828,ret16446829,self16416830) {
var anf_fun636724933 = G(ret16446829,"visit",L[3757]);
var $z2492524926 = D;
var $f2493124932 = function(_) {
return R.isFunction(anf_fun636724933)?anf_fun636724933.app(self16416830):R.ffi.throwNonFunApp(L[3756],anf_fun636724933,[self16416830]);
};
try {
if(--R.GAS > 0) {
$z2492524926 = $f2493124932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2493124932,
"from":L[3756]});
}
} catch($e2492324924) {
if(R.isCont($e2492324924)) {
var $ss2492724928 = {"from":L[3756],
"go":function(anf_arg636824934) {
return $Hanf_arg1075324935(anf_arg636824934,a_DASH_method5152331,anf_arg63666827,l16426828);
}};
$e2492324924.stack[R.EXN_STACKHEIGHT++] = $ss2492724928;
}
if(R.isPyretException($e2492324924)) {
$e2492324924.pyretStack.push(L[3756]);
}
throw $e2492324924;
}
var $ret2492924930 = $Hanf_arg1075324935($z2492524926,a_DASH_method5152331,anf_arg63666827,l16426828);
++R.GAS;
return $ret2492924930;
};
var $Hanf_arg1075324935 = function(anf_arg636824934,a_DASH_method5152331,anf_arg63666827,l16426828) {
var $z2493824939 = D;
var $f2494424945 = function(_) {
return R.isFunction(a_DASH_method5152331.$var)?a_DASH_method5152331.$var.app(l16426828,anf_arg63666827,anf_arg636824934):R.ffi.throwNonFunApp(L[1244],a_DASH_method5152331.$var,[l16426828,anf_arg63666827,anf_arg636824934]);
};
try {
if(--R.GAS > 0) {
$z2493824939 = $f2494424945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2494424945,
"from":L[1244]});
}
} catch($e2493624937) {
if(R.isCont($e2493624937)) {
var $ss2494024941 = {"from":L[1244],
"go":function(ann_DASH_check_DASH_temp636124946) {
return $Hann_DASH_check_DASH_temp1075224947(ann_DASH_check_DASH_temp636124946);
}};
$e2493624937.stack[R.EXN_STACKHEIGHT++] = $ss2494024941;
}
if(R.isPyretException($e2493624937)) {
$e2493624937.pyretStack.push(L[1244]);
}
throw $e2493624937;
}
var $ret2494224943 = $Hann_DASH_check_DASH_temp1075224947($z2493824939);
++R.GAS;
return $ret2494224943;
};
var $Hann_DASH_check_DASH_temp1075224947 = function(ann_DASH_check_DASH_temp636124946) {
return ann_DASH_check_DASH_temp636124946;
};
var $Hann_DASH_check_DASH_temp107516845 = function(ann_DASH_check_DASH_temp63636844) {
return ann_DASH_check_DASH_temp63636844;
};
var $Hanf_arg107506864 = function(anf_arg63576859,a_DASH_arrow5132327,l16376860,ret16396861,self16366862,use_DASH_parens16406863) {
var anf_fun635824958 = G(ret16396861,"visit",L[3759]);
var $z2495024951 = D;
var $f2495624957 = function(_) {
return R.isFunction(anf_fun635824958)?anf_fun635824958.app(self16366862):R.ffi.throwNonFunApp(L[3758],anf_fun635824958,[self16366862]);
};
try {
if(--R.GAS > 0) {
$z2495024951 = $f2495624957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2495624957,
"from":L[3758]});
}
} catch($e2494824949) {
if(R.isCont($e2494824949)) {
var $ss2495224953 = {"from":L[3758],
"go":function(anf_arg635924959) {
return $Hanf_arg1074924960(anf_arg635924959,a_DASH_arrow5132327,anf_arg63576859,l16376860,use_DASH_parens16406863);
}};
$e2494824949.stack[R.EXN_STACKHEIGHT++] = $ss2495224953;
}
if(R.isPyretException($e2494824949)) {
$e2494824949.pyretStack.push(L[3758]);
}
throw $e2494824949;
}
var $ret2495424955 = $Hanf_arg1074924960($z2495024951,a_DASH_arrow5132327,anf_arg63576859,l16376860,use_DASH_parens16406863);
++R.GAS;
return $ret2495424955;
};
var $Hanf_arg1074924960 = function(anf_arg635924959,a_DASH_arrow5132327,anf_arg63576859,l16376860,use_DASH_parens16406863) {
var $z2496324964 = D;
var $f2496924970 = function(_) {
return R.isFunction(a_DASH_arrow5132327.$var)?a_DASH_arrow5132327.$var.app(l16376860,anf_arg63576859,anf_arg635924959,use_DASH_parens16406863):R.ffi.throwNonFunApp(L[1248],a_DASH_arrow5132327.$var,[l16376860,anf_arg63576859,anf_arg635924959,use_DASH_parens16406863]);
};
try {
if(--R.GAS > 0) {
$z2496324964 = $f2496924970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2496924970,
"from":L[1248]});
}
} catch($e2496124962) {
if(R.isCont($e2496124962)) {
var $ss2496524966 = {"from":L[1248],
"go":function(ann_DASH_check_DASH_temp635224971) {
return $Hann_DASH_check_DASH_temp1074824972(ann_DASH_check_DASH_temp635224971);
}};
$e2496124962.stack[R.EXN_STACKHEIGHT++] = $ss2496524966;
}
if(R.isPyretException($e2496124962)) {
$e2496124962.pyretStack.push(L[1248]);
}
throw $e2496124962;
}
var $ret2496724968 = $Hann_DASH_check_DASH_temp1074824972($z2496324964);
++R.GAS;
return $ret2496724968;
};
var $Hann_DASH_check_DASH_temp1074824972 = function(ann_DASH_check_DASH_temp635224971) {
return ann_DASH_check_DASH_temp635224971;
};
var $Hann_DASH_check_DASH_temp107476878 = function(ann_DASH_check_DASH_temp63546877) {
return ann_DASH_check_DASH_temp63546877;
};
var $Hanf_arg107466894 = function(anf_arg63506892,a_DASH_name5112323,l16346893) {
var $z2497524976 = D;
var $f2498124982 = function(_) {
return R.isFunction(a_DASH_name5112323.$var)?a_DASH_name5112323.$var.app(l16346893,anf_arg63506892):R.ffi.throwNonFunApp(L[1251],a_DASH_name5112323.$var,[l16346893,anf_arg63506892]);
};
try {
if(--R.GAS > 0) {
$z2497524976 = $f2498124982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2498124982,
"from":L[1251]});
}
} catch($e2497324974) {
if(R.isCont($e2497324974)) {
var $ss2497724978 = {"from":L[1251],
"go":function(ann_DASH_check_DASH_temp634824983) {
return $Hann_DASH_check_DASH_temp1074524984(ann_DASH_check_DASH_temp634824983);
}};
$e2497324974.stack[R.EXN_STACKHEIGHT++] = $ss2497724978;
}
if(R.isPyretException($e2497324974)) {
$e2497324974.pyretStack.push(L[1251]);
}
throw $e2497324974;
}
var $ret2497924980 = $Hann_DASH_check_DASH_temp1074524984($z2497524976);
++R.GAS;
return $ret2497924980;
};
var $Hann_DASH_check_DASH_temp1074524984 = function(ann_DASH_check_DASH_temp634824983) {
return ann_DASH_check_DASH_temp634824983;
};
var $Hanf_arg107446915 = function(anf_arg63426912,l16286913,s_DASH_datatype_DASH_constructor4872275,self_DASH_arg16296914) {
var $z2498724988 = D;
var $f2499324994 = function(_) {
return R.isFunction(s_DASH_datatype_DASH_constructor4872275.$var)?s_DASH_datatype_DASH_constructor4872275.$var.app(l16286913,self_DASH_arg16296914,anf_arg63426912):R.ffi.throwNonFunApp(L[1259],s_DASH_datatype_DASH_constructor4872275.$var,[l16286913,self_DASH_arg16296914,anf_arg63426912]);
};
try {
if(--R.GAS > 0) {
$z2498724988 = $f2499324994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2499324994,
"from":L[1259]});
}
} catch($e2498524986) {
if(R.isCont($e2498524986)) {
var $ss2498924990 = {"from":L[1259],
"go":function(ann_DASH_check_DASH_temp634024995) {
return $Hann_DASH_check_DASH_temp1074324996(ann_DASH_check_DASH_temp634024995);
}};
$e2498524986.stack[R.EXN_STACKHEIGHT++] = $ss2498924990;
}
if(R.isPyretException($e2498524986)) {
$e2498524986.pyretStack.push(L[1259]);
}
throw $e2498524986;
}
var $ret2499124992 = $Hann_DASH_check_DASH_temp1074324996($z2498724988);
++R.GAS;
return $ret2499124992;
};
var $Hann_DASH_check_DASH_temp1074324996 = function(ann_DASH_check_DASH_temp634024995) {
return ann_DASH_check_DASH_temp634024995;
};
var $Hanf_arg107426932 = function(anf_arg63386929,l16246930,name16256931,s_DASH_datatype_DASH_singleton_DASH_variant4822265) {
var $z2499925000 = D;
var $f2500525006 = function(_) {
return R.isFunction(s_DASH_datatype_DASH_singleton_DASH_variant4822265.$var)?s_DASH_datatype_DASH_singleton_DASH_variant4822265.$var.app(l16246930,name16256931,anf_arg63386929):R.ffi.throwNonFunApp(L[1265],s_DASH_datatype_DASH_singleton_DASH_variant4822265.$var,[l16246930,name16256931,anf_arg63386929]);
};
try {
if(--R.GAS > 0) {
$z2499925000 = $f2500525006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2500525006,
"from":L[1265]});
}
} catch($e2499724998) {
if(R.isCont($e2499724998)) {
var $ss2500125002 = {"from":L[1265],
"go":function(ann_DASH_check_DASH_temp633625007) {
return $Hann_DASH_check_DASH_temp1074125008(ann_DASH_check_DASH_temp633625007);
}};
$e2499724998.stack[R.EXN_STACKHEIGHT++] = $ss2500125002;
}
if(R.isPyretException($e2499724998)) {
$e2499724998.pyretStack.push(L[1265]);
}
throw $e2499724998;
}
var $ret2500325004 = $Hann_DASH_check_DASH_temp1074125008($z2499925000);
++R.GAS;
return $ret2500325004;
};
var $Hann_DASH_check_DASH_temp1074125008 = function(ann_DASH_check_DASH_temp633625007) {
return ann_DASH_check_DASH_temp633625007;
};
var $Hanf_arg107406951 = function(anf_arg63326946,constructor16226947,l16196948,name16206949,s_DASH_datatype_DASH_variant4802261,self16186950) {
var anf_fun633325019 = G(constructor16226947,"visit",L[3761]);
var $z2501125012 = D;
var $f2501725018 = function(_) {
return R.isFunction(anf_fun633325019)?anf_fun633325019.app(self16186950):R.ffi.throwNonFunApp(L[3760],anf_fun633325019,[self16186950]);
};
try {
if(--R.GAS > 0) {
$z2501125012 = $f2501725018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2501725018,
"from":L[3760]});
}
} catch($e2500925010) {
if(R.isCont($e2500925010)) {
var $ss2501325014 = {"from":L[3760],
"go":function(anf_arg633425020) {
return $Hanf_arg1073925021(anf_arg633425020,anf_arg63326946,l16196948,name16206949,s_DASH_datatype_DASH_variant4802261);
}};
$e2500925010.stack[R.EXN_STACKHEIGHT++] = $ss2501325014;
}
if(R.isPyretException($e2500925010)) {
$e2500925010.pyretStack.push(L[3760]);
}
throw $e2500925010;
}
var $ret2501525016 = $Hanf_arg1073925021($z2501125012,anf_arg63326946,l16196948,name16206949,s_DASH_datatype_DASH_variant4802261);
++R.GAS;
return $ret2501525016;
};
var $Hanf_arg1073925021 = function(anf_arg633425020,anf_arg63326946,l16196948,name16206949,s_DASH_datatype_DASH_variant4802261) {
var $z2502425025 = D;
var $f2503025031 = function(_) {
return R.isFunction(s_DASH_datatype_DASH_variant4802261.$var)?s_DASH_datatype_DASH_variant4802261.$var.app(l16196948,name16206949,anf_arg63326946,anf_arg633425020):R.ffi.throwNonFunApp(L[1273],s_DASH_datatype_DASH_variant4802261.$var,[l16196948,name16206949,anf_arg63326946,anf_arg633425020]);
};
try {
if(--R.GAS > 0) {
$z2502425025 = $f2503025031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2503025031,
"from":L[1273]});
}
} catch($e2502225023) {
if(R.isCont($e2502225023)) {
var $ss2502625027 = {"from":L[1273],
"go":function(ann_DASH_check_DASH_temp632725032) {
return $Hann_DASH_check_DASH_temp1073825033(ann_DASH_check_DASH_temp632725032);
}};
$e2502225023.stack[R.EXN_STACKHEIGHT++] = $ss2502625027;
}
if(R.isPyretException($e2502225023)) {
$e2502225023.pyretStack.push(L[1273]);
}
throw $e2502225023;
}
var $ret2502825029 = $Hann_DASH_check_DASH_temp1073825033($z2502425025);
++R.GAS;
return $ret2502825029;
};
var $Hann_DASH_check_DASH_temp1073825033 = function(ann_DASH_check_DASH_temp632725032) {
return ann_DASH_check_DASH_temp632725032;
};
var $Hann_DASH_check_DASH_temp107376965 = function(ann_DASH_check_DASH_temp63296964) {
return ann_DASH_check_DASH_temp63296964;
};
var $Hanf_arg107366982 = function(anf_arg63256979,l16156980,name16166981,s_DASH_singleton_DASH_variant4752251) {
var $z2503625037 = D;
var $f2504225043 = function(_) {
return R.isFunction(s_DASH_singleton_DASH_variant4752251.$var)?s_DASH_singleton_DASH_variant4752251.$var.app(l16156980,name16166981,anf_arg63256979):R.ffi.throwNonFunApp(L[1280],s_DASH_singleton_DASH_variant4752251.$var,[l16156980,name16166981,anf_arg63256979]);
};
try {
if(--R.GAS > 0) {
$z2503625037 = $f2504225043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2504225043,
"from":L[1280]});
}
} catch($e2503425035) {
if(R.isCont($e2503425035)) {
var $ss2503825039 = {"from":L[1280],
"go":function(ann_DASH_check_DASH_temp632025044) {
return $Hann_DASH_check_DASH_temp1073525045(ann_DASH_check_DASH_temp632025044);
}};
$e2503425035.stack[R.EXN_STACKHEIGHT++] = $ss2503825039;
}
if(R.isPyretException($e2503425035)) {
$e2503425035.pyretStack.push(L[1280]);
}
throw $e2503425035;
}
var $ret2504025041 = $Hann_DASH_check_DASH_temp1073525045($z2503625037);
++R.GAS;
return $ret2504025041;
};
var $Hann_DASH_check_DASH_temp1073525045 = function(ann_DASH_check_DASH_temp632025044) {
return ann_DASH_check_DASH_temp632025044;
};
var $Hann_DASH_check_DASH_temp107346997 = function(ann_DASH_check_DASH_temp63226996) {
return ann_DASH_check_DASH_temp63226996;
};
var $Hanf_arg107337017 = function(anf_arg63137011,constr_DASH_loc16107012,l16097013,name16117014,s_DASH_variant4732247,self16087015,with_DASH_members16137016) {
var anf_fun631425056 = G(with_DASH_members16137016,"map",L[3764]);
var anf_arg631725057 = R.makeFunction(function(recv_DASH_75525060) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3763],1,arguments);
}
var anf_fun631625071 = G(recv_DASH_75525060,"visit",L[3763]);
var $z2506325064 = D;
var $f2506925070 = function(_) {
return R.isFunction(anf_fun631625071)?anf_fun631625071.app(self16087015):R.ffi.throwNonFunApp(L[3763],anf_fun631625071,[self16087015]);
};
try {
if(--R.GAS > 0) {
$z2506325064 = $f2506925070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2506925070,
"from":L[3763]});
}
} catch($e2506125062) {
if(R.isCont($e2506125062)) {
var $ss2506525066 = {"from":L[3763],
"go":function(ann_DASH_check_DASH_temp631525072) {
return $Hann_DASH_check_DASH_temp1073025073(ann_DASH_check_DASH_temp631525072);
}};
$e2506125062.stack[R.EXN_STACKHEIGHT++] = $ss2506525066;
}
if(R.isPyretException($e2506125062)) {
$e2506125062.pyretStack.push(L[3763]);
}
throw $e2506125062;
}
var $ret2506725068 = $Hann_DASH_check_DASH_temp1073025073($z2506325064);
++R.GAS;
return $ret2506725068;
});
var $z2504825049 = D;
var $f2505425055 = function(_) {
return R.isFunction(anf_fun631425056)?anf_fun631425056.app(anf_arg631725057):R.ffi.throwNonFunApp(L[3762],anf_fun631425056,[anf_arg631725057]);
};
try {
if(--R.GAS > 0) {
$z2504825049 = $f2505425055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2505425055,
"from":L[3762]});
}
} catch($e2504625047) {
if(R.isCont($e2504625047)) {
var $ss2505025051 = {"from":L[3762],
"go":function(anf_arg631825058) {
return $Hanf_arg1073225059(anf_arg631825058,anf_arg63137011,constr_DASH_loc16107012,l16097013,name16117014,s_DASH_variant4732247);
}};
$e2504625047.stack[R.EXN_STACKHEIGHT++] = $ss2505025051;
}
if(R.isPyretException($e2504625047)) {
$e2504625047.pyretStack.push(L[3762]);
}
throw $e2504625047;
}
var $ret2505225053 = $Hanf_arg1073225059($z2504825049,anf_arg63137011,constr_DASH_loc16107012,l16097013,name16117014,s_DASH_variant4732247);
++R.GAS;
return $ret2505225053;
};
var $Hanf_arg1073225059 = function(anf_arg631825058,anf_arg63137011,constr_DASH_loc16107012,l16097013,name16117014,s_DASH_variant4732247) {
var $z2507625077 = D;
var $f2508225083 = function(_) {
return R.isFunction(s_DASH_variant4732247.$var)?s_DASH_variant4732247.$var.app(l16097013,constr_DASH_loc16107012,name16117014,anf_arg63137011,anf_arg631825058):R.ffi.throwNonFunApp(L[1289],s_DASH_variant4732247.$var,[l16097013,constr_DASH_loc16107012,name16117014,anf_arg63137011,anf_arg631825058]);
};
try {
if(--R.GAS > 0) {
$z2507625077 = $f2508225083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2508225083,
"from":L[1289]});
}
} catch($e2507425075) {
if(R.isCont($e2507425075)) {
var $ss2507825079 = {"from":L[1289],
"go":function(ann_DASH_check_DASH_temp630825084) {
return $Hann_DASH_check_DASH_temp1073125085(ann_DASH_check_DASH_temp630825084);
}};
$e2507425075.stack[R.EXN_STACKHEIGHT++] = $ss2507825079;
}
if(R.isPyretException($e2507425075)) {
$e2507425075.pyretStack.push(L[1289]);
}
throw $e2507425075;
}
var $ret2508025081 = $Hann_DASH_check_DASH_temp1073125085($z2507625077);
++R.GAS;
return $ret2508025081;
};
var $Hann_DASH_check_DASH_temp1073125085 = function(ann_DASH_check_DASH_temp630825084) {
return ann_DASH_check_DASH_temp630825084;
};
var $Hann_DASH_check_DASH_temp1073025073 = function(ann_DASH_check_DASH_temp631525072) {
return ann_DASH_check_DASH_temp631525072;
};
var $Hann_DASH_check_DASH_temp107297031 = function(ann_DASH_check_DASH_temp63107030) {
return ann_DASH_check_DASH_temp63107030;
};
var $Hanf_arg107287048 = function(anf_arg63067045,l16057046,member_DASH_type16067047,s_DASH_variant_DASH_member4682237) {
var $z2508825089 = D;
var $f2509425095 = function(_) {
return R.isFunction(s_DASH_variant_DASH_member4682237.$var)?s_DASH_variant_DASH_member4682237.$var.app(l16057046,member_DASH_type16067047,anf_arg63067045):R.ffi.throwNonFunApp(L[1295],s_DASH_variant_DASH_member4682237.$var,[l16057046,member_DASH_type16067047,anf_arg63067045]);
};
try {
if(--R.GAS > 0) {
$z2508825089 = $f2509425095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2509425095,
"from":L[1295]});
}
} catch($e2508625087) {
if(R.isCont($e2508625087)) {
var $ss2509025091 = {"from":L[1295],
"go":function(ann_DASH_check_DASH_temp630425096) {
return $Hann_DASH_check_DASH_temp1072725097(ann_DASH_check_DASH_temp630425096);
}};
$e2508625087.stack[R.EXN_STACKHEIGHT++] = $ss2509025091;
}
if(R.isPyretException($e2508625087)) {
$e2508625087.pyretStack.push(L[1295]);
}
throw $e2508625087;
}
var $ret2509225093 = $Hann_DASH_check_DASH_temp1072725097($z2508825089);
++R.GAS;
return $ret2509225093;
};
var $Hann_DASH_check_DASH_temp1072725097 = function(ann_DASH_check_DASH_temp630425096) {
return ann_DASH_check_DASH_temp630425096;
};
var $Hanf_arg107267065 = function(anf_arg63007062,l16017063,s_DASH_for_DASH_bind4542209,self16007061,value16037064) {
var anf_fun630125108 = G(value16037064,"visit",L[3766]);
var $z2510025101 = D;
var $f2510625107 = function(_) {
return R.isFunction(anf_fun630125108)?anf_fun630125108.app(self16007061):R.ffi.throwNonFunApp(L[3765],anf_fun630125108,[self16007061]);
};
try {
if(--R.GAS > 0) {
$z2510025101 = $f2510625107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2510625107,
"from":L[3765]});
}
} catch($e2509825099) {
if(R.isCont($e2509825099)) {
var $ss2510225103 = {"from":L[3765],
"go":function(anf_arg630225109) {
return $Hanf_arg1072525110(anf_arg630225109,anf_arg63007062,l16017063,s_DASH_for_DASH_bind4542209);
}};
$e2509825099.stack[R.EXN_STACKHEIGHT++] = $ss2510225103;
}
if(R.isPyretException($e2509825099)) {
$e2509825099.pyretStack.push(L[3765]);
}
throw $e2509825099;
}
var $ret2510425105 = $Hanf_arg1072525110($z2510025101,anf_arg63007062,l16017063,s_DASH_for_DASH_bind4542209);
++R.GAS;
return $ret2510425105;
};
var $Hanf_arg1072525110 = function(anf_arg630225109,anf_arg63007062,l16017063,s_DASH_for_DASH_bind4542209) {
var $z2511325114 = D;
var $f2511925120 = function(_) {
return R.isFunction(s_DASH_for_DASH_bind4542209.$var)?s_DASH_for_DASH_bind4542209.$var.app(l16017063,anf_arg63007062,anf_arg630225109):R.ffi.throwNonFunApp(L[1301],s_DASH_for_DASH_bind4542209.$var,[l16017063,anf_arg63007062,anf_arg630225109]);
};
try {
if(--R.GAS > 0) {
$z2511325114 = $f2511925120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2511925120,
"from":L[1301]});
}
} catch($e2511125112) {
if(R.isCont($e2511125112)) {
var $ss2511525116 = {"from":L[1301],
"go":function(ann_DASH_check_DASH_temp629825121) {
return $Hann_DASH_check_DASH_temp1072425122(ann_DASH_check_DASH_temp629825121);
}};
$e2511125112.stack[R.EXN_STACKHEIGHT++] = $ss2511525116;
}
if(R.isPyretException($e2511125112)) {
$e2511125112.pyretStack.push(L[1301]);
}
throw $e2511125112;
}
var $ret2511725118 = $Hann_DASH_check_DASH_temp1072425122($z2511325114);
++R.GAS;
return $ret2511725118;
};
var $Hann_DASH_check_DASH_temp1072425122 = function(ann_DASH_check_DASH_temp629825121) {
return ann_DASH_check_DASH_temp629825121;
};
var $Hanf_arg107237086 = function(anf_arg62857079,_check15997080,ann15967081,args15957082,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078) {
var anf_fun628625133 = G(args15957082,"map",L[3769]);
var anf_arg628925134 = R.makeFunction(function(recv_DASH_75325137) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3768],1,arguments);
}
var anf_fun628825148 = G(recv_DASH_75325137,"visit",L[3768]);
var $z2514025141 = D;
var $f2514625147 = function(_) {
return R.isFunction(anf_fun628825148)?anf_fun628825148.app(self15927078):R.ffi.throwNonFunApp(L[3768],anf_fun628825148,[self15927078]);
};
try {
if(--R.GAS > 0) {
$z2514025141 = $f2514625147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2514625147,
"from":L[3768]});
}
} catch($e2513825139) {
if(R.isCont($e2513825139)) {
var $ss2514225143 = {"from":L[3768],
"go":function(ann_DASH_check_DASH_temp628725149) {
return $Hann_DASH_check_DASH_temp1071725150(ann_DASH_check_DASH_temp628725149);
}};
$e2513825139.stack[R.EXN_STACKHEIGHT++] = $ss2514225143;
}
if(R.isPyretException($e2513825139)) {
$e2513825139.pyretStack.push(L[3768]);
}
throw $e2513825139;
}
var $ret2514425145 = $Hann_DASH_check_DASH_temp1071725150($z2514025141);
++R.GAS;
return $ret2514425145;
});
var $z2512525126 = D;
var $f2513125132 = function(_) {
return R.isFunction(anf_fun628625133)?anf_fun628625133.app(anf_arg628925134):R.ffi.throwNonFunApp(L[3767],anf_fun628625133,[anf_arg628925134]);
};
try {
if(--R.GAS > 0) {
$z2512525126 = $f2513125132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2513125132,
"from":L[3767]});
}
} catch($e2512325124) {
if(R.isCont($e2512325124)) {
var $ss2512725128 = {"from":L[3767],
"go":function(anf_arg629025135) {
return $Hanf_arg1072225136(anf_arg629025135,_check15997080,anf_arg62857079,ann15967081,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078);
}};
$e2512325124.stack[R.EXN_STACKHEIGHT++] = $ss2512725128;
}
if(R.isPyretException($e2512325124)) {
$e2512325124.pyretStack.push(L[3767]);
}
throw $e2512325124;
}
var $ret2512925130 = $Hanf_arg1072225136($z2512525126,_check15997080,anf_arg62857079,ann15967081,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078);
++R.GAS;
return $ret2512925130;
};
var $Hanf_arg1072225136 = function(anf_arg629025135,_check15997080,anf_arg62857079,ann15967081,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078) {
var anf_fun629125161 = G(ann15967081,"visit",L[3771]);
var $z2515325154 = D;
var $f2515925160 = function(_) {
return R.isFunction(anf_fun629125161)?anf_fun629125161.app(self15927078):R.ffi.throwNonFunApp(L[3770],anf_fun629125161,[self15927078]);
};
try {
if(--R.GAS > 0) {
$z2515325154 = $f2515925160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2515925160,
"from":L[3770]});
}
} catch($e2515125152) {
if(R.isCont($e2515125152)) {
var $ss2515525156 = {"from":L[3770],
"go":function(anf_arg629225162) {
return $Hanf_arg1072125163(anf_arg629225162,_check15997080,anf_arg62857079,anf_arg629025135,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078);
}};
$e2515125152.stack[R.EXN_STACKHEIGHT++] = $ss2515525156;
}
if(R.isPyretException($e2515125152)) {
$e2515125152.pyretStack.push(L[3770]);
}
throw $e2515125152;
}
var $ret2515725158 = $Hanf_arg1072125163($z2515325154,_check15997080,anf_arg62857079,anf_arg629025135,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078);
++R.GAS;
return $ret2515725158;
};
var $Hanf_arg1072125163 = function(anf_arg629225162,_check15997080,anf_arg62857079,anf_arg629025135,body15987083,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078) {
var anf_fun629325174 = G(body15987083,"visit",L[3773]);
var $z2516625167 = D;
var $f2517225173 = function(_) {
return R.isFunction(anf_fun629325174)?anf_fun629325174.app(self15927078):R.ffi.throwNonFunApp(L[3772],anf_fun629325174,[self15927078]);
};
try {
if(--R.GAS > 0) {
$z2516625167 = $f2517225173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2517225173,
"from":L[3772]});
}
} catch($e2516425165) {
if(R.isCont($e2516425165)) {
var $ss2516825169 = {"from":L[3772],
"go":function(anf_arg629425175) {
return $Hanf_arg1072025176(anf_arg629425175,_check15997080,anf_arg62857079,anf_arg629025135,anf_arg629225162,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078);
}};
$e2516425165.stack[R.EXN_STACKHEIGHT++] = $ss2516825169;
}
if(R.isPyretException($e2516425165)) {
$e2516425165.pyretStack.push(L[3772]);
}
throw $e2516425165;
}
var $ret2517025171 = $Hanf_arg1072025176($z2516625167,_check15997080,anf_arg62857079,anf_arg629025135,anf_arg629225162,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078);
++R.GAS;
return $ret2517025171;
};
var $Hanf_arg1072025176 = function(anf_arg629425175,_check15997080,anf_arg62857079,anf_arg629025135,anf_arg629225162,doc15977084,l15937085,s_DASH_method_DASH_field4492199,self15927078) {
var anf_fun629525187 = G(self15927078,"option",L[3775]);
var $z2517925180 = D;
var $f2518525186 = function(_) {
return R.isFunction(anf_fun629525187)?anf_fun629525187.app(_check15997080):R.ffi.throwNonFunApp(L[3774],anf_fun629525187,[_check15997080]);
};
try {
if(--R.GAS > 0) {
$z2517925180 = $f2518525186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2518525186,
"from":L[3774]});
}
} catch($e2517725178) {
if(R.isCont($e2517725178)) {
var $ss2518125182 = {"from":L[3774],
"go":function(anf_arg629625188) {
return $Hanf_arg1071925189(anf_arg629625188,anf_arg62857079,anf_arg629025135,anf_arg629225162,anf_arg629425175,doc15977084,l15937085,s_DASH_method_DASH_field4492199);
}};
$e2517725178.stack[R.EXN_STACKHEIGHT++] = $ss2518125182;
}
if(R.isPyretException($e2517725178)) {
$e2517725178.pyretStack.push(L[3774]);
}
throw $e2517725178;
}
var $ret2518325184 = $Hanf_arg1071925189($z2517925180,anf_arg62857079,anf_arg629025135,anf_arg629225162,anf_arg629425175,doc15977084,l15937085,s_DASH_method_DASH_field4492199);
++R.GAS;
return $ret2518325184;
};
var $Hanf_arg1071925189 = function(anf_arg629625188,anf_arg62857079,anf_arg629025135,anf_arg629225162,anf_arg629425175,doc15977084,l15937085,s_DASH_method_DASH_field4492199) {
var $z2519225193 = D;
var $f2519825199 = function(_) {
return R.isFunction(s_DASH_method_DASH_field4492199.$var)?s_DASH_method_DASH_field4492199.$var.app(l15937085,anf_arg62857079,anf_arg629025135,anf_arg629225162,doc15977084,anf_arg629425175,anf_arg629625188):R.ffi.throwNonFunApp(L[1311],s_DASH_method_DASH_field4492199.$var,[l15937085,anf_arg62857079,anf_arg629025135,anf_arg629225162,doc15977084,anf_arg629425175,anf_arg629625188]);
};
try {
if(--R.GAS > 0) {
$z2519225193 = $f2519825199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2519825199,
"from":L[1311]});
}
} catch($e2519025191) {
if(R.isCont($e2519025191)) {
var $ss2519425195 = {"from":L[1311],
"go":function(ann_DASH_check_DASH_temp628325200) {
return $Hann_DASH_check_DASH_temp1071825201(ann_DASH_check_DASH_temp628325200);
}};
$e2519025191.stack[R.EXN_STACKHEIGHT++] = $ss2519425195;
}
if(R.isPyretException($e2519025191)) {
$e2519025191.pyretStack.push(L[1311]);
}
throw $e2519025191;
}
var $ret2519625197 = $Hann_DASH_check_DASH_temp1071825201($z2519225193);
++R.GAS;
return $ret2519625197;
};
var $Hann_DASH_check_DASH_temp1071825201 = function(ann_DASH_check_DASH_temp628325200) {
return ann_DASH_check_DASH_temp628325200;
};
var $Hann_DASH_check_DASH_temp1071725150 = function(ann_DASH_check_DASH_temp628725149) {
return ann_DASH_check_DASH_temp628725149;
};
var $Hanf_arg107167104 = function(anf_arg62777100,ann15907101,l15887102,s_DASH_once_DASH_field4472195,self15877099,value15917103) {
var anf_fun627825212 = G(ann15907101,"visit",L[3777]);
var $z2520425205 = D;
var $f2521025211 = function(_) {
return R.isFunction(anf_fun627825212)?anf_fun627825212.app(self15877099):R.ffi.throwNonFunApp(L[3776],anf_fun627825212,[self15877099]);
};
try {
if(--R.GAS > 0) {
$z2520425205 = $f2521025211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2521025211,
"from":L[3776]});
}
} catch($e2520225203) {
if(R.isCont($e2520225203)) {
var $ss2520625207 = {"from":L[3776],
"go":function(anf_arg627925213) {
return $Hanf_arg1071525214(anf_arg627925213,anf_arg62777100,l15887102,s_DASH_once_DASH_field4472195,self15877099,value15917103);
}};
$e2520225203.stack[R.EXN_STACKHEIGHT++] = $ss2520625207;
}
if(R.isPyretException($e2520225203)) {
$e2520225203.pyretStack.push(L[3776]);
}
throw $e2520225203;
}
var $ret2520825209 = $Hanf_arg1071525214($z2520425205,anf_arg62777100,l15887102,s_DASH_once_DASH_field4472195,self15877099,value15917103);
++R.GAS;
return $ret2520825209;
};
var $Hanf_arg1071525214 = function(anf_arg627925213,anf_arg62777100,l15887102,s_DASH_once_DASH_field4472195,self15877099,value15917103) {
var anf_fun628025225 = G(value15917103,"visit",L[3779]);
var $z2521725218 = D;
var $f2522325224 = function(_) {
return R.isFunction(anf_fun628025225)?anf_fun628025225.app(self15877099):R.ffi.throwNonFunApp(L[3778],anf_fun628025225,[self15877099]);
};
try {
if(--R.GAS > 0) {
$z2521725218 = $f2522325224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2522325224,
"from":L[3778]});
}
} catch($e2521525216) {
if(R.isCont($e2521525216)) {
var $ss2521925220 = {"from":L[3778],
"go":function(anf_arg628125226) {
return $Hanf_arg1071425227(anf_arg628125226,anf_arg62777100,anf_arg627925213,l15887102,s_DASH_once_DASH_field4472195);
}};
$e2521525216.stack[R.EXN_STACKHEIGHT++] = $ss2521925220;
}
if(R.isPyretException($e2521525216)) {
$e2521525216.pyretStack.push(L[3778]);
}
throw $e2521525216;
}
var $ret2522125222 = $Hanf_arg1071425227($z2521725218,anf_arg62777100,anf_arg627925213,l15887102,s_DASH_once_DASH_field4472195);
++R.GAS;
return $ret2522125222;
};
var $Hanf_arg1071425227 = function(anf_arg628125226,anf_arg62777100,anf_arg627925213,l15887102,s_DASH_once_DASH_field4472195) {
var $z2523025231 = D;
var $f2523625237 = function(_) {
return R.isFunction(s_DASH_once_DASH_field4472195.$var)?s_DASH_once_DASH_field4472195.$var.app(l15887102,anf_arg62777100,anf_arg627925213,anf_arg628125226):R.ffi.throwNonFunApp(L[1318],s_DASH_once_DASH_field4472195.$var,[l15887102,anf_arg62777100,anf_arg627925213,anf_arg628125226]);
};
try {
if(--R.GAS > 0) {
$z2523025231 = $f2523625237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2523625237,
"from":L[1318]});
}
} catch($e2522825229) {
if(R.isCont($e2522825229)) {
var $ss2523225233 = {"from":L[1318],
"go":function(ann_DASH_check_DASH_temp627525238) {
return $Hann_DASH_check_DASH_temp1071325239(ann_DASH_check_DASH_temp627525238);
}};
$e2522825229.stack[R.EXN_STACKHEIGHT++] = $ss2523225233;
}
if(R.isPyretException($e2522825229)) {
$e2522825229.pyretStack.push(L[1318]);
}
throw $e2522825229;
}
var $ret2523425235 = $Hann_DASH_check_DASH_temp1071325239($z2523025231);
++R.GAS;
return $ret2523425235;
};
var $Hann_DASH_check_DASH_temp1071325239 = function(ann_DASH_check_DASH_temp627525238) {
return ann_DASH_check_DASH_temp627525238;
};
var $Hanf_arg107127122 = function(anf_arg62697118,ann15857119,l15837120,s_DASH_mutable_DASH_field4452191,self15827117,value15867121) {
var anf_fun627025250 = G(ann15857119,"visit",L[3781]);
var $z2524225243 = D;
var $f2524825249 = function(_) {
return R.isFunction(anf_fun627025250)?anf_fun627025250.app(self15827117):R.ffi.throwNonFunApp(L[3780],anf_fun627025250,[self15827117]);
};
try {
if(--R.GAS > 0) {
$z2524225243 = $f2524825249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2524825249,
"from":L[3780]});
}
} catch($e2524025241) {
if(R.isCont($e2524025241)) {
var $ss2524425245 = {"from":L[3780],
"go":function(anf_arg627125251) {
return $Hanf_arg1071125252(anf_arg627125251,anf_arg62697118,l15837120,s_DASH_mutable_DASH_field4452191,self15827117,value15867121);
}};
$e2524025241.stack[R.EXN_STACKHEIGHT++] = $ss2524425245;
}
if(R.isPyretException($e2524025241)) {
$e2524025241.pyretStack.push(L[3780]);
}
throw $e2524025241;
}
var $ret2524625247 = $Hanf_arg1071125252($z2524225243,anf_arg62697118,l15837120,s_DASH_mutable_DASH_field4452191,self15827117,value15867121);
++R.GAS;
return $ret2524625247;
};
var $Hanf_arg1071125252 = function(anf_arg627125251,anf_arg62697118,l15837120,s_DASH_mutable_DASH_field4452191,self15827117,value15867121) {
var anf_fun627225263 = G(value15867121,"visit",L[3783]);
var $z2525525256 = D;
var $f2526125262 = function(_) {
return R.isFunction(anf_fun627225263)?anf_fun627225263.app(self15827117):R.ffi.throwNonFunApp(L[3782],anf_fun627225263,[self15827117]);
};
try {
if(--R.GAS > 0) {
$z2525525256 = $f2526125262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2526125262,
"from":L[3782]});
}
} catch($e2525325254) {
if(R.isCont($e2525325254)) {
var $ss2525725258 = {"from":L[3782],
"go":function(anf_arg627325264) {
return $Hanf_arg1071025265(anf_arg627325264,anf_arg62697118,anf_arg627125251,l15837120,s_DASH_mutable_DASH_field4452191);
}};
$e2525325254.stack[R.EXN_STACKHEIGHT++] = $ss2525725258;
}
if(R.isPyretException($e2525325254)) {
$e2525325254.pyretStack.push(L[3782]);
}
throw $e2525325254;
}
var $ret2525925260 = $Hanf_arg1071025265($z2525525256,anf_arg62697118,anf_arg627125251,l15837120,s_DASH_mutable_DASH_field4452191);
++R.GAS;
return $ret2525925260;
};
var $Hanf_arg1071025265 = function(anf_arg627325264,anf_arg62697118,anf_arg627125251,l15837120,s_DASH_mutable_DASH_field4452191) {
var $z2526825269 = D;
var $f2527425275 = function(_) {
return R.isFunction(s_DASH_mutable_DASH_field4452191.$var)?s_DASH_mutable_DASH_field4452191.$var.app(l15837120,anf_arg62697118,anf_arg627125251,anf_arg627325264):R.ffi.throwNonFunApp(L[1325],s_DASH_mutable_DASH_field4452191.$var,[l15837120,anf_arg62697118,anf_arg627125251,anf_arg627325264]);
};
try {
if(--R.GAS > 0) {
$z2526825269 = $f2527425275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2527425275,
"from":L[1325]});
}
} catch($e2526625267) {
if(R.isCont($e2526625267)) {
var $ss2527025271 = {"from":L[1325],
"go":function(ann_DASH_check_DASH_temp626725276) {
return $Hann_DASH_check_DASH_temp1070925277(ann_DASH_check_DASH_temp626725276);
}};
$e2526625267.stack[R.EXN_STACKHEIGHT++] = $ss2527025271;
}
if(R.isPyretException($e2526625267)) {
$e2526625267.pyretStack.push(L[1325]);
}
throw $e2526625267;
}
var $ret2527225273 = $Hann_DASH_check_DASH_temp1070925277($z2526825269);
++R.GAS;
return $ret2527225273;
};
var $Hann_DASH_check_DASH_temp1070925277 = function(ann_DASH_check_DASH_temp626725276) {
return ann_DASH_check_DASH_temp626725276;
};
var $Hanf_arg107087139 = function(anf_arg62637136,l15797137,s_DASH_data_DASH_field4432187,self15787135,value15817138) {
var anf_fun626425288 = G(value15817138,"visit",L[3785]);
var $z2528025281 = D;
var $f2528625287 = function(_) {
return R.isFunction(anf_fun626425288)?anf_fun626425288.app(self15787135):R.ffi.throwNonFunApp(L[3784],anf_fun626425288,[self15787135]);
};
try {
if(--R.GAS > 0) {
$z2528025281 = $f2528625287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2528625287,
"from":L[3784]});
}
} catch($e2527825279) {
if(R.isCont($e2527825279)) {
var $ss2528225283 = {"from":L[3784],
"go":function(anf_arg626525289) {
return $Hanf_arg1070725290(anf_arg626525289,anf_arg62637136,l15797137,s_DASH_data_DASH_field4432187);
}};
$e2527825279.stack[R.EXN_STACKHEIGHT++] = $ss2528225283;
}
if(R.isPyretException($e2527825279)) {
$e2527825279.pyretStack.push(L[3784]);
}
throw $e2527825279;
}
var $ret2528425285 = $Hanf_arg1070725290($z2528025281,anf_arg62637136,l15797137,s_DASH_data_DASH_field4432187);
++R.GAS;
return $ret2528425285;
};
var $Hanf_arg1070725290 = function(anf_arg626525289,anf_arg62637136,l15797137,s_DASH_data_DASH_field4432187) {
var $z2529325294 = D;
var $f2529925300 = function(_) {
return R.isFunction(s_DASH_data_DASH_field4432187.$var)?s_DASH_data_DASH_field4432187.$var.app(l15797137,anf_arg62637136,anf_arg626525289):R.ffi.throwNonFunApp(L[1331],s_DASH_data_DASH_field4432187.$var,[l15797137,anf_arg62637136,anf_arg626525289]);
};
try {
if(--R.GAS > 0) {
$z2529325294 = $f2529925300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2529925300,
"from":L[1331]});
}
} catch($e2529125292) {
if(R.isCont($e2529125292)) {
var $ss2529525296 = {"from":L[1331],
"go":function(ann_DASH_check_DASH_temp626125301) {
return $Hann_DASH_check_DASH_temp1070625302(ann_DASH_check_DASH_temp626125301);
}};
$e2529125292.stack[R.EXN_STACKHEIGHT++] = $ss2529525296;
}
if(R.isPyretException($e2529125292)) {
$e2529125292.pyretStack.push(L[1331]);
}
throw $e2529125292;
}
var $ret2529725298 = $Hann_DASH_check_DASH_temp1070625302($z2529325294);
++R.GAS;
return $ret2529725298;
};
var $Hann_DASH_check_DASH_temp1070625302 = function(ann_DASH_check_DASH_temp626125301) {
return ann_DASH_check_DASH_temp626125301;
};
var $Hanf_arg107057157 = function(anf_arg62597153,keyword_DASH_check15777154,l15747155,name15757156,s_DASH_check4262153) {
var $z2530525306 = D;
var $f2531125312 = function(_) {
return R.isFunction(s_DASH_check4262153.$var)?s_DASH_check4262153.$var.app(l15747155,name15757156,anf_arg62597153,keyword_DASH_check15777154):R.ffi.throwNonFunApp(L[1338],s_DASH_check4262153.$var,[l15747155,name15757156,anf_arg62597153,keyword_DASH_check15777154]);
};
try {
if(--R.GAS > 0) {
$z2530525306 = $f2531125312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2531125312,
"from":L[1338]});
}
} catch($e2530325304) {
if(R.isCont($e2530325304)) {
var $ss2530725308 = {"from":L[1338],
"go":function(ann_DASH_check_DASH_temp625725313) {
return $Hann_DASH_check_DASH_temp1070425314(ann_DASH_check_DASH_temp625725313);
}};
$e2530325304.stack[R.EXN_STACKHEIGHT++] = $ss2530725308;
}
if(R.isPyretException($e2530325304)) {
$e2530325304.pyretStack.push(L[1338]);
}
throw $e2530325304;
}
var $ret2530925310 = $Hann_DASH_check_DASH_temp1070425314($z2530525306);
++R.GAS;
return $ret2530925310;
};
var $Hann_DASH_check_DASH_temp1070425314 = function(ann_DASH_check_DASH_temp625725313) {
return ann_DASH_check_DASH_temp625725313;
};
var $Hanf_arg107037176 = function(anf_arg62467171,ann15717172,bindings15707173,body15727174,l15687175,s_DASH_for4242149,self15677170) {
var anf_fun624725325 = G(bindings15707173,"map",L[3788]);
var anf_arg625025326 = R.makeFunction(function(recv_DASH_75225329) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3787],1,arguments);
}
var anf_fun624925340 = G(recv_DASH_75225329,"visit",L[3787]);
var $z2533225333 = D;
var $f2533825339 = function(_) {
return R.isFunction(anf_fun624925340)?anf_fun624925340.app(self15677170):R.ffi.throwNonFunApp(L[3787],anf_fun624925340,[self15677170]);
};
try {
if(--R.GAS > 0) {
$z2533225333 = $f2533825339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2533825339,
"from":L[3787]});
}
} catch($e2533025331) {
if(R.isCont($e2533025331)) {
var $ss2533425335 = {"from":L[3787],
"go":function(ann_DASH_check_DASH_temp624825341) {
return $Hann_DASH_check_DASH_temp1069825342(ann_DASH_check_DASH_temp624825341);
}};
$e2533025331.stack[R.EXN_STACKHEIGHT++] = $ss2533425335;
}
if(R.isPyretException($e2533025331)) {
$e2533025331.pyretStack.push(L[3787]);
}
throw $e2533025331;
}
var $ret2533625337 = $Hann_DASH_check_DASH_temp1069825342($z2533225333);
++R.GAS;
return $ret2533625337;
});
var $z2531725318 = D;
var $f2532325324 = function(_) {
return R.isFunction(anf_fun624725325)?anf_fun624725325.app(anf_arg625025326):R.ffi.throwNonFunApp(L[3786],anf_fun624725325,[anf_arg625025326]);
};
try {
if(--R.GAS > 0) {
$z2531725318 = $f2532325324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2532325324,
"from":L[3786]});
}
} catch($e2531525316) {
if(R.isCont($e2531525316)) {
var $ss2531925320 = {"from":L[3786],
"go":function(anf_arg625125327) {
return $Hanf_arg1070225328(anf_arg625125327,anf_arg62467171,ann15717172,body15727174,l15687175,s_DASH_for4242149,self15677170);
}};
$e2531525316.stack[R.EXN_STACKHEIGHT++] = $ss2531925320;
}
if(R.isPyretException($e2531525316)) {
$e2531525316.pyretStack.push(L[3786]);
}
throw $e2531525316;
}
var $ret2532125322 = $Hanf_arg1070225328($z2531725318,anf_arg62467171,ann15717172,body15727174,l15687175,s_DASH_for4242149,self15677170);
++R.GAS;
return $ret2532125322;
};
var $Hanf_arg1070225328 = function(anf_arg625125327,anf_arg62467171,ann15717172,body15727174,l15687175,s_DASH_for4242149,self15677170) {
var anf_fun625225353 = G(ann15717172,"visit",L[3790]);
var $z2534525346 = D;
var $f2535125352 = function(_) {
return R.isFunction(anf_fun625225353)?anf_fun625225353.app(self15677170):R.ffi.throwNonFunApp(L[3789],anf_fun625225353,[self15677170]);
};
try {
if(--R.GAS > 0) {
$z2534525346 = $f2535125352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2535125352,
"from":L[3789]});
}
} catch($e2534325344) {
if(R.isCont($e2534325344)) {
var $ss2534725348 = {"from":L[3789],
"go":function(anf_arg625325354) {
return $Hanf_arg1070125355(anf_arg625325354,anf_arg62467171,anf_arg625125327,body15727174,l15687175,s_DASH_for4242149,self15677170);
}};
$e2534325344.stack[R.EXN_STACKHEIGHT++] = $ss2534725348;
}
if(R.isPyretException($e2534325344)) {
$e2534325344.pyretStack.push(L[3789]);
}
throw $e2534325344;
}
var $ret2534925350 = $Hanf_arg1070125355($z2534525346,anf_arg62467171,anf_arg625125327,body15727174,l15687175,s_DASH_for4242149,self15677170);
++R.GAS;
return $ret2534925350;
};
var $Hanf_arg1070125355 = function(anf_arg625325354,anf_arg62467171,anf_arg625125327,body15727174,l15687175,s_DASH_for4242149,self15677170) {
var anf_fun625425366 = G(body15727174,"visit",L[3792]);
var $z2535825359 = D;
var $f2536425365 = function(_) {
return R.isFunction(anf_fun625425366)?anf_fun625425366.app(self15677170):R.ffi.throwNonFunApp(L[3791],anf_fun625425366,[self15677170]);
};
try {
if(--R.GAS > 0) {
$z2535825359 = $f2536425365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2536425365,
"from":L[3791]});
}
} catch($e2535625357) {
if(R.isCont($e2535625357)) {
var $ss2536025361 = {"from":L[3791],
"go":function(anf_arg625525367) {
return $Hanf_arg1070025368(anf_arg625525367,anf_arg62467171,anf_arg625125327,anf_arg625325354,l15687175,s_DASH_for4242149);
}};
$e2535625357.stack[R.EXN_STACKHEIGHT++] = $ss2536025361;
}
if(R.isPyretException($e2535625357)) {
$e2535625357.pyretStack.push(L[3791]);
}
throw $e2535625357;
}
var $ret2536225363 = $Hanf_arg1070025368($z2535825359,anf_arg62467171,anf_arg625125327,anf_arg625325354,l15687175,s_DASH_for4242149);
++R.GAS;
return $ret2536225363;
};
var $Hanf_arg1070025368 = function(anf_arg625525367,anf_arg62467171,anf_arg625125327,anf_arg625325354,l15687175,s_DASH_for4242149) {
var $z2537125372 = D;
var $f2537725378 = function(_) {
return R.isFunction(s_DASH_for4242149.$var)?s_DASH_for4242149.$var.app(l15687175,anf_arg62467171,anf_arg625125327,anf_arg625325354,anf_arg625525367):R.ffi.throwNonFunApp(L[1346],s_DASH_for4242149.$var,[l15687175,anf_arg62467171,anf_arg625125327,anf_arg625325354,anf_arg625525367]);
};
try {
if(--R.GAS > 0) {
$z2537125372 = $f2537725378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2537725378,
"from":L[1346]});
}
} catch($e2536925370) {
if(R.isCont($e2536925370)) {
var $ss2537325374 = {"from":L[1346],
"go":function(ann_DASH_check_DASH_temp624425379) {
return $Hann_DASH_check_DASH_temp1069925380(ann_DASH_check_DASH_temp624425379);
}};
$e2536925370.stack[R.EXN_STACKHEIGHT++] = $ss2537325374;
}
if(R.isPyretException($e2536925370)) {
$e2536925370.pyretStack.push(L[1346]);
}
throw $e2536925370;
}
var $ret2537525376 = $Hann_DASH_check_DASH_temp1069925380($z2537125372);
++R.GAS;
return $ret2537525376;
};
var $Hann_DASH_check_DASH_temp1069925380 = function(ann_DASH_check_DASH_temp624425379) {
return ann_DASH_check_DASH_temp624425379;
};
var $Hann_DASH_check_DASH_temp1069825342 = function(ann_DASH_check_DASH_temp624825341) {
return ann_DASH_check_DASH_temp624825341;
};
var $Hanf_arg106977198 = function(anf_arg62207190,_check15667191,l15597192,mixins15637193,name15607194,params15627195,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197) {
var anf_fun622125391 = G(params15627195,"map",L[3795]);
var anf_arg622425392 = R.makeFunction(function(recv_DASH_74825395) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3794],1,arguments);
}
var anf_fun622325406 = G(recv_DASH_74825395,"visit",L[3794]);
var $z2539825399 = D;
var $f2540425405 = function(_) {
return R.isFunction(anf_fun622325406)?anf_fun622325406.app(self15587189):R.ffi.throwNonFunApp(L[3794],anf_fun622325406,[self15587189]);
};
try {
if(--R.GAS > 0) {
$z2539825399 = $f2540425405();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2540425405,
"from":L[3794]});
}
} catch($e2539625397) {
if(R.isCont($e2539625397)) {
var $ss2540025401 = {"from":L[3794],
"go":function(ann_DASH_check_DASH_temp622225407) {
return $Hann_DASH_check_DASH_temp1068725408(ann_DASH_check_DASH_temp622225407);
}};
$e2539625397.stack[R.EXN_STACKHEIGHT++] = $ss2540025401;
}
if(R.isPyretException($e2539625397)) {
$e2539625397.pyretStack.push(L[3794]);
}
throw $e2539625397;
}
var $ret2540225403 = $Hann_DASH_check_DASH_temp1068725408($z2539825399);
++R.GAS;
return $ret2540225403;
});
var $z2538325384 = D;
var $f2538925390 = function(_) {
return R.isFunction(anf_fun622125391)?anf_fun622125391.app(anf_arg622425392):R.ffi.throwNonFunApp(L[3793],anf_fun622125391,[anf_arg622425392]);
};
try {
if(--R.GAS > 0) {
$z2538325384 = $f2538925390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2538925390,
"from":L[3793]});
}
} catch($e2538125382) {
if(R.isCont($e2538125382)) {
var $ss2538525386 = {"from":L[3793],
"go":function(anf_arg622525393) {
return $Hanf_arg1069625394(anf_arg622525393,_check15667191,anf_arg62207190,l15597192,mixins15637193,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197);
}};
$e2538125382.stack[R.EXN_STACKHEIGHT++] = $ss2538525386;
}
if(R.isPyretException($e2538125382)) {
$e2538125382.pyretStack.push(L[3793]);
}
throw $e2538125382;
}
var $ret2538725388 = $Hanf_arg1069625394($z2538325384,_check15667191,anf_arg62207190,l15597192,mixins15637193,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197);
++R.GAS;
return $ret2538725388;
};
var $Hanf_arg1069625394 = function(anf_arg622525393,_check15667191,anf_arg62207190,l15597192,mixins15637193,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197) {
var anf_fun622625419 = G(mixins15637193,"map",L[3798]);
var anf_arg622925420 = R.makeFunction(function(recv_DASH_74925423) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3797],1,arguments);
}
var anf_fun622825434 = G(recv_DASH_74925423,"visit",L[3797]);
var $z2542625427 = D;
var $f2543225433 = function(_) {
return R.isFunction(anf_fun622825434)?anf_fun622825434.app(self15587189):R.ffi.throwNonFunApp(L[3797],anf_fun622825434,[self15587189]);
};
try {
if(--R.GAS > 0) {
$z2542625427 = $f2543225433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2543225433,
"from":L[3797]});
}
} catch($e2542425425) {
if(R.isCont($e2542425425)) {
var $ss2542825429 = {"from":L[3797],
"go":function(ann_DASH_check_DASH_temp622725435) {
return $Hann_DASH_check_DASH_temp1068825436(ann_DASH_check_DASH_temp622725435);
}};
$e2542425425.stack[R.EXN_STACKHEIGHT++] = $ss2542825429;
}
if(R.isPyretException($e2542425425)) {
$e2542425425.pyretStack.push(L[3797]);
}
throw $e2542425425;
}
var $ret2543025431 = $Hann_DASH_check_DASH_temp1068825436($z2542625427);
++R.GAS;
return $ret2543025431;
});
var $z2541125412 = D;
var $f2541725418 = function(_) {
return R.isFunction(anf_fun622625419)?anf_fun622625419.app(anf_arg622925420):R.ffi.throwNonFunApp(L[3796],anf_fun622625419,[anf_arg622925420]);
};
try {
if(--R.GAS > 0) {
$z2541125412 = $f2541725418();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2541725418,
"from":L[3796]});
}
} catch($e2540925410) {
if(R.isCont($e2540925410)) {
var $ss2541325414 = {"from":L[3796],
"go":function(anf_arg623025421) {
return $Hanf_arg1069525422(anf_arg623025421,_check15667191,anf_arg62207190,anf_arg622525393,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197);
}};
$e2540925410.stack[R.EXN_STACKHEIGHT++] = $ss2541325414;
}
if(R.isPyretException($e2540925410)) {
$e2540925410.pyretStack.push(L[3796]);
}
throw $e2540925410;
}
var $ret2541525416 = $Hanf_arg1069525422($z2541125412,_check15667191,anf_arg62207190,anf_arg622525393,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197);
++R.GAS;
return $ret2541525416;
};
var $Hanf_arg1069525422 = function(anf_arg623025421,_check15667191,anf_arg62207190,anf_arg622525393,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196,variants15647197) {
var anf_fun623125447 = G(variants15647197,"map",L[3801]);
var anf_arg623425448 = R.makeFunction(function(recv_DASH_75025451) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3800],1,arguments);
}
var anf_fun623325462 = G(recv_DASH_75025451,"visit",L[3800]);
var $z2545425455 = D;
var $f2546025461 = function(_) {
return R.isFunction(anf_fun623325462)?anf_fun623325462.app(self15587189):R.ffi.throwNonFunApp(L[3800],anf_fun623325462,[self15587189]);
};
try {
if(--R.GAS > 0) {
$z2545425455 = $f2546025461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2546025461,
"from":L[3800]});
}
} catch($e2545225453) {
if(R.isCont($e2545225453)) {
var $ss2545625457 = {"from":L[3800],
"go":function(ann_DASH_check_DASH_temp623225463) {
return $Hann_DASH_check_DASH_temp1068925464(ann_DASH_check_DASH_temp623225463);
}};
$e2545225453.stack[R.EXN_STACKHEIGHT++] = $ss2545625457;
}
if(R.isPyretException($e2545225453)) {
$e2545225453.pyretStack.push(L[3800]);
}
throw $e2545225453;
}
var $ret2545825459 = $Hann_DASH_check_DASH_temp1068925464($z2545425455);
++R.GAS;
return $ret2545825459;
});
var $z2543925440 = D;
var $f2544525446 = function(_) {
return R.isFunction(anf_fun623125447)?anf_fun623125447.app(anf_arg623425448):R.ffi.throwNonFunApp(L[3799],anf_fun623125447,[anf_arg623425448]);
};
try {
if(--R.GAS > 0) {
$z2543925440 = $f2544525446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2544525446,
"from":L[3799]});
}
} catch($e2543725438) {
if(R.isCont($e2543725438)) {
var $ss2544125442 = {"from":L[3799],
"go":function(anf_arg623525449) {
return $Hanf_arg1069425450(anf_arg623525449,_check15667191,anf_arg62207190,anf_arg622525393,anf_arg623025421,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196);
}};
$e2543725438.stack[R.EXN_STACKHEIGHT++] = $ss2544125442;
}
if(R.isPyretException($e2543725438)) {
$e2543725438.pyretStack.push(L[3799]);
}
throw $e2543725438;
}
var $ret2544325444 = $Hanf_arg1069425450($z2543925440,_check15667191,anf_arg62207190,anf_arg622525393,anf_arg623025421,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196);
++R.GAS;
return $ret2544325444;
};
var $Hanf_arg1069425450 = function(anf_arg623525449,_check15667191,anf_arg62207190,anf_arg622525393,anf_arg623025421,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189,shared_DASH_members15657196) {
var anf_fun623625475 = G(shared_DASH_members15657196,"map",L[3804]);
var anf_arg623925476 = R.makeFunction(function(recv_DASH_75125479) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3803],1,arguments);
}
var anf_fun623825490 = G(recv_DASH_75125479,"visit",L[3803]);
var $z2548225483 = D;
var $f2548825489 = function(_) {
return R.isFunction(anf_fun623825490)?anf_fun623825490.app(self15587189):R.ffi.throwNonFunApp(L[3803],anf_fun623825490,[self15587189]);
};
try {
if(--R.GAS > 0) {
$z2548225483 = $f2548825489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2548825489,
"from":L[3803]});
}
} catch($e2548025481) {
if(R.isCont($e2548025481)) {
var $ss2548425485 = {"from":L[3803],
"go":function(ann_DASH_check_DASH_temp623725491) {
return $Hann_DASH_check_DASH_temp1069025492(ann_DASH_check_DASH_temp623725491);
}};
$e2548025481.stack[R.EXN_STACKHEIGHT++] = $ss2548425485;
}
if(R.isPyretException($e2548025481)) {
$e2548025481.pyretStack.push(L[3803]);
}
throw $e2548025481;
}
var $ret2548625487 = $Hann_DASH_check_DASH_temp1069025492($z2548225483);
++R.GAS;
return $ret2548625487;
});
var $z2546725468 = D;
var $f2547325474 = function(_) {
return R.isFunction(anf_fun623625475)?anf_fun623625475.app(anf_arg623925476):R.ffi.throwNonFunApp(L[3802],anf_fun623625475,[anf_arg623925476]);
};
try {
if(--R.GAS > 0) {
$z2546725468 = $f2547325474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2547325474,
"from":L[3802]});
}
} catch($e2546525466) {
if(R.isCont($e2546525466)) {
var $ss2546925470 = {"from":L[3802],
"go":function(anf_arg624025477) {
return $Hanf_arg1069325478(anf_arg624025477,_check15667191,anf_arg62207190,anf_arg622525393,anf_arg623025421,anf_arg623525449,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189);
}};
$e2546525466.stack[R.EXN_STACKHEIGHT++] = $ss2546925470;
}
if(R.isPyretException($e2546525466)) {
$e2546525466.pyretStack.push(L[3802]);
}
throw $e2546525466;
}
var $ret2547125472 = $Hanf_arg1069325478($z2546725468,_check15667191,anf_arg62207190,anf_arg622525393,anf_arg623025421,anf_arg623525449,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189);
++R.GAS;
return $ret2547125472;
};
var $Hanf_arg1069325478 = function(anf_arg624025477,_check15667191,anf_arg62207190,anf_arg622525393,anf_arg623025421,anf_arg623525449,l15597192,name15607194,s_DASH_data_DASH_expr4222145,self15587189) {
var anf_fun624125503 = G(self15587189,"option",L[3806]);
var $z2549525496 = D;
var $f2550125502 = function(_) {
return R.isFunction(anf_fun624125503)?anf_fun624125503.app(_check15667191):R.ffi.throwNonFunApp(L[3805],anf_fun624125503,[_check15667191]);
};
try {
if(--R.GAS > 0) {
$z2549525496 = $f2550125502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2550125502,
"from":L[3805]});
}
} catch($e2549325494) {
if(R.isCont($e2549325494)) {
var $ss2549725498 = {"from":L[3805],
"go":function(anf_arg624225504) {
return $Hanf_arg1069225505(anf_arg624225504,anf_arg62207190,anf_arg622525393,anf_arg623025421,anf_arg623525449,anf_arg624025477,l15597192,name15607194,s_DASH_data_DASH_expr4222145);
}};
$e2549325494.stack[R.EXN_STACKHEIGHT++] = $ss2549725498;
}
if(R.isPyretException($e2549325494)) {
$e2549325494.pyretStack.push(L[3805]);
}
throw $e2549325494;
}
var $ret2549925500 = $Hanf_arg1069225505($z2549525496,anf_arg62207190,anf_arg622525393,anf_arg623025421,anf_arg623525449,anf_arg624025477,l15597192,name15607194,s_DASH_data_DASH_expr4222145);
++R.GAS;
return $ret2549925500;
};
var $Hanf_arg1069225505 = function(anf_arg624225504,anf_arg62207190,anf_arg622525393,anf_arg623025421,anf_arg623525449,anf_arg624025477,l15597192,name15607194,s_DASH_data_DASH_expr4222145) {
var $z2550825509 = D;
var $f2551425515 = function(_) {
return R.isFunction(s_DASH_data_DASH_expr4222145.$var)?s_DASH_data_DASH_expr4222145.$var.app(l15597192,name15607194,anf_arg62207190,anf_arg622525393,anf_arg623025421,anf_arg623525449,anf_arg624025477,anf_arg624225504):R.ffi.throwNonFunApp(L[1357],s_DASH_data_DASH_expr4222145.$var,[l15597192,name15607194,anf_arg62207190,anf_arg622525393,anf_arg623025421,anf_arg623525449,anf_arg624025477,anf_arg624225504]);
};
try {
if(--R.GAS > 0) {
$z2550825509 = $f2551425515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2551425515,
"from":L[1357]});
}
} catch($e2550625507) {
if(R.isCont($e2550625507)) {
var $ss2551025511 = {"from":L[1357],
"go":function(ann_DASH_check_DASH_temp621825516) {
return $Hann_DASH_check_DASH_temp1069125517(ann_DASH_check_DASH_temp621825516);
}};
$e2550625507.stack[R.EXN_STACKHEIGHT++] = $ss2551025511;
}
if(R.isPyretException($e2550625507)) {
$e2550625507.pyretStack.push(L[1357]);
}
throw $e2550625507;
}
var $ret2551225513 = $Hann_DASH_check_DASH_temp1069125517($z2550825509);
++R.GAS;
return $ret2551225513;
};
var $Hann_DASH_check_DASH_temp1069125517 = function(ann_DASH_check_DASH_temp621825516) {
return ann_DASH_check_DASH_temp621825516;
};
var $Hann_DASH_check_DASH_temp1069025492 = function(ann_DASH_check_DASH_temp623725491) {
return ann_DASH_check_DASH_temp623725491;
};
var $Hann_DASH_check_DASH_temp1068925464 = function(ann_DASH_check_DASH_temp623225463) {
return ann_DASH_check_DASH_temp623225463;
};
var $Hann_DASH_check_DASH_temp1068825436 = function(ann_DASH_check_DASH_temp622725435) {
return ann_DASH_check_DASH_temp622725435;
};
var $Hann_DASH_check_DASH_temp1068725408 = function(ann_DASH_check_DASH_temp622225407) {
return ann_DASH_check_DASH_temp622225407;
};
var $Hanf_arg106867220 = function(anf_arg61997212,_check15577213,l15517214,mixins15547215,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218,variants15557219) {
var anf_fun620025528 = G(mixins15547215,"map",L[3809]);
var anf_arg620325529 = R.makeFunction(function(recv_DASH_74525532) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3808],1,arguments);
}
var anf_fun620225543 = G(recv_DASH_74525532,"visit",L[3808]);
var $z2553525536 = D;
var $f2554125542 = function(_) {
return R.isFunction(anf_fun620225543)?anf_fun620225543.app(self15507217):R.ffi.throwNonFunApp(L[3808],anf_fun620225543,[self15507217]);
};
try {
if(--R.GAS > 0) {
$z2553525536 = $f2554125542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2554125542,
"from":L[3808]});
}
} catch($e2553325534) {
if(R.isCont($e2553325534)) {
var $ss2553725538 = {"from":L[3808],
"go":function(ann_DASH_check_DASH_temp620125544) {
return $Hann_DASH_check_DASH_temp1067825545(ann_DASH_check_DASH_temp620125544);
}};
$e2553325534.stack[R.EXN_STACKHEIGHT++] = $ss2553725538;
}
if(R.isPyretException($e2553325534)) {
$e2553325534.pyretStack.push(L[3808]);
}
throw $e2553325534;
}
var $ret2553925540 = $Hann_DASH_check_DASH_temp1067825545($z2553525536);
++R.GAS;
return $ret2553925540;
});
var $z2552025521 = D;
var $f2552625527 = function(_) {
return R.isFunction(anf_fun620025528)?anf_fun620025528.app(anf_arg620325529):R.ffi.throwNonFunApp(L[3807],anf_fun620025528,[anf_arg620325529]);
};
try {
if(--R.GAS > 0) {
$z2552025521 = $f2552625527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2552625527,
"from":L[3807]});
}
} catch($e2551825519) {
if(R.isCont($e2551825519)) {
var $ss2552225523 = {"from":L[3807],
"go":function(anf_arg620425530) {
return $Hanf_arg1068525531(anf_arg620425530,_check15577213,anf_arg61997212,l15517214,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218,variants15557219);
}};
$e2551825519.stack[R.EXN_STACKHEIGHT++] = $ss2552225523;
}
if(R.isPyretException($e2551825519)) {
$e2551825519.pyretStack.push(L[3807]);
}
throw $e2551825519;
}
var $ret2552425525 = $Hanf_arg1068525531($z2552025521,_check15577213,anf_arg61997212,l15517214,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218,variants15557219);
++R.GAS;
return $ret2552425525;
};
var $Hanf_arg1068525531 = function(anf_arg620425530,_check15577213,anf_arg61997212,l15517214,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218,variants15557219) {
var anf_fun620525556 = G(variants15557219,"map",L[3812]);
var anf_arg620825557 = R.makeFunction(function(recv_DASH_74625560) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3811],1,arguments);
}
var anf_fun620725571 = G(recv_DASH_74625560,"visit",L[3811]);
var $z2556325564 = D;
var $f2556925570 = function(_) {
return R.isFunction(anf_fun620725571)?anf_fun620725571.app(self15507217):R.ffi.throwNonFunApp(L[3811],anf_fun620725571,[self15507217]);
};
try {
if(--R.GAS > 0) {
$z2556325564 = $f2556925570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2556925570,
"from":L[3811]});
}
} catch($e2556125562) {
if(R.isCont($e2556125562)) {
var $ss2556525566 = {"from":L[3811],
"go":function(ann_DASH_check_DASH_temp620625572) {
return $Hann_DASH_check_DASH_temp1067925573(ann_DASH_check_DASH_temp620625572);
}};
$e2556125562.stack[R.EXN_STACKHEIGHT++] = $ss2556525566;
}
if(R.isPyretException($e2556125562)) {
$e2556125562.pyretStack.push(L[3811]);
}
throw $e2556125562;
}
var $ret2556725568 = $Hann_DASH_check_DASH_temp1067925573($z2556325564);
++R.GAS;
return $ret2556725568;
});
var $z2554825549 = D;
var $f2555425555 = function(_) {
return R.isFunction(anf_fun620525556)?anf_fun620525556.app(anf_arg620825557):R.ffi.throwNonFunApp(L[3810],anf_fun620525556,[anf_arg620825557]);
};
try {
if(--R.GAS > 0) {
$z2554825549 = $f2555425555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2555425555,
"from":L[3810]});
}
} catch($e2554625547) {
if(R.isCont($e2554625547)) {
var $ss2555025551 = {"from":L[3810],
"go":function(anf_arg620925558) {
return $Hanf_arg1068425559(anf_arg620925558,_check15577213,anf_arg61997212,anf_arg620425530,l15517214,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218);
}};
$e2554625547.stack[R.EXN_STACKHEIGHT++] = $ss2555025551;
}
if(R.isPyretException($e2554625547)) {
$e2554625547.pyretStack.push(L[3810]);
}
throw $e2554625547;
}
var $ret2555225553 = $Hanf_arg1068425559($z2554825549,_check15577213,anf_arg61997212,anf_arg620425530,l15517214,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218);
++R.GAS;
return $ret2555225553;
};
var $Hanf_arg1068425559 = function(anf_arg620925558,_check15577213,anf_arg61997212,anf_arg620425530,l15517214,name15527216,s_DASH_data4202141,self15507217,shared_DASH_members15567218) {
var anf_fun621025584 = G(shared_DASH_members15567218,"map",L[3815]);
var anf_arg621325585 = R.makeFunction(function(recv_DASH_74725588) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3814],1,arguments);
}
var anf_fun621225599 = G(recv_DASH_74725588,"visit",L[3814]);
var $z2559125592 = D;
var $f2559725598 = function(_) {
return R.isFunction(anf_fun621225599)?anf_fun621225599.app(self15507217):R.ffi.throwNonFunApp(L[3814],anf_fun621225599,[self15507217]);
};
try {
if(--R.GAS > 0) {
$z2559125592 = $f2559725598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2559725598,
"from":L[3814]});
}
} catch($e2558925590) {
if(R.isCont($e2558925590)) {
var $ss2559325594 = {"from":L[3814],
"go":function(ann_DASH_check_DASH_temp621125600) {
return $Hann_DASH_check_DASH_temp1068025601(ann_DASH_check_DASH_temp621125600);
}};
$e2558925590.stack[R.EXN_STACKHEIGHT++] = $ss2559325594;
}
if(R.isPyretException($e2558925590)) {
$e2558925590.pyretStack.push(L[3814]);
}
throw $e2558925590;
}
var $ret2559525596 = $Hann_DASH_check_DASH_temp1068025601($z2559125592);
++R.GAS;
return $ret2559525596;
});
var $z2557625577 = D;
var $f2558225583 = function(_) {
return R.isFunction(anf_fun621025584)?anf_fun621025584.app(anf_arg621325585):R.ffi.throwNonFunApp(L[3813],anf_fun621025584,[anf_arg621325585]);
};
try {
if(--R.GAS > 0) {
$z2557625577 = $f2558225583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2558225583,
"from":L[3813]});
}
} catch($e2557425575) {
if(R.isCont($e2557425575)) {
var $ss2557825579 = {"from":L[3813],
"go":function(anf_arg621425586) {
return $Hanf_arg1068325587(anf_arg621425586,_check15577213,anf_arg61997212,anf_arg620425530,anf_arg620925558,l15517214,name15527216,s_DASH_data4202141,self15507217);
}};
$e2557425575.stack[R.EXN_STACKHEIGHT++] = $ss2557825579;
}
if(R.isPyretException($e2557425575)) {
$e2557425575.pyretStack.push(L[3813]);
}
throw $e2557425575;
}
var $ret2558025581 = $Hanf_arg1068325587($z2557625577,_check15577213,anf_arg61997212,anf_arg620425530,anf_arg620925558,l15517214,name15527216,s_DASH_data4202141,self15507217);
++R.GAS;
return $ret2558025581;
};
var $Hanf_arg1068325587 = function(anf_arg621425586,_check15577213,anf_arg61997212,anf_arg620425530,anf_arg620925558,l15517214,name15527216,s_DASH_data4202141,self15507217) {
var anf_fun621525612 = G(self15507217,"option",L[3817]);
var $z2560425605 = D;
var $f2561025611 = function(_) {
return R.isFunction(anf_fun621525612)?anf_fun621525612.app(_check15577213):R.ffi.throwNonFunApp(L[3816],anf_fun621525612,[_check15577213]);
};
try {
if(--R.GAS > 0) {
$z2560425605 = $f2561025611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2561025611,
"from":L[3816]});
}
} catch($e2560225603) {
if(R.isCont($e2560225603)) {
var $ss2560625607 = {"from":L[3816],
"go":function(anf_arg621625613) {
return $Hanf_arg1068225614(anf_arg621625613,anf_arg61997212,anf_arg620425530,anf_arg620925558,anf_arg621425586,l15517214,name15527216,s_DASH_data4202141);
}};
$e2560225603.stack[R.EXN_STACKHEIGHT++] = $ss2560625607;
}
if(R.isPyretException($e2560225603)) {
$e2560225603.pyretStack.push(L[3816]);
}
throw $e2560225603;
}
var $ret2560825609 = $Hanf_arg1068225614($z2560425605,anf_arg61997212,anf_arg620425530,anf_arg620925558,anf_arg621425586,l15517214,name15527216,s_DASH_data4202141);
++R.GAS;
return $ret2560825609;
};
var $Hanf_arg1068225614 = function(anf_arg621625613,anf_arg61997212,anf_arg620425530,anf_arg620925558,anf_arg621425586,l15517214,name15527216,s_DASH_data4202141) {
var $z2561725618 = D;
var $f2562325624 = function(_) {
return R.isFunction(s_DASH_data4202141.$var)?s_DASH_data4202141.$var.app(l15517214,name15527216,anf_arg61997212,anf_arg620425530,anf_arg620925558,anf_arg621425586,anf_arg621625613):R.ffi.throwNonFunApp(L[1368],s_DASH_data4202141.$var,[l15517214,name15527216,anf_arg61997212,anf_arg620425530,anf_arg620925558,anf_arg621425586,anf_arg621625613]);
};
try {
if(--R.GAS > 0) {
$z2561725618 = $f2562325624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2562325624,
"from":L[1368]});
}
} catch($e2561525616) {
if(R.isCont($e2561525616)) {
var $ss2561925620 = {"from":L[1368],
"go":function(ann_DASH_check_DASH_temp619425625) {
return $Hann_DASH_check_DASH_temp1068125626(ann_DASH_check_DASH_temp619425625);
}};
$e2561525616.stack[R.EXN_STACKHEIGHT++] = $ss2561925620;
}
if(R.isPyretException($e2561525616)) {
$e2561525616.pyretStack.push(L[1368]);
}
throw $e2561525616;
}
var $ret2562125622 = $Hann_DASH_check_DASH_temp1068125626($z2561725618);
++R.GAS;
return $ret2562125622;
};
var $Hann_DASH_check_DASH_temp1068125626 = function(ann_DASH_check_DASH_temp619425625) {
return ann_DASH_check_DASH_temp619425625;
};
var $Hann_DASH_check_DASH_temp1068025601 = function(ann_DASH_check_DASH_temp621125600) {
return ann_DASH_check_DASH_temp621125600;
};
var $Hann_DASH_check_DASH_temp1067925573 = function(ann_DASH_check_DASH_temp620625572) {
return ann_DASH_check_DASH_temp620625572;
};
var $Hann_DASH_check_DASH_temp1067825545 = function(ann_DASH_check_DASH_temp620125544) {
return ann_DASH_check_DASH_temp620125544;
};
var $Hann_DASH_check_DASH_temp106777234 = function(ann_DASH_check_DASH_temp61967233) {
return ann_DASH_check_DASH_temp61967233;
};
var $Hanf_arg106767251 = function(anf_arg61907248,field15497249,l15477250,s_DASH_bracket4182137,self15467247) {
var anf_fun619125637 = G(field15497249,"visit",L[3819]);
var $z2562925630 = D;
var $f2563525636 = function(_) {
return R.isFunction(anf_fun619125637)?anf_fun619125637.app(self15467247):R.ffi.throwNonFunApp(L[3818],anf_fun619125637,[self15467247]);
};
try {
if(--R.GAS > 0) {
$z2562925630 = $f2563525636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2563525636,
"from":L[3818]});
}
} catch($e2562725628) {
if(R.isCont($e2562725628)) {
var $ss2563125632 = {"from":L[3818],
"go":function(anf_arg619225638) {
return $Hanf_arg1067525639(anf_arg619225638,anf_arg61907248,l15477250,s_DASH_bracket4182137);
}};
$e2562725628.stack[R.EXN_STACKHEIGHT++] = $ss2563125632;
}
if(R.isPyretException($e2562725628)) {
$e2562725628.pyretStack.push(L[3818]);
}
throw $e2562725628;
}
var $ret2563325634 = $Hanf_arg1067525639($z2562925630,anf_arg61907248,l15477250,s_DASH_bracket4182137);
++R.GAS;
return $ret2563325634;
};
var $Hanf_arg1067525639 = function(anf_arg619225638,anf_arg61907248,l15477250,s_DASH_bracket4182137) {
var $z2564225643 = D;
var $f2564825649 = function(_) {
return R.isFunction(s_DASH_bracket4182137.$var)?s_DASH_bracket4182137.$var.app(l15477250,anf_arg61907248,anf_arg619225638):R.ffi.throwNonFunApp(L[1374],s_DASH_bracket4182137.$var,[l15477250,anf_arg61907248,anf_arg619225638]);
};
try {
if(--R.GAS > 0) {
$z2564225643 = $f2564825649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2564825649,
"from":L[1374]});
}
} catch($e2564025641) {
if(R.isCont($e2564025641)) {
var $ss2564425645 = {"from":L[1374],
"go":function(ann_DASH_check_DASH_temp618825650) {
return $Hann_DASH_check_DASH_temp1067425651(ann_DASH_check_DASH_temp618825650);
}};
$e2564025641.stack[R.EXN_STACKHEIGHT++] = $ss2564425645;
}
if(R.isPyretException($e2564025641)) {
$e2564025641.pyretStack.push(L[1374]);
}
throw $e2564025641;
}
var $ret2564625647 = $Hann_DASH_check_DASH_temp1067425651($z2564225643);
++R.GAS;
return $ret2564625647;
};
var $Hann_DASH_check_DASH_temp1067425651 = function(ann_DASH_check_DASH_temp618825650) {
return ann_DASH_check_DASH_temp618825650;
};
var $Hanf_arg106737268 = function(anf_arg61867265,field15457266,l15437267,s_DASH_get_DASH_bang4162133) {
var $z2565425655 = D;
var $f2566025661 = function(_) {
return R.isFunction(s_DASH_get_DASH_bang4162133.$var)?s_DASH_get_DASH_bang4162133.$var.app(l15437267,anf_arg61867265,field15457266):R.ffi.throwNonFunApp(L[1380],s_DASH_get_DASH_bang4162133.$var,[l15437267,anf_arg61867265,field15457266]);
};
try {
if(--R.GAS > 0) {
$z2565425655 = $f2566025661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2566025661,
"from":L[1380]});
}
} catch($e2565225653) {
if(R.isCont($e2565225653)) {
var $ss2565625657 = {"from":L[1380],
"go":function(ann_DASH_check_DASH_temp618425662) {
return $Hann_DASH_check_DASH_temp1067225663(ann_DASH_check_DASH_temp618425662);
}};
$e2565225653.stack[R.EXN_STACKHEIGHT++] = $ss2565625657;
}
if(R.isPyretException($e2565225653)) {
$e2565225653.pyretStack.push(L[1380]);
}
throw $e2565225653;
}
var $ret2565825659 = $Hann_DASH_check_DASH_temp1067225663($z2565425655);
++R.GAS;
return $ret2565825659;
};
var $Hann_DASH_check_DASH_temp1067225663 = function(ann_DASH_check_DASH_temp618425662) {
return ann_DASH_check_DASH_temp618425662;
};
var $Hanf_arg106717285 = function(anf_arg61827282,field15417283,l15397284,s_DASH_dot4142129) {
var $z2566625667 = D;
var $f2567225673 = function(_) {
return R.isFunction(s_DASH_dot4142129.$var)?s_DASH_dot4142129.$var.app(l15397284,anf_arg61827282,field15417283):R.ffi.throwNonFunApp(L[1386],s_DASH_dot4142129.$var,[l15397284,anf_arg61827282,field15417283]);
};
try {
if(--R.GAS > 0) {
$z2566625667 = $f2567225673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2567225673,
"from":L[1386]});
}
} catch($e2566425665) {
if(R.isCont($e2566425665)) {
var $ss2566825669 = {"from":L[1386],
"go":function(ann_DASH_check_DASH_temp618025674) {
return $Hann_DASH_check_DASH_temp1067025675(ann_DASH_check_DASH_temp618025674);
}};
$e2566425665.stack[R.EXN_STACKHEIGHT++] = $ss2566825669;
}
if(R.isPyretException($e2566425665)) {
$e2566425665.pyretStack.push(L[1386]);
}
throw $e2566425665;
}
var $ret2567025671 = $Hann_DASH_check_DASH_temp1067025675($z2566625667);
++R.GAS;
return $ret2567025671;
};
var $Hann_DASH_check_DASH_temp1067025675 = function(ann_DASH_check_DASH_temp618025674) {
return ann_DASH_check_DASH_temp618025674;
};
var $Hann_DASH_check_DASH_temp106697300 = function(ann_DASH_check_DASH_temp61787299) {
return ann_DASH_check_DASH_temp61787299;
};
var $Hann_DASH_check_DASH_temp106687315 = function(ann_DASH_check_DASH_temp61767314) {
return ann_DASH_check_DASH_temp61767314;
};
var $Hann_DASH_check_DASH_temp106677331 = function(ann_DASH_check_DASH_temp61747330) {
return ann_DASH_check_DASH_temp61747330;
};
var $Hann_DASH_check_DASH_temp106667346 = function(ann_DASH_check_DASH_temp61727345) {
return ann_DASH_check_DASH_temp61727345;
};
var $Hann_DASH_check_DASH_temp106657361 = function(ann_DASH_check_DASH_temp61707360) {
return ann_DASH_check_DASH_temp61707360;
};
var $Hann_DASH_check_DASH_temp106647375 = function(ann_DASH_check_DASH_temp61687374) {
return ann_DASH_check_DASH_temp61687374;
};
var $Hanf_arg106637392 = function(anf_arg61667389,l15177390,s_DASH_id_DASH_letrec4002101,safe15197391) {
var $z2567825679 = D;
var $f2568425685 = function(_) {
return R.isFunction(s_DASH_id_DASH_letrec4002101.$var)?s_DASH_id_DASH_letrec4002101.$var.app(l15177390,anf_arg61667389,safe15197391):R.ffi.throwNonFunApp(L[1408],s_DASH_id_DASH_letrec4002101.$var,[l15177390,anf_arg61667389,safe15197391]);
};
try {
if(--R.GAS > 0) {
$z2567825679 = $f2568425685();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2568425685,
"from":L[1408]});
}
} catch($e2567625677) {
if(R.isCont($e2567625677)) {
var $ss2568025681 = {"from":L[1408],
"go":function(ann_DASH_check_DASH_temp616425686) {
return $Hann_DASH_check_DASH_temp1066225687(ann_DASH_check_DASH_temp616425686);
}};
$e2567625677.stack[R.EXN_STACKHEIGHT++] = $ss2568025681;
}
if(R.isPyretException($e2567625677)) {
$e2567625677.pyretStack.push(L[1408]);
}
throw $e2567625677;
}
var $ret2568225683 = $Hann_DASH_check_DASH_temp1066225687($z2567825679);
++R.GAS;
return $ret2568225683;
};
var $Hann_DASH_check_DASH_temp1066225687 = function(ann_DASH_check_DASH_temp616425686) {
return ann_DASH_check_DASH_temp616425686;
};
var $Hanf_arg106617408 = function(anf_arg61627406,l15147407,s_DASH_id_DASH_var3982097) {
var $z2569025691 = D;
var $f2569625697 = function(_) {
return R.isFunction(s_DASH_id_DASH_var3982097.$var)?s_DASH_id_DASH_var3982097.$var.app(l15147407,anf_arg61627406):R.ffi.throwNonFunApp(L[1413],s_DASH_id_DASH_var3982097.$var,[l15147407,anf_arg61627406]);
};
try {
if(--R.GAS > 0) {
$z2569025691 = $f2569625697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2569625697,
"from":L[1413]});
}
} catch($e2568825689) {
if(R.isCont($e2568825689)) {
var $ss2569225693 = {"from":L[1413],
"go":function(ann_DASH_check_DASH_temp616025698) {
return $Hann_DASH_check_DASH_temp1066025699(ann_DASH_check_DASH_temp616025698);
}};
$e2568825689.stack[R.EXN_STACKHEIGHT++] = $ss2569225693;
}
if(R.isPyretException($e2568825689)) {
$e2568825689.pyretStack.push(L[1413]);
}
throw $e2568825689;
}
var $ret2569425695 = $Hann_DASH_check_DASH_temp1066025699($z2569025691);
++R.GAS;
return $ret2569425695;
};
var $Hann_DASH_check_DASH_temp1066025699 = function(ann_DASH_check_DASH_temp616025698) {
return ann_DASH_check_DASH_temp616025698;
};
var $Hanf_arg106597424 = function(anf_arg61587422,l15117423,s_DASH_id3962093) {
var $z2570225703 = D;
var $f2570825709 = function(_) {
return R.isFunction(s_DASH_id3962093.$var)?s_DASH_id3962093.$var.app(l15117423,anf_arg61587422):R.ffi.throwNonFunApp(L[1418],s_DASH_id3962093.$var,[l15117423,anf_arg61587422]);
};
try {
if(--R.GAS > 0) {
$z2570225703 = $f2570825709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2570825709,
"from":L[1418]});
}
} catch($e2570025701) {
if(R.isCont($e2570025701)) {
var $ss2570425705 = {"from":L[1418],
"go":function(ann_DASH_check_DASH_temp615625710) {
return $Hann_DASH_check_DASH_temp1065825711(ann_DASH_check_DASH_temp615625710);
}};
$e2570025701.stack[R.EXN_STACKHEIGHT++] = $ss2570425705;
}
if(R.isPyretException($e2570025701)) {
$e2570025701.pyretStack.push(L[1418]);
}
throw $e2570025701;
}
var $ret2570625707 = $Hann_DASH_check_DASH_temp1065825711($z2570225703);
++R.GAS;
return $ret2570625707;
};
var $Hann_DASH_check_DASH_temp1065825711 = function(ann_DASH_check_DASH_temp615625710) {
return ann_DASH_check_DASH_temp615625710;
};
var $Hann_DASH_check_DASH_temp106577439 = function(ann_DASH_check_DASH_temp61547438) {
return ann_DASH_check_DASH_temp61547438;
};
var $Hanf_arg106567456 = function(anf_arg61527453,_fun15057454,l15047455,s_DASH_prim_DASH_app3922085) {
var $z2571425715 = D;
var $f2572025721 = function(_) {
return R.isFunction(s_DASH_prim_DASH_app3922085.$var)?s_DASH_prim_DASH_app3922085.$var.app(l15047455,_fun15057454,anf_arg61527453):R.ffi.throwNonFunApp(L[1428],s_DASH_prim_DASH_app3922085.$var,[l15047455,_fun15057454,anf_arg61527453]);
};
try {
if(--R.GAS > 0) {
$z2571425715 = $f2572025721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2572025721,
"from":L[1428]});
}
} catch($e2571225713) {
if(R.isCont($e2571225713)) {
var $ss2571625717 = {"from":L[1428],
"go":function(ann_DASH_check_DASH_temp614725722) {
return $Hann_DASH_check_DASH_temp1065525723(ann_DASH_check_DASH_temp614725722);
}};
$e2571225713.stack[R.EXN_STACKHEIGHT++] = $ss2571625717;
}
if(R.isPyretException($e2571225713)) {
$e2571225713.pyretStack.push(L[1428]);
}
throw $e2571225713;
}
var $ret2571825719 = $Hann_DASH_check_DASH_temp1065525723($z2571425715);
++R.GAS;
return $ret2571825719;
};
var $Hann_DASH_check_DASH_temp1065525723 = function(ann_DASH_check_DASH_temp614725722) {
return ann_DASH_check_DASH_temp614725722;
};
var $Hann_DASH_check_DASH_temp106547471 = function(ann_DASH_check_DASH_temp61497470) {
return ann_DASH_check_DASH_temp61497470;
};
var $Hanf_arg106537488 = function(anf_arg61407485,args15027486,l15007487,s_DASH_app3902081,self14997484) {
var anf_fun614125734 = G(args15027486,"map",L[3822]);
var anf_arg614425735 = R.makeFunction(function(recv_DASH_74225738) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3821],1,arguments);
}
var anf_fun614325749 = G(recv_DASH_74225738,"visit",L[3821]);
var $z2574125742 = D;
var $f2574725748 = function(_) {
return R.isFunction(anf_fun614325749)?anf_fun614325749.app(self14997484):R.ffi.throwNonFunApp(L[3821],anf_fun614325749,[self14997484]);
};
try {
if(--R.GAS > 0) {
$z2574125742 = $f2574725748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2574725748,
"from":L[3821]});
}
} catch($e2573925740) {
if(R.isCont($e2573925740)) {
var $ss2574325744 = {"from":L[3821],
"go":function(ann_DASH_check_DASH_temp614225750) {
return $Hann_DASH_check_DASH_temp1065025751(ann_DASH_check_DASH_temp614225750);
}};
$e2573925740.stack[R.EXN_STACKHEIGHT++] = $ss2574325744;
}
if(R.isPyretException($e2573925740)) {
$e2573925740.pyretStack.push(L[3821]);
}
throw $e2573925740;
}
var $ret2574525746 = $Hann_DASH_check_DASH_temp1065025751($z2574125742);
++R.GAS;
return $ret2574525746;
});
var $z2572625727 = D;
var $f2573225733 = function(_) {
return R.isFunction(anf_fun614125734)?anf_fun614125734.app(anf_arg614425735):R.ffi.throwNonFunApp(L[3820],anf_fun614125734,[anf_arg614425735]);
};
try {
if(--R.GAS > 0) {
$z2572625727 = $f2573225733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2573225733,
"from":L[3820]});
}
} catch($e2572425725) {
if(R.isCont($e2572425725)) {
var $ss2572825729 = {"from":L[3820],
"go":function(anf_arg614525736) {
return $Hanf_arg1065225737(anf_arg614525736,anf_arg61407485,l15007487,s_DASH_app3902081);
}};
$e2572425725.stack[R.EXN_STACKHEIGHT++] = $ss2572825729;
}
if(R.isPyretException($e2572425725)) {
$e2572425725.pyretStack.push(L[3820]);
}
throw $e2572425725;
}
var $ret2573025731 = $Hanf_arg1065225737($z2572625727,anf_arg61407485,l15007487,s_DASH_app3902081);
++R.GAS;
return $ret2573025731;
};
var $Hanf_arg1065225737 = function(anf_arg614525736,anf_arg61407485,l15007487,s_DASH_app3902081) {
var $z2575425755 = D;
var $f2576025761 = function(_) {
return R.isFunction(s_DASH_app3902081.$var)?s_DASH_app3902081.$var.app(l15007487,anf_arg61407485,anf_arg614525736):R.ffi.throwNonFunApp(L[1434],s_DASH_app3902081.$var,[l15007487,anf_arg61407485,anf_arg614525736]);
};
try {
if(--R.GAS > 0) {
$z2575425755 = $f2576025761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2576025761,
"from":L[1434]});
}
} catch($e2575225753) {
if(R.isCont($e2575225753)) {
var $ss2575625757 = {"from":L[1434],
"go":function(ann_DASH_check_DASH_temp613825762) {
return $Hann_DASH_check_DASH_temp1065125763(ann_DASH_check_DASH_temp613825762);
}};
$e2575225753.stack[R.EXN_STACKHEIGHT++] = $ss2575625757;
}
if(R.isPyretException($e2575225753)) {
$e2575225753.pyretStack.push(L[1434]);
}
throw $e2575225753;
}
var $ret2575825759 = $Hann_DASH_check_DASH_temp1065125763($z2575425755);
++R.GAS;
return $ret2575825759;
};
var $Hann_DASH_check_DASH_temp1065125763 = function(ann_DASH_check_DASH_temp613825762) {
return ann_DASH_check_DASH_temp613825762;
};
var $Hann_DASH_check_DASH_temp1065025751 = function(ann_DASH_check_DASH_temp614225750) {
return ann_DASH_check_DASH_temp614225750;
};
var $Hanf_arg106497506 = function(anf_arg61317502,l14957503,mod14967504,s_DASH_construct3842069,self14947501,values14987505) {
var anf_fun613225774 = G(values14987505,"map",L[3825]);
var anf_arg613525775 = R.makeFunction(function(recv_DASH_74125778) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3824],1,arguments);
}
var anf_fun613425789 = G(recv_DASH_74125778,"visit",L[3824]);
var $z2578125782 = D;
var $f2578725788 = function(_) {
return R.isFunction(anf_fun613425789)?anf_fun613425789.app(self14947501):R.ffi.throwNonFunApp(L[3824],anf_fun613425789,[self14947501]);
};
try {
if(--R.GAS > 0) {
$z2578125782 = $f2578725788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2578725788,
"from":L[3824]});
}
} catch($e2577925780) {
if(R.isCont($e2577925780)) {
var $ss2578325784 = {"from":L[3824],
"go":function(ann_DASH_check_DASH_temp613325790) {
return $Hann_DASH_check_DASH_temp1064625791(ann_DASH_check_DASH_temp613325790);
}};
$e2577925780.stack[R.EXN_STACKHEIGHT++] = $ss2578325784;
}
if(R.isPyretException($e2577925780)) {
$e2577925780.pyretStack.push(L[3824]);
}
throw $e2577925780;
}
var $ret2578525786 = $Hann_DASH_check_DASH_temp1064625791($z2578125782);
++R.GAS;
return $ret2578525786;
});
var $z2576625767 = D;
var $f2577225773 = function(_) {
return R.isFunction(anf_fun613225774)?anf_fun613225774.app(anf_arg613525775):R.ffi.throwNonFunApp(L[3823],anf_fun613225774,[anf_arg613525775]);
};
try {
if(--R.GAS > 0) {
$z2576625767 = $f2577225773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2577225773,
"from":L[3823]});
}
} catch($e2576425765) {
if(R.isCont($e2576425765)) {
var $ss2576825769 = {"from":L[3823],
"go":function(anf_arg613625776) {
return $Hanf_arg1064825777(anf_arg613625776,anf_arg61317502,l14957503,mod14967504,s_DASH_construct3842069);
}};
$e2576425765.stack[R.EXN_STACKHEIGHT++] = $ss2576825769;
}
if(R.isPyretException($e2576425765)) {
$e2576425765.pyretStack.push(L[3823]);
}
throw $e2576425765;
}
var $ret2577025771 = $Hanf_arg1064825777($z2576625767,anf_arg61317502,l14957503,mod14967504,s_DASH_construct3842069);
++R.GAS;
return $ret2577025771;
};
var $Hanf_arg1064825777 = function(anf_arg613625776,anf_arg61317502,l14957503,mod14967504,s_DASH_construct3842069) {
var $z2579425795 = D;
var $f2580025801 = function(_) {
return R.isFunction(s_DASH_construct3842069.$var)?s_DASH_construct3842069.$var.app(l14957503,mod14967504,anf_arg61317502,anf_arg613625776):R.ffi.throwNonFunApp(L[1441],s_DASH_construct3842069.$var,[l14957503,mod14967504,anf_arg61317502,anf_arg613625776]);
};
try {
if(--R.GAS > 0) {
$z2579425795 = $f2580025801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2580025801,
"from":L[1441]});
}
} catch($e2579225793) {
if(R.isCont($e2579225793)) {
var $ss2579625797 = {"from":L[1441],
"go":function(ann_DASH_check_DASH_temp612925802) {
return $Hann_DASH_check_DASH_temp1064725803(ann_DASH_check_DASH_temp612925802);
}};
$e2579225793.stack[R.EXN_STACKHEIGHT++] = $ss2579625797;
}
if(R.isPyretException($e2579225793)) {
$e2579225793.pyretStack.push(L[1441]);
}
throw $e2579225793;
}
var $ret2579825799 = $Hann_DASH_check_DASH_temp1064725803($z2579425795);
++R.GAS;
return $ret2579825799;
};
var $Hann_DASH_check_DASH_temp1064725803 = function(ann_DASH_check_DASH_temp612925802) {
return ann_DASH_check_DASH_temp612925802;
};
var $Hann_DASH_check_DASH_temp1064625791 = function(ann_DASH_check_DASH_temp613325790) {
return ann_DASH_check_DASH_temp613325790;
};
var $Hanf_arg106457523 = function(anf_arg61257520,l14917521,s_DASH_confirm3862073,self14907519,typ14937522) {
var anf_fun612625814 = G(typ14937522,"visit",L[3827]);
var $z2580625807 = D;
var $f2581225813 = function(_) {
return R.isFunction(anf_fun612625814)?anf_fun612625814.app(self14907519):R.ffi.throwNonFunApp(L[3826],anf_fun612625814,[self14907519]);
};
try {
if(--R.GAS > 0) {
$z2580625807 = $f2581225813();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2581225813,
"from":L[3826]});
}
} catch($e2580425805) {
if(R.isCont($e2580425805)) {
var $ss2580825809 = {"from":L[3826],
"go":function(anf_arg612725815) {
return $Hanf_arg1064425816(anf_arg612725815,anf_arg61257520,l14917521,s_DASH_confirm3862073);
}};
$e2580425805.stack[R.EXN_STACKHEIGHT++] = $ss2580825809;
}
if(R.isPyretException($e2580425805)) {
$e2580425805.pyretStack.push(L[3826]);
}
throw $e2580425805;
}
var $ret2581025811 = $Hanf_arg1064425816($z2580625807,anf_arg61257520,l14917521,s_DASH_confirm3862073);
++R.GAS;
return $ret2581025811;
};
var $Hanf_arg1064425816 = function(anf_arg612725815,anf_arg61257520,l14917521,s_DASH_confirm3862073) {
var $z2581925820 = D;
var $f2582525826 = function(_) {
return R.isFunction(s_DASH_confirm3862073.$var)?s_DASH_confirm3862073.$var.app(l14917521,anf_arg61257520,anf_arg612725815):R.ffi.throwNonFunApp(L[1447],s_DASH_confirm3862073.$var,[l14917521,anf_arg61257520,anf_arg612725815]);
};
try {
if(--R.GAS > 0) {
$z2581925820 = $f2582525826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2582525826,
"from":L[1447]});
}
} catch($e2581725818) {
if(R.isCont($e2581725818)) {
var $ss2582125822 = {"from":L[1447],
"go":function(ann_DASH_check_DASH_temp612325827) {
return $Hann_DASH_check_DASH_temp1064325828(ann_DASH_check_DASH_temp612325827);
}};
$e2581725818.stack[R.EXN_STACKHEIGHT++] = $ss2582125822;
}
if(R.isPyretException($e2581725818)) {
$e2581725818.pyretStack.push(L[1447]);
}
throw $e2581725818;
}
var $ret2582325824 = $Hann_DASH_check_DASH_temp1064325828($z2581925820);
++R.GAS;
return $ret2582325824;
};
var $Hann_DASH_check_DASH_temp1064325828 = function(ann_DASH_check_DASH_temp612325827) {
return ann_DASH_check_DASH_temp612325827;
};
var $Hanf_arg106427540 = function(anf_arg61197537,l14877538,s_DASH_bless3882077,self14867536,typ14897539) {
var anf_fun612025839 = G(typ14897539,"visit",L[3829]);
var $z2583125832 = D;
var $f2583725838 = function(_) {
return R.isFunction(anf_fun612025839)?anf_fun612025839.app(self14867536):R.ffi.throwNonFunApp(L[3828],anf_fun612025839,[self14867536]);
};
try {
if(--R.GAS > 0) {
$z2583125832 = $f2583725838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2583725838,
"from":L[3828]});
}
} catch($e2582925830) {
if(R.isCont($e2582925830)) {
var $ss2583325834 = {"from":L[3828],
"go":function(anf_arg612125840) {
return $Hanf_arg1064125841(anf_arg612125840,anf_arg61197537,l14877538,s_DASH_bless3882077);
}};
$e2582925830.stack[R.EXN_STACKHEIGHT++] = $ss2583325834;
}
if(R.isPyretException($e2582925830)) {
$e2582925830.pyretStack.push(L[3828]);
}
throw $e2582925830;
}
var $ret2583525836 = $Hanf_arg1064125841($z2583125832,anf_arg61197537,l14877538,s_DASH_bless3882077);
++R.GAS;
return $ret2583525836;
};
var $Hanf_arg1064125841 = function(anf_arg612125840,anf_arg61197537,l14877538,s_DASH_bless3882077) {
var $z2584425845 = D;
var $f2585025851 = function(_) {
return R.isFunction(s_DASH_bless3882077.$var)?s_DASH_bless3882077.$var.app(l14877538,anf_arg61197537,anf_arg612125840):R.ffi.throwNonFunApp(L[1453],s_DASH_bless3882077.$var,[l14877538,anf_arg61197537,anf_arg612125840]);
};
try {
if(--R.GAS > 0) {
$z2584425845 = $f2585025851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2585025851,
"from":L[1453]});
}
} catch($e2584225843) {
if(R.isCont($e2584225843)) {
var $ss2584625847 = {"from":L[1453],
"go":function(ann_DASH_check_DASH_temp611725852) {
return $Hann_DASH_check_DASH_temp1064025853(ann_DASH_check_DASH_temp611725852);
}};
$e2584225843.stack[R.EXN_STACKHEIGHT++] = $ss2584625847;
}
if(R.isPyretException($e2584225843)) {
$e2584225843.pyretStack.push(L[1453]);
}
throw $e2584225843;
}
var $ret2584825849 = $Hann_DASH_check_DASH_temp1064025853($z2584425845);
++R.GAS;
return $ret2584825849;
};
var $Hann_DASH_check_DASH_temp1064025853 = function(ann_DASH_check_DASH_temp611725852) {
return ann_DASH_check_DASH_temp611725852;
};
var $Hanf_arg106397556 = function(anf_arg61157554,l14847555,s_DASH_array3822065) {
var $z2585625857 = D;
var $f2586225863 = function(_) {
return R.isFunction(s_DASH_array3822065.$var)?s_DASH_array3822065.$var.app(l14847555,anf_arg61157554):R.ffi.throwNonFunApp(L[1459],s_DASH_array3822065.$var,[l14847555,anf_arg61157554]);
};
try {
if(--R.GAS > 0) {
$z2585625857 = $f2586225863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2586225863,
"from":L[1459]});
}
} catch($e2585425855) {
if(R.isCont($e2585425855)) {
var $ss2585825859 = {"from":L[1459],
"go":function(ann_DASH_check_DASH_temp611025864) {
return $Hann_DASH_check_DASH_temp1063825865(ann_DASH_check_DASH_temp611025864);
}};
$e2585425855.stack[R.EXN_STACKHEIGHT++] = $ss2585825859;
}
if(R.isPyretException($e2585425855)) {
$e2585425855.pyretStack.push(L[1459]);
}
throw $e2585425855;
}
var $ret2586025861 = $Hann_DASH_check_DASH_temp1063825865($z2585625857);
++R.GAS;
return $ret2586025861;
};
var $Hann_DASH_check_DASH_temp1063825865 = function(ann_DASH_check_DASH_temp611025864) {
return ann_DASH_check_DASH_temp611025864;
};
var $Hann_DASH_check_DASH_temp106377571 = function(ann_DASH_check_DASH_temp61127570) {
return ann_DASH_check_DASH_temp61127570;
};
var $Hanf_arg106367587 = function(anf_arg61087585,l14817586,s_DASH_obj3802061) {
var $z2586825869 = D;
var $f2587425875 = function(_) {
return R.isFunction(s_DASH_obj3802061.$var)?s_DASH_obj3802061.$var.app(l14817586,anf_arg61087585):R.ffi.throwNonFunApp(L[1465],s_DASH_obj3802061.$var,[l14817586,anf_arg61087585]);
};
try {
if(--R.GAS > 0) {
$z2586825869 = $f2587425875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2587425875,
"from":L[1465]});
}
} catch($e2586625867) {
if(R.isCont($e2586625867)) {
var $ss2587025871 = {"from":L[1465],
"go":function(ann_DASH_check_DASH_temp610325876) {
return $Hann_DASH_check_DASH_temp1063525877(ann_DASH_check_DASH_temp610325876);
}};
$e2586625867.stack[R.EXN_STACKHEIGHT++] = $ss2587025871;
}
if(R.isPyretException($e2586625867)) {
$e2586625867.pyretStack.push(L[1465]);
}
throw $e2586625867;
}
var $ret2587225873 = $Hann_DASH_check_DASH_temp1063525877($z2586825869);
++R.GAS;
return $ret2587225873;
};
var $Hann_DASH_check_DASH_temp1063525877 = function(ann_DASH_check_DASH_temp610325876) {
return ann_DASH_check_DASH_temp610325876;
};
var $Hann_DASH_check_DASH_temp106347602 = function(ann_DASH_check_DASH_temp61057601) {
return ann_DASH_check_DASH_temp61057601;
};
var $Hanf_arg106337619 = function(anf_arg60967616,fields14797617,l14777618,s_DASH_update3782057,self14767615) {
var anf_fun609725888 = G(fields14797617,"map",L[3832]);
var anf_arg610025889 = R.makeFunction(function(recv_DASH_73825892) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3831],1,arguments);
}
var anf_fun609925903 = G(recv_DASH_73825892,"visit",L[3831]);
var $z2589525896 = D;
var $f2590125902 = function(_) {
return R.isFunction(anf_fun609925903)?anf_fun609925903.app(self14767615):R.ffi.throwNonFunApp(L[3831],anf_fun609925903,[self14767615]);
};
try {
if(--R.GAS > 0) {
$z2589525896 = $f2590125902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2590125902,
"from":L[3831]});
}
} catch($e2589325894) {
if(R.isCont($e2589325894)) {
var $ss2589725898 = {"from":L[3831],
"go":function(ann_DASH_check_DASH_temp609825904) {
return $Hann_DASH_check_DASH_temp1063025905(ann_DASH_check_DASH_temp609825904);
}};
$e2589325894.stack[R.EXN_STACKHEIGHT++] = $ss2589725898;
}
if(R.isPyretException($e2589325894)) {
$e2589325894.pyretStack.push(L[3831]);
}
throw $e2589325894;
}
var $ret2589925900 = $Hann_DASH_check_DASH_temp1063025905($z2589525896);
++R.GAS;
return $ret2589925900;
});
var $z2588025881 = D;
var $f2588625887 = function(_) {
return R.isFunction(anf_fun609725888)?anf_fun609725888.app(anf_arg610025889):R.ffi.throwNonFunApp(L[3830],anf_fun609725888,[anf_arg610025889]);
};
try {
if(--R.GAS > 0) {
$z2588025881 = $f2588625887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2588625887,
"from":L[3830]});
}
} catch($e2587825879) {
if(R.isCont($e2587825879)) {
var $ss2588225883 = {"from":L[3830],
"go":function(anf_arg610125890) {
return $Hanf_arg1063225891(anf_arg610125890,anf_arg60967616,l14777618,s_DASH_update3782057);
}};
$e2587825879.stack[R.EXN_STACKHEIGHT++] = $ss2588225883;
}
if(R.isPyretException($e2587825879)) {
$e2587825879.pyretStack.push(L[3830]);
}
throw $e2587825879;
}
var $ret2588425885 = $Hanf_arg1063225891($z2588025881,anf_arg60967616,l14777618,s_DASH_update3782057);
++R.GAS;
return $ret2588425885;
};
var $Hanf_arg1063225891 = function(anf_arg610125890,anf_arg60967616,l14777618,s_DASH_update3782057) {
var $z2590825909 = D;
var $f2591425915 = function(_) {
return R.isFunction(s_DASH_update3782057.$var)?s_DASH_update3782057.$var.app(l14777618,anf_arg60967616,anf_arg610125890):R.ffi.throwNonFunApp(L[1471],s_DASH_update3782057.$var,[l14777618,anf_arg60967616,anf_arg610125890]);
};
try {
if(--R.GAS > 0) {
$z2590825909 = $f2591425915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2591425915,
"from":L[1471]});
}
} catch($e2590625907) {
if(R.isCont($e2590625907)) {
var $ss2591025911 = {"from":L[1471],
"go":function(ann_DASH_check_DASH_temp609425916) {
return $Hann_DASH_check_DASH_temp1063125917(ann_DASH_check_DASH_temp609425916);
}};
$e2590625907.stack[R.EXN_STACKHEIGHT++] = $ss2591025911;
}
if(R.isPyretException($e2590625907)) {
$e2590625907.pyretStack.push(L[1471]);
}
throw $e2590625907;
}
var $ret2591225913 = $Hann_DASH_check_DASH_temp1063125917($z2590825909);
++R.GAS;
return $ret2591225913;
};
var $Hann_DASH_check_DASH_temp1063125917 = function(ann_DASH_check_DASH_temp609425916) {
return ann_DASH_check_DASH_temp609425916;
};
var $Hann_DASH_check_DASH_temp1063025905 = function(ann_DASH_check_DASH_temp609825904) {
return ann_DASH_check_DASH_temp609825904;
};
var $Hanf_arg106297636 = function(anf_arg60877633,fields14757634,l14737635,s_DASH_extend3762053,self14727632) {
var anf_fun608825928 = G(fields14757634,"map",L[3835]);
var anf_arg609125929 = R.makeFunction(function(recv_DASH_73725932) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3834],1,arguments);
}
var anf_fun609025943 = G(recv_DASH_73725932,"visit",L[3834]);
var $z2593525936 = D;
var $f2594125942 = function(_) {
return R.isFunction(anf_fun609025943)?anf_fun609025943.app(self14727632):R.ffi.throwNonFunApp(L[3834],anf_fun609025943,[self14727632]);
};
try {
if(--R.GAS > 0) {
$z2593525936 = $f2594125942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2594125942,
"from":L[3834]});
}
} catch($e2593325934) {
if(R.isCont($e2593325934)) {
var $ss2593725938 = {"from":L[3834],
"go":function(ann_DASH_check_DASH_temp608925944) {
return $Hann_DASH_check_DASH_temp1062625945(ann_DASH_check_DASH_temp608925944);
}};
$e2593325934.stack[R.EXN_STACKHEIGHT++] = $ss2593725938;
}
if(R.isPyretException($e2593325934)) {
$e2593325934.pyretStack.push(L[3834]);
}
throw $e2593325934;
}
var $ret2593925940 = $Hann_DASH_check_DASH_temp1062625945($z2593525936);
++R.GAS;
return $ret2593925940;
});
var $z2592025921 = D;
var $f2592625927 = function(_) {
return R.isFunction(anf_fun608825928)?anf_fun608825928.app(anf_arg609125929):R.ffi.throwNonFunApp(L[3833],anf_fun608825928,[anf_arg609125929]);
};
try {
if(--R.GAS > 0) {
$z2592025921 = $f2592625927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2592625927,
"from":L[3833]});
}
} catch($e2591825919) {
if(R.isCont($e2591825919)) {
var $ss2592225923 = {"from":L[3833],
"go":function(anf_arg609225930) {
return $Hanf_arg1062825931(anf_arg609225930,anf_arg60877633,l14737635,s_DASH_extend3762053);
}};
$e2591825919.stack[R.EXN_STACKHEIGHT++] = $ss2592225923;
}
if(R.isPyretException($e2591825919)) {
$e2591825919.pyretStack.push(L[3833]);
}
throw $e2591825919;
}
var $ret2592425925 = $Hanf_arg1062825931($z2592025921,anf_arg60877633,l14737635,s_DASH_extend3762053);
++R.GAS;
return $ret2592425925;
};
var $Hanf_arg1062825931 = function(anf_arg609225930,anf_arg60877633,l14737635,s_DASH_extend3762053) {
var $z2594825949 = D;
var $f2595425955 = function(_) {
return R.isFunction(s_DASH_extend3762053.$var)?s_DASH_extend3762053.$var.app(l14737635,anf_arg60877633,anf_arg609225930):R.ffi.throwNonFunApp(L[1477],s_DASH_extend3762053.$var,[l14737635,anf_arg60877633,anf_arg609225930]);
};
try {
if(--R.GAS > 0) {
$z2594825949 = $f2595425955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2595425955,
"from":L[1477]});
}
} catch($e2594625947) {
if(R.isCont($e2594625947)) {
var $ss2595025951 = {"from":L[1477],
"go":function(ann_DASH_check_DASH_temp608525956) {
return $Hann_DASH_check_DASH_temp1062725957(ann_DASH_check_DASH_temp608525956);
}};
$e2594625947.stack[R.EXN_STACKHEIGHT++] = $ss2595025951;
}
if(R.isPyretException($e2594625947)) {
$e2594625947.pyretStack.push(L[1477]);
}
throw $e2594625947;
}
var $ret2595225953 = $Hann_DASH_check_DASH_temp1062725957($z2594825949);
++R.GAS;
return $ret2595225953;
};
var $Hann_DASH_check_DASH_temp1062725957 = function(ann_DASH_check_DASH_temp608525956) {
return ann_DASH_check_DASH_temp608525956;
};
var $Hann_DASH_check_DASH_temp1062625945 = function(ann_DASH_check_DASH_temp608925944) {
return ann_DASH_check_DASH_temp608925944;
};
var $Hanf_arg106257657 = function(anf_arg60777650,_check14717651,ann14687652,body14707653,doc14697654,l14667655,s_DASH_method3742049,self14657656) {
var anf_fun607825968 = G(ann14687652,"visit",L[3837]);
var $z2596025961 = D;
var $f2596625967 = function(_) {
return R.isFunction(anf_fun607825968)?anf_fun607825968.app(self14657656):R.ffi.throwNonFunApp(L[3836],anf_fun607825968,[self14657656]);
};
try {
if(--R.GAS > 0) {
$z2596025961 = $f2596625967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2596625967,
"from":L[3836]});
}
} catch($e2595825959) {
if(R.isCont($e2595825959)) {
var $ss2596225963 = {"from":L[3836],
"go":function(anf_arg607925969) {
return $Hanf_arg1062425970(anf_arg607925969,_check14717651,anf_arg60777650,body14707653,doc14697654,l14667655,s_DASH_method3742049,self14657656);
}};
$e2595825959.stack[R.EXN_STACKHEIGHT++] = $ss2596225963;
}
if(R.isPyretException($e2595825959)) {
$e2595825959.pyretStack.push(L[3836]);
}
throw $e2595825959;
}
var $ret2596425965 = $Hanf_arg1062425970($z2596025961,_check14717651,anf_arg60777650,body14707653,doc14697654,l14667655,s_DASH_method3742049,self14657656);
++R.GAS;
return $ret2596425965;
};
var $Hanf_arg1062425970 = function(anf_arg607925969,_check14717651,anf_arg60777650,body14707653,doc14697654,l14667655,s_DASH_method3742049,self14657656) {
var anf_fun608025981 = G(body14707653,"visit",L[3839]);
var $z2597325974 = D;
var $f2597925980 = function(_) {
return R.isFunction(anf_fun608025981)?anf_fun608025981.app(self14657656):R.ffi.throwNonFunApp(L[3838],anf_fun608025981,[self14657656]);
};
try {
if(--R.GAS > 0) {
$z2597325974 = $f2597925980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2597925980,
"from":L[3838]});
}
} catch($e2597125972) {
if(R.isCont($e2597125972)) {
var $ss2597525976 = {"from":L[3838],
"go":function(anf_arg608125982) {
return $Hanf_arg1062325983(anf_arg608125982,_check14717651,anf_arg60777650,anf_arg607925969,doc14697654,l14667655,s_DASH_method3742049,self14657656);
}};
$e2597125972.stack[R.EXN_STACKHEIGHT++] = $ss2597525976;
}
if(R.isPyretException($e2597125972)) {
$e2597125972.pyretStack.push(L[3838]);
}
throw $e2597125972;
}
var $ret2597725978 = $Hanf_arg1062325983($z2597325974,_check14717651,anf_arg60777650,anf_arg607925969,doc14697654,l14667655,s_DASH_method3742049,self14657656);
++R.GAS;
return $ret2597725978;
};
var $Hanf_arg1062325983 = function(anf_arg608125982,_check14717651,anf_arg60777650,anf_arg607925969,doc14697654,l14667655,s_DASH_method3742049,self14657656) {
var anf_fun608225994 = G(self14657656,"option",L[3841]);
var $z2598625987 = D;
var $f2599225993 = function(_) {
return R.isFunction(anf_fun608225994)?anf_fun608225994.app(_check14717651):R.ffi.throwNonFunApp(L[3840],anf_fun608225994,[_check14717651]);
};
try {
if(--R.GAS > 0) {
$z2598625987 = $f2599225993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2599225993,
"from":L[3840]});
}
} catch($e2598425985) {
if(R.isCont($e2598425985)) {
var $ss2598825989 = {"from":L[3840],
"go":function(anf_arg608325995) {
return $Hanf_arg1062225996(anf_arg608325995,anf_arg60777650,anf_arg607925969,anf_arg608125982,doc14697654,l14667655,s_DASH_method3742049);
}};
$e2598425985.stack[R.EXN_STACKHEIGHT++] = $ss2598825989;
}
if(R.isPyretException($e2598425985)) {
$e2598425985.pyretStack.push(L[3840]);
}
throw $e2598425985;
}
var $ret2599025991 = $Hanf_arg1062225996($z2598625987,anf_arg60777650,anf_arg607925969,anf_arg608125982,doc14697654,l14667655,s_DASH_method3742049);
++R.GAS;
return $ret2599025991;
};
var $Hanf_arg1062225996 = function(anf_arg608325995,anf_arg60777650,anf_arg607925969,anf_arg608125982,doc14697654,l14667655,s_DASH_method3742049) {
var $z2599926000 = D;
var $f2600526006 = function(_) {
return R.isFunction(s_DASH_method3742049.$var)?s_DASH_method3742049.$var.app(l14667655,anf_arg60777650,anf_arg607925969,doc14697654,anf_arg608125982,anf_arg608325995):R.ffi.throwNonFunApp(L[1487],s_DASH_method3742049.$var,[l14667655,anf_arg60777650,anf_arg607925969,doc14697654,anf_arg608125982,anf_arg608325995]);
};
try {
if(--R.GAS > 0) {
$z2599926000 = $f2600526006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2600526006,
"from":L[1487]});
}
} catch($e2599725998) {
if(R.isCont($e2599725998)) {
var $ss2600126002 = {"from":L[1487],
"go":function(ann_DASH_check_DASH_temp607226007) {
return $Hann_DASH_check_DASH_temp1062126008(ann_DASH_check_DASH_temp607226007);
}};
$e2599725998.stack[R.EXN_STACKHEIGHT++] = $ss2600126002;
}
if(R.isPyretException($e2599725998)) {
$e2599725998.pyretStack.push(L[1487]);
}
throw $e2599725998;
}
var $ret2600326004 = $Hann_DASH_check_DASH_temp1062126008($z2599926000);
++R.GAS;
return $ret2600326004;
};
var $Hann_DASH_check_DASH_temp1062126008 = function(ann_DASH_check_DASH_temp607226007) {
return ann_DASH_check_DASH_temp607226007;
};
var $Hann_DASH_check_DASH_temp106207671 = function(ann_DASH_check_DASH_temp60747670) {
return ann_DASH_check_DASH_temp60747670;
};
var $Hanf_arg106197693 = function(anf_arg60597685,_check14647686,ann14617687,args14607688,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692) {
var anf_fun606026019 = G(args14607688,"map",L[3844]);
var anf_arg606326020 = R.makeFunction(function(recv_DASH_73526023) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3843],1,arguments);
}
var anf_fun606226034 = G(recv_DASH_73526023,"visit",L[3843]);
var $z2602626027 = D;
var $f2603226033 = function(_) {
return R.isFunction(anf_fun606226034)?anf_fun606226034.app(self14577692):R.ffi.throwNonFunApp(L[3843],anf_fun606226034,[self14577692]);
};
try {
if(--R.GAS > 0) {
$z2602626027 = $f2603226033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2603226033,
"from":L[3843]});
}
} catch($e2602426025) {
if(R.isCont($e2602426025)) {
var $ss2602826029 = {"from":L[3843],
"go":function(ann_DASH_check_DASH_temp606126035) {
return $Hann_DASH_check_DASH_temp1061326036(ann_DASH_check_DASH_temp606126035);
}};
$e2602426025.stack[R.EXN_STACKHEIGHT++] = $ss2602826029;
}
if(R.isPyretException($e2602426025)) {
$e2602426025.pyretStack.push(L[3843]);
}
throw $e2602426025;
}
var $ret2603026031 = $Hann_DASH_check_DASH_temp1061326036($z2602626027);
++R.GAS;
return $ret2603026031;
});
var $z2601126012 = D;
var $f2601726018 = function(_) {
return R.isFunction(anf_fun606026019)?anf_fun606026019.app(anf_arg606326020):R.ffi.throwNonFunApp(L[3842],anf_fun606026019,[anf_arg606326020]);
};
try {
if(--R.GAS > 0) {
$z2601126012 = $f2601726018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2601726018,
"from":L[3842]});
}
} catch($e2600926010) {
if(R.isCont($e2600926010)) {
var $ss2601326014 = {"from":L[3842],
"go":function(anf_arg606426021) {
return $Hanf_arg1061826022(anf_arg606426021,_check14647686,anf_arg60597685,ann14617687,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692);
}};
$e2600926010.stack[R.EXN_STACKHEIGHT++] = $ss2601326014;
}
if(R.isPyretException($e2600926010)) {
$e2600926010.pyretStack.push(L[3842]);
}
throw $e2600926010;
}
var $ret2601526016 = $Hanf_arg1061826022($z2601126012,_check14647686,anf_arg60597685,ann14617687,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692);
++R.GAS;
return $ret2601526016;
};
var $Hanf_arg1061826022 = function(anf_arg606426021,_check14647686,anf_arg60597685,ann14617687,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692) {
var anf_fun606526047 = G(ann14617687,"visit",L[3846]);
var $z2603926040 = D;
var $f2604526046 = function(_) {
return R.isFunction(anf_fun606526047)?anf_fun606526047.app(self14577692):R.ffi.throwNonFunApp(L[3845],anf_fun606526047,[self14577692]);
};
try {
if(--R.GAS > 0) {
$z2603926040 = $f2604526046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2604526046,
"from":L[3845]});
}
} catch($e2603726038) {
if(R.isCont($e2603726038)) {
var $ss2604126042 = {"from":L[3845],
"go":function(anf_arg606626048) {
return $Hanf_arg1061726049(anf_arg606626048,_check14647686,anf_arg60597685,anf_arg606426021,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692);
}};
$e2603726038.stack[R.EXN_STACKHEIGHT++] = $ss2604126042;
}
if(R.isPyretException($e2603726038)) {
$e2603726038.pyretStack.push(L[3845]);
}
throw $e2603726038;
}
var $ret2604326044 = $Hanf_arg1061726049($z2603926040,_check14647686,anf_arg60597685,anf_arg606426021,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692);
++R.GAS;
return $ret2604326044;
};
var $Hanf_arg1061726049 = function(anf_arg606626048,_check14647686,anf_arg60597685,anf_arg606426021,body14637689,doc14627690,l14587691,s_DASH_lam3722045,self14577692) {
var anf_fun606726060 = G(body14637689,"visit",L[3848]);
var $z2605226053 = D;
var $f2605826059 = function(_) {
return R.isFunction(anf_fun606726060)?anf_fun606726060.app(self14577692):R.ffi.throwNonFunApp(L[3847],anf_fun606726060,[self14577692]);
};
try {
if(--R.GAS > 0) {
$z2605226053 = $f2605826059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2605826059,
"from":L[3847]});
}
} catch($e2605026051) {
if(R.isCont($e2605026051)) {
var $ss2605426055 = {"from":L[3847],
"go":function(anf_arg606826061) {
return $Hanf_arg1061626062(anf_arg606826061,_check14647686,anf_arg60597685,anf_arg606426021,anf_arg606626048,doc14627690,l14587691,s_DASH_lam3722045,self14577692);
}};
$e2605026051.stack[R.EXN_STACKHEIGHT++] = $ss2605426055;
}
if(R.isPyretException($e2605026051)) {
$e2605026051.pyretStack.push(L[3847]);
}
throw $e2605026051;
}
var $ret2605626057 = $Hanf_arg1061626062($z2605226053,_check14647686,anf_arg60597685,anf_arg606426021,anf_arg606626048,doc14627690,l14587691,s_DASH_lam3722045,self14577692);
++R.GAS;
return $ret2605626057;
};
var $Hanf_arg1061626062 = function(anf_arg606826061,_check14647686,anf_arg60597685,anf_arg606426021,anf_arg606626048,doc14627690,l14587691,s_DASH_lam3722045,self14577692) {
var anf_fun606926073 = G(self14577692,"option",L[3850]);
var $z2606526066 = D;
var $f2607126072 = function(_) {
return R.isFunction(anf_fun606926073)?anf_fun606926073.app(_check14647686):R.ffi.throwNonFunApp(L[3849],anf_fun606926073,[_check14647686]);
};
try {
if(--R.GAS > 0) {
$z2606526066 = $f2607126072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2607126072,
"from":L[3849]});
}
} catch($e2606326064) {
if(R.isCont($e2606326064)) {
var $ss2606726068 = {"from":L[3849],
"go":function(anf_arg607026074) {
return $Hanf_arg1061526075(anf_arg607026074,anf_arg60597685,anf_arg606426021,anf_arg606626048,anf_arg606826061,doc14627690,l14587691,s_DASH_lam3722045);
}};
$e2606326064.stack[R.EXN_STACKHEIGHT++] = $ss2606726068;
}
if(R.isPyretException($e2606326064)) {
$e2606326064.pyretStack.push(L[3849]);
}
throw $e2606326064;
}
var $ret2606926070 = $Hanf_arg1061526075($z2606526066,anf_arg60597685,anf_arg606426021,anf_arg606626048,anf_arg606826061,doc14627690,l14587691,s_DASH_lam3722045);
++R.GAS;
return $ret2606926070;
};
var $Hanf_arg1061526075 = function(anf_arg607026074,anf_arg60597685,anf_arg606426021,anf_arg606626048,anf_arg606826061,doc14627690,l14587691,s_DASH_lam3722045) {
var $z2607826079 = D;
var $f2608426085 = function(_) {
return R.isFunction(s_DASH_lam3722045.$var)?s_DASH_lam3722045.$var.app(l14587691,anf_arg60597685,anf_arg606426021,anf_arg606626048,doc14627690,anf_arg606826061,anf_arg607026074):R.ffi.throwNonFunApp(L[1498],s_DASH_lam3722045.$var,[l14587691,anf_arg60597685,anf_arg606426021,anf_arg606626048,doc14627690,anf_arg606826061,anf_arg607026074]);
};
try {
if(--R.GAS > 0) {
$z2607826079 = $f2608426085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2608426085,
"from":L[1498]});
}
} catch($e2607626077) {
if(R.isCont($e2607626077)) {
var $ss2608026081 = {"from":L[1498],
"go":function(ann_DASH_check_DASH_temp605426086) {
return $Hann_DASH_check_DASH_temp1061426087(ann_DASH_check_DASH_temp605426086);
}};
$e2607626077.stack[R.EXN_STACKHEIGHT++] = $ss2608026081;
}
if(R.isPyretException($e2607626077)) {
$e2607626077.pyretStack.push(L[1498]);
}
throw $e2607626077;
}
var $ret2608226083 = $Hann_DASH_check_DASH_temp1061426087($z2607826079);
++R.GAS;
return $ret2608226083;
};
var $Hann_DASH_check_DASH_temp1061426087 = function(ann_DASH_check_DASH_temp605426086) {
return ann_DASH_check_DASH_temp605426086;
};
var $Hann_DASH_check_DASH_temp1061326036 = function(ann_DASH_check_DASH_temp606126035) {
return ann_DASH_check_DASH_temp606126035;
};
var $Hann_DASH_check_DASH_temp106127707 = function(ann_DASH_check_DASH_temp60567706) {
return ann_DASH_check_DASH_temp60567706;
};
var $Hanf_arg106117723 = function(anf_arg60527721,l14557722,s_DASH_paren3702041) {
var $z2609026091 = D;
var $f2609626097 = function(_) {
return R.isFunction(s_DASH_paren3702041.$var)?s_DASH_paren3702041.$var.app(l14557722,anf_arg60527721):R.ffi.throwNonFunApp(L[1503],s_DASH_paren3702041.$var,[l14557722,anf_arg60527721]);
};
try {
if(--R.GAS > 0) {
$z2609026091 = $f2609626097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2609626097,
"from":L[1503]});
}
} catch($e2608826089) {
if(R.isCont($e2608826089)) {
var $ss2609226093 = {"from":L[1503],
"go":function(ann_DASH_check_DASH_temp605026098) {
return $Hann_DASH_check_DASH_temp1061026099(ann_DASH_check_DASH_temp605026098);
}};
$e2608826089.stack[R.EXN_STACKHEIGHT++] = $ss2609226093;
}
if(R.isPyretException($e2608826089)) {
$e2608826089.pyretStack.push(L[1503]);
}
throw $e2608826089;
}
var $ret2609426095 = $Hann_DASH_check_DASH_temp1061026099($z2609026091);
++R.GAS;
return $ret2609426095;
};
var $Hann_DASH_check_DASH_temp1061026099 = function(ann_DASH_check_DASH_temp605026098) {
return ann_DASH_check_DASH_temp605026098;
};
var $Hanf_arg106097741 = function(anf_arg60467737,l14507738,op14517739,right14537740,s_DASH_check_DASH_test3682037,self14497736) {
var anf_fun604726110 = G(right14537740,"visit",L[3852]);
var $z2610226103 = D;
var $f2610826109 = function(_) {
return R.isFunction(anf_fun604726110)?anf_fun604726110.app(self14497736):R.ffi.throwNonFunApp(L[3851],anf_fun604726110,[self14497736]);
};
try {
if(--R.GAS > 0) {
$z2610226103 = $f2610826109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2610826109,
"from":L[3851]});
}
} catch($e2610026101) {
if(R.isCont($e2610026101)) {
var $ss2610426105 = {"from":L[3851],
"go":function(anf_arg604826111) {
return $Hanf_arg1060826112(anf_arg604826111,anf_arg60467737,l14507738,op14517739,s_DASH_check_DASH_test3682037);
}};
$e2610026101.stack[R.EXN_STACKHEIGHT++] = $ss2610426105;
}
if(R.isPyretException($e2610026101)) {
$e2610026101.pyretStack.push(L[3851]);
}
throw $e2610026101;
}
var $ret2610626107 = $Hanf_arg1060826112($z2610226103,anf_arg60467737,l14507738,op14517739,s_DASH_check_DASH_test3682037);
++R.GAS;
return $ret2610626107;
};
var $Hanf_arg1060826112 = function(anf_arg604826111,anf_arg60467737,l14507738,op14517739,s_DASH_check_DASH_test3682037) {
var $z2611526116 = D;
var $f2612126122 = function(_) {
return R.isFunction(s_DASH_check_DASH_test3682037.$var)?s_DASH_check_DASH_test3682037.$var.app(l14507738,op14517739,anf_arg60467737,anf_arg604826111):R.ffi.throwNonFunApp(L[1510],s_DASH_check_DASH_test3682037.$var,[l14507738,op14517739,anf_arg60467737,anf_arg604826111]);
};
try {
if(--R.GAS > 0) {
$z2611526116 = $f2612126122();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2612126122,
"from":L[1510]});
}
} catch($e2611326114) {
if(R.isCont($e2611326114)) {
var $ss2611726118 = {"from":L[1510],
"go":function(ann_DASH_check_DASH_temp604426123) {
return $Hann_DASH_check_DASH_temp1060726124(ann_DASH_check_DASH_temp604426123);
}};
$e2611326114.stack[R.EXN_STACKHEIGHT++] = $ss2611726118;
}
if(R.isPyretException($e2611326114)) {
$e2611326114.pyretStack.push(L[1510]);
}
throw $e2611326114;
}
var $ret2611926120 = $Hann_DASH_check_DASH_temp1060726124($z2611526116);
++R.GAS;
return $ret2611926120;
};
var $Hann_DASH_check_DASH_temp1060726124 = function(ann_DASH_check_DASH_temp604426123) {
return ann_DASH_check_DASH_temp604426123;
};
var $Hanf_arg106067759 = function(anf_arg60407755,l14457756,op14467757,right14487758,s_DASH_op3662033,self14447754) {
var anf_fun604126135 = G(right14487758,"visit",L[3854]);
var $z2612726128 = D;
var $f2613326134 = function(_) {
return R.isFunction(anf_fun604126135)?anf_fun604126135.app(self14447754):R.ffi.throwNonFunApp(L[3853],anf_fun604126135,[self14447754]);
};
try {
if(--R.GAS > 0) {
$z2612726128 = $f2613326134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2613326134,
"from":L[3853]});
}
} catch($e2612526126) {
if(R.isCont($e2612526126)) {
var $ss2612926130 = {"from":L[3853],
"go":function(anf_arg604226136) {
return $Hanf_arg1060526137(anf_arg604226136,anf_arg60407755,l14457756,op14467757,s_DASH_op3662033);
}};
$e2612526126.stack[R.EXN_STACKHEIGHT++] = $ss2612926130;
}
if(R.isPyretException($e2612526126)) {
$e2612526126.pyretStack.push(L[3853]);
}
throw $e2612526126;
}
var $ret2613126132 = $Hanf_arg1060526137($z2612726128,anf_arg60407755,l14457756,op14467757,s_DASH_op3662033);
++R.GAS;
return $ret2613126132;
};
var $Hanf_arg1060526137 = function(anf_arg604226136,anf_arg60407755,l14457756,op14467757,s_DASH_op3662033) {
var $z2614026141 = D;
var $f2614626147 = function(_) {
return R.isFunction(s_DASH_op3662033.$var)?s_DASH_op3662033.$var.app(l14457756,op14467757,anf_arg60407755,anf_arg604226136):R.ffi.throwNonFunApp(L[1517],s_DASH_op3662033.$var,[l14457756,op14467757,anf_arg60407755,anf_arg604226136]);
};
try {
if(--R.GAS > 0) {
$z2614026141 = $f2614626147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2614626147,
"from":L[1517]});
}
} catch($e2613826139) {
if(R.isCont($e2613826139)) {
var $ss2614226143 = {"from":L[1517],
"go":function(ann_DASH_check_DASH_temp603826148) {
return $Hann_DASH_check_DASH_temp1060426149(ann_DASH_check_DASH_temp603826148);
}};
$e2613826139.stack[R.EXN_STACKHEIGHT++] = $ss2614226143;
}
if(R.isPyretException($e2613826139)) {
$e2613826139.pyretStack.push(L[1517]);
}
throw $e2613826139;
}
var $ret2614426145 = $Hann_DASH_check_DASH_temp1060426149($z2614026141);
++R.GAS;
return $ret2614426145;
};
var $Hann_DASH_check_DASH_temp1060426149 = function(ann_DASH_check_DASH_temp603826148) {
return ann_DASH_check_DASH_temp603826148;
};
var $Hanf_arg106037777 = function(anf_arg60327773,_except14437774,id14427775,l14407776,s_DASH_try3642029,self14397772) {
var anf_fun603326160 = G(id14427775,"visit",L[3856]);
var $z2615226153 = D;
var $f2615826159 = function(_) {
return R.isFunction(anf_fun603326160)?anf_fun603326160.app(self14397772):R.ffi.throwNonFunApp(L[3855],anf_fun603326160,[self14397772]);
};
try {
if(--R.GAS > 0) {
$z2615226153 = $f2615826159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2615826159,
"from":L[3855]});
}
} catch($e2615026151) {
if(R.isCont($e2615026151)) {
var $ss2615426155 = {"from":L[3855],
"go":function(anf_arg603426161) {
return $Hanf_arg1060226162(anf_arg603426161,_except14437774,anf_arg60327773,l14407776,s_DASH_try3642029,self14397772);
}};
$e2615026151.stack[R.EXN_STACKHEIGHT++] = $ss2615426155;
}
if(R.isPyretException($e2615026151)) {
$e2615026151.pyretStack.push(L[3855]);
}
throw $e2615026151;
}
var $ret2615626157 = $Hanf_arg1060226162($z2615226153,_except14437774,anf_arg60327773,l14407776,s_DASH_try3642029,self14397772);
++R.GAS;
return $ret2615626157;
};
var $Hanf_arg1060226162 = function(anf_arg603426161,_except14437774,anf_arg60327773,l14407776,s_DASH_try3642029,self14397772) {
var anf_fun603526173 = G(_except14437774,"visit",L[3858]);
var $z2616526166 = D;
var $f2617126172 = function(_) {
return R.isFunction(anf_fun603526173)?anf_fun603526173.app(self14397772):R.ffi.throwNonFunApp(L[3857],anf_fun603526173,[self14397772]);
};
try {
if(--R.GAS > 0) {
$z2616526166 = $f2617126172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2617126172,
"from":L[3857]});
}
} catch($e2616326164) {
if(R.isCont($e2616326164)) {
var $ss2616726168 = {"from":L[3857],
"go":function(anf_arg603626174) {
return $Hanf_arg1060126175(anf_arg603626174,anf_arg60327773,anf_arg603426161,l14407776,s_DASH_try3642029);
}};
$e2616326164.stack[R.EXN_STACKHEIGHT++] = $ss2616726168;
}
if(R.isPyretException($e2616326164)) {
$e2616326164.pyretStack.push(L[3857]);
}
throw $e2616326164;
}
var $ret2616926170 = $Hanf_arg1060126175($z2616526166,anf_arg60327773,anf_arg603426161,l14407776,s_DASH_try3642029);
++R.GAS;
return $ret2616926170;
};
var $Hanf_arg1060126175 = function(anf_arg603626174,anf_arg60327773,anf_arg603426161,l14407776,s_DASH_try3642029) {
var $z2617826179 = D;
var $f2618426185 = function(_) {
return R.isFunction(s_DASH_try3642029.$var)?s_DASH_try3642029.$var.app(l14407776,anf_arg60327773,anf_arg603426161,anf_arg603626174):R.ffi.throwNonFunApp(L[1524],s_DASH_try3642029.$var,[l14407776,anf_arg60327773,anf_arg603426161,anf_arg603626174]);
};
try {
if(--R.GAS > 0) {
$z2617826179 = $f2618426185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2618426185,
"from":L[1524]});
}
} catch($e2617626177) {
if(R.isCont($e2617626177)) {
var $ss2618026181 = {"from":L[1524],
"go":function(ann_DASH_check_DASH_temp603026186) {
return $Hann_DASH_check_DASH_temp1060026187(ann_DASH_check_DASH_temp603026186);
}};
$e2617626177.stack[R.EXN_STACKHEIGHT++] = $ss2618026181;
}
if(R.isPyretException($e2617626177)) {
$e2617626177.pyretStack.push(L[1524]);
}
throw $e2617626177;
}
var $ret2618226183 = $Hann_DASH_check_DASH_temp1060026187($z2617826179);
++R.GAS;
return $ret2618226183;
};
var $Hann_DASH_check_DASH_temp1060026187 = function(ann_DASH_check_DASH_temp603026186) {
return ann_DASH_check_DASH_temp603026186;
};
var $Hanf_arg105997796 = function(anf_arg60197791,_else14387792,branches14377793,l14347794,s_DASH_cases_DASH_else3622025,self14337790,val14367795) {
var anf_fun602026198 = G(val14367795,"visit",L[3860]);
var $z2619026191 = D;
var $f2619626197 = function(_) {
return R.isFunction(anf_fun602026198)?anf_fun602026198.app(self14337790):R.ffi.throwNonFunApp(L[3859],anf_fun602026198,[self14337790]);
};
try {
if(--R.GAS > 0) {
$z2619026191 = $f2619626197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2619626197,
"from":L[3859]});
}
} catch($e2618826189) {
if(R.isCont($e2618826189)) {
var $ss2619226193 = {"from":L[3859],
"go":function(anf_arg602126199) {
return $Hanf_arg1059826200(anf_arg602126199,_else14387792,anf_arg60197791,branches14377793,l14347794,s_DASH_cases_DASH_else3622025,self14337790);
}};
$e2618826189.stack[R.EXN_STACKHEIGHT++] = $ss2619226193;
}
if(R.isPyretException($e2618826189)) {
$e2618826189.pyretStack.push(L[3859]);
}
throw $e2618826189;
}
var $ret2619426195 = $Hanf_arg1059826200($z2619026191,_else14387792,anf_arg60197791,branches14377793,l14347794,s_DASH_cases_DASH_else3622025,self14337790);
++R.GAS;
return $ret2619426195;
};
var $Hanf_arg1059826200 = function(anf_arg602126199,_else14387792,anf_arg60197791,branches14377793,l14347794,s_DASH_cases_DASH_else3622025,self14337790) {
var anf_fun602226211 = G(branches14377793,"map",L[3863]);
var anf_arg602526212 = R.makeFunction(function(recv_DASH_73326215) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3862],1,arguments);
}
var anf_fun602426226 = G(recv_DASH_73326215,"visit",L[3862]);
var $z2621826219 = D;
var $f2622426225 = function(_) {
return R.isFunction(anf_fun602426226)?anf_fun602426226.app(self14337790):R.ffi.throwNonFunApp(L[3862],anf_fun602426226,[self14337790]);
};
try {
if(--R.GAS > 0) {
$z2621826219 = $f2622426225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2622426225,
"from":L[3862]});
}
} catch($e2621626217) {
if(R.isCont($e2621626217)) {
var $ss2622026221 = {"from":L[3862],
"go":function(ann_DASH_check_DASH_temp602326227) {
return $Hann_DASH_check_DASH_temp1059426228(ann_DASH_check_DASH_temp602326227);
}};
$e2621626217.stack[R.EXN_STACKHEIGHT++] = $ss2622026221;
}
if(R.isPyretException($e2621626217)) {
$e2621626217.pyretStack.push(L[3862]);
}
throw $e2621626217;
}
var $ret2622226223 = $Hann_DASH_check_DASH_temp1059426228($z2621826219);
++R.GAS;
return $ret2622226223;
});
var $z2620326204 = D;
var $f2620926210 = function(_) {
return R.isFunction(anf_fun602226211)?anf_fun602226211.app(anf_arg602526212):R.ffi.throwNonFunApp(L[3861],anf_fun602226211,[anf_arg602526212]);
};
try {
if(--R.GAS > 0) {
$z2620326204 = $f2620926210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2620926210,
"from":L[3861]});
}
} catch($e2620126202) {
if(R.isCont($e2620126202)) {
var $ss2620526206 = {"from":L[3861],
"go":function(anf_arg602626213) {
return $Hanf_arg1059726214(anf_arg602626213,_else14387792,anf_arg60197791,anf_arg602126199,l14347794,s_DASH_cases_DASH_else3622025,self14337790);
}};
$e2620126202.stack[R.EXN_STACKHEIGHT++] = $ss2620526206;
}
if(R.isPyretException($e2620126202)) {
$e2620126202.pyretStack.push(L[3861]);
}
throw $e2620126202;
}
var $ret2620726208 = $Hanf_arg1059726214($z2620326204,_else14387792,anf_arg60197791,anf_arg602126199,l14347794,s_DASH_cases_DASH_else3622025,self14337790);
++R.GAS;
return $ret2620726208;
};
var $Hanf_arg1059726214 = function(anf_arg602626213,_else14387792,anf_arg60197791,anf_arg602126199,l14347794,s_DASH_cases_DASH_else3622025,self14337790) {
var anf_fun602726239 = G(_else14387792,"visit",L[3865]);
var $z2623126232 = D;
var $f2623726238 = function(_) {
return R.isFunction(anf_fun602726239)?anf_fun602726239.app(self14337790):R.ffi.throwNonFunApp(L[3864],anf_fun602726239,[self14337790]);
};
try {
if(--R.GAS > 0) {
$z2623126232 = $f2623726238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2623726238,
"from":L[3864]});
}
} catch($e2622926230) {
if(R.isCont($e2622926230)) {
var $ss2623326234 = {"from":L[3864],
"go":function(anf_arg602826240) {
return $Hanf_arg1059626241(anf_arg602826240,anf_arg60197791,anf_arg602126199,anf_arg602626213,l14347794,s_DASH_cases_DASH_else3622025);
}};
$e2622926230.stack[R.EXN_STACKHEIGHT++] = $ss2623326234;
}
if(R.isPyretException($e2622926230)) {
$e2622926230.pyretStack.push(L[3864]);
}
throw $e2622926230;
}
var $ret2623526236 = $Hanf_arg1059626241($z2623126232,anf_arg60197791,anf_arg602126199,anf_arg602626213,l14347794,s_DASH_cases_DASH_else3622025);
++R.GAS;
return $ret2623526236;
};
var $Hanf_arg1059626241 = function(anf_arg602826240,anf_arg60197791,anf_arg602126199,anf_arg602626213,l14347794,s_DASH_cases_DASH_else3622025) {
var $z2624426245 = D;
var $f2625026251 = function(_) {
return R.isFunction(s_DASH_cases_DASH_else3622025.$var)?s_DASH_cases_DASH_else3622025.$var.app(l14347794,anf_arg60197791,anf_arg602126199,anf_arg602626213,anf_arg602826240):R.ffi.throwNonFunApp(L[1532],s_DASH_cases_DASH_else3622025.$var,[l14347794,anf_arg60197791,anf_arg602126199,anf_arg602626213,anf_arg602826240]);
};
try {
if(--R.GAS > 0) {
$z2624426245 = $f2625026251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2625026251,
"from":L[1532]});
}
} catch($e2624226243) {
if(R.isCont($e2624226243)) {
var $ss2624626247 = {"from":L[1532],
"go":function(ann_DASH_check_DASH_temp601726252) {
return $Hann_DASH_check_DASH_temp1059526253(ann_DASH_check_DASH_temp601726252);
}};
$e2624226243.stack[R.EXN_STACKHEIGHT++] = $ss2624626247;
}
if(R.isPyretException($e2624226243)) {
$e2624226243.pyretStack.push(L[1532]);
}
throw $e2624226243;
}
var $ret2624826249 = $Hann_DASH_check_DASH_temp1059526253($z2624426245);
++R.GAS;
return $ret2624826249;
};
var $Hann_DASH_check_DASH_temp1059526253 = function(ann_DASH_check_DASH_temp601726252) {
return ann_DASH_check_DASH_temp601726252;
};
var $Hann_DASH_check_DASH_temp1059426228 = function(ann_DASH_check_DASH_temp602326227) {
return ann_DASH_check_DASH_temp602326227;
};
var $Hanf_arg105937814 = function(anf_arg60087810,branches14327811,l14297812,s_DASH_cases3602021,self14287809,val14317813) {
var anf_fun600926264 = G(val14317813,"visit",L[3867]);
var $z2625626257 = D;
var $f2626226263 = function(_) {
return R.isFunction(anf_fun600926264)?anf_fun600926264.app(self14287809):R.ffi.throwNonFunApp(L[3866],anf_fun600926264,[self14287809]);
};
try {
if(--R.GAS > 0) {
$z2625626257 = $f2626226263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2626226263,
"from":L[3866]});
}
} catch($e2625426255) {
if(R.isCont($e2625426255)) {
var $ss2625826259 = {"from":L[3866],
"go":function(anf_arg601026265) {
return $Hanf_arg1059226266(anf_arg601026265,anf_arg60087810,branches14327811,l14297812,s_DASH_cases3602021,self14287809);
}};
$e2625426255.stack[R.EXN_STACKHEIGHT++] = $ss2625826259;
}
if(R.isPyretException($e2625426255)) {
$e2625426255.pyretStack.push(L[3866]);
}
throw $e2625426255;
}
var $ret2626026261 = $Hanf_arg1059226266($z2625626257,anf_arg60087810,branches14327811,l14297812,s_DASH_cases3602021,self14287809);
++R.GAS;
return $ret2626026261;
};
var $Hanf_arg1059226266 = function(anf_arg601026265,anf_arg60087810,branches14327811,l14297812,s_DASH_cases3602021,self14287809) {
var anf_fun601126277 = G(branches14327811,"map",L[3870]);
var anf_arg601426278 = R.makeFunction(function(recv_DASH_73226281) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3869],1,arguments);
}
var anf_fun601326292 = G(recv_DASH_73226281,"visit",L[3869]);
var $z2628426285 = D;
var $f2629026291 = function(_) {
return R.isFunction(anf_fun601326292)?anf_fun601326292.app(self14287809):R.ffi.throwNonFunApp(L[3869],anf_fun601326292,[self14287809]);
};
try {
if(--R.GAS > 0) {
$z2628426285 = $f2629026291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2629026291,
"from":L[3869]});
}
} catch($e2628226283) {
if(R.isCont($e2628226283)) {
var $ss2628626287 = {"from":L[3869],
"go":function(ann_DASH_check_DASH_temp601226293) {
return $Hann_DASH_check_DASH_temp1058926294(ann_DASH_check_DASH_temp601226293);
}};
$e2628226283.stack[R.EXN_STACKHEIGHT++] = $ss2628626287;
}
if(R.isPyretException($e2628226283)) {
$e2628226283.pyretStack.push(L[3869]);
}
throw $e2628226283;
}
var $ret2628826289 = $Hann_DASH_check_DASH_temp1058926294($z2628426285);
++R.GAS;
return $ret2628826289;
});
var $z2626926270 = D;
var $f2627526276 = function(_) {
return R.isFunction(anf_fun601126277)?anf_fun601126277.app(anf_arg601426278):R.ffi.throwNonFunApp(L[3868],anf_fun601126277,[anf_arg601426278]);
};
try {
if(--R.GAS > 0) {
$z2626926270 = $f2627526276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2627526276,
"from":L[3868]});
}
} catch($e2626726268) {
if(R.isCont($e2626726268)) {
var $ss2627126272 = {"from":L[3868],
"go":function(anf_arg601526279) {
return $Hanf_arg1059126280(anf_arg601526279,anf_arg60087810,anf_arg601026265,l14297812,s_DASH_cases3602021);
}};
$e2626726268.stack[R.EXN_STACKHEIGHT++] = $ss2627126272;
}
if(R.isPyretException($e2626726268)) {
$e2626726268.pyretStack.push(L[3868]);
}
throw $e2626726268;
}
var $ret2627326274 = $Hanf_arg1059126280($z2626926270,anf_arg60087810,anf_arg601026265,l14297812,s_DASH_cases3602021);
++R.GAS;
return $ret2627326274;
};
var $Hanf_arg1059126280 = function(anf_arg601526279,anf_arg60087810,anf_arg601026265,l14297812,s_DASH_cases3602021) {
var $z2629726298 = D;
var $f2630326304 = function(_) {
return R.isFunction(s_DASH_cases3602021.$var)?s_DASH_cases3602021.$var.app(l14297812,anf_arg60087810,anf_arg601026265,anf_arg601526279):R.ffi.throwNonFunApp(L[1539],s_DASH_cases3602021.$var,[l14297812,anf_arg60087810,anf_arg601026265,anf_arg601526279]);
};
try {
if(--R.GAS > 0) {
$z2629726298 = $f2630326304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2630326304,
"from":L[1539]});
}
} catch($e2629526296) {
if(R.isCont($e2629526296)) {
var $ss2629926300 = {"from":L[1539],
"go":function(ann_DASH_check_DASH_temp600626305) {
return $Hann_DASH_check_DASH_temp1059026306(ann_DASH_check_DASH_temp600626305);
}};
$e2629526296.stack[R.EXN_STACKHEIGHT++] = $ss2629926300;
}
if(R.isPyretException($e2629526296)) {
$e2629526296.pyretStack.push(L[1539]);
}
throw $e2629526296;
}
var $ret2630126302 = $Hann_DASH_check_DASH_temp1059026306($z2629726298);
++R.GAS;
return $ret2630126302;
};
var $Hann_DASH_check_DASH_temp1059026306 = function(ann_DASH_check_DASH_temp600626305) {
return ann_DASH_check_DASH_temp600626305;
};
var $Hann_DASH_check_DASH_temp1058926294 = function(ann_DASH_check_DASH_temp601226293) {
return ann_DASH_check_DASH_temp601226293;
};
var $Hanf_arg105887833 = function(anf_arg60027828,body14277829,l14247830,name14257831,s_DASH_cases_DASH_branch5022305,self14237832) {
var anf_fun600326317 = G(body14277829,"visit",L[3872]);
var $z2630926310 = D;
var $f2631526316 = function(_) {
return R.isFunction(anf_fun600326317)?anf_fun600326317.app(self14237832):R.ffi.throwNonFunApp(L[3871],anf_fun600326317,[self14237832]);
};
try {
if(--R.GAS > 0) {
$z2630926310 = $f2631526316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2631526316,
"from":L[3871]});
}
} catch($e2630726308) {
if(R.isCont($e2630726308)) {
var $ss2631126312 = {"from":L[3871],
"go":function(anf_arg600426318) {
return $Hanf_arg1058726319(anf_arg600426318,anf_arg60027828,l14247830,name14257831,s_DASH_cases_DASH_branch5022305);
}};
$e2630726308.stack[R.EXN_STACKHEIGHT++] = $ss2631126312;
}
if(R.isPyretException($e2630726308)) {
$e2630726308.pyretStack.push(L[3871]);
}
throw $e2630726308;
}
var $ret2631326314 = $Hanf_arg1058726319($z2630926310,anf_arg60027828,l14247830,name14257831,s_DASH_cases_DASH_branch5022305);
++R.GAS;
return $ret2631326314;
};
var $Hanf_arg1058726319 = function(anf_arg600426318,anf_arg60027828,l14247830,name14257831,s_DASH_cases_DASH_branch5022305) {
var $z2632226323 = D;
var $f2632826329 = function(_) {
return R.isFunction(s_DASH_cases_DASH_branch5022305.$var)?s_DASH_cases_DASH_branch5022305.$var.app(l14247830,name14257831,anf_arg60027828,anf_arg600426318):R.ffi.throwNonFunApp(L[1547],s_DASH_cases_DASH_branch5022305.$var,[l14247830,name14257831,anf_arg60027828,anf_arg600426318]);
};
try {
if(--R.GAS > 0) {
$z2632226323 = $f2632826329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2632826329,
"from":L[1547]});
}
} catch($e2632026321) {
if(R.isCont($e2632026321)) {
var $ss2632426325 = {"from":L[1547],
"go":function(ann_DASH_check_DASH_temp599726330) {
return $Hann_DASH_check_DASH_temp1058626331(ann_DASH_check_DASH_temp599726330);
}};
$e2632026321.stack[R.EXN_STACKHEIGHT++] = $ss2632426325;
}
if(R.isPyretException($e2632026321)) {
$e2632026321.pyretStack.push(L[1547]);
}
throw $e2632026321;
}
var $ret2632626327 = $Hann_DASH_check_DASH_temp1058626331($z2632226323);
++R.GAS;
return $ret2632626327;
};
var $Hann_DASH_check_DASH_temp1058626331 = function(ann_DASH_check_DASH_temp599726330) {
return ann_DASH_check_DASH_temp599726330;
};
var $Hann_DASH_check_DASH_temp105857847 = function(ann_DASH_check_DASH_temp59997846) {
return ann_DASH_check_DASH_temp59997846;
};
var $Hanf_arg105847865 = function(anf_arg59937861,_else14227862,l14207863,s_DASH_if_DASH_pipe_DASH_else3542009,self14197864) {
var anf_fun599426342 = G(_else14227862,"visit",L[3874]);
var $z2633426335 = D;
var $f2634026341 = function(_) {
return R.isFunction(anf_fun599426342)?anf_fun599426342.app(self14197864):R.ffi.throwNonFunApp(L[3873],anf_fun599426342,[self14197864]);
};
try {
if(--R.GAS > 0) {
$z2633426335 = $f2634026341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2634026341,
"from":L[3873]});
}
} catch($e2633226333) {
if(R.isCont($e2633226333)) {
var $ss2633626337 = {"from":L[3873],
"go":function(anf_arg599526343) {
return $Hanf_arg1058326344(anf_arg599526343,anf_arg59937861,l14207863,s_DASH_if_DASH_pipe_DASH_else3542009);
}};
$e2633226333.stack[R.EXN_STACKHEIGHT++] = $ss2633626337;
}
if(R.isPyretException($e2633226333)) {
$e2633226333.pyretStack.push(L[3873]);
}
throw $e2633226333;
}
var $ret2633826339 = $Hanf_arg1058326344($z2633426335,anf_arg59937861,l14207863,s_DASH_if_DASH_pipe_DASH_else3542009);
++R.GAS;
return $ret2633826339;
};
var $Hanf_arg1058326344 = function(anf_arg599526343,anf_arg59937861,l14207863,s_DASH_if_DASH_pipe_DASH_else3542009) {
var $z2634726348 = D;
var $f2635326354 = function(_) {
return R.isFunction(s_DASH_if_DASH_pipe_DASH_else3542009.$var)?s_DASH_if_DASH_pipe_DASH_else3542009.$var.app(l14207863,anf_arg59937861,anf_arg599526343):R.ffi.throwNonFunApp(L[1554],s_DASH_if_DASH_pipe_DASH_else3542009.$var,[l14207863,anf_arg59937861,anf_arg599526343]);
};
try {
if(--R.GAS > 0) {
$z2634726348 = $f2635326354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2635326354,
"from":L[1554]});
}
} catch($e2634526346) {
if(R.isCont($e2634526346)) {
var $ss2634926350 = {"from":L[1554],
"go":function(ann_DASH_check_DASH_temp598826355) {
return $Hann_DASH_check_DASH_temp1058226356(ann_DASH_check_DASH_temp598826355);
}};
$e2634526346.stack[R.EXN_STACKHEIGHT++] = $ss2634926350;
}
if(R.isPyretException($e2634526346)) {
$e2634526346.pyretStack.push(L[1554]);
}
throw $e2634526346;
}
var $ret2635126352 = $Hann_DASH_check_DASH_temp1058226356($z2634726348);
++R.GAS;
return $ret2635126352;
};
var $Hann_DASH_check_DASH_temp1058226356 = function(ann_DASH_check_DASH_temp598826355) {
return ann_DASH_check_DASH_temp598826355;
};
var $Hann_DASH_check_DASH_temp105817879 = function(ann_DASH_check_DASH_temp59907878) {
return ann_DASH_check_DASH_temp59907878;
};
var $Hanf_arg105807895 = function(anf_arg59867893,l14177894,s_DASH_if_DASH_pipe3522005) {
var $z2635926360 = D;
var $f2636526366 = function(_) {
return R.isFunction(s_DASH_if_DASH_pipe3522005.$var)?s_DASH_if_DASH_pipe3522005.$var.app(l14177894,anf_arg59867893):R.ffi.throwNonFunApp(L[1560],s_DASH_if_DASH_pipe3522005.$var,[l14177894,anf_arg59867893]);
};
try {
if(--R.GAS > 0) {
$z2635926360 = $f2636526366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2636526366,
"from":L[1560]});
}
} catch($e2635726358) {
if(R.isCont($e2635726358)) {
var $ss2636126362 = {"from":L[1560],
"go":function(ann_DASH_check_DASH_temp598126367) {
return $Hann_DASH_check_DASH_temp1057926368(ann_DASH_check_DASH_temp598126367);
}};
$e2635726358.stack[R.EXN_STACKHEIGHT++] = $ss2636126362;
}
if(R.isPyretException($e2635726358)) {
$e2635726358.pyretStack.push(L[1560]);
}
throw $e2635726358;
}
var $ret2636326364 = $Hann_DASH_check_DASH_temp1057926368($z2635926360);
++R.GAS;
return $ret2636326364;
};
var $Hann_DASH_check_DASH_temp1057926368 = function(ann_DASH_check_DASH_temp598126367) {
return ann_DASH_check_DASH_temp598126367;
};
var $Hann_DASH_check_DASH_temp105787910 = function(ann_DASH_check_DASH_temp59837909) {
return ann_DASH_check_DASH_temp59837909;
};
var $Hanf_arg105777928 = function(anf_arg59777924,_else14157925,l14137926,s_DASH_if_DASH_else3582017,self14127927) {
var anf_fun597826379 = G(_else14157925,"visit",L[3876]);
var $z2637126372 = D;
var $f2637726378 = function(_) {
return R.isFunction(anf_fun597826379)?anf_fun597826379.app(self14127927):R.ffi.throwNonFunApp(L[3875],anf_fun597826379,[self14127927]);
};
try {
if(--R.GAS > 0) {
$z2637126372 = $f2637726378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2637726378,
"from":L[3875]});
}
} catch($e2636926370) {
if(R.isCont($e2636926370)) {
var $ss2637326374 = {"from":L[3875],
"go":function(anf_arg597926380) {
return $Hanf_arg1057626381(anf_arg597926380,anf_arg59777924,l14137926,s_DASH_if_DASH_else3582017);
}};
$e2636926370.stack[R.EXN_STACKHEIGHT++] = $ss2637326374;
}
if(R.isPyretException($e2636926370)) {
$e2636926370.pyretStack.push(L[3875]);
}
throw $e2636926370;
}
var $ret2637526376 = $Hanf_arg1057626381($z2637126372,anf_arg59777924,l14137926,s_DASH_if_DASH_else3582017);
++R.GAS;
return $ret2637526376;
};
var $Hanf_arg1057626381 = function(anf_arg597926380,anf_arg59777924,l14137926,s_DASH_if_DASH_else3582017) {
var $z2638426385 = D;
var $f2639026391 = function(_) {
return R.isFunction(s_DASH_if_DASH_else3582017.$var)?s_DASH_if_DASH_else3582017.$var.app(l14137926,anf_arg59777924,anf_arg597926380):R.ffi.throwNonFunApp(L[1567],s_DASH_if_DASH_else3582017.$var,[l14137926,anf_arg59777924,anf_arg597926380]);
};
try {
if(--R.GAS > 0) {
$z2638426385 = $f2639026391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2639026391,
"from":L[1567]});
}
} catch($e2638226383) {
if(R.isCont($e2638226383)) {
var $ss2638626387 = {"from":L[1567],
"go":function(ann_DASH_check_DASH_temp597226392) {
return $Hann_DASH_check_DASH_temp1057526393(ann_DASH_check_DASH_temp597226392);
}};
$e2638226383.stack[R.EXN_STACKHEIGHT++] = $ss2638626387;
}
if(R.isPyretException($e2638226383)) {
$e2638226383.pyretStack.push(L[1567]);
}
throw $e2638226383;
}
var $ret2638826389 = $Hann_DASH_check_DASH_temp1057526393($z2638426385);
++R.GAS;
return $ret2638826389;
};
var $Hann_DASH_check_DASH_temp1057526393 = function(ann_DASH_check_DASH_temp597226392) {
return ann_DASH_check_DASH_temp597226392;
};
var $Hann_DASH_check_DASH_temp105747942 = function(ann_DASH_check_DASH_temp59747941) {
return ann_DASH_check_DASH_temp59747941;
};
var $Hanf_arg105737958 = function(anf_arg59707956,l14107957,s_DASH_if3562013) {
var $z2639626397 = D;
var $f2640226403 = function(_) {
return R.isFunction(s_DASH_if3562013.$var)?s_DASH_if3562013.$var.app(l14107957,anf_arg59707956):R.ffi.throwNonFunApp(L[1573],s_DASH_if3562013.$var,[l14107957,anf_arg59707956]);
};
try {
if(--R.GAS > 0) {
$z2639626397 = $f2640226403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2640226403,
"from":L[1573]});
}
} catch($e2639426395) {
if(R.isCont($e2639426395)) {
var $ss2639826399 = {"from":L[1573],
"go":function(ann_DASH_check_DASH_temp596526404) {
return $Hann_DASH_check_DASH_temp1057226405(ann_DASH_check_DASH_temp596526404);
}};
$e2639426395.stack[R.EXN_STACKHEIGHT++] = $ss2639826399;
}
if(R.isPyretException($e2639426395)) {
$e2639426395.pyretStack.push(L[1573]);
}
throw $e2639426395;
}
var $ret2640026401 = $Hann_DASH_check_DASH_temp1057226405($z2639626397);
++R.GAS;
return $ret2640026401;
};
var $Hann_DASH_check_DASH_temp1057226405 = function(ann_DASH_check_DASH_temp596526404) {
return ann_DASH_check_DASH_temp596526404;
};
var $Hann_DASH_check_DASH_temp105717973 = function(ann_DASH_check_DASH_temp59677972) {
return ann_DASH_check_DASH_temp59677972;
};
var $Hanf_arg105707990 = function(anf_arg59617987,body14087988,l14067989,s_DASH_if_DASH_pipe_DASH_branch4972295,self14057986) {
var anf_fun596226416 = G(body14087988,"visit",L[3878]);
var $z2640826409 = D;
var $f2641426415 = function(_) {
return R.isFunction(anf_fun596226416)?anf_fun596226416.app(self14057986):R.ffi.throwNonFunApp(L[3877],anf_fun596226416,[self14057986]);
};
try {
if(--R.GAS > 0) {
$z2640826409 = $f2641426415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2641426415,
"from":L[3877]});
}
} catch($e2640626407) {
if(R.isCont($e2640626407)) {
var $ss2641026411 = {"from":L[3877],
"go":function(anf_arg596326417) {
return $Hanf_arg1056926418(anf_arg596326417,anf_arg59617987,l14067989,s_DASH_if_DASH_pipe_DASH_branch4972295);
}};
$e2640626407.stack[R.EXN_STACKHEIGHT++] = $ss2641026411;
}
if(R.isPyretException($e2640626407)) {
$e2640626407.pyretStack.push(L[3877]);
}
throw $e2640626407;
}
var $ret2641226413 = $Hanf_arg1056926418($z2640826409,anf_arg59617987,l14067989,s_DASH_if_DASH_pipe_DASH_branch4972295);
++R.GAS;
return $ret2641226413;
};
var $Hanf_arg1056926418 = function(anf_arg596326417,anf_arg59617987,l14067989,s_DASH_if_DASH_pipe_DASH_branch4972295) {
var $z2642126422 = D;
var $f2642726428 = function(_) {
return R.isFunction(s_DASH_if_DASH_pipe_DASH_branch4972295.$var)?s_DASH_if_DASH_pipe_DASH_branch4972295.$var.app(l14067989,anf_arg59617987,anf_arg596326417):R.ffi.throwNonFunApp(L[1579],s_DASH_if_DASH_pipe_DASH_branch4972295.$var,[l14067989,anf_arg59617987,anf_arg596326417]);
};
try {
if(--R.GAS > 0) {
$z2642126422 = $f2642726428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2642726428,
"from":L[1579]});
}
} catch($e2641926420) {
if(R.isCont($e2641926420)) {
var $ss2642326424 = {"from":L[1579],
"go":function(ann_DASH_check_DASH_temp595926429) {
return $Hann_DASH_check_DASH_temp1056826430(ann_DASH_check_DASH_temp595926429);
}};
$e2641926420.stack[R.EXN_STACKHEIGHT++] = $ss2642326424;
}
if(R.isPyretException($e2641926420)) {
$e2641926420.pyretStack.push(L[1579]);
}
throw $e2641926420;
}
var $ret2642526426 = $Hann_DASH_check_DASH_temp1056826430($z2642126422);
++R.GAS;
return $ret2642526426;
};
var $Hann_DASH_check_DASH_temp1056826430 = function(ann_DASH_check_DASH_temp595926429) {
return ann_DASH_check_DASH_temp595926429;
};
var $Hanf_arg105678007 = function(anf_arg59558004,body14048005,l14028006,s_DASH_if_DASH_branch4922285,self14018003) {
var anf_fun595626441 = G(body14048005,"visit",L[3880]);
var $z2643326434 = D;
var $f2643926440 = function(_) {
return R.isFunction(anf_fun595626441)?anf_fun595626441.app(self14018003):R.ffi.throwNonFunApp(L[3879],anf_fun595626441,[self14018003]);
};
try {
if(--R.GAS > 0) {
$z2643326434 = $f2643926440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2643926440,
"from":L[3879]});
}
} catch($e2643126432) {
if(R.isCont($e2643126432)) {
var $ss2643526436 = {"from":L[3879],
"go":function(anf_arg595726442) {
return $Hanf_arg1056626443(anf_arg595726442,anf_arg59558004,l14028006,s_DASH_if_DASH_branch4922285);
}};
$e2643126432.stack[R.EXN_STACKHEIGHT++] = $ss2643526436;
}
if(R.isPyretException($e2643126432)) {
$e2643126432.pyretStack.push(L[3879]);
}
throw $e2643126432;
}
var $ret2643726438 = $Hanf_arg1056626443($z2643326434,anf_arg59558004,l14028006,s_DASH_if_DASH_branch4922285);
++R.GAS;
return $ret2643726438;
};
var $Hanf_arg1056626443 = function(anf_arg595726442,anf_arg59558004,l14028006,s_DASH_if_DASH_branch4922285) {
var $z2644626447 = D;
var $f2645226453 = function(_) {
return R.isFunction(s_DASH_if_DASH_branch4922285.$var)?s_DASH_if_DASH_branch4922285.$var.app(l14028006,anf_arg59558004,anf_arg595726442):R.ffi.throwNonFunApp(L[1585],s_DASH_if_DASH_branch4922285.$var,[l14028006,anf_arg59558004,anf_arg595726442]);
};
try {
if(--R.GAS > 0) {
$z2644626447 = $f2645226453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2645226453,
"from":L[1585]});
}
} catch($e2644426445) {
if(R.isCont($e2644426445)) {
var $ss2644826449 = {"from":L[1585],
"go":function(ann_DASH_check_DASH_temp595326454) {
return $Hann_DASH_check_DASH_temp1056526455(ann_DASH_check_DASH_temp595326454);
}};
$e2644426445.stack[R.EXN_STACKHEIGHT++] = $ss2644826449;
}
if(R.isPyretException($e2644426445)) {
$e2644426445.pyretStack.push(L[1585]);
}
throw $e2644426445;
}
var $ret2645026451 = $Hann_DASH_check_DASH_temp1056526455($z2644626447);
++R.GAS;
return $ret2645026451;
};
var $Hann_DASH_check_DASH_temp1056526455 = function(ann_DASH_check_DASH_temp595326454) {
return ann_DASH_check_DASH_temp595326454;
};
var $Hanf_arg105648024 = function(anf_arg59498021,l13988022,s_DASH_assign3502001,self13978020,value14008023) {
var anf_fun595026466 = G(value14008023,"visit",L[3882]);
var $z2645826459 = D;
var $f2646426465 = function(_) {
return R.isFunction(anf_fun595026466)?anf_fun595026466.app(self13978020):R.ffi.throwNonFunApp(L[3881],anf_fun595026466,[self13978020]);
};
try {
if(--R.GAS > 0) {
$z2645826459 = $f2646426465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2646426465,
"from":L[3881]});
}
} catch($e2645626457) {
if(R.isCont($e2645626457)) {
var $ss2646026461 = {"from":L[3881],
"go":function(anf_arg595126467) {
return $Hanf_arg1056326468(anf_arg595126467,anf_arg59498021,l13988022,s_DASH_assign3502001);
}};
$e2645626457.stack[R.EXN_STACKHEIGHT++] = $ss2646026461;
}
if(R.isPyretException($e2645626457)) {
$e2645626457.pyretStack.push(L[3881]);
}
throw $e2645626457;
}
var $ret2646226463 = $Hanf_arg1056326468($z2645826459,anf_arg59498021,l13988022,s_DASH_assign3502001);
++R.GAS;
return $ret2646226463;
};
var $Hanf_arg1056326468 = function(anf_arg595126467,anf_arg59498021,l13988022,s_DASH_assign3502001) {
var $z2647126472 = D;
var $f2647726478 = function(_) {
return R.isFunction(s_DASH_assign3502001.$var)?s_DASH_assign3502001.$var.app(l13988022,anf_arg59498021,anf_arg595126467):R.ffi.throwNonFunApp(L[1591],s_DASH_assign3502001.$var,[l13988022,anf_arg59498021,anf_arg595126467]);
};
try {
if(--R.GAS > 0) {
$z2647126472 = $f2647726478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2647726478,
"from":L[1591]});
}
} catch($e2646926470) {
if(R.isCont($e2646926470)) {
var $ss2647326474 = {"from":L[1591],
"go":function(ann_DASH_check_DASH_temp594726479) {
return $Hann_DASH_check_DASH_temp1056226480(ann_DASH_check_DASH_temp594726479);
}};
$e2646926470.stack[R.EXN_STACKHEIGHT++] = $ss2647326474;
}
if(R.isPyretException($e2646926470)) {
$e2646926470.pyretStack.push(L[1591]);
}
throw $e2646926470;
}
var $ret2647526476 = $Hann_DASH_check_DASH_temp1056226480($z2647126472);
++R.GAS;
return $ret2647526476;
};
var $Hann_DASH_check_DASH_temp1056226480 = function(ann_DASH_check_DASH_temp594726479) {
return ann_DASH_check_DASH_temp594726479;
};
var $Hanf_arg105618041 = function(anf_arg59438038,ann13968039,l13948040,s_DASH_contract3461993,self13938037) {
var anf_fun594426491 = G(ann13968039,"visit",L[3884]);
var $z2648326484 = D;
var $f2648926490 = function(_) {
return R.isFunction(anf_fun594426491)?anf_fun594426491.app(self13938037):R.ffi.throwNonFunApp(L[3883],anf_fun594426491,[self13938037]);
};
try {
if(--R.GAS > 0) {
$z2648326484 = $f2648926490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2648926490,
"from":L[3883]});
}
} catch($e2648126482) {
if(R.isCont($e2648126482)) {
var $ss2648526486 = {"from":L[3883],
"go":function(anf_arg594526492) {
return $Hanf_arg1056026493(anf_arg594526492,anf_arg59438038,l13948040,s_DASH_contract3461993);
}};
$e2648126482.stack[R.EXN_STACKHEIGHT++] = $ss2648526486;
}
if(R.isPyretException($e2648126482)) {
$e2648126482.pyretStack.push(L[3883]);
}
throw $e2648126482;
}
var $ret2648726488 = $Hanf_arg1056026493($z2648326484,anf_arg59438038,l13948040,s_DASH_contract3461993);
++R.GAS;
return $ret2648726488;
};
var $Hanf_arg1056026493 = function(anf_arg594526492,anf_arg59438038,l13948040,s_DASH_contract3461993) {
var $z2649626497 = D;
var $f2650226503 = function(_) {
return R.isFunction(s_DASH_contract3461993.$var)?s_DASH_contract3461993.$var.app(l13948040,anf_arg59438038,anf_arg594526492):R.ffi.throwNonFunApp(L[1594],s_DASH_contract3461993.$var,[l13948040,anf_arg59438038,anf_arg594526492]);
};
try {
if(--R.GAS > 0) {
$z2649626497 = $f2650226503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2650226503,
"from":L[1594]});
}
} catch($e2649426495) {
if(R.isCont($e2649426495)) {
var $ss2649826499 = {"from":L[1594],
"go":function(ann_DASH_check_DASH_temp594126504) {
return $Hann_DASH_check_DASH_temp1055926505(ann_DASH_check_DASH_temp594126504);
}};
$e2649426495.stack[R.EXN_STACKHEIGHT++] = $ss2649826499;
}
if(R.isPyretException($e2649426495)) {
$e2649426495.pyretStack.push(L[1594]);
}
throw $e2649426495;
}
var $ret2650026501 = $Hann_DASH_check_DASH_temp1055926505($z2649626497);
++R.GAS;
return $ret2650026501;
};
var $Hann_DASH_check_DASH_temp1055926505 = function(ann_DASH_check_DASH_temp594126504) {
return ann_DASH_check_DASH_temp594126504;
};
var $Hanf_arg105588058 = function(anf_arg59378055,block13928056,l13908057,s_DASH_when3481997,self13898054) {
var anf_fun593826516 = G(block13928056,"visit",L[3886]);
var $z2650826509 = D;
var $f2651426515 = function(_) {
return R.isFunction(anf_fun593826516)?anf_fun593826516.app(self13898054):R.ffi.throwNonFunApp(L[3885],anf_fun593826516,[self13898054]);
};
try {
if(--R.GAS > 0) {
$z2650826509 = $f2651426515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2651426515,
"from":L[3885]});
}
} catch($e2650626507) {
if(R.isCont($e2650626507)) {
var $ss2651026511 = {"from":L[3885],
"go":function(anf_arg593926517) {
return $Hanf_arg1055726518(anf_arg593926517,anf_arg59378055,l13908057,s_DASH_when3481997);
}};
$e2650626507.stack[R.EXN_STACKHEIGHT++] = $ss2651026511;
}
if(R.isPyretException($e2650626507)) {
$e2650626507.pyretStack.push(L[3885]);
}
throw $e2650626507;
}
var $ret2651226513 = $Hanf_arg1055726518($z2650826509,anf_arg59378055,l13908057,s_DASH_when3481997);
++R.GAS;
return $ret2651226513;
};
var $Hanf_arg1055726518 = function(anf_arg593926517,anf_arg59378055,l13908057,s_DASH_when3481997) {
var $z2652126522 = D;
var $f2652726528 = function(_) {
return R.isFunction(s_DASH_when3481997.$var)?s_DASH_when3481997.$var.app(l13908057,anf_arg59378055,anf_arg593926517):R.ffi.throwNonFunApp(L[1600],s_DASH_when3481997.$var,[l13908057,anf_arg59378055,anf_arg593926517]);
};
try {
if(--R.GAS > 0) {
$z2652126522 = $f2652726528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2652726528,
"from":L[1600]});
}
} catch($e2651926520) {
if(R.isCont($e2651926520)) {
var $ss2652326524 = {"from":L[1600],
"go":function(ann_DASH_check_DASH_temp593526529) {
return $Hann_DASH_check_DASH_temp1055626530(ann_DASH_check_DASH_temp593526529);
}};
$e2651926520.stack[R.EXN_STACKHEIGHT++] = $ss2652326524;
}
if(R.isPyretException($e2651926520)) {
$e2651926520.pyretStack.push(L[1600]);
}
throw $e2651926520;
}
var $ret2652526526 = $Hann_DASH_check_DASH_temp1055626530($z2652126522);
++R.GAS;
return $ret2652526526;
};
var $Hann_DASH_check_DASH_temp1055626530 = function(ann_DASH_check_DASH_temp593526529) {
return ann_DASH_check_DASH_temp593526529;
};
var $Hanf_arg105558074 = function(anf_arg59338072,l13878073,s_DASH_graph3441989) {
var $z2653326534 = D;
var $f2653926540 = function(_) {
return R.isFunction(s_DASH_graph3441989.$var)?s_DASH_graph3441989.$var.app(l13878073,anf_arg59338072):R.ffi.throwNonFunApp(L[1606],s_DASH_graph3441989.$var,[l13878073,anf_arg59338072]);
};
try {
if(--R.GAS > 0) {
$z2653326534 = $f2653926540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2653926540,
"from":L[1606]});
}
} catch($e2653126532) {
if(R.isCont($e2653126532)) {
var $ss2653526536 = {"from":L[1606],
"go":function(ann_DASH_check_DASH_temp592826541) {
return $Hann_DASH_check_DASH_temp1055426542(ann_DASH_check_DASH_temp592826541);
}};
$e2653126532.stack[R.EXN_STACKHEIGHT++] = $ss2653526536;
}
if(R.isPyretException($e2653126532)) {
$e2653126532.pyretStack.push(L[1606]);
}
throw $e2653126532;
}
var $ret2653726538 = $Hann_DASH_check_DASH_temp1055426542($z2653326534);
++R.GAS;
return $ret2653726538;
};
var $Hann_DASH_check_DASH_temp1055426542 = function(ann_DASH_check_DASH_temp592826541) {
return ann_DASH_check_DASH_temp592826541;
};
var $Hann_DASH_check_DASH_temp105538089 = function(ann_DASH_check_DASH_temp59308088) {
return ann_DASH_check_DASH_temp59308088;
};
var $Hanf_arg105528107 = function(anf_arg59248103,keyword_DASH_val13858104,l13828105,s_DASH_let3421985,self13818102,value13848106) {
var anf_fun592526553 = G(value13848106,"visit",L[3888]);
var $z2654526546 = D;
var $f2655126552 = function(_) {
return R.isFunction(anf_fun592526553)?anf_fun592526553.app(self13818102):R.ffi.throwNonFunApp(L[3887],anf_fun592526553,[self13818102]);
};
try {
if(--R.GAS > 0) {
$z2654526546 = $f2655126552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2655126552,
"from":L[3887]});
}
} catch($e2654326544) {
if(R.isCont($e2654326544)) {
var $ss2654726548 = {"from":L[3887],
"go":function(anf_arg592626554) {
return $Hanf_arg1055126555(anf_arg592626554,anf_arg59248103,keyword_DASH_val13858104,l13828105,s_DASH_let3421985);
}};
$e2654326544.stack[R.EXN_STACKHEIGHT++] = $ss2654726548;
}
if(R.isPyretException($e2654326544)) {
$e2654326544.pyretStack.push(L[3887]);
}
throw $e2654326544;
}
var $ret2654926550 = $Hanf_arg1055126555($z2654526546,anf_arg59248103,keyword_DASH_val13858104,l13828105,s_DASH_let3421985);
++R.GAS;
return $ret2654926550;
};
var $Hanf_arg1055126555 = function(anf_arg592626554,anf_arg59248103,keyword_DASH_val13858104,l13828105,s_DASH_let3421985) {
var $z2655826559 = D;
var $f2656426565 = function(_) {
return R.isFunction(s_DASH_let3421985.$var)?s_DASH_let3421985.$var.app(l13828105,anf_arg59248103,anf_arg592626554,keyword_DASH_val13858104):R.ffi.throwNonFunApp(L[1613],s_DASH_let3421985.$var,[l13828105,anf_arg59248103,anf_arg592626554,keyword_DASH_val13858104]);
};
try {
if(--R.GAS > 0) {
$z2655826559 = $f2656426565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2656426565,
"from":L[1613]});
}
} catch($e2655626557) {
if(R.isCont($e2655626557)) {
var $ss2656026561 = {"from":L[1613],
"go":function(ann_DASH_check_DASH_temp592226566) {
return $Hann_DASH_check_DASH_temp1055026567(ann_DASH_check_DASH_temp592226566);
}};
$e2655626557.stack[R.EXN_STACKHEIGHT++] = $ss2656026561;
}
if(R.isPyretException($e2655626557)) {
$e2655626557.pyretStack.push(L[1613]);
}
throw $e2655626557;
}
var $ret2656226563 = $Hann_DASH_check_DASH_temp1055026567($z2655826559);
++R.GAS;
return $ret2656226563;
};
var $Hann_DASH_check_DASH_temp1055026567 = function(ann_DASH_check_DASH_temp592226566) {
return ann_DASH_check_DASH_temp592226566;
};
var $Hanf_arg105498124 = function(anf_arg59188121,l13788122,s_DASH_var3401981,self13778120,value13808123) {
var anf_fun591926578 = G(value13808123,"visit",L[3890]);
var $z2657026571 = D;
var $f2657626577 = function(_) {
return R.isFunction(anf_fun591926578)?anf_fun591926578.app(self13778120):R.ffi.throwNonFunApp(L[3889],anf_fun591926578,[self13778120]);
};
try {
if(--R.GAS > 0) {
$z2657026571 = $f2657626577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2657626577,
"from":L[3889]});
}
} catch($e2656826569) {
if(R.isCont($e2656826569)) {
var $ss2657226573 = {"from":L[3889],
"go":function(anf_arg592026579) {
return $Hanf_arg1054826580(anf_arg592026579,anf_arg59188121,l13788122,s_DASH_var3401981);
}};
$e2656826569.stack[R.EXN_STACKHEIGHT++] = $ss2657226573;
}
if(R.isPyretException($e2656826569)) {
$e2656826569.pyretStack.push(L[3889]);
}
throw $e2656826569;
}
var $ret2657426575 = $Hanf_arg1054826580($z2657026571,anf_arg59188121,l13788122,s_DASH_var3401981);
++R.GAS;
return $ret2657426575;
};
var $Hanf_arg1054826580 = function(anf_arg592026579,anf_arg59188121,l13788122,s_DASH_var3401981) {
var $z2658326584 = D;
var $f2658926590 = function(_) {
return R.isFunction(s_DASH_var3401981.$var)?s_DASH_var3401981.$var.app(l13788122,anf_arg59188121,anf_arg592026579):R.ffi.throwNonFunApp(L[1619],s_DASH_var3401981.$var,[l13788122,anf_arg59188121,anf_arg592026579]);
};
try {
if(--R.GAS > 0) {
$z2658326584 = $f2658926590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2658926590,
"from":L[1619]});
}
} catch($e2658126582) {
if(R.isCont($e2658126582)) {
var $ss2658526586 = {"from":L[1619],
"go":function(ann_DASH_check_DASH_temp591626591) {
return $Hann_DASH_check_DASH_temp1054726592(ann_DASH_check_DASH_temp591626591);
}};
$e2658126582.stack[R.EXN_STACKHEIGHT++] = $ss2658526586;
}
if(R.isPyretException($e2658126582)) {
$e2658126582.pyretStack.push(L[1619]);
}
throw $e2658126582;
}
var $ret2658726588 = $Hann_DASH_check_DASH_temp1054726592($z2658326584);
++R.GAS;
return $ret2658726588;
};
var $Hann_DASH_check_DASH_temp1054726592 = function(ann_DASH_check_DASH_temp591626591) {
return ann_DASH_check_DASH_temp591626591;
};
var $Hanf_arg105468141 = function(anf_arg59128138,l13748139,namet13768140,s_DASH_newtype3381977,self13738137) {
var anf_fun591326603 = G(namet13768140,"visit",L[3892]);
var $z2659526596 = D;
var $f2660126602 = function(_) {
return R.isFunction(anf_fun591326603)?anf_fun591326603.app(self13738137):R.ffi.throwNonFunApp(L[3891],anf_fun591326603,[self13738137]);
};
try {
if(--R.GAS > 0) {
$z2659526596 = $f2660126602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2660126602,
"from":L[3891]});
}
} catch($e2659326594) {
if(R.isCont($e2659326594)) {
var $ss2659726598 = {"from":L[3891],
"go":function(anf_arg591426604) {
return $Hanf_arg1054526605(anf_arg591426604,anf_arg59128138,l13748139,s_DASH_newtype3381977);
}};
$e2659326594.stack[R.EXN_STACKHEIGHT++] = $ss2659726598;
}
if(R.isPyretException($e2659326594)) {
$e2659326594.pyretStack.push(L[3891]);
}
throw $e2659326594;
}
var $ret2659926600 = $Hanf_arg1054526605($z2659526596,anf_arg59128138,l13748139,s_DASH_newtype3381977);
++R.GAS;
return $ret2659926600;
};
var $Hanf_arg1054526605 = function(anf_arg591426604,anf_arg59128138,l13748139,s_DASH_newtype3381977) {
var $z2660826609 = D;
var $f2661426615 = function(_) {
return R.isFunction(s_DASH_newtype3381977.$var)?s_DASH_newtype3381977.$var.app(l13748139,anf_arg59128138,anf_arg591426604):R.ffi.throwNonFunApp(L[1625],s_DASH_newtype3381977.$var,[l13748139,anf_arg59128138,anf_arg591426604]);
};
try {
if(--R.GAS > 0) {
$z2660826609 = $f2661426615();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2661426615,
"from":L[1625]});
}
} catch($e2660626607) {
if(R.isCont($e2660626607)) {
var $ss2661026611 = {"from":L[1625],
"go":function(ann_DASH_check_DASH_temp591026616) {
return $Hann_DASH_check_DASH_temp1054426617(ann_DASH_check_DASH_temp591026616);
}};
$e2660626607.stack[R.EXN_STACKHEIGHT++] = $ss2661026611;
}
if(R.isPyretException($e2660626607)) {
$e2660626607.pyretStack.push(L[1625]);
}
throw $e2660626607;
}
var $ret2661226613 = $Hann_DASH_check_DASH_temp1054426617($z2660826609);
++R.GAS;
return $ret2661226613;
};
var $Hann_DASH_check_DASH_temp1054426617 = function(ann_DASH_check_DASH_temp591026616) {
return ann_DASH_check_DASH_temp591026616;
};
var $Hanf_arg105438158 = function(anf_arg59068155,ann13728156,l13708157,s_DASH_type3361973,self13698154) {
var anf_fun590726628 = G(ann13728156,"visit",L[3894]);
var $z2662026621 = D;
var $f2662626627 = function(_) {
return R.isFunction(anf_fun590726628)?anf_fun590726628.app(self13698154):R.ffi.throwNonFunApp(L[3893],anf_fun590726628,[self13698154]);
};
try {
if(--R.GAS > 0) {
$z2662026621 = $f2662626627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2662626627,
"from":L[3893]});
}
} catch($e2661826619) {
if(R.isCont($e2661826619)) {
var $ss2662226623 = {"from":L[3893],
"go":function(anf_arg590826629) {
return $Hanf_arg1054226630(anf_arg590826629,anf_arg59068155,l13708157,s_DASH_type3361973);
}};
$e2661826619.stack[R.EXN_STACKHEIGHT++] = $ss2662226623;
}
if(R.isPyretException($e2661826619)) {
$e2661826619.pyretStack.push(L[3893]);
}
throw $e2661826619;
}
var $ret2662426625 = $Hanf_arg1054226630($z2662026621,anf_arg59068155,l13708157,s_DASH_type3361973);
++R.GAS;
return $ret2662426625;
};
var $Hanf_arg1054226630 = function(anf_arg590826629,anf_arg59068155,l13708157,s_DASH_type3361973) {
var $z2663326634 = D;
var $f2663926640 = function(_) {
return R.isFunction(s_DASH_type3361973.$var)?s_DASH_type3361973.$var.app(l13708157,anf_arg59068155,anf_arg590826629):R.ffi.throwNonFunApp(L[1631],s_DASH_type3361973.$var,[l13708157,anf_arg59068155,anf_arg590826629]);
};
try {
if(--R.GAS > 0) {
$z2663326634 = $f2663926640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2663926640,
"from":L[1631]});
}
} catch($e2663126632) {
if(R.isCont($e2663126632)) {
var $ss2663526636 = {"from":L[1631],
"go":function(ann_DASH_check_DASH_temp590426641) {
return $Hann_DASH_check_DASH_temp1054126642(ann_DASH_check_DASH_temp590426641);
}};
$e2663126632.stack[R.EXN_STACKHEIGHT++] = $ss2663526636;
}
if(R.isPyretException($e2663126632)) {
$e2663126632.pyretStack.push(L[1631]);
}
throw $e2663126632;
}
var $ret2663726638 = $Hann_DASH_check_DASH_temp1054126642($z2663326634);
++R.GAS;
return $ret2663726638;
};
var $Hann_DASH_check_DASH_temp1054126642 = function(ann_DASH_check_DASH_temp590426641) {
return ann_DASH_check_DASH_temp590426641;
};
var $Hanf_arg105408181 = function(anf_arg58968172,_check13688173,ann13658174,body13678175,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180) {
var anf_fun589726653 = G(ann13658174,"visit",L[3896]);
var $z2664526646 = D;
var $f2665126652 = function(_) {
return R.isFunction(anf_fun589726653)?anf_fun589726653.app(self13608180):R.ffi.throwNonFunApp(L[3895],anf_fun589726653,[self13608180]);
};
try {
if(--R.GAS > 0) {
$z2664526646 = $f2665126652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2665126652,
"from":L[3895]});
}
} catch($e2664326644) {
if(R.isCont($e2664326644)) {
var $ss2664726648 = {"from":L[3895],
"go":function(anf_arg589826654) {
return $Hanf_arg1053926655(anf_arg589826654,_check13688173,anf_arg58968172,body13678175,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180);
}};
$e2664326644.stack[R.EXN_STACKHEIGHT++] = $ss2664726648;
}
if(R.isPyretException($e2664326644)) {
$e2664326644.pyretStack.push(L[3895]);
}
throw $e2664326644;
}
var $ret2664926650 = $Hanf_arg1053926655($z2664526646,_check13688173,anf_arg58968172,body13678175,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180);
++R.GAS;
return $ret2664926650;
};
var $Hanf_arg1053926655 = function(anf_arg589826654,_check13688173,anf_arg58968172,body13678175,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180) {
var anf_fun589926666 = G(body13678175,"visit",L[3898]);
var $z2665826659 = D;
var $f2666426665 = function(_) {
return R.isFunction(anf_fun589926666)?anf_fun589926666.app(self13608180):R.ffi.throwNonFunApp(L[3897],anf_fun589926666,[self13608180]);
};
try {
if(--R.GAS > 0) {
$z2665826659 = $f2666426665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2666426665,
"from":L[3897]});
}
} catch($e2665626657) {
if(R.isCont($e2665626657)) {
var $ss2666026661 = {"from":L[3897],
"go":function(anf_arg590026667) {
return $Hanf_arg1053826668(anf_arg590026667,_check13688173,anf_arg58968172,anf_arg589826654,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180);
}};
$e2665626657.stack[R.EXN_STACKHEIGHT++] = $ss2666026661;
}
if(R.isPyretException($e2665626657)) {
$e2665626657.pyretStack.push(L[3897]);
}
throw $e2665626657;
}
var $ret2666226663 = $Hanf_arg1053826668($z2665826659,_check13688173,anf_arg58968172,anf_arg589826654,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180);
++R.GAS;
return $ret2666226663;
};
var $Hanf_arg1053826668 = function(anf_arg590026667,_check13688173,anf_arg58968172,anf_arg589826654,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969,self13608180) {
var anf_fun590126679 = G(self13608180,"option",L[3900]);
var $z2667126672 = D;
var $f2667726678 = function(_) {
return R.isFunction(anf_fun590126679)?anf_fun590126679.app(_check13688173):R.ffi.throwNonFunApp(L[3899],anf_fun590126679,[_check13688173]);
};
try {
if(--R.GAS > 0) {
$z2667126672 = $f2667726678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2667726678,
"from":L[3899]});
}
} catch($e2666926670) {
if(R.isCont($e2666926670)) {
var $ss2667326674 = {"from":L[3899],
"go":function(anf_arg590226680) {
return $Hanf_arg1053726681(anf_arg590226680,anf_arg58968172,anf_arg589826654,anf_arg590026667,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969);
}};
$e2666926670.stack[R.EXN_STACKHEIGHT++] = $ss2667326674;
}
if(R.isPyretException($e2666926670)) {
$e2666926670.pyretStack.push(L[3899]);
}
throw $e2666926670;
}
var $ret2667526676 = $Hanf_arg1053726681($z2667126672,anf_arg58968172,anf_arg589826654,anf_arg590026667,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969);
++R.GAS;
return $ret2667526676;
};
var $Hanf_arg1053726681 = function(anf_arg590226680,anf_arg58968172,anf_arg589826654,anf_arg590026667,doc13668176,l13618177,name13628178,params13638179,s_DASH_fun3341969) {
var $z2668426685 = D;
var $f2669026691 = function(_) {
return R.isFunction(s_DASH_fun3341969.$var)?s_DASH_fun3341969.$var.app(l13618177,name13628178,params13638179,anf_arg58968172,anf_arg589826654,doc13668176,anf_arg590026667,anf_arg590226680):R.ffi.throwNonFunApp(L[1635],s_DASH_fun3341969.$var,[l13618177,name13628178,params13638179,anf_arg58968172,anf_arg589826654,doc13668176,anf_arg590026667,anf_arg590226680]);
};
try {
if(--R.GAS > 0) {
$z2668426685 = $f2669026691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2669026691,
"from":L[1635]});
}
} catch($e2668226683) {
if(R.isCont($e2668226683)) {
var $ss2668626687 = {"from":L[1635],
"go":function(ann_DASH_check_DASH_temp589126692) {
return $Hann_DASH_check_DASH_temp1053626693(ann_DASH_check_DASH_temp589126692);
}};
$e2668226683.stack[R.EXN_STACKHEIGHT++] = $ss2668626687;
}
if(R.isPyretException($e2668226683)) {
$e2668226683.pyretStack.push(L[1635]);
}
throw $e2668226683;
}
var $ret2668826689 = $Hann_DASH_check_DASH_temp1053626693($z2668426685);
++R.GAS;
return $ret2668826689;
};
var $Hann_DASH_check_DASH_temp1053626693 = function(ann_DASH_check_DASH_temp589126692) {
return ann_DASH_check_DASH_temp589126692;
};
var $Hann_DASH_check_DASH_temp105358195 = function(ann_DASH_check_DASH_temp58938194) {
return ann_DASH_check_DASH_temp58938194;
};
var $Hanf_arg105348211 = function(anf_arg58898209,l13588210,s_DASH_user_DASH_block3321965) {
var $z2669626697 = D;
var $f2670226703 = function(_) {
return R.isFunction(s_DASH_user_DASH_block3321965.$var)?s_DASH_user_DASH_block3321965.$var.app(l13588210,anf_arg58898209):R.ffi.throwNonFunApp(L[1640],s_DASH_user_DASH_block3321965.$var,[l13588210,anf_arg58898209]);
};
try {
if(--R.GAS > 0) {
$z2669626697 = $f2670226703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2670226703,
"from":L[1640]});
}
} catch($e2669426695) {
if(R.isCont($e2669426695)) {
var $ss2669826699 = {"from":L[1640],
"go":function(ann_DASH_check_DASH_temp588726704) {
return $Hann_DASH_check_DASH_temp1053326705(ann_DASH_check_DASH_temp588726704);
}};
$e2669426695.stack[R.EXN_STACKHEIGHT++] = $ss2669826699;
}
if(R.isPyretException($e2669426695)) {
$e2669426695.pyretStack.push(L[1640]);
}
throw $e2669426695;
}
var $ret2670026701 = $Hann_DASH_check_DASH_temp1053326705($z2669626697);
++R.GAS;
return $ret2670026701;
};
var $Hann_DASH_check_DASH_temp1053326705 = function(ann_DASH_check_DASH_temp588726704) {
return ann_DASH_check_DASH_temp588726704;
};
var $Hanf_arg105328227 = function(anf_arg58858225,l13558226,s_DASH_block3301961) {
var $z2670826709 = D;
var $f2671426715 = function(_) {
return R.isFunction(s_DASH_block3301961.$var)?s_DASH_block3301961.$var.app(l13558226,anf_arg58858225):R.ffi.throwNonFunApp(L[1644],s_DASH_block3301961.$var,[l13558226,anf_arg58858225]);
};
try {
if(--R.GAS > 0) {
$z2670826709 = $f2671426715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2671426715,
"from":L[1644]});
}
} catch($e2670626707) {
if(R.isCont($e2670626707)) {
var $ss2671026711 = {"from":L[1644],
"go":function(ann_DASH_check_DASH_temp588026716) {
return $Hann_DASH_check_DASH_temp1053126717(ann_DASH_check_DASH_temp588026716);
}};
$e2670626707.stack[R.EXN_STACKHEIGHT++] = $ss2671026711;
}
if(R.isPyretException($e2670626707)) {
$e2670626707.pyretStack.push(L[1644]);
}
throw $e2670626707;
}
var $ret2671226713 = $Hann_DASH_check_DASH_temp1053126717($z2670826709);
++R.GAS;
return $ret2671226713;
};
var $Hann_DASH_check_DASH_temp1053126717 = function(ann_DASH_check_DASH_temp588026716) {
return ann_DASH_check_DASH_temp588026716;
};
var $Hann_DASH_check_DASH_temp105308242 = function(ann_DASH_check_DASH_temp58828241) {
return ann_DASH_check_DASH_temp58828241;
};
var $Hanf_arg105298259 = function(anf_arg58738256,l13518257,params13538258,s_DASH_instantiate3281957,self13508255) {
var anf_fun587426728 = G(params13538258,"map",L[3903]);
var anf_arg587726729 = R.makeFunction(function(recv_DASH_72326732) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3902],1,arguments);
}
var anf_fun587626743 = G(recv_DASH_72326732,"visit",L[3902]);
var $z2673526736 = D;
var $f2674126742 = function(_) {
return R.isFunction(anf_fun587626743)?anf_fun587626743.app(self13508255):R.ffi.throwNonFunApp(L[3902],anf_fun587626743,[self13508255]);
};
try {
if(--R.GAS > 0) {
$z2673526736 = $f2674126742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2674126742,
"from":L[3902]});
}
} catch($e2673326734) {
if(R.isCont($e2673326734)) {
var $ss2673726738 = {"from":L[3902],
"go":function(ann_DASH_check_DASH_temp587526744) {
return $Hann_DASH_check_DASH_temp1052626745(ann_DASH_check_DASH_temp587526744);
}};
$e2673326734.stack[R.EXN_STACKHEIGHT++] = $ss2673726738;
}
if(R.isPyretException($e2673326734)) {
$e2673326734.pyretStack.push(L[3902]);
}
throw $e2673326734;
}
var $ret2673926740 = $Hann_DASH_check_DASH_temp1052626745($z2673526736);
++R.GAS;
return $ret2673926740;
});
var $z2672026721 = D;
var $f2672626727 = function(_) {
return R.isFunction(anf_fun587426728)?anf_fun587426728.app(anf_arg587726729):R.ffi.throwNonFunApp(L[3901],anf_fun587426728,[anf_arg587726729]);
};
try {
if(--R.GAS > 0) {
$z2672026721 = $f2672626727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2672626727,
"from":L[3901]});
}
} catch($e2671826719) {
if(R.isCont($e2671826719)) {
var $ss2672226723 = {"from":L[3901],
"go":function(anf_arg587826730) {
return $Hanf_arg1052826731(anf_arg587826730,anf_arg58738256,l13518257,s_DASH_instantiate3281957);
}};
$e2671826719.stack[R.EXN_STACKHEIGHT++] = $ss2672226723;
}
if(R.isPyretException($e2671826719)) {
$e2671826719.pyretStack.push(L[3901]);
}
throw $e2671826719;
}
var $ret2672426725 = $Hanf_arg1052826731($z2672026721,anf_arg58738256,l13518257,s_DASH_instantiate3281957);
++R.GAS;
return $ret2672426725;
};
var $Hanf_arg1052826731 = function(anf_arg587826730,anf_arg58738256,l13518257,s_DASH_instantiate3281957) {
var $z2674826749 = D;
var $f2675426755 = function(_) {
return R.isFunction(s_DASH_instantiate3281957.$var)?s_DASH_instantiate3281957.$var.app(l13518257,anf_arg58738256,anf_arg587826730):R.ffi.throwNonFunApp(L[1650],s_DASH_instantiate3281957.$var,[l13518257,anf_arg58738256,anf_arg587826730]);
};
try {
if(--R.GAS > 0) {
$z2674826749 = $f2675426755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2675426755,
"from":L[1650]});
}
} catch($e2674626747) {
if(R.isCont($e2674626747)) {
var $ss2675026751 = {"from":L[1650],
"go":function(ann_DASH_check_DASH_temp587126756) {
return $Hann_DASH_check_DASH_temp1052726757(ann_DASH_check_DASH_temp587126756);
}};
$e2674626747.stack[R.EXN_STACKHEIGHT++] = $ss2675026751;
}
if(R.isPyretException($e2674626747)) {
$e2674626747.pyretStack.push(L[1650]);
}
throw $e2674626747;
}
var $ret2675226753 = $Hann_DASH_check_DASH_temp1052726757($z2674826749);
++R.GAS;
return $ret2675226753;
};
var $Hann_DASH_check_DASH_temp1052726757 = function(ann_DASH_check_DASH_temp587126756) {
return ann_DASH_check_DASH_temp587126756;
};
var $Hann_DASH_check_DASH_temp1052626745 = function(ann_DASH_check_DASH_temp587526744) {
return ann_DASH_check_DASH_temp587526744;
};
var $Hanf_arg105258276 = function(anf_arg58698273,hints13488274,l13478275,s_DASH_hint_DASH_exp3261953) {
var $z2676026761 = D;
var $f2676626767 = function(_) {
return R.isFunction(s_DASH_hint_DASH_exp3261953.$var)?s_DASH_hint_DASH_exp3261953.$var.app(l13478275,hints13488274,anf_arg58698273):R.ffi.throwNonFunApp(L[1656],s_DASH_hint_DASH_exp3261953.$var,[l13478275,hints13488274,anf_arg58698273]);
};
try {
if(--R.GAS > 0) {
$z2676026761 = $f2676626767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2676626767,
"from":L[1656]});
}
} catch($e2675826759) {
if(R.isCont($e2675826759)) {
var $ss2676226763 = {"from":L[1656],
"go":function(ann_DASH_check_DASH_temp586726768) {
return $Hann_DASH_check_DASH_temp1052426769(ann_DASH_check_DASH_temp586726768);
}};
$e2675826759.stack[R.EXN_STACKHEIGHT++] = $ss2676226763;
}
if(R.isPyretException($e2675826759)) {
$e2675826759.pyretStack.push(L[1656]);
}
throw $e2675826759;
}
var $ret2676426765 = $Hann_DASH_check_DASH_temp1052426769($z2676026761);
++R.GAS;
return $ret2676426765;
};
var $Hann_DASH_check_DASH_temp1052426769 = function(ann_DASH_check_DASH_temp586726768) {
return ann_DASH_check_DASH_temp586726768;
};
var $Hanf_arg105238294 = function(anf_arg58638290,body13458291,l13438292,s_DASH_letrec3241949,self13428293) {
var anf_fun586426780 = G(body13458291,"visit",L[3905]);
var $z2677226773 = D;
var $f2677826779 = function(_) {
return R.isFunction(anf_fun586426780)?anf_fun586426780.app(self13428293):R.ffi.throwNonFunApp(L[3904],anf_fun586426780,[self13428293]);
};
try {
if(--R.GAS > 0) {
$z2677226773 = $f2677826779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2677826779,
"from":L[3904]});
}
} catch($e2677026771) {
if(R.isCont($e2677026771)) {
var $ss2677426775 = {"from":L[3904],
"go":function(anf_arg586526781) {
return $Hanf_arg1052226782(anf_arg586526781,anf_arg58638290,l13438292,s_DASH_letrec3241949);
}};
$e2677026771.stack[R.EXN_STACKHEIGHT++] = $ss2677426775;
}
if(R.isPyretException($e2677026771)) {
$e2677026771.pyretStack.push(L[3904]);
}
throw $e2677026771;
}
var $ret2677626777 = $Hanf_arg1052226782($z2677226773,anf_arg58638290,l13438292,s_DASH_letrec3241949);
++R.GAS;
return $ret2677626777;
};
var $Hanf_arg1052226782 = function(anf_arg586526781,anf_arg58638290,l13438292,s_DASH_letrec3241949) {
var $z2678526786 = D;
var $f2679126792 = function(_) {
return R.isFunction(s_DASH_letrec3241949.$var)?s_DASH_letrec3241949.$var.app(l13438292,anf_arg58638290,anf_arg586526781):R.ffi.throwNonFunApp(L[1660],s_DASH_letrec3241949.$var,[l13438292,anf_arg58638290,anf_arg586526781]);
};
try {
if(--R.GAS > 0) {
$z2678526786 = $f2679126792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2679126792,
"from":L[1660]});
}
} catch($e2678326784) {
if(R.isCont($e2678326784)) {
var $ss2678726788 = {"from":L[1660],
"go":function(ann_DASH_check_DASH_temp585826793) {
return $Hann_DASH_check_DASH_temp1052126794(ann_DASH_check_DASH_temp585826793);
}};
$e2678326784.stack[R.EXN_STACKHEIGHT++] = $ss2678726788;
}
if(R.isPyretException($e2678326784)) {
$e2678326784.pyretStack.push(L[1660]);
}
throw $e2678326784;
}
var $ret2678926790 = $Hann_DASH_check_DASH_temp1052126794($z2678526786);
++R.GAS;
return $ret2678926790;
};
var $Hann_DASH_check_DASH_temp1052126794 = function(ann_DASH_check_DASH_temp585826793) {
return ann_DASH_check_DASH_temp585826793;
};
var $Hann_DASH_check_DASH_temp105208308 = function(ann_DASH_check_DASH_temp58608307) {
return ann_DASH_check_DASH_temp58608307;
};
var $Hanf_arg105198325 = function(anf_arg58548322,expr13418323,l13398324,s_DASH_letrec_DASH_bind3061913,self13388321) {
var anf_fun585526805 = G(expr13418323,"visit",L[3907]);
var $z2679726798 = D;
var $f2680326804 = function(_) {
return R.isFunction(anf_fun585526805)?anf_fun585526805.app(self13388321):R.ffi.throwNonFunApp(L[3906],anf_fun585526805,[self13388321]);
};
try {
if(--R.GAS > 0) {
$z2679726798 = $f2680326804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2680326804,
"from":L[3906]});
}
} catch($e2679526796) {
if(R.isCont($e2679526796)) {
var $ss2679926800 = {"from":L[3906],
"go":function(anf_arg585626806) {
return $Hanf_arg1051826807(anf_arg585626806,anf_arg58548322,l13398324,s_DASH_letrec_DASH_bind3061913);
}};
$e2679526796.stack[R.EXN_STACKHEIGHT++] = $ss2679926800;
}
if(R.isPyretException($e2679526796)) {
$e2679526796.pyretStack.push(L[3906]);
}
throw $e2679526796;
}
var $ret2680126802 = $Hanf_arg1051826807($z2679726798,anf_arg58548322,l13398324,s_DASH_letrec_DASH_bind3061913);
++R.GAS;
return $ret2680126802;
};
var $Hanf_arg1051826807 = function(anf_arg585626806,anf_arg58548322,l13398324,s_DASH_letrec_DASH_bind3061913) {
var $z2681026811 = D;
var $f2681626817 = function(_) {
return R.isFunction(s_DASH_letrec_DASH_bind3061913.$var)?s_DASH_letrec_DASH_bind3061913.$var.app(l13398324,anf_arg58548322,anf_arg585626806):R.ffi.throwNonFunApp(L[1663],s_DASH_letrec_DASH_bind3061913.$var,[l13398324,anf_arg58548322,anf_arg585626806]);
};
try {
if(--R.GAS > 0) {
$z2681026811 = $f2681626817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2681626817,
"from":L[1663]});
}
} catch($e2680826809) {
if(R.isCont($e2680826809)) {
var $ss2681226813 = {"from":L[1663],
"go":function(ann_DASH_check_DASH_temp585226818) {
return $Hann_DASH_check_DASH_temp1051726819(ann_DASH_check_DASH_temp585226818);
}};
$e2680826809.stack[R.EXN_STACKHEIGHT++] = $ss2681226813;
}
if(R.isPyretException($e2680826809)) {
$e2680826809.pyretStack.push(L[1663]);
}
throw $e2680826809;
}
var $ret2681426815 = $Hann_DASH_check_DASH_temp1051726819($z2681026811);
++R.GAS;
return $ret2681426815;
};
var $Hann_DASH_check_DASH_temp1051726819 = function(ann_DASH_check_DASH_temp585226818) {
return ann_DASH_check_DASH_temp585226818;
};
var $Hanf_arg105168343 = function(anf_arg58488339,body13378340,l13358341,s_DASH_let_DASH_expr3221945,self13348342) {
var anf_fun584926830 = G(body13378340,"visit",L[3909]);
var $z2682226823 = D;
var $f2682826829 = function(_) {
return R.isFunction(anf_fun584926830)?anf_fun584926830.app(self13348342):R.ffi.throwNonFunApp(L[3908],anf_fun584926830,[self13348342]);
};
try {
if(--R.GAS > 0) {
$z2682226823 = $f2682826829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2682826829,
"from":L[3908]});
}
} catch($e2682026821) {
if(R.isCont($e2682026821)) {
var $ss2682426825 = {"from":L[3908],
"go":function(anf_arg585026831) {
return $Hanf_arg1051526832(anf_arg585026831,anf_arg58488339,l13358341,s_DASH_let_DASH_expr3221945);
}};
$e2682026821.stack[R.EXN_STACKHEIGHT++] = $ss2682426825;
}
if(R.isPyretException($e2682026821)) {
$e2682026821.pyretStack.push(L[3908]);
}
throw $e2682026821;
}
var $ret2682626827 = $Hanf_arg1051526832($z2682226823,anf_arg58488339,l13358341,s_DASH_let_DASH_expr3221945);
++R.GAS;
return $ret2682626827;
};
var $Hanf_arg1051526832 = function(anf_arg585026831,anf_arg58488339,l13358341,s_DASH_let_DASH_expr3221945) {
var $z2683526836 = D;
var $f2684126842 = function(_) {
return R.isFunction(s_DASH_let_DASH_expr3221945.$var)?s_DASH_let_DASH_expr3221945.$var.app(l13358341,anf_arg58488339,anf_arg585026831):R.ffi.throwNonFunApp(L[1667],s_DASH_let_DASH_expr3221945.$var,[l13358341,anf_arg58488339,anf_arg585026831]);
};
try {
if(--R.GAS > 0) {
$z2683526836 = $f2684126842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2684126842,
"from":L[1667]});
}
} catch($e2683326834) {
if(R.isCont($e2683326834)) {
var $ss2683726838 = {"from":L[1667],
"go":function(ann_DASH_check_DASH_temp584326843) {
return $Hann_DASH_check_DASH_temp1051426844(ann_DASH_check_DASH_temp584326843);
}};
$e2683326834.stack[R.EXN_STACKHEIGHT++] = $ss2683726838;
}
if(R.isPyretException($e2683326834)) {
$e2683326834.pyretStack.push(L[1667]);
}
throw $e2683326834;
}
var $ret2683926840 = $Hann_DASH_check_DASH_temp1051426844($z2683526836);
++R.GAS;
return $ret2683926840;
};
var $Hann_DASH_check_DASH_temp1051426844 = function(ann_DASH_check_DASH_temp584326843) {
return ann_DASH_check_DASH_temp584326843;
};
var $Hann_DASH_check_DASH_temp105138357 = function(ann_DASH_check_DASH_temp58458356) {
return ann_DASH_check_DASH_temp58458356;
};
var $Hanf_arg105128375 = function(anf_arg58398371,body13338372,l13318373,s_DASH_type_DASH_let_DASH_expr3201941,self13308374) {
var anf_fun584026855 = G(body13338372,"visit",L[3911]);
var $z2684726848 = D;
var $f2685326854 = function(_) {
return R.isFunction(anf_fun584026855)?anf_fun584026855.app(self13308374):R.ffi.throwNonFunApp(L[3910],anf_fun584026855,[self13308374]);
};
try {
if(--R.GAS > 0) {
$z2684726848 = $f2685326854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2685326854,
"from":L[3910]});
}
} catch($e2684526846) {
if(R.isCont($e2684526846)) {
var $ss2684926850 = {"from":L[3910],
"go":function(anf_arg584126856) {
return $Hanf_arg1051126857(anf_arg584126856,anf_arg58398371,l13318373,s_DASH_type_DASH_let_DASH_expr3201941);
}};
$e2684526846.stack[R.EXN_STACKHEIGHT++] = $ss2684926850;
}
if(R.isPyretException($e2684526846)) {
$e2684526846.pyretStack.push(L[3910]);
}
throw $e2684526846;
}
var $ret2685126852 = $Hanf_arg1051126857($z2684726848,anf_arg58398371,l13318373,s_DASH_type_DASH_let_DASH_expr3201941);
++R.GAS;
return $ret2685126852;
};
var $Hanf_arg1051126857 = function(anf_arg584126856,anf_arg58398371,l13318373,s_DASH_type_DASH_let_DASH_expr3201941) {
var $z2686026861 = D;
var $f2686626867 = function(_) {
return R.isFunction(s_DASH_type_DASH_let_DASH_expr3201941.$var)?s_DASH_type_DASH_let_DASH_expr3201941.$var.app(l13318373,anf_arg58398371,anf_arg584126856):R.ffi.throwNonFunApp(L[1671],s_DASH_type_DASH_let_DASH_expr3201941.$var,[l13318373,anf_arg58398371,anf_arg584126856]);
};
try {
if(--R.GAS > 0) {
$z2686026861 = $f2686626867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2686626867,
"from":L[1671]});
}
} catch($e2685826859) {
if(R.isCont($e2685826859)) {
var $ss2686226863 = {"from":L[1671],
"go":function(ann_DASH_check_DASH_temp583426868) {
return $Hann_DASH_check_DASH_temp1051026869(ann_DASH_check_DASH_temp583426868);
}};
$e2685826859.stack[R.EXN_STACKHEIGHT++] = $ss2686226863;
}
if(R.isPyretException($e2685826859)) {
$e2685826859.pyretStack.push(L[1671]);
}
throw $e2685826859;
}
var $ret2686426865 = $Hann_DASH_check_DASH_temp1051026869($z2686026861);
++R.GAS;
return $ret2686426865;
};
var $Hann_DASH_check_DASH_temp1051026869 = function(ann_DASH_check_DASH_temp583426868) {
return ann_DASH_check_DASH_temp583426868;
};
var $Hann_DASH_check_DASH_temp105098389 = function(ann_DASH_check_DASH_temp58368388) {
return ann_DASH_check_DASH_temp58368388;
};
var $Hanf_arg105088406 = function(anf_arg58308403,l13278404,namet13298405,s_DASH_newtype_DASH_bind3131927,self13268402) {
var anf_fun583126880 = G(namet13298405,"visit",L[3913]);
var $z2687226873 = D;
var $f2687826879 = function(_) {
return R.isFunction(anf_fun583126880)?anf_fun583126880.app(self13268402):R.ffi.throwNonFunApp(L[3912],anf_fun583126880,[self13268402]);
};
try {
if(--R.GAS > 0) {
$z2687226873 = $f2687826879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2687826879,
"from":L[3912]});
}
} catch($e2687026871) {
if(R.isCont($e2687026871)) {
var $ss2687426875 = {"from":L[3912],
"go":function(anf_arg583226881) {
return $Hanf_arg1050726882(anf_arg583226881,anf_arg58308403,l13278404,s_DASH_newtype_DASH_bind3131927);
}};
$e2687026871.stack[R.EXN_STACKHEIGHT++] = $ss2687426875;
}
if(R.isPyretException($e2687026871)) {
$e2687026871.pyretStack.push(L[3912]);
}
throw $e2687026871;
}
var $ret2687626877 = $Hanf_arg1050726882($z2687226873,anf_arg58308403,l13278404,s_DASH_newtype_DASH_bind3131927);
++R.GAS;
return $ret2687626877;
};
var $Hanf_arg1050726882 = function(anf_arg583226881,anf_arg58308403,l13278404,s_DASH_newtype_DASH_bind3131927) {
var $z2688526886 = D;
var $f2689126892 = function(_) {
return R.isFunction(s_DASH_newtype_DASH_bind3131927.$var)?s_DASH_newtype_DASH_bind3131927.$var.app(l13278404,anf_arg58308403,anf_arg583226881):R.ffi.throwNonFunApp(L[1674],s_DASH_newtype_DASH_bind3131927.$var,[l13278404,anf_arg58308403,anf_arg583226881]);
};
try {
if(--R.GAS > 0) {
$z2688526886 = $f2689126892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2689126892,
"from":L[1674]});
}
} catch($e2688326884) {
if(R.isCont($e2688326884)) {
var $ss2688726888 = {"from":L[1674],
"go":function(ann_DASH_check_DASH_temp582826893) {
return $Hann_DASH_check_DASH_temp1050626894(ann_DASH_check_DASH_temp582826893);
}};
$e2688326884.stack[R.EXN_STACKHEIGHT++] = $ss2688726888;
}
if(R.isPyretException($e2688326884)) {
$e2688326884.pyretStack.push(L[1674]);
}
throw $e2688326884;
}
var $ret2688926890 = $Hann_DASH_check_DASH_temp1050626894($z2688526886);
++R.GAS;
return $ret2688926890;
};
var $Hann_DASH_check_DASH_temp1050626894 = function(ann_DASH_check_DASH_temp582826893) {
return ann_DASH_check_DASH_temp582826893;
};
var $Hanf_arg105058423 = function(anf_arg58248420,ann13258421,l13238422,s_DASH_type_DASH_bind3111923,self13228419) {
var anf_fun582526905 = G(ann13258421,"visit",L[3915]);
var $z2689726898 = D;
var $f2690326904 = function(_) {
return R.isFunction(anf_fun582526905)?anf_fun582526905.app(self13228419):R.ffi.throwNonFunApp(L[3914],anf_fun582526905,[self13228419]);
};
try {
if(--R.GAS > 0) {
$z2689726898 = $f2690326904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2690326904,
"from":L[3914]});
}
} catch($e2689526896) {
if(R.isCont($e2689526896)) {
var $ss2689926900 = {"from":L[3914],
"go":function(anf_arg582626906) {
return $Hanf_arg1050426907(anf_arg582626906,anf_arg58248420,l13238422,s_DASH_type_DASH_bind3111923);
}};
$e2689526896.stack[R.EXN_STACKHEIGHT++] = $ss2689926900;
}
if(R.isPyretException($e2689526896)) {
$e2689526896.pyretStack.push(L[3914]);
}
throw $e2689526896;
}
var $ret2690126902 = $Hanf_arg1050426907($z2689726898,anf_arg58248420,l13238422,s_DASH_type_DASH_bind3111923);
++R.GAS;
return $ret2690126902;
};
var $Hanf_arg1050426907 = function(anf_arg582626906,anf_arg58248420,l13238422,s_DASH_type_DASH_bind3111923) {
var $z2691026911 = D;
var $f2691626917 = function(_) {
return R.isFunction(s_DASH_type_DASH_bind3111923.$var)?s_DASH_type_DASH_bind3111923.$var.app(l13238422,anf_arg58248420,anf_arg582626906):R.ffi.throwNonFunApp(L[1677],s_DASH_type_DASH_bind3111923.$var,[l13238422,anf_arg58248420,anf_arg582626906]);
};
try {
if(--R.GAS > 0) {
$z2691026911 = $f2691626917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2691626917,
"from":L[1677]});
}
} catch($e2690826909) {
if(R.isCont($e2690826909)) {
var $ss2691226913 = {"from":L[1677],
"go":function(ann_DASH_check_DASH_temp582226918) {
return $Hann_DASH_check_DASH_temp1050326919(ann_DASH_check_DASH_temp582226918);
}};
$e2690826909.stack[R.EXN_STACKHEIGHT++] = $ss2691226913;
}
if(R.isPyretException($e2690826909)) {
$e2690826909.pyretStack.push(L[1677]);
}
throw $e2690826909;
}
var $ret2691426915 = $Hann_DASH_check_DASH_temp1050326919($z2691026911);
++R.GAS;
return $ret2691426915;
};
var $Hann_DASH_check_DASH_temp1050326919 = function(ann_DASH_check_DASH_temp582226918) {
return ann_DASH_check_DASH_temp582226918;
};
var $Hanf_arg105028440 = function(anf_arg58188437,expr13218438,l13198439,s_DASH_let_DASH_bind2991899,self13188436) {
var anf_fun581926930 = G(expr13218438,"visit",L[3917]);
var $z2692226923 = D;
var $f2692826929 = function(_) {
return R.isFunction(anf_fun581926930)?anf_fun581926930.app(self13188436):R.ffi.throwNonFunApp(L[3916],anf_fun581926930,[self13188436]);
};
try {
if(--R.GAS > 0) {
$z2692226923 = $f2692826929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2692826929,
"from":L[3916]});
}
} catch($e2692026921) {
if(R.isCont($e2692026921)) {
var $ss2692426925 = {"from":L[3916],
"go":function(anf_arg582026931) {
return $Hanf_arg1050126932(anf_arg582026931,anf_arg58188437,l13198439,s_DASH_let_DASH_bind2991899);
}};
$e2692026921.stack[R.EXN_STACKHEIGHT++] = $ss2692426925;
}
if(R.isPyretException($e2692026921)) {
$e2692026921.pyretStack.push(L[3916]);
}
throw $e2692026921;
}
var $ret2692626927 = $Hanf_arg1050126932($z2692226923,anf_arg58188437,l13198439,s_DASH_let_DASH_bind2991899);
++R.GAS;
return $ret2692626927;
};
var $Hanf_arg1050126932 = function(anf_arg582026931,anf_arg58188437,l13198439,s_DASH_let_DASH_bind2991899) {
var $z2693526936 = D;
var $f2694126942 = function(_) {
return R.isFunction(s_DASH_let_DASH_bind2991899.$var)?s_DASH_let_DASH_bind2991899.$var.app(l13198439,anf_arg58188437,anf_arg582026931):R.ffi.throwNonFunApp(L[1680],s_DASH_let_DASH_bind2991899.$var,[l13198439,anf_arg58188437,anf_arg582026931]);
};
try {
if(--R.GAS > 0) {
$z2693526936 = $f2694126942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2694126942,
"from":L[1680]});
}
} catch($e2693326934) {
if(R.isCont($e2693326934)) {
var $ss2693726938 = {"from":L[1680],
"go":function(ann_DASH_check_DASH_temp581626943) {
return $Hann_DASH_check_DASH_temp1050026944(ann_DASH_check_DASH_temp581626943);
}};
$e2693326934.stack[R.EXN_STACKHEIGHT++] = $ss2693726938;
}
if(R.isPyretException($e2693326934)) {
$e2693326934.pyretStack.push(L[1680]);
}
throw $e2693326934;
}
var $ret2693926940 = $Hann_DASH_check_DASH_temp1050026944($z2693526936);
++R.GAS;
return $ret2693926940;
};
var $Hann_DASH_check_DASH_temp1050026944 = function(ann_DASH_check_DASH_temp581626943) {
return ann_DASH_check_DASH_temp581626943;
};
var $Hanf_arg104998457 = function(anf_arg58128454,expr13178455,l13158456,s_DASH_var_DASH_bind3011903,self13148453) {
var anf_fun581326955 = G(expr13178455,"visit",L[3919]);
var $z2694726948 = D;
var $f2695326954 = function(_) {
return R.isFunction(anf_fun581326955)?anf_fun581326955.app(self13148453):R.ffi.throwNonFunApp(L[3918],anf_fun581326955,[self13148453]);
};
try {
if(--R.GAS > 0) {
$z2694726948 = $f2695326954();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2695326954,
"from":L[3918]});
}
} catch($e2694526946) {
if(R.isCont($e2694526946)) {
var $ss2694926950 = {"from":L[3918],
"go":function(anf_arg581426956) {
return $Hanf_arg1049826957(anf_arg581426956,anf_arg58128454,l13158456,s_DASH_var_DASH_bind3011903);
}};
$e2694526946.stack[R.EXN_STACKHEIGHT++] = $ss2694926950;
}
if(R.isPyretException($e2694526946)) {
$e2694526946.pyretStack.push(L[3918]);
}
throw $e2694526946;
}
var $ret2695126952 = $Hanf_arg1049826957($z2694726948,anf_arg58128454,l13158456,s_DASH_var_DASH_bind3011903);
++R.GAS;
return $ret2695126952;
};
var $Hanf_arg1049826957 = function(anf_arg581426956,anf_arg58128454,l13158456,s_DASH_var_DASH_bind3011903) {
var $z2696026961 = D;
var $f2696626967 = function(_) {
return R.isFunction(s_DASH_var_DASH_bind3011903.$var)?s_DASH_var_DASH_bind3011903.$var.app(l13158456,anf_arg58128454,anf_arg581426956):R.ffi.throwNonFunApp(L[1683],s_DASH_var_DASH_bind3011903.$var,[l13158456,anf_arg58128454,anf_arg581426956]);
};
try {
if(--R.GAS > 0) {
$z2696026961 = $f2696626967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2696626967,
"from":L[1683]});
}
} catch($e2695826959) {
if(R.isCont($e2695826959)) {
var $ss2696226963 = {"from":L[1683],
"go":function(ann_DASH_check_DASH_temp581026968) {
return $Hann_DASH_check_DASH_temp1049726969(ann_DASH_check_DASH_temp581026968);
}};
$e2695826959.stack[R.EXN_STACKHEIGHT++] = $ss2696226963;
}
if(R.isPyretException($e2695826959)) {
$e2695826959.pyretStack.push(L[1683]);
}
throw $e2695826959;
}
var $ret2696426965 = $Hann_DASH_check_DASH_temp1049726969($z2696026961);
++R.GAS;
return $ret2696426965;
};
var $Hann_DASH_check_DASH_temp1049726969 = function(ann_DASH_check_DASH_temp581026968) {
return ann_DASH_check_DASH_temp581026968;
};
var $Hanf_arg104968475 = function(anf_arg58068471,ann13138472,l13108473,s_DASH_bind4382177,self13098470,shadows13118474) {
var anf_fun580726980 = G(ann13138472,"visit",L[3921]);
var $z2697226973 = D;
var $f2697826979 = function(_) {
return R.isFunction(anf_fun580726980)?anf_fun580726980.app(self13098470):R.ffi.throwNonFunApp(L[3920],anf_fun580726980,[self13098470]);
};
try {
if(--R.GAS > 0) {
$z2697226973 = $f2697826979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2697826979,
"from":L[3920]});
}
} catch($e2697026971) {
if(R.isCont($e2697026971)) {
var $ss2697426975 = {"from":L[3920],
"go":function(anf_arg580826981) {
return $Hanf_arg1049526982(anf_arg580826981,anf_arg58068471,l13108473,s_DASH_bind4382177,shadows13118474);
}};
$e2697026971.stack[R.EXN_STACKHEIGHT++] = $ss2697426975;
}
if(R.isPyretException($e2697026971)) {
$e2697026971.pyretStack.push(L[3920]);
}
throw $e2697026971;
}
var $ret2697626977 = $Hanf_arg1049526982($z2697226973,anf_arg58068471,l13108473,s_DASH_bind4382177,shadows13118474);
++R.GAS;
return $ret2697626977;
};
var $Hanf_arg1049526982 = function(anf_arg580826981,anf_arg58068471,l13108473,s_DASH_bind4382177,shadows13118474) {
var $z2698526986 = D;
var $f2699126992 = function(_) {
return R.isFunction(s_DASH_bind4382177.$var)?s_DASH_bind4382177.$var.app(l13108473,shadows13118474,anf_arg58068471,anf_arg580826981):R.ffi.throwNonFunApp(L[1686],s_DASH_bind4382177.$var,[l13108473,shadows13118474,anf_arg58068471,anf_arg580826981]);
};
try {
if(--R.GAS > 0) {
$z2698526986 = $f2699126992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2699126992,
"from":L[1686]});
}
} catch($e2698326984) {
if(R.isCont($e2698326984)) {
var $ss2698726988 = {"from":L[1686],
"go":function(ann_DASH_check_DASH_temp580426993) {
return $Hann_DASH_check_DASH_temp1049426994(ann_DASH_check_DASH_temp580426993);
}};
$e2698326984.stack[R.EXN_STACKHEIGHT++] = $ss2698726988;
}
if(R.isPyretException($e2698326984)) {
$e2698326984.pyretStack.push(L[1686]);
}
throw $e2698326984;
}
var $ret2698926990 = $Hann_DASH_check_DASH_temp1049426994($z2698526986);
++R.GAS;
return $ret2698926990;
};
var $Hann_DASH_check_DASH_temp1049426994 = function(ann_DASH_check_DASH_temp580426993) {
return ann_DASH_check_DASH_temp580426993;
};
var $Hann_DASH_check_DASH_temp104938489 = function(ann_DASH_check_DASH_temp58028488) {
return ann_DASH_check_DASH_temp58028488;
};
var $Hann_DASH_check_DASH_temp104928503 = function(ann_DASH_check_DASH_temp58008502) {
return ann_DASH_check_DASH_temp58008502;
};
var $Hanf_arg104918519 = function(anf_arg57988517,l13038518,s_DASH_provide_DASH_types2781857) {
var $z2699726998 = D;
var $f2700327004 = function(_) {
return R.isFunction(s_DASH_provide_DASH_types2781857.$var)?s_DASH_provide_DASH_types2781857.$var.app(l13038518,anf_arg57988517):R.ffi.throwNonFunApp(L[1692],s_DASH_provide_DASH_types2781857.$var,[l13038518,anf_arg57988517]);
};
try {
if(--R.GAS > 0) {
$z2699726998 = $f2700327004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2700327004,
"from":L[1692]});
}
} catch($e2699526996) {
if(R.isCont($e2699526996)) {
var $ss2699927000 = {"from":L[1692],
"go":function(ann_DASH_check_DASH_temp579327005) {
return $Hann_DASH_check_DASH_temp1049027006(ann_DASH_check_DASH_temp579327005);
}};
$e2699526996.stack[R.EXN_STACKHEIGHT++] = $ss2699927000;
}
if(R.isPyretException($e2699526996)) {
$e2699526996.pyretStack.push(L[1692]);
}
throw $e2699526996;
}
var $ret2700127002 = $Hann_DASH_check_DASH_temp1049027006($z2699726998);
++R.GAS;
return $ret2700127002;
};
var $Hann_DASH_check_DASH_temp1049027006 = function(ann_DASH_check_DASH_temp579327005) {
return ann_DASH_check_DASH_temp579327005;
};
var $Hann_DASH_check_DASH_temp104898534 = function(ann_DASH_check_DASH_temp57958533) {
return ann_DASH_check_DASH_temp57958533;
};
var $Hann_DASH_check_DASH_temp104888548 = function(ann_DASH_check_DASH_temp57918547) {
return ann_DASH_check_DASH_temp57918547;
};
var $Hann_DASH_check_DASH_temp104878562 = function(ann_DASH_check_DASH_temp57898561) {
return ann_DASH_check_DASH_temp57898561;
};
var $Hanf_arg104868578 = function(anf_arg57878576,l12968577,s_DASH_provide2691839) {
var $z2700927010 = D;
var $f2701527016 = function(_) {
return R.isFunction(s_DASH_provide2691839.$var)?s_DASH_provide2691839.$var.app(l12968577,anf_arg57878576):R.ffi.throwNonFunApp(L[1697],s_DASH_provide2691839.$var,[l12968577,anf_arg57878576]);
};
try {
if(--R.GAS > 0) {
$z2700927010 = $f2701527016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2701527016,
"from":L[1697]});
}
} catch($e2700727008) {
if(R.isCont($e2700727008)) {
var $ss2701127012 = {"from":L[1697],
"go":function(ann_DASH_check_DASH_temp578527017) {
return $Hann_DASH_check_DASH_temp1048527018(ann_DASH_check_DASH_temp578527017);
}};
$e2700727008.stack[R.EXN_STACKHEIGHT++] = $ss2701127012;
}
if(R.isPyretException($e2700727008)) {
$e2700727008.pyretStack.push(L[1697]);
}
throw $e2700727008;
}
var $ret2701327014 = $Hann_DASH_check_DASH_temp1048527018($z2700927010);
++R.GAS;
return $ret2701327014;
};
var $Hann_DASH_check_DASH_temp1048527018 = function(ann_DASH_check_DASH_temp578527017) {
return ann_DASH_check_DASH_temp578527017;
};
var $Hanf_arg104848595 = function(anf_arg57838592,import_DASH_type12948593,l12928594,s_DASH_import_DASH_fields2641829) {
var $z2702127022 = D;
var $f2702727028 = function(_) {
return R.isFunction(s_DASH_import_DASH_fields2641829.$var)?s_DASH_import_DASH_fields2641829.$var.app(l12928594,anf_arg57838592,import_DASH_type12948593):R.ffi.throwNonFunApp(L[1701],s_DASH_import_DASH_fields2641829.$var,[l12928594,anf_arg57838592,import_DASH_type12948593]);
};
try {
if(--R.GAS > 0) {
$z2702127022 = $f2702727028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2702727028,
"from":L[1701]});
}
} catch($e2701927020) {
if(R.isCont($e2701927020)) {
var $ss2702327024 = {"from":L[1701],
"go":function(ann_DASH_check_DASH_temp577827029) {
return $Hann_DASH_check_DASH_temp1048327030(ann_DASH_check_DASH_temp577827029);
}};
$e2701927020.stack[R.EXN_STACKHEIGHT++] = $ss2702327024;
}
if(R.isPyretException($e2701927020)) {
$e2701927020.pyretStack.push(L[1701]);
}
throw $e2701927020;
}
var $ret2702527026 = $Hann_DASH_check_DASH_temp1048327030($z2702127022);
++R.GAS;
return $ret2702527026;
};
var $Hann_DASH_check_DASH_temp1048327030 = function(ann_DASH_check_DASH_temp577827029) {
return ann_DASH_check_DASH_temp577827029;
};
var $Hann_DASH_check_DASH_temp104828610 = function(ann_DASH_check_DASH_temp57808609) {
return ann_DASH_check_DASH_temp57808609;
};
var $Hanf_arg104818628 = function(anf_arg57748624,import_DASH_type12888625,l12878626,s_DASH_import_DASH_types2621825,self12868623,types12908627) {
var anf_fun577527041 = G(types12908627,"visit",L[3923]);
var $z2703327034 = D;
var $f2703927040 = function(_) {
return R.isFunction(anf_fun577527041)?anf_fun577527041.app(self12868623):R.ffi.throwNonFunApp(L[3922],anf_fun577527041,[self12868623]);
};
try {
if(--R.GAS > 0) {
$z2703327034 = $f2703927040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2703927040,
"from":L[3922]});
}
} catch($e2703127032) {
if(R.isCont($e2703127032)) {
var $ss2703527036 = {"from":L[3922],
"go":function(anf_arg577627042) {
return $Hanf_arg1048027043(anf_arg577627042,anf_arg57748624,import_DASH_type12888625,l12878626,s_DASH_import_DASH_types2621825);
}};
$e2703127032.stack[R.EXN_STACKHEIGHT++] = $ss2703527036;
}
if(R.isPyretException($e2703127032)) {
$e2703127032.pyretStack.push(L[3922]);
}
throw $e2703127032;
}
var $ret2703727038 = $Hanf_arg1048027043($z2703327034,anf_arg57748624,import_DASH_type12888625,l12878626,s_DASH_import_DASH_types2621825);
++R.GAS;
return $ret2703727038;
};
var $Hanf_arg1048027043 = function(anf_arg577627042,anf_arg57748624,import_DASH_type12888625,l12878626,s_DASH_import_DASH_types2621825) {
var $z2704627047 = D;
var $f2705227053 = function(_) {
return R.isFunction(s_DASH_import_DASH_types2621825.$var)?s_DASH_import_DASH_types2621825.$var.app(l12878626,import_DASH_type12888625,anf_arg57748624,anf_arg577627042):R.ffi.throwNonFunApp(L[1704],s_DASH_import_DASH_types2621825.$var,[l12878626,import_DASH_type12888625,anf_arg57748624,anf_arg577627042]);
};
try {
if(--R.GAS > 0) {
$z2704627047 = $f2705227053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2705227053,
"from":L[1704]});
}
} catch($e2704427045) {
if(R.isCont($e2704427045)) {
var $ss2704827049 = {"from":L[1704],
"go":function(ann_DASH_check_DASH_temp577227054) {
return $Hann_DASH_check_DASH_temp1047927055(ann_DASH_check_DASH_temp577227054);
}};
$e2704427045.stack[R.EXN_STACKHEIGHT++] = $ss2704827049;
}
if(R.isPyretException($e2704427045)) {
$e2704427045.pyretStack.push(L[1704]);
}
throw $e2704427045;
}
var $ret2705027051 = $Hann_DASH_check_DASH_temp1047927055($z2704627047);
++R.GAS;
return $ret2705027051;
};
var $Hann_DASH_check_DASH_temp1047927055 = function(ann_DASH_check_DASH_temp577227054) {
return ann_DASH_check_DASH_temp577227054;
};
var $Hann_DASH_check_DASH_temp104788643 = function(ann_DASH_check_DASH_temp57708642) {
return ann_DASH_check_DASH_temp57708642;
};
var $Hann_DASH_check_DASH_temp104778658 = function(ann_DASH_check_DASH_temp57688657) {
return ann_DASH_check_DASH_temp57688657;
};
var $Hanf_arg104768675 = function(anf_arg57648672,l12778673,name12798674,s_DASH_import2601821,self12768671) {
var anf_fun576527066 = G(name12798674,"visit",L[3925]);
var $z2705827059 = D;
var $f2706427065 = function(_) {
return R.isFunction(anf_fun576527066)?anf_fun576527066.app(self12768671):R.ffi.throwNonFunApp(L[3924],anf_fun576527066,[self12768671]);
};
try {
if(--R.GAS > 0) {
$z2705827059 = $f2706427065();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2706427065,
"from":L[3924]});
}
} catch($e2705627057) {
if(R.isCont($e2705627057)) {
var $ss2706027061 = {"from":L[3924],
"go":function(anf_arg576627067) {
return $Hanf_arg1047527068(anf_arg576627067,anf_arg57648672,l12778673,s_DASH_import2601821);
}};
$e2705627057.stack[R.EXN_STACKHEIGHT++] = $ss2706027061;
}
if(R.isPyretException($e2705627057)) {
$e2705627057.pyretStack.push(L[3924]);
}
throw $e2705627057;
}
var $ret2706227063 = $Hanf_arg1047527068($z2705827059,anf_arg57648672,l12778673,s_DASH_import2601821);
++R.GAS;
return $ret2706227063;
};
var $Hanf_arg1047527068 = function(anf_arg576627067,anf_arg57648672,l12778673,s_DASH_import2601821) {
var $z2707127072 = D;
var $f2707727078 = function(_) {
return R.isFunction(s_DASH_import2601821.$var)?s_DASH_import2601821.$var.app(l12778673,anf_arg57648672,anf_arg576627067):R.ffi.throwNonFunApp(L[1709],s_DASH_import2601821.$var,[l12778673,anf_arg57648672,anf_arg576627067]);
};
try {
if(--R.GAS > 0) {
$z2707127072 = $f2707727078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2707727078,
"from":L[1709]});
}
} catch($e2706927070) {
if(R.isCont($e2706927070)) {
var $ss2707327074 = {"from":L[1709],
"go":function(ann_DASH_check_DASH_temp576227079) {
return $Hann_DASH_check_DASH_temp1047427080(ann_DASH_check_DASH_temp576227079);
}};
$e2706927070.stack[R.EXN_STACKHEIGHT++] = $ss2707327074;
}
if(R.isPyretException($e2706927070)) {
$e2706927070.pyretStack.push(L[1709]);
}
throw $e2706927070;
}
var $ret2707527076 = $Hann_DASH_check_DASH_temp1047427080($z2707127072);
++R.GAS;
return $ret2707527076;
};
var $Hann_DASH_check_DASH_temp1047427080 = function(ann_DASH_check_DASH_temp576227079) {
return ann_DASH_check_DASH_temp576227079;
};
var $Hanf_arg104738694 = function(anf_arg57518689,body12758690,imports12748691,l12718692,provided_DASH_types12738693,s_DASH_program2551811,self12708688) {
var anf_fun575227091 = G(provided_DASH_types12738693,"visit",L[3927]);
var $z2708327084 = D;
var $f2708927090 = function(_) {
return R.isFunction(anf_fun575227091)?anf_fun575227091.app(self12708688):R.ffi.throwNonFunApp(L[3926],anf_fun575227091,[self12708688]);
};
try {
if(--R.GAS > 0) {
$z2708327084 = $f2708927090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2708927090,
"from":L[3926]});
}
} catch($e2708127082) {
if(R.isCont($e2708127082)) {
var $ss2708527086 = {"from":L[3926],
"go":function(anf_arg575327092) {
return $Hanf_arg1047227093(anf_arg575327092,anf_arg57518689,body12758690,imports12748691,l12718692,s_DASH_program2551811,self12708688);
}};
$e2708127082.stack[R.EXN_STACKHEIGHT++] = $ss2708527086;
}
if(R.isPyretException($e2708127082)) {
$e2708127082.pyretStack.push(L[3926]);
}
throw $e2708127082;
}
var $ret2708727088 = $Hanf_arg1047227093($z2708327084,anf_arg57518689,body12758690,imports12748691,l12718692,s_DASH_program2551811,self12708688);
++R.GAS;
return $ret2708727088;
};
var $Hanf_arg1047227093 = function(anf_arg575327092,anf_arg57518689,body12758690,imports12748691,l12718692,s_DASH_program2551811,self12708688) {
var anf_fun575427104 = G(imports12748691,"map",L[3930]);
var anf_arg575727105 = R.makeFunction(function(recv_DASH_71727108) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3929],1,arguments);
}
var anf_fun575627119 = G(recv_DASH_71727108,"visit",L[3929]);
var $z2711127112 = D;
var $f2711727118 = function(_) {
return R.isFunction(anf_fun575627119)?anf_fun575627119.app(self12708688):R.ffi.throwNonFunApp(L[3929],anf_fun575627119,[self12708688]);
};
try {
if(--R.GAS > 0) {
$z2711127112 = $f2711727118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2711727118,
"from":L[3929]});
}
} catch($e2710927110) {
if(R.isCont($e2710927110)) {
var $ss2711327114 = {"from":L[3929],
"go":function(ann_DASH_check_DASH_temp575527120) {
return $Hann_DASH_check_DASH_temp1046827121(ann_DASH_check_DASH_temp575527120);
}};
$e2710927110.stack[R.EXN_STACKHEIGHT++] = $ss2711327114;
}
if(R.isPyretException($e2710927110)) {
$e2710927110.pyretStack.push(L[3929]);
}
throw $e2710927110;
}
var $ret2711527116 = $Hann_DASH_check_DASH_temp1046827121($z2711127112);
++R.GAS;
return $ret2711527116;
});
var $z2709627097 = D;
var $f2710227103 = function(_) {
return R.isFunction(anf_fun575427104)?anf_fun575427104.app(anf_arg575727105):R.ffi.throwNonFunApp(L[3928],anf_fun575427104,[anf_arg575727105]);
};
try {
if(--R.GAS > 0) {
$z2709627097 = $f2710227103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2710227103,
"from":L[3928]});
}
} catch($e2709427095) {
if(R.isCont($e2709427095)) {
var $ss2709827099 = {"from":L[3928],
"go":function(anf_arg575827106) {
return $Hanf_arg1047127107(anf_arg575827106,anf_arg57518689,anf_arg575327092,body12758690,l12718692,s_DASH_program2551811,self12708688);
}};
$e2709427095.stack[R.EXN_STACKHEIGHT++] = $ss2709827099;
}
if(R.isPyretException($e2709427095)) {
$e2709427095.pyretStack.push(L[3928]);
}
throw $e2709427095;
}
var $ret2710027101 = $Hanf_arg1047127107($z2709627097,anf_arg57518689,anf_arg575327092,body12758690,l12718692,s_DASH_program2551811,self12708688);
++R.GAS;
return $ret2710027101;
};
var $Hanf_arg1047127107 = function(anf_arg575827106,anf_arg57518689,anf_arg575327092,body12758690,l12718692,s_DASH_program2551811,self12708688) {
var anf_fun575927132 = G(body12758690,"visit",L[3932]);
var $z2712427125 = D;
var $f2713027131 = function(_) {
return R.isFunction(anf_fun575927132)?anf_fun575927132.app(self12708688):R.ffi.throwNonFunApp(L[3931],anf_fun575927132,[self12708688]);
};
try {
if(--R.GAS > 0) {
$z2712427125 = $f2713027131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2713027131,
"from":L[3931]});
}
} catch($e2712227123) {
if(R.isCont($e2712227123)) {
var $ss2712627127 = {"from":L[3931],
"go":function(anf_arg576027133) {
return $Hanf_arg1047027134(anf_arg576027133,anf_arg57518689,anf_arg575327092,anf_arg575827106,l12718692,s_DASH_program2551811);
}};
$e2712227123.stack[R.EXN_STACKHEIGHT++] = $ss2712627127;
}
if(R.isPyretException($e2712227123)) {
$e2712227123.pyretStack.push(L[3931]);
}
throw $e2712227123;
}
var $ret2712827129 = $Hanf_arg1047027134($z2712427125,anf_arg57518689,anf_arg575327092,anf_arg575827106,l12718692,s_DASH_program2551811);
++R.GAS;
return $ret2712827129;
};
var $Hanf_arg1047027134 = function(anf_arg576027133,anf_arg57518689,anf_arg575327092,anf_arg575827106,l12718692,s_DASH_program2551811) {
var $z2713727138 = D;
var $f2714327144 = function(_) {
return R.isFunction(s_DASH_program2551811.$var)?s_DASH_program2551811.$var.app(l12718692,anf_arg57518689,anf_arg575327092,anf_arg575827106,anf_arg576027133):R.ffi.throwNonFunApp(L[1712],s_DASH_program2551811.$var,[l12718692,anf_arg57518689,anf_arg575327092,anf_arg575827106,anf_arg576027133]);
};
try {
if(--R.GAS > 0) {
$z2713727138 = $f2714327144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2714327144,
"from":L[1712]});
}
} catch($e2713527136) {
if(R.isCont($e2713527136)) {
var $ss2713927140 = {"from":L[1712],
"go":function(ann_DASH_check_DASH_temp574927145) {
return $Hann_DASH_check_DASH_temp1046927146(ann_DASH_check_DASH_temp574927145);
}};
$e2713527136.stack[R.EXN_STACKHEIGHT++] = $ss2713927140;
}
if(R.isPyretException($e2713527136)) {
$e2713527136.pyretStack.push(L[1712]);
}
throw $e2713527136;
}
var $ret2714127142 = $Hann_DASH_check_DASH_temp1046927146($z2713727138);
++R.GAS;
return $ret2714127142;
};
var $Hann_DASH_check_DASH_temp1046927146 = function(ann_DASH_check_DASH_temp574927145) {
return ann_DASH_check_DASH_temp574927145;
};
var $Hann_DASH_check_DASH_temp1046827121 = function(ann_DASH_check_DASH_temp575527120) {
return ann_DASH_check_DASH_temp575527120;
};
var $Hanf_arg104678713 = function(anf_arg57388708,checks12698709,l12658710,lists974,provides12678711,s_DASH_module3181937,self12648707,types12688712) {
var anf_fun573927157 = G(provides12678711,"visit",L[3934]);
var $z2714927150 = D;
var $f2715527156 = function(_) {
return R.isFunction(anf_fun573927157)?anf_fun573927157.app(self12648707):R.ffi.throwNonFunApp(L[3933],anf_fun573927157,[self12648707]);
};
try {
if(--R.GAS > 0) {
$z2714927150 = $f2715527156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2715527156,
"from":L[3933]});
}
} catch($e2714727148) {
if(R.isCont($e2714727148)) {
var $ss2715127152 = {"from":L[3933],
"go":function(anf_arg574027158) {
return $Hanf_arg1046627159(anf_arg574027158,anf_arg57388708,checks12698709,l12658710,lists974,s_DASH_module3181937,self12648707,types12688712);
}};
$e2714727148.stack[R.EXN_STACKHEIGHT++] = $ss2715127152;
}
if(R.isPyretException($e2714727148)) {
$e2714727148.pyretStack.push(L[3933]);
}
throw $e2714727148;
}
var $ret2715327154 = $Hanf_arg1046627159($z2714927150,anf_arg57388708,checks12698709,l12658710,lists974,s_DASH_module3181937,self12648707,types12688712);
++R.GAS;
return $ret2715327154;
};
var $Hanf_arg1046627159 = function(anf_arg574027158,anf_arg57388708,checks12698709,l12658710,lists974,s_DASH_module3181937,self12648707,types12688712) {
var anf_fun574127170 = G(lists974,"map",L[3937]);
var anf_arg574427171 = R.makeFunction(function(recv_DASH_71627174) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3936],1,arguments);
}
var anf_fun574327185 = G(recv_DASH_71627174,"visit",L[3936]);
var $z2717727178 = D;
var $f2718327184 = function(_) {
return R.isFunction(anf_fun574327185)?anf_fun574327185.app(self12648707):R.ffi.throwNonFunApp(L[3936],anf_fun574327185,[self12648707]);
};
try {
if(--R.GAS > 0) {
$z2717727178 = $f2718327184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2718327184,
"from":L[3936]});
}
} catch($e2717527176) {
if(R.isCont($e2717527176)) {
var $ss2717927180 = {"from":L[3936],
"go":function(ann_DASH_check_DASH_temp574227186) {
return $Hann_DASH_check_DASH_temp1046227187(ann_DASH_check_DASH_temp574227186);
}};
$e2717527176.stack[R.EXN_STACKHEIGHT++] = $ss2717927180;
}
if(R.isPyretException($e2717527176)) {
$e2717527176.pyretStack.push(L[3936]);
}
throw $e2717527176;
}
var $ret2718127182 = $Hann_DASH_check_DASH_temp1046227187($z2717727178);
++R.GAS;
return $ret2718127182;
});
var $z2716227163 = D;
var $f2716827169 = function(_) {
return R.isFunction(anf_fun574127170)?anf_fun574127170.app(anf_arg574427171,types12688712):R.ffi.throwNonFunApp(L[3935],anf_fun574127170,[anf_arg574427171,types12688712]);
};
try {
if(--R.GAS > 0) {
$z2716227163 = $f2716827169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2716827169,
"from":L[3935]});
}
} catch($e2716027161) {
if(R.isCont($e2716027161)) {
var $ss2716427165 = {"from":L[3935],
"go":function(anf_arg574527172) {
return $Hanf_arg1046527173(anf_arg574527172,anf_arg57388708,anf_arg574027158,checks12698709,l12658710,s_DASH_module3181937,self12648707);
}};
$e2716027161.stack[R.EXN_STACKHEIGHT++] = $ss2716427165;
}
if(R.isPyretException($e2716027161)) {
$e2716027161.pyretStack.push(L[3935]);
}
throw $e2716027161;
}
var $ret2716627167 = $Hanf_arg1046527173($z2716227163,anf_arg57388708,anf_arg574027158,checks12698709,l12658710,s_DASH_module3181937,self12648707);
++R.GAS;
return $ret2716627167;
};
var $Hanf_arg1046527173 = function(anf_arg574527172,anf_arg57388708,anf_arg574027158,checks12698709,l12658710,s_DASH_module3181937,self12648707) {
var anf_fun574627198 = G(checks12698709,"visit",L[3939]);
var $z2719027191 = D;
var $f2719627197 = function(_) {
return R.isFunction(anf_fun574627198)?anf_fun574627198.app(self12648707):R.ffi.throwNonFunApp(L[3938],anf_fun574627198,[self12648707]);
};
try {
if(--R.GAS > 0) {
$z2719027191 = $f2719627197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2719627197,
"from":L[3938]});
}
} catch($e2718827189) {
if(R.isCont($e2718827189)) {
var $ss2719227193 = {"from":L[3938],
"go":function(anf_arg574727199) {
return $Hanf_arg1046427200(anf_arg574727199,anf_arg57388708,anf_arg574027158,anf_arg574527172,l12658710,s_DASH_module3181937);
}};
$e2718827189.stack[R.EXN_STACKHEIGHT++] = $ss2719227193;
}
if(R.isPyretException($e2718827189)) {
$e2718827189.pyretStack.push(L[3938]);
}
throw $e2718827189;
}
var $ret2719427195 = $Hanf_arg1046427200($z2719027191,anf_arg57388708,anf_arg574027158,anf_arg574527172,l12658710,s_DASH_module3181937);
++R.GAS;
return $ret2719427195;
};
var $Hanf_arg1046427200 = function(anf_arg574727199,anf_arg57388708,anf_arg574027158,anf_arg574527172,l12658710,s_DASH_module3181937) {
var $z2720327204 = D;
var $f2720927210 = function(_) {
return R.isFunction(s_DASH_module3181937.$var)?s_DASH_module3181937.$var.app(l12658710,anf_arg57388708,anf_arg574027158,anf_arg574527172,anf_arg574727199):R.ffi.throwNonFunApp(L[1715],s_DASH_module3181937.$var,[l12658710,anf_arg57388708,anf_arg574027158,anf_arg574527172,anf_arg574727199]);
};
try {
if(--R.GAS > 0) {
$z2720327204 = $f2720927210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2720927210,
"from":L[1715]});
}
} catch($e2720127202) {
if(R.isCont($e2720127202)) {
var $ss2720527206 = {"from":L[1715],
"go":function(ann_DASH_check_DASH_temp573627211) {
return $Hann_DASH_check_DASH_temp1046327212(ann_DASH_check_DASH_temp573627211);
}};
$e2720127202.stack[R.EXN_STACKHEIGHT++] = $ss2720527206;
}
if(R.isPyretException($e2720127202)) {
$e2720127202.pyretStack.push(L[1715]);
}
throw $e2720127202;
}
var $ret2720727208 = $Hann_DASH_check_DASH_temp1046327212($z2720327204);
++R.GAS;
return $ret2720727208;
};
var $Hann_DASH_check_DASH_temp1046327212 = function(ann_DASH_check_DASH_temp573627211) {
return ann_DASH_check_DASH_temp573627211;
};
var $Hann_DASH_check_DASH_temp1046227187 = function(ann_DASH_check_DASH_temp574227186) {
return ann_DASH_check_DASH_temp574227186;
};
var $Hann_DASH_check_DASH_temp104618728 = function(ann_DASH_check_DASH_temp57348727) {
return ann_DASH_check_DASH_temp57348727;
};
var $Hann_DASH_check_DASH_temp104608742 = function(ann_DASH_check_DASH_temp57328741) {
return ann_DASH_check_DASH_temp57328741;
};
var $Hann_DASH_check_DASH_temp104598756 = function(ann_DASH_check_DASH_temp57308755) {
return ann_DASH_check_DASH_temp57308755;
};
var $Hann_DASH_check_DASH_temp104588771 = function(ann_DASH_check_DASH_temp57288770) {
return ann_DASH_check_DASH_temp57288770;
};
var $Hann_DASH_check_DASH_temp104578785 = function(ann_DASH_check_DASH_temp57268784) {
return ann_DASH_check_DASH_temp57268784;
};
var $Hann_DASH_check_DASH_temp104568801 = function(ann_DASH_check_DASH_temp57148800) {
return ann_DASH_check_DASH_temp57148800;
};
var $Hanf_arg104558819 = function(anf_arg57208818,some62156) {
var $z2721527216 = D;
var $f2722127222 = function(_) {
return R.isFunction(some62156)?some62156.app(anf_arg57208818):R.ffi.throwNonFunApp(L[1723],some62156,[anf_arg57208818]);
};
try {
if(--R.GAS > 0) {
$z2721527216 = $f2722127222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2722127222,
"from":L[1723]});
}
} catch($e2721327214) {
if(R.isCont($e2721327214)) {
var $ss2721727218 = {"from":L[1723],
"go":function(ann_DASH_check_DASH_temp571827223) {
return $Hann_DASH_check_DASH_temp1045427224(ann_DASH_check_DASH_temp571827223);
}};
$e2721327214.stack[R.EXN_STACKHEIGHT++] = $ss2721727218;
}
if(R.isPyretException($e2721327214)) {
$e2721327214.pyretStack.push(L[1723]);
}
throw $e2721327214;
}
var $ret2721927220 = $Hann_DASH_check_DASH_temp1045427224($z2721527216);
++R.GAS;
return $ret2721927220;
};
var $Hann_DASH_check_DASH_temp1045427224 = function(ann_DASH_check_DASH_temp571827223) {
return ann_DASH_check_DASH_temp571827223;
};
var $Hann_DASH_check_DASH_temp104538838 = function(ann_DASH_check_DASH_temp57068837,List17129,Name66133) {
return ann_DASH_check_DASH_temp57068837;
};
var $Hann_DASH_check_DASH_temp104528850 = function(ann_DASH_check_DASH_temp57118849) {
return ann_DASH_check_DASH_temp57118849;
};
var $Hann_DASH_check_DASH_temp104518868 = function(ann_DASH_check_DASH_temp57088867) {
return ann_DASH_check_DASH_temp57088867;
};
var $Hann_DASH_check_DASH_temp104508885 = function(ann_DASH_check_DASH_temp56968884,List17129,Name66133) {
return ann_DASH_check_DASH_temp56968884;
};
var $Hann_DASH_check_DASH_temp104498897 = function(ann_DASH_check_DASH_temp57038896) {
return ann_DASH_check_DASH_temp57038896;
};
var $Hanf_arg104488913 = function(anf_arg57008912,flatten5302361) {
var $z2722727228 = D;
var $f2723327234 = function(_) {
return R.isFunction(flatten5302361.$var)?flatten5302361.$var.app(anf_arg57008912):R.ffi.throwNonFunApp(L[1733],flatten5302361.$var,[anf_arg57008912]);
};
try {
if(--R.GAS > 0) {
$z2722727228 = $f2723327234();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2723327234,
"from":L[1733]});
}
} catch($e2722527226) {
if(R.isCont($e2722527226)) {
var $ss2722927230 = {"from":L[1733],
"go":function(ann_DASH_check_DASH_temp569827235) {
return $Hann_DASH_check_DASH_temp1044727236(ann_DASH_check_DASH_temp569827235);
}};
$e2722527226.stack[R.EXN_STACKHEIGHT++] = $ss2722927230;
}
if(R.isPyretException($e2722527226)) {
$e2722527226.pyretStack.push(L[1733]);
}
throw $e2722527226;
}
var $ret2723127232 = $Hann_DASH_check_DASH_temp1044727236($z2722727228);
++R.GAS;
return $ret2723127232;
};
var $Hann_DASH_check_DASH_temp1044727236 = function(ann_DASH_check_DASH_temp569827235) {
return ann_DASH_check_DASH_temp569827235;
};
var $Hann_DASH_check_DASH_temp104468932 = function(ann_DASH_check_DASH_temp56428931,List17129,Name66133) {
return ann_DASH_check_DASH_temp56428931;
};
var $Hann_DASH_check_DASH_temp104458945 = function(ann_DASH_check_DASH_temp56928944) {
return ann_DASH_check_DASH_temp56928944;
};
var $Hanf_arg104448970 = function(anf_arg56898968,anf_fun56888969) {
var $z2723927240 = D;
var $f2724527246 = function(_) {
return R.isFunction(anf_fun56888969)?anf_fun56888969.app(anf_arg56898968):R.ffi.throwNonFunApp(L[1740],anf_fun56888969,[anf_arg56898968]);
};
try {
if(--R.GAS > 0) {
$z2723927240 = $f2724527246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2724527246,
"from":L[1740]});
}
} catch($e2723727238) {
if(R.isCont($e2723727238)) {
var $ss2724127242 = {"from":L[1740],
"go":function(ann_DASH_check_DASH_temp567827247) {
return $Hann_DASH_check_DASH_temp1044327248(ann_DASH_check_DASH_temp567827247);
}};
$e2723727238.stack[R.EXN_STACKHEIGHT++] = $ss2724127242;
}
if(R.isPyretException($e2723727238)) {
$e2723727238.pyretStack.push(L[1740]);
}
throw $e2723727238;
}
var $ret2724327244 = $Hann_DASH_check_DASH_temp1044327248($z2723927240);
++R.GAS;
return $ret2724327244;
};
var $Hann_DASH_check_DASH_temp1044327248 = function(ann_DASH_check_DASH_temp567827247) {
return ann_DASH_check_DASH_temp567827247;
};
var $Hanf_arg104428984 = function(anf_arg56858982,anf_fun56848983,arg_DASH_7118971,l12328951,link29153,s_DASH_name1901015) {
var $z2725127252 = D;
var $f2725727258 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l12328951,anf_arg56858982):R.ffi.throwNonFunApp(L[3940],s_DASH_name1901015.$var,[l12328951,anf_arg56858982]);
};
try {
if(--R.GAS > 0) {
$z2725127252 = $f2725727258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2725727258,
"from":L[3940]});
}
} catch($e2724927250) {
if(R.isCont($e2724927250)) {
var $ss2725327254 = {"from":L[3940],
"go":function(anf_arg568627259) {
return $Hanf_arg1044127260(anf_arg568627259,anf_fun56848983,arg_DASH_7118971,link29153);
}};
$e2724927250.stack[R.EXN_STACKHEIGHT++] = $ss2725327254;
}
if(R.isPyretException($e2724927250)) {
$e2724927250.pyretStack.push(L[3940]);
}
throw $e2724927250;
}
var $ret2725527256 = $Hanf_arg1044127260($z2725127252,anf_fun56848983,arg_DASH_7118971,link29153);
++R.GAS;
return $ret2725527256;
};
var $Hanf_arg1044127260 = function(anf_arg568627259,anf_fun56848983,arg_DASH_7118971,link29153) {
var $z2726327264 = D;
var $f2726927270 = function(_) {
return R.isFunction(anf_fun56848983)?anf_fun56848983.app(anf_arg568627259):R.ffi.throwNonFunApp(L[1744],anf_fun56848983,[anf_arg568627259]);
};
try {
if(--R.GAS > 0) {
$z2726327264 = $f2726927270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2726927270,
"from":L[1744]});
}
} catch($e2726127262) {
if(R.isCont($e2726127262)) {
var $ss2726527266 = {"from":L[1744],
"go":function(anf_arg568727271) {
return $Hanf_arg1044027272(anf_arg568727271,arg_DASH_7118971,link29153);
}};
$e2726127262.stack[R.EXN_STACKHEIGHT++] = $ss2726527266;
}
if(R.isPyretException($e2726127262)) {
$e2726127262.pyretStack.push(L[1744]);
}
throw $e2726127262;
}
var $ret2726727268 = $Hanf_arg1044027272($z2726327264,arg_DASH_7118971,link29153);
++R.GAS;
return $ret2726727268;
};
var $Hanf_arg1044027272 = function(anf_arg568727271,arg_DASH_7118971,link29153) {
var $z2727527276 = D;
var $f2728127282 = function(_) {
return R.isFunction(link29153)?link29153.app(arg_DASH_7118971,anf_arg568727271):R.ffi.throwNonFunApp(L[1742],link29153,[arg_DASH_7118971,anf_arg568727271]);
};
try {
if(--R.GAS > 0) {
$z2727527276 = $f2728127282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2728127282,
"from":L[1742]});
}
} catch($e2727327274) {
if(R.isCont($e2727327274)) {
var $ss2727727278 = {"from":L[1742],
"go":function(ann_DASH_check_DASH_temp567927283) {
return $Hann_DASH_check_DASH_temp1043927284(ann_DASH_check_DASH_temp567927283);
}};
$e2727327274.stack[R.EXN_STACKHEIGHT++] = $ss2727727278;
}
if(R.isPyretException($e2727327274)) {
$e2727327274.pyretStack.push(L[1742]);
}
throw $e2727327274;
}
var $ret2727927280 = $Hann_DASH_check_DASH_temp1043927284($z2727527276);
++R.GAS;
return $ret2727927280;
};
var $Hann_DASH_check_DASH_temp1043927284 = function(ann_DASH_check_DASH_temp567927283) {
return ann_DASH_check_DASH_temp567927283;
};
var $Hanf_arg104388998 = function(anf_arg56828997,arg_DASH_7108985,flatten5302361,link29153) {
var $z2728727288 = D;
var $f2729327294 = function(_) {
return R.isFunction(flatten5302361.$var)?flatten5302361.$var.app(anf_arg56828997):R.ffi.throwNonFunApp(L[3941],flatten5302361.$var,[anf_arg56828997]);
};
try {
if(--R.GAS > 0) {
$z2728727288 = $f2729327294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2729327294,
"from":L[3941]});
}
} catch($e2728527286) {
if(R.isCont($e2728527286)) {
var $ss2728927290 = {"from":L[3941],
"go":function(anf_arg568327295) {
return $Hanf_arg1043727296(anf_arg568327295,arg_DASH_7108985,link29153);
}};
$e2728527286.stack[R.EXN_STACKHEIGHT++] = $ss2728927290;
}
if(R.isPyretException($e2728527286)) {
$e2728527286.pyretStack.push(L[3941]);
}
throw $e2728527286;
}
var $ret2729127292 = $Hanf_arg1043727296($z2728727288,arg_DASH_7108985,link29153);
++R.GAS;
return $ret2729127292;
};
var $Hanf_arg1043727296 = function(anf_arg568327295,arg_DASH_7108985,link29153) {
var $z2729927300 = D;
var $f2730527306 = function(_) {
return R.isFunction(link29153)?link29153.app(arg_DASH_7108985,anf_arg568327295):R.ffi.throwNonFunApp(L[1744],link29153,[arg_DASH_7108985,anf_arg568327295]);
};
try {
if(--R.GAS > 0) {
$z2729927300 = $f2730527306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2730527306,
"from":L[1744]});
}
} catch($e2729727298) {
if(R.isCont($e2729727298)) {
var $ss2730127302 = {"from":L[1744],
"go":function(ann_DASH_check_DASH_temp568027307) {
return $Hann_DASH_check_DASH_temp1043627308(ann_DASH_check_DASH_temp568027307);
}};
$e2729727298.stack[R.EXN_STACKHEIGHT++] = $ss2730127302;
}
if(R.isPyretException($e2729727298)) {
$e2729727298.pyretStack.push(L[1744]);
}
throw $e2729727298;
}
var $ret2730327304 = $Hann_DASH_check_DASH_temp1043627308($z2729927300);
++R.GAS;
return $ret2730327304;
};
var $Hann_DASH_check_DASH_temp1043627308 = function(ann_DASH_check_DASH_temp568027307) {
return ann_DASH_check_DASH_temp568027307;
};
var $Hanf_arg104359013 = function(anf_arg56769012,flatten5302361) {
var $z2731127312 = D;
var $f2731727318 = function(_) {
return R.isFunction(flatten5302361.$var)?flatten5302361.$var.app(anf_arg56769012):R.ffi.throwNonFunApp(L[1747],flatten5302361.$var,[anf_arg56769012]);
};
try {
if(--R.GAS > 0) {
$z2731127312 = $f2731727318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2731727318,
"from":L[1747]});
}
} catch($e2730927310) {
if(R.isCont($e2730927310)) {
var $ss2731327314 = {"from":L[1747],
"go":function(ann_DASH_check_DASH_temp567427319) {
return $Hann_DASH_check_DASH_temp1043427320(ann_DASH_check_DASH_temp567427319);
}};
$e2730927310.stack[R.EXN_STACKHEIGHT++] = $ss2731327314;
}
if(R.isPyretException($e2730927310)) {
$e2730927310.pyretStack.push(L[1747]);
}
throw $e2730927310;
}
var $ret2731527316 = $Hann_DASH_check_DASH_temp1043427320($z2731127312);
++R.GAS;
return $ret2731527316;
};
var $Hann_DASH_check_DASH_temp1043427320 = function(ann_DASH_check_DASH_temp567427319) {
return ann_DASH_check_DASH_temp567427319;
};
var $Hanf_array_val104339034 = function(anf_array_val56729032,anf_fun56719033) {
var $z2732327324 = D;
var $f2732927330 = function(_) {
return R.isFunction(anf_fun56719033)?anf_fun56719033.app([anf_array_val56729032]):R.ffi.throwNonFunApp(L[1750],anf_fun56719033,[[anf_array_val56729032]]);
};
try {
if(--R.GAS > 0) {
$z2732327324 = $f2732927330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2732927330,
"from":L[1750]});
}
} catch($e2732127322) {
if(R.isCont($e2732127322)) {
var $ss2732527326 = {"from":L[1750],
"go":function(ann_DASH_check_DASH_temp567027331) {
return $Hann_DASH_check_DASH_temp1043227332(ann_DASH_check_DASH_temp567027331);
}};
$e2732127322.stack[R.EXN_STACKHEIGHT++] = $ss2732527326;
}
if(R.isPyretException($e2732127322)) {
$e2732127322.pyretStack.push(L[1750]);
}
throw $e2732127322;
}
var $ret2732727328 = $Hann_DASH_check_DASH_temp1043227332($z2732327324);
++R.GAS;
return $ret2732727328;
};
var $Hann_DASH_check_DASH_temp1043227332 = function(ann_DASH_check_DASH_temp567027331) {
return ann_DASH_check_DASH_temp567027331;
};
var $Hann_DASH_check_DASH_temp104319051 = function(ann_DASH_check_DASH_temp56669050) {
return ann_DASH_check_DASH_temp56669050;
};
var $Hann_DASH_check_DASH_temp104309069 = function(ann_DASH_check_DASH_temp56629068) {
return ann_DASH_check_DASH_temp56629068;
};
var $Hann_DASH_check_DASH_temp104299086 = function(ann_DASH_check_DASH_temp56439085) {
return ann_DASH_check_DASH_temp56439085;
};
var $Hanf_array_val104289105 = function(anf_array_val56539103,anf_fun56529104,l12129090,make_DASH_checker_DASH_name5292359,name12139091,s_DASH_name1901015) {
var $z2733527336 = D;
var $f2734127342 = function(_) {
return R.isFunction(make_DASH_checker_DASH_name5292359.$var)?make_DASH_checker_DASH_name5292359.$var.app(name12139091):R.ffi.throwNonFunApp(L[3942],make_DASH_checker_DASH_name5292359.$var,[name12139091]);
};
try {
if(--R.GAS > 0) {
$z2733527336 = $f2734127342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2734127342,
"from":L[3942]});
}
} catch($e2733327334) {
if(R.isCont($e2733327334)) {
var $ss2733727338 = {"from":L[3942],
"go":function(anf_arg565427343) {
return $Hanf_arg1042727344(anf_arg565427343,anf_array_val56539103,anf_fun56529104,l12129090,s_DASH_name1901015);
}};
$e2733327334.stack[R.EXN_STACKHEIGHT++] = $ss2733727338;
}
if(R.isPyretException($e2733327334)) {
$e2733327334.pyretStack.push(L[3942]);
}
throw $e2733327334;
}
var $ret2733927340 = $Hanf_arg1042727344($z2733527336,anf_array_val56539103,anf_fun56529104,l12129090,s_DASH_name1901015);
++R.GAS;
return $ret2733927340;
};
var $Hanf_arg1042727344 = function(anf_arg565427343,anf_array_val56539103,anf_fun56529104,l12129090,s_DASH_name1901015) {
var $z2734727348 = D;
var $f2735327354 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l12129090,anf_arg565427343):R.ffi.throwNonFunApp(L[3943],s_DASH_name1901015.$var,[l12129090,anf_arg565427343]);
};
try {
if(--R.GAS > 0) {
$z2734727348 = $f2735327354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2735327354,
"from":L[3943]});
}
} catch($e2734527346) {
if(R.isCont($e2734527346)) {
var $ss2734927350 = {"from":L[3943],
"go":function(anf_array_val565527355) {
return $Hanf_array_val1042627356(anf_array_val565527355,anf_array_val56539103,anf_fun56529104);
}};
$e2734527346.stack[R.EXN_STACKHEIGHT++] = $ss2734927350;
}
if(R.isPyretException($e2734527346)) {
$e2734527346.pyretStack.push(L[3943]);
}
throw $e2734527346;
}
var $ret2735127352 = $Hanf_array_val1042627356($z2734727348,anf_array_val56539103,anf_fun56529104);
++R.GAS;
return $ret2735127352;
};
var $Hanf_array_val1042627356 = function(anf_array_val565527355,anf_array_val56539103,anf_fun56529104) {
var $z2735927360 = D;
var $f2736527366 = function(_) {
return R.isFunction(anf_fun56529104)?anf_fun56529104.app([anf_array_val56539103,anf_array_val565527355]):R.ffi.throwNonFunApp(L[1761],anf_fun56529104,[[anf_array_val56539103,anf_array_val565527355]]);
};
try {
if(--R.GAS > 0) {
$z2735927360 = $f2736527366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2736527366,
"from":L[1761]});
}
} catch($e2735727358) {
if(R.isCont($e2735727358)) {
var $ss2736127362 = {"from":L[1761],
"go":function(ann_DASH_check_DASH_temp565127367) {
return $Hann_DASH_check_DASH_temp1042527368(ann_DASH_check_DASH_temp565127367);
}};
$e2735727358.stack[R.EXN_STACKHEIGHT++] = $ss2736127362;
}
if(R.isPyretException($e2735727358)) {
$e2735727358.pyretStack.push(L[1761]);
}
throw $e2735727358;
}
var $ret2736327364 = $Hann_DASH_check_DASH_temp1042527368($z2735927360);
++R.GAS;
return $ret2736327364;
};
var $Hann_DASH_check_DASH_temp1042527368 = function(ann_DASH_check_DASH_temp565127367) {
return ann_DASH_check_DASH_temp565127367;
};
var $Hanf_array_val104249123 = function(anf_array_val56479121,anf_fun56469122,l212089107,make_DASH_checker_DASH_name5292359,name12099108,s_DASH_name1901015) {
var $z2737127372 = D;
var $f2737727378 = function(_) {
return R.isFunction(make_DASH_checker_DASH_name5292359.$var)?make_DASH_checker_DASH_name5292359.$var.app(name12099108):R.ffi.throwNonFunApp(L[3944],make_DASH_checker_DASH_name5292359.$var,[name12099108]);
};
try {
if(--R.GAS > 0) {
$z2737127372 = $f2737727378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2737727378,
"from":L[3944]});
}
} catch($e2736927370) {
if(R.isCont($e2736927370)) {
var $ss2737327374 = {"from":L[3944],
"go":function(anf_arg564827379) {
return $Hanf_arg1042327380(anf_arg564827379,anf_array_val56479121,anf_fun56469122,l212089107,s_DASH_name1901015);
}};
$e2736927370.stack[R.EXN_STACKHEIGHT++] = $ss2737327374;
}
if(R.isPyretException($e2736927370)) {
$e2736927370.pyretStack.push(L[3944]);
}
throw $e2736927370;
}
var $ret2737527376 = $Hanf_arg1042327380($z2737127372,anf_array_val56479121,anf_fun56469122,l212089107,s_DASH_name1901015);
++R.GAS;
return $ret2737527376;
};
var $Hanf_arg1042327380 = function(anf_arg564827379,anf_array_val56479121,anf_fun56469122,l212089107,s_DASH_name1901015) {
var $z2738327384 = D;
var $f2738927390 = function(_) {
return R.isFunction(s_DASH_name1901015.$var)?s_DASH_name1901015.$var.app(l212089107,anf_arg564827379):R.ffi.throwNonFunApp(L[3945],s_DASH_name1901015.$var,[l212089107,anf_arg564827379]);
};
try {
if(--R.GAS > 0) {
$z2738327384 = $f2738927390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2738927390,
"from":L[3945]});
}
} catch($e2738127382) {
if(R.isCont($e2738127382)) {
var $ss2738527386 = {"from":L[3945],
"go":function(anf_array_val564927391) {
return $Hanf_array_val1042227392(anf_array_val564927391,anf_array_val56479121,anf_fun56469122);
}};
$e2738127382.stack[R.EXN_STACKHEIGHT++] = $ss2738527386;
}
if(R.isPyretException($e2738127382)) {
$e2738127382.pyretStack.push(L[3945]);
}
throw $e2738127382;
}
var $ret2738727388 = $Hanf_array_val1042227392($z2738327384,anf_array_val56479121,anf_fun56469122);
++R.GAS;
return $ret2738727388;
};
var $Hanf_array_val1042227392 = function(anf_array_val564927391,anf_array_val56479121,anf_fun56469122) {
var $z2739527396 = D;
var $f2740127402 = function(_) {
return R.isFunction(anf_fun56469122)?anf_fun56469122.app([anf_array_val56479121,anf_array_val564927391]):R.ffi.throwNonFunApp(L[1764],anf_fun56469122,[[anf_array_val56479121,anf_array_val564927391]]);
};
try {
if(--R.GAS > 0) {
$z2739527396 = $f2740127402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2740127402,
"from":L[1764]});
}
} catch($e2739327394) {
if(R.isCont($e2739327394)) {
var $ss2739727398 = {"from":L[1764],
"go":function(ann_DASH_check_DASH_temp564527403) {
return $Hann_DASH_check_DASH_temp1042127404(ann_DASH_check_DASH_temp564527403);
}};
$e2739327394.stack[R.EXN_STACKHEIGHT++] = $ss2739727398;
}
if(R.isPyretException($e2739327394)) {
$e2739327394.pyretStack.push(L[1764]);
}
throw $e2739327394;
}
var $ret2739927400 = $Hann_DASH_check_DASH_temp1042127404($z2739527396);
++R.GAS;
return $ret2739927400;
};
var $Hann_DASH_check_DASH_temp1042127404 = function(ann_DASH_check_DASH_temp564527403) {
return ann_DASH_check_DASH_temp564527403;
};
var $Hann_DASH_check_DASH_temp104209140 = function(ann_DASH_check_DASH_temp56329139,List17129,Name66133) {
return ann_DASH_check_DASH_temp56329139;
};
var $Hann_DASH_check_DASH_temp104199152 = function(ann_DASH_check_DASH_temp56399151) {
return ann_DASH_check_DASH_temp56399151;
};
var $Hanf_arg104189168 = function(anf_arg56369167,flatten5302361) {
var $z2740727408 = D;
var $f2741327414 = function(_) {
return R.isFunction(flatten5302361.$var)?flatten5302361.$var.app(anf_arg56369167):R.ffi.throwNonFunApp(L[1769],flatten5302361.$var,[anf_arg56369167]);
};
try {
if(--R.GAS > 0) {
$z2740727408 = $f2741327414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2741327414,
"from":L[1769]});
}
} catch($e2740527406) {
if(R.isCont($e2740527406)) {
var $ss2740927410 = {"from":L[1769],
"go":function(ann_DASH_check_DASH_temp563427415) {
return $Hann_DASH_check_DASH_temp1041727416(ann_DASH_check_DASH_temp563427415);
}};
$e2740527406.stack[R.EXN_STACKHEIGHT++] = $ss2740927410;
}
if(R.isPyretException($e2740527406)) {
$e2740527406.pyretStack.push(L[1769]);
}
throw $e2740527406;
}
var $ret2741127412 = $Hann_DASH_check_DASH_temp1041727416($z2740727408);
++R.GAS;
return $ret2741127412;
};
var $Hann_DASH_check_DASH_temp1041727416 = function(ann_DASH_check_DASH_temp563427415) {
return ann_DASH_check_DASH_temp563427415;
};
var $Hann_DASH_check_DASH_temp104169185 = function(ann_DASH_check_DASH_temp56139184,List17129,Name66133) {
return ann_DASH_check_DASH_temp56139184;
};
var $Hanf_obj104159209 = function(anf_obj56259207,anf_fun56249208) {
var anf_array_val562627427 = R.makeObject({"bind-type":("data"),
"name":anf_obj56259207});
var $z2741927420 = D;
var $f2742527426 = function(_) {
return R.isFunction(anf_fun56249208)?anf_fun56249208.app([anf_array_val562627427]):R.ffi.throwNonFunApp(L[1775],anf_fun56249208,[[anf_array_val562627427]]);
};
try {
if(--R.GAS > 0) {
$z2741927420 = $f2742527426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2742527426,
"from":L[1775]});
}
} catch($e2741727418) {
if(R.isCont($e2741727418)) {
var $ss2742127422 = {"from":L[1775],
"go":function(ann_DASH_check_DASH_temp562327428) {
return $Hann_DASH_check_DASH_temp1041427429(ann_DASH_check_DASH_temp562327428);
}};
$e2741727418.stack[R.EXN_STACKHEIGHT++] = $ss2742127422;
}
if(R.isPyretException($e2741727418)) {
$e2741727418.pyretStack.push(L[1775]);
}
throw $e2741727418;
}
var $ret2742327424 = $Hann_DASH_check_DASH_temp1041427429($z2741927420);
++R.GAS;
return $ret2742327424;
};
var $Hann_DASH_check_DASH_temp1041427429 = function(ann_DASH_check_DASH_temp562327428) {
return ann_DASH_check_DASH_temp562327428;
};
var $Hann_DASH_check_DASH_temp104139226 = function(ann_DASH_check_DASH_temp56199225) {
return ann_DASH_check_DASH_temp56199225;
};
var $Hann_DASH_check_DASH_temp104129243 = function(ann_DASH_check_DASH_temp56159242) {
return ann_DASH_check_DASH_temp56159242;
};
var $Hanf_arg104119259 = function(anf_arg56119257,anf_arg56099258,fold53151,list_DASH_of_DASH_lists11849245) {
var $z2743227433 = D;
var $f2743827439 = function(_) {
return R.isFunction(fold53151)?fold53151.app(anf_arg56099258,anf_arg56119257,list_DASH_of_DASH_lists11849245):R.ffi.throwNonFunApp(L[1782],fold53151,[anf_arg56099258,anf_arg56119257,list_DASH_of_DASH_lists11849245]);
};
try {
if(--R.GAS > 0) {
$z2743227433 = $f2743827439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2743827439,
"from":L[1782]});
}
} catch($e2743027431) {
if(R.isCont($e2743027431)) {
var $ss2743427435 = {"from":L[1782],
"go":function(ann_DASH_check_DASH_temp560727440) {
return $Hann_DASH_check_DASH_temp1041027441(ann_DASH_check_DASH_temp560727440);
}};
$e2743027431.stack[R.EXN_STACKHEIGHT++] = $ss2743427435;
}
if(R.isPyretException($e2743027431)) {
$e2743027431.pyretStack.push(L[1782]);
}
throw $e2743027431;
}
var $ret2743627437 = $Hann_DASH_check_DASH_temp1041027441($z2743227433);
++R.GAS;
return $ret2743627437;
};
var $Hann_DASH_check_DASH_temp1041027441 = function(ann_DASH_check_DASH_temp560727440) {
return ann_DASH_check_DASH_temp560727440;
};
var $Hann_DASH_check_DASH_temp104099273 = function(ann_DASH_check_DASH_temp56089272) {
return ann_DASH_check_DASH_temp56089272;
};
var $Hann_DASH_check_DASH_temp104089286 = function(ann_DASH_check_DASH_temp56059285) {
return ann_DASH_check_DASH_temp56059285;
};
var $Hif_DASH_104079313 = function(if_DASH_7069311,INDENT118169,PP170,self11809312,str_DASH_coloncolon135377) {
var if_helper558127455 = R.makeFunction(function(if_helper_arg558227476) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1793],1,arguments);
}
var ann_DASH_check_DASH_temp557927477 = if_helper_arg558227476;
return ann_DASH_check_DASH_temp557927477;
});
var anf_if558527475 = R.isBoolean(if_DASH_7069311);
if(R.isPyretTrue(anf_if558527475)) {
if(R.isPyretTrue(if_DASH_7069311)) {
var anf_fun559527452 = G(PP170,"str",L[3948]);
var anf_arg559627453 = G(self11809312,"name",L[3947]);
var $z2744427445 = D;
var $f2745027451 = function(_) {
return R.isFunction(anf_fun559527452)?anf_fun559527452.app(anf_arg559627453):R.ffi.throwNonFunApp(L[3946],anf_fun559527452,[anf_arg559627453]);
};
try {
if(--R.GAS > 0) {
$z2744427445 = $f2745027451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2745027451,
"from":L[3946]});
}
} catch($e2744227443) {
if(R.isCont($e2744227443)) {
var $ss2744627447 = {"from":L[3946],
"go":function(cont_tail_arg559727454) {
return $Hcont_tail_arg1040327456(cont_tail_arg559727454,if_helper558127455);
}};
$e2744227443.stack[R.EXN_STACKHEIGHT++] = $ss2744627447;
}
if(R.isPyretException($e2744227443)) {
$e2744227443.pyretStack.push(L[3946]);
}
throw $e2744227443;
}
var $ret2744827449 = $Hcont_tail_arg1040327456($z2744427445,if_helper558127455);
++R.GAS;
return $ret2744827449;
} else {
var anf_fun558627470 = G(PP170,"infix",L[3952]);
var anf_fun558727467 = G(PP170,"str",L[3951]);
var anf_arg558827468 = G(self11809312,"name",L[3950]);
var $z2745927460 = D;
var $f2746527466 = function(_) {
return R.isFunction(anf_fun558727467)?anf_fun558727467.app(anf_arg558827468):R.ffi.throwNonFunApp(L[3949],anf_fun558727467,[anf_arg558827468]);
};
try {
if(--R.GAS > 0) {
$z2745927460 = $f2746527466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2746527466,
"from":L[3949]});
}
} catch($e2745727458) {
if(R.isCont($e2745727458)) {
var $ss2746127462 = {"from":L[3949],
"go":function(anf_arg558927469) {
return $Hanf_arg1040627471(anf_arg558927469,INDENT118169,anf_fun558627470,if_helper558127455,self11809312,str_DASH_coloncolon135377);
}};
$e2745727458.stack[R.EXN_STACKHEIGHT++] = $ss2746127462;
}
if(R.isPyretException($e2745727458)) {
$e2745727458.pyretStack.push(L[3949]);
}
throw $e2745727458;
}
var $ret2746327464 = $Hanf_arg1040627471($z2745927460,INDENT118169,anf_fun558627470,if_helper558127455,self11809312,str_DASH_coloncolon135377);
++R.GAS;
return $ret2746327464;
}
} else {
var cont_tail_arg558327474 = R.throwNonBooleanCondition(L[1793],("if"),if_DASH_7069311);
if(--R.GAS > 0) {
$z2747227473 = R.isFunction(if_helper558127455)?if_helper558127455.app(cont_tail_arg558327474):R.ffi.throwNonFunApp(L[1793],if_helper558127455,[cont_tail_arg558327474]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper558127455)?if_helper558127455.app(cont_tail_arg558327474):R.ffi.throwNonFunApp(L[1793],if_helper558127455,[cont_tail_arg558327474]);
},
"from":L[1793]});
}
++R.GAS;
return $z2747227473;
}
};
var $Hcont_tail_arg1040327456 = function(cont_tail_arg559727454,if_helper558127455) {
if(--R.GAS > 0) {
$z2747827479 = R.isFunction(if_helper558127455)?if_helper558127455.app(cont_tail_arg559727454):R.ffi.throwNonFunApp(L[3946],if_helper558127455,[cont_tail_arg559727454]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper558127455)?if_helper558127455.app(cont_tail_arg559727454):R.ffi.throwNonFunApp(L[3946],if_helper558127455,[cont_tail_arg559727454]);
},
"from":L[3946]});
}
++R.GAS;
return $z2747827479;
};
var $Hanf_arg1040627471 = function(anf_arg558927469,INDENT118169,anf_fun558627470,if_helper558127455,self11809312,str_DASH_coloncolon135377) {
var anf_bracket559027493 = G(self11809312,"ann",L[3955]);
var anf_fun559127490 = G(anf_bracket559027493,"tosource",L[3954]);
var $z2748227483 = D;
var $f2748827489 = function(_) {
return R.isFunction(anf_fun559127490)?anf_fun559127490.app():R.ffi.throwNonFunApp(L[3953],anf_fun559127490,[]);
};
try {
if(--R.GAS > 0) {
$z2748227483 = $f2748827489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2748827489,
"from":L[3953]});
}
} catch($e2748027481) {
if(R.isCont($e2748027481)) {
var $ss2748427485 = {"from":L[3953],
"go":function(anf_arg559227491) {
return $Hanf_arg1040527492(anf_arg559227491,INDENT118169,anf_arg558927469,anf_fun558627470,if_helper558127455,str_DASH_coloncolon135377);
}};
$e2748027481.stack[R.EXN_STACKHEIGHT++] = $ss2748427485;
}
if(R.isPyretException($e2748027481)) {
$e2748027481.pyretStack.push(L[3953]);
}
throw $e2748027481;
}
var $ret2748627487 = $Hanf_arg1040527492($z2748227483,INDENT118169,anf_arg558927469,anf_fun558627470,if_helper558127455,str_DASH_coloncolon135377);
++R.GAS;
return $ret2748627487;
};
var $Hanf_arg1040527492 = function(anf_arg559227491,INDENT118169,anf_arg558927469,anf_fun558627470,if_helper558127455,str_DASH_coloncolon135377) {
var $z2749627497 = D;
var $f2750227503 = function(_) {
return R.isFunction(anf_fun558627470)?anf_fun558627470.app(INDENT118169,(1),str_DASH_coloncolon135377,anf_arg558927469,anf_arg559227491):R.ffi.throwNonFunApp(L[3956],anf_fun558627470,[INDENT118169,(1),str_DASH_coloncolon135377,anf_arg558927469,anf_arg559227491]);
};
try {
if(--R.GAS > 0) {
$z2749627497 = $f2750227503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2750227503,
"from":L[3956]});
}
} catch($e2749427495) {
if(R.isCont($e2749427495)) {
var $ss2749827499 = {"from":L[3956],
"go":function(cont_tail_arg559327504) {
return $Hcont_tail_arg1040427505(cont_tail_arg559327504,if_helper558127455);
}};
$e2749427495.stack[R.EXN_STACKHEIGHT++] = $ss2749827499;
}
if(R.isPyretException($e2749427495)) {
$e2749427495.pyretStack.push(L[3956]);
}
throw $e2749427495;
}
var $ret2750027501 = $Hcont_tail_arg1040427505($z2749627497,if_helper558127455);
++R.GAS;
return $ret2750027501;
};
var $Hcont_tail_arg1040427505 = function(cont_tail_arg559327504,if_helper558127455) {
if(--R.GAS > 0) {
$z2750627507 = R.isFunction(if_helper558127455)?if_helper558127455.app(cont_tail_arg559327504):R.ffi.throwNonFunApp(L[3956],if_helper558127455,[cont_tail_arg559327504]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper558127455)?if_helper558127455.app(cont_tail_arg559327504):R.ffi.throwNonFunApp(L[3956],if_helper558127455,[cont_tail_arg559327504]);
},
"from":L[3956]});
}
++R.GAS;
return $z2750627507;
};
var $Hanf_arg104029329 = function(anf_arg55659327,self7049328,_plus55,torepr65) {
var anf_arg556627518 = G(self7049328,"name",L[1787]);
var $z2751027511 = D;
var $f2751627517 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg556627518):R.ffi.throwNonFunApp(L[1787],torepr65,[anf_arg556627518]);
};
try {
if(--R.GAS > 0) {
$z2751027511 = $f2751627517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2751627517,
"from":L[1787]});
}
} catch($e2750827509) {
if(R.isCont($e2750827509)) {
var $ss2751227513 = {"from":L[1787],
"go":function(anf_arg556727519) {
return $Hanf_arg1040127520(anf_arg556727519,anf_arg55659327,self7049328,_plus55,torepr65);
}};
$e2750827509.stack[R.EXN_STACKHEIGHT++] = $ss2751227513;
}
if(R.isPyretException($e2750827509)) {
$e2750827509.pyretStack.push(L[1787]);
}
throw $e2750827509;
}
var $ret2751427515 = $Hanf_arg1040127520($z2751027511,anf_arg55659327,self7049328,_plus55,torepr65);
++R.GAS;
return $ret2751427515;
};
var $Hanf_arg1040127520 = function(anf_arg556727519,anf_arg55659327,self7049328,_plus55,torepr65) {
var $z2752327524 = D;
var $f2752927530 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg556727519):R.ffi.throwNonFunApp(L[1787],_plus55,[(", "),anf_arg556727519]);
};
try {
if(--R.GAS > 0) {
$z2752327524 = $f2752927530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2752927530,
"from":L[1787]});
}
} catch($e2752127522) {
if(R.isCont($e2752127522)) {
var $ss2752527526 = {"from":L[1787],
"go":function(anf_arg556827531) {
return $Hanf_arg1040027532(anf_arg556827531,anf_arg55659327,self7049328,_plus55,torepr65);
}};
$e2752127522.stack[R.EXN_STACKHEIGHT++] = $ss2752527526;
}
if(R.isPyretException($e2752127522)) {
$e2752127522.pyretStack.push(L[1787]);
}
throw $e2752127522;
}
var $ret2752727528 = $Hanf_arg1040027532($z2752327524,anf_arg55659327,self7049328,_plus55,torepr65);
++R.GAS;
return $ret2752727528;
};
var $Hanf_arg1040027532 = function(anf_arg556827531,anf_arg55659327,self7049328,_plus55,torepr65) {
var $z2753527536 = D;
var $f2754127542 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg55659327,anf_arg556827531):R.ffi.throwNonFunApp(L[1787],_plus55,[anf_arg55659327,anf_arg556827531]);
};
try {
if(--R.GAS > 0) {
$z2753527536 = $f2754127542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2754127542,
"from":L[1787]});
}
} catch($e2753327534) {
if(R.isCont($e2753327534)) {
var $ss2753727538 = {"from":L[1787],
"go":function(anf_arg556927543) {
return $Hanf_arg1039927544(anf_arg556927543,self7049328,_plus55,torepr65);
}};
$e2753327534.stack[R.EXN_STACKHEIGHT++] = $ss2753727538;
}
if(R.isPyretException($e2753327534)) {
$e2753327534.pyretStack.push(L[1787]);
}
throw $e2753327534;
}
var $ret2753927540 = $Hanf_arg1039927544($z2753527536,self7049328,_plus55,torepr65);
++R.GAS;
return $ret2753927540;
};
var $Hanf_arg1039927544 = function(anf_arg556927543,self7049328,_plus55,torepr65) {
var anf_arg557027555 = G(self7049328,"ann",L[1787]);
var $z2754727548 = D;
var $f2755327554 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg557027555):R.ffi.throwNonFunApp(L[1787],torepr65,[anf_arg557027555]);
};
try {
if(--R.GAS > 0) {
$z2754727548 = $f2755327554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2755327554,
"from":L[1787]});
}
} catch($e2754527546) {
if(R.isCont($e2754527546)) {
var $ss2754927550 = {"from":L[1787],
"go":function(anf_arg557127556) {
return $Hanf_arg1039827557(anf_arg557127556,anf_arg556927543,_plus55);
}};
$e2754527546.stack[R.EXN_STACKHEIGHT++] = $ss2754927550;
}
if(R.isPyretException($e2754527546)) {
$e2754527546.pyretStack.push(L[1787]);
}
throw $e2754527546;
}
var $ret2755127552 = $Hanf_arg1039827557($z2754727548,anf_arg556927543,_plus55);
++R.GAS;
return $ret2755127552;
};
var $Hanf_arg1039827557 = function(anf_arg557127556,anf_arg556927543,_plus55) {
var $z2756027561 = D;
var $f2756627567 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg557127556):R.ffi.throwNonFunApp(L[1787],_plus55,[(", "),anf_arg557127556]);
};
try {
if(--R.GAS > 0) {
$z2756027561 = $f2756627567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2756627567,
"from":L[1787]});
}
} catch($e2755827559) {
if(R.isCont($e2755827559)) {
var $ss2756227563 = {"from":L[1787],
"go":function(anf_arg557227568) {
return $Hanf_arg1039727569(anf_arg557227568,anf_arg556927543,_plus55);
}};
$e2755827559.stack[R.EXN_STACKHEIGHT++] = $ss2756227563;
}
if(R.isPyretException($e2755827559)) {
$e2755827559.pyretStack.push(L[1787]);
}
throw $e2755827559;
}
var $ret2756427565 = $Hanf_arg1039727569($z2756027561,anf_arg556927543,_plus55);
++R.GAS;
return $ret2756427565;
};
var $Hanf_arg1039727569 = function(anf_arg557227568,anf_arg556927543,_plus55) {
var $z2757227573 = D;
var $f2757827579 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg556927543,anf_arg557227568):R.ffi.throwNonFunApp(L[1787],_plus55,[anf_arg556927543,anf_arg557227568]);
};
try {
if(--R.GAS > 0) {
$z2757227573 = $f2757827579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2757827579,
"from":L[1787]});
}
} catch($e2757027571) {
if(R.isCont($e2757027571)) {
var $ss2757427575 = {"from":L[1787],
"go":function(anf_arg557327580) {
return $Hanf_arg1039627581(anf_arg557327580,_plus55);
}};
$e2757027571.stack[R.EXN_STACKHEIGHT++] = $ss2757427575;
}
if(R.isPyretException($e2757027571)) {
$e2757027571.pyretStack.push(L[1787]);
}
throw $e2757027571;
}
var $ret2757627577 = $Hanf_arg1039627581($z2757227573,_plus55);
++R.GAS;
return $ret2757627577;
};
var $Hanf_arg1039627581 = function(anf_arg557327580,_plus55) {
var $z2758427585 = D;
var $f2759027591 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg557327580,(")")):R.ffi.throwNonFunApp(L[1787],_plus55,[anf_arg557327580,(")")]);
};
try {
if(--R.GAS > 0) {
$z2758427585 = $f2759027591();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2759027591,
"from":L[1787]});
}
} catch($e2758227583) {
if(R.isCont($e2758227583)) {
var $ss2758627587 = {"from":L[1787],
"go":function(anf_arg557427592) {
return $Hanf_arg1039527593(anf_arg557427592,_plus55);
}};
$e2758227583.stack[R.EXN_STACKHEIGHT++] = $ss2758627587;
}
if(R.isPyretException($e2758227583)) {
$e2758227583.pyretStack.push(L[1787]);
}
throw $e2758227583;
}
var $ret2758827589 = $Hanf_arg1039527593($z2758427585,_plus55);
++R.GAS;
return $ret2758827589;
};
var $Hanf_arg1039527593 = function(anf_arg557427592,_plus55) {
var $z2759627597 = D;
var $f2760227603 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg557427592):R.ffi.throwNonFunApp(L[1787],_plus55,[("("),anf_arg557427592]);
};
try {
if(--R.GAS > 0) {
$z2759627597 = $f2760227603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2760227603,
"from":L[1787]});
}
} catch($e2759427595) {
if(R.isCont($e2759427595)) {
var $ss2759827599 = {"from":L[1787],
"go":function(anf_arg557527604) {
return $Hanf_arg1039427605(anf_arg557527604,_plus55);
}};
$e2759427595.stack[R.EXN_STACKHEIGHT++] = $ss2759827599;
}
if(R.isPyretException($e2759427595)) {
$e2759427595.pyretStack.push(L[1787]);
}
throw $e2759427595;
}
var $ret2760027601 = $Hanf_arg1039427605($z2759627597,_plus55);
++R.GAS;
return $ret2760027601;
};
var $Hanf_arg1039427605 = function(anf_arg557527604,_plus55) {
var $z2760827609 = D;
var $f2761427615 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("a-field"),anf_arg557527604):R.ffi.throwNonFunApp(L[1787],_plus55,[("a-field"),anf_arg557527604]);
};
try {
if(--R.GAS > 0) {
$z2760827609 = $f2761427615();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2761427615,
"from":L[1787]});
}
} catch($e2760627607) {
if(R.isCont($e2760627607)) {
var $ss2761027611 = {"from":L[1787],
"go":function(ann_DASH_check_DASH_temp556327616) {
return $Hann_DASH_check_DASH_temp1039327617(ann_DASH_check_DASH_temp556327616);
}};
$e2760627607.stack[R.EXN_STACKHEIGHT++] = $ss2761027611;
}
if(R.isPyretException($e2760627607)) {
$e2760627607.pyretStack.push(L[1787]);
}
throw $e2760627607;
}
var $ret2761227613 = $Hann_DASH_check_DASH_temp1039327617($z2760827609);
++R.GAS;
return $ret2761227613;
};
var $Hann_DASH_check_DASH_temp1039327617 = function(ann_DASH_check_DASH_temp556327616) {
return ann_DASH_check_DASH_temp556327616;
};
var $Hcont_tail_arg103919346 = function(cont_tail_arg55609344,if_helper55509345) {
if(--R.GAS > 0) {
$z2761827619 = R.isFunction(if_helper55509345)?if_helper55509345.app(cont_tail_arg55609344):R.ffi.throwNonFunApp(L[1787],if_helper55509345,[cont_tail_arg55609344]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper55509345)?if_helper55509345.app(cont_tail_arg55609344):R.ffi.throwNonFunApp(L[1787],if_helper55509345,[cont_tail_arg55609344]);
},
"from":L[1787]});
}
++R.GAS;
return $z2761827619;
};
var $Hcont_tail_arg103929361 = function(cont_tail_arg55559360,if_helper55509345) {
if(--R.GAS > 0) {
$z2762027621 = R.isFunction(if_helper55509345)?if_helper55509345.app(cont_tail_arg55559360):R.ffi.throwNonFunApp(L[1787],if_helper55509345,[cont_tail_arg55559360]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper55509345)?if_helper55509345.app(cont_tail_arg55559360):R.ffi.throwNonFunApp(L[1787],if_helper55509345,[cont_tail_arg55559360]);
},
"from":L[1787]});
}
++R.GAS;
return $z2762027621;
};
var $Hann_DASH_check_DASH_temp103909383 = function(ann_DASH_check_DASH_temp55419382) {
return ann_DASH_check_DASH_temp55419382;
};
var $Hanf_arg103899396 = function(anf_arg55459395,_plus55,raise62) {
var $z2762427625 = D;
var $f2763027631 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg55459395):R.ffi.throwNonFunApp(L[3957],_plus55,[("No visitor field for "),anf_arg55459395]);
};
try {
if(--R.GAS > 0) {
$z2762427625 = $f2763027631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2763027631,
"from":L[3957]});
}
} catch($e2762227623) {
if(R.isCont($e2762227623)) {
var $ss2762627627 = {"from":L[3957],
"go":function(anf_arg554627632) {
return $Hanf_arg1038827633(anf_arg554627632,raise62);
}};
$e2762227623.stack[R.EXN_STACKHEIGHT++] = $ss2762627627;
}
if(R.isPyretException($e2762227623)) {
$e2762227623.pyretStack.push(L[3957]);
}
throw $e2762227623;
}
var $ret2762827629 = $Hanf_arg1038827633($z2762427625,raise62);
++R.GAS;
return $ret2762827629;
};
var $Hanf_arg1038827633 = function(anf_arg554627632,raise62) {
var $z2763627637 = D;
var $f2764227643 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg554627632):R.ffi.throwNonFunApp(L[1801],raise62,[anf_arg554627632]);
};
try {
if(--R.GAS > 0) {
$z2763627637 = $f2764227643();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2764227643,
"from":L[1801]});
}
} catch($e2763427635) {
if(R.isCont($e2763427635)) {
var $ss2763827639 = {"from":L[1801],
"go":function(ann_DASH_check_DASH_temp554327644) {
return $Hann_DASH_check_DASH_temp1038727645(ann_DASH_check_DASH_temp554327644);
}};
$e2763427635.stack[R.EXN_STACKHEIGHT++] = $ss2763827639;
}
if(R.isPyretException($e2763427635)) {
$e2763427635.pyretStack.push(L[1801]);
}
throw $e2763427635;
}
var $ret2764027641 = $Hann_DASH_check_DASH_temp1038727645($z2763627637);
++R.GAS;
return $ret2764027641;
};
var $Hann_DASH_check_DASH_temp1038727645 = function(ann_DASH_check_DASH_temp554327644) {
return ann_DASH_check_DASH_temp554327644;
};
var $Hanf_arg103869513 = function(anf_arg55149511,PP170,self11739512,_plus55) {
var anf_fun551527658 = G(PP170,"str",L[3960]);
var anf_arg551627656 = G(self11739512,"field",L[3959]);
var $z2764827649 = D;
var $f2765427655 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("."),anf_arg551627656):R.ffi.throwNonFunApp(L[3958],_plus55,[("."),anf_arg551627656]);
};
try {
if(--R.GAS > 0) {
$z2764827649 = $f2765427655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2765427655,
"from":L[3958]});
}
} catch($e2764627647) {
if(R.isCont($e2764627647)) {
var $ss2765027651 = {"from":L[3958],
"go":function(anf_arg551727657) {
return $Hanf_arg1038527659(anf_arg551727657,anf_arg55149511,anf_fun551527658,_plus55);
}};
$e2764627647.stack[R.EXN_STACKHEIGHT++] = $ss2765027651;
}
if(R.isPyretException($e2764627647)) {
$e2764627647.pyretStack.push(L[3958]);
}
throw $e2764627647;
}
var $ret2765227653 = $Hanf_arg1038527659($z2764827649,anf_arg55149511,anf_fun551527658,_plus55);
++R.GAS;
return $ret2765227653;
};
var $Hanf_arg1038527659 = function(anf_arg551727657,anf_arg55149511,anf_fun551527658,_plus55) {
var $z2766227663 = D;
var $f2766827669 = function(_) {
return R.isFunction(anf_fun551527658)?anf_fun551527658.app(anf_arg551727657):R.ffi.throwNonFunApp(L[3961],anf_fun551527658,[anf_arg551727657]);
};
try {
if(--R.GAS > 0) {
$z2766227663 = $f2766827669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2766827669,
"from":L[3961]});
}
} catch($e2766027661) {
if(R.isCont($e2766027661)) {
var $ss2766427665 = {"from":L[3961],
"go":function(anf_arg551827670) {
return $Hanf_arg1038427671(anf_arg551827670,anf_arg55149511,_plus55);
}};
$e2766027661.stack[R.EXN_STACKHEIGHT++] = $ss2766427665;
}
if(R.isPyretException($e2766027661)) {
$e2766027661.pyretStack.push(L[3961]);
}
throw $e2766027661;
}
var $ret2766627667 = $Hanf_arg1038427671($z2766227663,anf_arg55149511,_plus55);
++R.GAS;
return $ret2766627667;
};
var $Hanf_arg1038427671 = function(anf_arg551827670,anf_arg55149511,_plus55) {
var $z2767427675 = D;
var $f2768027681 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg55149511,anf_arg551827670):R.ffi.throwNonFunApp(L[1845],_plus55,[anf_arg55149511,anf_arg551827670]);
};
try {
if(--R.GAS > 0) {
$z2767427675 = $f2768027681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2768027681,
"from":L[1845]});
}
} catch($e2767227673) {
if(R.isCont($e2767227673)) {
var $ss2767627677 = {"from":L[1845],
"go":function(ann_DASH_check_DASH_temp551127682) {
return $Hann_DASH_check_DASH_temp1038327683(ann_DASH_check_DASH_temp551127682);
}};
$e2767227673.stack[R.EXN_STACKHEIGHT++] = $ss2767627677;
}
if(R.isPyretException($e2767227673)) {
$e2767227673.pyretStack.push(L[1845]);
}
throw $e2767227673;
}
var $ret2767827679 = $Hann_DASH_check_DASH_temp1038327683($z2767427675);
++R.GAS;
return $ret2767827679;
};
var $Hann_DASH_check_DASH_temp1038327683 = function(ann_DASH_check_DASH_temp551127682) {
return ann_DASH_check_DASH_temp551127682;
};
var $Hanf_arg103829530 = function(anf_arg54979528,self6989529,_plus55,torepr65) {
var anf_arg549827694 = G(self6989529,"obj",L[1805]);
var $z2768627687 = D;
var $f2769227693 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg549827694):R.ffi.throwNonFunApp(L[1805],torepr65,[anf_arg549827694]);
};
try {
if(--R.GAS > 0) {
$z2768627687 = $f2769227693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2769227693,
"from":L[1805]});
}
} catch($e2768427685) {
if(R.isCont($e2768427685)) {
var $ss2768827689 = {"from":L[1805],
"go":function(anf_arg549927695) {
return $Hanf_arg1038127696(anf_arg549927695,anf_arg54979528,self6989529,_plus55,torepr65);
}};
$e2768427685.stack[R.EXN_STACKHEIGHT++] = $ss2768827689;
}
if(R.isPyretException($e2768427685)) {
$e2768427685.pyretStack.push(L[1805]);
}
throw $e2768427685;
}
var $ret2769027691 = $Hanf_arg1038127696($z2768627687,anf_arg54979528,self6989529,_plus55,torepr65);
++R.GAS;
return $ret2769027691;
};
var $Hanf_arg1038127696 = function(anf_arg549927695,anf_arg54979528,self6989529,_plus55,torepr65) {
var $z2769927700 = D;
var $f2770527706 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg549927695):R.ffi.throwNonFunApp(L[1805],_plus55,[(", "),anf_arg549927695]);
};
try {
if(--R.GAS > 0) {
$z2769927700 = $f2770527706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2770527706,
"from":L[1805]});
}
} catch($e2769727698) {
if(R.isCont($e2769727698)) {
var $ss2770127702 = {"from":L[1805],
"go":function(anf_arg550027707) {
return $Hanf_arg1038027708(anf_arg550027707,anf_arg54979528,self6989529,_plus55,torepr65);
}};
$e2769727698.stack[R.EXN_STACKHEIGHT++] = $ss2770127702;
}
if(R.isPyretException($e2769727698)) {
$e2769727698.pyretStack.push(L[1805]);
}
throw $e2769727698;
}
var $ret2770327704 = $Hanf_arg1038027708($z2769927700,anf_arg54979528,self6989529,_plus55,torepr65);
++R.GAS;
return $ret2770327704;
};
var $Hanf_arg1038027708 = function(anf_arg550027707,anf_arg54979528,self6989529,_plus55,torepr65) {
var $z2771127712 = D;
var $f2771727718 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg54979528,anf_arg550027707):R.ffi.throwNonFunApp(L[1805],_plus55,[anf_arg54979528,anf_arg550027707]);
};
try {
if(--R.GAS > 0) {
$z2771127712 = $f2771727718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2771727718,
"from":L[1805]});
}
} catch($e2770927710) {
if(R.isCont($e2770927710)) {
var $ss2771327714 = {"from":L[1805],
"go":function(anf_arg550127719) {
return $Hanf_arg1037927720(anf_arg550127719,self6989529,_plus55,torepr65);
}};
$e2770927710.stack[R.EXN_STACKHEIGHT++] = $ss2771327714;
}
if(R.isPyretException($e2770927710)) {
$e2770927710.pyretStack.push(L[1805]);
}
throw $e2770927710;
}
var $ret2771527716 = $Hanf_arg1037927720($z2771127712,self6989529,_plus55,torepr65);
++R.GAS;
return $ret2771527716;
};
var $Hanf_arg1037927720 = function(anf_arg550127719,self6989529,_plus55,torepr65) {
var anf_arg550227731 = G(self6989529,"field",L[1805]);
var $z2772327724 = D;
var $f2772927730 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg550227731):R.ffi.throwNonFunApp(L[1805],torepr65,[anf_arg550227731]);
};
try {
if(--R.GAS > 0) {
$z2772327724 = $f2772927730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2772927730,
"from":L[1805]});
}
} catch($e2772127722) {
if(R.isCont($e2772127722)) {
var $ss2772527726 = {"from":L[1805],
"go":function(anf_arg550327732) {
return $Hanf_arg1037827733(anf_arg550327732,anf_arg550127719,_plus55);
}};
$e2772127722.stack[R.EXN_STACKHEIGHT++] = $ss2772527726;
}
if(R.isPyretException($e2772127722)) {
$e2772127722.pyretStack.push(L[1805]);
}
throw $e2772127722;
}
var $ret2772727728 = $Hanf_arg1037827733($z2772327724,anf_arg550127719,_plus55);
++R.GAS;
return $ret2772727728;
};
var $Hanf_arg1037827733 = function(anf_arg550327732,anf_arg550127719,_plus55) {
var $z2773627737 = D;
var $f2774227743 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg550327732):R.ffi.throwNonFunApp(L[1805],_plus55,[(", "),anf_arg550327732]);
};
try {
if(--R.GAS > 0) {
$z2773627737 = $f2774227743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2774227743,
"from":L[1805]});
}
} catch($e2773427735) {
if(R.isCont($e2773427735)) {
var $ss2773827739 = {"from":L[1805],
"go":function(anf_arg550427744) {
return $Hanf_arg1037727745(anf_arg550427744,anf_arg550127719,_plus55);
}};
$e2773427735.stack[R.EXN_STACKHEIGHT++] = $ss2773827739;
}
if(R.isPyretException($e2773427735)) {
$e2773427735.pyretStack.push(L[1805]);
}
throw $e2773427735;
}
var $ret2774027741 = $Hanf_arg1037727745($z2773627737,anf_arg550127719,_plus55);
++R.GAS;
return $ret2774027741;
};
var $Hanf_arg1037727745 = function(anf_arg550427744,anf_arg550127719,_plus55) {
var $z2774827749 = D;
var $f2775427755 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg550127719,anf_arg550427744):R.ffi.throwNonFunApp(L[1805],_plus55,[anf_arg550127719,anf_arg550427744]);
};
try {
if(--R.GAS > 0) {
$z2774827749 = $f2775427755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2775427755,
"from":L[1805]});
}
} catch($e2774627747) {
if(R.isCont($e2774627747)) {
var $ss2775027751 = {"from":L[1805],
"go":function(anf_arg550527756) {
return $Hanf_arg1037627757(anf_arg550527756,_plus55);
}};
$e2774627747.stack[R.EXN_STACKHEIGHT++] = $ss2775027751;
}
if(R.isPyretException($e2774627747)) {
$e2774627747.pyretStack.push(L[1805]);
}
throw $e2774627747;
}
var $ret2775227753 = $Hanf_arg1037627757($z2774827749,_plus55);
++R.GAS;
return $ret2775227753;
};
var $Hanf_arg1037627757 = function(anf_arg550527756,_plus55) {
var $z2776027761 = D;
var $f2776627767 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg550527756,(")")):R.ffi.throwNonFunApp(L[1805],_plus55,[anf_arg550527756,(")")]);
};
try {
if(--R.GAS > 0) {
$z2776027761 = $f2776627767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2776627767,
"from":L[1805]});
}
} catch($e2775827759) {
if(R.isCont($e2775827759)) {
var $ss2776227763 = {"from":L[1805],
"go":function(anf_arg550627768) {
return $Hanf_arg1037527769(anf_arg550627768,_plus55);
}};
$e2775827759.stack[R.EXN_STACKHEIGHT++] = $ss2776227763;
}
if(R.isPyretException($e2775827759)) {
$e2775827759.pyretStack.push(L[1805]);
}
throw $e2775827759;
}
var $ret2776427765 = $Hanf_arg1037527769($z2776027761,_plus55);
++R.GAS;
return $ret2776427765;
};
var $Hanf_arg1037527769 = function(anf_arg550627768,_plus55) {
var $z2777227773 = D;
var $f2777827779 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg550627768):R.ffi.throwNonFunApp(L[1805],_plus55,[("("),anf_arg550627768]);
};
try {
if(--R.GAS > 0) {
$z2777227773 = $f2777827779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2777827779,
"from":L[1805]});
}
} catch($e2777027771) {
if(R.isCont($e2777027771)) {
var $ss2777427775 = {"from":L[1805],
"go":function(anf_arg550727780) {
return $Hanf_arg1037427781(anf_arg550727780,_plus55);
}};
$e2777027771.stack[R.EXN_STACKHEIGHT++] = $ss2777427775;
}
if(R.isPyretException($e2777027771)) {
$e2777027771.pyretStack.push(L[1805]);
}
throw $e2777027771;
}
var $ret2777627777 = $Hanf_arg1037427781($z2777227773,_plus55);
++R.GAS;
return $ret2777627777;
};
var $Hanf_arg1037427781 = function(anf_arg550727780,_plus55) {
var $z2778427785 = D;
var $f2779027791 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("a-dot"),anf_arg550727780):R.ffi.throwNonFunApp(L[1805],_plus55,[("a-dot"),anf_arg550727780]);
};
try {
if(--R.GAS > 0) {
$z2778427785 = $f2779027791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2779027791,
"from":L[1805]});
}
} catch($e2778227783) {
if(R.isCont($e2778227783)) {
var $ss2778627787 = {"from":L[1805],
"go":function(ann_DASH_check_DASH_temp549527792) {
return $Hann_DASH_check_DASH_temp1037327793(ann_DASH_check_DASH_temp549527792);
}};
$e2778227783.stack[R.EXN_STACKHEIGHT++] = $ss2778627787;
}
if(R.isPyretException($e2778227783)) {
$e2778227783.pyretStack.push(L[1805]);
}
throw $e2778227783;
}
var $ret2778827789 = $Hann_DASH_check_DASH_temp1037327793($z2778427785);
++R.GAS;
return $ret2778827789;
};
var $Hann_DASH_check_DASH_temp1037327793 = function(ann_DASH_check_DASH_temp549527792) {
return ann_DASH_check_DASH_temp549527792;
};
var $Hcont_tail_arg103719547 = function(cont_tail_arg54929545,if_helper54829546) {
if(--R.GAS > 0) {
$z2779427795 = R.isFunction(if_helper54829546)?if_helper54829546.app(cont_tail_arg54929545):R.ffi.throwNonFunApp(L[1805],if_helper54829546,[cont_tail_arg54929545]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper54829546)?if_helper54829546.app(cont_tail_arg54929545):R.ffi.throwNonFunApp(L[1805],if_helper54829546,[cont_tail_arg54929545]);
},
"from":L[1805]});
}
++R.GAS;
return $z2779427795;
};
var $Hcont_tail_arg103729562 = function(cont_tail_arg54879561,if_helper54829546) {
if(--R.GAS > 0) {
$z2779627797 = R.isFunction(if_helper54829546)?if_helper54829546.app(cont_tail_arg54879561):R.ffi.throwNonFunApp(L[1805],if_helper54829546,[cont_tail_arg54879561]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper54829546)?if_helper54829546.app(cont_tail_arg54879561):R.ffi.throwNonFunApp(L[1805],if_helper54829546,[cont_tail_arg54879561]);
},
"from":L[1805]});
}
++R.GAS;
return $z2779627797;
};
var $Hanf_arg103709583 = function(anf_arg54749581,PP170,self11689582,_plus55) {
var anf_fun547527810 = G(PP170,"parens",L[3965]);
var anf_bracket547627812 = G(self11689582,"exp",L[3964]);
var anf_fun547727808 = G(anf_bracket547627812,"tosource",L[3963]);
var $z2780027801 = D;
var $f2780627807 = function(_) {
return R.isFunction(anf_fun547727808)?anf_fun547727808.app():R.ffi.throwNonFunApp(L[3962],anf_fun547727808,[]);
};
try {
if(--R.GAS > 0) {
$z2780027801 = $f2780627807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2780627807,
"from":L[3962]});
}
} catch($e2779827799) {
if(R.isCont($e2779827799)) {
var $ss2780227803 = {"from":L[3962],
"go":function(anf_arg547827809) {
return $Hanf_arg1036927811(anf_arg547827809,anf_arg54749581,anf_fun547527810,_plus55);
}};
$e2779827799.stack[R.EXN_STACKHEIGHT++] = $ss2780227803;
}
if(R.isPyretException($e2779827799)) {
$e2779827799.pyretStack.push(L[3962]);
}
throw $e2779827799;
}
var $ret2780427805 = $Hanf_arg1036927811($z2780027801,anf_arg54749581,anf_fun547527810,_plus55);
++R.GAS;
return $ret2780427805;
};
var $Hanf_arg1036927811 = function(anf_arg547827809,anf_arg54749581,anf_fun547527810,_plus55) {
var $z2781527816 = D;
var $f2782127822 = function(_) {
return R.isFunction(anf_fun547527810)?anf_fun547527810.app(anf_arg547827809):R.ffi.throwNonFunApp(L[3966],anf_fun547527810,[anf_arg547827809]);
};
try {
if(--R.GAS > 0) {
$z2781527816 = $f2782127822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2782127822,
"from":L[3966]});
}
} catch($e2781327814) {
if(R.isCont($e2781327814)) {
var $ss2781727818 = {"from":L[3966],
"go":function(anf_arg547927823) {
return $Hanf_arg1036827824(anf_arg547927823,anf_arg54749581,_plus55);
}};
$e2781327814.stack[R.EXN_STACKHEIGHT++] = $ss2781727818;
}
if(R.isPyretException($e2781327814)) {
$e2781327814.pyretStack.push(L[3966]);
}
throw $e2781327814;
}
var $ret2781927820 = $Hanf_arg1036827824($z2781527816,anf_arg54749581,_plus55);
++R.GAS;
return $ret2781927820;
};
var $Hanf_arg1036827824 = function(anf_arg547927823,anf_arg54749581,_plus55) {
var $z2782727828 = D;
var $f2783327834 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg54749581,anf_arg547927823):R.ffi.throwNonFunApp(L[1853],_plus55,[anf_arg54749581,anf_arg547927823]);
};
try {
if(--R.GAS > 0) {
$z2782727828 = $f2783327834();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2783327834,
"from":L[1853]});
}
} catch($e2782527826) {
if(R.isCont($e2782527826)) {
var $ss2782927830 = {"from":L[1853],
"go":function(ann_DASH_check_DASH_temp547127835) {
return $Hann_DASH_check_DASH_temp1036727836(ann_DASH_check_DASH_temp547127835);
}};
$e2782527826.stack[R.EXN_STACKHEIGHT++] = $ss2782927830;
}
if(R.isPyretException($e2782527826)) {
$e2782527826.pyretStack.push(L[1853]);
}
throw $e2782527826;
}
var $ret2783127832 = $Hann_DASH_check_DASH_temp1036727836($z2782727828);
++R.GAS;
return $ret2783127832;
};
var $Hann_DASH_check_DASH_temp1036727836 = function(ann_DASH_check_DASH_temp547127835) {
return ann_DASH_check_DASH_temp547127835;
};
var $Hanf_arg103669600 = function(anf_arg54579598,self6929599,_plus55,torepr65) {
var anf_arg545827847 = G(self6929599,"ann",L[1806]);
var $z2783927840 = D;
var $f2784527846 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg545827847):R.ffi.throwNonFunApp(L[1806],torepr65,[anf_arg545827847]);
};
try {
if(--R.GAS > 0) {
$z2783927840 = $f2784527846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2784527846,
"from":L[1806]});
}
} catch($e2783727838) {
if(R.isCont($e2783727838)) {
var $ss2784127842 = {"from":L[1806],
"go":function(anf_arg545927848) {
return $Hanf_arg1036527849(anf_arg545927848,anf_arg54579598,self6929599,_plus55,torepr65);
}};
$e2783727838.stack[R.EXN_STACKHEIGHT++] = $ss2784127842;
}
if(R.isPyretException($e2783727838)) {
$e2783727838.pyretStack.push(L[1806]);
}
throw $e2783727838;
}
var $ret2784327844 = $Hanf_arg1036527849($z2783927840,anf_arg54579598,self6929599,_plus55,torepr65);
++R.GAS;
return $ret2784327844;
};
var $Hanf_arg1036527849 = function(anf_arg545927848,anf_arg54579598,self6929599,_plus55,torepr65) {
var $z2785227853 = D;
var $f2785827859 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg545927848):R.ffi.throwNonFunApp(L[1806],_plus55,[(", "),anf_arg545927848]);
};
try {
if(--R.GAS > 0) {
$z2785227853 = $f2785827859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2785827859,
"from":L[1806]});
}
} catch($e2785027851) {
if(R.isCont($e2785027851)) {
var $ss2785427855 = {"from":L[1806],
"go":function(anf_arg546027860) {
return $Hanf_arg1036427861(anf_arg546027860,anf_arg54579598,self6929599,_plus55,torepr65);
}};
$e2785027851.stack[R.EXN_STACKHEIGHT++] = $ss2785427855;
}
if(R.isPyretException($e2785027851)) {
$e2785027851.pyretStack.push(L[1806]);
}
throw $e2785027851;
}
var $ret2785627857 = $Hanf_arg1036427861($z2785227853,anf_arg54579598,self6929599,_plus55,torepr65);
++R.GAS;
return $ret2785627857;
};
var $Hanf_arg1036427861 = function(anf_arg546027860,anf_arg54579598,self6929599,_plus55,torepr65) {
var $z2786427865 = D;
var $f2787027871 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg54579598,anf_arg546027860):R.ffi.throwNonFunApp(L[1806],_plus55,[anf_arg54579598,anf_arg546027860]);
};
try {
if(--R.GAS > 0) {
$z2786427865 = $f2787027871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2787027871,
"from":L[1806]});
}
} catch($e2786227863) {
if(R.isCont($e2786227863)) {
var $ss2786627867 = {"from":L[1806],
"go":function(anf_arg546127872) {
return $Hanf_arg1036327873(anf_arg546127872,self6929599,_plus55,torepr65);
}};
$e2786227863.stack[R.EXN_STACKHEIGHT++] = $ss2786627867;
}
if(R.isPyretException($e2786227863)) {
$e2786227863.pyretStack.push(L[1806]);
}
throw $e2786227863;
}
var $ret2786827869 = $Hanf_arg1036327873($z2786427865,self6929599,_plus55,torepr65);
++R.GAS;
return $ret2786827869;
};
var $Hanf_arg1036327873 = function(anf_arg546127872,self6929599,_plus55,torepr65) {
var anf_arg546227884 = G(self6929599,"exp",L[1806]);
var $z2787627877 = D;
var $f2788227883 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg546227884):R.ffi.throwNonFunApp(L[1806],torepr65,[anf_arg546227884]);
};
try {
if(--R.GAS > 0) {
$z2787627877 = $f2788227883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2788227883,
"from":L[1806]});
}
} catch($e2787427875) {
if(R.isCont($e2787427875)) {
var $ss2787827879 = {"from":L[1806],
"go":function(anf_arg546327885) {
return $Hanf_arg1036227886(anf_arg546327885,anf_arg546127872,_plus55);
}};
$e2787427875.stack[R.EXN_STACKHEIGHT++] = $ss2787827879;
}
if(R.isPyretException($e2787427875)) {
$e2787427875.pyretStack.push(L[1806]);
}
throw $e2787427875;
}
var $ret2788027881 = $Hanf_arg1036227886($z2787627877,anf_arg546127872,_plus55);
++R.GAS;
return $ret2788027881;
};
var $Hanf_arg1036227886 = function(anf_arg546327885,anf_arg546127872,_plus55) {
var $z2788927890 = D;
var $f2789527896 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg546327885):R.ffi.throwNonFunApp(L[1806],_plus55,[(", "),anf_arg546327885]);
};
try {
if(--R.GAS > 0) {
$z2788927890 = $f2789527896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2789527896,
"from":L[1806]});
}
} catch($e2788727888) {
if(R.isCont($e2788727888)) {
var $ss2789127892 = {"from":L[1806],
"go":function(anf_arg546427897) {
return $Hanf_arg1036127898(anf_arg546427897,anf_arg546127872,_plus55);
}};
$e2788727888.stack[R.EXN_STACKHEIGHT++] = $ss2789127892;
}
if(R.isPyretException($e2788727888)) {
$e2788727888.pyretStack.push(L[1806]);
}
throw $e2788727888;
}
var $ret2789327894 = $Hanf_arg1036127898($z2788927890,anf_arg546127872,_plus55);
++R.GAS;
return $ret2789327894;
};
var $Hanf_arg1036127898 = function(anf_arg546427897,anf_arg546127872,_plus55) {
var $z2790127902 = D;
var $f2790727908 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg546127872,anf_arg546427897):R.ffi.throwNonFunApp(L[1806],_plus55,[anf_arg546127872,anf_arg546427897]);
};
try {
if(--R.GAS > 0) {
$z2790127902 = $f2790727908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2790727908,
"from":L[1806]});
}
} catch($e2789927900) {
if(R.isCont($e2789927900)) {
var $ss2790327904 = {"from":L[1806],
"go":function(anf_arg546527909) {
return $Hanf_arg1036027910(anf_arg546527909,_plus55);
}};
$e2789927900.stack[R.EXN_STACKHEIGHT++] = $ss2790327904;
}
if(R.isPyretException($e2789927900)) {
$e2789927900.pyretStack.push(L[1806]);
}
throw $e2789927900;
}
var $ret2790527906 = $Hanf_arg1036027910($z2790127902,_plus55);
++R.GAS;
return $ret2790527906;
};
var $Hanf_arg1036027910 = function(anf_arg546527909,_plus55) {
var $z2791327914 = D;
var $f2791927920 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg546527909,(")")):R.ffi.throwNonFunApp(L[1806],_plus55,[anf_arg546527909,(")")]);
};
try {
if(--R.GAS > 0) {
$z2791327914 = $f2791927920();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2791927920,
"from":L[1806]});
}
} catch($e2791127912) {
if(R.isCont($e2791127912)) {
var $ss2791527916 = {"from":L[1806],
"go":function(anf_arg546627921) {
return $Hanf_arg1035927922(anf_arg546627921,_plus55);
}};
$e2791127912.stack[R.EXN_STACKHEIGHT++] = $ss2791527916;
}
if(R.isPyretException($e2791127912)) {
$e2791127912.pyretStack.push(L[1806]);
}
throw $e2791127912;
}
var $ret2791727918 = $Hanf_arg1035927922($z2791327914,_plus55);
++R.GAS;
return $ret2791727918;
};
var $Hanf_arg1035927922 = function(anf_arg546627921,_plus55) {
var $z2792527926 = D;
var $f2793127932 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg546627921):R.ffi.throwNonFunApp(L[1806],_plus55,[("("),anf_arg546627921]);
};
try {
if(--R.GAS > 0) {
$z2792527926 = $f2793127932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2793127932,
"from":L[1806]});
}
} catch($e2792327924) {
if(R.isCont($e2792327924)) {
var $ss2792727928 = {"from":L[1806],
"go":function(anf_arg546727933) {
return $Hanf_arg1035827934(anf_arg546727933,_plus55);
}};
$e2792327924.stack[R.EXN_STACKHEIGHT++] = $ss2792727928;
}
if(R.isPyretException($e2792327924)) {
$e2792327924.pyretStack.push(L[1806]);
}
throw $e2792327924;
}
var $ret2792927930 = $Hanf_arg1035827934($z2792527926,_plus55);
++R.GAS;
return $ret2792927930;
};
var $Hanf_arg1035827934 = function(anf_arg546727933,_plus55) {
var $z2793727938 = D;
var $f2794327944 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("a-pred"),anf_arg546727933):R.ffi.throwNonFunApp(L[1806],_plus55,[("a-pred"),anf_arg546727933]);
};
try {
if(--R.GAS > 0) {
$z2793727938 = $f2794327944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2794327944,
"from":L[1806]});
}
} catch($e2793527936) {
if(R.isCont($e2793527936)) {
var $ss2793927940 = {"from":L[1806],
"go":function(ann_DASH_check_DASH_temp545527945) {
return $Hann_DASH_check_DASH_temp1035727946(ann_DASH_check_DASH_temp545527945);
}};
$e2793527936.stack[R.EXN_STACKHEIGHT++] = $ss2793927940;
}
if(R.isPyretException($e2793527936)) {
$e2793527936.pyretStack.push(L[1806]);
}
throw $e2793527936;
}
var $ret2794127942 = $Hann_DASH_check_DASH_temp1035727946($z2793727938);
++R.GAS;
return $ret2794127942;
};
var $Hann_DASH_check_DASH_temp1035727946 = function(ann_DASH_check_DASH_temp545527945) {
return ann_DASH_check_DASH_temp545527945;
};
var $Hcont_tail_arg103559617 = function(cont_tail_arg54529615,if_helper54429616) {
if(--R.GAS > 0) {
$z2794727948 = R.isFunction(if_helper54429616)?if_helper54429616.app(cont_tail_arg54529615):R.ffi.throwNonFunApp(L[1806],if_helper54429616,[cont_tail_arg54529615]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper54429616)?if_helper54429616.app(cont_tail_arg54529615):R.ffi.throwNonFunApp(L[1806],if_helper54429616,[cont_tail_arg54529615]);
},
"from":L[1806]});
}
++R.GAS;
return $z2794727948;
};
var $Hcont_tail_arg103569632 = function(cont_tail_arg54479631,if_helper54429616) {
if(--R.GAS > 0) {
$z2794927950 = R.isFunction(if_helper54429616)?if_helper54429616.app(cont_tail_arg54479631):R.ffi.throwNonFunApp(L[1806],if_helper54429616,[cont_tail_arg54479631]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper54429616)?if_helper54429616.app(cont_tail_arg54479631):R.ffi.throwNonFunApp(L[1806],if_helper54429616,[cont_tail_arg54479631]);
},
"from":L[1806]});
}
++R.GAS;
return $z2794927950;
};
var $Hanf_arg103549654 = function(anf_arg54219651,INDENT118169,PP170,anf_fun54189652,self11639653,_plus55) {
var anf_fun542227966 = G(PP170,"group",L[3975]);
var anf_arg542327964 = G(PP170,"langle",L[3974]);
var anf_fun542427967 = G(PP170,"nest",L[3973]);
var anf_fun542527968 = G(PP170,"separate",L[3972]);
var anf_arg542627965 = G(PP170,"commabreak",L[3971]);
var anf_bracket542727984 = G(self11639653,"args",L[3970]);
var anf_fun542827961 = G(anf_bracket542727984,"map",L[3969]);
var anf_arg543127962 = R.makeFunction(function(recv_DASH_68727970) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3968],1,arguments);
}
var anf_fun543027981 = G(recv_DASH_68727970,"tosource",L[3968]);
var $z2797327974 = D;
var $f2797927980 = function(_) {
return R.isFunction(anf_fun543027981)?anf_fun543027981.app():R.ffi.throwNonFunApp(L[3968],anf_fun543027981,[]);
};
try {
if(--R.GAS > 0) {
$z2797327974 = $f2797927980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2797927980,
"from":L[3968]});
}
} catch($e2797127972) {
if(R.isCont($e2797127972)) {
var $ss2797527976 = {"from":L[3968],
"go":function(ann_DASH_check_DASH_temp542927982) {
return $Hann_DASH_check_DASH_temp1034527983(ann_DASH_check_DASH_temp542927982);
}};
$e2797127972.stack[R.EXN_STACKHEIGHT++] = $ss2797527976;
}
if(R.isPyretException($e2797127972)) {
$e2797127972.pyretStack.push(L[3968]);
}
throw $e2797127972;
}
var $ret2797727978 = $Hann_DASH_check_DASH_temp1034527983($z2797327974);
++R.GAS;
return $ret2797727978;
});
var $z2795327954 = D;
var $f2795927960 = function(_) {
return R.isFunction(anf_fun542827961)?anf_fun542827961.app(anf_arg543127962):R.ffi.throwNonFunApp(L[3967],anf_fun542827961,[anf_arg543127962]);
};
try {
if(--R.GAS > 0) {
$z2795327954 = $f2795927960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2795927960,
"from":L[3967]});
}
} catch($e2795127952) {
if(R.isCont($e2795127952)) {
var $ss2795527956 = {"from":L[3967],
"go":function(anf_arg543227963) {
return $Hanf_arg1035327969(anf_arg543227963,INDENT118169,PP170,anf_arg54219651,anf_arg542327964,anf_arg542627965,anf_fun54189652,anf_fun542227966,anf_fun542427967,anf_fun542527968,_plus55);
}};
$e2795127952.stack[R.EXN_STACKHEIGHT++] = $ss2795527956;
}
if(R.isPyretException($e2795127952)) {
$e2795127952.pyretStack.push(L[3967]);
}
throw $e2795127952;
}
var $ret2795727958 = $Hanf_arg1035327969($z2795327954,INDENT118169,PP170,anf_arg54219651,anf_arg542327964,anf_arg542627965,anf_fun54189652,anf_fun542227966,anf_fun542427967,anf_fun542527968,_plus55);
++R.GAS;
return $ret2795727958;
};
var $Hanf_arg1035327969 = function(anf_arg543227963,INDENT118169,PP170,anf_arg54219651,anf_arg542327964,anf_arg542627965,anf_fun54189652,anf_fun542227966,anf_fun542427967,anf_fun542527968,_plus55) {
var $z2798727988 = D;
var $f2799327994 = function(_) {
return R.isFunction(anf_fun542527968)?anf_fun542527968.app(anf_arg542627965,anf_arg543227963):R.ffi.throwNonFunApp(L[3976],anf_fun542527968,[anf_arg542627965,anf_arg543227963]);
};
try {
if(--R.GAS > 0) {
$z2798727988 = $f2799327994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2799327994,
"from":L[3976]});
}
} catch($e2798527986) {
if(R.isCont($e2798527986)) {
var $ss2798927990 = {"from":L[3976],
"go":function(anf_arg543327995) {
return $Hanf_arg1035227996(anf_arg543327995,INDENT118169,PP170,anf_arg54219651,anf_arg542327964,anf_fun54189652,anf_fun542227966,anf_fun542427967,_plus55);
}};
$e2798527986.stack[R.EXN_STACKHEIGHT++] = $ss2798927990;
}
if(R.isPyretException($e2798527986)) {
$e2798527986.pyretStack.push(L[3976]);
}
throw $e2798527986;
}
var $ret2799127992 = $Hanf_arg1035227996($z2798727988,INDENT118169,PP170,anf_arg54219651,anf_arg542327964,anf_fun54189652,anf_fun542227966,anf_fun542427967,_plus55);
++R.GAS;
return $ret2799127992;
};
var $Hanf_arg1035227996 = function(anf_arg543327995,INDENT118169,PP170,anf_arg54219651,anf_arg542327964,anf_fun54189652,anf_fun542227966,anf_fun542427967,_plus55) {
var $z2799928000 = D;
var $f2800528006 = function(_) {
return R.isFunction(anf_fun542427967)?anf_fun542427967.app(INDENT118169,anf_arg543327995):R.ffi.throwNonFunApp(L[3977],anf_fun542427967,[INDENT118169,anf_arg543327995]);
};
try {
if(--R.GAS > 0) {
$z2799928000 = $f2800528006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2800528006,
"from":L[3977]});
}
} catch($e2799727998) {
if(R.isCont($e2799727998)) {
var $ss2800128002 = {"from":L[3977],
"go":function(anf_arg543428007) {
return $Hanf_arg1035128008(anf_arg543428007,PP170,anf_arg54219651,anf_arg542327964,anf_fun54189652,anf_fun542227966,_plus55);
}};
$e2799727998.stack[R.EXN_STACKHEIGHT++] = $ss2800128002;
}
if(R.isPyretException($e2799727998)) {
$e2799727998.pyretStack.push(L[3977]);
}
throw $e2799727998;
}
var $ret2800328004 = $Hanf_arg1035128008($z2799928000,PP170,anf_arg54219651,anf_arg542327964,anf_fun54189652,anf_fun542227966,_plus55);
++R.GAS;
return $ret2800328004;
};
var $Hanf_arg1035128008 = function(anf_arg543428007,PP170,anf_arg54219651,anf_arg542327964,anf_fun54189652,anf_fun542227966,_plus55) {
var $z2801128012 = D;
var $f2801728018 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg542327964,anf_arg543428007):R.ffi.throwNonFunApp(L[3978],_plus55,[anf_arg542327964,anf_arg543428007]);
};
try {
if(--R.GAS > 0) {
$z2801128012 = $f2801728018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2801728018,
"from":L[3978]});
}
} catch($e2800928010) {
if(R.isCont($e2800928010)) {
var $ss2801328014 = {"from":L[3978],
"go":function(anf_arg543528019) {
return $Hanf_arg1035028020(anf_arg543528019,PP170,anf_arg54219651,anf_fun54189652,anf_fun542227966,_plus55);
}};
$e2800928010.stack[R.EXN_STACKHEIGHT++] = $ss2801328014;
}
if(R.isPyretException($e2800928010)) {
$e2800928010.pyretStack.push(L[3978]);
}
throw $e2800928010;
}
var $ret2801528016 = $Hanf_arg1035028020($z2801128012,PP170,anf_arg54219651,anf_fun54189652,anf_fun542227966,_plus55);
++R.GAS;
return $ret2801528016;
};
var $Hanf_arg1035028020 = function(anf_arg543528019,PP170,anf_arg54219651,anf_fun54189652,anf_fun542227966,_plus55) {
var anf_arg543628031 = G(PP170,"rangle",L[3979]);
var $z2802328024 = D;
var $f2802928030 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg543528019,anf_arg543628031):R.ffi.throwNonFunApp(L[3978],_plus55,[anf_arg543528019,anf_arg543628031]);
};
try {
if(--R.GAS > 0) {
$z2802328024 = $f2802928030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2802928030,
"from":L[3978]});
}
} catch($e2802128022) {
if(R.isCont($e2802128022)) {
var $ss2802528026 = {"from":L[3978],
"go":function(anf_arg543728032) {
return $Hanf_arg1034928033(anf_arg543728032,anf_arg54219651,anf_fun54189652,anf_fun542227966,_plus55);
}};
$e2802128022.stack[R.EXN_STACKHEIGHT++] = $ss2802528026;
}
if(R.isPyretException($e2802128022)) {
$e2802128022.pyretStack.push(L[3978]);
}
throw $e2802128022;
}
var $ret2802728028 = $Hanf_arg1034928033($z2802328024,anf_arg54219651,anf_fun54189652,anf_fun542227966,_plus55);
++R.GAS;
return $ret2802728028;
};
var $Hanf_arg1034928033 = function(anf_arg543728032,anf_arg54219651,anf_fun54189652,anf_fun542227966,_plus55) {
var $z2803628037 = D;
var $f2804228043 = function(_) {
return R.isFunction(anf_fun542227966)?anf_fun542227966.app(anf_arg543728032):R.ffi.throwNonFunApp(L[3980],anf_fun542227966,[anf_arg543728032]);
};
try {
if(--R.GAS > 0) {
$z2803628037 = $f2804228043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2804228043,
"from":L[3980]});
}
} catch($e2803428035) {
if(R.isCont($e2803428035)) {
var $ss2803828039 = {"from":L[3980],
"go":function(anf_arg543828044) {
return $Hanf_arg1034828045(anf_arg543828044,anf_arg54219651,anf_fun54189652,_plus55);
}};
$e2803428035.stack[R.EXN_STACKHEIGHT++] = $ss2803828039;
}
if(R.isPyretException($e2803428035)) {
$e2803428035.pyretStack.push(L[3980]);
}
throw $e2803428035;
}
var $ret2804028041 = $Hanf_arg1034828045($z2803628037,anf_arg54219651,anf_fun54189652,_plus55);
++R.GAS;
return $ret2804028041;
};
var $Hanf_arg1034828045 = function(anf_arg543828044,anf_arg54219651,anf_fun54189652,_plus55) {
var $z2804828049 = D;
var $f2805428055 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg54219651,anf_arg543828044):R.ffi.throwNonFunApp(L[3981],_plus55,[anf_arg54219651,anf_arg543828044]);
};
try {
if(--R.GAS > 0) {
$z2804828049 = $f2805428055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2805428055,
"from":L[3981]});
}
} catch($e2804628047) {
if(R.isCont($e2804628047)) {
var $ss2805028051 = {"from":L[3981],
"go":function(anf_arg543928056) {
return $Hanf_arg1034728057(anf_arg543928056,anf_fun54189652);
}};
$e2804628047.stack[R.EXN_STACKHEIGHT++] = $ss2805028051;
}
if(R.isPyretException($e2804628047)) {
$e2804628047.pyretStack.push(L[3981]);
}
throw $e2804628047;
}
var $ret2805228053 = $Hanf_arg1034728057($z2804828049,anf_fun54189652);
++R.GAS;
return $ret2805228053;
};
var $Hanf_arg1034728057 = function(anf_arg543928056,anf_fun54189652) {
var $z2806028061 = D;
var $f2806628067 = function(_) {
return R.isFunction(anf_fun54189652)?anf_fun54189652.app(anf_arg543928056):R.ffi.throwNonFunApp(L[1862],anf_fun54189652,[anf_arg543928056]);
};
try {
if(--R.GAS > 0) {
$z2806028061 = $f2806628067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2806628067,
"from":L[1862]});
}
} catch($e2805828059) {
if(R.isCont($e2805828059)) {
var $ss2806228063 = {"from":L[1862],
"go":function(ann_DASH_check_DASH_temp541728068) {
return $Hann_DASH_check_DASH_temp1034628069(ann_DASH_check_DASH_temp541728068);
}};
$e2805828059.stack[R.EXN_STACKHEIGHT++] = $ss2806228063;
}
if(R.isPyretException($e2805828059)) {
$e2805828059.pyretStack.push(L[1862]);
}
throw $e2805828059;
}
var $ret2806428065 = $Hann_DASH_check_DASH_temp1034628069($z2806028061);
++R.GAS;
return $ret2806428065;
};
var $Hann_DASH_check_DASH_temp1034628069 = function(ann_DASH_check_DASH_temp541728068) {
return ann_DASH_check_DASH_temp541728068;
};
var $Hann_DASH_check_DASH_temp1034527983 = function(ann_DASH_check_DASH_temp542927982) {
return ann_DASH_check_DASH_temp542927982;
};
var $Hanf_arg103449671 = function(anf_arg54039669,self6859670,_plus55,torepr65) {
var anf_arg540428080 = G(self6859670,"ann",L[1807]);
var $z2807228073 = D;
var $f2807828079 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg540428080):R.ffi.throwNonFunApp(L[1807],torepr65,[anf_arg540428080]);
};
try {
if(--R.GAS > 0) {
$z2807228073 = $f2807828079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2807828079,
"from":L[1807]});
}
} catch($e2807028071) {
if(R.isCont($e2807028071)) {
var $ss2807428075 = {"from":L[1807],
"go":function(anf_arg540528081) {
return $Hanf_arg1034328082(anf_arg540528081,anf_arg54039669,self6859670,_plus55,torepr65);
}};
$e2807028071.stack[R.EXN_STACKHEIGHT++] = $ss2807428075;
}
if(R.isPyretException($e2807028071)) {
$e2807028071.pyretStack.push(L[1807]);
}
throw $e2807028071;
}
var $ret2807628077 = $Hanf_arg1034328082($z2807228073,anf_arg54039669,self6859670,_plus55,torepr65);
++R.GAS;
return $ret2807628077;
};
var $Hanf_arg1034328082 = function(anf_arg540528081,anf_arg54039669,self6859670,_plus55,torepr65) {
var $z2808528086 = D;
var $f2809128092 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg540528081):R.ffi.throwNonFunApp(L[1807],_plus55,[(", "),anf_arg540528081]);
};
try {
if(--R.GAS > 0) {
$z2808528086 = $f2809128092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2809128092,
"from":L[1807]});
}
} catch($e2808328084) {
if(R.isCont($e2808328084)) {
var $ss2808728088 = {"from":L[1807],
"go":function(anf_arg540628093) {
return $Hanf_arg1034228094(anf_arg540628093,anf_arg54039669,self6859670,_plus55,torepr65);
}};
$e2808328084.stack[R.EXN_STACKHEIGHT++] = $ss2808728088;
}
if(R.isPyretException($e2808328084)) {
$e2808328084.pyretStack.push(L[1807]);
}
throw $e2808328084;
}
var $ret2808928090 = $Hanf_arg1034228094($z2808528086,anf_arg54039669,self6859670,_plus55,torepr65);
++R.GAS;
return $ret2808928090;
};
var $Hanf_arg1034228094 = function(anf_arg540628093,anf_arg54039669,self6859670,_plus55,torepr65) {
var $z2809728098 = D;
var $f2810328104 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg54039669,anf_arg540628093):R.ffi.throwNonFunApp(L[1807],_plus55,[anf_arg54039669,anf_arg540628093]);
};
try {
if(--R.GAS > 0) {
$z2809728098 = $f2810328104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2810328104,
"from":L[1807]});
}
} catch($e2809528096) {
if(R.isCont($e2809528096)) {
var $ss2809928100 = {"from":L[1807],
"go":function(anf_arg540728105) {
return $Hanf_arg1034128106(anf_arg540728105,self6859670,_plus55,torepr65);
}};
$e2809528096.stack[R.EXN_STACKHEIGHT++] = $ss2809928100;
}
if(R.isPyretException($e2809528096)) {
$e2809528096.pyretStack.push(L[1807]);
}
throw $e2809528096;
}
var $ret2810128102 = $Hanf_arg1034128106($z2809728098,self6859670,_plus55,torepr65);
++R.GAS;
return $ret2810128102;
};
var $Hanf_arg1034128106 = function(anf_arg540728105,self6859670,_plus55,torepr65) {
var anf_arg540828117 = G(self6859670,"args",L[1807]);
var $z2810928110 = D;
var $f2811528116 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg540828117):R.ffi.throwNonFunApp(L[1807],torepr65,[anf_arg540828117]);
};
try {
if(--R.GAS > 0) {
$z2810928110 = $f2811528116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2811528116,
"from":L[1807]});
}
} catch($e2810728108) {
if(R.isCont($e2810728108)) {
var $ss2811128112 = {"from":L[1807],
"go":function(anf_arg540928118) {
return $Hanf_arg1034028119(anf_arg540928118,anf_arg540728105,_plus55);
}};
$e2810728108.stack[R.EXN_STACKHEIGHT++] = $ss2811128112;
}
if(R.isPyretException($e2810728108)) {
$e2810728108.pyretStack.push(L[1807]);
}
throw $e2810728108;
}
var $ret2811328114 = $Hanf_arg1034028119($z2810928110,anf_arg540728105,_plus55);
++R.GAS;
return $ret2811328114;
};
var $Hanf_arg1034028119 = function(anf_arg540928118,anf_arg540728105,_plus55) {
var $z2812228123 = D;
var $f2812828129 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg540928118):R.ffi.throwNonFunApp(L[1807],_plus55,[(", "),anf_arg540928118]);
};
try {
if(--R.GAS > 0) {
$z2812228123 = $f2812828129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2812828129,
"from":L[1807]});
}
} catch($e2812028121) {
if(R.isCont($e2812028121)) {
var $ss2812428125 = {"from":L[1807],
"go":function(anf_arg541028130) {
return $Hanf_arg1033928131(anf_arg541028130,anf_arg540728105,_plus55);
}};
$e2812028121.stack[R.EXN_STACKHEIGHT++] = $ss2812428125;
}
if(R.isPyretException($e2812028121)) {
$e2812028121.pyretStack.push(L[1807]);
}
throw $e2812028121;
}
var $ret2812628127 = $Hanf_arg1033928131($z2812228123,anf_arg540728105,_plus55);
++R.GAS;
return $ret2812628127;
};
var $Hanf_arg1033928131 = function(anf_arg541028130,anf_arg540728105,_plus55) {
var $z2813428135 = D;
var $f2814028141 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg540728105,anf_arg541028130):R.ffi.throwNonFunApp(L[1807],_plus55,[anf_arg540728105,anf_arg541028130]);
};
try {
if(--R.GAS > 0) {
$z2813428135 = $f2814028141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2814028141,
"from":L[1807]});
}
} catch($e2813228133) {
if(R.isCont($e2813228133)) {
var $ss2813628137 = {"from":L[1807],
"go":function(anf_arg541128142) {
return $Hanf_arg1033828143(anf_arg541128142,_plus55);
}};
$e2813228133.stack[R.EXN_STACKHEIGHT++] = $ss2813628137;
}
if(R.isPyretException($e2813228133)) {
$e2813228133.pyretStack.push(L[1807]);
}
throw $e2813228133;
}
var $ret2813828139 = $Hanf_arg1033828143($z2813428135,_plus55);
++R.GAS;
return $ret2813828139;
};
var $Hanf_arg1033828143 = function(anf_arg541128142,_plus55) {
var $z2814628147 = D;
var $f2815228153 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg541128142,(")")):R.ffi.throwNonFunApp(L[1807],_plus55,[anf_arg541128142,(")")]);
};
try {
if(--R.GAS > 0) {
$z2814628147 = $f2815228153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2815228153,
"from":L[1807]});
}
} catch($e2814428145) {
if(R.isCont($e2814428145)) {
var $ss2814828149 = {"from":L[1807],
"go":function(anf_arg541228154) {
return $Hanf_arg1033728155(anf_arg541228154,_plus55);
}};
$e2814428145.stack[R.EXN_STACKHEIGHT++] = $ss2814828149;
}
if(R.isPyretException($e2814428145)) {
$e2814428145.pyretStack.push(L[1807]);
}
throw $e2814428145;
}
var $ret2815028151 = $Hanf_arg1033728155($z2814628147,_plus55);
++R.GAS;
return $ret2815028151;
};
var $Hanf_arg1033728155 = function(anf_arg541228154,_plus55) {
var $z2815828159 = D;
var $f2816428165 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg541228154):R.ffi.throwNonFunApp(L[1807],_plus55,[("("),anf_arg541228154]);
};
try {
if(--R.GAS > 0) {
$z2815828159 = $f2816428165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2816428165,
"from":L[1807]});
}
} catch($e2815628157) {
if(R.isCont($e2815628157)) {
var $ss2816028161 = {"from":L[1807],
"go":function(anf_arg541328166) {
return $Hanf_arg1033628167(anf_arg541328166,_plus55);
}};
$e2815628157.stack[R.EXN_STACKHEIGHT++] = $ss2816028161;
}
if(R.isPyretException($e2815628157)) {
$e2815628157.pyretStack.push(L[1807]);
}
throw $e2815628157;
}
var $ret2816228163 = $Hanf_arg1033628167($z2815828159,_plus55);
++R.GAS;
return $ret2816228163;
};
var $Hanf_arg1033628167 = function(anf_arg541328166,_plus55) {
var $z2817028171 = D;
var $f2817628177 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("a-app"),anf_arg541328166):R.ffi.throwNonFunApp(L[1807],_plus55,[("a-app"),anf_arg541328166]);
};
try {
if(--R.GAS > 0) {
$z2817028171 = $f2817628177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2817628177,
"from":L[1807]});
}
} catch($e2816828169) {
if(R.isCont($e2816828169)) {
var $ss2817228173 = {"from":L[1807],
"go":function(ann_DASH_check_DASH_temp540128178) {
return $Hann_DASH_check_DASH_temp1033528179(ann_DASH_check_DASH_temp540128178);
}};
$e2816828169.stack[R.EXN_STACKHEIGHT++] = $ss2817228173;
}
if(R.isPyretException($e2816828169)) {
$e2816828169.pyretStack.push(L[1807]);
}
throw $e2816828169;
}
var $ret2817428175 = $Hann_DASH_check_DASH_temp1033528179($z2817028171);
++R.GAS;
return $ret2817428175;
};
var $Hann_DASH_check_DASH_temp1033528179 = function(ann_DASH_check_DASH_temp540128178) {
return ann_DASH_check_DASH_temp540128178;
};
var $Hcont_tail_arg103339688 = function(cont_tail_arg53989686,if_helper53889687) {
if(--R.GAS > 0) {
$z2818028181 = R.isFunction(if_helper53889687)?if_helper53889687.app(cont_tail_arg53989686):R.ffi.throwNonFunApp(L[1807],if_helper53889687,[cont_tail_arg53989686]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53889687)?if_helper53889687.app(cont_tail_arg53989686):R.ffi.throwNonFunApp(L[1807],if_helper53889687,[cont_tail_arg53989686]);
},
"from":L[1807]});
}
++R.GAS;
return $z2818028181;
};
var $Hcont_tail_arg103349703 = function(cont_tail_arg53939702,if_helper53889687) {
if(--R.GAS > 0) {
$z2818228183 = R.isFunction(if_helper53889687)?if_helper53889687.app(cont_tail_arg53939702):R.ffi.throwNonFunApp(L[1807],if_helper53889687,[cont_tail_arg53939702]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53889687)?if_helper53889687.app(cont_tail_arg53939702):R.ffi.throwNonFunApp(L[1807],if_helper53889687,[cont_tail_arg53939702]);
},
"from":L[1807]});
}
++R.GAS;
return $z2818228183;
};
var $Hanf_arg103329726 = function(anf_arg53769723,INDENT118169,PP170,anf_fun53739724,self11589725) {
var anf_arg537728197 = G(PP170,"lbrace",L[3988]);
var anf_arg537828198 = G(PP170,"commabreak",L[3987]);
var anf_arg537928199 = G(PP170,"rbrace",L[3986]);
var anf_bracket538028215 = G(self11589725,"fields",L[3985]);
var anf_fun538128194 = G(anf_bracket538028215,"map",L[3984]);
var anf_arg538428195 = R.makeFunction(function(recv_DASH_68028201) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3983],1,arguments);
}
var anf_fun538328212 = G(recv_DASH_68028201,"tosource",L[3983]);
var $z2820428205 = D;
var $f2821028211 = function(_) {
return R.isFunction(anf_fun538328212)?anf_fun538328212.app():R.ffi.throwNonFunApp(L[3983],anf_fun538328212,[]);
};
try {
if(--R.GAS > 0) {
$z2820428205 = $f2821028211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2821028211,
"from":L[3983]});
}
} catch($e2820228203) {
if(R.isCont($e2820228203)) {
var $ss2820628207 = {"from":L[3983],
"go":function(ann_DASH_check_DASH_temp538228213) {
return $Hann_DASH_check_DASH_temp1032928214(ann_DASH_check_DASH_temp538228213);
}};
$e2820228203.stack[R.EXN_STACKHEIGHT++] = $ss2820628207;
}
if(R.isPyretException($e2820228203)) {
$e2820228203.pyretStack.push(L[3983]);
}
throw $e2820228203;
}
var $ret2820828209 = $Hann_DASH_check_DASH_temp1032928214($z2820428205);
++R.GAS;
return $ret2820828209;
});
var $z2818628187 = D;
var $f2819228193 = function(_) {
return R.isFunction(anf_fun538128194)?anf_fun538128194.app(anf_arg538428195):R.ffi.throwNonFunApp(L[3982],anf_fun538128194,[anf_arg538428195]);
};
try {
if(--R.GAS > 0) {
$z2818628187 = $f2819228193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2819228193,
"from":L[3982]});
}
} catch($e2818428185) {
if(R.isCont($e2818428185)) {
var $ss2818828189 = {"from":L[3982],
"go":function(anf_arg538528196) {
return $Hanf_arg1033128200(anf_arg538528196,INDENT118169,anf_arg53769723,anf_arg537728197,anf_arg537828198,anf_arg537928199,anf_fun53739724);
}};
$e2818428185.stack[R.EXN_STACKHEIGHT++] = $ss2818828189;
}
if(R.isPyretException($e2818428185)) {
$e2818428185.pyretStack.push(L[3982]);
}
throw $e2818428185;
}
var $ret2819028191 = $Hanf_arg1033128200($z2818628187,INDENT118169,anf_arg53769723,anf_arg537728197,anf_arg537828198,anf_arg537928199,anf_fun53739724);
++R.GAS;
return $ret2819028191;
};
var $Hanf_arg1033128200 = function(anf_arg538528196,INDENT118169,anf_arg53769723,anf_arg537728197,anf_arg537828198,anf_arg537928199,anf_fun53739724) {
var $z2821828219 = D;
var $f2822428225 = function(_) {
return R.isFunction(anf_fun53739724)?anf_fun53739724.app(INDENT118169,(1),anf_arg53769723,anf_arg537728197,anf_arg537828198,anf_arg537928199,anf_arg538528196):R.ffi.throwNonFunApp(L[1871],anf_fun53739724,[INDENT118169,(1),anf_arg53769723,anf_arg537728197,anf_arg537828198,anf_arg537928199,anf_arg538528196]);
};
try {
if(--R.GAS > 0) {
$z2821828219 = $f2822428225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2822428225,
"from":L[1871]});
}
} catch($e2821628217) {
if(R.isCont($e2821628217)) {
var $ss2822028221 = {"from":L[1871],
"go":function(ann_DASH_check_DASH_temp537228226) {
return $Hann_DASH_check_DASH_temp1033028227(ann_DASH_check_DASH_temp537228226);
}};
$e2821628217.stack[R.EXN_STACKHEIGHT++] = $ss2822028221;
}
if(R.isPyretException($e2821628217)) {
$e2821628217.pyretStack.push(L[1871]);
}
throw $e2821628217;
}
var $ret2822228223 = $Hann_DASH_check_DASH_temp1033028227($z2821828219);
++R.GAS;
return $ret2822228223;
};
var $Hann_DASH_check_DASH_temp1033028227 = function(ann_DASH_check_DASH_temp537228226) {
return ann_DASH_check_DASH_temp537228226;
};
var $Hann_DASH_check_DASH_temp1032928214 = function(ann_DASH_check_DASH_temp538228213) {
return ann_DASH_check_DASH_temp538228213;
};
var $Hanf_arg103289742 = function(anf_arg53629740,self6789741,_plus55,torepr65) {
var anf_arg536328238 = G(self6789741,"fields",L[1808]);
var $z2823028231 = D;
var $f2823628237 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg536328238):R.ffi.throwNonFunApp(L[1808],torepr65,[anf_arg536328238]);
};
try {
if(--R.GAS > 0) {
$z2823028231 = $f2823628237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2823628237,
"from":L[1808]});
}
} catch($e2822828229) {
if(R.isCont($e2822828229)) {
var $ss2823228233 = {"from":L[1808],
"go":function(anf_arg536428239) {
return $Hanf_arg1032728240(anf_arg536428239,anf_arg53629740,_plus55);
}};
$e2822828229.stack[R.EXN_STACKHEIGHT++] = $ss2823228233;
}
if(R.isPyretException($e2822828229)) {
$e2822828229.pyretStack.push(L[1808]);
}
throw $e2822828229;
}
var $ret2823428235 = $Hanf_arg1032728240($z2823028231,anf_arg53629740,_plus55);
++R.GAS;
return $ret2823428235;
};
var $Hanf_arg1032728240 = function(anf_arg536428239,anf_arg53629740,_plus55) {
var $z2824328244 = D;
var $f2824928250 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg536428239):R.ffi.throwNonFunApp(L[1808],_plus55,[(", "),anf_arg536428239]);
};
try {
if(--R.GAS > 0) {
$z2824328244 = $f2824928250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2824928250,
"from":L[1808]});
}
} catch($e2824128242) {
if(R.isCont($e2824128242)) {
var $ss2824528246 = {"from":L[1808],
"go":function(anf_arg536528251) {
return $Hanf_arg1032628252(anf_arg536528251,anf_arg53629740,_plus55);
}};
$e2824128242.stack[R.EXN_STACKHEIGHT++] = $ss2824528246;
}
if(R.isPyretException($e2824128242)) {
$e2824128242.pyretStack.push(L[1808]);
}
throw $e2824128242;
}
var $ret2824728248 = $Hanf_arg1032628252($z2824328244,anf_arg53629740,_plus55);
++R.GAS;
return $ret2824728248;
};
var $Hanf_arg1032628252 = function(anf_arg536528251,anf_arg53629740,_plus55) {
var $z2825528256 = D;
var $f2826128262 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg53629740,anf_arg536528251):R.ffi.throwNonFunApp(L[1808],_plus55,[anf_arg53629740,anf_arg536528251]);
};
try {
if(--R.GAS > 0) {
$z2825528256 = $f2826128262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2826128262,
"from":L[1808]});
}
} catch($e2825328254) {
if(R.isCont($e2825328254)) {
var $ss2825728258 = {"from":L[1808],
"go":function(anf_arg536628263) {
return $Hanf_arg1032528264(anf_arg536628263,_plus55);
}};
$e2825328254.stack[R.EXN_STACKHEIGHT++] = $ss2825728258;
}
if(R.isPyretException($e2825328254)) {
$e2825328254.pyretStack.push(L[1808]);
}
throw $e2825328254;
}
var $ret2825928260 = $Hanf_arg1032528264($z2825528256,_plus55);
++R.GAS;
return $ret2825928260;
};
var $Hanf_arg1032528264 = function(anf_arg536628263,_plus55) {
var $z2826728268 = D;
var $f2827328274 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg536628263,(")")):R.ffi.throwNonFunApp(L[1808],_plus55,[anf_arg536628263,(")")]);
};
try {
if(--R.GAS > 0) {
$z2826728268 = $f2827328274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2827328274,
"from":L[1808]});
}
} catch($e2826528266) {
if(R.isCont($e2826528266)) {
var $ss2826928270 = {"from":L[1808],
"go":function(anf_arg536728275) {
return $Hanf_arg1032428276(anf_arg536728275,_plus55);
}};
$e2826528266.stack[R.EXN_STACKHEIGHT++] = $ss2826928270;
}
if(R.isPyretException($e2826528266)) {
$e2826528266.pyretStack.push(L[1808]);
}
throw $e2826528266;
}
var $ret2827128272 = $Hanf_arg1032428276($z2826728268,_plus55);
++R.GAS;
return $ret2827128272;
};
var $Hanf_arg1032428276 = function(anf_arg536728275,_plus55) {
var $z2827928280 = D;
var $f2828528286 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg536728275):R.ffi.throwNonFunApp(L[1808],_plus55,[("("),anf_arg536728275]);
};
try {
if(--R.GAS > 0) {
$z2827928280 = $f2828528286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2828528286,
"from":L[1808]});
}
} catch($e2827728278) {
if(R.isCont($e2827728278)) {
var $ss2828128282 = {"from":L[1808],
"go":function(anf_arg536828287) {
return $Hanf_arg1032328288(anf_arg536828287,_plus55);
}};
$e2827728278.stack[R.EXN_STACKHEIGHT++] = $ss2828128282;
}
if(R.isPyretException($e2827728278)) {
$e2827728278.pyretStack.push(L[1808]);
}
throw $e2827728278;
}
var $ret2828328284 = $Hanf_arg1032328288($z2827928280,_plus55);
++R.GAS;
return $ret2828328284;
};
var $Hanf_arg1032328288 = function(anf_arg536828287,_plus55) {
var $z2829128292 = D;
var $f2829728298 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("a-record"),anf_arg536828287):R.ffi.throwNonFunApp(L[1808],_plus55,[("a-record"),anf_arg536828287]);
};
try {
if(--R.GAS > 0) {
$z2829128292 = $f2829728298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2829728298,
"from":L[1808]});
}
} catch($e2828928290) {
if(R.isCont($e2828928290)) {
var $ss2829328294 = {"from":L[1808],
"go":function(ann_DASH_check_DASH_temp536028299) {
return $Hann_DASH_check_DASH_temp1032228300(ann_DASH_check_DASH_temp536028299);
}};
$e2828928290.stack[R.EXN_STACKHEIGHT++] = $ss2829328294;
}
if(R.isPyretException($e2828928290)) {
$e2828928290.pyretStack.push(L[1808]);
}
throw $e2828928290;
}
var $ret2829528296 = $Hann_DASH_check_DASH_temp1032228300($z2829128292);
++R.GAS;
return $ret2829528296;
};
var $Hann_DASH_check_DASH_temp1032228300 = function(ann_DASH_check_DASH_temp536028299) {
return ann_DASH_check_DASH_temp536028299;
};
var $Hcont_tail_arg103209758 = function(cont_tail_arg53579756,if_helper53489757) {
if(--R.GAS > 0) {
$z2830128302 = R.isFunction(if_helper53489757)?if_helper53489757.app(cont_tail_arg53579756):R.ffi.throwNonFunApp(L[1808],if_helper53489757,[cont_tail_arg53579756]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53489757)?if_helper53489757.app(cont_tail_arg53579756):R.ffi.throwNonFunApp(L[1808],if_helper53489757,[cont_tail_arg53579756]);
},
"from":L[1808]});
}
++R.GAS;
return $z2830128302;
};
var $Hcont_tail_arg103219773 = function(cont_tail_arg53539772,if_helper53489757) {
if(--R.GAS > 0) {
$z2830328304 = R.isFunction(if_helper53489757)?if_helper53489757.app(cont_tail_arg53539772):R.ffi.throwNonFunApp(L[1808],if_helper53489757,[cont_tail_arg53539772]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53489757)?if_helper53489757.app(cont_tail_arg53539772):R.ffi.throwNonFunApp(L[1808],if_helper53489757,[cont_tail_arg53539772]);
},
"from":L[1808]});
}
++R.GAS;
return $z2830328304;
};
var $Hann_DASH_check_DASH_temp103199793 = function(ann_DASH_check_DASH_temp53449792) {
return ann_DASH_check_DASH_temp53449792;
};
var $Hanf_arg103189810 = function(anf_arg53309808,self6729809,_plus55,torepr65) {
var anf_arg533128315 = G(self6729809,"args",L[1809]);
var $z2830728308 = D;
var $f2831328314 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg533128315):R.ffi.throwNonFunApp(L[1809],torepr65,[anf_arg533128315]);
};
try {
if(--R.GAS > 0) {
$z2830728308 = $f2831328314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2831328314,
"from":L[1809]});
}
} catch($e2830528306) {
if(R.isCont($e2830528306)) {
var $ss2830928310 = {"from":L[1809],
"go":function(anf_arg533228316) {
return $Hanf_arg1031728317(anf_arg533228316,anf_arg53309808,self6729809,_plus55,torepr65);
}};
$e2830528306.stack[R.EXN_STACKHEIGHT++] = $ss2830928310;
}
if(R.isPyretException($e2830528306)) {
$e2830528306.pyretStack.push(L[1809]);
}
throw $e2830528306;
}
var $ret2831128312 = $Hanf_arg1031728317($z2830728308,anf_arg53309808,self6729809,_plus55,torepr65);
++R.GAS;
return $ret2831128312;
};
var $Hanf_arg1031728317 = function(anf_arg533228316,anf_arg53309808,self6729809,_plus55,torepr65) {
var $z2832028321 = D;
var $f2832628327 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg533228316):R.ffi.throwNonFunApp(L[1809],_plus55,[(", "),anf_arg533228316]);
};
try {
if(--R.GAS > 0) {
$z2832028321 = $f2832628327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2832628327,
"from":L[1809]});
}
} catch($e2831828319) {
if(R.isCont($e2831828319)) {
var $ss2832228323 = {"from":L[1809],
"go":function(anf_arg533328328) {
return $Hanf_arg1031628329(anf_arg533328328,anf_arg53309808,self6729809,_plus55,torepr65);
}};
$e2831828319.stack[R.EXN_STACKHEIGHT++] = $ss2832228323;
}
if(R.isPyretException($e2831828319)) {
$e2831828319.pyretStack.push(L[1809]);
}
throw $e2831828319;
}
var $ret2832428325 = $Hanf_arg1031628329($z2832028321,anf_arg53309808,self6729809,_plus55,torepr65);
++R.GAS;
return $ret2832428325;
};
var $Hanf_arg1031628329 = function(anf_arg533328328,anf_arg53309808,self6729809,_plus55,torepr65) {
var $z2833228333 = D;
var $f2833828339 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg53309808,anf_arg533328328):R.ffi.throwNonFunApp(L[1809],_plus55,[anf_arg53309808,anf_arg533328328]);
};
try {
if(--R.GAS > 0) {
$z2833228333 = $f2833828339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2833828339,
"from":L[1809]});
}
} catch($e2833028331) {
if(R.isCont($e2833028331)) {
var $ss2833428335 = {"from":L[1809],
"go":function(anf_arg533428340) {
return $Hanf_arg1031528341(anf_arg533428340,self6729809,_plus55,torepr65);
}};
$e2833028331.stack[R.EXN_STACKHEIGHT++] = $ss2833428335;
}
if(R.isPyretException($e2833028331)) {
$e2833028331.pyretStack.push(L[1809]);
}
throw $e2833028331;
}
var $ret2833628337 = $Hanf_arg1031528341($z2833228333,self6729809,_plus55,torepr65);
++R.GAS;
return $ret2833628337;
};
var $Hanf_arg1031528341 = function(anf_arg533428340,self6729809,_plus55,torepr65) {
var anf_arg533528352 = G(self6729809,"ret",L[1809]);
var $z2834428345 = D;
var $f2835028351 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg533528352):R.ffi.throwNonFunApp(L[1809],torepr65,[anf_arg533528352]);
};
try {
if(--R.GAS > 0) {
$z2834428345 = $f2835028351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2835028351,
"from":L[1809]});
}
} catch($e2834228343) {
if(R.isCont($e2834228343)) {
var $ss2834628347 = {"from":L[1809],
"go":function(anf_arg533628353) {
return $Hanf_arg1031428354(anf_arg533628353,anf_arg533428340,_plus55);
}};
$e2834228343.stack[R.EXN_STACKHEIGHT++] = $ss2834628347;
}
if(R.isPyretException($e2834228343)) {
$e2834228343.pyretStack.push(L[1809]);
}
throw $e2834228343;
}
var $ret2834828349 = $Hanf_arg1031428354($z2834428345,anf_arg533428340,_plus55);
++R.GAS;
return $ret2834828349;
};
var $Hanf_arg1031428354 = function(anf_arg533628353,anf_arg533428340,_plus55) {
var $z2835728358 = D;
var $f2836328364 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg533628353):R.ffi.throwNonFunApp(L[1809],_plus55,[(", "),anf_arg533628353]);
};
try {
if(--R.GAS > 0) {
$z2835728358 = $f2836328364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2836328364,
"from":L[1809]});
}
} catch($e2835528356) {
if(R.isCont($e2835528356)) {
var $ss2835928360 = {"from":L[1809],
"go":function(anf_arg533728365) {
return $Hanf_arg1031328366(anf_arg533728365,anf_arg533428340,_plus55);
}};
$e2835528356.stack[R.EXN_STACKHEIGHT++] = $ss2835928360;
}
if(R.isPyretException($e2835528356)) {
$e2835528356.pyretStack.push(L[1809]);
}
throw $e2835528356;
}
var $ret2836128362 = $Hanf_arg1031328366($z2835728358,anf_arg533428340,_plus55);
++R.GAS;
return $ret2836128362;
};
var $Hanf_arg1031328366 = function(anf_arg533728365,anf_arg533428340,_plus55) {
var $z2836928370 = D;
var $f2837528376 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg533428340,anf_arg533728365):R.ffi.throwNonFunApp(L[1809],_plus55,[anf_arg533428340,anf_arg533728365]);
};
try {
if(--R.GAS > 0) {
$z2836928370 = $f2837528376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2837528376,
"from":L[1809]});
}
} catch($e2836728368) {
if(R.isCont($e2836728368)) {
var $ss2837128372 = {"from":L[1809],
"go":function(anf_arg533828377) {
return $Hanf_arg1031228378(anf_arg533828377,_plus55);
}};
$e2836728368.stack[R.EXN_STACKHEIGHT++] = $ss2837128372;
}
if(R.isPyretException($e2836728368)) {
$e2836728368.pyretStack.push(L[1809]);
}
throw $e2836728368;
}
var $ret2837328374 = $Hanf_arg1031228378($z2836928370,_plus55);
++R.GAS;
return $ret2837328374;
};
var $Hanf_arg1031228378 = function(anf_arg533828377,_plus55) {
var $z2838128382 = D;
var $f2838728388 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg533828377,(")")):R.ffi.throwNonFunApp(L[1809],_plus55,[anf_arg533828377,(")")]);
};
try {
if(--R.GAS > 0) {
$z2838128382 = $f2838728388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2838728388,
"from":L[1809]});
}
} catch($e2837928380) {
if(R.isCont($e2837928380)) {
var $ss2838328384 = {"from":L[1809],
"go":function(anf_arg533928389) {
return $Hanf_arg1031128390(anf_arg533928389,_plus55);
}};
$e2837928380.stack[R.EXN_STACKHEIGHT++] = $ss2838328384;
}
if(R.isPyretException($e2837928380)) {
$e2837928380.pyretStack.push(L[1809]);
}
throw $e2837928380;
}
var $ret2838528386 = $Hanf_arg1031128390($z2838128382,_plus55);
++R.GAS;
return $ret2838528386;
};
var $Hanf_arg1031128390 = function(anf_arg533928389,_plus55) {
var $z2839328394 = D;
var $f2839928400 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg533928389):R.ffi.throwNonFunApp(L[1809],_plus55,[("("),anf_arg533928389]);
};
try {
if(--R.GAS > 0) {
$z2839328394 = $f2839928400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2839928400,
"from":L[1809]});
}
} catch($e2839128392) {
if(R.isCont($e2839128392)) {
var $ss2839528396 = {"from":L[1809],
"go":function(anf_arg534028401) {
return $Hanf_arg1031028402(anf_arg534028401,_plus55);
}};
$e2839128392.stack[R.EXN_STACKHEIGHT++] = $ss2839528396;
}
if(R.isPyretException($e2839128392)) {
$e2839128392.pyretStack.push(L[1809]);
}
throw $e2839128392;
}
var $ret2839728398 = $Hanf_arg1031028402($z2839328394,_plus55);
++R.GAS;
return $ret2839728398;
};
var $Hanf_arg1031028402 = function(anf_arg534028401,_plus55) {
var $z2840528406 = D;
var $f2841128412 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("a-method"),anf_arg534028401):R.ffi.throwNonFunApp(L[1809],_plus55,[("a-method"),anf_arg534028401]);
};
try {
if(--R.GAS > 0) {
$z2840528406 = $f2841128412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2841128412,
"from":L[1809]});
}
} catch($e2840328404) {
if(R.isCont($e2840328404)) {
var $ss2840728408 = {"from":L[1809],
"go":function(ann_DASH_check_DASH_temp532828413) {
return $Hann_DASH_check_DASH_temp1030928414(ann_DASH_check_DASH_temp532828413);
}};
$e2840328404.stack[R.EXN_STACKHEIGHT++] = $ss2840728408;
}
if(R.isPyretException($e2840328404)) {
$e2840328404.pyretStack.push(L[1809]);
}
throw $e2840328404;
}
var $ret2840928410 = $Hann_DASH_check_DASH_temp1030928414($z2840528406);
++R.GAS;
return $ret2840928410;
};
var $Hann_DASH_check_DASH_temp1030928414 = function(ann_DASH_check_DASH_temp532828413) {
return ann_DASH_check_DASH_temp532828413;
};
var $Hcont_tail_arg103079827 = function(cont_tail_arg53259825,if_helper53159826) {
if(--R.GAS > 0) {
$z2841528416 = R.isFunction(if_helper53159826)?if_helper53159826.app(cont_tail_arg53259825):R.ffi.throwNonFunApp(L[1809],if_helper53159826,[cont_tail_arg53259825]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53159826)?if_helper53159826.app(cont_tail_arg53259825):R.ffi.throwNonFunApp(L[1809],if_helper53159826,[cont_tail_arg53259825]);
},
"from":L[1809]});
}
++R.GAS;
return $z2841528416;
};
var $Hcont_tail_arg103089842 = function(cont_tail_arg53209841,if_helper53159826) {
if(--R.GAS > 0) {
$z2841728418 = R.isFunction(if_helper53159826)?if_helper53159826.app(cont_tail_arg53209841):R.ffi.throwNonFunApp(L[1809],if_helper53159826,[cont_tail_arg53209841]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53159826)?if_helper53159826.app(cont_tail_arg53209841):R.ffi.throwNonFunApp(L[1809],if_helper53159826,[cont_tail_arg53209841]);
},
"from":L[1809]});
}
++R.GAS;
return $z2841728418;
};
var $Hanf_arg103069868 = function(anf_arg52939862,INDENT118169,PP170,anf_arg52879863,anf_fun52849864,anf_fun52859865,anf_fun52869866,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55) {
var $z2842128422 = D;
var $f2842728428 = function(_) {
return R.isFunction(anf_fun52869866)?anf_fun52869866.app(anf_arg52879863,anf_arg52939862):R.ffi.throwNonFunApp(L[3989],anf_fun52869866,[anf_arg52879863,anf_arg52939862]);
};
try {
if(--R.GAS > 0) {
$z2842128422 = $f2842728428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2842728428,
"from":L[3989]});
}
} catch($e2841928420) {
if(R.isCont($e2841928420)) {
var $ss2842328424 = {"from":L[3989],
"go":function(anf_array_val529428429) {
return $Hanf_array_val1030528430(anf_array_val529428429,INDENT118169,PP170,anf_fun52849864,anf_fun52859865,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55);
}};
$e2841928420.stack[R.EXN_STACKHEIGHT++] = $ss2842328424;
}
if(R.isPyretException($e2841928420)) {
$e2841928420.pyretStack.push(L[3989]);
}
throw $e2841928420;
}
var $ret2842528426 = $Hanf_array_val1030528430($z2842128422,INDENT118169,PP170,anf_fun52849864,anf_fun52859865,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55);
++R.GAS;
return $ret2842528426;
};
var $Hanf_array_val1030528430 = function(anf_array_val529428429,INDENT118169,PP170,anf_fun52849864,anf_fun52859865,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55) {
var $z2843328434 = D;
var $f2843928440 = function(_) {
return R.isFunction(anf_fun52859865)?anf_fun52859865.app([anf_array_val529428429]):R.ffi.throwNonFunApp(L[1887],anf_fun52859865,[[anf_array_val529428429]]);
};
try {
if(--R.GAS > 0) {
$z2843328434 = $f2843928440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2843928440,
"from":L[1887]});
}
} catch($e2843128432) {
if(R.isCont($e2843128432)) {
var $ss2843528436 = {"from":L[1887],
"go":function(anf_arg529528441) {
return $Hanf_arg1030428442(anf_arg529528441,INDENT118169,PP170,anf_fun52849864,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55);
}};
$e2843128432.stack[R.EXN_STACKHEIGHT++] = $ss2843528436;
}
if(R.isPyretException($e2843128432)) {
$e2843128432.pyretStack.push(L[1887]);
}
throw $e2843128432;
}
var $ret2843728438 = $Hanf_arg1030428442($z2843328434,INDENT118169,PP170,anf_fun52849864,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55);
++R.GAS;
return $ret2843728438;
};
var $Hanf_arg1030428442 = function(anf_arg529528441,INDENT118169,PP170,anf_fun52849864,list25154,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55) {
var anf_fun529628455 = G(list25154,"make",L[3993]);
var anf_bracket529728457 = G(self11489867,"ret",L[3992]);
var anf_fun529828453 = G(anf_bracket529728457,"tosource",L[3991]);
var $z2844528446 = D;
var $f2845128452 = function(_) {
return R.isFunction(anf_fun529828453)?anf_fun529828453.app():R.ffi.throwNonFunApp(L[3990],anf_fun529828453,[]);
};
try {
if(--R.GAS > 0) {
$z2844528446 = $f2845128452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2845128452,
"from":L[3990]});
}
} catch($e2844328444) {
if(R.isCont($e2844328444)) {
var $ss2844728448 = {"from":L[3990],
"go":function(anf_array_val529928454) {
return $Hanf_array_val1030328456(anf_array_val529928454,INDENT118169,PP170,anf_arg529528441,anf_fun52849864,anf_fun529628455,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55);
}};
$e2844328444.stack[R.EXN_STACKHEIGHT++] = $ss2844728448;
}
if(R.isPyretException($e2844328444)) {
$e2844328444.pyretStack.push(L[3990]);
}
throw $e2844328444;
}
var $ret2844928450 = $Hanf_array_val1030328456($z2844528446,INDENT118169,PP170,anf_arg529528441,anf_fun52849864,anf_fun529628455,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55);
++R.GAS;
return $ret2844928450;
};
var $Hanf_array_val1030328456 = function(anf_array_val529928454,INDENT118169,PP170,anf_arg529528441,anf_fun52849864,anf_fun529628455,self11489867,str_DASH_arrow121195,str_DASH_space168806,_plus55) {
var $z2846028461 = D;
var $f2846628467 = function(_) {
return R.isFunction(anf_fun529628455)?anf_fun529628455.app([str_DASH_arrow121195,anf_array_val529928454]):R.ffi.throwNonFunApp(L[3993],anf_fun529628455,[[str_DASH_arrow121195,anf_array_val529928454]]);
};
try {
if(--R.GAS > 0) {
$z2846028461 = $f2846628467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2846628467,
"from":L[3993]});
}
} catch($e2845828459) {
if(R.isCont($e2845828459)) {
var $ss2846228463 = {"from":L[3993],
"go":function(anf_arg530028468) {
return $Hanf_arg1030228469(anf_arg530028468,INDENT118169,PP170,anf_arg529528441,anf_fun52849864,self11489867,str_DASH_space168806,_plus55);
}};
$e2845828459.stack[R.EXN_STACKHEIGHT++] = $ss2846228463;
}
if(R.isPyretException($e2845828459)) {
$e2845828459.pyretStack.push(L[3993]);
}
throw $e2845828459;
}
var $ret2846428465 = $Hanf_arg1030228469($z2846028461,INDENT118169,PP170,anf_arg529528441,anf_fun52849864,self11489867,str_DASH_space168806,_plus55);
++R.GAS;
return $ret2846428465;
};
var $Hanf_arg1030228469 = function(anf_arg530028468,INDENT118169,PP170,anf_arg529528441,anf_fun52849864,self11489867,str_DASH_space168806,_plus55) {
var $z2847228473 = D;
var $f2847828479 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg529528441,anf_arg530028468):R.ffi.throwNonFunApp(L[3994],_plus55,[anf_arg529528441,anf_arg530028468]);
};
try {
if(--R.GAS > 0) {
$z2847228473 = $f2847828479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2847828479,
"from":L[3994]});
}
} catch($e2847028471) {
if(R.isCont($e2847028471)) {
var $ss2847428475 = {"from":L[3994],
"go":function(anf_arg530128480) {
return $Hanf_arg1030128481(anf_arg530128480,INDENT118169,PP170,anf_fun52849864,self11489867,str_DASH_space168806);
}};
$e2847028471.stack[R.EXN_STACKHEIGHT++] = $ss2847428475;
}
if(R.isPyretException($e2847028471)) {
$e2847028471.pyretStack.push(L[3994]);
}
throw $e2847028471;
}
var $ret2847628477 = $Hanf_arg1030128481($z2847228473,INDENT118169,PP170,anf_fun52849864,self11489867,str_DASH_space168806);
++R.GAS;
return $ret2847628477;
};
var $Hanf_arg1030128481 = function(anf_arg530128480,INDENT118169,PP170,anf_fun52849864,self11489867,str_DASH_space168806) {
var $z2848428485 = D;
var $f2849028491 = function(_) {
return R.isFunction(anf_fun52849864)?anf_fun52849864.app(str_DASH_space168806,anf_arg530128480):R.ffi.throwNonFunApp(L[3995],anf_fun52849864,[str_DASH_space168806,anf_arg530128480]);
};
try {
if(--R.GAS > 0) {
$z2848428485 = $f2849028491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2849028491,
"from":L[3995]});
}
} catch($e2848228483) {
if(R.isCont($e2848228483)) {
var $ss2848628487 = {"from":L[3995],
"go":function(ann114928492) {
return $Hann1030028493(ann114928492,INDENT118169,PP170,self11489867);
}};
$e2848228483.stack[R.EXN_STACKHEIGHT++] = $ss2848628487;
}
if(R.isPyretException($e2848228483)) {
$e2848228483.pyretStack.push(L[3995]);
}
throw $e2848228483;
}
var $ret2848828489 = $Hann1030028493($z2848428485,INDENT118169,PP170,self11489867);
++R.GAS;
return $ret2848828489;
};
var $Hann1030028493 = function(ann114928492,INDENT118169,PP170,self11489867) {
var if_DASH_66728522 = G(self11489867,"use-parens",L[4002]);
var if_helper530228508 = R.makeFunction(function(if_helper_arg530328527) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4001],1,arguments);
}
var ann_DASH_check_DASH_temp528328528 = if_helper_arg530328527;
return ann_DASH_check_DASH_temp528328528;
});
var anf_if530628526 = R.isBoolean(if_DASH_66728522);
if(R.isPyretTrue(anf_if530628526)) {
if(R.isPyretTrue(if_DASH_66728522)) {
var anf_fun530828504 = G(PP170,"surround",L[3999]);
var anf_arg530928505 = G(PP170,"lparen",L[3998]);
var anf_arg531028506 = G(PP170,"rparen",L[3997]);
var $z2849628497 = D;
var $f2850228503 = function(_) {
return R.isFunction(anf_fun530828504)?anf_fun530828504.app(INDENT118169,(0),anf_arg530928505,ann114928492,anf_arg531028506):R.ffi.throwNonFunApp(L[3996],anf_fun530828504,[INDENT118169,(0),anf_arg530928505,ann114928492,anf_arg531028506]);
};
try {
if(--R.GAS > 0) {
$z2849628497 = $f2850228503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2850228503,
"from":L[3996]});
}
} catch($e2849428495) {
if(R.isCont($e2849428495)) {
var $ss2849828499 = {"from":L[3996],
"go":function(cont_tail_arg531128507) {
return $Hcont_tail_arg1029828509(cont_tail_arg531128507,if_helper530228508);
}};
$e2849428495.stack[R.EXN_STACKHEIGHT++] = $ss2849828499;
}
if(R.isPyretException($e2849428495)) {
$e2849428495.pyretStack.push(L[3996]);
}
throw $e2849428495;
}
var $ret2850028501 = $Hcont_tail_arg1029828509($z2849628497,if_helper530228508);
++R.GAS;
return $ret2850028501;
} else {
var $z2851228513 = D;
var $f2851828519 = function(_) {
return R.isFunction(if_helper530228508)?if_helper530228508.app(ann114928492):R.ffi.throwNonFunApp(L[4000],if_helper530228508,[ann114928492]);
};
try {
if(--R.GAS > 0) {
$z2851228513 = $f2851828519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2851828519,
"from":L[4000]});
}
} catch($e2851028511) {
if(R.isCont($e2851028511)) {
var $ss2851428515 = {"from":L[4000],
"go":function(cont_tail_app530728520) {
return $Hcont_tail_app1029928521(cont_tail_app530728520);
}};
$e2851028511.stack[R.EXN_STACKHEIGHT++] = $ss2851428515;
}
if(R.isPyretException($e2851028511)) {
$e2851028511.pyretStack.push(L[4000]);
}
throw $e2851028511;
}
var $ret2851628517 = $Hcont_tail_app1029928521($z2851228513);
++R.GAS;
return $ret2851628517;
}
} else {
var cont_tail_arg530428525 = R.throwNonBooleanCondition(L[4001],("if"),if_DASH_66728522);
if(--R.GAS > 0) {
$z2852328524 = R.isFunction(if_helper530228508)?if_helper530228508.app(cont_tail_arg530428525):R.ffi.throwNonFunApp(L[4001],if_helper530228508,[cont_tail_arg530428525]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper530228508)?if_helper530228508.app(cont_tail_arg530428525):R.ffi.throwNonFunApp(L[4001],if_helper530228508,[cont_tail_arg530428525]);
},
"from":L[4001]});
}
++R.GAS;
return $z2852328524;
}
};
var $Hcont_tail_arg1029828509 = function(cont_tail_arg531128507,if_helper530228508) {
if(--R.GAS > 0) {
$z2852928530 = R.isFunction(if_helper530228508)?if_helper530228508.app(cont_tail_arg531128507):R.ffi.throwNonFunApp(L[3996],if_helper530228508,[cont_tail_arg531128507]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper530228508)?if_helper530228508.app(cont_tail_arg531128507):R.ffi.throwNonFunApp(L[3996],if_helper530228508,[cont_tail_arg531128507]);
},
"from":L[3996]});
}
++R.GAS;
return $z2852928530;
};
var $Hcont_tail_app1029928521 = function(cont_tail_app530728520) {
return cont_tail_app530728520;
};
var $Hann_DASH_check_DASH_temp102979882 = function(ann_DASH_check_DASH_temp52909881) {
return ann_DASH_check_DASH_temp52909881;
};
var $Hanf_arg102969899 = function(anf_arg52659897,self6649898,_plus55,torepr65) {
var anf_arg526628541 = G(self6649898,"args",L[1810]);
var $z2853328534 = D;
var $f2853928540 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg526628541):R.ffi.throwNonFunApp(L[1810],torepr65,[anf_arg526628541]);
};
try {
if(--R.GAS > 0) {
$z2853328534 = $f2853928540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2853928540,
"from":L[1810]});
}
} catch($e2853128532) {
if(R.isCont($e2853128532)) {
var $ss2853528536 = {"from":L[1810],
"go":function(anf_arg526728542) {
return $Hanf_arg1029528543(anf_arg526728542,anf_arg52659897,self6649898,_plus55,torepr65);
}};
$e2853128532.stack[R.EXN_STACKHEIGHT++] = $ss2853528536;
}
if(R.isPyretException($e2853128532)) {
$e2853128532.pyretStack.push(L[1810]);
}
throw $e2853128532;
}
var $ret2853728538 = $Hanf_arg1029528543($z2853328534,anf_arg52659897,self6649898,_plus55,torepr65);
++R.GAS;
return $ret2853728538;
};
var $Hanf_arg1029528543 = function(anf_arg526728542,anf_arg52659897,self6649898,_plus55,torepr65) {
var $z2854628547 = D;
var $f2855228553 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg526728542):R.ffi.throwNonFunApp(L[1810],_plus55,[(", "),anf_arg526728542]);
};
try {
if(--R.GAS > 0) {
$z2854628547 = $f2855228553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2855228553,
"from":L[1810]});
}
} catch($e2854428545) {
if(R.isCont($e2854428545)) {
var $ss2854828549 = {"from":L[1810],
"go":function(anf_arg526828554) {
return $Hanf_arg1029428555(anf_arg526828554,anf_arg52659897,self6649898,_plus55,torepr65);
}};
$e2854428545.stack[R.EXN_STACKHEIGHT++] = $ss2854828549;
}
if(R.isPyretException($e2854428545)) {
$e2854428545.pyretStack.push(L[1810]);
}
throw $e2854428545;
}
var $ret2855028551 = $Hanf_arg1029428555($z2854628547,anf_arg52659897,self6649898,_plus55,torepr65);
++R.GAS;
return $ret2855028551;
};
var $Hanf_arg1029428555 = function(anf_arg526828554,anf_arg52659897,self6649898,_plus55,torepr65) {
var $z2855828559 = D;
var $f2856428565 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg52659897,anf_arg526828554):R.ffi.throwNonFunApp(L[1810],_plus55,[anf_arg52659897,anf_arg526828554]);
};
try {
if(--R.GAS > 0) {
$z2855828559 = $f2856428565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2856428565,
"from":L[1810]});
}
} catch($e2855628557) {
if(R.isCont($e2855628557)) {
var $ss2856028561 = {"from":L[1810],
"go":function(anf_arg526928566) {
return $Hanf_arg1029328567(anf_arg526928566,self6649898,_plus55,torepr65);
}};
$e2855628557.stack[R.EXN_STACKHEIGHT++] = $ss2856028561;
}
if(R.isPyretException($e2855628557)) {
$e2855628557.pyretStack.push(L[1810]);
}
throw $e2855628557;
}
var $ret2856228563 = $Hanf_arg1029328567($z2855828559,self6649898,_plus55,torepr65);
++R.GAS;
return $ret2856228563;
};
var $Hanf_arg1029328567 = function(anf_arg526928566,self6649898,_plus55,torepr65) {
var anf_arg527028578 = G(self6649898,"ret",L[1810]);
var $z2857028571 = D;
var $f2857628577 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg527028578):R.ffi.throwNonFunApp(L[1810],torepr65,[anf_arg527028578]);
};
try {
if(--R.GAS > 0) {
$z2857028571 = $f2857628577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2857628577,
"from":L[1810]});
}
} catch($e2856828569) {
if(R.isCont($e2856828569)) {
var $ss2857228573 = {"from":L[1810],
"go":function(anf_arg527128579) {
return $Hanf_arg1029228580(anf_arg527128579,anf_arg526928566,self6649898,_plus55,torepr65);
}};
$e2856828569.stack[R.EXN_STACKHEIGHT++] = $ss2857228573;
}
if(R.isPyretException($e2856828569)) {
$e2856828569.pyretStack.push(L[1810]);
}
throw $e2856828569;
}
var $ret2857428575 = $Hanf_arg1029228580($z2857028571,anf_arg526928566,self6649898,_plus55,torepr65);
++R.GAS;
return $ret2857428575;
};
var $Hanf_arg1029228580 = function(anf_arg527128579,anf_arg526928566,self6649898,_plus55,torepr65) {
var $z2858328584 = D;
var $f2858928590 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg527128579):R.ffi.throwNonFunApp(L[1810],_plus55,[(", "),anf_arg527128579]);
};
try {
if(--R.GAS > 0) {
$z2858328584 = $f2858928590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2858928590,
"from":L[1810]});
}
} catch($e2858128582) {
if(R.isCont($e2858128582)) {
var $ss2858528586 = {"from":L[1810],
"go":function(anf_arg527228591) {
return $Hanf_arg1029128592(anf_arg527228591,anf_arg526928566,self6649898,_plus55,torepr65);
}};
$e2858128582.stack[R.EXN_STACKHEIGHT++] = $ss2858528586;
}
if(R.isPyretException($e2858128582)) {
$e2858128582.pyretStack.push(L[1810]);
}
throw $e2858128582;
}
var $ret2858728588 = $Hanf_arg1029128592($z2858328584,anf_arg526928566,self6649898,_plus55,torepr65);
++R.GAS;
return $ret2858728588;
};
var $Hanf_arg1029128592 = function(anf_arg527228591,anf_arg526928566,self6649898,_plus55,torepr65) {
var $z2859528596 = D;
var $f2860128602 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg526928566,anf_arg527228591):R.ffi.throwNonFunApp(L[1810],_plus55,[anf_arg526928566,anf_arg527228591]);
};
try {
if(--R.GAS > 0) {
$z2859528596 = $f2860128602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2860128602,
"from":L[1810]});
}
} catch($e2859328594) {
if(R.isCont($e2859328594)) {
var $ss2859728598 = {"from":L[1810],
"go":function(anf_arg527328603) {
return $Hanf_arg1029028604(anf_arg527328603,self6649898,_plus55,torepr65);
}};
$e2859328594.stack[R.EXN_STACKHEIGHT++] = $ss2859728598;
}
if(R.isPyretException($e2859328594)) {
$e2859328594.pyretStack.push(L[1810]);
}
throw $e2859328594;
}
var $ret2859928600 = $Hanf_arg1029028604($z2859528596,self6649898,_plus55,torepr65);
++R.GAS;
return $ret2859928600;
};
var $Hanf_arg1029028604 = function(anf_arg527328603,self6649898,_plus55,torepr65) {
var anf_arg527428615 = G(self6649898,"use-parens",L[1810]);
var $z2860728608 = D;
var $f2861328614 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg527428615):R.ffi.throwNonFunApp(L[1810],torepr65,[anf_arg527428615]);
};
try {
if(--R.GAS > 0) {
$z2860728608 = $f2861328614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2861328614,
"from":L[1810]});
}
} catch($e2860528606) {
if(R.isCont($e2860528606)) {
var $ss2860928610 = {"from":L[1810],
"go":function(anf_arg527528616) {
return $Hanf_arg1028928617(anf_arg527528616,anf_arg527328603,_plus55);
}};
$e2860528606.stack[R.EXN_STACKHEIGHT++] = $ss2860928610;
}
if(R.isPyretException($e2860528606)) {
$e2860528606.pyretStack.push(L[1810]);
}
throw $e2860528606;
}
var $ret2861128612 = $Hanf_arg1028928617($z2860728608,anf_arg527328603,_plus55);
++R.GAS;
return $ret2861128612;
};
var $Hanf_arg1028928617 = function(anf_arg527528616,anf_arg527328603,_plus55) {
var $z2862028621 = D;
var $f2862628627 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg527528616):R.ffi.throwNonFunApp(L[1810],_plus55,[(", "),anf_arg527528616]);
};
try {
if(--R.GAS > 0) {
$z2862028621 = $f2862628627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2862628627,
"from":L[1810]});
}
} catch($e2861828619) {
if(R.isCont($e2861828619)) {
var $ss2862228623 = {"from":L[1810],
"go":function(anf_arg527628628) {
return $Hanf_arg1028828629(anf_arg527628628,anf_arg527328603,_plus55);
}};
$e2861828619.stack[R.EXN_STACKHEIGHT++] = $ss2862228623;
}
if(R.isPyretException($e2861828619)) {
$e2861828619.pyretStack.push(L[1810]);
}
throw $e2861828619;
}
var $ret2862428625 = $Hanf_arg1028828629($z2862028621,anf_arg527328603,_plus55);
++R.GAS;
return $ret2862428625;
};
var $Hanf_arg1028828629 = function(anf_arg527628628,anf_arg527328603,_plus55) {
var $z2863228633 = D;
var $f2863828639 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg527328603,anf_arg527628628):R.ffi.throwNonFunApp(L[1810],_plus55,[anf_arg527328603,anf_arg527628628]);
};
try {
if(--R.GAS > 0) {
$z2863228633 = $f2863828639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2863828639,
"from":L[1810]});
}
} catch($e2863028631) {
if(R.isCont($e2863028631)) {
var $ss2863428635 = {"from":L[1810],
"go":function(anf_arg527728640) {
return $Hanf_arg1028728641(anf_arg527728640,_plus55);
}};
$e2863028631.stack[R.EXN_STACKHEIGHT++] = $ss2863428635;
}
if(R.isPyretException($e2863028631)) {
$e2863028631.pyretStack.push(L[1810]);
}
throw $e2863028631;
}
var $ret2863628637 = $Hanf_arg1028728641($z2863228633,_plus55);
++R.GAS;
return $ret2863628637;
};
var $Hanf_arg1028728641 = function(anf_arg527728640,_plus55) {
var $z2864428645 = D;
var $f2865028651 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg527728640,(")")):R.ffi.throwNonFunApp(L[1810],_plus55,[anf_arg527728640,(")")]);
};
try {
if(--R.GAS > 0) {
$z2864428645 = $f2865028651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2865028651,
"from":L[1810]});
}
} catch($e2864228643) {
if(R.isCont($e2864228643)) {
var $ss2864628647 = {"from":L[1810],
"go":function(anf_arg527828652) {
return $Hanf_arg1028628653(anf_arg527828652,_plus55);
}};
$e2864228643.stack[R.EXN_STACKHEIGHT++] = $ss2864628647;
}
if(R.isPyretException($e2864228643)) {
$e2864228643.pyretStack.push(L[1810]);
}
throw $e2864228643;
}
var $ret2864828649 = $Hanf_arg1028628653($z2864428645,_plus55);
++R.GAS;
return $ret2864828649;
};
var $Hanf_arg1028628653 = function(anf_arg527828652,_plus55) {
var $z2865628657 = D;
var $f2866228663 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg527828652):R.ffi.throwNonFunApp(L[1810],_plus55,[("("),anf_arg527828652]);
};
try {
if(--R.GAS > 0) {
$z2865628657 = $f2866228663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2866228663,
"from":L[1810]});
}
} catch($e2865428655) {
if(R.isCont($e2865428655)) {
var $ss2865828659 = {"from":L[1810],
"go":function(anf_arg527928664) {
return $Hanf_arg1028528665(anf_arg527928664,_plus55);
}};
$e2865428655.stack[R.EXN_STACKHEIGHT++] = $ss2865828659;
}
if(R.isPyretException($e2865428655)) {
$e2865428655.pyretStack.push(L[1810]);
}
throw $e2865428655;
}
var $ret2866028661 = $Hanf_arg1028528665($z2865628657,_plus55);
++R.GAS;
return $ret2866028661;
};
var $Hanf_arg1028528665 = function(anf_arg527928664,_plus55) {
var $z2866828669 = D;
var $f2867428675 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("a-arrow"),anf_arg527928664):R.ffi.throwNonFunApp(L[1810],_plus55,[("a-arrow"),anf_arg527928664]);
};
try {
if(--R.GAS > 0) {
$z2866828669 = $f2867428675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2867428675,
"from":L[1810]});
}
} catch($e2866628667) {
if(R.isCont($e2866628667)) {
var $ss2867028671 = {"from":L[1810],
"go":function(ann_DASH_check_DASH_temp526328676) {
return $Hann_DASH_check_DASH_temp1028428677(ann_DASH_check_DASH_temp526328676);
}};
$e2866628667.stack[R.EXN_STACKHEIGHT++] = $ss2867028671;
}
if(R.isPyretException($e2866628667)) {
$e2866628667.pyretStack.push(L[1810]);
}
throw $e2866628667;
}
var $ret2867228673 = $Hann_DASH_check_DASH_temp1028428677($z2866828669);
++R.GAS;
return $ret2867228673;
};
var $Hann_DASH_check_DASH_temp1028428677 = function(ann_DASH_check_DASH_temp526328676) {
return ann_DASH_check_DASH_temp526328676;
};
var $Hcont_tail_arg102829917 = function(cont_tail_arg52609915,if_helper52499916) {
if(--R.GAS > 0) {
$z2867828679 = R.isFunction(if_helper52499916)?if_helper52499916.app(cont_tail_arg52609915):R.ffi.throwNonFunApp(L[1810],if_helper52499916,[cont_tail_arg52609915]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper52499916)?if_helper52499916.app(cont_tail_arg52609915):R.ffi.throwNonFunApp(L[1810],if_helper52499916,[cont_tail_arg52609915]);
},
"from":L[1810]});
}
++R.GAS;
return $z2867828679;
};
var $Hcont_tail_arg102839932 = function(cont_tail_arg52549931,if_helper52499916) {
if(--R.GAS > 0) {
$z2868028681 = R.isFunction(if_helper52499916)?if_helper52499916.app(cont_tail_arg52549931):R.ffi.throwNonFunApp(L[1810],if_helper52499916,[cont_tail_arg52549931]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper52499916)?if_helper52499916.app(cont_tail_arg52549931):R.ffi.throwNonFunApp(L[1810],if_helper52499916,[cont_tail_arg52549931]);
},
"from":L[1810]});
}
++R.GAS;
return $z2868028681;
};
var $Hann_DASH_check_DASH_temp102819952 = function(ann_DASH_check_DASH_temp52449951) {
return ann_DASH_check_DASH_temp52449951;
};
var $Hanf_arg102809970 = function(anf_arg52349968,self6589969,_plus55,torepr65) {
var anf_arg523528692 = G(self6589969,"id",L[1811]);
var $z2868428685 = D;
var $f2869028691 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg523528692):R.ffi.throwNonFunApp(L[1811],torepr65,[anf_arg523528692]);
};
try {
if(--R.GAS > 0) {
$z2868428685 = $f2869028691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2869028691,
"from":L[1811]});
}
} catch($e2868228683) {
if(R.isCont($e2868228683)) {
var $ss2868628687 = {"from":L[1811],
"go":function(anf_arg523628693) {
return $Hanf_arg1027928694(anf_arg523628693,anf_arg52349968,_plus55);
}};
$e2868228683.stack[R.EXN_STACKHEIGHT++] = $ss2868628687;
}
if(R.isPyretException($e2868228683)) {
$e2868228683.pyretStack.push(L[1811]);
}
throw $e2868228683;
}
var $ret2868828689 = $Hanf_arg1027928694($z2868428685,anf_arg52349968,_plus55);
++R.GAS;
return $ret2868828689;
};
var $Hanf_arg1027928694 = function(anf_arg523628693,anf_arg52349968,_plus55) {
var $z2869728698 = D;
var $f2870328704 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg523628693):R.ffi.throwNonFunApp(L[1811],_plus55,[(", "),anf_arg523628693]);
};
try {
if(--R.GAS > 0) {
$z2869728698 = $f2870328704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2870328704,
"from":L[1811]});
}
} catch($e2869528696) {
if(R.isCont($e2869528696)) {
var $ss2869928700 = {"from":L[1811],
"go":function(anf_arg523728705) {
return $Hanf_arg1027828706(anf_arg523728705,anf_arg52349968,_plus55);
}};
$e2869528696.stack[R.EXN_STACKHEIGHT++] = $ss2869928700;
}
if(R.isPyretException($e2869528696)) {
$e2869528696.pyretStack.push(L[1811]);
}
throw $e2869528696;
}
var $ret2870128702 = $Hanf_arg1027828706($z2869728698,anf_arg52349968,_plus55);
++R.GAS;
return $ret2870128702;
};
var $Hanf_arg1027828706 = function(anf_arg523728705,anf_arg52349968,_plus55) {
var $z2870928710 = D;
var $f2871528716 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg52349968,anf_arg523728705):R.ffi.throwNonFunApp(L[1811],_plus55,[anf_arg52349968,anf_arg523728705]);
};
try {
if(--R.GAS > 0) {
$z2870928710 = $f2871528716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2871528716,
"from":L[1811]});
}
} catch($e2870728708) {
if(R.isCont($e2870728708)) {
var $ss2871128712 = {"from":L[1811],
"go":function(anf_arg523828717) {
return $Hanf_arg1027728718(anf_arg523828717,_plus55);
}};
$e2870728708.stack[R.EXN_STACKHEIGHT++] = $ss2871128712;
}
if(R.isPyretException($e2870728708)) {
$e2870728708.pyretStack.push(L[1811]);
}
throw $e2870728708;
}
var $ret2871328714 = $Hanf_arg1027728718($z2870928710,_plus55);
++R.GAS;
return $ret2871328714;
};
var $Hanf_arg1027728718 = function(anf_arg523828717,_plus55) {
var $z2872128722 = D;
var $f2872728728 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg523828717,(")")):R.ffi.throwNonFunApp(L[1811],_plus55,[anf_arg523828717,(")")]);
};
try {
if(--R.GAS > 0) {
$z2872128722 = $f2872728728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2872728728,
"from":L[1811]});
}
} catch($e2871928720) {
if(R.isCont($e2871928720)) {
var $ss2872328724 = {"from":L[1811],
"go":function(anf_arg523928729) {
return $Hanf_arg1027628730(anf_arg523928729,_plus55);
}};
$e2871928720.stack[R.EXN_STACKHEIGHT++] = $ss2872328724;
}
if(R.isPyretException($e2871928720)) {
$e2871928720.pyretStack.push(L[1811]);
}
throw $e2871928720;
}
var $ret2872528726 = $Hanf_arg1027628730($z2872128722,_plus55);
++R.GAS;
return $ret2872528726;
};
var $Hanf_arg1027628730 = function(anf_arg523928729,_plus55) {
var $z2873328734 = D;
var $f2873928740 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg523928729):R.ffi.throwNonFunApp(L[1811],_plus55,[("("),anf_arg523928729]);
};
try {
if(--R.GAS > 0) {
$z2873328734 = $f2873928740();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2873928740,
"from":L[1811]});
}
} catch($e2873128732) {
if(R.isCont($e2873128732)) {
var $ss2873528736 = {"from":L[1811],
"go":function(anf_arg524028741) {
return $Hanf_arg1027528742(anf_arg524028741,_plus55);
}};
$e2873128732.stack[R.EXN_STACKHEIGHT++] = $ss2873528736;
}
if(R.isPyretException($e2873128732)) {
$e2873128732.pyretStack.push(L[1811]);
}
throw $e2873128732;
}
var $ret2873728738 = $Hanf_arg1027528742($z2873328734,_plus55);
++R.GAS;
return $ret2873728738;
};
var $Hanf_arg1027528742 = function(anf_arg524028741,_plus55) {
var $z2874528746 = D;
var $f2875128752 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("a-name"),anf_arg524028741):R.ffi.throwNonFunApp(L[1811],_plus55,[("a-name"),anf_arg524028741]);
};
try {
if(--R.GAS > 0) {
$z2874528746 = $f2875128752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2875128752,
"from":L[1811]});
}
} catch($e2874328744) {
if(R.isCont($e2874328744)) {
var $ss2874728748 = {"from":L[1811],
"go":function(ann_DASH_check_DASH_temp523228753) {
return $Hann_DASH_check_DASH_temp1027428754(ann_DASH_check_DASH_temp523228753);
}};
$e2874328744.stack[R.EXN_STACKHEIGHT++] = $ss2874728748;
}
if(R.isPyretException($e2874328744)) {
$e2874328744.pyretStack.push(L[1811]);
}
throw $e2874328744;
}
var $ret2874928750 = $Hann_DASH_check_DASH_temp1027428754($z2874528746);
++R.GAS;
return $ret2874928750;
};
var $Hann_DASH_check_DASH_temp1027428754 = function(ann_DASH_check_DASH_temp523228753) {
return ann_DASH_check_DASH_temp523228753;
};
var $Hcont_tail_arg102729986 = function(cont_tail_arg52299984,if_helper52209985) {
if(--R.GAS > 0) {
$z2875528756 = R.isFunction(if_helper52209985)?if_helper52209985.app(cont_tail_arg52299984):R.ffi.throwNonFunApp(L[1811],if_helper52209985,[cont_tail_arg52299984]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper52209985)?if_helper52209985.app(cont_tail_arg52299984):R.ffi.throwNonFunApp(L[1811],if_helper52209985,[cont_tail_arg52299984]);
},
"from":L[1811]});
}
++R.GAS;
return $z2875528756;
};
var $Hcont_tail_arg1027310001 = function(cont_tail_arg522510000,if_helper52209985) {
if(--R.GAS > 0) {
$z2875728758 = R.isFunction(if_helper52209985)?if_helper52209985.app(cont_tail_arg522510000):R.ffi.throwNonFunApp(L[1811],if_helper52209985,[cont_tail_arg522510000]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper52209985)?if_helper52209985.app(cont_tail_arg522510000):R.ffi.throwNonFunApp(L[1811],if_helper52209985,[cont_tail_arg522510000]);
},
"from":L[1811]});
}
++R.GAS;
return $z2875728758;
};
var $Hcont_tail_arg1027010028 = function(cont_tail_arg521010026,if_helper520310027) {
if(--R.GAS > 0) {
$z2875928760 = R.isFunction(if_helper520310027)?if_helper520310027.app(cont_tail_arg521010026):R.ffi.throwNonFunApp(L[1812],if_helper520310027,[cont_tail_arg521010026]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper520310027)?if_helper520310027.app(cont_tail_arg521010026):R.ffi.throwNonFunApp(L[1812],if_helper520310027,[cont_tail_arg521010026]);
},
"from":L[1812]});
}
++R.GAS;
return $z2875928760;
};
var $Hcont_tail_arg1027110042 = function(cont_tail_arg520810041,if_helper520310027) {
if(--R.GAS > 0) {
$z2876128762 = R.isFunction(if_helper520310027)?if_helper520310027.app(cont_tail_arg520810041):R.ffi.throwNonFunApp(L[1812],if_helper520310027,[cont_tail_arg520810041]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper520310027)?if_helper520310027.app(cont_tail_arg520810041):R.ffi.throwNonFunApp(L[1812],if_helper520310027,[cont_tail_arg520810041]);
},
"from":L[1812]});
}
++R.GAS;
return $z2876128762;
};
var $Hcont_tail_arg1026810070 = function(cont_tail_arg519310068,if_helper518610069) {
if(--R.GAS > 0) {
$z2876328764 = R.isFunction(if_helper518610069)?if_helper518610069.app(cont_tail_arg519310068):R.ffi.throwNonFunApp(L[1813],if_helper518610069,[cont_tail_arg519310068]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper518610069)?if_helper518610069.app(cont_tail_arg519310068):R.ffi.throwNonFunApp(L[1813],if_helper518610069,[cont_tail_arg519310068]);
},
"from":L[1813]});
}
++R.GAS;
return $z2876328764;
};
var $Hcont_tail_arg1026910084 = function(cont_tail_arg519110083,if_helper518610069) {
if(--R.GAS > 0) {
$z2876528766 = R.isFunction(if_helper518610069)?if_helper518610069.app(cont_tail_arg519110083):R.ffi.throwNonFunApp(L[1813],if_helper518610069,[cont_tail_arg519110083]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper518610069)?if_helper518610069.app(cont_tail_arg519110083):R.ffi.throwNonFunApp(L[1813],if_helper518610069,[cont_tail_arg519110083]);
},
"from":L[1813]});
}
++R.GAS;
return $z2876528766;
};
var $Hann_DASH_check_DASH_temp1026710107 = function(ann_DASH_check_DASH_temp517710106) {
return ann_DASH_check_DASH_temp517710106;
};
var $Hanf_arg1026610120 = function(anf_arg518110119,_plus55,raise62) {
var $z2876928770 = D;
var $f2877528776 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg518110119):R.ffi.throwNonFunApp(L[4003],_plus55,[("No visitor field for "),anf_arg518110119]);
};
try {
if(--R.GAS > 0) {
$z2876928770 = $f2877528776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2877528776,
"from":L[4003]});
}
} catch($e2876728768) {
if(R.isCont($e2876728768)) {
var $ss2877128772 = {"from":L[4003],
"go":function(anf_arg518228777) {
return $Hanf_arg1026528778(anf_arg518228777,raise62);
}};
$e2876728768.stack[R.EXN_STACKHEIGHT++] = $ss2877128772;
}
if(R.isPyretException($e2876728768)) {
$e2876728768.pyretStack.push(L[4003]);
}
throw $e2876728768;
}
var $ret2877328774 = $Hanf_arg1026528778($z2876928770,raise62);
++R.GAS;
return $ret2877328774;
};
var $Hanf_arg1026528778 = function(anf_arg518228777,raise62) {
var $z2878128782 = D;
var $f2878728788 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg518228777):R.ffi.throwNonFunApp(L[1906],raise62,[anf_arg518228777]);
};
try {
if(--R.GAS > 0) {
$z2878128782 = $f2878728788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2878728788,
"from":L[1906]});
}
} catch($e2877928780) {
if(R.isCont($e2877928780)) {
var $ss2878328784 = {"from":L[1906],
"go":function(ann_DASH_check_DASH_temp517928789) {
return $Hann_DASH_check_DASH_temp1026428790(ann_DASH_check_DASH_temp517928789);
}};
$e2877928780.stack[R.EXN_STACKHEIGHT++] = $ss2878328784;
}
if(R.isPyretException($e2877928780)) {
$e2877928780.pyretStack.push(L[1906]);
}
throw $e2877928780;
}
var $ret2878528786 = $Hann_DASH_check_DASH_temp1026428790($z2878128782);
++R.GAS;
return $ret2878528786;
};
var $Hann_DASH_check_DASH_temp1026428790 = function(ann_DASH_check_DASH_temp517928789) {
return ann_DASH_check_DASH_temp517928789;
};
var $Hanf_arg1026310152 = function(anf_arg514810147,INDENT118169,PP170,anf_fun514410148,anf_fun514510149,anf_fun514610150,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55) {
var $z2879328794 = D;
var $f2879928800 = function(_) {
return R.isFunction(anf_fun514610150)?anf_fun514610150.app(anf_arg514810147):R.ffi.throwNonFunApp(L[4004],anf_fun514610150,[anf_arg514810147]);
};
try {
if(--R.GAS > 0) {
$z2879328794 = $f2879928800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2879928800,
"from":L[4004]});
}
} catch($e2879128792) {
if(R.isCont($e2879128792)) {
var $ss2879528796 = {"from":L[4004],
"go":function(anf_arg514928801) {
return $Hanf_arg1026228802(anf_arg514928801,INDENT118169,PP170,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
}};
$e2879128792.stack[R.EXN_STACKHEIGHT++] = $ss2879528796;
}
if(R.isPyretException($e2879128792)) {
$e2879128792.pyretStack.push(L[4004]);
}
throw $e2879128792;
}
var $ret2879728798 = $Hanf_arg1026228802($z2879328794,INDENT118169,PP170,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
++R.GAS;
return $ret2879728798;
};
var $Hanf_arg1026228802 = function(anf_arg514928801,INDENT118169,PP170,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55) {
var anf_fun515028820 = G(PP170,"surround-separate",L[4014]);
var anf_arg515128816 = G(PP170,"mt-doc",L[4013]);
var anf_arg515228817 = G(PP170,"lparen",L[4012]);
var anf_arg515328818 = G(PP170,"commabreak",L[4011]);
var anf_arg515428819 = G(PP170,"rparen",L[4010]);
var anf_bracket515528836 = G(self113110151,"args",L[4009]);
var anf_fun515628813 = G(anf_bracket515528836,"map",L[4008]);
var anf_arg515928814 = R.makeFunction(function(a113228822) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4006],1,arguments);
}
var anf_fun515828833 = G(a113228822,"tosource",L[4007]);
var $z2882528826 = D;
var $f2883128832 = function(_) {
return R.isFunction(anf_fun515828833)?anf_fun515828833.app():R.ffi.throwNonFunApp(L[4006],anf_fun515828833,[]);
};
try {
if(--R.GAS > 0) {
$z2882528826 = $f2883128832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2883128832,
"from":L[4006]});
}
} catch($e2882328824) {
if(R.isCont($e2882328824)) {
var $ss2882728828 = {"from":L[4006],
"go":function(ann_DASH_check_DASH_temp515728834) {
return $Hann_DASH_check_DASH_temp1025128835(ann_DASH_check_DASH_temp515728834);
}};
$e2882328824.stack[R.EXN_STACKHEIGHT++] = $ss2882728828;
}
if(R.isPyretException($e2882328824)) {
$e2882328824.pyretStack.push(L[4006]);
}
throw $e2882328824;
}
var $ret2882928830 = $Hann_DASH_check_DASH_temp1025128835($z2882528826);
++R.GAS;
return $ret2882928830;
});
var $z2880528806 = D;
var $f2881128812 = function(_) {
return R.isFunction(anf_fun515628813)?anf_fun515628813.app(anf_arg515928814):R.ffi.throwNonFunApp(L[4005],anf_fun515628813,[anf_arg515928814]);
};
try {
if(--R.GAS > 0) {
$z2880528806 = $f2881128812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2881128812,
"from":L[4005]});
}
} catch($e2880328804) {
if(R.isCont($e2880328804)) {
var $ss2880728808 = {"from":L[4005],
"go":function(anf_arg516028815) {
return $Hanf_arg1026128821(anf_arg516028815,INDENT118169,anf_arg514928801,anf_arg515128816,anf_arg515228817,anf_arg515328818,anf_arg515428819,anf_fun514410148,anf_fun514510149,anf_fun515028820,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
}};
$e2880328804.stack[R.EXN_STACKHEIGHT++] = $ss2880728808;
}
if(R.isPyretException($e2880328804)) {
$e2880328804.pyretStack.push(L[4005]);
}
throw $e2880328804;
}
var $ret2880928810 = $Hanf_arg1026128821($z2880528806,INDENT118169,anf_arg514928801,anf_arg515128816,anf_arg515228817,anf_arg515328818,anf_arg515428819,anf_fun514410148,anf_fun514510149,anf_fun515028820,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
++R.GAS;
return $ret2880928810;
};
var $Hanf_arg1026128821 = function(anf_arg516028815,INDENT118169,anf_arg514928801,anf_arg515128816,anf_arg515228817,anf_arg515328818,anf_arg515428819,anf_fun514410148,anf_fun514510149,anf_fun515028820,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55) {
var $z2883928840 = D;
var $f2884528846 = function(_) {
return R.isFunction(anf_fun515028820)?anf_fun515028820.app(INDENT118169,(0),anf_arg515128816,anf_arg515228817,anf_arg515328818,anf_arg515428819,anf_arg516028815):R.ffi.throwNonFunApp(L[4015],anf_fun515028820,[INDENT118169,(0),anf_arg515128816,anf_arg515228817,anf_arg515328818,anf_arg515428819,anf_arg516028815]);
};
try {
if(--R.GAS > 0) {
$z2883928840 = $f2884528846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2884528846,
"from":L[4015]});
}
} catch($e2883728838) {
if(R.isCont($e2883728838)) {
var $ss2884128842 = {"from":L[4015],
"go":function(anf_arg516128847) {
return $Hanf_arg1026028848(anf_arg516128847,INDENT118169,anf_arg514928801,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
}};
$e2883728838.stack[R.EXN_STACKHEIGHT++] = $ss2884128842;
}
if(R.isPyretException($e2883728838)) {
$e2883728838.pyretStack.push(L[4015]);
}
throw $e2883728838;
}
var $ret2884328844 = $Hanf_arg1026028848($z2883928840,INDENT118169,anf_arg514928801,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
++R.GAS;
return $ret2884328844;
};
var $Hanf_arg1026028848 = function(anf_arg516128847,INDENT118169,anf_arg514928801,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55) {
var $z2885128852 = D;
var $f2885728858 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg514928801,anf_arg516128847):R.ffi.throwNonFunApp(L[4016],_plus55,[anf_arg514928801,anf_arg516128847]);
};
try {
if(--R.GAS > 0) {
$z2885128852 = $f2885728858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2885728858,
"from":L[4016]});
}
} catch($e2884928850) {
if(R.isCont($e2884928850)) {
var $ss2885328854 = {"from":L[4016],
"go":function(anf_arg516228859) {
return $Hanf_arg1025928860(anf_arg516228859,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
}};
$e2884928850.stack[R.EXN_STACKHEIGHT++] = $ss2885328854;
}
if(R.isPyretException($e2884928850)) {
$e2884928850.pyretStack.push(L[4016]);
}
throw $e2884928850;
}
var $ret2885528856 = $Hanf_arg1025928860($z2885128852,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
++R.GAS;
return $ret2885528856;
};
var $Hanf_arg1025928860 = function(anf_arg516228859,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55) {
var $z2886328864 = D;
var $f2886928870 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg516228859,break_DASH_one119168):R.ffi.throwNonFunApp(L[4016],_plus55,[anf_arg516228859,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z2886328864 = $f2886928870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2886928870,
"from":L[4016]});
}
} catch($e2886128862) {
if(R.isCont($e2886128862)) {
var $ss2886528866 = {"from":L[4016],
"go":function(anf_arg516328871) {
return $Hanf_arg1025828872(anf_arg516328871,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
}};
$e2886128862.stack[R.EXN_STACKHEIGHT++] = $ss2886528866;
}
if(R.isPyretException($e2886128862)) {
$e2886128862.pyretStack.push(L[4016]);
}
throw $e2886128862;
}
var $ret2886728868 = $Hanf_arg1025828872($z2886328864,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55);
++R.GAS;
return $ret2886728868;
};
var $Hanf_arg1025828872 = function(anf_arg516328871,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,str_DASH_thickarrow172858,_plus55) {
var $z2887528876 = D;
var $f2888128882 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg516328871,str_DASH_thickarrow172858):R.ffi.throwNonFunApp(L[4016],_plus55,[anf_arg516328871,str_DASH_thickarrow172858]);
};
try {
if(--R.GAS > 0) {
$z2887528876 = $f2888128882();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2888128882,
"from":L[4016]});
}
} catch($e2887328874) {
if(R.isCont($e2887328874)) {
var $ss2887728878 = {"from":L[4016],
"go":function(anf_arg516428883) {
return $Hanf_arg1025728884(anf_arg516428883,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,_plus55);
}};
$e2887328874.stack[R.EXN_STACKHEIGHT++] = $ss2887728878;
}
if(R.isPyretException($e2887328874)) {
$e2887328874.pyretStack.push(L[4016]);
}
throw $e2887328874;
}
var $ret2887928880 = $Hanf_arg1025728884($z2887528876,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,_plus55);
++R.GAS;
return $ret2887928880;
};
var $Hanf_arg1025728884 = function(anf_arg516428883,INDENT118169,anf_fun514410148,anf_fun514510149,break_DASH_one119168,self113110151,_plus55) {
var $z2888728888 = D;
var $f2889328894 = function(_) {
return R.isFunction(anf_fun514510149)?anf_fun514510149.app(anf_arg516428883):R.ffi.throwNonFunApp(L[4017],anf_fun514510149,[anf_arg516428883]);
};
try {
if(--R.GAS > 0) {
$z2888728888 = $f2889328894();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2889328894,
"from":L[4017]});
}
} catch($e2888528886) {
if(R.isCont($e2888528886)) {
var $ss2888928890 = {"from":L[4017],
"go":function(anf_arg516528895) {
return $Hanf_arg1025628896(anf_arg516528895,INDENT118169,anf_fun514410148,break_DASH_one119168,self113110151,_plus55);
}};
$e2888528886.stack[R.EXN_STACKHEIGHT++] = $ss2888928890;
}
if(R.isPyretException($e2888528886)) {
$e2888528886.pyretStack.push(L[4017]);
}
throw $e2888528886;
}
var $ret2889128892 = $Hanf_arg1025628896($z2888728888,INDENT118169,anf_fun514410148,break_DASH_one119168,self113110151,_plus55);
++R.GAS;
return $ret2889128892;
};
var $Hanf_arg1025628896 = function(anf_arg516528895,INDENT118169,anf_fun514410148,break_DASH_one119168,self113110151,_plus55) {
var $z2889928900 = D;
var $f2890528906 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg516528895,break_DASH_one119168):R.ffi.throwNonFunApp(L[4018],_plus55,[anf_arg516528895,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z2889928900 = $f2890528906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2890528906,
"from":L[4018]});
}
} catch($e2889728898) {
if(R.isCont($e2889728898)) {
var $ss2890128902 = {"from":L[4018],
"go":function(anf_arg516628907) {
return $Hanf_arg1025528908(anf_arg516628907,INDENT118169,anf_fun514410148,self113110151,_plus55);
}};
$e2889728898.stack[R.EXN_STACKHEIGHT++] = $ss2890128902;
}
if(R.isPyretException($e2889728898)) {
$e2889728898.pyretStack.push(L[4018]);
}
throw $e2889728898;
}
var $ret2890328904 = $Hanf_arg1025528908($z2889928900,INDENT118169,anf_fun514410148,self113110151,_plus55);
++R.GAS;
return $ret2890328904;
};
var $Hanf_arg1025528908 = function(anf_arg516628907,INDENT118169,anf_fun514410148,self113110151,_plus55) {
var anf_bracket516728922 = G(self113110151,"body",L[4021]);
var anf_fun516828919 = G(anf_bracket516728922,"tosource",L[4020]);
var $z2891128912 = D;
var $f2891728918 = function(_) {
return R.isFunction(anf_fun516828919)?anf_fun516828919.app():R.ffi.throwNonFunApp(L[4019],anf_fun516828919,[]);
};
try {
if(--R.GAS > 0) {
$z2891128912 = $f2891728918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2891728918,
"from":L[4019]});
}
} catch($e2890928910) {
if(R.isCont($e2890928910)) {
var $ss2891328914 = {"from":L[4019],
"go":function(anf_arg516928920) {
return $Hanf_arg1025428921(anf_arg516928920,INDENT118169,anf_arg516628907,anf_fun514410148,_plus55);
}};
$e2890928910.stack[R.EXN_STACKHEIGHT++] = $ss2891328914;
}
if(R.isPyretException($e2890928910)) {
$e2890928910.pyretStack.push(L[4019]);
}
throw $e2890928910;
}
var $ret2891528916 = $Hanf_arg1025428921($z2891128912,INDENT118169,anf_arg516628907,anf_fun514410148,_plus55);
++R.GAS;
return $ret2891528916;
};
var $Hanf_arg1025428921 = function(anf_arg516928920,INDENT118169,anf_arg516628907,anf_fun514410148,_plus55) {
var $z2892528926 = D;
var $f2893128932 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg516628907,anf_arg516928920):R.ffi.throwNonFunApp(L[4018],_plus55,[anf_arg516628907,anf_arg516928920]);
};
try {
if(--R.GAS > 0) {
$z2892528926 = $f2893128932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2893128932,
"from":L[4018]});
}
} catch($e2892328924) {
if(R.isCont($e2892328924)) {
var $ss2892728928 = {"from":L[4018],
"go":function(anf_arg517028933) {
return $Hanf_arg1025328934(anf_arg517028933,INDENT118169,anf_fun514410148);
}};
$e2892328924.stack[R.EXN_STACKHEIGHT++] = $ss2892728928;
}
if(R.isPyretException($e2892328924)) {
$e2892328924.pyretStack.push(L[4018]);
}
throw $e2892328924;
}
var $ret2892928930 = $Hanf_arg1025328934($z2892528926,INDENT118169,anf_fun514410148);
++R.GAS;
return $ret2892928930;
};
var $Hanf_arg1025328934 = function(anf_arg517028933,INDENT118169,anf_fun514410148) {
var $z2893728938 = D;
var $f2894328944 = function(_) {
return R.isFunction(anf_fun514410148)?anf_fun514410148.app(INDENT118169,anf_arg517028933):R.ffi.throwNonFunApp(L[1922],anf_fun514410148,[INDENT118169,anf_arg517028933]);
};
try {
if(--R.GAS > 0) {
$z2893728938 = $f2894328944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2894328944,
"from":L[1922]});
}
} catch($e2893528936) {
if(R.isCont($e2893528936)) {
var $ss2893928940 = {"from":L[1922],
"go":function(ann_DASH_check_DASH_temp514328945) {
return $Hann_DASH_check_DASH_temp1025228946(ann_DASH_check_DASH_temp514328945);
}};
$e2893528936.stack[R.EXN_STACKHEIGHT++] = $ss2893928940;
}
if(R.isPyretException($e2893528936)) {
$e2893528936.pyretStack.push(L[1922]);
}
throw $e2893528936;
}
var $ret2894128942 = $Hann_DASH_check_DASH_temp1025228946($z2893728938);
++R.GAS;
return $ret2894128942;
};
var $Hann_DASH_check_DASH_temp1025228946 = function(ann_DASH_check_DASH_temp514328945) {
return ann_DASH_check_DASH_temp514328945;
};
var $Hann_DASH_check_DASH_temp1025128835 = function(ann_DASH_check_DASH_temp515728834) {
return ann_DASH_check_DASH_temp515728834;
};
var $Hanf_arg1025010168 = function(anf_arg512510166,self64010167,_plus55,torepr65) {
var anf_arg512628957 = G(self64010167,"name",L[1910]);
var $z2894928950 = D;
var $f2895528956 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg512628957):R.ffi.throwNonFunApp(L[1910],torepr65,[anf_arg512628957]);
};
try {
if(--R.GAS > 0) {
$z2894928950 = $f2895528956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2895528956,
"from":L[1910]});
}
} catch($e2894728948) {
if(R.isCont($e2894728948)) {
var $ss2895128952 = {"from":L[1910],
"go":function(anf_arg512728958) {
return $Hanf_arg1024928959(anf_arg512728958,anf_arg512510166,self64010167,_plus55,torepr65);
}};
$e2894728948.stack[R.EXN_STACKHEIGHT++] = $ss2895128952;
}
if(R.isPyretException($e2894728948)) {
$e2894728948.pyretStack.push(L[1910]);
}
throw $e2894728948;
}
var $ret2895328954 = $Hanf_arg1024928959($z2894928950,anf_arg512510166,self64010167,_plus55,torepr65);
++R.GAS;
return $ret2895328954;
};
var $Hanf_arg1024928959 = function(anf_arg512728958,anf_arg512510166,self64010167,_plus55,torepr65) {
var $z2896228963 = D;
var $f2896828969 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg512728958):R.ffi.throwNonFunApp(L[1910],_plus55,[(", "),anf_arg512728958]);
};
try {
if(--R.GAS > 0) {
$z2896228963 = $f2896828969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2896828969,
"from":L[1910]});
}
} catch($e2896028961) {
if(R.isCont($e2896028961)) {
var $ss2896428965 = {"from":L[1910],
"go":function(anf_arg512828970) {
return $Hanf_arg1024828971(anf_arg512828970,anf_arg512510166,self64010167,_plus55,torepr65);
}};
$e2896028961.stack[R.EXN_STACKHEIGHT++] = $ss2896428965;
}
if(R.isPyretException($e2896028961)) {
$e2896028961.pyretStack.push(L[1910]);
}
throw $e2896028961;
}
var $ret2896628967 = $Hanf_arg1024828971($z2896228963,anf_arg512510166,self64010167,_plus55,torepr65);
++R.GAS;
return $ret2896628967;
};
var $Hanf_arg1024828971 = function(anf_arg512828970,anf_arg512510166,self64010167,_plus55,torepr65) {
var $z2897428975 = D;
var $f2898028981 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg512510166,anf_arg512828970):R.ffi.throwNonFunApp(L[1910],_plus55,[anf_arg512510166,anf_arg512828970]);
};
try {
if(--R.GAS > 0) {
$z2897428975 = $f2898028981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2898028981,
"from":L[1910]});
}
} catch($e2897228973) {
if(R.isCont($e2897228973)) {
var $ss2897628977 = {"from":L[1910],
"go":function(anf_arg512928982) {
return $Hanf_arg1024728983(anf_arg512928982,self64010167,_plus55,torepr65);
}};
$e2897228973.stack[R.EXN_STACKHEIGHT++] = $ss2897628977;
}
if(R.isPyretException($e2897228973)) {
$e2897228973.pyretStack.push(L[1910]);
}
throw $e2897228973;
}
var $ret2897828979 = $Hanf_arg1024728983($z2897428975,self64010167,_plus55,torepr65);
++R.GAS;
return $ret2897828979;
};
var $Hanf_arg1024728983 = function(anf_arg512928982,self64010167,_plus55,torepr65) {
var anf_arg513028994 = G(self64010167,"args",L[1910]);
var $z2898628987 = D;
var $f2899228993 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg513028994):R.ffi.throwNonFunApp(L[1910],torepr65,[anf_arg513028994]);
};
try {
if(--R.GAS > 0) {
$z2898628987 = $f2899228993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2899228993,
"from":L[1910]});
}
} catch($e2898428985) {
if(R.isCont($e2898428985)) {
var $ss2898828989 = {"from":L[1910],
"go":function(anf_arg513128995) {
return $Hanf_arg1024628996(anf_arg513128995,anf_arg512928982,self64010167,_plus55,torepr65);
}};
$e2898428985.stack[R.EXN_STACKHEIGHT++] = $ss2898828989;
}
if(R.isPyretException($e2898428985)) {
$e2898428985.pyretStack.push(L[1910]);
}
throw $e2898428985;
}
var $ret2899028991 = $Hanf_arg1024628996($z2898628987,anf_arg512928982,self64010167,_plus55,torepr65);
++R.GAS;
return $ret2899028991;
};
var $Hanf_arg1024628996 = function(anf_arg513128995,anf_arg512928982,self64010167,_plus55,torepr65) {
var $z2899929000 = D;
var $f2900529006 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg513128995):R.ffi.throwNonFunApp(L[1910],_plus55,[(", "),anf_arg513128995]);
};
try {
if(--R.GAS > 0) {
$z2899929000 = $f2900529006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2900529006,
"from":L[1910]});
}
} catch($e2899728998) {
if(R.isCont($e2899728998)) {
var $ss2900129002 = {"from":L[1910],
"go":function(anf_arg513229007) {
return $Hanf_arg1024529008(anf_arg513229007,anf_arg512928982,self64010167,_plus55,torepr65);
}};
$e2899728998.stack[R.EXN_STACKHEIGHT++] = $ss2900129002;
}
if(R.isPyretException($e2899728998)) {
$e2899728998.pyretStack.push(L[1910]);
}
throw $e2899728998;
}
var $ret2900329004 = $Hanf_arg1024529008($z2899929000,anf_arg512928982,self64010167,_plus55,torepr65);
++R.GAS;
return $ret2900329004;
};
var $Hanf_arg1024529008 = function(anf_arg513229007,anf_arg512928982,self64010167,_plus55,torepr65) {
var $z2901129012 = D;
var $f2901729018 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg512928982,anf_arg513229007):R.ffi.throwNonFunApp(L[1910],_plus55,[anf_arg512928982,anf_arg513229007]);
};
try {
if(--R.GAS > 0) {
$z2901129012 = $f2901729018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2901729018,
"from":L[1910]});
}
} catch($e2900929010) {
if(R.isCont($e2900929010)) {
var $ss2901329014 = {"from":L[1910],
"go":function(anf_arg513329019) {
return $Hanf_arg1024429020(anf_arg513329019,self64010167,_plus55,torepr65);
}};
$e2900929010.stack[R.EXN_STACKHEIGHT++] = $ss2901329014;
}
if(R.isPyretException($e2900929010)) {
$e2900929010.pyretStack.push(L[1910]);
}
throw $e2900929010;
}
var $ret2901529016 = $Hanf_arg1024429020($z2901129012,self64010167,_plus55,torepr65);
++R.GAS;
return $ret2901529016;
};
var $Hanf_arg1024429020 = function(anf_arg513329019,self64010167,_plus55,torepr65) {
var anf_arg513429031 = G(self64010167,"body",L[1910]);
var $z2902329024 = D;
var $f2902929030 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg513429031):R.ffi.throwNonFunApp(L[1910],torepr65,[anf_arg513429031]);
};
try {
if(--R.GAS > 0) {
$z2902329024 = $f2902929030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2902929030,
"from":L[1910]});
}
} catch($e2902129022) {
if(R.isCont($e2902129022)) {
var $ss2902529026 = {"from":L[1910],
"go":function(anf_arg513529032) {
return $Hanf_arg1024329033(anf_arg513529032,anf_arg513329019,_plus55);
}};
$e2902129022.stack[R.EXN_STACKHEIGHT++] = $ss2902529026;
}
if(R.isPyretException($e2902129022)) {
$e2902129022.pyretStack.push(L[1910]);
}
throw $e2902129022;
}
var $ret2902729028 = $Hanf_arg1024329033($z2902329024,anf_arg513329019,_plus55);
++R.GAS;
return $ret2902729028;
};
var $Hanf_arg1024329033 = function(anf_arg513529032,anf_arg513329019,_plus55) {
var $z2903629037 = D;
var $f2904229043 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg513529032):R.ffi.throwNonFunApp(L[1910],_plus55,[(", "),anf_arg513529032]);
};
try {
if(--R.GAS > 0) {
$z2903629037 = $f2904229043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2904229043,
"from":L[1910]});
}
} catch($e2903429035) {
if(R.isCont($e2903429035)) {
var $ss2903829039 = {"from":L[1910],
"go":function(anf_arg513629044) {
return $Hanf_arg1024229045(anf_arg513629044,anf_arg513329019,_plus55);
}};
$e2903429035.stack[R.EXN_STACKHEIGHT++] = $ss2903829039;
}
if(R.isPyretException($e2903429035)) {
$e2903429035.pyretStack.push(L[1910]);
}
throw $e2903429035;
}
var $ret2904029041 = $Hanf_arg1024229045($z2903629037,anf_arg513329019,_plus55);
++R.GAS;
return $ret2904029041;
};
var $Hanf_arg1024229045 = function(anf_arg513629044,anf_arg513329019,_plus55) {
var $z2904829049 = D;
var $f2905429055 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg513329019,anf_arg513629044):R.ffi.throwNonFunApp(L[1910],_plus55,[anf_arg513329019,anf_arg513629044]);
};
try {
if(--R.GAS > 0) {
$z2904829049 = $f2905429055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2905429055,
"from":L[1910]});
}
} catch($e2904629047) {
if(R.isCont($e2904629047)) {
var $ss2905029051 = {"from":L[1910],
"go":function(anf_arg513729056) {
return $Hanf_arg1024129057(anf_arg513729056,_plus55);
}};
$e2904629047.stack[R.EXN_STACKHEIGHT++] = $ss2905029051;
}
if(R.isPyretException($e2904629047)) {
$e2904629047.pyretStack.push(L[1910]);
}
throw $e2904629047;
}
var $ret2905229053 = $Hanf_arg1024129057($z2904829049,_plus55);
++R.GAS;
return $ret2905229053;
};
var $Hanf_arg1024129057 = function(anf_arg513729056,_plus55) {
var $z2906029061 = D;
var $f2906629067 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg513729056,(")")):R.ffi.throwNonFunApp(L[1910],_plus55,[anf_arg513729056,(")")]);
};
try {
if(--R.GAS > 0) {
$z2906029061 = $f2906629067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2906629067,
"from":L[1910]});
}
} catch($e2905829059) {
if(R.isCont($e2905829059)) {
var $ss2906229063 = {"from":L[1910],
"go":function(anf_arg513829068) {
return $Hanf_arg1024029069(anf_arg513829068,_plus55);
}};
$e2905829059.stack[R.EXN_STACKHEIGHT++] = $ss2906229063;
}
if(R.isPyretException($e2905829059)) {
$e2905829059.pyretStack.push(L[1910]);
}
throw $e2905829059;
}
var $ret2906429065 = $Hanf_arg1024029069($z2906029061,_plus55);
++R.GAS;
return $ret2906429065;
};
var $Hanf_arg1024029069 = function(anf_arg513829068,_plus55) {
var $z2907229073 = D;
var $f2907829079 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg513829068):R.ffi.throwNonFunApp(L[1910],_plus55,[("("),anf_arg513829068]);
};
try {
if(--R.GAS > 0) {
$z2907229073 = $f2907829079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2907829079,
"from":L[1910]});
}
} catch($e2907029071) {
if(R.isCont($e2907029071)) {
var $ss2907429075 = {"from":L[1910],
"go":function(anf_arg513929080) {
return $Hanf_arg1023929081(anf_arg513929080,_plus55);
}};
$e2907029071.stack[R.EXN_STACKHEIGHT++] = $ss2907429075;
}
if(R.isPyretException($e2907029071)) {
$e2907029071.pyretStack.push(L[1910]);
}
throw $e2907029071;
}
var $ret2907629077 = $Hanf_arg1023929081($z2907229073,_plus55);
++R.GAS;
return $ret2907629077;
};
var $Hanf_arg1023929081 = function(anf_arg513929080,_plus55) {
var $z2908429085 = D;
var $f2909029091 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-cases-branch"),anf_arg513929080):R.ffi.throwNonFunApp(L[1910],_plus55,[("s-cases-branch"),anf_arg513929080]);
};
try {
if(--R.GAS > 0) {
$z2908429085 = $f2909029091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2909029091,
"from":L[1910]});
}
} catch($e2908229083) {
if(R.isCont($e2908229083)) {
var $ss2908629087 = {"from":L[1910],
"go":function(ann_DASH_check_DASH_temp512329092) {
return $Hann_DASH_check_DASH_temp1023829093(ann_DASH_check_DASH_temp512329092);
}};
$e2908229083.stack[R.EXN_STACKHEIGHT++] = $ss2908629087;
}
if(R.isPyretException($e2908229083)) {
$e2908229083.pyretStack.push(L[1910]);
}
throw $e2908229083;
}
var $ret2908829089 = $Hann_DASH_check_DASH_temp1023829093($z2908429085);
++R.GAS;
return $ret2908829089;
};
var $Hann_DASH_check_DASH_temp1023829093 = function(ann_DASH_check_DASH_temp512329092) {
return ann_DASH_check_DASH_temp512329092;
};
var $Hcont_tail_arg1023610186 = function(cont_tail_arg512010184,if_helper510910185) {
if(--R.GAS > 0) {
$z2909429095 = R.isFunction(if_helper510910185)?if_helper510910185.app(cont_tail_arg512010184):R.ffi.throwNonFunApp(L[1910],if_helper510910185,[cont_tail_arg512010184]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper510910185)?if_helper510910185.app(cont_tail_arg512010184):R.ffi.throwNonFunApp(L[1910],if_helper510910185,[cont_tail_arg512010184]);
},
"from":L[1910]});
}
++R.GAS;
return $z2909429095;
};
var $Hcont_tail_arg1023710201 = function(cont_tail_arg511410200,if_helper510910185) {
if(--R.GAS > 0) {
$z2909629097 = R.isFunction(if_helper510910185)?if_helper510910185.app(cont_tail_arg511410200):R.ffi.throwNonFunApp(L[1910],if_helper510910185,[cont_tail_arg511410200]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper510910185)?if_helper510910185.app(cont_tail_arg511410200):R.ffi.throwNonFunApp(L[1910],if_helper510910185,[cont_tail_arg511410200]);
},
"from":L[1910]});
}
++R.GAS;
return $z2909629097;
};
var $Hann_DASH_check_DASH_temp1023510223 = function(ann_DASH_check_DASH_temp510010222) {
return ann_DASH_check_DASH_temp510010222;
};
var $Hanf_arg1023410236 = function(anf_arg510410235,_plus55,raise62) {
var $z2910029101 = D;
var $f2910629107 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg510410235):R.ffi.throwNonFunApp(L[4022],_plus55,[("No visitor field for "),anf_arg510410235]);
};
try {
if(--R.GAS > 0) {
$z2910029101 = $f2910629107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2910629107,
"from":L[4022]});
}
} catch($e2909829099) {
if(R.isCont($e2909829099)) {
var $ss2910229103 = {"from":L[4022],
"go":function(anf_arg510529108) {
return $Hanf_arg1023329109(anf_arg510529108,raise62);
}};
$e2909829099.stack[R.EXN_STACKHEIGHT++] = $ss2910229103;
}
if(R.isPyretException($e2909829099)) {
$e2909829099.pyretStack.push(L[4022]);
}
throw $e2909829099;
}
var $ret2910429105 = $Hanf_arg1023329109($z2910029101,raise62);
++R.GAS;
return $ret2910429105;
};
var $Hanf_arg1023329109 = function(anf_arg510529108,raise62) {
var $z2911229113 = D;
var $f2911829119 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg510529108):R.ffi.throwNonFunApp(L[1929],raise62,[anf_arg510529108]);
};
try {
if(--R.GAS > 0) {
$z2911229113 = $f2911829119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2911829119,
"from":L[1929]});
}
} catch($e2911029111) {
if(R.isCont($e2911029111)) {
var $ss2911429115 = {"from":L[1929],
"go":function(ann_DASH_check_DASH_temp510229120) {
return $Hann_DASH_check_DASH_temp1023229121(ann_DASH_check_DASH_temp510229120);
}};
$e2911029111.stack[R.EXN_STACKHEIGHT++] = $ss2911429115;
}
if(R.isPyretException($e2911029111)) {
$e2911029111.pyretStack.push(L[1929]);
}
throw $e2911029111;
}
var $ret2911629117 = $Hann_DASH_check_DASH_temp1023229121($z2911229113);
++R.GAS;
return $ret2911629117;
};
var $Hann_DASH_check_DASH_temp1023229121 = function(ann_DASH_check_DASH_temp510229120) {
return ann_DASH_check_DASH_temp510229120;
};
var $Hanf_arg1023110264 = function(anf_arg508010261,INDENT118169,PP170,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55) {
var anf_bracket508129135 = G(self112310263,"test",L[4025]);
var anf_fun508229132 = G(anf_bracket508129135,"tosource",L[4024]);
var $z2912429125 = D;
var $f2913029131 = function(_) {
return R.isFunction(anf_fun508229132)?anf_fun508229132.app():R.ffi.throwNonFunApp(L[4023],anf_fun508229132,[]);
};
try {
if(--R.GAS > 0) {
$z2912429125 = $f2913029131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2913029131,
"from":L[4023]});
}
} catch($e2912229123) {
if(R.isCont($e2912229123)) {
var $ss2912629127 = {"from":L[4023],
"go":function(anf_arg508329133) {
return $Hanf_arg1023029134(anf_arg508329133,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55);
}};
$e2912229123.stack[R.EXN_STACKHEIGHT++] = $ss2912629127;
}
if(R.isPyretException($e2912229123)) {
$e2912229123.pyretStack.push(L[4023]);
}
throw $e2912229123;
}
var $ret2912829129 = $Hanf_arg1023029134($z2912429125,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55);
++R.GAS;
return $ret2912829129;
};
var $Hanf_arg1023029134 = function(anf_arg508329133,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55) {
var $z2913829139 = D;
var $f2914429145 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg508329133,break_DASH_one119168):R.ffi.throwNonFunApp(L[4026],_plus55,[anf_arg508329133,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z2913829139 = $f2914429145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2914429145,
"from":L[4026]});
}
} catch($e2913629137) {
if(R.isCont($e2913629137)) {
var $ss2914029141 = {"from":L[4026],
"go":function(anf_arg508429146) {
return $Hanf_arg1022929147(anf_arg508429146,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55);
}};
$e2913629137.stack[R.EXN_STACKHEIGHT++] = $ss2914029141;
}
if(R.isPyretException($e2913629137)) {
$e2913629137.pyretStack.push(L[4026]);
}
throw $e2913629137;
}
var $ret2914229143 = $Hanf_arg1022929147($z2913829139,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55);
++R.GAS;
return $ret2914229143;
};
var $Hanf_arg1022929147 = function(anf_arg508429146,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,str_DASH_thencolon171845,_plus55) {
var $z2915029151 = D;
var $f2915629157 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg508429146,str_DASH_thencolon171845):R.ffi.throwNonFunApp(L[4026],_plus55,[anf_arg508429146,str_DASH_thencolon171845]);
};
try {
if(--R.GAS > 0) {
$z2915029151 = $f2915629157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2915629157,
"from":L[4026]});
}
} catch($e2914829149) {
if(R.isCont($e2914829149)) {
var $ss2915229153 = {"from":L[4026],
"go":function(anf_arg508529158) {
return $Hanf_arg1022829159(anf_arg508529158,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,_plus55);
}};
$e2914829149.stack[R.EXN_STACKHEIGHT++] = $ss2915229153;
}
if(R.isPyretException($e2914829149)) {
$e2914829149.pyretStack.push(L[4026]);
}
throw $e2914829149;
}
var $ret2915429155 = $Hanf_arg1022829159($z2915029151,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,_plus55);
++R.GAS;
return $ret2915429155;
};
var $Hanf_arg1022829159 = function(anf_arg508529158,INDENT118169,PP170,anf_arg508010261,anf_fun507910262,break_DASH_one119168,self112310263,str_DASH_pipespace162728,_plus55) {
var $z2916229163 = D;
var $f2916829169 = function(_) {
return R.isFunction(anf_fun507910262)?anf_fun507910262.app(anf_arg508010261,anf_arg508529158):R.ffi.throwNonFunApp(L[4027],anf_fun507910262,[anf_arg508010261,anf_arg508529158]);
};
try {
if(--R.GAS > 0) {
$z2916229163 = $f2916829169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2916829169,
"from":L[4027]});
}
} catch($e2916029161) {
if(R.isCont($e2916029161)) {
var $ss2916429165 = {"from":L[4027],
"go":function(anf_arg508629170) {
return $Hanf_arg1022729171(anf_arg508629170,INDENT118169,PP170,break_DASH_one119168,self112310263,str_DASH_pipespace162728,_plus55);
}};
$e2916029161.stack[R.EXN_STACKHEIGHT++] = $ss2916429165;
}
if(R.isPyretException($e2916029161)) {
$e2916029161.pyretStack.push(L[4027]);
}
throw $e2916029161;
}
var $ret2916629167 = $Hanf_arg1022729171($z2916229163,INDENT118169,PP170,break_DASH_one119168,self112310263,str_DASH_pipespace162728,_plus55);
++R.GAS;
return $ret2916629167;
};
var $Hanf_arg1022729171 = function(anf_arg508629170,INDENT118169,PP170,break_DASH_one119168,self112310263,str_DASH_pipespace162728,_plus55) {
var $z2917429175 = D;
var $f2918029181 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_pipespace162728,anf_arg508629170):R.ffi.throwNonFunApp(L[4028],_plus55,[str_DASH_pipespace162728,anf_arg508629170]);
};
try {
if(--R.GAS > 0) {
$z2917429175 = $f2918029181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2918029181,
"from":L[4028]});
}
} catch($e2917229173) {
if(R.isCont($e2917229173)) {
var $ss2917629177 = {"from":L[4028],
"go":function(anf_arg508729182) {
return $Hanf_arg1022629183(anf_arg508729182,INDENT118169,PP170,break_DASH_one119168,self112310263,_plus55);
}};
$e2917229173.stack[R.EXN_STACKHEIGHT++] = $ss2917629177;
}
if(R.isPyretException($e2917229173)) {
$e2917229173.pyretStack.push(L[4028]);
}
throw $e2917229173;
}
var $ret2917829179 = $Hanf_arg1022629183($z2917429175,INDENT118169,PP170,break_DASH_one119168,self112310263,_plus55);
++R.GAS;
return $ret2917829179;
};
var $Hanf_arg1022629183 = function(anf_arg508729182,INDENT118169,PP170,break_DASH_one119168,self112310263,_plus55) {
var anf_fun508829196 = G(PP170,"nest",L[4032]);
var anf_bracket508929198 = G(self112310263,"body",L[4031]);
var anf_fun509029194 = G(anf_bracket508929198,"tosource",L[4030]);
var $z2918629187 = D;
var $f2919229193 = function(_) {
return R.isFunction(anf_fun509029194)?anf_fun509029194.app():R.ffi.throwNonFunApp(L[4029],anf_fun509029194,[]);
};
try {
if(--R.GAS > 0) {
$z2918629187 = $f2919229193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2919229193,
"from":L[4029]});
}
} catch($e2918429185) {
if(R.isCont($e2918429185)) {
var $ss2918829189 = {"from":L[4029],
"go":function(anf_arg509129195) {
return $Hanf_arg1022529197(anf_arg509129195,INDENT118169,anf_arg508729182,anf_fun508829196,break_DASH_one119168,_plus55);
}};
$e2918429185.stack[R.EXN_STACKHEIGHT++] = $ss2918829189;
}
if(R.isPyretException($e2918429185)) {
$e2918429185.pyretStack.push(L[4029]);
}
throw $e2918429185;
}
var $ret2919029191 = $Hanf_arg1022529197($z2918629187,INDENT118169,anf_arg508729182,anf_fun508829196,break_DASH_one119168,_plus55);
++R.GAS;
return $ret2919029191;
};
var $Hanf_arg1022529197 = function(anf_arg509129195,INDENT118169,anf_arg508729182,anf_fun508829196,break_DASH_one119168,_plus55) {
var $z2920129202 = D;
var $f2920729208 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,anf_arg509129195):R.ffi.throwNonFunApp(L[4033],_plus55,[break_DASH_one119168,anf_arg509129195]);
};
try {
if(--R.GAS > 0) {
$z2920129202 = $f2920729208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2920729208,
"from":L[4033]});
}
} catch($e2919929200) {
if(R.isCont($e2919929200)) {
var $ss2920329204 = {"from":L[4033],
"go":function(anf_arg509229209) {
return $Hanf_arg1022429210(anf_arg509229209,INDENT118169,anf_arg508729182,anf_fun508829196,_plus55);
}};
$e2919929200.stack[R.EXN_STACKHEIGHT++] = $ss2920329204;
}
if(R.isPyretException($e2919929200)) {
$e2919929200.pyretStack.push(L[4033]);
}
throw $e2919929200;
}
var $ret2920529206 = $Hanf_arg1022429210($z2920129202,INDENT118169,anf_arg508729182,anf_fun508829196,_plus55);
++R.GAS;
return $ret2920529206;
};
var $Hanf_arg1022429210 = function(anf_arg509229209,INDENT118169,anf_arg508729182,anf_fun508829196,_plus55) {
var $z2921329214 = D;
var $f2921929220 = function(_) {
return R.isFunction(anf_fun508829196)?anf_fun508829196.app(INDENT118169,anf_arg509229209):R.ffi.throwNonFunApp(L[4034],anf_fun508829196,[INDENT118169,anf_arg509229209]);
};
try {
if(--R.GAS > 0) {
$z2921329214 = $f2921929220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2921929220,
"from":L[4034]});
}
} catch($e2921129212) {
if(R.isCont($e2921129212)) {
var $ss2921529216 = {"from":L[4034],
"go":function(anf_arg509329221) {
return $Hanf_arg1022329222(anf_arg509329221,anf_arg508729182,_plus55);
}};
$e2921129212.stack[R.EXN_STACKHEIGHT++] = $ss2921529216;
}
if(R.isPyretException($e2921129212)) {
$e2921129212.pyretStack.push(L[4034]);
}
throw $e2921129212;
}
var $ret2921729218 = $Hanf_arg1022329222($z2921329214,anf_arg508729182,_plus55);
++R.GAS;
return $ret2921729218;
};
var $Hanf_arg1022329222 = function(anf_arg509329221,anf_arg508729182,_plus55) {
var $z2922529226 = D;
var $f2923129232 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg508729182,anf_arg509329221):R.ffi.throwNonFunApp(L[1941],_plus55,[anf_arg508729182,anf_arg509329221]);
};
try {
if(--R.GAS > 0) {
$z2922529226 = $f2923129232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2923129232,
"from":L[1941]});
}
} catch($e2922329224) {
if(R.isCont($e2922329224)) {
var $ss2922729228 = {"from":L[1941],
"go":function(ann_DASH_check_DASH_temp507829233) {
return $Hann_DASH_check_DASH_temp1022229234(ann_DASH_check_DASH_temp507829233);
}};
$e2922329224.stack[R.EXN_STACKHEIGHT++] = $ss2922729228;
}
if(R.isPyretException($e2922329224)) {
$e2922329224.pyretStack.push(L[1941]);
}
throw $e2922329224;
}
var $ret2922929230 = $Hann_DASH_check_DASH_temp1022229234($z2922529226);
++R.GAS;
return $ret2922929230;
};
var $Hann_DASH_check_DASH_temp1022229234 = function(ann_DASH_check_DASH_temp507829233) {
return ann_DASH_check_DASH_temp507829233;
};
var $Hanf_arg1022110280 = function(anf_arg506410278,self63410279,_plus55,torepr65) {
var anf_arg506529245 = G(self63410279,"test",L[1933]);
var $z2923729238 = D;
var $f2924329244 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg506529245):R.ffi.throwNonFunApp(L[1933],torepr65,[anf_arg506529245]);
};
try {
if(--R.GAS > 0) {
$z2923729238 = $f2924329244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2924329244,
"from":L[1933]});
}
} catch($e2923529236) {
if(R.isCont($e2923529236)) {
var $ss2923929240 = {"from":L[1933],
"go":function(anf_arg506629246) {
return $Hanf_arg1022029247(anf_arg506629246,anf_arg506410278,self63410279,_plus55,torepr65);
}};
$e2923529236.stack[R.EXN_STACKHEIGHT++] = $ss2923929240;
}
if(R.isPyretException($e2923529236)) {
$e2923529236.pyretStack.push(L[1933]);
}
throw $e2923529236;
}
var $ret2924129242 = $Hanf_arg1022029247($z2923729238,anf_arg506410278,self63410279,_plus55,torepr65);
++R.GAS;
return $ret2924129242;
};
var $Hanf_arg1022029247 = function(anf_arg506629246,anf_arg506410278,self63410279,_plus55,torepr65) {
var $z2925029251 = D;
var $f2925629257 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg506629246):R.ffi.throwNonFunApp(L[1933],_plus55,[(", "),anf_arg506629246]);
};
try {
if(--R.GAS > 0) {
$z2925029251 = $f2925629257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2925629257,
"from":L[1933]});
}
} catch($e2924829249) {
if(R.isCont($e2924829249)) {
var $ss2925229253 = {"from":L[1933],
"go":function(anf_arg506729258) {
return $Hanf_arg1021929259(anf_arg506729258,anf_arg506410278,self63410279,_plus55,torepr65);
}};
$e2924829249.stack[R.EXN_STACKHEIGHT++] = $ss2925229253;
}
if(R.isPyretException($e2924829249)) {
$e2924829249.pyretStack.push(L[1933]);
}
throw $e2924829249;
}
var $ret2925429255 = $Hanf_arg1021929259($z2925029251,anf_arg506410278,self63410279,_plus55,torepr65);
++R.GAS;
return $ret2925429255;
};
var $Hanf_arg1021929259 = function(anf_arg506729258,anf_arg506410278,self63410279,_plus55,torepr65) {
var $z2926229263 = D;
var $f2926829269 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg506410278,anf_arg506729258):R.ffi.throwNonFunApp(L[1933],_plus55,[anf_arg506410278,anf_arg506729258]);
};
try {
if(--R.GAS > 0) {
$z2926229263 = $f2926829269();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2926829269,
"from":L[1933]});
}
} catch($e2926029261) {
if(R.isCont($e2926029261)) {
var $ss2926429265 = {"from":L[1933],
"go":function(anf_arg506829270) {
return $Hanf_arg1021829271(anf_arg506829270,self63410279,_plus55,torepr65);
}};
$e2926029261.stack[R.EXN_STACKHEIGHT++] = $ss2926429265;
}
if(R.isPyretException($e2926029261)) {
$e2926029261.pyretStack.push(L[1933]);
}
throw $e2926029261;
}
var $ret2926629267 = $Hanf_arg1021829271($z2926229263,self63410279,_plus55,torepr65);
++R.GAS;
return $ret2926629267;
};
var $Hanf_arg1021829271 = function(anf_arg506829270,self63410279,_plus55,torepr65) {
var anf_arg506929282 = G(self63410279,"body",L[1933]);
var $z2927429275 = D;
var $f2928029281 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg506929282):R.ffi.throwNonFunApp(L[1933],torepr65,[anf_arg506929282]);
};
try {
if(--R.GAS > 0) {
$z2927429275 = $f2928029281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2928029281,
"from":L[1933]});
}
} catch($e2927229273) {
if(R.isCont($e2927229273)) {
var $ss2927629277 = {"from":L[1933],
"go":function(anf_arg507029283) {
return $Hanf_arg1021729284(anf_arg507029283,anf_arg506829270,_plus55);
}};
$e2927229273.stack[R.EXN_STACKHEIGHT++] = $ss2927629277;
}
if(R.isPyretException($e2927229273)) {
$e2927229273.pyretStack.push(L[1933]);
}
throw $e2927229273;
}
var $ret2927829279 = $Hanf_arg1021729284($z2927429275,anf_arg506829270,_plus55);
++R.GAS;
return $ret2927829279;
};
var $Hanf_arg1021729284 = function(anf_arg507029283,anf_arg506829270,_plus55) {
var $z2928729288 = D;
var $f2929329294 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg507029283):R.ffi.throwNonFunApp(L[1933],_plus55,[(", "),anf_arg507029283]);
};
try {
if(--R.GAS > 0) {
$z2928729288 = $f2929329294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2929329294,
"from":L[1933]});
}
} catch($e2928529286) {
if(R.isCont($e2928529286)) {
var $ss2928929290 = {"from":L[1933],
"go":function(anf_arg507129295) {
return $Hanf_arg1021629296(anf_arg507129295,anf_arg506829270,_plus55);
}};
$e2928529286.stack[R.EXN_STACKHEIGHT++] = $ss2928929290;
}
if(R.isPyretException($e2928529286)) {
$e2928529286.pyretStack.push(L[1933]);
}
throw $e2928529286;
}
var $ret2929129292 = $Hanf_arg1021629296($z2928729288,anf_arg506829270,_plus55);
++R.GAS;
return $ret2929129292;
};
var $Hanf_arg1021629296 = function(anf_arg507129295,anf_arg506829270,_plus55) {
var $z2929929300 = D;
var $f2930529306 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg506829270,anf_arg507129295):R.ffi.throwNonFunApp(L[1933],_plus55,[anf_arg506829270,anf_arg507129295]);
};
try {
if(--R.GAS > 0) {
$z2929929300 = $f2930529306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2930529306,
"from":L[1933]});
}
} catch($e2929729298) {
if(R.isCont($e2929729298)) {
var $ss2930129302 = {"from":L[1933],
"go":function(anf_arg507229307) {
return $Hanf_arg1021529308(anf_arg507229307,_plus55);
}};
$e2929729298.stack[R.EXN_STACKHEIGHT++] = $ss2930129302;
}
if(R.isPyretException($e2929729298)) {
$e2929729298.pyretStack.push(L[1933]);
}
throw $e2929729298;
}
var $ret2930329304 = $Hanf_arg1021529308($z2929929300,_plus55);
++R.GAS;
return $ret2930329304;
};
var $Hanf_arg1021529308 = function(anf_arg507229307,_plus55) {
var $z2931129312 = D;
var $f2931729318 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg507229307,(")")):R.ffi.throwNonFunApp(L[1933],_plus55,[anf_arg507229307,(")")]);
};
try {
if(--R.GAS > 0) {
$z2931129312 = $f2931729318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2931729318,
"from":L[1933]});
}
} catch($e2930929310) {
if(R.isCont($e2930929310)) {
var $ss2931329314 = {"from":L[1933],
"go":function(anf_arg507329319) {
return $Hanf_arg1021429320(anf_arg507329319,_plus55);
}};
$e2930929310.stack[R.EXN_STACKHEIGHT++] = $ss2931329314;
}
if(R.isPyretException($e2930929310)) {
$e2930929310.pyretStack.push(L[1933]);
}
throw $e2930929310;
}
var $ret2931529316 = $Hanf_arg1021429320($z2931129312,_plus55);
++R.GAS;
return $ret2931529316;
};
var $Hanf_arg1021429320 = function(anf_arg507329319,_plus55) {
var $z2932329324 = D;
var $f2932929330 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg507329319):R.ffi.throwNonFunApp(L[1933],_plus55,[("("),anf_arg507329319]);
};
try {
if(--R.GAS > 0) {
$z2932329324 = $f2932929330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2932929330,
"from":L[1933]});
}
} catch($e2932129322) {
if(R.isCont($e2932129322)) {
var $ss2932529326 = {"from":L[1933],
"go":function(anf_arg507429331) {
return $Hanf_arg1021329332(anf_arg507429331,_plus55);
}};
$e2932129322.stack[R.EXN_STACKHEIGHT++] = $ss2932529326;
}
if(R.isPyretException($e2932129322)) {
$e2932129322.pyretStack.push(L[1933]);
}
throw $e2932129322;
}
var $ret2932729328 = $Hanf_arg1021329332($z2932329324,_plus55);
++R.GAS;
return $ret2932729328;
};
var $Hanf_arg1021329332 = function(anf_arg507429331,_plus55) {
var $z2933529336 = D;
var $f2934129342 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-if-pipe-branch"),anf_arg507429331):R.ffi.throwNonFunApp(L[1933],_plus55,[("s-if-pipe-branch"),anf_arg507429331]);
};
try {
if(--R.GAS > 0) {
$z2933529336 = $f2934129342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2934129342,
"from":L[1933]});
}
} catch($e2933329334) {
if(R.isCont($e2933329334)) {
var $ss2933729338 = {"from":L[1933],
"go":function(ann_DASH_check_DASH_temp506229343) {
return $Hann_DASH_check_DASH_temp1021229344(ann_DASH_check_DASH_temp506229343);
}};
$e2933329334.stack[R.EXN_STACKHEIGHT++] = $ss2933729338;
}
if(R.isPyretException($e2933329334)) {
$e2933329334.pyretStack.push(L[1933]);
}
throw $e2933329334;
}
var $ret2933929340 = $Hann_DASH_check_DASH_temp1021229344($z2933529336);
++R.GAS;
return $ret2933929340;
};
var $Hann_DASH_check_DASH_temp1021229344 = function(ann_DASH_check_DASH_temp506229343) {
return ann_DASH_check_DASH_temp506229343;
};
var $Hcont_tail_arg1021010297 = function(cont_tail_arg505910295,if_helper504910296) {
if(--R.GAS > 0) {
$z2934529346 = R.isFunction(if_helper504910296)?if_helper504910296.app(cont_tail_arg505910295):R.ffi.throwNonFunApp(L[1933],if_helper504910296,[cont_tail_arg505910295]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper504910296)?if_helper504910296.app(cont_tail_arg505910295):R.ffi.throwNonFunApp(L[1933],if_helper504910296,[cont_tail_arg505910295]);
},
"from":L[1933]});
}
++R.GAS;
return $z2934529346;
};
var $Hcont_tail_arg1021110312 = function(cont_tail_arg505410311,if_helper504910296) {
if(--R.GAS > 0) {
$z2934729348 = R.isFunction(if_helper504910296)?if_helper504910296.app(cont_tail_arg505410311):R.ffi.throwNonFunApp(L[1933],if_helper504910296,[cont_tail_arg505410311]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper504910296)?if_helper504910296.app(cont_tail_arg505410311):R.ffi.throwNonFunApp(L[1933],if_helper504910296,[cont_tail_arg505410311]);
},
"from":L[1933]});
}
++R.GAS;
return $z2934729348;
};
var $Hann_DASH_check_DASH_temp1020910334 = function(ann_DASH_check_DASH_temp504010333) {
return ann_DASH_check_DASH_temp504010333;
};
var $Hanf_arg1020810347 = function(anf_arg504410346,_plus55,raise62) {
var $z2935129352 = D;
var $f2935729358 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg504410346):R.ffi.throwNonFunApp(L[4035],_plus55,[("No visitor field for "),anf_arg504410346]);
};
try {
if(--R.GAS > 0) {
$z2935129352 = $f2935729358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2935729358,
"from":L[4035]});
}
} catch($e2934929350) {
if(R.isCont($e2934929350)) {
var $ss2935329354 = {"from":L[4035],
"go":function(anf_arg504529359) {
return $Hanf_arg1020729360(anf_arg504529359,raise62);
}};
$e2934929350.stack[R.EXN_STACKHEIGHT++] = $ss2935329354;
}
if(R.isPyretException($e2934929350)) {
$e2934929350.pyretStack.push(L[4035]);
}
throw $e2934929350;
}
var $ret2935529356 = $Hanf_arg1020729360($z2935129352,raise62);
++R.GAS;
return $ret2935529356;
};
var $Hanf_arg1020729360 = function(anf_arg504529359,raise62) {
var $z2936329364 = D;
var $f2936929370 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg504529359):R.ffi.throwNonFunApp(L[1947],raise62,[anf_arg504529359]);
};
try {
if(--R.GAS > 0) {
$z2936329364 = $f2936929370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2936929370,
"from":L[1947]});
}
} catch($e2936129362) {
if(R.isCont($e2936129362)) {
var $ss2936529366 = {"from":L[1947],
"go":function(ann_DASH_check_DASH_temp504229371) {
return $Hann_DASH_check_DASH_temp1020629372(ann_DASH_check_DASH_temp504229371);
}};
$e2936129362.stack[R.EXN_STACKHEIGHT++] = $ss2936529366;
}
if(R.isPyretException($e2936129362)) {
$e2936129362.pyretStack.push(L[1947]);
}
throw $e2936129362;
}
var $ret2936729368 = $Hann_DASH_check_DASH_temp1020629372($z2936329364);
++R.GAS;
return $ret2936729368;
};
var $Hann_DASH_check_DASH_temp1020629372 = function(ann_DASH_check_DASH_temp504229371) {
return ann_DASH_check_DASH_temp504229371;
};
var $Hanf_arg1020510375 = function(anf_arg502110372,INDENT118169,PP170,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_colon134364,str_DASH_if155637,_plus55) {
var anf_bracket502229386 = G(self111610374,"test",L[4038]);
var anf_fun502329383 = G(anf_bracket502229386,"tosource",L[4037]);
var $z2937529376 = D;
var $f2938129382 = function(_) {
return R.isFunction(anf_fun502329383)?anf_fun502329383.app():R.ffi.throwNonFunApp(L[4036],anf_fun502329383,[]);
};
try {
if(--R.GAS > 0) {
$z2937529376 = $f2938129382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2938129382,
"from":L[4036]});
}
} catch($e2937329374) {
if(R.isCont($e2937329374)) {
var $ss2937729378 = {"from":L[4036],
"go":function(anf_arg502429384) {
return $Hanf_arg1020429385(anf_arg502429384,INDENT118169,PP170,anf_arg502110372,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_colon134364,str_DASH_if155637,_plus55);
}};
$e2937329374.stack[R.EXN_STACKHEIGHT++] = $ss2937729378;
}
if(R.isPyretException($e2937329374)) {
$e2937329374.pyretStack.push(L[4036]);
}
throw $e2937329374;
}
var $ret2937929380 = $Hanf_arg1020429385($z2937529376,INDENT118169,PP170,anf_arg502110372,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_colon134364,str_DASH_if155637,_plus55);
++R.GAS;
return $ret2937929380;
};
var $Hanf_arg1020429385 = function(anf_arg502429384,INDENT118169,PP170,anf_arg502110372,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_colon134364,str_DASH_if155637,_plus55) {
var $z2938929390 = D;
var $f2939529396 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg502429384,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4039],_plus55,[anf_arg502429384,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z2938929390 = $f2939529396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2939529396,
"from":L[4039]});
}
} catch($e2938729388) {
if(R.isCont($e2938729388)) {
var $ss2939129392 = {"from":L[4039],
"go":function(anf_arg502529397) {
return $Hanf_arg1020329398(anf_arg502529397,INDENT118169,PP170,anf_arg502110372,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_if155637,_plus55);
}};
$e2938729388.stack[R.EXN_STACKHEIGHT++] = $ss2939129392;
}
if(R.isPyretException($e2938729388)) {
$e2938729388.pyretStack.push(L[4039]);
}
throw $e2938729388;
}
var $ret2939329394 = $Hanf_arg1020329398($z2938929390,INDENT118169,PP170,anf_arg502110372,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_if155637,_plus55);
++R.GAS;
return $ret2939329394;
};
var $Hanf_arg1020329398 = function(anf_arg502529397,INDENT118169,PP170,anf_arg502110372,anf_fun502010373,break_DASH_one119168,self111610374,str_DASH_if155637,_plus55) {
var $z2940129402 = D;
var $f2940729408 = function(_) {
return R.isFunction(anf_fun502010373)?anf_fun502010373.app(anf_arg502110372,anf_arg502529397):R.ffi.throwNonFunApp(L[4040],anf_fun502010373,[anf_arg502110372,anf_arg502529397]);
};
try {
if(--R.GAS > 0) {
$z2940129402 = $f2940729408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2940729408,
"from":L[4040]});
}
} catch($e2939929400) {
if(R.isCont($e2939929400)) {
var $ss2940329404 = {"from":L[4040],
"go":function(anf_arg502629409) {
return $Hanf_arg1020229410(anf_arg502629409,INDENT118169,PP170,break_DASH_one119168,self111610374,str_DASH_if155637,_plus55);
}};
$e2939929400.stack[R.EXN_STACKHEIGHT++] = $ss2940329404;
}
if(R.isPyretException($e2939929400)) {
$e2939929400.pyretStack.push(L[4040]);
}
throw $e2939929400;
}
var $ret2940529406 = $Hanf_arg1020229410($z2940129402,INDENT118169,PP170,break_DASH_one119168,self111610374,str_DASH_if155637,_plus55);
++R.GAS;
return $ret2940529406;
};
var $Hanf_arg1020229410 = function(anf_arg502629409,INDENT118169,PP170,break_DASH_one119168,self111610374,str_DASH_if155637,_plus55) {
var $z2941329414 = D;
var $f2941929420 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_if155637,anf_arg502629409):R.ffi.throwNonFunApp(L[4041],_plus55,[str_DASH_if155637,anf_arg502629409]);
};
try {
if(--R.GAS > 0) {
$z2941329414 = $f2941929420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2941929420,
"from":L[4041]});
}
} catch($e2941129412) {
if(R.isCont($e2941129412)) {
var $ss2941529416 = {"from":L[4041],
"go":function(anf_arg502729421) {
return $Hanf_arg1020129422(anf_arg502729421,INDENT118169,PP170,break_DASH_one119168,self111610374,_plus55);
}};
$e2941129412.stack[R.EXN_STACKHEIGHT++] = $ss2941529416;
}
if(R.isPyretException($e2941129412)) {
$e2941129412.pyretStack.push(L[4041]);
}
throw $e2941129412;
}
var $ret2941729418 = $Hanf_arg1020129422($z2941329414,INDENT118169,PP170,break_DASH_one119168,self111610374,_plus55);
++R.GAS;
return $ret2941729418;
};
var $Hanf_arg1020129422 = function(anf_arg502729421,INDENT118169,PP170,break_DASH_one119168,self111610374,_plus55) {
var anf_fun502829435 = G(PP170,"nest",L[4045]);
var anf_bracket502929437 = G(self111610374,"body",L[4044]);
var anf_fun503029433 = G(anf_bracket502929437,"tosource",L[4043]);
var $z2942529426 = D;
var $f2943129432 = function(_) {
return R.isFunction(anf_fun503029433)?anf_fun503029433.app():R.ffi.throwNonFunApp(L[4042],anf_fun503029433,[]);
};
try {
if(--R.GAS > 0) {
$z2942529426 = $f2943129432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2943129432,
"from":L[4042]});
}
} catch($e2942329424) {
if(R.isCont($e2942329424)) {
var $ss2942729428 = {"from":L[4042],
"go":function(anf_arg503129434) {
return $Hanf_arg1020029436(anf_arg503129434,INDENT118169,anf_arg502729421,anf_fun502829435,break_DASH_one119168,_plus55);
}};
$e2942329424.stack[R.EXN_STACKHEIGHT++] = $ss2942729428;
}
if(R.isPyretException($e2942329424)) {
$e2942329424.pyretStack.push(L[4042]);
}
throw $e2942329424;
}
var $ret2942929430 = $Hanf_arg1020029436($z2942529426,INDENT118169,anf_arg502729421,anf_fun502829435,break_DASH_one119168,_plus55);
++R.GAS;
return $ret2942929430;
};
var $Hanf_arg1020029436 = function(anf_arg503129434,INDENT118169,anf_arg502729421,anf_fun502829435,break_DASH_one119168,_plus55) {
var $z2944029441 = D;
var $f2944629447 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,anf_arg503129434):R.ffi.throwNonFunApp(L[4046],_plus55,[break_DASH_one119168,anf_arg503129434]);
};
try {
if(--R.GAS > 0) {
$z2944029441 = $f2944629447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2944629447,
"from":L[4046]});
}
} catch($e2943829439) {
if(R.isCont($e2943829439)) {
var $ss2944229443 = {"from":L[4046],
"go":function(anf_arg503229448) {
return $Hanf_arg1019929449(anf_arg503229448,INDENT118169,anf_arg502729421,anf_fun502829435,_plus55);
}};
$e2943829439.stack[R.EXN_STACKHEIGHT++] = $ss2944229443;
}
if(R.isPyretException($e2943829439)) {
$e2943829439.pyretStack.push(L[4046]);
}
throw $e2943829439;
}
var $ret2944429445 = $Hanf_arg1019929449($z2944029441,INDENT118169,anf_arg502729421,anf_fun502829435,_plus55);
++R.GAS;
return $ret2944429445;
};
var $Hanf_arg1019929449 = function(anf_arg503229448,INDENT118169,anf_arg502729421,anf_fun502829435,_plus55) {
var $z2945229453 = D;
var $f2945829459 = function(_) {
return R.isFunction(anf_fun502829435)?anf_fun502829435.app(INDENT118169,anf_arg503229448):R.ffi.throwNonFunApp(L[4047],anf_fun502829435,[INDENT118169,anf_arg503229448]);
};
try {
if(--R.GAS > 0) {
$z2945229453 = $f2945829459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2945829459,
"from":L[4047]});
}
} catch($e2945029451) {
if(R.isCont($e2945029451)) {
var $ss2945429455 = {"from":L[4047],
"go":function(anf_arg503329460) {
return $Hanf_arg1019829461(anf_arg503329460,anf_arg502729421,_plus55);
}};
$e2945029451.stack[R.EXN_STACKHEIGHT++] = $ss2945429455;
}
if(R.isPyretException($e2945029451)) {
$e2945029451.pyretStack.push(L[4047]);
}
throw $e2945029451;
}
var $ret2945629457 = $Hanf_arg1019829461($z2945229453,anf_arg502729421,_plus55);
++R.GAS;
return $ret2945629457;
};
var $Hanf_arg1019829461 = function(anf_arg503329460,anf_arg502729421,_plus55) {
var $z2946429465 = D;
var $f2947029471 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg502729421,anf_arg503329460):R.ffi.throwNonFunApp(L[1959],_plus55,[anf_arg502729421,anf_arg503329460]);
};
try {
if(--R.GAS > 0) {
$z2946429465 = $f2947029471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2947029471,
"from":L[1959]});
}
} catch($e2946229463) {
if(R.isCont($e2946229463)) {
var $ss2946629467 = {"from":L[1959],
"go":function(ann_DASH_check_DASH_temp501929472) {
return $Hann_DASH_check_DASH_temp1019729473(ann_DASH_check_DASH_temp501929472);
}};
$e2946229463.stack[R.EXN_STACKHEIGHT++] = $ss2946629467;
}
if(R.isPyretException($e2946229463)) {
$e2946229463.pyretStack.push(L[1959]);
}
throw $e2946229463;
}
var $ret2946829469 = $Hann_DASH_check_DASH_temp1019729473($z2946429465);
++R.GAS;
return $ret2946829469;
};
var $Hann_DASH_check_DASH_temp1019729473 = function(ann_DASH_check_DASH_temp501929472) {
return ann_DASH_check_DASH_temp501929472;
};
var $Hanf_arg1019610391 = function(anf_arg500510389,self62810390,_plus55,torepr65) {
var anf_arg500629484 = G(self62810390,"test",L[1951]);
var $z2947629477 = D;
var $f2948229483 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg500629484):R.ffi.throwNonFunApp(L[1951],torepr65,[anf_arg500629484]);
};
try {
if(--R.GAS > 0) {
$z2947629477 = $f2948229483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2948229483,
"from":L[1951]});
}
} catch($e2947429475) {
if(R.isCont($e2947429475)) {
var $ss2947829479 = {"from":L[1951],
"go":function(anf_arg500729485) {
return $Hanf_arg1019529486(anf_arg500729485,anf_arg500510389,self62810390,_plus55,torepr65);
}};
$e2947429475.stack[R.EXN_STACKHEIGHT++] = $ss2947829479;
}
if(R.isPyretException($e2947429475)) {
$e2947429475.pyretStack.push(L[1951]);
}
throw $e2947429475;
}
var $ret2948029481 = $Hanf_arg1019529486($z2947629477,anf_arg500510389,self62810390,_plus55,torepr65);
++R.GAS;
return $ret2948029481;
};
var $Hanf_arg1019529486 = function(anf_arg500729485,anf_arg500510389,self62810390,_plus55,torepr65) {
var $z2948929490 = D;
var $f2949529496 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg500729485):R.ffi.throwNonFunApp(L[1951],_plus55,[(", "),anf_arg500729485]);
};
try {
if(--R.GAS > 0) {
$z2948929490 = $f2949529496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2949529496,
"from":L[1951]});
}
} catch($e2948729488) {
if(R.isCont($e2948729488)) {
var $ss2949129492 = {"from":L[1951],
"go":function(anf_arg500829497) {
return $Hanf_arg1019429498(anf_arg500829497,anf_arg500510389,self62810390,_plus55,torepr65);
}};
$e2948729488.stack[R.EXN_STACKHEIGHT++] = $ss2949129492;
}
if(R.isPyretException($e2948729488)) {
$e2948729488.pyretStack.push(L[1951]);
}
throw $e2948729488;
}
var $ret2949329494 = $Hanf_arg1019429498($z2948929490,anf_arg500510389,self62810390,_plus55,torepr65);
++R.GAS;
return $ret2949329494;
};
var $Hanf_arg1019429498 = function(anf_arg500829497,anf_arg500510389,self62810390,_plus55,torepr65) {
var $z2950129502 = D;
var $f2950729508 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg500510389,anf_arg500829497):R.ffi.throwNonFunApp(L[1951],_plus55,[anf_arg500510389,anf_arg500829497]);
};
try {
if(--R.GAS > 0) {
$z2950129502 = $f2950729508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2950729508,
"from":L[1951]});
}
} catch($e2949929500) {
if(R.isCont($e2949929500)) {
var $ss2950329504 = {"from":L[1951],
"go":function(anf_arg500929509) {
return $Hanf_arg1019329510(anf_arg500929509,self62810390,_plus55,torepr65);
}};
$e2949929500.stack[R.EXN_STACKHEIGHT++] = $ss2950329504;
}
if(R.isPyretException($e2949929500)) {
$e2949929500.pyretStack.push(L[1951]);
}
throw $e2949929500;
}
var $ret2950529506 = $Hanf_arg1019329510($z2950129502,self62810390,_plus55,torepr65);
++R.GAS;
return $ret2950529506;
};
var $Hanf_arg1019329510 = function(anf_arg500929509,self62810390,_plus55,torepr65) {
var anf_arg501029521 = G(self62810390,"body",L[1951]);
var $z2951329514 = D;
var $f2951929520 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg501029521):R.ffi.throwNonFunApp(L[1951],torepr65,[anf_arg501029521]);
};
try {
if(--R.GAS > 0) {
$z2951329514 = $f2951929520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2951929520,
"from":L[1951]});
}
} catch($e2951129512) {
if(R.isCont($e2951129512)) {
var $ss2951529516 = {"from":L[1951],
"go":function(anf_arg501129522) {
return $Hanf_arg1019229523(anf_arg501129522,anf_arg500929509,_plus55);
}};
$e2951129512.stack[R.EXN_STACKHEIGHT++] = $ss2951529516;
}
if(R.isPyretException($e2951129512)) {
$e2951129512.pyretStack.push(L[1951]);
}
throw $e2951129512;
}
var $ret2951729518 = $Hanf_arg1019229523($z2951329514,anf_arg500929509,_plus55);
++R.GAS;
return $ret2951729518;
};
var $Hanf_arg1019229523 = function(anf_arg501129522,anf_arg500929509,_plus55) {
var $z2952629527 = D;
var $f2953229533 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg501129522):R.ffi.throwNonFunApp(L[1951],_plus55,[(", "),anf_arg501129522]);
};
try {
if(--R.GAS > 0) {
$z2952629527 = $f2953229533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2953229533,
"from":L[1951]});
}
} catch($e2952429525) {
if(R.isCont($e2952429525)) {
var $ss2952829529 = {"from":L[1951],
"go":function(anf_arg501229534) {
return $Hanf_arg1019129535(anf_arg501229534,anf_arg500929509,_plus55);
}};
$e2952429525.stack[R.EXN_STACKHEIGHT++] = $ss2952829529;
}
if(R.isPyretException($e2952429525)) {
$e2952429525.pyretStack.push(L[1951]);
}
throw $e2952429525;
}
var $ret2953029531 = $Hanf_arg1019129535($z2952629527,anf_arg500929509,_plus55);
++R.GAS;
return $ret2953029531;
};
var $Hanf_arg1019129535 = function(anf_arg501229534,anf_arg500929509,_plus55) {
var $z2953829539 = D;
var $f2954429545 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg500929509,anf_arg501229534):R.ffi.throwNonFunApp(L[1951],_plus55,[anf_arg500929509,anf_arg501229534]);
};
try {
if(--R.GAS > 0) {
$z2953829539 = $f2954429545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2954429545,
"from":L[1951]});
}
} catch($e2953629537) {
if(R.isCont($e2953629537)) {
var $ss2954029541 = {"from":L[1951],
"go":function(anf_arg501329546) {
return $Hanf_arg1019029547(anf_arg501329546,_plus55);
}};
$e2953629537.stack[R.EXN_STACKHEIGHT++] = $ss2954029541;
}
if(R.isPyretException($e2953629537)) {
$e2953629537.pyretStack.push(L[1951]);
}
throw $e2953629537;
}
var $ret2954229543 = $Hanf_arg1019029547($z2953829539,_plus55);
++R.GAS;
return $ret2954229543;
};
var $Hanf_arg1019029547 = function(anf_arg501329546,_plus55) {
var $z2955029551 = D;
var $f2955629557 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg501329546,(")")):R.ffi.throwNonFunApp(L[1951],_plus55,[anf_arg501329546,(")")]);
};
try {
if(--R.GAS > 0) {
$z2955029551 = $f2955629557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2955629557,
"from":L[1951]});
}
} catch($e2954829549) {
if(R.isCont($e2954829549)) {
var $ss2955229553 = {"from":L[1951],
"go":function(anf_arg501429558) {
return $Hanf_arg1018929559(anf_arg501429558,_plus55);
}};
$e2954829549.stack[R.EXN_STACKHEIGHT++] = $ss2955229553;
}
if(R.isPyretException($e2954829549)) {
$e2954829549.pyretStack.push(L[1951]);
}
throw $e2954829549;
}
var $ret2955429555 = $Hanf_arg1018929559($z2955029551,_plus55);
++R.GAS;
return $ret2955429555;
};
var $Hanf_arg1018929559 = function(anf_arg501429558,_plus55) {
var $z2956229563 = D;
var $f2956829569 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg501429558):R.ffi.throwNonFunApp(L[1951],_plus55,[("("),anf_arg501429558]);
};
try {
if(--R.GAS > 0) {
$z2956229563 = $f2956829569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2956829569,
"from":L[1951]});
}
} catch($e2956029561) {
if(R.isCont($e2956029561)) {
var $ss2956429565 = {"from":L[1951],
"go":function(anf_arg501529570) {
return $Hanf_arg1018829571(anf_arg501529570,_plus55);
}};
$e2956029561.stack[R.EXN_STACKHEIGHT++] = $ss2956429565;
}
if(R.isPyretException($e2956029561)) {
$e2956029561.pyretStack.push(L[1951]);
}
throw $e2956029561;
}
var $ret2956629567 = $Hanf_arg1018829571($z2956229563,_plus55);
++R.GAS;
return $ret2956629567;
};
var $Hanf_arg1018829571 = function(anf_arg501529570,_plus55) {
var $z2957429575 = D;
var $f2958029581 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-if-branch"),anf_arg501529570):R.ffi.throwNonFunApp(L[1951],_plus55,[("s-if-branch"),anf_arg501529570]);
};
try {
if(--R.GAS > 0) {
$z2957429575 = $f2958029581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2958029581,
"from":L[1951]});
}
} catch($e2957229573) {
if(R.isCont($e2957229573)) {
var $ss2957629577 = {"from":L[1951],
"go":function(ann_DASH_check_DASH_temp500329582) {
return $Hann_DASH_check_DASH_temp1018729583(ann_DASH_check_DASH_temp500329582);
}};
$e2957229573.stack[R.EXN_STACKHEIGHT++] = $ss2957629577;
}
if(R.isPyretException($e2957229573)) {
$e2957229573.pyretStack.push(L[1951]);
}
throw $e2957229573;
}
var $ret2957829579 = $Hann_DASH_check_DASH_temp1018729583($z2957429575);
++R.GAS;
return $ret2957829579;
};
var $Hann_DASH_check_DASH_temp1018729583 = function(ann_DASH_check_DASH_temp500329582) {
return ann_DASH_check_DASH_temp500329582;
};
var $Hcont_tail_arg1018510408 = function(cont_tail_arg500010406,if_helper499010407) {
if(--R.GAS > 0) {
$z2958429585 = R.isFunction(if_helper499010407)?if_helper499010407.app(cont_tail_arg500010406):R.ffi.throwNonFunApp(L[1951],if_helper499010407,[cont_tail_arg500010406]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper499010407)?if_helper499010407.app(cont_tail_arg500010406):R.ffi.throwNonFunApp(L[1951],if_helper499010407,[cont_tail_arg500010406]);
},
"from":L[1951]});
}
++R.GAS;
return $z2958429585;
};
var $Hcont_tail_arg1018610423 = function(cont_tail_arg499510422,if_helper499010407) {
if(--R.GAS > 0) {
$z2958629587 = R.isFunction(if_helper499010407)?if_helper499010407.app(cont_tail_arg499510422):R.ffi.throwNonFunApp(L[1951],if_helper499010407,[cont_tail_arg499510422]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper499010407)?if_helper499010407.app(cont_tail_arg499510422):R.ffi.throwNonFunApp(L[1951],if_helper499010407,[cont_tail_arg499510422]);
},
"from":L[1951]});
}
++R.GAS;
return $z2958629587;
};
var $Hann_DASH_check_DASH_temp1018410445 = function(ann_DASH_check_DASH_temp498110444) {
return ann_DASH_check_DASH_temp498110444;
};
var $Hanf_arg1018310458 = function(anf_arg498510457,_plus55,raise62) {
var $z2959029591 = D;
var $f2959629597 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg498510457):R.ffi.throwNonFunApp(L[4048],_plus55,[("No visitor field for "),anf_arg498510457]);
};
try {
if(--R.GAS > 0) {
$z2959029591 = $f2959629597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2959629597,
"from":L[4048]});
}
} catch($e2958829589) {
if(R.isCont($e2958829589)) {
var $ss2959229593 = {"from":L[4048],
"go":function(anf_arg498629598) {
return $Hanf_arg1018229599(anf_arg498629598,raise62);
}};
$e2958829589.stack[R.EXN_STACKHEIGHT++] = $ss2959229593;
}
if(R.isPyretException($e2958829589)) {
$e2958829589.pyretStack.push(L[4048]);
}
throw $e2958829589;
}
var $ret2959429595 = $Hanf_arg1018229599($z2959029591,raise62);
++R.GAS;
return $ret2959429595;
};
var $Hanf_arg1018229599 = function(anf_arg498629598,raise62) {
var $z2960229603 = D;
var $f2960829609 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg498629598):R.ffi.throwNonFunApp(L[1965],raise62,[anf_arg498629598]);
};
try {
if(--R.GAS > 0) {
$z2960229603 = $f2960829609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2960829609,
"from":L[1965]});
}
} catch($e2960029601) {
if(R.isCont($e2960029601)) {
var $ss2960429605 = {"from":L[1965],
"go":function(ann_DASH_check_DASH_temp498329610) {
return $Hann_DASH_check_DASH_temp1018129611(ann_DASH_check_DASH_temp498329610);
}};
$e2960029601.stack[R.EXN_STACKHEIGHT++] = $ss2960429605;
}
if(R.isPyretException($e2960029601)) {
$e2960029601.pyretStack.push(L[1965]);
}
throw $e2960029601;
}
var $ret2960629607 = $Hann_DASH_check_DASH_temp1018129611($z2960229603);
++R.GAS;
return $ret2960629607;
};
var $Hann_DASH_check_DASH_temp1018129611 = function(ann_DASH_check_DASH_temp498329610) {
return ann_DASH_check_DASH_temp498329610;
};
var $Hann_DASH_check_DASH_temp1018010485 = function(ann_DASH_check_DASH_temp497310484) {
return ann_DASH_check_DASH_temp497310484;
};
var $Hanf_arg1017910502 = function(anf_arg495910500,self62210501,_plus55,torepr65) {
var anf_arg496029622 = G(self62210501,"self",L[1969]);
var $z2961429615 = D;
var $f2962029621 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg496029622):R.ffi.throwNonFunApp(L[1969],torepr65,[anf_arg496029622]);
};
try {
if(--R.GAS > 0) {
$z2961429615 = $f2962029621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2962029621,
"from":L[1969]});
}
} catch($e2961229613) {
if(R.isCont($e2961229613)) {
var $ss2961629617 = {"from":L[1969],
"go":function(anf_arg496129623) {
return $Hanf_arg1017829624(anf_arg496129623,anf_arg495910500,self62210501,_plus55,torepr65);
}};
$e2961229613.stack[R.EXN_STACKHEIGHT++] = $ss2961629617;
}
if(R.isPyretException($e2961229613)) {
$e2961229613.pyretStack.push(L[1969]);
}
throw $e2961229613;
}
var $ret2961829619 = $Hanf_arg1017829624($z2961429615,anf_arg495910500,self62210501,_plus55,torepr65);
++R.GAS;
return $ret2961829619;
};
var $Hanf_arg1017829624 = function(anf_arg496129623,anf_arg495910500,self62210501,_plus55,torepr65) {
var $z2962729628 = D;
var $f2963329634 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg496129623):R.ffi.throwNonFunApp(L[1969],_plus55,[(", "),anf_arg496129623]);
};
try {
if(--R.GAS > 0) {
$z2962729628 = $f2963329634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2963329634,
"from":L[1969]});
}
} catch($e2962529626) {
if(R.isCont($e2962529626)) {
var $ss2962929630 = {"from":L[1969],
"go":function(anf_arg496229635) {
return $Hanf_arg1017729636(anf_arg496229635,anf_arg495910500,self62210501,_plus55,torepr65);
}};
$e2962529626.stack[R.EXN_STACKHEIGHT++] = $ss2962929630;
}
if(R.isPyretException($e2962529626)) {
$e2962529626.pyretStack.push(L[1969]);
}
throw $e2962529626;
}
var $ret2963129632 = $Hanf_arg1017729636($z2962729628,anf_arg495910500,self62210501,_plus55,torepr65);
++R.GAS;
return $ret2963129632;
};
var $Hanf_arg1017729636 = function(anf_arg496229635,anf_arg495910500,self62210501,_plus55,torepr65) {
var $z2963929640 = D;
var $f2964529646 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg495910500,anf_arg496229635):R.ffi.throwNonFunApp(L[1969],_plus55,[anf_arg495910500,anf_arg496229635]);
};
try {
if(--R.GAS > 0) {
$z2963929640 = $f2964529646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2964529646,
"from":L[1969]});
}
} catch($e2963729638) {
if(R.isCont($e2963729638)) {
var $ss2964129642 = {"from":L[1969],
"go":function(anf_arg496329647) {
return $Hanf_arg1017629648(anf_arg496329647,self62210501,_plus55,torepr65);
}};
$e2963729638.stack[R.EXN_STACKHEIGHT++] = $ss2964129642;
}
if(R.isPyretException($e2963729638)) {
$e2963729638.pyretStack.push(L[1969]);
}
throw $e2963729638;
}
var $ret2964329644 = $Hanf_arg1017629648($z2963929640,self62210501,_plus55,torepr65);
++R.GAS;
return $ret2964329644;
};
var $Hanf_arg1017629648 = function(anf_arg496329647,self62210501,_plus55,torepr65) {
var anf_arg496429659 = G(self62210501,"body",L[1969]);
var $z2965129652 = D;
var $f2965729658 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg496429659):R.ffi.throwNonFunApp(L[1969],torepr65,[anf_arg496429659]);
};
try {
if(--R.GAS > 0) {
$z2965129652 = $f2965729658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2965729658,
"from":L[1969]});
}
} catch($e2964929650) {
if(R.isCont($e2964929650)) {
var $ss2965329654 = {"from":L[1969],
"go":function(anf_arg496529660) {
return $Hanf_arg1017529661(anf_arg496529660,anf_arg496329647,_plus55);
}};
$e2964929650.stack[R.EXN_STACKHEIGHT++] = $ss2965329654;
}
if(R.isPyretException($e2964929650)) {
$e2964929650.pyretStack.push(L[1969]);
}
throw $e2964929650;
}
var $ret2965529656 = $Hanf_arg1017529661($z2965129652,anf_arg496329647,_plus55);
++R.GAS;
return $ret2965529656;
};
var $Hanf_arg1017529661 = function(anf_arg496529660,anf_arg496329647,_plus55) {
var $z2966429665 = D;
var $f2967029671 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg496529660):R.ffi.throwNonFunApp(L[1969],_plus55,[(", "),anf_arg496529660]);
};
try {
if(--R.GAS > 0) {
$z2966429665 = $f2967029671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2967029671,
"from":L[1969]});
}
} catch($e2966229663) {
if(R.isCont($e2966229663)) {
var $ss2966629667 = {"from":L[1969],
"go":function(anf_arg496629672) {
return $Hanf_arg1017429673(anf_arg496629672,anf_arg496329647,_plus55);
}};
$e2966229663.stack[R.EXN_STACKHEIGHT++] = $ss2966629667;
}
if(R.isPyretException($e2966229663)) {
$e2966229663.pyretStack.push(L[1969]);
}
throw $e2966229663;
}
var $ret2966829669 = $Hanf_arg1017429673($z2966429665,anf_arg496329647,_plus55);
++R.GAS;
return $ret2966829669;
};
var $Hanf_arg1017429673 = function(anf_arg496629672,anf_arg496329647,_plus55) {
var $z2967629677 = D;
var $f2968229683 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg496329647,anf_arg496629672):R.ffi.throwNonFunApp(L[1969],_plus55,[anf_arg496329647,anf_arg496629672]);
};
try {
if(--R.GAS > 0) {
$z2967629677 = $f2968229683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2968229683,
"from":L[1969]});
}
} catch($e2967429675) {
if(R.isCont($e2967429675)) {
var $ss2967829679 = {"from":L[1969],
"go":function(anf_arg496729684) {
return $Hanf_arg1017329685(anf_arg496729684,_plus55);
}};
$e2967429675.stack[R.EXN_STACKHEIGHT++] = $ss2967829679;
}
if(R.isPyretException($e2967429675)) {
$e2967429675.pyretStack.push(L[1969]);
}
throw $e2967429675;
}
var $ret2968029681 = $Hanf_arg1017329685($z2967629677,_plus55);
++R.GAS;
return $ret2968029681;
};
var $Hanf_arg1017329685 = function(anf_arg496729684,_plus55) {
var $z2968829689 = D;
var $f2969429695 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg496729684,(")")):R.ffi.throwNonFunApp(L[1969],_plus55,[anf_arg496729684,(")")]);
};
try {
if(--R.GAS > 0) {
$z2968829689 = $f2969429695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2969429695,
"from":L[1969]});
}
} catch($e2968629687) {
if(R.isCont($e2968629687)) {
var $ss2969029691 = {"from":L[1969],
"go":function(anf_arg496829696) {
return $Hanf_arg1017229697(anf_arg496829696,_plus55);
}};
$e2968629687.stack[R.EXN_STACKHEIGHT++] = $ss2969029691;
}
if(R.isPyretException($e2968629687)) {
$e2968629687.pyretStack.push(L[1969]);
}
throw $e2968629687;
}
var $ret2969229693 = $Hanf_arg1017229697($z2968829689,_plus55);
++R.GAS;
return $ret2969229693;
};
var $Hanf_arg1017229697 = function(anf_arg496829696,_plus55) {
var $z2970029701 = D;
var $f2970629707 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg496829696):R.ffi.throwNonFunApp(L[1969],_plus55,[("("),anf_arg496829696]);
};
try {
if(--R.GAS > 0) {
$z2970029701 = $f2970629707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2970629707,
"from":L[1969]});
}
} catch($e2969829699) {
if(R.isCont($e2969829699)) {
var $ss2970229703 = {"from":L[1969],
"go":function(anf_arg496929708) {
return $Hanf_arg1017129709(anf_arg496929708,_plus55);
}};
$e2969829699.stack[R.EXN_STACKHEIGHT++] = $ss2970229703;
}
if(R.isPyretException($e2969829699)) {
$e2969829699.pyretStack.push(L[1969]);
}
throw $e2969829699;
}
var $ret2970429705 = $Hanf_arg1017129709($z2970029701,_plus55);
++R.GAS;
return $ret2970429705;
};
var $Hanf_arg1017129709 = function(anf_arg496929708,_plus55) {
var $z2971229713 = D;
var $f2971829719 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-datatype-constructor"),anf_arg496929708):R.ffi.throwNonFunApp(L[1969],_plus55,[("s-datatype-constructor"),anf_arg496929708]);
};
try {
if(--R.GAS > 0) {
$z2971229713 = $f2971829719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2971829719,
"from":L[1969]});
}
} catch($e2971029711) {
if(R.isCont($e2971029711)) {
var $ss2971429715 = {"from":L[1969],
"go":function(ann_DASH_check_DASH_temp495729720) {
return $Hann_DASH_check_DASH_temp1017029721(ann_DASH_check_DASH_temp495729720);
}};
$e2971029711.stack[R.EXN_STACKHEIGHT++] = $ss2971429715;
}
if(R.isPyretException($e2971029711)) {
$e2971029711.pyretStack.push(L[1969]);
}
throw $e2971029711;
}
var $ret2971629717 = $Hann_DASH_check_DASH_temp1017029721($z2971229713);
++R.GAS;
return $ret2971629717;
};
var $Hann_DASH_check_DASH_temp1017029721 = function(ann_DASH_check_DASH_temp495729720) {
return ann_DASH_check_DASH_temp495729720;
};
var $Hcont_tail_arg1016810519 = function(cont_tail_arg495410517,if_helper494410518) {
if(--R.GAS > 0) {
$z2972229723 = R.isFunction(if_helper494410518)?if_helper494410518.app(cont_tail_arg495410517):R.ffi.throwNonFunApp(L[1969],if_helper494410518,[cont_tail_arg495410517]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper494410518)?if_helper494410518.app(cont_tail_arg495410517):R.ffi.throwNonFunApp(L[1969],if_helper494410518,[cont_tail_arg495410517]);
},
"from":L[1969]});
}
++R.GAS;
return $z2972229723;
};
var $Hcont_tail_arg1016910534 = function(cont_tail_arg494910533,if_helper494410518) {
if(--R.GAS > 0) {
$z2972429725 = R.isFunction(if_helper494410518)?if_helper494410518.app(cont_tail_arg494910533):R.ffi.throwNonFunApp(L[1969],if_helper494410518,[cont_tail_arg494910533]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper494410518)?if_helper494410518.app(cont_tail_arg494910533):R.ffi.throwNonFunApp(L[1969],if_helper494410518,[cont_tail_arg494910533]);
},
"from":L[1969]});
}
++R.GAS;
return $z2972429725;
};
var $Hann_DASH_check_DASH_temp1016710556 = function(ann_DASH_check_DASH_temp493510555) {
return ann_DASH_check_DASH_temp493510555;
};
var $Hanf_arg1016610569 = function(anf_arg493910568,_plus55,raise62) {
var $z2972829729 = D;
var $f2973429735 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg493910568):R.ffi.throwNonFunApp(L[4049],_plus55,[("No visitor field for "),anf_arg493910568]);
};
try {
if(--R.GAS > 0) {
$z2972829729 = $f2973429735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2973429735,
"from":L[4049]});
}
} catch($e2972629727) {
if(R.isCont($e2972629727)) {
var $ss2973029731 = {"from":L[4049],
"go":function(anf_arg494029736) {
return $Hanf_arg1016529737(anf_arg494029736,raise62);
}};
$e2972629727.stack[R.EXN_STACKHEIGHT++] = $ss2973029731;
}
if(R.isPyretException($e2972629727)) {
$e2972629727.pyretStack.push(L[4049]);
}
throw $e2972629727;
}
var $ret2973229733 = $Hanf_arg1016529737($z2972829729,raise62);
++R.GAS;
return $ret2973229733;
};
var $Hanf_arg1016529737 = function(anf_arg494029736,raise62) {
var $z2974029741 = D;
var $f2974629747 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg494029736):R.ffi.throwNonFunApp(L[1982],raise62,[anf_arg494029736]);
};
try {
if(--R.GAS > 0) {
$z2974029741 = $f2974629747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2974629747,
"from":L[1982]});
}
} catch($e2973829739) {
if(R.isCont($e2973829739)) {
var $ss2974229743 = {"from":L[1982],
"go":function(ann_DASH_check_DASH_temp493729748) {
return $Hann_DASH_check_DASH_temp1016429749(ann_DASH_check_DASH_temp493729748);
}};
$e2973829739.stack[R.EXN_STACKHEIGHT++] = $ss2974229743;
}
if(R.isPyretException($e2973829739)) {
$e2973829739.pyretStack.push(L[1982]);
}
throw $e2973829739;
}
var $ret2974429745 = $Hann_DASH_check_DASH_temp1016429749($z2974029741);
++R.GAS;
return $ret2974429745;
};
var $Hann_DASH_check_DASH_temp1016429749 = function(ann_DASH_check_DASH_temp493729748) {
return ann_DASH_check_DASH_temp493729748;
};
var $Hann_DASH_check_DASH_temp1016310609 = function(ann_DASH_check_DASH_temp492510608) {
return ann_DASH_check_DASH_temp492510608;
};
var $Hanf_arg1016210626 = function(anf_arg491110624,self61610625,_plus55,torepr65) {
var anf_arg491229760 = G(self61610625,"name",L[1986]);
var $z2975229753 = D;
var $f2975829759 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg491229760):R.ffi.throwNonFunApp(L[1986],torepr65,[anf_arg491229760]);
};
try {
if(--R.GAS > 0) {
$z2975229753 = $f2975829759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2975829759,
"from":L[1986]});
}
} catch($e2975029751) {
if(R.isCont($e2975029751)) {
var $ss2975429755 = {"from":L[1986],
"go":function(anf_arg491329761) {
return $Hanf_arg1016129762(anf_arg491329761,anf_arg491110624,self61610625,_plus55,torepr65);
}};
$e2975029751.stack[R.EXN_STACKHEIGHT++] = $ss2975429755;
}
if(R.isPyretException($e2975029751)) {
$e2975029751.pyretStack.push(L[1986]);
}
throw $e2975029751;
}
var $ret2975629757 = $Hanf_arg1016129762($z2975229753,anf_arg491110624,self61610625,_plus55,torepr65);
++R.GAS;
return $ret2975629757;
};
var $Hanf_arg1016129762 = function(anf_arg491329761,anf_arg491110624,self61610625,_plus55,torepr65) {
var $z2976529766 = D;
var $f2977129772 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg491329761):R.ffi.throwNonFunApp(L[1986],_plus55,[(", "),anf_arg491329761]);
};
try {
if(--R.GAS > 0) {
$z2976529766 = $f2977129772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2977129772,
"from":L[1986]});
}
} catch($e2976329764) {
if(R.isCont($e2976329764)) {
var $ss2976729768 = {"from":L[1986],
"go":function(anf_arg491429773) {
return $Hanf_arg1016029774(anf_arg491429773,anf_arg491110624,self61610625,_plus55,torepr65);
}};
$e2976329764.stack[R.EXN_STACKHEIGHT++] = $ss2976729768;
}
if(R.isPyretException($e2976329764)) {
$e2976329764.pyretStack.push(L[1986]);
}
throw $e2976329764;
}
var $ret2976929770 = $Hanf_arg1016029774($z2976529766,anf_arg491110624,self61610625,_plus55,torepr65);
++R.GAS;
return $ret2976929770;
};
var $Hanf_arg1016029774 = function(anf_arg491429773,anf_arg491110624,self61610625,_plus55,torepr65) {
var $z2977729778 = D;
var $f2978329784 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg491110624,anf_arg491429773):R.ffi.throwNonFunApp(L[1986],_plus55,[anf_arg491110624,anf_arg491429773]);
};
try {
if(--R.GAS > 0) {
$z2977729778 = $f2978329784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2978329784,
"from":L[1986]});
}
} catch($e2977529776) {
if(R.isCont($e2977529776)) {
var $ss2977929780 = {"from":L[1986],
"go":function(anf_arg491529785) {
return $Hanf_arg1015929786(anf_arg491529785,self61610625,_plus55,torepr65);
}};
$e2977529776.stack[R.EXN_STACKHEIGHT++] = $ss2977929780;
}
if(R.isPyretException($e2977529776)) {
$e2977529776.pyretStack.push(L[1986]);
}
throw $e2977529776;
}
var $ret2978129782 = $Hanf_arg1015929786($z2977729778,self61610625,_plus55,torepr65);
++R.GAS;
return $ret2978129782;
};
var $Hanf_arg1015929786 = function(anf_arg491529785,self61610625,_plus55,torepr65) {
var anf_arg491629797 = G(self61610625,"constructor",L[1986]);
var $z2978929790 = D;
var $f2979529796 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg491629797):R.ffi.throwNonFunApp(L[1986],torepr65,[anf_arg491629797]);
};
try {
if(--R.GAS > 0) {
$z2978929790 = $f2979529796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2979529796,
"from":L[1986]});
}
} catch($e2978729788) {
if(R.isCont($e2978729788)) {
var $ss2979129792 = {"from":L[1986],
"go":function(anf_arg491729798) {
return $Hanf_arg1015829799(anf_arg491729798,anf_arg491529785,_plus55);
}};
$e2978729788.stack[R.EXN_STACKHEIGHT++] = $ss2979129792;
}
if(R.isPyretException($e2978729788)) {
$e2978729788.pyretStack.push(L[1986]);
}
throw $e2978729788;
}
var $ret2979329794 = $Hanf_arg1015829799($z2978929790,anf_arg491529785,_plus55);
++R.GAS;
return $ret2979329794;
};
var $Hanf_arg1015829799 = function(anf_arg491729798,anf_arg491529785,_plus55) {
var $z2980229803 = D;
var $f2980829809 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg491729798):R.ffi.throwNonFunApp(L[1986],_plus55,[(", "),anf_arg491729798]);
};
try {
if(--R.GAS > 0) {
$z2980229803 = $f2980829809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2980829809,
"from":L[1986]});
}
} catch($e2980029801) {
if(R.isCont($e2980029801)) {
var $ss2980429805 = {"from":L[1986],
"go":function(anf_arg491829810) {
return $Hanf_arg1015729811(anf_arg491829810,anf_arg491529785,_plus55);
}};
$e2980029801.stack[R.EXN_STACKHEIGHT++] = $ss2980429805;
}
if(R.isPyretException($e2980029801)) {
$e2980029801.pyretStack.push(L[1986]);
}
throw $e2980029801;
}
var $ret2980629807 = $Hanf_arg1015729811($z2980229803,anf_arg491529785,_plus55);
++R.GAS;
return $ret2980629807;
};
var $Hanf_arg1015729811 = function(anf_arg491829810,anf_arg491529785,_plus55) {
var $z2981429815 = D;
var $f2982029821 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg491529785,anf_arg491829810):R.ffi.throwNonFunApp(L[1986],_plus55,[anf_arg491529785,anf_arg491829810]);
};
try {
if(--R.GAS > 0) {
$z2981429815 = $f2982029821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2982029821,
"from":L[1986]});
}
} catch($e2981229813) {
if(R.isCont($e2981229813)) {
var $ss2981629817 = {"from":L[1986],
"go":function(anf_arg491929822) {
return $Hanf_arg1015629823(anf_arg491929822,_plus55);
}};
$e2981229813.stack[R.EXN_STACKHEIGHT++] = $ss2981629817;
}
if(R.isPyretException($e2981229813)) {
$e2981229813.pyretStack.push(L[1986]);
}
throw $e2981229813;
}
var $ret2981829819 = $Hanf_arg1015629823($z2981429815,_plus55);
++R.GAS;
return $ret2981829819;
};
var $Hanf_arg1015629823 = function(anf_arg491929822,_plus55) {
var $z2982629827 = D;
var $f2983229833 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg491929822,(")")):R.ffi.throwNonFunApp(L[1986],_plus55,[anf_arg491929822,(")")]);
};
try {
if(--R.GAS > 0) {
$z2982629827 = $f2983229833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2983229833,
"from":L[1986]});
}
} catch($e2982429825) {
if(R.isCont($e2982429825)) {
var $ss2982829829 = {"from":L[1986],
"go":function(anf_arg492029834) {
return $Hanf_arg1015529835(anf_arg492029834,_plus55);
}};
$e2982429825.stack[R.EXN_STACKHEIGHT++] = $ss2982829829;
}
if(R.isPyretException($e2982429825)) {
$e2982429825.pyretStack.push(L[1986]);
}
throw $e2982429825;
}
var $ret2983029831 = $Hanf_arg1015529835($z2982629827,_plus55);
++R.GAS;
return $ret2983029831;
};
var $Hanf_arg1015529835 = function(anf_arg492029834,_plus55) {
var $z2983829839 = D;
var $f2984429845 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg492029834):R.ffi.throwNonFunApp(L[1986],_plus55,[("("),anf_arg492029834]);
};
try {
if(--R.GAS > 0) {
$z2983829839 = $f2984429845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2984429845,
"from":L[1986]});
}
} catch($e2983629837) {
if(R.isCont($e2983629837)) {
var $ss2984029841 = {"from":L[1986],
"go":function(anf_arg492129846) {
return $Hanf_arg1015429847(anf_arg492129846,_plus55);
}};
$e2983629837.stack[R.EXN_STACKHEIGHT++] = $ss2984029841;
}
if(R.isPyretException($e2983629837)) {
$e2983629837.pyretStack.push(L[1986]);
}
throw $e2983629837;
}
var $ret2984229843 = $Hanf_arg1015429847($z2983829839,_plus55);
++R.GAS;
return $ret2984229843;
};
var $Hanf_arg1015429847 = function(anf_arg492129846,_plus55) {
var $z2985029851 = D;
var $f2985629857 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-datatype-singleton-variant"),anf_arg492129846):R.ffi.throwNonFunApp(L[1986],_plus55,[("s-datatype-singleton-variant"),anf_arg492129846]);
};
try {
if(--R.GAS > 0) {
$z2985029851 = $f2985629857();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2985629857,
"from":L[1986]});
}
} catch($e2984829849) {
if(R.isCont($e2984829849)) {
var $ss2985229853 = {"from":L[1986],
"go":function(ann_DASH_check_DASH_temp490929858) {
return $Hann_DASH_check_DASH_temp1015329859(ann_DASH_check_DASH_temp490929858);
}};
$e2984829849.stack[R.EXN_STACKHEIGHT++] = $ss2985229853;
}
if(R.isPyretException($e2984829849)) {
$e2984829849.pyretStack.push(L[1986]);
}
throw $e2984829849;
}
var $ret2985429855 = $Hann_DASH_check_DASH_temp1015329859($z2985029851);
++R.GAS;
return $ret2985429855;
};
var $Hann_DASH_check_DASH_temp1015329859 = function(ann_DASH_check_DASH_temp490929858) {
return ann_DASH_check_DASH_temp490929858;
};
var $Hcont_tail_arg1015110643 = function(cont_tail_arg490610641,if_helper489610642) {
if(--R.GAS > 0) {
$z2986029861 = R.isFunction(if_helper489610642)?if_helper489610642.app(cont_tail_arg490610641):R.ffi.throwNonFunApp(L[1986],if_helper489610642,[cont_tail_arg490610641]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper489610642)?if_helper489610642.app(cont_tail_arg490610641):R.ffi.throwNonFunApp(L[1986],if_helper489610642,[cont_tail_arg490610641]);
},
"from":L[1986]});
}
++R.GAS;
return $z2986029861;
};
var $Hcont_tail_arg1015210658 = function(cont_tail_arg490110657,if_helper489610642) {
if(--R.GAS > 0) {
$z2986229863 = R.isFunction(if_helper489610642)?if_helper489610642.app(cont_tail_arg490110657):R.ffi.throwNonFunApp(L[1986],if_helper489610642,[cont_tail_arg490110657]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper489610642)?if_helper489610642.app(cont_tail_arg490110657):R.ffi.throwNonFunApp(L[1986],if_helper489610642,[cont_tail_arg490110657]);
},
"from":L[1986]});
}
++R.GAS;
return $z2986229863;
};
var $Hann_DASH_check_DASH_temp1015010678 = function(ann_DASH_check_DASH_temp489210677) {
return ann_DASH_check_DASH_temp489210677;
};
var $Hanf_arg1014910695 = function(anf_arg487410693,self61010694,_plus55,torepr65) {
var anf_arg487529874 = G(self61010694,"name",L[1987]);
var $z2986629867 = D;
var $f2987229873 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg487529874):R.ffi.throwNonFunApp(L[1987],torepr65,[anf_arg487529874]);
};
try {
if(--R.GAS > 0) {
$z2986629867 = $f2987229873();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2987229873,
"from":L[1987]});
}
} catch($e2986429865) {
if(R.isCont($e2986429865)) {
var $ss2986829869 = {"from":L[1987],
"go":function(anf_arg487629875) {
return $Hanf_arg1014829876(anf_arg487629875,anf_arg487410693,self61010694,_plus55,torepr65);
}};
$e2986429865.stack[R.EXN_STACKHEIGHT++] = $ss2986829869;
}
if(R.isPyretException($e2986429865)) {
$e2986429865.pyretStack.push(L[1987]);
}
throw $e2986429865;
}
var $ret2987029871 = $Hanf_arg1014829876($z2986629867,anf_arg487410693,self61010694,_plus55,torepr65);
++R.GAS;
return $ret2987029871;
};
var $Hanf_arg1014829876 = function(anf_arg487629875,anf_arg487410693,self61010694,_plus55,torepr65) {
var $z2987929880 = D;
var $f2988529886 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg487629875):R.ffi.throwNonFunApp(L[1987],_plus55,[(", "),anf_arg487629875]);
};
try {
if(--R.GAS > 0) {
$z2987929880 = $f2988529886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2988529886,
"from":L[1987]});
}
} catch($e2987729878) {
if(R.isCont($e2987729878)) {
var $ss2988129882 = {"from":L[1987],
"go":function(anf_arg487729887) {
return $Hanf_arg1014729888(anf_arg487729887,anf_arg487410693,self61010694,_plus55,torepr65);
}};
$e2987729878.stack[R.EXN_STACKHEIGHT++] = $ss2988129882;
}
if(R.isPyretException($e2987729878)) {
$e2987729878.pyretStack.push(L[1987]);
}
throw $e2987729878;
}
var $ret2988329884 = $Hanf_arg1014729888($z2987929880,anf_arg487410693,self61010694,_plus55,torepr65);
++R.GAS;
return $ret2988329884;
};
var $Hanf_arg1014729888 = function(anf_arg487729887,anf_arg487410693,self61010694,_plus55,torepr65) {
var $z2989129892 = D;
var $f2989729898 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg487410693,anf_arg487729887):R.ffi.throwNonFunApp(L[1987],_plus55,[anf_arg487410693,anf_arg487729887]);
};
try {
if(--R.GAS > 0) {
$z2989129892 = $f2989729898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2989729898,
"from":L[1987]});
}
} catch($e2988929890) {
if(R.isCont($e2988929890)) {
var $ss2989329894 = {"from":L[1987],
"go":function(anf_arg487829899) {
return $Hanf_arg1014629900(anf_arg487829899,self61010694,_plus55,torepr65);
}};
$e2988929890.stack[R.EXN_STACKHEIGHT++] = $ss2989329894;
}
if(R.isPyretException($e2988929890)) {
$e2988929890.pyretStack.push(L[1987]);
}
throw $e2988929890;
}
var $ret2989529896 = $Hanf_arg1014629900($z2989129892,self61010694,_plus55,torepr65);
++R.GAS;
return $ret2989529896;
};
var $Hanf_arg1014629900 = function(anf_arg487829899,self61010694,_plus55,torepr65) {
var anf_arg487929911 = G(self61010694,"members",L[1987]);
var $z2990329904 = D;
var $f2990929910 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg487929911):R.ffi.throwNonFunApp(L[1987],torepr65,[anf_arg487929911]);
};
try {
if(--R.GAS > 0) {
$z2990329904 = $f2990929910();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2990929910,
"from":L[1987]});
}
} catch($e2990129902) {
if(R.isCont($e2990129902)) {
var $ss2990529906 = {"from":L[1987],
"go":function(anf_arg488029912) {
return $Hanf_arg1014529913(anf_arg488029912,anf_arg487829899,self61010694,_plus55,torepr65);
}};
$e2990129902.stack[R.EXN_STACKHEIGHT++] = $ss2990529906;
}
if(R.isPyretException($e2990129902)) {
$e2990129902.pyretStack.push(L[1987]);
}
throw $e2990129902;
}
var $ret2990729908 = $Hanf_arg1014529913($z2990329904,anf_arg487829899,self61010694,_plus55,torepr65);
++R.GAS;
return $ret2990729908;
};
var $Hanf_arg1014529913 = function(anf_arg488029912,anf_arg487829899,self61010694,_plus55,torepr65) {
var $z2991629917 = D;
var $f2992229923 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg488029912):R.ffi.throwNonFunApp(L[1987],_plus55,[(", "),anf_arg488029912]);
};
try {
if(--R.GAS > 0) {
$z2991629917 = $f2992229923();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2992229923,
"from":L[1987]});
}
} catch($e2991429915) {
if(R.isCont($e2991429915)) {
var $ss2991829919 = {"from":L[1987],
"go":function(anf_arg488129924) {
return $Hanf_arg1014429925(anf_arg488129924,anf_arg487829899,self61010694,_plus55,torepr65);
}};
$e2991429915.stack[R.EXN_STACKHEIGHT++] = $ss2991829919;
}
if(R.isPyretException($e2991429915)) {
$e2991429915.pyretStack.push(L[1987]);
}
throw $e2991429915;
}
var $ret2992029921 = $Hanf_arg1014429925($z2991629917,anf_arg487829899,self61010694,_plus55,torepr65);
++R.GAS;
return $ret2992029921;
};
var $Hanf_arg1014429925 = function(anf_arg488129924,anf_arg487829899,self61010694,_plus55,torepr65) {
var $z2992829929 = D;
var $f2993429935 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg487829899,anf_arg488129924):R.ffi.throwNonFunApp(L[1987],_plus55,[anf_arg487829899,anf_arg488129924]);
};
try {
if(--R.GAS > 0) {
$z2992829929 = $f2993429935();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2993429935,
"from":L[1987]});
}
} catch($e2992629927) {
if(R.isCont($e2992629927)) {
var $ss2993029931 = {"from":L[1987],
"go":function(anf_arg488229936) {
return $Hanf_arg1014329937(anf_arg488229936,self61010694,_plus55,torepr65);
}};
$e2992629927.stack[R.EXN_STACKHEIGHT++] = $ss2993029931;
}
if(R.isPyretException($e2992629927)) {
$e2992629927.pyretStack.push(L[1987]);
}
throw $e2992629927;
}
var $ret2993229933 = $Hanf_arg1014329937($z2992829929,self61010694,_plus55,torepr65);
++R.GAS;
return $ret2993229933;
};
var $Hanf_arg1014329937 = function(anf_arg488229936,self61010694,_plus55,torepr65) {
var anf_arg488329948 = G(self61010694,"constructor",L[1987]);
var $z2994029941 = D;
var $f2994629947 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg488329948):R.ffi.throwNonFunApp(L[1987],torepr65,[anf_arg488329948]);
};
try {
if(--R.GAS > 0) {
$z2994029941 = $f2994629947();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2994629947,
"from":L[1987]});
}
} catch($e2993829939) {
if(R.isCont($e2993829939)) {
var $ss2994229943 = {"from":L[1987],
"go":function(anf_arg488429949) {
return $Hanf_arg1014229950(anf_arg488429949,anf_arg488229936,_plus55);
}};
$e2993829939.stack[R.EXN_STACKHEIGHT++] = $ss2994229943;
}
if(R.isPyretException($e2993829939)) {
$e2993829939.pyretStack.push(L[1987]);
}
throw $e2993829939;
}
var $ret2994429945 = $Hanf_arg1014229950($z2994029941,anf_arg488229936,_plus55);
++R.GAS;
return $ret2994429945;
};
var $Hanf_arg1014229950 = function(anf_arg488429949,anf_arg488229936,_plus55) {
var $z2995329954 = D;
var $f2995929960 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg488429949):R.ffi.throwNonFunApp(L[1987],_plus55,[(", "),anf_arg488429949]);
};
try {
if(--R.GAS > 0) {
$z2995329954 = $f2995929960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2995929960,
"from":L[1987]});
}
} catch($e2995129952) {
if(R.isCont($e2995129952)) {
var $ss2995529956 = {"from":L[1987],
"go":function(anf_arg488529961) {
return $Hanf_arg1014129962(anf_arg488529961,anf_arg488229936,_plus55);
}};
$e2995129952.stack[R.EXN_STACKHEIGHT++] = $ss2995529956;
}
if(R.isPyretException($e2995129952)) {
$e2995129952.pyretStack.push(L[1987]);
}
throw $e2995129952;
}
var $ret2995729958 = $Hanf_arg1014129962($z2995329954,anf_arg488229936,_plus55);
++R.GAS;
return $ret2995729958;
};
var $Hanf_arg1014129962 = function(anf_arg488529961,anf_arg488229936,_plus55) {
var $z2996529966 = D;
var $f2997129972 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg488229936,anf_arg488529961):R.ffi.throwNonFunApp(L[1987],_plus55,[anf_arg488229936,anf_arg488529961]);
};
try {
if(--R.GAS > 0) {
$z2996529966 = $f2997129972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2997129972,
"from":L[1987]});
}
} catch($e2996329964) {
if(R.isCont($e2996329964)) {
var $ss2996729968 = {"from":L[1987],
"go":function(anf_arg488629973) {
return $Hanf_arg1014029974(anf_arg488629973,_plus55);
}};
$e2996329964.stack[R.EXN_STACKHEIGHT++] = $ss2996729968;
}
if(R.isPyretException($e2996329964)) {
$e2996329964.pyretStack.push(L[1987]);
}
throw $e2996329964;
}
var $ret2996929970 = $Hanf_arg1014029974($z2996529966,_plus55);
++R.GAS;
return $ret2996929970;
};
var $Hanf_arg1014029974 = function(anf_arg488629973,_plus55) {
var $z2997729978 = D;
var $f2998329984 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg488629973,(")")):R.ffi.throwNonFunApp(L[1987],_plus55,[anf_arg488629973,(")")]);
};
try {
if(--R.GAS > 0) {
$z2997729978 = $f2998329984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2998329984,
"from":L[1987]});
}
} catch($e2997529976) {
if(R.isCont($e2997529976)) {
var $ss2997929980 = {"from":L[1987],
"go":function(anf_arg488729985) {
return $Hanf_arg1013929986(anf_arg488729985,_plus55);
}};
$e2997529976.stack[R.EXN_STACKHEIGHT++] = $ss2997929980;
}
if(R.isPyretException($e2997529976)) {
$e2997529976.pyretStack.push(L[1987]);
}
throw $e2997529976;
}
var $ret2998129982 = $Hanf_arg1013929986($z2997729978,_plus55);
++R.GAS;
return $ret2998129982;
};
var $Hanf_arg1013929986 = function(anf_arg488729985,_plus55) {
var $z2998929990 = D;
var $f2999529996 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg488729985):R.ffi.throwNonFunApp(L[1987],_plus55,[("("),anf_arg488729985]);
};
try {
if(--R.GAS > 0) {
$z2998929990 = $f2999529996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f2999529996,
"from":L[1987]});
}
} catch($e2998729988) {
if(R.isCont($e2998729988)) {
var $ss2999129992 = {"from":L[1987],
"go":function(anf_arg488829997) {
return $Hanf_arg1013829998(anf_arg488829997,_plus55);
}};
$e2998729988.stack[R.EXN_STACKHEIGHT++] = $ss2999129992;
}
if(R.isPyretException($e2998729988)) {
$e2998729988.pyretStack.push(L[1987]);
}
throw $e2998729988;
}
var $ret2999329994 = $Hanf_arg1013829998($z2998929990,_plus55);
++R.GAS;
return $ret2999329994;
};
var $Hanf_arg1013829998 = function(anf_arg488829997,_plus55) {
var $z3000130002 = D;
var $f3000730008 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-datatype-variant"),anf_arg488829997):R.ffi.throwNonFunApp(L[1987],_plus55,[("s-datatype-variant"),anf_arg488829997]);
};
try {
if(--R.GAS > 0) {
$z3000130002 = $f3000730008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3000730008,
"from":L[1987]});
}
} catch($e2999930000) {
if(R.isCont($e2999930000)) {
var $ss3000330004 = {"from":L[1987],
"go":function(ann_DASH_check_DASH_temp487230009) {
return $Hann_DASH_check_DASH_temp1013730010(ann_DASH_check_DASH_temp487230009);
}};
$e2999930000.stack[R.EXN_STACKHEIGHT++] = $ss3000330004;
}
if(R.isPyretException($e2999930000)) {
$e2999930000.pyretStack.push(L[1987]);
}
throw $e2999930000;
}
var $ret3000530006 = $Hann_DASH_check_DASH_temp1013730010($z3000130002);
++R.GAS;
return $ret3000530006;
};
var $Hann_DASH_check_DASH_temp1013730010 = function(ann_DASH_check_DASH_temp487230009) {
return ann_DASH_check_DASH_temp487230009;
};
var $Hcont_tail_arg1013510713 = function(cont_tail_arg486910711,if_helper485810712) {
if(--R.GAS > 0) {
$z3001130012 = R.isFunction(if_helper485810712)?if_helper485810712.app(cont_tail_arg486910711):R.ffi.throwNonFunApp(L[1987],if_helper485810712,[cont_tail_arg486910711]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper485810712)?if_helper485810712.app(cont_tail_arg486910711):R.ffi.throwNonFunApp(L[1987],if_helper485810712,[cont_tail_arg486910711]);
},
"from":L[1987]});
}
++R.GAS;
return $z3001130012;
};
var $Hcont_tail_arg1013610728 = function(cont_tail_arg486310727,if_helper485810712) {
if(--R.GAS > 0) {
$z3001330014 = R.isFunction(if_helper485810712)?if_helper485810712.app(cont_tail_arg486310727):R.ffi.throwNonFunApp(L[1987],if_helper485810712,[cont_tail_arg486310727]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper485810712)?if_helper485810712.app(cont_tail_arg486310727):R.ffi.throwNonFunApp(L[1987],if_helper485810712,[cont_tail_arg486310727]);
},
"from":L[1987]});
}
++R.GAS;
return $z3001330014;
};
var $Hann_DASH_check_DASH_temp1013410750 = function(ann_DASH_check_DASH_temp484910749) {
return ann_DASH_check_DASH_temp484910749;
};
var $Hanf_arg1013310763 = function(anf_arg485310762,_plus55,raise62) {
var $z3001730018 = D;
var $f3002330024 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg485310762):R.ffi.throwNonFunApp(L[4050],_plus55,[("No visitor field for "),anf_arg485310762]);
};
try {
if(--R.GAS > 0) {
$z3001730018 = $f3002330024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3002330024,
"from":L[4050]});
}
} catch($e3001530016) {
if(R.isCont($e3001530016)) {
var $ss3001930020 = {"from":L[4050],
"go":function(anf_arg485430025) {
return $Hanf_arg1013230026(anf_arg485430025,raise62);
}};
$e3001530016.stack[R.EXN_STACKHEIGHT++] = $ss3001930020;
}
if(R.isPyretException($e3001530016)) {
$e3001530016.pyretStack.push(L[4050]);
}
throw $e3001530016;
}
var $ret3002130022 = $Hanf_arg1013230026($z3001730018,raise62);
++R.GAS;
return $ret3002130022;
};
var $Hanf_arg1013230026 = function(anf_arg485430025,raise62) {
var $z3002930030 = D;
var $f3003530036 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg485430025):R.ffi.throwNonFunApp(L[2012],raise62,[anf_arg485430025]);
};
try {
if(--R.GAS > 0) {
$z3002930030 = $f3003530036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3003530036,
"from":L[2012]});
}
} catch($e3002730028) {
if(R.isCont($e3002730028)) {
var $ss3003130032 = {"from":L[2012],
"go":function(ann_DASH_check_DASH_temp485130037) {
return $Hann_DASH_check_DASH_temp1013130038(ann_DASH_check_DASH_temp485130037);
}};
$e3002730028.stack[R.EXN_STACKHEIGHT++] = $ss3003130032;
}
if(R.isPyretException($e3002730028)) {
$e3002730028.pyretStack.push(L[2012]);
}
throw $e3002730028;
}
var $ret3003330034 = $Hann_DASH_check_DASH_temp1013130038($z3002930030);
++R.GAS;
return $ret3003330034;
};
var $Hann_DASH_check_DASH_temp1013130038 = function(ann_DASH_check_DASH_temp485130037) {
return ann_DASH_check_DASH_temp485130037;
};
var $Hheader_DASH_nowith1013010806 = function(header_DASH_nowith108610804,INDENT118169,PP170,break_DASH_one119168,lists974,self108510805,str_DASH_with1831001,_plus55) {
var anf_fun481630050 = G(PP170,"group",L[4052]);
var $z3004130042 = D;
var $f3004730048 = function(_) {
return R.isFunction(_plus55)?_plus55.app(header_DASH_nowith108610804,break_DASH_one119168):R.ffi.throwNonFunApp(L[4051],_plus55,[header_DASH_nowith108610804,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3004130042 = $f3004730048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3004730048,
"from":L[4051]});
}
} catch($e3003930040) {
if(R.isCont($e3003930040)) {
var $ss3004330044 = {"from":L[4051],
"go":function(anf_arg481730049) {
return $Hanf_arg1012930051(anf_arg481730049,INDENT118169,PP170,anf_fun481630050,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,str_DASH_with1831001,_plus55);
}};
$e3003930040.stack[R.EXN_STACKHEIGHT++] = $ss3004330044;
}
if(R.isPyretException($e3003930040)) {
$e3003930040.pyretStack.push(L[4051]);
}
throw $e3003930040;
}
var $ret3004530046 = $Hanf_arg1012930051($z3004130042,INDENT118169,PP170,anf_fun481630050,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,str_DASH_with1831001,_plus55);
++R.GAS;
return $ret3004530046;
};
var $Hanf_arg1012930051 = function(anf_arg481730049,INDENT118169,PP170,anf_fun481630050,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,str_DASH_with1831001,_plus55) {
var $z3005430055 = D;
var $f3006030061 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg481730049,str_DASH_with1831001):R.ffi.throwNonFunApp(L[4051],_plus55,[anf_arg481730049,str_DASH_with1831001]);
};
try {
if(--R.GAS > 0) {
$z3005430055 = $f3006030061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3006030061,
"from":L[4051]});
}
} catch($e3005230053) {
if(R.isCont($e3005230053)) {
var $ss3005630057 = {"from":L[4051],
"go":function(anf_arg481830062) {
return $Hanf_arg1012830063(anf_arg481830062,INDENT118169,PP170,anf_fun481630050,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,_plus55);
}};
$e3005230053.stack[R.EXN_STACKHEIGHT++] = $ss3005630057;
}
if(R.isPyretException($e3005230053)) {
$e3005230053.pyretStack.push(L[4051]);
}
throw $e3005230053;
}
var $ret3005830059 = $Hanf_arg1012830063($z3005430055,INDENT118169,PP170,anf_fun481630050,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,_plus55);
++R.GAS;
return $ret3005830059;
};
var $Hanf_arg1012830063 = function(anf_arg481830062,INDENT118169,PP170,anf_fun481630050,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,_plus55) {
var $z3006630067 = D;
var $f3007230073 = function(_) {
return R.isFunction(anf_fun481630050)?anf_fun481630050.app(anf_arg481830062):R.ffi.throwNonFunApp(L[4053],anf_fun481630050,[anf_arg481830062]);
};
try {
if(--R.GAS > 0) {
$z3006630067 = $f3007230073();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3007230073,
"from":L[4053]});
}
} catch($e3006430065) {
if(R.isCont($e3006430065)) {
var $ss3006830069 = {"from":L[4053],
"go":function(header108730074) {
return $Hheader1012730075(header108730074,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,_plus55);
}};
$e3006430065.stack[R.EXN_STACKHEIGHT++] = $ss3006830069;
}
if(R.isPyretException($e3006430065)) {
$e3006430065.pyretStack.push(L[4053]);
}
throw $e3006430065;
}
var $ret3007030071 = $Hheader1012730075($z3006630067,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,_plus55);
++R.GAS;
return $ret3007030071;
};
var $Hheader1012730075 = function(header108730074,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,lists974,self108510805,_plus55) {
var anf_bracket481930104 = G(self108510805,"with-members",L[4058]);
var anf_fun482030086 = G(anf_bracket481930104,"map",L[4057]);
var anf_arg482330087 = R.makeFunction(function(m108930090) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4055],1,arguments);
}
var anf_fun482230101 = G(m108930090,"tosource",L[4056]);
var $z3009330094 = D;
var $f3009930100 = function(_) {
return R.isFunction(anf_fun482230101)?anf_fun482230101.app():R.ffi.throwNonFunApp(L[4055],anf_fun482230101,[]);
};
try {
if(--R.GAS > 0) {
$z3009330094 = $f3009930100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3009930100,
"from":L[4055]});
}
} catch($e3009130092) {
if(R.isCont($e3009130092)) {
var $ss3009530096 = {"from":L[4055],
"go":function(ann_DASH_check_DASH_temp482130102) {
return $Hann_DASH_check_DASH_temp1011830103(ann_DASH_check_DASH_temp482130102);
}};
$e3009130092.stack[R.EXN_STACKHEIGHT++] = $ss3009530096;
}
if(R.isPyretException($e3009130092)) {
$e3009130092.pyretStack.push(L[4055]);
}
throw $e3009130092;
}
var $ret3009730098 = $Hann_DASH_check_DASH_temp1011830103($z3009330094);
++R.GAS;
return $ret3009730098;
});
var $z3007830079 = D;
var $f3008430085 = function(_) {
return R.isFunction(anf_fun482030086)?anf_fun482030086.app(anf_arg482330087):R.ffi.throwNonFunApp(L[4054],anf_fun482030086,[anf_arg482330087]);
};
try {
if(--R.GAS > 0) {
$z3007830079 = $f3008430085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3008430085,
"from":L[4054]});
}
} catch($e3007630077) {
if(R.isCont($e3007630077)) {
var $ss3008030081 = {"from":L[4054],
"go":function(withs108830088) {
return $Hwiths1012630089(withs108830088,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,header108730074,lists974,_plus55);
}};
$e3007630077.stack[R.EXN_STACKHEIGHT++] = $ss3008030081;
}
if(R.isPyretException($e3007630077)) {
$e3007630077.pyretStack.push(L[4054]);
}
throw $e3007630077;
}
var $ret3008230083 = $Hwiths1012630089($z3007830079,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,header108730074,lists974,_plus55);
++R.GAS;
return $ret3008230083;
};
var $Hwiths1012630089 = function(withs108830088,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,header108730074,lists974,_plus55) {
var anf_fun482430115 = G(lists974,"is-empty",L[4060]);
var $z3010730108 = D;
var $f3011330114 = function(_) {
return R.isFunction(anf_fun482430115)?anf_fun482430115.app(withs108830088):R.ffi.throwNonFunApp(L[4059],anf_fun482430115,[withs108830088]);
};
try {
if(--R.GAS > 0) {
$z3010730108 = $f3011330114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3011330114,
"from":L[4059]});
}
} catch($e3010530106) {
if(R.isCont($e3010530106)) {
var $ss3010930110 = {"from":L[4059],
"go":function(if_DASH_60530116) {
return $Hif_DASH_1012530117(if_DASH_60530116,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,header108730074,withs108830088,_plus55);
}};
$e3010530106.stack[R.EXN_STACKHEIGHT++] = $ss3010930110;
}
if(R.isPyretException($e3010530106)) {
$e3010530106.pyretStack.push(L[4059]);
}
throw $e3010530106;
}
var $ret3011130112 = $Hif_DASH_1012530117($z3010730108,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,header108730074,withs108830088,_plus55);
++R.GAS;
return $ret3011130112;
};
var $Hif_DASH_1012530117 = function(if_DASH_60530116,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith108610804,header108730074,withs108830088,_plus55) {
var if_helper482530128 = R.makeFunction(function(if_helper_arg482630151) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4059],1,arguments);
}
var ann_DASH_check_DASH_temp481330152 = if_helper_arg482630151;
return ann_DASH_check_DASH_temp481330152;
});
var anf_if482930150 = R.isBoolean(if_DASH_60530116);
if(R.isPyretTrue(anf_if482930150)) {
if(R.isPyretTrue(if_DASH_60530116)) {
var $z3012030121 = D;
var $f3012630127 = function(_) {
return R.isFunction(if_helper482530128)?if_helper482530128.app(header_DASH_nowith108610804):R.ffi.throwNonFunApp(L[4061],if_helper482530128,[header_DASH_nowith108610804]);
};
try {
if(--R.GAS > 0) {
$z3012030121 = $f3012630127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3012630127,
"from":L[4061]});
}
} catch($e3011830119) {
if(R.isCont($e3011830119)) {
var $ss3012230123 = {"from":L[4061],
"go":function(cont_tail_app484030129) {
return $Hcont_tail_app1011930130(cont_tail_app484030129);
}};
$e3011830119.stack[R.EXN_STACKHEIGHT++] = $ss3012230123;
}
if(R.isPyretException($e3011830119)) {
$e3011830119.pyretStack.push(L[4061]);
}
throw $e3011830119;
}
var $ret3012430125 = $Hcont_tail_app1011930130($z3012030121);
++R.GAS;
return $ret3012430125;
} else {
var anf_fun483030144 = G(PP170,"group",L[4066]);
var anf_fun483130145 = G(PP170,"nest",L[4065]);
var anf_fun483230141 = G(PP170,"separate",L[4064]);
var anf_arg483330142 = G(PP170,"commabreak",L[4063]);
var $z3013330134 = D;
var $f3013930140 = function(_) {
return R.isFunction(anf_fun483230141)?anf_fun483230141.app(anf_arg483330142,withs108830088):R.ffi.throwNonFunApp(L[4062],anf_fun483230141,[anf_arg483330142,withs108830088]);
};
try {
if(--R.GAS > 0) {
$z3013330134 = $f3013930140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3013930140,
"from":L[4062]});
}
} catch($e3013130132) {
if(R.isCont($e3013130132)) {
var $ss3013530136 = {"from":L[4062],
"go":function(anf_arg483430143) {
return $Hanf_arg1012430146(anf_arg483430143,INDENT118169,anf_fun483030144,anf_fun483130145,break_DASH_one119168,header108730074,if_helper482530128,_plus55);
}};
$e3013130132.stack[R.EXN_STACKHEIGHT++] = $ss3013530136;
}
if(R.isPyretException($e3013130132)) {
$e3013130132.pyretStack.push(L[4062]);
}
throw $e3013130132;
}
var $ret3013730138 = $Hanf_arg1012430146($z3013330134,INDENT118169,anf_fun483030144,anf_fun483130145,break_DASH_one119168,header108730074,if_helper482530128,_plus55);
++R.GAS;
return $ret3013730138;
}
} else {
var cont_tail_arg482730149 = R.throwNonBooleanCondition(L[4059],("if"),if_DASH_60530116);
if(--R.GAS > 0) {
$z3014730148 = R.isFunction(if_helper482530128)?if_helper482530128.app(cont_tail_arg482730149):R.ffi.throwNonFunApp(L[4059],if_helper482530128,[cont_tail_arg482730149]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper482530128)?if_helper482530128.app(cont_tail_arg482730149):R.ffi.throwNonFunApp(L[4059],if_helper482530128,[cont_tail_arg482730149]);
},
"from":L[4059]});
}
++R.GAS;
return $z3014730148;
}
};
var $Hcont_tail_app1011930130 = function(cont_tail_app484030129) {
return cont_tail_app484030129;
};
var $Hanf_arg1012430146 = function(anf_arg483430143,INDENT118169,anf_fun483030144,anf_fun483130145,break_DASH_one119168,header108730074,if_helper482530128,_plus55) {
var $z3015530156 = D;
var $f3016130162 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,anf_arg483430143):R.ffi.throwNonFunApp(L[4067],_plus55,[break_DASH_one119168,anf_arg483430143]);
};
try {
if(--R.GAS > 0) {
$z3015530156 = $f3016130162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3016130162,
"from":L[4067]});
}
} catch($e3015330154) {
if(R.isCont($e3015330154)) {
var $ss3015730158 = {"from":L[4067],
"go":function(anf_arg483530163) {
return $Hanf_arg1012330164(anf_arg483530163,INDENT118169,anf_fun483030144,anf_fun483130145,header108730074,if_helper482530128,_plus55);
}};
$e3015330154.stack[R.EXN_STACKHEIGHT++] = $ss3015730158;
}
if(R.isPyretException($e3015330154)) {
$e3015330154.pyretStack.push(L[4067]);
}
throw $e3015330154;
}
var $ret3015930160 = $Hanf_arg1012330164($z3015530156,INDENT118169,anf_fun483030144,anf_fun483130145,header108730074,if_helper482530128,_plus55);
++R.GAS;
return $ret3015930160;
};
var $Hanf_arg1012330164 = function(anf_arg483530163,INDENT118169,anf_fun483030144,anf_fun483130145,header108730074,if_helper482530128,_plus55) {
var $z3016730168 = D;
var $f3017330174 = function(_) {
return R.isFunction(anf_fun483130145)?anf_fun483130145.app(INDENT118169,anf_arg483530163):R.ffi.throwNonFunApp(L[4068],anf_fun483130145,[INDENT118169,anf_arg483530163]);
};
try {
if(--R.GAS > 0) {
$z3016730168 = $f3017330174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3017330174,
"from":L[4068]});
}
} catch($e3016530166) {
if(R.isCont($e3016530166)) {
var $ss3016930170 = {"from":L[4068],
"go":function(anf_arg483630175) {
return $Hanf_arg1012230176(anf_arg483630175,anf_fun483030144,header108730074,if_helper482530128,_plus55);
}};
$e3016530166.stack[R.EXN_STACKHEIGHT++] = $ss3016930170;
}
if(R.isPyretException($e3016530166)) {
$e3016530166.pyretStack.push(L[4068]);
}
throw $e3016530166;
}
var $ret3017130172 = $Hanf_arg1012230176($z3016730168,anf_fun483030144,header108730074,if_helper482530128,_plus55);
++R.GAS;
return $ret3017130172;
};
var $Hanf_arg1012230176 = function(anf_arg483630175,anf_fun483030144,header108730074,if_helper482530128,_plus55) {
var $z3017930180 = D;
var $f3018530186 = function(_) {
return R.isFunction(anf_fun483030144)?anf_fun483030144.app(anf_arg483630175):R.ffi.throwNonFunApp(L[4069],anf_fun483030144,[anf_arg483630175]);
};
try {
if(--R.GAS > 0) {
$z3017930180 = $f3018530186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3018530186,
"from":L[4069]});
}
} catch($e3017730178) {
if(R.isCont($e3017730178)) {
var $ss3018130182 = {"from":L[4069],
"go":function(anf_arg483730187) {
return $Hanf_arg1012130188(anf_arg483730187,header108730074,if_helper482530128,_plus55);
}};
$e3017730178.stack[R.EXN_STACKHEIGHT++] = $ss3018130182;
}
if(R.isPyretException($e3017730178)) {
$e3017730178.pyretStack.push(L[4069]);
}
throw $e3017730178;
}
var $ret3018330184 = $Hanf_arg1012130188($z3017930180,header108730074,if_helper482530128,_plus55);
++R.GAS;
return $ret3018330184;
};
var $Hanf_arg1012130188 = function(anf_arg483730187,header108730074,if_helper482530128,_plus55) {
var $z3019130192 = D;
var $f3019730198 = function(_) {
return R.isFunction(_plus55)?_plus55.app(header108730074,anf_arg483730187):R.ffi.throwNonFunApp(L[4070],_plus55,[header108730074,anf_arg483730187]);
};
try {
if(--R.GAS > 0) {
$z3019130192 = $f3019730198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3019730198,
"from":L[4070]});
}
} catch($e3018930190) {
if(R.isCont($e3018930190)) {
var $ss3019330194 = {"from":L[4070],
"go":function(cont_tail_arg483830199) {
return $Hcont_tail_arg1012030200(cont_tail_arg483830199,if_helper482530128);
}};
$e3018930190.stack[R.EXN_STACKHEIGHT++] = $ss3019330194;
}
if(R.isPyretException($e3018930190)) {
$e3018930190.pyretStack.push(L[4070]);
}
throw $e3018930190;
}
var $ret3019530196 = $Hcont_tail_arg1012030200($z3019130192,if_helper482530128);
++R.GAS;
return $ret3019530196;
};
var $Hcont_tail_arg1012030200 = function(cont_tail_arg483830199,if_helper482530128) {
if(--R.GAS > 0) {
$z3020130202 = R.isFunction(if_helper482530128)?if_helper482530128.app(cont_tail_arg483830199):R.ffi.throwNonFunApp(L[4070],if_helper482530128,[cont_tail_arg483830199]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper482530128)?if_helper482530128.app(cont_tail_arg483830199):R.ffi.throwNonFunApp(L[4070],if_helper482530128,[cont_tail_arg483830199]);
},
"from":L[4070]});
}
++R.GAS;
return $z3020130202;
};
var $Hann_DASH_check_DASH_temp1011830103 = function(ann_DASH_check_DASH_temp482130102) {
return ann_DASH_check_DASH_temp482130102;
};
var $Hanf_arg1011710822 = function(anf_arg479910820,self60310821,_plus55,torepr65) {
var anf_arg480030213 = G(self60310821,"name",L[2016]);
var $z3020530206 = D;
var $f3021130212 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg480030213):R.ffi.throwNonFunApp(L[2016],torepr65,[anf_arg480030213]);
};
try {
if(--R.GAS > 0) {
$z3020530206 = $f3021130212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3021130212,
"from":L[2016]});
}
} catch($e3020330204) {
if(R.isCont($e3020330204)) {
var $ss3020730208 = {"from":L[2016],
"go":function(anf_arg480130214) {
return $Hanf_arg1011630215(anf_arg480130214,anf_arg479910820,self60310821,_plus55,torepr65);
}};
$e3020330204.stack[R.EXN_STACKHEIGHT++] = $ss3020730208;
}
if(R.isPyretException($e3020330204)) {
$e3020330204.pyretStack.push(L[2016]);
}
throw $e3020330204;
}
var $ret3020930210 = $Hanf_arg1011630215($z3020530206,anf_arg479910820,self60310821,_plus55,torepr65);
++R.GAS;
return $ret3020930210;
};
var $Hanf_arg1011630215 = function(anf_arg480130214,anf_arg479910820,self60310821,_plus55,torepr65) {
var $z3021830219 = D;
var $f3022430225 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg480130214):R.ffi.throwNonFunApp(L[2016],_plus55,[(", "),anf_arg480130214]);
};
try {
if(--R.GAS > 0) {
$z3021830219 = $f3022430225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3022430225,
"from":L[2016]});
}
} catch($e3021630217) {
if(R.isCont($e3021630217)) {
var $ss3022030221 = {"from":L[2016],
"go":function(anf_arg480230226) {
return $Hanf_arg1011530227(anf_arg480230226,anf_arg479910820,self60310821,_plus55,torepr65);
}};
$e3021630217.stack[R.EXN_STACKHEIGHT++] = $ss3022030221;
}
if(R.isPyretException($e3021630217)) {
$e3021630217.pyretStack.push(L[2016]);
}
throw $e3021630217;
}
var $ret3022230223 = $Hanf_arg1011530227($z3021830219,anf_arg479910820,self60310821,_plus55,torepr65);
++R.GAS;
return $ret3022230223;
};
var $Hanf_arg1011530227 = function(anf_arg480230226,anf_arg479910820,self60310821,_plus55,torepr65) {
var $z3023030231 = D;
var $f3023630237 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg479910820,anf_arg480230226):R.ffi.throwNonFunApp(L[2016],_plus55,[anf_arg479910820,anf_arg480230226]);
};
try {
if(--R.GAS > 0) {
$z3023030231 = $f3023630237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3023630237,
"from":L[2016]});
}
} catch($e3022830229) {
if(R.isCont($e3022830229)) {
var $ss3023230233 = {"from":L[2016],
"go":function(anf_arg480330238) {
return $Hanf_arg1011430239(anf_arg480330238,self60310821,_plus55,torepr65);
}};
$e3022830229.stack[R.EXN_STACKHEIGHT++] = $ss3023230233;
}
if(R.isPyretException($e3022830229)) {
$e3022830229.pyretStack.push(L[2016]);
}
throw $e3022830229;
}
var $ret3023430235 = $Hanf_arg1011430239($z3023030231,self60310821,_plus55,torepr65);
++R.GAS;
return $ret3023430235;
};
var $Hanf_arg1011430239 = function(anf_arg480330238,self60310821,_plus55,torepr65) {
var anf_arg480430250 = G(self60310821,"with-members",L[2016]);
var $z3024230243 = D;
var $f3024830249 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg480430250):R.ffi.throwNonFunApp(L[2016],torepr65,[anf_arg480430250]);
};
try {
if(--R.GAS > 0) {
$z3024230243 = $f3024830249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3024830249,
"from":L[2016]});
}
} catch($e3024030241) {
if(R.isCont($e3024030241)) {
var $ss3024430245 = {"from":L[2016],
"go":function(anf_arg480530251) {
return $Hanf_arg1011330252(anf_arg480530251,anf_arg480330238,_plus55);
}};
$e3024030241.stack[R.EXN_STACKHEIGHT++] = $ss3024430245;
}
if(R.isPyretException($e3024030241)) {
$e3024030241.pyretStack.push(L[2016]);
}
throw $e3024030241;
}
var $ret3024630247 = $Hanf_arg1011330252($z3024230243,anf_arg480330238,_plus55);
++R.GAS;
return $ret3024630247;
};
var $Hanf_arg1011330252 = function(anf_arg480530251,anf_arg480330238,_plus55) {
var $z3025530256 = D;
var $f3026130262 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg480530251):R.ffi.throwNonFunApp(L[2016],_plus55,[(", "),anf_arg480530251]);
};
try {
if(--R.GAS > 0) {
$z3025530256 = $f3026130262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3026130262,
"from":L[2016]});
}
} catch($e3025330254) {
if(R.isCont($e3025330254)) {
var $ss3025730258 = {"from":L[2016],
"go":function(anf_arg480630263) {
return $Hanf_arg1011230264(anf_arg480630263,anf_arg480330238,_plus55);
}};
$e3025330254.stack[R.EXN_STACKHEIGHT++] = $ss3025730258;
}
if(R.isPyretException($e3025330254)) {
$e3025330254.pyretStack.push(L[2016]);
}
throw $e3025330254;
}
var $ret3025930260 = $Hanf_arg1011230264($z3025530256,anf_arg480330238,_plus55);
++R.GAS;
return $ret3025930260;
};
var $Hanf_arg1011230264 = function(anf_arg480630263,anf_arg480330238,_plus55) {
var $z3026730268 = D;
var $f3027330274 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg480330238,anf_arg480630263):R.ffi.throwNonFunApp(L[2016],_plus55,[anf_arg480330238,anf_arg480630263]);
};
try {
if(--R.GAS > 0) {
$z3026730268 = $f3027330274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3027330274,
"from":L[2016]});
}
} catch($e3026530266) {
if(R.isCont($e3026530266)) {
var $ss3026930270 = {"from":L[2016],
"go":function(anf_arg480730275) {
return $Hanf_arg1011130276(anf_arg480730275,_plus55);
}};
$e3026530266.stack[R.EXN_STACKHEIGHT++] = $ss3026930270;
}
if(R.isPyretException($e3026530266)) {
$e3026530266.pyretStack.push(L[2016]);
}
throw $e3026530266;
}
var $ret3027130272 = $Hanf_arg1011130276($z3026730268,_plus55);
++R.GAS;
return $ret3027130272;
};
var $Hanf_arg1011130276 = function(anf_arg480730275,_plus55) {
var $z3027930280 = D;
var $f3028530286 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg480730275,(")")):R.ffi.throwNonFunApp(L[2016],_plus55,[anf_arg480730275,(")")]);
};
try {
if(--R.GAS > 0) {
$z3027930280 = $f3028530286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3028530286,
"from":L[2016]});
}
} catch($e3027730278) {
if(R.isCont($e3027730278)) {
var $ss3028130282 = {"from":L[2016],
"go":function(anf_arg480830287) {
return $Hanf_arg1011030288(anf_arg480830287,_plus55);
}};
$e3027730278.stack[R.EXN_STACKHEIGHT++] = $ss3028130282;
}
if(R.isPyretException($e3027730278)) {
$e3027730278.pyretStack.push(L[2016]);
}
throw $e3027730278;
}
var $ret3028330284 = $Hanf_arg1011030288($z3027930280,_plus55);
++R.GAS;
return $ret3028330284;
};
var $Hanf_arg1011030288 = function(anf_arg480830287,_plus55) {
var $z3029130292 = D;
var $f3029730298 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg480830287):R.ffi.throwNonFunApp(L[2016],_plus55,[("("),anf_arg480830287]);
};
try {
if(--R.GAS > 0) {
$z3029130292 = $f3029730298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3029730298,
"from":L[2016]});
}
} catch($e3028930290) {
if(R.isCont($e3028930290)) {
var $ss3029330294 = {"from":L[2016],
"go":function(anf_arg480930299) {
return $Hanf_arg1010930300(anf_arg480930299,_plus55);
}};
$e3028930290.stack[R.EXN_STACKHEIGHT++] = $ss3029330294;
}
if(R.isPyretException($e3028930290)) {
$e3028930290.pyretStack.push(L[2016]);
}
throw $e3028930290;
}
var $ret3029530296 = $Hanf_arg1010930300($z3029130292,_plus55);
++R.GAS;
return $ret3029530296;
};
var $Hanf_arg1010930300 = function(anf_arg480930299,_plus55) {
var $z3030330304 = D;
var $f3030930310 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-singleton-variant"),anf_arg480930299):R.ffi.throwNonFunApp(L[2016],_plus55,[("s-singleton-variant"),anf_arg480930299]);
};
try {
if(--R.GAS > 0) {
$z3030330304 = $f3030930310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3030930310,
"from":L[2016]});
}
} catch($e3030130302) {
if(R.isCont($e3030130302)) {
var $ss3030530306 = {"from":L[2016],
"go":function(ann_DASH_check_DASH_temp479730311) {
return $Hann_DASH_check_DASH_temp1010830312(ann_DASH_check_DASH_temp479730311);
}};
$e3030130302.stack[R.EXN_STACKHEIGHT++] = $ss3030530306;
}
if(R.isPyretException($e3030130302)) {
$e3030130302.pyretStack.push(L[2016]);
}
throw $e3030130302;
}
var $ret3030730308 = $Hann_DASH_check_DASH_temp1010830312($z3030330304);
++R.GAS;
return $ret3030730308;
};
var $Hann_DASH_check_DASH_temp1010830312 = function(ann_DASH_check_DASH_temp479730311) {
return ann_DASH_check_DASH_temp479730311;
};
var $Hcont_tail_arg1010610839 = function(cont_tail_arg479410837,if_helper478410838) {
if(--R.GAS > 0) {
$z3031330314 = R.isFunction(if_helper478410838)?if_helper478410838.app(cont_tail_arg479410837):R.ffi.throwNonFunApp(L[2016],if_helper478410838,[cont_tail_arg479410837]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper478410838)?if_helper478410838.app(cont_tail_arg479410837):R.ffi.throwNonFunApp(L[2016],if_helper478410838,[cont_tail_arg479410837]);
},
"from":L[2016]});
}
++R.GAS;
return $z3031330314;
};
var $Hcont_tail_arg1010710854 = function(cont_tail_arg478910853,if_helper478410838) {
if(--R.GAS > 0) {
$z3031530316 = R.isFunction(if_helper478410838)?if_helper478410838.app(cont_tail_arg478910853):R.ffi.throwNonFunApp(L[2016],if_helper478410838,[cont_tail_arg478910853]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper478410838)?if_helper478410838.app(cont_tail_arg478910853):R.ffi.throwNonFunApp(L[2016],if_helper478410838,[cont_tail_arg478910853]);
},
"from":L[2016]});
}
++R.GAS;
return $z3031530316;
};
var $Hanf_arg1010510876 = function(anf_arg474410874,INDENT118169,PP170,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55) {
var anf_fun474530334 = G(PP170,"surround-separate",L[4080]);
var anf_arg474630330 = G(PP170,"mt-doc",L[4079]);
var anf_arg474730331 = G(PP170,"lparen",L[4078]);
var anf_arg474830332 = G(PP170,"commabreak",L[4077]);
var anf_arg474930333 = G(PP170,"rparen",L[4076]);
var anf_bracket475030350 = G(self107510875,"members",L[4075]);
var anf_fun475130327 = G(anf_bracket475030350,"map",L[4074]);
var anf_arg475430328 = R.makeFunction(function(b107730336) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4072],1,arguments);
}
var anf_fun475330347 = G(b107730336,"tosource",L[4073]);
var $z3033930340 = D;
var $f3034530346 = function(_) {
return R.isFunction(anf_fun475330347)?anf_fun475330347.app():R.ffi.throwNonFunApp(L[4072],anf_fun475330347,[]);
};
try {
if(--R.GAS > 0) {
$z3033930340 = $f3034530346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3034530346,
"from":L[4072]});
}
} catch($e3033730338) {
if(R.isCont($e3033730338)) {
var $ss3034130342 = {"from":L[4072],
"go":function(ann_DASH_check_DASH_temp475230348) {
return $Hann_DASH_check_DASH_temp1008930349(ann_DASH_check_DASH_temp475230348);
}};
$e3033730338.stack[R.EXN_STACKHEIGHT++] = $ss3034130342;
}
if(R.isPyretException($e3033730338)) {
$e3033730338.pyretStack.push(L[4072]);
}
throw $e3033730338;
}
var $ret3034330344 = $Hann_DASH_check_DASH_temp1008930349($z3033930340);
++R.GAS;
return $ret3034330344;
});
var $z3031930320 = D;
var $f3032530326 = function(_) {
return R.isFunction(anf_fun475130327)?anf_fun475130327.app(anf_arg475430328):R.ffi.throwNonFunApp(L[4071],anf_fun475130327,[anf_arg475430328]);
};
try {
if(--R.GAS > 0) {
$z3031930320 = $f3032530326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3032530326,
"from":L[4071]});
}
} catch($e3031730318) {
if(R.isCont($e3031730318)) {
var $ss3032130322 = {"from":L[4071],
"go":function(anf_arg475530329) {
return $Hanf_arg1010430335(anf_arg475530329,INDENT118169,PP170,anf_arg474410874,anf_arg474630330,anf_arg474730331,anf_arg474830332,anf_arg474930333,anf_fun474530334,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55);
}};
$e3031730318.stack[R.EXN_STACKHEIGHT++] = $ss3032130322;
}
if(R.isPyretException($e3031730318)) {
$e3031730318.pyretStack.push(L[4071]);
}
throw $e3031730318;
}
var $ret3032330324 = $Hanf_arg1010430335($z3031930320,INDENT118169,PP170,anf_arg474410874,anf_arg474630330,anf_arg474730331,anf_arg474830332,anf_arg474930333,anf_fun474530334,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55);
++R.GAS;
return $ret3032330324;
};
var $Hanf_arg1010430335 = function(anf_arg475530329,INDENT118169,PP170,anf_arg474410874,anf_arg474630330,anf_arg474730331,anf_arg474830332,anf_arg474930333,anf_fun474530334,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55) {
var $z3035330354 = D;
var $f3035930360 = function(_) {
return R.isFunction(anf_fun474530334)?anf_fun474530334.app(INDENT118169,(0),anf_arg474630330,anf_arg474730331,anf_arg474830332,anf_arg474930333,anf_arg475530329):R.ffi.throwNonFunApp(L[4081],anf_fun474530334,[INDENT118169,(0),anf_arg474630330,anf_arg474730331,anf_arg474830332,anf_arg474930333,anf_arg475530329]);
};
try {
if(--R.GAS > 0) {
$z3035330354 = $f3035930360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3035930360,
"from":L[4081]});
}
} catch($e3035130352) {
if(R.isCont($e3035130352)) {
var $ss3035530356 = {"from":L[4081],
"go":function(anf_arg475630361) {
return $Hanf_arg1010330362(anf_arg475630361,INDENT118169,PP170,anf_arg474410874,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55);
}};
$e3035130352.stack[R.EXN_STACKHEIGHT++] = $ss3035530356;
}
if(R.isPyretException($e3035130352)) {
$e3035130352.pyretStack.push(L[4081]);
}
throw $e3035130352;
}
var $ret3035730358 = $Hanf_arg1010330362($z3035330354,INDENT118169,PP170,anf_arg474410874,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55);
++R.GAS;
return $ret3035730358;
};
var $Hanf_arg1010330362 = function(anf_arg475630361,INDENT118169,PP170,anf_arg474410874,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55) {
var $z3036530366 = D;
var $f3037130372 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg474410874,anf_arg475630361):R.ffi.throwNonFunApp(L[4082],_plus55,[anf_arg474410874,anf_arg475630361]);
};
try {
if(--R.GAS > 0) {
$z3036530366 = $f3037130372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3037130372,
"from":L[4082]});
}
} catch($e3036330364) {
if(R.isCont($e3036330364)) {
var $ss3036730368 = {"from":L[4082],
"go":function(header_DASH_nowith107630373) {
return $Hheader_DASH_nowith1010230374(header_DASH_nowith107630373,INDENT118169,PP170,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55);
}};
$e3036330364.stack[R.EXN_STACKHEIGHT++] = $ss3036730368;
}
if(R.isPyretException($e3036330364)) {
$e3036330364.pyretStack.push(L[4082]);
}
throw $e3036330364;
}
var $ret3036930370 = $Hheader_DASH_nowith1010230374($z3036530366,INDENT118169,PP170,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55);
++R.GAS;
return $ret3036930370;
};
var $Hheader_DASH_nowith1010230374 = function(header_DASH_nowith107630373,INDENT118169,PP170,break_DASH_one119168,lists974,self107510875,str_DASH_with1831001,_plus55) {
var anf_fun475730386 = G(PP170,"group",L[4084]);
var $z3037730378 = D;
var $f3038330384 = function(_) {
return R.isFunction(_plus55)?_plus55.app(header_DASH_nowith107630373,break_DASH_one119168):R.ffi.throwNonFunApp(L[4083],_plus55,[header_DASH_nowith107630373,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3037730378 = $f3038330384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3038330384,
"from":L[4083]});
}
} catch($e3037530376) {
if(R.isCont($e3037530376)) {
var $ss3037930380 = {"from":L[4083],
"go":function(anf_arg475830385) {
return $Hanf_arg1010130387(anf_arg475830385,INDENT118169,PP170,anf_fun475730386,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,str_DASH_with1831001,_plus55);
}};
$e3037530376.stack[R.EXN_STACKHEIGHT++] = $ss3037930380;
}
if(R.isPyretException($e3037530376)) {
$e3037530376.pyretStack.push(L[4083]);
}
throw $e3037530376;
}
var $ret3038130382 = $Hanf_arg1010130387($z3037730378,INDENT118169,PP170,anf_fun475730386,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,str_DASH_with1831001,_plus55);
++R.GAS;
return $ret3038130382;
};
var $Hanf_arg1010130387 = function(anf_arg475830385,INDENT118169,PP170,anf_fun475730386,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,str_DASH_with1831001,_plus55) {
var $z3039030391 = D;
var $f3039630397 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg475830385,str_DASH_with1831001):R.ffi.throwNonFunApp(L[4083],_plus55,[anf_arg475830385,str_DASH_with1831001]);
};
try {
if(--R.GAS > 0) {
$z3039030391 = $f3039630397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3039630397,
"from":L[4083]});
}
} catch($e3038830389) {
if(R.isCont($e3038830389)) {
var $ss3039230393 = {"from":L[4083],
"go":function(anf_arg475930398) {
return $Hanf_arg1010030399(anf_arg475930398,INDENT118169,PP170,anf_fun475730386,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,_plus55);
}};
$e3038830389.stack[R.EXN_STACKHEIGHT++] = $ss3039230393;
}
if(R.isPyretException($e3038830389)) {
$e3038830389.pyretStack.push(L[4083]);
}
throw $e3038830389;
}
var $ret3039430395 = $Hanf_arg1010030399($z3039030391,INDENT118169,PP170,anf_fun475730386,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,_plus55);
++R.GAS;
return $ret3039430395;
};
var $Hanf_arg1010030399 = function(anf_arg475930398,INDENT118169,PP170,anf_fun475730386,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,_plus55) {
var $z3040230403 = D;
var $f3040830409 = function(_) {
return R.isFunction(anf_fun475730386)?anf_fun475730386.app(anf_arg475930398):R.ffi.throwNonFunApp(L[4085],anf_fun475730386,[anf_arg475930398]);
};
try {
if(--R.GAS > 0) {
$z3040230403 = $f3040830409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3040830409,
"from":L[4085]});
}
} catch($e3040030401) {
if(R.isCont($e3040030401)) {
var $ss3040430405 = {"from":L[4085],
"go":function(header107830410) {
return $Hheader1009930411(header107830410,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,_plus55);
}};
$e3040030401.stack[R.EXN_STACKHEIGHT++] = $ss3040430405;
}
if(R.isPyretException($e3040030401)) {
$e3040030401.pyretStack.push(L[4085]);
}
throw $e3040030401;
}
var $ret3040630407 = $Hheader1009930411($z3040230403,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,_plus55);
++R.GAS;
return $ret3040630407;
};
var $Hheader1009930411 = function(header107830410,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,lists974,self107510875,_plus55) {
var anf_bracket476030440 = G(self107510875,"with-members",L[4090]);
var anf_fun476130422 = G(anf_bracket476030440,"map",L[4089]);
var anf_arg476430423 = R.makeFunction(function(m108030426) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4087],1,arguments);
}
var anf_fun476330437 = G(m108030426,"tosource",L[4088]);
var $z3042930430 = D;
var $f3043530436 = function(_) {
return R.isFunction(anf_fun476330437)?anf_fun476330437.app():R.ffi.throwNonFunApp(L[4087],anf_fun476330437,[]);
};
try {
if(--R.GAS > 0) {
$z3042930430 = $f3043530436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3043530436,
"from":L[4087]});
}
} catch($e3042730428) {
if(R.isCont($e3042730428)) {
var $ss3043130432 = {"from":L[4087],
"go":function(ann_DASH_check_DASH_temp476230438) {
return $Hann_DASH_check_DASH_temp1009030439(ann_DASH_check_DASH_temp476230438);
}};
$e3042730428.stack[R.EXN_STACKHEIGHT++] = $ss3043130432;
}
if(R.isPyretException($e3042730428)) {
$e3042730428.pyretStack.push(L[4087]);
}
throw $e3042730428;
}
var $ret3043330434 = $Hann_DASH_check_DASH_temp1009030439($z3042930430);
++R.GAS;
return $ret3043330434;
});
var $z3041430415 = D;
var $f3042030421 = function(_) {
return R.isFunction(anf_fun476130422)?anf_fun476130422.app(anf_arg476430423):R.ffi.throwNonFunApp(L[4086],anf_fun476130422,[anf_arg476430423]);
};
try {
if(--R.GAS > 0) {
$z3041430415 = $f3042030421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3042030421,
"from":L[4086]});
}
} catch($e3041230413) {
if(R.isCont($e3041230413)) {
var $ss3041630417 = {"from":L[4086],
"go":function(withs107930424) {
return $Hwiths1009830425(withs107930424,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,header107830410,lists974,_plus55);
}};
$e3041230413.stack[R.EXN_STACKHEIGHT++] = $ss3041630417;
}
if(R.isPyretException($e3041230413)) {
$e3041230413.pyretStack.push(L[4086]);
}
throw $e3041230413;
}
var $ret3041830419 = $Hwiths1009830425($z3041430415,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,header107830410,lists974,_plus55);
++R.GAS;
return $ret3041830419;
};
var $Hwiths1009830425 = function(withs107930424,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,header107830410,lists974,_plus55) {
var anf_fun476530451 = G(lists974,"is-empty",L[4092]);
var $z3044330444 = D;
var $f3044930450 = function(_) {
return R.isFunction(anf_fun476530451)?anf_fun476530451.app(withs107930424):R.ffi.throwNonFunApp(L[4091],anf_fun476530451,[withs107930424]);
};
try {
if(--R.GAS > 0) {
$z3044330444 = $f3044930450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3044930450,
"from":L[4091]});
}
} catch($e3044130442) {
if(R.isCont($e3044130442)) {
var $ss3044530446 = {"from":L[4091],
"go":function(if_DASH_59830452) {
return $Hif_DASH_1009730453(if_DASH_59830452,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,header107830410,withs107930424,_plus55);
}};
$e3044130442.stack[R.EXN_STACKHEIGHT++] = $ss3044530446;
}
if(R.isPyretException($e3044130442)) {
$e3044130442.pyretStack.push(L[4091]);
}
throw $e3044130442;
}
var $ret3044730448 = $Hif_DASH_1009730453($z3044330444,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,header107830410,withs107930424,_plus55);
++R.GAS;
return $ret3044730448;
};
var $Hif_DASH_1009730453 = function(if_DASH_59830452,INDENT118169,PP170,break_DASH_one119168,header_DASH_nowith107630373,header107830410,withs107930424,_plus55) {
var if_helper476630464 = R.makeFunction(function(if_helper_arg476730487) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4091],1,arguments);
}
var ann_DASH_check_DASH_temp474130488 = if_helper_arg476730487;
return ann_DASH_check_DASH_temp474130488;
});
var anf_if477030486 = R.isBoolean(if_DASH_59830452);
if(R.isPyretTrue(anf_if477030486)) {
if(R.isPyretTrue(if_DASH_59830452)) {
var $z3045630457 = D;
var $f3046230463 = function(_) {
return R.isFunction(if_helper476630464)?if_helper476630464.app(header_DASH_nowith107630373):R.ffi.throwNonFunApp(L[4093],if_helper476630464,[header_DASH_nowith107630373]);
};
try {
if(--R.GAS > 0) {
$z3045630457 = $f3046230463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3046230463,
"from":L[4093]});
}
} catch($e3045430455) {
if(R.isCont($e3045430455)) {
var $ss3045830459 = {"from":L[4093],
"go":function(cont_tail_app478130465) {
return $Hcont_tail_app1009130466(cont_tail_app478130465);
}};
$e3045430455.stack[R.EXN_STACKHEIGHT++] = $ss3045830459;
}
if(R.isPyretException($e3045430455)) {
$e3045430455.pyretStack.push(L[4093]);
}
throw $e3045430455;
}
var $ret3046030461 = $Hcont_tail_app1009130466($z3045630457);
++R.GAS;
return $ret3046030461;
} else {
var anf_fun477130480 = G(PP170,"group",L[4098]);
var anf_fun477230481 = G(PP170,"nest",L[4097]);
var anf_fun477330477 = G(PP170,"separate",L[4096]);
var anf_arg477430478 = G(PP170,"commabreak",L[4095]);
var $z3046930470 = D;
var $f3047530476 = function(_) {
return R.isFunction(anf_fun477330477)?anf_fun477330477.app(anf_arg477430478,withs107930424):R.ffi.throwNonFunApp(L[4094],anf_fun477330477,[anf_arg477430478,withs107930424]);
};
try {
if(--R.GAS > 0) {
$z3046930470 = $f3047530476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3047530476,
"from":L[4094]});
}
} catch($e3046730468) {
if(R.isCont($e3046730468)) {
var $ss3047130472 = {"from":L[4094],
"go":function(anf_arg477530479) {
return $Hanf_arg1009630482(anf_arg477530479,INDENT118169,anf_fun477130480,anf_fun477230481,break_DASH_one119168,header107830410,if_helper476630464,_plus55);
}};
$e3046730468.stack[R.EXN_STACKHEIGHT++] = $ss3047130472;
}
if(R.isPyretException($e3046730468)) {
$e3046730468.pyretStack.push(L[4094]);
}
throw $e3046730468;
}
var $ret3047330474 = $Hanf_arg1009630482($z3046930470,INDENT118169,anf_fun477130480,anf_fun477230481,break_DASH_one119168,header107830410,if_helper476630464,_plus55);
++R.GAS;
return $ret3047330474;
}
} else {
var cont_tail_arg476830485 = R.throwNonBooleanCondition(L[4091],("if"),if_DASH_59830452);
if(--R.GAS > 0) {
$z3048330484 = R.isFunction(if_helper476630464)?if_helper476630464.app(cont_tail_arg476830485):R.ffi.throwNonFunApp(L[4091],if_helper476630464,[cont_tail_arg476830485]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper476630464)?if_helper476630464.app(cont_tail_arg476830485):R.ffi.throwNonFunApp(L[4091],if_helper476630464,[cont_tail_arg476830485]);
},
"from":L[4091]});
}
++R.GAS;
return $z3048330484;
}
};
var $Hcont_tail_app1009130466 = function(cont_tail_app478130465) {
return cont_tail_app478130465;
};
var $Hanf_arg1009630482 = function(anf_arg477530479,INDENT118169,anf_fun477130480,anf_fun477230481,break_DASH_one119168,header107830410,if_helper476630464,_plus55) {
var $z3049130492 = D;
var $f3049730498 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,anf_arg477530479):R.ffi.throwNonFunApp(L[4099],_plus55,[break_DASH_one119168,anf_arg477530479]);
};
try {
if(--R.GAS > 0) {
$z3049130492 = $f3049730498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3049730498,
"from":L[4099]});
}
} catch($e3048930490) {
if(R.isCont($e3048930490)) {
var $ss3049330494 = {"from":L[4099],
"go":function(anf_arg477630499) {
return $Hanf_arg1009530500(anf_arg477630499,INDENT118169,anf_fun477130480,anf_fun477230481,header107830410,if_helper476630464,_plus55);
}};
$e3048930490.stack[R.EXN_STACKHEIGHT++] = $ss3049330494;
}
if(R.isPyretException($e3048930490)) {
$e3048930490.pyretStack.push(L[4099]);
}
throw $e3048930490;
}
var $ret3049530496 = $Hanf_arg1009530500($z3049130492,INDENT118169,anf_fun477130480,anf_fun477230481,header107830410,if_helper476630464,_plus55);
++R.GAS;
return $ret3049530496;
};
var $Hanf_arg1009530500 = function(anf_arg477630499,INDENT118169,anf_fun477130480,anf_fun477230481,header107830410,if_helper476630464,_plus55) {
var $z3050330504 = D;
var $f3050930510 = function(_) {
return R.isFunction(anf_fun477230481)?anf_fun477230481.app(INDENT118169,anf_arg477630499):R.ffi.throwNonFunApp(L[4100],anf_fun477230481,[INDENT118169,anf_arg477630499]);
};
try {
if(--R.GAS > 0) {
$z3050330504 = $f3050930510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3050930510,
"from":L[4100]});
}
} catch($e3050130502) {
if(R.isCont($e3050130502)) {
var $ss3050530506 = {"from":L[4100],
"go":function(anf_arg477730511) {
return $Hanf_arg1009430512(anf_arg477730511,anf_fun477130480,header107830410,if_helper476630464,_plus55);
}};
$e3050130502.stack[R.EXN_STACKHEIGHT++] = $ss3050530506;
}
if(R.isPyretException($e3050130502)) {
$e3050130502.pyretStack.push(L[4100]);
}
throw $e3050130502;
}
var $ret3050730508 = $Hanf_arg1009430512($z3050330504,anf_fun477130480,header107830410,if_helper476630464,_plus55);
++R.GAS;
return $ret3050730508;
};
var $Hanf_arg1009430512 = function(anf_arg477730511,anf_fun477130480,header107830410,if_helper476630464,_plus55) {
var $z3051530516 = D;
var $f3052130522 = function(_) {
return R.isFunction(anf_fun477130480)?anf_fun477130480.app(anf_arg477730511):R.ffi.throwNonFunApp(L[4101],anf_fun477130480,[anf_arg477730511]);
};
try {
if(--R.GAS > 0) {
$z3051530516 = $f3052130522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3052130522,
"from":L[4101]});
}
} catch($e3051330514) {
if(R.isCont($e3051330514)) {
var $ss3051730518 = {"from":L[4101],
"go":function(anf_arg477830523) {
return $Hanf_arg1009330524(anf_arg477830523,header107830410,if_helper476630464,_plus55);
}};
$e3051330514.stack[R.EXN_STACKHEIGHT++] = $ss3051730518;
}
if(R.isPyretException($e3051330514)) {
$e3051330514.pyretStack.push(L[4101]);
}
throw $e3051330514;
}
var $ret3051930520 = $Hanf_arg1009330524($z3051530516,header107830410,if_helper476630464,_plus55);
++R.GAS;
return $ret3051930520;
};
var $Hanf_arg1009330524 = function(anf_arg477830523,header107830410,if_helper476630464,_plus55) {
var $z3052730528 = D;
var $f3053330534 = function(_) {
return R.isFunction(_plus55)?_plus55.app(header107830410,anf_arg477830523):R.ffi.throwNonFunApp(L[4102],_plus55,[header107830410,anf_arg477830523]);
};
try {
if(--R.GAS > 0) {
$z3052730528 = $f3053330534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3053330534,
"from":L[4102]});
}
} catch($e3052530526) {
if(R.isCont($e3052530526)) {
var $ss3052930530 = {"from":L[4102],
"go":function(cont_tail_arg477930535) {
return $Hcont_tail_arg1009230536(cont_tail_arg477930535,if_helper476630464);
}};
$e3052530526.stack[R.EXN_STACKHEIGHT++] = $ss3052930530;
}
if(R.isPyretException($e3052530526)) {
$e3052530526.pyretStack.push(L[4102]);
}
throw $e3052530526;
}
var $ret3053130532 = $Hcont_tail_arg1009230536($z3052730528,if_helper476630464);
++R.GAS;
return $ret3053130532;
};
var $Hcont_tail_arg1009230536 = function(cont_tail_arg477930535,if_helper476630464) {
if(--R.GAS > 0) {
$z3053730538 = R.isFunction(if_helper476630464)?if_helper476630464.app(cont_tail_arg477930535):R.ffi.throwNonFunApp(L[4102],if_helper476630464,[cont_tail_arg477930535]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper476630464)?if_helper476630464.app(cont_tail_arg477930535):R.ffi.throwNonFunApp(L[4102],if_helper476630464,[cont_tail_arg477930535]);
},
"from":L[4102]});
}
++R.GAS;
return $z3053730538;
};
var $Hann_DASH_check_DASH_temp1009030439 = function(ann_DASH_check_DASH_temp476230438) {
return ann_DASH_check_DASH_temp476230438;
};
var $Hann_DASH_check_DASH_temp1008930349 = function(ann_DASH_check_DASH_temp475230348) {
return ann_DASH_check_DASH_temp475230348;
};
var $Hanf_arg1008810892 = function(anf_arg471910890,self59610891,_plus55,torepr65) {
var anf_arg472030549 = G(self59610891,"constr-loc",L[2017]);
var $z3054130542 = D;
var $f3054730548 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg472030549):R.ffi.throwNonFunApp(L[2017],torepr65,[anf_arg472030549]);
};
try {
if(--R.GAS > 0) {
$z3054130542 = $f3054730548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3054730548,
"from":L[2017]});
}
} catch($e3053930540) {
if(R.isCont($e3053930540)) {
var $ss3054330544 = {"from":L[2017],
"go":function(anf_arg472130550) {
return $Hanf_arg1008730551(anf_arg472130550,anf_arg471910890,self59610891,_plus55,torepr65);
}};
$e3053930540.stack[R.EXN_STACKHEIGHT++] = $ss3054330544;
}
if(R.isPyretException($e3053930540)) {
$e3053930540.pyretStack.push(L[2017]);
}
throw $e3053930540;
}
var $ret3054530546 = $Hanf_arg1008730551($z3054130542,anf_arg471910890,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3054530546;
};
var $Hanf_arg1008730551 = function(anf_arg472130550,anf_arg471910890,self59610891,_plus55,torepr65) {
var $z3055430555 = D;
var $f3056030561 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg472130550):R.ffi.throwNonFunApp(L[2017],_plus55,[(", "),anf_arg472130550]);
};
try {
if(--R.GAS > 0) {
$z3055430555 = $f3056030561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3056030561,
"from":L[2017]});
}
} catch($e3055230553) {
if(R.isCont($e3055230553)) {
var $ss3055630557 = {"from":L[2017],
"go":function(anf_arg472230562) {
return $Hanf_arg1008630563(anf_arg472230562,anf_arg471910890,self59610891,_plus55,torepr65);
}};
$e3055230553.stack[R.EXN_STACKHEIGHT++] = $ss3055630557;
}
if(R.isPyretException($e3055230553)) {
$e3055230553.pyretStack.push(L[2017]);
}
throw $e3055230553;
}
var $ret3055830559 = $Hanf_arg1008630563($z3055430555,anf_arg471910890,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3055830559;
};
var $Hanf_arg1008630563 = function(anf_arg472230562,anf_arg471910890,self59610891,_plus55,torepr65) {
var $z3056630567 = D;
var $f3057230573 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg471910890,anf_arg472230562):R.ffi.throwNonFunApp(L[2017],_plus55,[anf_arg471910890,anf_arg472230562]);
};
try {
if(--R.GAS > 0) {
$z3056630567 = $f3057230573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3057230573,
"from":L[2017]});
}
} catch($e3056430565) {
if(R.isCont($e3056430565)) {
var $ss3056830569 = {"from":L[2017],
"go":function(anf_arg472330574) {
return $Hanf_arg1008530575(anf_arg472330574,self59610891,_plus55,torepr65);
}};
$e3056430565.stack[R.EXN_STACKHEIGHT++] = $ss3056830569;
}
if(R.isPyretException($e3056430565)) {
$e3056430565.pyretStack.push(L[2017]);
}
throw $e3056430565;
}
var $ret3057030571 = $Hanf_arg1008530575($z3056630567,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3057030571;
};
var $Hanf_arg1008530575 = function(anf_arg472330574,self59610891,_plus55,torepr65) {
var anf_arg472430586 = G(self59610891,"name",L[2017]);
var $z3057830579 = D;
var $f3058430585 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg472430586):R.ffi.throwNonFunApp(L[2017],torepr65,[anf_arg472430586]);
};
try {
if(--R.GAS > 0) {
$z3057830579 = $f3058430585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3058430585,
"from":L[2017]});
}
} catch($e3057630577) {
if(R.isCont($e3057630577)) {
var $ss3058030581 = {"from":L[2017],
"go":function(anf_arg472530587) {
return $Hanf_arg1008430588(anf_arg472530587,anf_arg472330574,self59610891,_plus55,torepr65);
}};
$e3057630577.stack[R.EXN_STACKHEIGHT++] = $ss3058030581;
}
if(R.isPyretException($e3057630577)) {
$e3057630577.pyretStack.push(L[2017]);
}
throw $e3057630577;
}
var $ret3058230583 = $Hanf_arg1008430588($z3057830579,anf_arg472330574,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3058230583;
};
var $Hanf_arg1008430588 = function(anf_arg472530587,anf_arg472330574,self59610891,_plus55,torepr65) {
var $z3059130592 = D;
var $f3059730598 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg472530587):R.ffi.throwNonFunApp(L[2017],_plus55,[(", "),anf_arg472530587]);
};
try {
if(--R.GAS > 0) {
$z3059130592 = $f3059730598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3059730598,
"from":L[2017]});
}
} catch($e3058930590) {
if(R.isCont($e3058930590)) {
var $ss3059330594 = {"from":L[2017],
"go":function(anf_arg472630599) {
return $Hanf_arg1008330600(anf_arg472630599,anf_arg472330574,self59610891,_plus55,torepr65);
}};
$e3058930590.stack[R.EXN_STACKHEIGHT++] = $ss3059330594;
}
if(R.isPyretException($e3058930590)) {
$e3058930590.pyretStack.push(L[2017]);
}
throw $e3058930590;
}
var $ret3059530596 = $Hanf_arg1008330600($z3059130592,anf_arg472330574,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3059530596;
};
var $Hanf_arg1008330600 = function(anf_arg472630599,anf_arg472330574,self59610891,_plus55,torepr65) {
var $z3060330604 = D;
var $f3060930610 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg472330574,anf_arg472630599):R.ffi.throwNonFunApp(L[2017],_plus55,[anf_arg472330574,anf_arg472630599]);
};
try {
if(--R.GAS > 0) {
$z3060330604 = $f3060930610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3060930610,
"from":L[2017]});
}
} catch($e3060130602) {
if(R.isCont($e3060130602)) {
var $ss3060530606 = {"from":L[2017],
"go":function(anf_arg472730611) {
return $Hanf_arg1008230612(anf_arg472730611,self59610891,_plus55,torepr65);
}};
$e3060130602.stack[R.EXN_STACKHEIGHT++] = $ss3060530606;
}
if(R.isPyretException($e3060130602)) {
$e3060130602.pyretStack.push(L[2017]);
}
throw $e3060130602;
}
var $ret3060730608 = $Hanf_arg1008230612($z3060330604,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3060730608;
};
var $Hanf_arg1008230612 = function(anf_arg472730611,self59610891,_plus55,torepr65) {
var anf_arg472830623 = G(self59610891,"members",L[2017]);
var $z3061530616 = D;
var $f3062130622 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg472830623):R.ffi.throwNonFunApp(L[2017],torepr65,[anf_arg472830623]);
};
try {
if(--R.GAS > 0) {
$z3061530616 = $f3062130622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3062130622,
"from":L[2017]});
}
} catch($e3061330614) {
if(R.isCont($e3061330614)) {
var $ss3061730618 = {"from":L[2017],
"go":function(anf_arg472930624) {
return $Hanf_arg1008130625(anf_arg472930624,anf_arg472730611,self59610891,_plus55,torepr65);
}};
$e3061330614.stack[R.EXN_STACKHEIGHT++] = $ss3061730618;
}
if(R.isPyretException($e3061330614)) {
$e3061330614.pyretStack.push(L[2017]);
}
throw $e3061330614;
}
var $ret3061930620 = $Hanf_arg1008130625($z3061530616,anf_arg472730611,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3061930620;
};
var $Hanf_arg1008130625 = function(anf_arg472930624,anf_arg472730611,self59610891,_plus55,torepr65) {
var $z3062830629 = D;
var $f3063430635 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg472930624):R.ffi.throwNonFunApp(L[2017],_plus55,[(", "),anf_arg472930624]);
};
try {
if(--R.GAS > 0) {
$z3062830629 = $f3063430635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3063430635,
"from":L[2017]});
}
} catch($e3062630627) {
if(R.isCont($e3062630627)) {
var $ss3063030631 = {"from":L[2017],
"go":function(anf_arg473030636) {
return $Hanf_arg1008030637(anf_arg473030636,anf_arg472730611,self59610891,_plus55,torepr65);
}};
$e3062630627.stack[R.EXN_STACKHEIGHT++] = $ss3063030631;
}
if(R.isPyretException($e3062630627)) {
$e3062630627.pyretStack.push(L[2017]);
}
throw $e3062630627;
}
var $ret3063230633 = $Hanf_arg1008030637($z3062830629,anf_arg472730611,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3063230633;
};
var $Hanf_arg1008030637 = function(anf_arg473030636,anf_arg472730611,self59610891,_plus55,torepr65) {
var $z3064030641 = D;
var $f3064630647 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg472730611,anf_arg473030636):R.ffi.throwNonFunApp(L[2017],_plus55,[anf_arg472730611,anf_arg473030636]);
};
try {
if(--R.GAS > 0) {
$z3064030641 = $f3064630647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3064630647,
"from":L[2017]});
}
} catch($e3063830639) {
if(R.isCont($e3063830639)) {
var $ss3064230643 = {"from":L[2017],
"go":function(anf_arg473130648) {
return $Hanf_arg1007930649(anf_arg473130648,self59610891,_plus55,torepr65);
}};
$e3063830639.stack[R.EXN_STACKHEIGHT++] = $ss3064230643;
}
if(R.isPyretException($e3063830639)) {
$e3063830639.pyretStack.push(L[2017]);
}
throw $e3063830639;
}
var $ret3064430645 = $Hanf_arg1007930649($z3064030641,self59610891,_plus55,torepr65);
++R.GAS;
return $ret3064430645;
};
var $Hanf_arg1007930649 = function(anf_arg473130648,self59610891,_plus55,torepr65) {
var anf_arg473230660 = G(self59610891,"with-members",L[2017]);
var $z3065230653 = D;
var $f3065830659 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg473230660):R.ffi.throwNonFunApp(L[2017],torepr65,[anf_arg473230660]);
};
try {
if(--R.GAS > 0) {
$z3065230653 = $f3065830659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3065830659,
"from":L[2017]});
}
} catch($e3065030651) {
if(R.isCont($e3065030651)) {
var $ss3065430655 = {"from":L[2017],
"go":function(anf_arg473330661) {
return $Hanf_arg1007830662(anf_arg473330661,anf_arg473130648,_plus55);
}};
$e3065030651.stack[R.EXN_STACKHEIGHT++] = $ss3065430655;
}
if(R.isPyretException($e3065030651)) {
$e3065030651.pyretStack.push(L[2017]);
}
throw $e3065030651;
}
var $ret3065630657 = $Hanf_arg1007830662($z3065230653,anf_arg473130648,_plus55);
++R.GAS;
return $ret3065630657;
};
var $Hanf_arg1007830662 = function(anf_arg473330661,anf_arg473130648,_plus55) {
var $z3066530666 = D;
var $f3067130672 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg473330661):R.ffi.throwNonFunApp(L[2017],_plus55,[(", "),anf_arg473330661]);
};
try {
if(--R.GAS > 0) {
$z3066530666 = $f3067130672();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3067130672,
"from":L[2017]});
}
} catch($e3066330664) {
if(R.isCont($e3066330664)) {
var $ss3066730668 = {"from":L[2017],
"go":function(anf_arg473430673) {
return $Hanf_arg1007730674(anf_arg473430673,anf_arg473130648,_plus55);
}};
$e3066330664.stack[R.EXN_STACKHEIGHT++] = $ss3066730668;
}
if(R.isPyretException($e3066330664)) {
$e3066330664.pyretStack.push(L[2017]);
}
throw $e3066330664;
}
var $ret3066930670 = $Hanf_arg1007730674($z3066530666,anf_arg473130648,_plus55);
++R.GAS;
return $ret3066930670;
};
var $Hanf_arg1007730674 = function(anf_arg473430673,anf_arg473130648,_plus55) {
var $z3067730678 = D;
var $f3068330684 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg473130648,anf_arg473430673):R.ffi.throwNonFunApp(L[2017],_plus55,[anf_arg473130648,anf_arg473430673]);
};
try {
if(--R.GAS > 0) {
$z3067730678 = $f3068330684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3068330684,
"from":L[2017]});
}
} catch($e3067530676) {
if(R.isCont($e3067530676)) {
var $ss3067930680 = {"from":L[2017],
"go":function(anf_arg473530685) {
return $Hanf_arg1007630686(anf_arg473530685,_plus55);
}};
$e3067530676.stack[R.EXN_STACKHEIGHT++] = $ss3067930680;
}
if(R.isPyretException($e3067530676)) {
$e3067530676.pyretStack.push(L[2017]);
}
throw $e3067530676;
}
var $ret3068130682 = $Hanf_arg1007630686($z3067730678,_plus55);
++R.GAS;
return $ret3068130682;
};
var $Hanf_arg1007630686 = function(anf_arg473530685,_plus55) {
var $z3068930690 = D;
var $f3069530696 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg473530685,(")")):R.ffi.throwNonFunApp(L[2017],_plus55,[anf_arg473530685,(")")]);
};
try {
if(--R.GAS > 0) {
$z3068930690 = $f3069530696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3069530696,
"from":L[2017]});
}
} catch($e3068730688) {
if(R.isCont($e3068730688)) {
var $ss3069130692 = {"from":L[2017],
"go":function(anf_arg473630697) {
return $Hanf_arg1007530698(anf_arg473630697,_plus55);
}};
$e3068730688.stack[R.EXN_STACKHEIGHT++] = $ss3069130692;
}
if(R.isPyretException($e3068730688)) {
$e3068730688.pyretStack.push(L[2017]);
}
throw $e3068730688;
}
var $ret3069330694 = $Hanf_arg1007530698($z3068930690,_plus55);
++R.GAS;
return $ret3069330694;
};
var $Hanf_arg1007530698 = function(anf_arg473630697,_plus55) {
var $z3070130702 = D;
var $f3070730708 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg473630697):R.ffi.throwNonFunApp(L[2017],_plus55,[("("),anf_arg473630697]);
};
try {
if(--R.GAS > 0) {
$z3070130702 = $f3070730708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3070730708,
"from":L[2017]});
}
} catch($e3069930700) {
if(R.isCont($e3069930700)) {
var $ss3070330704 = {"from":L[2017],
"go":function(anf_arg473730709) {
return $Hanf_arg1007430710(anf_arg473730709,_plus55);
}};
$e3069930700.stack[R.EXN_STACKHEIGHT++] = $ss3070330704;
}
if(R.isPyretException($e3069930700)) {
$e3069930700.pyretStack.push(L[2017]);
}
throw $e3069930700;
}
var $ret3070530706 = $Hanf_arg1007430710($z3070130702,_plus55);
++R.GAS;
return $ret3070530706;
};
var $Hanf_arg1007430710 = function(anf_arg473730709,_plus55) {
var $z3071330714 = D;
var $f3071930720 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-variant"),anf_arg473730709):R.ffi.throwNonFunApp(L[2017],_plus55,[("s-variant"),anf_arg473730709]);
};
try {
if(--R.GAS > 0) {
$z3071330714 = $f3071930720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3071930720,
"from":L[2017]});
}
} catch($e3071130712) {
if(R.isCont($e3071130712)) {
var $ss3071530716 = {"from":L[2017],
"go":function(ann_DASH_check_DASH_temp471730721) {
return $Hann_DASH_check_DASH_temp1007330722(ann_DASH_check_DASH_temp471730721);
}};
$e3071130712.stack[R.EXN_STACKHEIGHT++] = $ss3071530716;
}
if(R.isPyretException($e3071130712)) {
$e3071130712.pyretStack.push(L[2017]);
}
throw $e3071130712;
}
var $ret3071730718 = $Hann_DASH_check_DASH_temp1007330722($z3071330714);
++R.GAS;
return $ret3071730718;
};
var $Hann_DASH_check_DASH_temp1007330722 = function(ann_DASH_check_DASH_temp471730721) {
return ann_DASH_check_DASH_temp471730721;
};
var $Hcont_tail_arg1007110911 = function(cont_tail_arg471410909,if_helper470210910) {
if(--R.GAS > 0) {
$z3072330724 = R.isFunction(if_helper470210910)?if_helper470210910.app(cont_tail_arg471410909):R.ffi.throwNonFunApp(L[2017],if_helper470210910,[cont_tail_arg471410909]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper470210910)?if_helper470210910.app(cont_tail_arg471410909):R.ffi.throwNonFunApp(L[2017],if_helper470210910,[cont_tail_arg471410909]);
},
"from":L[2017]});
}
++R.GAS;
return $z3072330724;
};
var $Hcont_tail_arg1007210926 = function(cont_tail_arg470710925,if_helper470210910) {
if(--R.GAS > 0) {
$z3072530726 = R.isFunction(if_helper470210910)?if_helper470210910.app(cont_tail_arg470710925):R.ffi.throwNonFunApp(L[2017],if_helper470210910,[cont_tail_arg470710925]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper470210910)?if_helper470210910.app(cont_tail_arg470710925):R.ffi.throwNonFunApp(L[2017],if_helper470210910,[cont_tail_arg470710925]);
},
"from":L[2017]});
}
++R.GAS;
return $z3072530726;
};
var $Hann_DASH_check_DASH_temp1007010948 = function(ann_DASH_check_DASH_temp469310947) {
return ann_DASH_check_DASH_temp469310947;
};
var $Hanf_arg1006910961 = function(anf_arg469710960,_plus55,raise62) {
var $z3072930730 = D;
var $f3073530736 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg469710960):R.ffi.throwNonFunApp(L[4103],_plus55,[("No visitor field for "),anf_arg469710960]);
};
try {
if(--R.GAS > 0) {
$z3072930730 = $f3073530736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3073530736,
"from":L[4103]});
}
} catch($e3072730728) {
if(R.isCont($e3072730728)) {
var $ss3073130732 = {"from":L[4103],
"go":function(anf_arg469830737) {
return $Hanf_arg1006830738(anf_arg469830737,raise62);
}};
$e3072730728.stack[R.EXN_STACKHEIGHT++] = $ss3073130732;
}
if(R.isPyretException($e3072730728)) {
$e3072730728.pyretStack.push(L[4103]);
}
throw $e3072730728;
}
var $ret3073330734 = $Hanf_arg1006830738($z3072930730,raise62);
++R.GAS;
return $ret3073330734;
};
var $Hanf_arg1006830738 = function(anf_arg469830737,raise62) {
var $z3074130742 = D;
var $f3074730748 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg469830737):R.ffi.throwNonFunApp(L[2048],raise62,[anf_arg469830737]);
};
try {
if(--R.GAS > 0) {
$z3074130742 = $f3074730748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3074730748,
"from":L[2048]});
}
} catch($e3073930740) {
if(R.isCont($e3073930740)) {
var $ss3074330744 = {"from":L[2048],
"go":function(ann_DASH_check_DASH_temp469530749) {
return $Hann_DASH_check_DASH_temp1006730750(ann_DASH_check_DASH_temp469530749);
}};
$e3073930740.stack[R.EXN_STACKHEIGHT++] = $ss3074330744;
}
if(R.isPyretException($e3073930740)) {
$e3073930740.pyretStack.push(L[2048]);
}
throw $e3073930740;
}
var $ret3074530746 = $Hann_DASH_check_DASH_temp1006730750($z3074130742);
++R.GAS;
return $ret3074530746;
};
var $Hann_DASH_check_DASH_temp1006730750 = function(ann_DASH_check_DASH_temp469530749) {
return ann_DASH_check_DASH_temp469530749;
};
var $Hanf_arg1006610989 = function(anf_arg468310987,self106610988,_plus55) {
var anf_bracket468430764 = G(self106610988,"bind",L[4106]);
var anf_fun468530761 = G(anf_bracket468430764,"tosource",L[4105]);
var $z3075330754 = D;
var $f3075930760 = function(_) {
return R.isFunction(anf_fun468530761)?anf_fun468530761.app():R.ffi.throwNonFunApp(L[4104],anf_fun468530761,[]);
};
try {
if(--R.GAS > 0) {
$z3075330754 = $f3075930760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3075930760,
"from":L[4104]});
}
} catch($e3075130752) {
if(R.isCont($e3075130752)) {
var $ss3075530756 = {"from":L[4104],
"go":function(anf_arg468630762) {
return $Hanf_arg1006530763(anf_arg468630762,anf_arg468310987,_plus55);
}};
$e3075130752.stack[R.EXN_STACKHEIGHT++] = $ss3075530756;
}
if(R.isPyretException($e3075130752)) {
$e3075130752.pyretStack.push(L[4104]);
}
throw $e3075130752;
}
var $ret3075730758 = $Hanf_arg1006530763($z3075330754,anf_arg468310987,_plus55);
++R.GAS;
return $ret3075730758;
};
var $Hanf_arg1006530763 = function(anf_arg468630762,anf_arg468310987,_plus55) {
var $z3076730768 = D;
var $f3077330774 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg468310987,anf_arg468630762):R.ffi.throwNonFunApp(L[2061],_plus55,[anf_arg468310987,anf_arg468630762]);
};
try {
if(--R.GAS > 0) {
$z3076730768 = $f3077330774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3077330774,
"from":L[2061]});
}
} catch($e3076530766) {
if(R.isCont($e3076530766)) {
var $ss3076930770 = {"from":L[2061],
"go":function(ann_DASH_check_DASH_temp468030775) {
return $Hann_DASH_check_DASH_temp1006430776(ann_DASH_check_DASH_temp468030775);
}};
$e3076530766.stack[R.EXN_STACKHEIGHT++] = $ss3076930770;
}
if(R.isPyretException($e3076530766)) {
$e3076530766.pyretStack.push(L[2061]);
}
throw $e3076530766;
}
var $ret3077130772 = $Hann_DASH_check_DASH_temp1006430776($z3076730768);
++R.GAS;
return $ret3077130772;
};
var $Hann_DASH_check_DASH_temp1006430776 = function(ann_DASH_check_DASH_temp468030775) {
return ann_DASH_check_DASH_temp468030775;
};
var $Hanf_arg1006311006 = function(anf_arg466611004,self59011005,_plus55,torepr65) {
var anf_arg466730787 = G(self59011005,"member-type",L[2052]);
var $z3077930780 = D;
var $f3078530786 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg466730787):R.ffi.throwNonFunApp(L[2052],torepr65,[anf_arg466730787]);
};
try {
if(--R.GAS > 0) {
$z3077930780 = $f3078530786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3078530786,
"from":L[2052]});
}
} catch($e3077730778) {
if(R.isCont($e3077730778)) {
var $ss3078130782 = {"from":L[2052],
"go":function(anf_arg466830788) {
return $Hanf_arg1006230789(anf_arg466830788,anf_arg466611004,self59011005,_plus55,torepr65);
}};
$e3077730778.stack[R.EXN_STACKHEIGHT++] = $ss3078130782;
}
if(R.isPyretException($e3077730778)) {
$e3077730778.pyretStack.push(L[2052]);
}
throw $e3077730778;
}
var $ret3078330784 = $Hanf_arg1006230789($z3077930780,anf_arg466611004,self59011005,_plus55,torepr65);
++R.GAS;
return $ret3078330784;
};
var $Hanf_arg1006230789 = function(anf_arg466830788,anf_arg466611004,self59011005,_plus55,torepr65) {
var $z3079230793 = D;
var $f3079830799 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg466830788):R.ffi.throwNonFunApp(L[2052],_plus55,[(", "),anf_arg466830788]);
};
try {
if(--R.GAS > 0) {
$z3079230793 = $f3079830799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3079830799,
"from":L[2052]});
}
} catch($e3079030791) {
if(R.isCont($e3079030791)) {
var $ss3079430795 = {"from":L[2052],
"go":function(anf_arg466930800) {
return $Hanf_arg1006130801(anf_arg466930800,anf_arg466611004,self59011005,_plus55,torepr65);
}};
$e3079030791.stack[R.EXN_STACKHEIGHT++] = $ss3079430795;
}
if(R.isPyretException($e3079030791)) {
$e3079030791.pyretStack.push(L[2052]);
}
throw $e3079030791;
}
var $ret3079630797 = $Hanf_arg1006130801($z3079230793,anf_arg466611004,self59011005,_plus55,torepr65);
++R.GAS;
return $ret3079630797;
};
var $Hanf_arg1006130801 = function(anf_arg466930800,anf_arg466611004,self59011005,_plus55,torepr65) {
var $z3080430805 = D;
var $f3081030811 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg466611004,anf_arg466930800):R.ffi.throwNonFunApp(L[2052],_plus55,[anf_arg466611004,anf_arg466930800]);
};
try {
if(--R.GAS > 0) {
$z3080430805 = $f3081030811();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3081030811,
"from":L[2052]});
}
} catch($e3080230803) {
if(R.isCont($e3080230803)) {
var $ss3080630807 = {"from":L[2052],
"go":function(anf_arg467030812) {
return $Hanf_arg1006030813(anf_arg467030812,self59011005,_plus55,torepr65);
}};
$e3080230803.stack[R.EXN_STACKHEIGHT++] = $ss3080630807;
}
if(R.isPyretException($e3080230803)) {
$e3080230803.pyretStack.push(L[2052]);
}
throw $e3080230803;
}
var $ret3080830809 = $Hanf_arg1006030813($z3080430805,self59011005,_plus55,torepr65);
++R.GAS;
return $ret3080830809;
};
var $Hanf_arg1006030813 = function(anf_arg467030812,self59011005,_plus55,torepr65) {
var anf_arg467130824 = G(self59011005,"bind",L[2052]);
var $z3081630817 = D;
var $f3082230823 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg467130824):R.ffi.throwNonFunApp(L[2052],torepr65,[anf_arg467130824]);
};
try {
if(--R.GAS > 0) {
$z3081630817 = $f3082230823();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3082230823,
"from":L[2052]});
}
} catch($e3081430815) {
if(R.isCont($e3081430815)) {
var $ss3081830819 = {"from":L[2052],
"go":function(anf_arg467230825) {
return $Hanf_arg1005930826(anf_arg467230825,anf_arg467030812,_plus55);
}};
$e3081430815.stack[R.EXN_STACKHEIGHT++] = $ss3081830819;
}
if(R.isPyretException($e3081430815)) {
$e3081430815.pyretStack.push(L[2052]);
}
throw $e3081430815;
}
var $ret3082030821 = $Hanf_arg1005930826($z3081630817,anf_arg467030812,_plus55);
++R.GAS;
return $ret3082030821;
};
var $Hanf_arg1005930826 = function(anf_arg467230825,anf_arg467030812,_plus55) {
var $z3082930830 = D;
var $f3083530836 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg467230825):R.ffi.throwNonFunApp(L[2052],_plus55,[(", "),anf_arg467230825]);
};
try {
if(--R.GAS > 0) {
$z3082930830 = $f3083530836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3083530836,
"from":L[2052]});
}
} catch($e3082730828) {
if(R.isCont($e3082730828)) {
var $ss3083130832 = {"from":L[2052],
"go":function(anf_arg467330837) {
return $Hanf_arg1005830838(anf_arg467330837,anf_arg467030812,_plus55);
}};
$e3082730828.stack[R.EXN_STACKHEIGHT++] = $ss3083130832;
}
if(R.isPyretException($e3082730828)) {
$e3082730828.pyretStack.push(L[2052]);
}
throw $e3082730828;
}
var $ret3083330834 = $Hanf_arg1005830838($z3082930830,anf_arg467030812,_plus55);
++R.GAS;
return $ret3083330834;
};
var $Hanf_arg1005830838 = function(anf_arg467330837,anf_arg467030812,_plus55) {
var $z3084130842 = D;
var $f3084730848 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg467030812,anf_arg467330837):R.ffi.throwNonFunApp(L[2052],_plus55,[anf_arg467030812,anf_arg467330837]);
};
try {
if(--R.GAS > 0) {
$z3084130842 = $f3084730848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3084730848,
"from":L[2052]});
}
} catch($e3083930840) {
if(R.isCont($e3083930840)) {
var $ss3084330844 = {"from":L[2052],
"go":function(anf_arg467430849) {
return $Hanf_arg1005730850(anf_arg467430849,_plus55);
}};
$e3083930840.stack[R.EXN_STACKHEIGHT++] = $ss3084330844;
}
if(R.isPyretException($e3083930840)) {
$e3083930840.pyretStack.push(L[2052]);
}
throw $e3083930840;
}
var $ret3084530846 = $Hanf_arg1005730850($z3084130842,_plus55);
++R.GAS;
return $ret3084530846;
};
var $Hanf_arg1005730850 = function(anf_arg467430849,_plus55) {
var $z3085330854 = D;
var $f3085930860 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg467430849,(")")):R.ffi.throwNonFunApp(L[2052],_plus55,[anf_arg467430849,(")")]);
};
try {
if(--R.GAS > 0) {
$z3085330854 = $f3085930860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3085930860,
"from":L[2052]});
}
} catch($e3085130852) {
if(R.isCont($e3085130852)) {
var $ss3085530856 = {"from":L[2052],
"go":function(anf_arg467530861) {
return $Hanf_arg1005630862(anf_arg467530861,_plus55);
}};
$e3085130852.stack[R.EXN_STACKHEIGHT++] = $ss3085530856;
}
if(R.isPyretException($e3085130852)) {
$e3085130852.pyretStack.push(L[2052]);
}
throw $e3085130852;
}
var $ret3085730858 = $Hanf_arg1005630862($z3085330854,_plus55);
++R.GAS;
return $ret3085730858;
};
var $Hanf_arg1005630862 = function(anf_arg467530861,_plus55) {
var $z3086530866 = D;
var $f3087130872 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg467530861):R.ffi.throwNonFunApp(L[2052],_plus55,[("("),anf_arg467530861]);
};
try {
if(--R.GAS > 0) {
$z3086530866 = $f3087130872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3087130872,
"from":L[2052]});
}
} catch($e3086330864) {
if(R.isCont($e3086330864)) {
var $ss3086730868 = {"from":L[2052],
"go":function(anf_arg467630873) {
return $Hanf_arg1005530874(anf_arg467630873,_plus55);
}};
$e3086330864.stack[R.EXN_STACKHEIGHT++] = $ss3086730868;
}
if(R.isPyretException($e3086330864)) {
$e3086330864.pyretStack.push(L[2052]);
}
throw $e3086330864;
}
var $ret3086930870 = $Hanf_arg1005530874($z3086530866,_plus55);
++R.GAS;
return $ret3086930870;
};
var $Hanf_arg1005530874 = function(anf_arg467630873,_plus55) {
var $z3087730878 = D;
var $f3088330884 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-variant-member"),anf_arg467630873):R.ffi.throwNonFunApp(L[2052],_plus55,[("s-variant-member"),anf_arg467630873]);
};
try {
if(--R.GAS > 0) {
$z3087730878 = $f3088330884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3088330884,
"from":L[2052]});
}
} catch($e3087530876) {
if(R.isCont($e3087530876)) {
var $ss3087930880 = {"from":L[2052],
"go":function(ann_DASH_check_DASH_temp466430885) {
return $Hann_DASH_check_DASH_temp1005430886(ann_DASH_check_DASH_temp466430885);
}};
$e3087530876.stack[R.EXN_STACKHEIGHT++] = $ss3087930880;
}
if(R.isPyretException($e3087530876)) {
$e3087530876.pyretStack.push(L[2052]);
}
throw $e3087530876;
}
var $ret3088130882 = $Hann_DASH_check_DASH_temp1005430886($z3087730878);
++R.GAS;
return $ret3088130882;
};
var $Hann_DASH_check_DASH_temp1005430886 = function(ann_DASH_check_DASH_temp466430885) {
return ann_DASH_check_DASH_temp466430885;
};
var $Hcont_tail_arg1005211023 = function(cont_tail_arg466111021,if_helper465111022) {
if(--R.GAS > 0) {
$z3088730888 = R.isFunction(if_helper465111022)?if_helper465111022.app(cont_tail_arg466111021):R.ffi.throwNonFunApp(L[2052],if_helper465111022,[cont_tail_arg466111021]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper465111022)?if_helper465111022.app(cont_tail_arg466111021):R.ffi.throwNonFunApp(L[2052],if_helper465111022,[cont_tail_arg466111021]);
},
"from":L[2052]});
}
++R.GAS;
return $z3088730888;
};
var $Hcont_tail_arg1005311038 = function(cont_tail_arg465611037,if_helper465111022) {
if(--R.GAS > 0) {
$z3088930890 = R.isFunction(if_helper465111022)?if_helper465111022.app(cont_tail_arg465611037):R.ffi.throwNonFunApp(L[2052],if_helper465111022,[cont_tail_arg465611037]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper465111022)?if_helper465111022.app(cont_tail_arg465611037):R.ffi.throwNonFunApp(L[2052],if_helper465111022,[cont_tail_arg465611037]);
},
"from":L[2052]});
}
++R.GAS;
return $z3088930890;
};
var $Hann_DASH_check_DASH_temp1005111060 = function(ann_DASH_check_DASH_temp464211059) {
return ann_DASH_check_DASH_temp464211059;
};
var $Hanf_arg1005011073 = function(anf_arg464611072,_plus55,raise62) {
var $z3089330894 = D;
var $f3089930900 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg464611072):R.ffi.throwNonFunApp(L[4107],_plus55,[("No visitor field for "),anf_arg464611072]);
};
try {
if(--R.GAS > 0) {
$z3089330894 = $f3089930900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3089930900,
"from":L[4107]});
}
} catch($e3089130892) {
if(R.isCont($e3089130892)) {
var $ss3089530896 = {"from":L[4107],
"go":function(anf_arg464730901) {
return $Hanf_arg1004930902(anf_arg464730901,raise62);
}};
$e3089130892.stack[R.EXN_STACKHEIGHT++] = $ss3089530896;
}
if(R.isPyretException($e3089130892)) {
$e3089130892.pyretStack.push(L[4107]);
}
throw $e3089130892;
}
var $ret3089730898 = $Hanf_arg1004930902($z3089330894,raise62);
++R.GAS;
return $ret3089730898;
};
var $Hanf_arg1004930902 = function(anf_arg464730901,raise62) {
var $z3090530906 = D;
var $f3091130912 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg464730901):R.ffi.throwNonFunApp(L[2067],raise62,[anf_arg464730901]);
};
try {
if(--R.GAS > 0) {
$z3090530906 = $f3091130912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3091130912,
"from":L[2067]});
}
} catch($e3090330904) {
if(R.isCont($e3090330904)) {
var $ss3090730908 = {"from":L[2067],
"go":function(ann_DASH_check_DASH_temp464430913) {
return $Hann_DASH_check_DASH_temp1004830914(ann_DASH_check_DASH_temp464430913);
}};
$e3090330904.stack[R.EXN_STACKHEIGHT++] = $ss3090730908;
}
if(R.isPyretException($e3090330904)) {
$e3090330904.pyretStack.push(L[2067]);
}
throw $e3090330904;
}
var $ret3090930910 = $Hann_DASH_check_DASH_temp1004830914($z3090530906);
++R.GAS;
return $ret3090930910;
};
var $Hann_DASH_check_DASH_temp1004830914 = function(ann_DASH_check_DASH_temp464430913) {
return ann_DASH_check_DASH_temp464430913;
};
var $Hann_DASH_check_DASH_temp1004711115 = function(ann_DASH_check_DASH_temp463011114) {
return ann_DASH_check_DASH_temp463011114;
};
var $Hcont_tail_arg1004511134 = function(cont_tail_arg462311132,if_helper461611133) {
if(--R.GAS > 0) {
$z3091530916 = R.isFunction(if_helper461611133)?if_helper461611133.app(cont_tail_arg462311132):R.ffi.throwNonFunApp(L[2071],if_helper461611133,[cont_tail_arg462311132]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper461611133)?if_helper461611133.app(cont_tail_arg462311132):R.ffi.throwNonFunApp(L[2071],if_helper461611133,[cont_tail_arg462311132]);
},
"from":L[2071]});
}
++R.GAS;
return $z3091530916;
};
var $Hcont_tail_arg1004611148 = function(cont_tail_arg462111147,if_helper461611133) {
if(--R.GAS > 0) {
$z3091730918 = R.isFunction(if_helper461611133)?if_helper461611133.app(cont_tail_arg462111147):R.ffi.throwNonFunApp(L[2071],if_helper461611133,[cont_tail_arg462111147]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper461611133)?if_helper461611133.app(cont_tail_arg462111147):R.ffi.throwNonFunApp(L[2071],if_helper461611133,[cont_tail_arg462111147]);
},
"from":L[2071]});
}
++R.GAS;
return $z3091730918;
};
var $Hann_DASH_check_DASH_temp1004411169 = function(ann_DASH_check_DASH_temp461211168) {
return ann_DASH_check_DASH_temp461211168;
};
var $Hcont_tail_arg1004211188 = function(cont_tail_arg460511186,if_helper459811187) {
if(--R.GAS > 0) {
$z3091930920 = R.isFunction(if_helper459811187)?if_helper459811187.app(cont_tail_arg460511186):R.ffi.throwNonFunApp(L[2072],if_helper459811187,[cont_tail_arg460511186]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper459811187)?if_helper459811187.app(cont_tail_arg460511186):R.ffi.throwNonFunApp(L[2072],if_helper459811187,[cont_tail_arg460511186]);
},
"from":L[2072]});
}
++R.GAS;
return $z3091930920;
};
var $Hcont_tail_arg1004311202 = function(cont_tail_arg460311201,if_helper459811187) {
if(--R.GAS > 0) {
$z3092130922 = R.isFunction(if_helper459811187)?if_helper459811187.app(cont_tail_arg460311201):R.ffi.throwNonFunApp(L[2072],if_helper459811187,[cont_tail_arg460311201]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper459811187)?if_helper459811187.app(cont_tail_arg460311201):R.ffi.throwNonFunApp(L[2072],if_helper459811187,[cont_tail_arg460311201]);
},
"from":L[2072]});
}
++R.GAS;
return $z3092130922;
};
var $Hcont_tail_arg1004011230 = function(cont_tail_arg458811228,if_helper458111229) {
if(--R.GAS > 0) {
$z3092330924 = R.isFunction(if_helper458111229)?if_helper458111229.app(cont_tail_arg458811228):R.ffi.throwNonFunApp(L[2073],if_helper458111229,[cont_tail_arg458811228]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper458111229)?if_helper458111229.app(cont_tail_arg458811228):R.ffi.throwNonFunApp(L[2073],if_helper458111229,[cont_tail_arg458811228]);
},
"from":L[2073]});
}
++R.GAS;
return $z3092330924;
};
var $Hcont_tail_arg1004111244 = function(cont_tail_arg458611243,if_helper458111229) {
if(--R.GAS > 0) {
$z3092530926 = R.isFunction(if_helper458111229)?if_helper458111229.app(cont_tail_arg458611243):R.ffi.throwNonFunApp(L[2073],if_helper458111229,[cont_tail_arg458611243]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper458111229)?if_helper458111229.app(cont_tail_arg458611243):R.ffi.throwNonFunApp(L[2073],if_helper458111229,[cont_tail_arg458611243]);
},
"from":L[2073]});
}
++R.GAS;
return $z3092530926;
};
var $Hann_DASH_check_DASH_temp1003911267 = function(ann_DASH_check_DASH_temp457211266) {
return ann_DASH_check_DASH_temp457211266;
};
var $Hanf_arg1003811280 = function(anf_arg457611279,_plus55,raise62) {
var $z3092930930 = D;
var $f3093530936 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg457611279):R.ffi.throwNonFunApp(L[4108],_plus55,[("No visitor field for "),anf_arg457611279]);
};
try {
if(--R.GAS > 0) {
$z3092930930 = $f3093530936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3093530936,
"from":L[4108]});
}
} catch($e3092730928) {
if(R.isCont($e3092730928)) {
var $ss3093130932 = {"from":L[4108],
"go":function(anf_arg457730937) {
return $Hanf_arg1003730938(anf_arg457730937,raise62);
}};
$e3092730928.stack[R.EXN_STACKHEIGHT++] = $ss3093130932;
}
if(R.isPyretException($e3092730928)) {
$e3092730928.pyretStack.push(L[4108]);
}
throw $e3092730928;
}
var $ret3093330934 = $Hanf_arg1003730938($z3092930930,raise62);
++R.GAS;
return $ret3093330934;
};
var $Hanf_arg1003730938 = function(anf_arg457730937,raise62) {
var $z3094130942 = D;
var $f3094730948 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg457730937):R.ffi.throwNonFunApp(L[2085],raise62,[anf_arg457730937]);
};
try {
if(--R.GAS > 0) {
$z3094130942 = $f3094730948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3094730948,
"from":L[2085]});
}
} catch($e3093930940) {
if(R.isCont($e3093930940)) {
var $ss3094330944 = {"from":L[2085],
"go":function(ann_DASH_check_DASH_temp457430949) {
return $Hann_DASH_check_DASH_temp1003630950(ann_DASH_check_DASH_temp457430949);
}};
$e3093930940.stack[R.EXN_STACKHEIGHT++] = $ss3094330944;
}
if(R.isPyretException($e3093930940)) {
$e3093930940.pyretStack.push(L[2085]);
}
throw $e3093930940;
}
var $ret3094530946 = $Hann_DASH_check_DASH_temp1003630950($z3094130942);
++R.GAS;
return $ret3094530946;
};
var $Hann_DASH_check_DASH_temp1003630950 = function(ann_DASH_check_DASH_temp457430949) {
return ann_DASH_check_DASH_temp457430949;
};
var $Hanf_arg1003511309 = function(anf_arg455811306,anf_fun455511307,break_DASH_one119168,self105111308,str_DASH_from151585,_plus55) {
var $z3095330954 = D;
var $f3095930960 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg455811306,break_DASH_one119168):R.ffi.throwNonFunApp(L[4109],_plus55,[anf_arg455811306,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3095330954 = $f3095930960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3095930960,
"from":L[4109]});
}
} catch($e3095130952) {
if(R.isCont($e3095130952)) {
var $ss3095530956 = {"from":L[4109],
"go":function(anf_arg455930961) {
return $Hanf_arg1003430962(anf_arg455930961,anf_fun455511307,break_DASH_one119168,self105111308,str_DASH_from151585,_plus55);
}};
$e3095130952.stack[R.EXN_STACKHEIGHT++] = $ss3095530956;
}
if(R.isPyretException($e3095130952)) {
$e3095130952.pyretStack.push(L[4109]);
}
throw $e3095130952;
}
var $ret3095730958 = $Hanf_arg1003430962($z3095330954,anf_fun455511307,break_DASH_one119168,self105111308,str_DASH_from151585,_plus55);
++R.GAS;
return $ret3095730958;
};
var $Hanf_arg1003430962 = function(anf_arg455930961,anf_fun455511307,break_DASH_one119168,self105111308,str_DASH_from151585,_plus55) {
var $z3096530966 = D;
var $f3097130972 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg455930961,str_DASH_from151585):R.ffi.throwNonFunApp(L[4109],_plus55,[anf_arg455930961,str_DASH_from151585]);
};
try {
if(--R.GAS > 0) {
$z3096530966 = $f3097130972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3097130972,
"from":L[4109]});
}
} catch($e3096330964) {
if(R.isCont($e3096330964)) {
var $ss3096730968 = {"from":L[4109],
"go":function(anf_arg456030973) {
return $Hanf_arg1003330974(anf_arg456030973,anf_fun455511307,break_DASH_one119168,self105111308,_plus55);
}};
$e3096330964.stack[R.EXN_STACKHEIGHT++] = $ss3096730968;
}
if(R.isPyretException($e3096330964)) {
$e3096330964.pyretStack.push(L[4109]);
}
throw $e3096330964;
}
var $ret3096930970 = $Hanf_arg1003330974($z3096530966,anf_fun455511307,break_DASH_one119168,self105111308,_plus55);
++R.GAS;
return $ret3096930970;
};
var $Hanf_arg1003330974 = function(anf_arg456030973,anf_fun455511307,break_DASH_one119168,self105111308,_plus55) {
var $z3097730978 = D;
var $f3098330984 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg456030973,break_DASH_one119168):R.ffi.throwNonFunApp(L[4109],_plus55,[anf_arg456030973,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3097730978 = $f3098330984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3098330984,
"from":L[4109]});
}
} catch($e3097530976) {
if(R.isCont($e3097530976)) {
var $ss3097930980 = {"from":L[4109],
"go":function(anf_arg456130985) {
return $Hanf_arg1003230986(anf_arg456130985,anf_fun455511307,self105111308,_plus55);
}};
$e3097530976.stack[R.EXN_STACKHEIGHT++] = $ss3097930980;
}
if(R.isPyretException($e3097530976)) {
$e3097530976.pyretStack.push(L[4109]);
}
throw $e3097530976;
}
var $ret3098130982 = $Hanf_arg1003230986($z3097730978,anf_fun455511307,self105111308,_plus55);
++R.GAS;
return $ret3098130982;
};
var $Hanf_arg1003230986 = function(anf_arg456130985,anf_fun455511307,self105111308,_plus55) {
var anf_bracket456231000 = G(self105111308,"value",L[4112]);
var anf_fun456330997 = G(anf_bracket456231000,"tosource",L[4111]);
var $z3098930990 = D;
var $f3099530996 = function(_) {
return R.isFunction(anf_fun456330997)?anf_fun456330997.app():R.ffi.throwNonFunApp(L[4110],anf_fun456330997,[]);
};
try {
if(--R.GAS > 0) {
$z3098930990 = $f3099530996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3099530996,
"from":L[4110]});
}
} catch($e3098730988) {
if(R.isCont($e3098730988)) {
var $ss3099130992 = {"from":L[4110],
"go":function(anf_arg456430998) {
return $Hanf_arg1003130999(anf_arg456430998,anf_arg456130985,anf_fun455511307,_plus55);
}};
$e3098730988.stack[R.EXN_STACKHEIGHT++] = $ss3099130992;
}
if(R.isPyretException($e3098730988)) {
$e3098730988.pyretStack.push(L[4110]);
}
throw $e3098730988;
}
var $ret3099330994 = $Hanf_arg1003130999($z3098930990,anf_arg456130985,anf_fun455511307,_plus55);
++R.GAS;
return $ret3099330994;
};
var $Hanf_arg1003130999 = function(anf_arg456430998,anf_arg456130985,anf_fun455511307,_plus55) {
var $z3100331004 = D;
var $f3100931010 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg456130985,anf_arg456430998):R.ffi.throwNonFunApp(L[4109],_plus55,[anf_arg456130985,anf_arg456430998]);
};
try {
if(--R.GAS > 0) {
$z3100331004 = $f3100931010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3100931010,
"from":L[4109]});
}
} catch($e3100131002) {
if(R.isCont($e3100131002)) {
var $ss3100531006 = {"from":L[4109],
"go":function(anf_arg456531011) {
return $Hanf_arg1003031012(anf_arg456531011,anf_fun455511307);
}};
$e3100131002.stack[R.EXN_STACKHEIGHT++] = $ss3100531006;
}
if(R.isPyretException($e3100131002)) {
$e3100131002.pyretStack.push(L[4109]);
}
throw $e3100131002;
}
var $ret3100731008 = $Hanf_arg1003031012($z3100331004,anf_fun455511307);
++R.GAS;
return $ret3100731008;
};
var $Hanf_arg1003031012 = function(anf_arg456531011,anf_fun455511307) {
var $z3101531016 = D;
var $f3102131022 = function(_) {
return R.isFunction(anf_fun455511307)?anf_fun455511307.app(anf_arg456531011):R.ffi.throwNonFunApp(L[2099],anf_fun455511307,[anf_arg456531011]);
};
try {
if(--R.GAS > 0) {
$z3101531016 = $f3102131022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3102131022,
"from":L[2099]});
}
} catch($e3101331014) {
if(R.isCont($e3101331014)) {
var $ss3101731018 = {"from":L[2099],
"go":function(ann_DASH_check_DASH_temp455431023) {
return $Hann_DASH_check_DASH_temp1002931024(ann_DASH_check_DASH_temp455431023);
}};
$e3101331014.stack[R.EXN_STACKHEIGHT++] = $ss3101731018;
}
if(R.isPyretException($e3101331014)) {
$e3101331014.pyretStack.push(L[2099]);
}
throw $e3101331014;
}
var $ret3101931020 = $Hann_DASH_check_DASH_temp1002931024($z3101531016);
++R.GAS;
return $ret3101931020;
};
var $Hann_DASH_check_DASH_temp1002931024 = function(ann_DASH_check_DASH_temp455431023) {
return ann_DASH_check_DASH_temp455431023;
};
var $Hanf_arg1002811326 = function(anf_arg454011324,self56611325,_plus55,torepr65) {
var anf_arg454131035 = G(self56611325,"bind",L[2089]);
var $z3102731028 = D;
var $f3103331034 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg454131035):R.ffi.throwNonFunApp(L[2089],torepr65,[anf_arg454131035]);
};
try {
if(--R.GAS > 0) {
$z3102731028 = $f3103331034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3103331034,
"from":L[2089]});
}
} catch($e3102531026) {
if(R.isCont($e3102531026)) {
var $ss3102931030 = {"from":L[2089],
"go":function(anf_arg454231036) {
return $Hanf_arg1002731037(anf_arg454231036,anf_arg454011324,self56611325,_plus55,torepr65);
}};
$e3102531026.stack[R.EXN_STACKHEIGHT++] = $ss3102931030;
}
if(R.isPyretException($e3102531026)) {
$e3102531026.pyretStack.push(L[2089]);
}
throw $e3102531026;
}
var $ret3103131032 = $Hanf_arg1002731037($z3102731028,anf_arg454011324,self56611325,_plus55,torepr65);
++R.GAS;
return $ret3103131032;
};
var $Hanf_arg1002731037 = function(anf_arg454231036,anf_arg454011324,self56611325,_plus55,torepr65) {
var $z3104031041 = D;
var $f3104631047 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg454231036):R.ffi.throwNonFunApp(L[2089],_plus55,[(", "),anf_arg454231036]);
};
try {
if(--R.GAS > 0) {
$z3104031041 = $f3104631047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3104631047,
"from":L[2089]});
}
} catch($e3103831039) {
if(R.isCont($e3103831039)) {
var $ss3104231043 = {"from":L[2089],
"go":function(anf_arg454331048) {
return $Hanf_arg1002631049(anf_arg454331048,anf_arg454011324,self56611325,_plus55,torepr65);
}};
$e3103831039.stack[R.EXN_STACKHEIGHT++] = $ss3104231043;
}
if(R.isPyretException($e3103831039)) {
$e3103831039.pyretStack.push(L[2089]);
}
throw $e3103831039;
}
var $ret3104431045 = $Hanf_arg1002631049($z3104031041,anf_arg454011324,self56611325,_plus55,torepr65);
++R.GAS;
return $ret3104431045;
};
var $Hanf_arg1002631049 = function(anf_arg454331048,anf_arg454011324,self56611325,_plus55,torepr65) {
var $z3105231053 = D;
var $f3105831059 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg454011324,anf_arg454331048):R.ffi.throwNonFunApp(L[2089],_plus55,[anf_arg454011324,anf_arg454331048]);
};
try {
if(--R.GAS > 0) {
$z3105231053 = $f3105831059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3105831059,
"from":L[2089]});
}
} catch($e3105031051) {
if(R.isCont($e3105031051)) {
var $ss3105431055 = {"from":L[2089],
"go":function(anf_arg454431060) {
return $Hanf_arg1002531061(anf_arg454431060,self56611325,_plus55,torepr65);
}};
$e3105031051.stack[R.EXN_STACKHEIGHT++] = $ss3105431055;
}
if(R.isPyretException($e3105031051)) {
$e3105031051.pyretStack.push(L[2089]);
}
throw $e3105031051;
}
var $ret3105631057 = $Hanf_arg1002531061($z3105231053,self56611325,_plus55,torepr65);
++R.GAS;
return $ret3105631057;
};
var $Hanf_arg1002531061 = function(anf_arg454431060,self56611325,_plus55,torepr65) {
var anf_arg454531072 = G(self56611325,"value",L[2089]);
var $z3106431065 = D;
var $f3107031071 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg454531072):R.ffi.throwNonFunApp(L[2089],torepr65,[anf_arg454531072]);
};
try {
if(--R.GAS > 0) {
$z3106431065 = $f3107031071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3107031071,
"from":L[2089]});
}
} catch($e3106231063) {
if(R.isCont($e3106231063)) {
var $ss3106631067 = {"from":L[2089],
"go":function(anf_arg454631073) {
return $Hanf_arg1002431074(anf_arg454631073,anf_arg454431060,_plus55);
}};
$e3106231063.stack[R.EXN_STACKHEIGHT++] = $ss3106631067;
}
if(R.isPyretException($e3106231063)) {
$e3106231063.pyretStack.push(L[2089]);
}
throw $e3106231063;
}
var $ret3106831069 = $Hanf_arg1002431074($z3106431065,anf_arg454431060,_plus55);
++R.GAS;
return $ret3106831069;
};
var $Hanf_arg1002431074 = function(anf_arg454631073,anf_arg454431060,_plus55) {
var $z3107731078 = D;
var $f3108331084 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg454631073):R.ffi.throwNonFunApp(L[2089],_plus55,[(", "),anf_arg454631073]);
};
try {
if(--R.GAS > 0) {
$z3107731078 = $f3108331084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3108331084,
"from":L[2089]});
}
} catch($e3107531076) {
if(R.isCont($e3107531076)) {
var $ss3107931080 = {"from":L[2089],
"go":function(anf_arg454731085) {
return $Hanf_arg1002331086(anf_arg454731085,anf_arg454431060,_plus55);
}};
$e3107531076.stack[R.EXN_STACKHEIGHT++] = $ss3107931080;
}
if(R.isPyretException($e3107531076)) {
$e3107531076.pyretStack.push(L[2089]);
}
throw $e3107531076;
}
var $ret3108131082 = $Hanf_arg1002331086($z3107731078,anf_arg454431060,_plus55);
++R.GAS;
return $ret3108131082;
};
var $Hanf_arg1002331086 = function(anf_arg454731085,anf_arg454431060,_plus55) {
var $z3108931090 = D;
var $f3109531096 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg454431060,anf_arg454731085):R.ffi.throwNonFunApp(L[2089],_plus55,[anf_arg454431060,anf_arg454731085]);
};
try {
if(--R.GAS > 0) {
$z3108931090 = $f3109531096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3109531096,
"from":L[2089]});
}
} catch($e3108731088) {
if(R.isCont($e3108731088)) {
var $ss3109131092 = {"from":L[2089],
"go":function(anf_arg454831097) {
return $Hanf_arg1002231098(anf_arg454831097,_plus55);
}};
$e3108731088.stack[R.EXN_STACKHEIGHT++] = $ss3109131092;
}
if(R.isPyretException($e3108731088)) {
$e3108731088.pyretStack.push(L[2089]);
}
throw $e3108731088;
}
var $ret3109331094 = $Hanf_arg1002231098($z3108931090,_plus55);
++R.GAS;
return $ret3109331094;
};
var $Hanf_arg1002231098 = function(anf_arg454831097,_plus55) {
var $z3110131102 = D;
var $f3110731108 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg454831097,(")")):R.ffi.throwNonFunApp(L[2089],_plus55,[anf_arg454831097,(")")]);
};
try {
if(--R.GAS > 0) {
$z3110131102 = $f3110731108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3110731108,
"from":L[2089]});
}
} catch($e3109931100) {
if(R.isCont($e3109931100)) {
var $ss3110331104 = {"from":L[2089],
"go":function(anf_arg454931109) {
return $Hanf_arg1002131110(anf_arg454931109,_plus55);
}};
$e3109931100.stack[R.EXN_STACKHEIGHT++] = $ss3110331104;
}
if(R.isPyretException($e3109931100)) {
$e3109931100.pyretStack.push(L[2089]);
}
throw $e3109931100;
}
var $ret3110531106 = $Hanf_arg1002131110($z3110131102,_plus55);
++R.GAS;
return $ret3110531106;
};
var $Hanf_arg1002131110 = function(anf_arg454931109,_plus55) {
var $z3111331114 = D;
var $f3111931120 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg454931109):R.ffi.throwNonFunApp(L[2089],_plus55,[("("),anf_arg454931109]);
};
try {
if(--R.GAS > 0) {
$z3111331114 = $f3111931120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3111931120,
"from":L[2089]});
}
} catch($e3111131112) {
if(R.isCont($e3111131112)) {
var $ss3111531116 = {"from":L[2089],
"go":function(anf_arg455031121) {
return $Hanf_arg1002031122(anf_arg455031121,_plus55);
}};
$e3111131112.stack[R.EXN_STACKHEIGHT++] = $ss3111531116;
}
if(R.isPyretException($e3111131112)) {
$e3111131112.pyretStack.push(L[2089]);
}
throw $e3111131112;
}
var $ret3111731118 = $Hanf_arg1002031122($z3111331114,_plus55);
++R.GAS;
return $ret3111731118;
};
var $Hanf_arg1002031122 = function(anf_arg455031121,_plus55) {
var $z3112531126 = D;
var $f3113131132 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-for-bind"),anf_arg455031121):R.ffi.throwNonFunApp(L[2089],_plus55,[("s-for-bind"),anf_arg455031121]);
};
try {
if(--R.GAS > 0) {
$z3112531126 = $f3113131132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3113131132,
"from":L[2089]});
}
} catch($e3112331124) {
if(R.isCont($e3112331124)) {
var $ss3112731128 = {"from":L[2089],
"go":function(ann_DASH_check_DASH_temp453831133) {
return $Hann_DASH_check_DASH_temp1001931134(ann_DASH_check_DASH_temp453831133);
}};
$e3112331124.stack[R.EXN_STACKHEIGHT++] = $ss3112731128;
}
if(R.isPyretException($e3112331124)) {
$e3112331124.pyretStack.push(L[2089]);
}
throw $e3112331124;
}
var $ret3112931130 = $Hann_DASH_check_DASH_temp1001931134($z3112531126);
++R.GAS;
return $ret3112931130;
};
var $Hann_DASH_check_DASH_temp1001931134 = function(ann_DASH_check_DASH_temp453831133) {
return ann_DASH_check_DASH_temp453831133;
};
var $Hcont_tail_arg1001711343 = function(cont_tail_arg453511341,if_helper452511342) {
if(--R.GAS > 0) {
$z3113531136 = R.isFunction(if_helper452511342)?if_helper452511342.app(cont_tail_arg453511341):R.ffi.throwNonFunApp(L[2089],if_helper452511342,[cont_tail_arg453511341]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper452511342)?if_helper452511342.app(cont_tail_arg453511341):R.ffi.throwNonFunApp(L[2089],if_helper452511342,[cont_tail_arg453511341]);
},
"from":L[2089]});
}
++R.GAS;
return $z3113531136;
};
var $Hcont_tail_arg1001811358 = function(cont_tail_arg453011357,if_helper452511342) {
if(--R.GAS > 0) {
$z3113731138 = R.isFunction(if_helper452511342)?if_helper452511342.app(cont_tail_arg453011357):R.ffi.throwNonFunApp(L[2089],if_helper452511342,[cont_tail_arg453011357]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper452511342)?if_helper452511342.app(cont_tail_arg453011357):R.ffi.throwNonFunApp(L[2089],if_helper452511342,[cont_tail_arg453011357]);
},
"from":L[2089]});
}
++R.GAS;
return $z3113731138;
};
var $Hann_DASH_check_DASH_temp1001611380 = function(ann_DASH_check_DASH_temp451611379) {
return ann_DASH_check_DASH_temp451611379;
};
var $Hanf_arg1001511393 = function(anf_arg452011392,_plus55,raise62) {
var $z3114131142 = D;
var $f3114731148 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg452011392):R.ffi.throwNonFunApp(L[4113],_plus55,[("No visitor field for "),anf_arg452011392]);
};
try {
if(--R.GAS > 0) {
$z3114131142 = $f3114731148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3114731148,
"from":L[4113]});
}
} catch($e3113931140) {
if(R.isCont($e3113931140)) {
var $ss3114331144 = {"from":L[4113],
"go":function(anf_arg452131149) {
return $Hanf_arg1001431150(anf_arg452131149,raise62);
}};
$e3113931140.stack[R.EXN_STACKHEIGHT++] = $ss3114331144;
}
if(R.isPyretException($e3113931140)) {
$e3113931140.pyretStack.push(L[4113]);
}
throw $e3113931140;
}
var $ret3114531146 = $Hanf_arg1001431150($z3114131142,raise62);
++R.GAS;
return $ret3114531146;
};
var $Hanf_arg1001431150 = function(anf_arg452131149,raise62) {
var $z3115331154 = D;
var $f3115931160 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg452131149):R.ffi.throwNonFunApp(L[2105],raise62,[anf_arg452131149]);
};
try {
if(--R.GAS > 0) {
$z3115331154 = $f3115931160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3115931160,
"from":L[2105]});
}
} catch($e3115131152) {
if(R.isCont($e3115131152)) {
var $ss3115531156 = {"from":L[2105],
"go":function(ann_DASH_check_DASH_temp451831161) {
return $Hann_DASH_check_DASH_temp1001331162(ann_DASH_check_DASH_temp451831161);
}};
$e3115131152.stack[R.EXN_STACKHEIGHT++] = $ss3115531156;
}
if(R.isPyretException($e3115131152)) {
$e3115131152.pyretStack.push(L[2105]);
}
throw $e3115131152;
}
var $ret3115731158 = $Hann_DASH_check_DASH_temp1001331162($z3115331154);
++R.GAS;
return $ret3115731158;
};
var $Hann_DASH_check_DASH_temp1001331162 = function(ann_DASH_check_DASH_temp451831161) {
return ann_DASH_check_DASH_temp451831161;
};
var $Hname_DASH_part1001211464 = function(name_DASH_part104211462,funlam_DASH_tosource2501801,self104111463,nothing61) {
var anf_arg449931173 = G(self104111463,"args",L[4118]);
var anf_arg450031174 = G(self104111463,"ann",L[4117]);
var anf_arg450131175 = G(self104111463,"doc",L[4116]);
var anf_arg450231176 = G(self104111463,"body",L[4115]);
var anf_arg450331177 = G(self104111463,"_check",L[4114]);
var $z3116531166 = D;
var $f3117131172 = function(_) {
return R.isFunction(funlam_DASH_tosource2501801.$var)?funlam_DASH_tosource2501801.$var.app(name_DASH_part104211462,nothing61,nothing61,anf_arg449931173,anf_arg450031174,anf_arg450131175,anf_arg450231176,anf_arg450331177):R.ffi.throwNonFunApp(L[2143],funlam_DASH_tosource2501801.$var,[name_DASH_part104211462,nothing61,nothing61,anf_arg449931173,anf_arg450031174,anf_arg450131175,anf_arg450231176,anf_arg450331177]);
};
try {
if(--R.GAS > 0) {
$z3116531166 = $f3117131172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3117131172,
"from":L[2143]});
}
} catch($e3116331164) {
if(R.isCont($e3116331164)) {
var $ss3116731168 = {"from":L[2143],
"go":function(ann_DASH_check_DASH_temp448931178) {
return $Hann_DASH_check_DASH_temp1001131179(ann_DASH_check_DASH_temp448931178);
}};
$e3116331164.stack[R.EXN_STACKHEIGHT++] = $ss3116731168;
}
if(R.isPyretException($e3116331164)) {
$e3116331164.pyretStack.push(L[2143]);
}
throw $e3116331164;
}
var $ret3116931170 = $Hann_DASH_check_DASH_temp1001131179($z3116531166);
++R.GAS;
return $ret3116931170;
};
var $Hann_DASH_check_DASH_temp1001131179 = function(ann_DASH_check_DASH_temp448931178) {
return ann_DASH_check_DASH_temp448931178;
};
var $Hann_DASH_check_DASH_temp1001011477 = function(ann_DASH_check_DASH_temp449511476) {
return ann_DASH_check_DASH_temp449511476;
};
var $Hann_DASH_check_DASH_temp1000911494 = function(ann_DASH_check_DASH_temp449111493) {
return ann_DASH_check_DASH_temp449111493;
};
var $Hanf_arg1000811511 = function(anf_arg445911509,self55911510,_plus55,torepr65) {
var anf_arg446031190 = G(self55911510,"name",L[2109]);
var $z3118231183 = D;
var $f3118831189 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg446031190):R.ffi.throwNonFunApp(L[2109],torepr65,[anf_arg446031190]);
};
try {
if(--R.GAS > 0) {
$z3118231183 = $f3118831189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3118831189,
"from":L[2109]});
}
} catch($e3118031181) {
if(R.isCont($e3118031181)) {
var $ss3118431185 = {"from":L[2109],
"go":function(anf_arg446131191) {
return $Hanf_arg1000731192(anf_arg446131191,anf_arg445911509,self55911510,_plus55,torepr65);
}};
$e3118031181.stack[R.EXN_STACKHEIGHT++] = $ss3118431185;
}
if(R.isPyretException($e3118031181)) {
$e3118031181.pyretStack.push(L[2109]);
}
throw $e3118031181;
}
var $ret3118631187 = $Hanf_arg1000731192($z3118231183,anf_arg445911509,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3118631187;
};
var $Hanf_arg1000731192 = function(anf_arg446131191,anf_arg445911509,self55911510,_plus55,torepr65) {
var $z3119531196 = D;
var $f3120131202 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg446131191):R.ffi.throwNonFunApp(L[2109],_plus55,[(", "),anf_arg446131191]);
};
try {
if(--R.GAS > 0) {
$z3119531196 = $f3120131202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3120131202,
"from":L[2109]});
}
} catch($e3119331194) {
if(R.isCont($e3119331194)) {
var $ss3119731198 = {"from":L[2109],
"go":function(anf_arg446231203) {
return $Hanf_arg1000631204(anf_arg446231203,anf_arg445911509,self55911510,_plus55,torepr65);
}};
$e3119331194.stack[R.EXN_STACKHEIGHT++] = $ss3119731198;
}
if(R.isPyretException($e3119331194)) {
$e3119331194.pyretStack.push(L[2109]);
}
throw $e3119331194;
}
var $ret3119931200 = $Hanf_arg1000631204($z3119531196,anf_arg445911509,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3119931200;
};
var $Hanf_arg1000631204 = function(anf_arg446231203,anf_arg445911509,self55911510,_plus55,torepr65) {
var $z3120731208 = D;
var $f3121331214 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg445911509,anf_arg446231203):R.ffi.throwNonFunApp(L[2109],_plus55,[anf_arg445911509,anf_arg446231203]);
};
try {
if(--R.GAS > 0) {
$z3120731208 = $f3121331214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3121331214,
"from":L[2109]});
}
} catch($e3120531206) {
if(R.isCont($e3120531206)) {
var $ss3120931210 = {"from":L[2109],
"go":function(anf_arg446331215) {
return $Hanf_arg1000531216(anf_arg446331215,self55911510,_plus55,torepr65);
}};
$e3120531206.stack[R.EXN_STACKHEIGHT++] = $ss3120931210;
}
if(R.isPyretException($e3120531206)) {
$e3120531206.pyretStack.push(L[2109]);
}
throw $e3120531206;
}
var $ret3121131212 = $Hanf_arg1000531216($z3120731208,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3121131212;
};
var $Hanf_arg1000531216 = function(anf_arg446331215,self55911510,_plus55,torepr65) {
var anf_arg446431227 = G(self55911510,"args",L[2109]);
var $z3121931220 = D;
var $f3122531226 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg446431227):R.ffi.throwNonFunApp(L[2109],torepr65,[anf_arg446431227]);
};
try {
if(--R.GAS > 0) {
$z3121931220 = $f3122531226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3122531226,
"from":L[2109]});
}
} catch($e3121731218) {
if(R.isCont($e3121731218)) {
var $ss3122131222 = {"from":L[2109],
"go":function(anf_arg446531228) {
return $Hanf_arg1000431229(anf_arg446531228,anf_arg446331215,self55911510,_plus55,torepr65);
}};
$e3121731218.stack[R.EXN_STACKHEIGHT++] = $ss3122131222;
}
if(R.isPyretException($e3121731218)) {
$e3121731218.pyretStack.push(L[2109]);
}
throw $e3121731218;
}
var $ret3122331224 = $Hanf_arg1000431229($z3121931220,anf_arg446331215,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3122331224;
};
var $Hanf_arg1000431229 = function(anf_arg446531228,anf_arg446331215,self55911510,_plus55,torepr65) {
var $z3123231233 = D;
var $f3123831239 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg446531228):R.ffi.throwNonFunApp(L[2109],_plus55,[(", "),anf_arg446531228]);
};
try {
if(--R.GAS > 0) {
$z3123231233 = $f3123831239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3123831239,
"from":L[2109]});
}
} catch($e3123031231) {
if(R.isCont($e3123031231)) {
var $ss3123431235 = {"from":L[2109],
"go":function(anf_arg446631240) {
return $Hanf_arg1000331241(anf_arg446631240,anf_arg446331215,self55911510,_plus55,torepr65);
}};
$e3123031231.stack[R.EXN_STACKHEIGHT++] = $ss3123431235;
}
if(R.isPyretException($e3123031231)) {
$e3123031231.pyretStack.push(L[2109]);
}
throw $e3123031231;
}
var $ret3123631237 = $Hanf_arg1000331241($z3123231233,anf_arg446331215,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3123631237;
};
var $Hanf_arg1000331241 = function(anf_arg446631240,anf_arg446331215,self55911510,_plus55,torepr65) {
var $z3124431245 = D;
var $f3125031251 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg446331215,anf_arg446631240):R.ffi.throwNonFunApp(L[2109],_plus55,[anf_arg446331215,anf_arg446631240]);
};
try {
if(--R.GAS > 0) {
$z3124431245 = $f3125031251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3125031251,
"from":L[2109]});
}
} catch($e3124231243) {
if(R.isCont($e3124231243)) {
var $ss3124631247 = {"from":L[2109],
"go":function(anf_arg446731252) {
return $Hanf_arg1000231253(anf_arg446731252,self55911510,_plus55,torepr65);
}};
$e3124231243.stack[R.EXN_STACKHEIGHT++] = $ss3124631247;
}
if(R.isPyretException($e3124231243)) {
$e3124231243.pyretStack.push(L[2109]);
}
throw $e3124231243;
}
var $ret3124831249 = $Hanf_arg1000231253($z3124431245,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3124831249;
};
var $Hanf_arg1000231253 = function(anf_arg446731252,self55911510,_plus55,torepr65) {
var anf_arg446831264 = G(self55911510,"ann",L[2109]);
var $z3125631257 = D;
var $f3126231263 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg446831264):R.ffi.throwNonFunApp(L[2109],torepr65,[anf_arg446831264]);
};
try {
if(--R.GAS > 0) {
$z3125631257 = $f3126231263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3126231263,
"from":L[2109]});
}
} catch($e3125431255) {
if(R.isCont($e3125431255)) {
var $ss3125831259 = {"from":L[2109],
"go":function(anf_arg446931265) {
return $Hanf_arg1000131266(anf_arg446931265,anf_arg446731252,self55911510,_plus55,torepr65);
}};
$e3125431255.stack[R.EXN_STACKHEIGHT++] = $ss3125831259;
}
if(R.isPyretException($e3125431255)) {
$e3125431255.pyretStack.push(L[2109]);
}
throw $e3125431255;
}
var $ret3126031261 = $Hanf_arg1000131266($z3125631257,anf_arg446731252,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3126031261;
};
var $Hanf_arg1000131266 = function(anf_arg446931265,anf_arg446731252,self55911510,_plus55,torepr65) {
var $z3126931270 = D;
var $f3127531276 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg446931265):R.ffi.throwNonFunApp(L[2109],_plus55,[(", "),anf_arg446931265]);
};
try {
if(--R.GAS > 0) {
$z3126931270 = $f3127531276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3127531276,
"from":L[2109]});
}
} catch($e3126731268) {
if(R.isCont($e3126731268)) {
var $ss3127131272 = {"from":L[2109],
"go":function(anf_arg447031277) {
return $Hanf_arg1000031278(anf_arg447031277,anf_arg446731252,self55911510,_plus55,torepr65);
}};
$e3126731268.stack[R.EXN_STACKHEIGHT++] = $ss3127131272;
}
if(R.isPyretException($e3126731268)) {
$e3126731268.pyretStack.push(L[2109]);
}
throw $e3126731268;
}
var $ret3127331274 = $Hanf_arg1000031278($z3126931270,anf_arg446731252,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3127331274;
};
var $Hanf_arg1000031278 = function(anf_arg447031277,anf_arg446731252,self55911510,_plus55,torepr65) {
var $z3128131282 = D;
var $f3128731288 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg446731252,anf_arg447031277):R.ffi.throwNonFunApp(L[2109],_plus55,[anf_arg446731252,anf_arg447031277]);
};
try {
if(--R.GAS > 0) {
$z3128131282 = $f3128731288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3128731288,
"from":L[2109]});
}
} catch($e3127931280) {
if(R.isCont($e3127931280)) {
var $ss3128331284 = {"from":L[2109],
"go":function(anf_arg447131289) {
return $Hanf_arg999931290(anf_arg447131289,self55911510,_plus55,torepr65);
}};
$e3127931280.stack[R.EXN_STACKHEIGHT++] = $ss3128331284;
}
if(R.isPyretException($e3127931280)) {
$e3127931280.pyretStack.push(L[2109]);
}
throw $e3127931280;
}
var $ret3128531286 = $Hanf_arg999931290($z3128131282,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3128531286;
};
var $Hanf_arg999931290 = function(anf_arg447131289,self55911510,_plus55,torepr65) {
var anf_arg447231301 = G(self55911510,"doc",L[2109]);
var $z3129331294 = D;
var $f3129931300 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg447231301):R.ffi.throwNonFunApp(L[2109],torepr65,[anf_arg447231301]);
};
try {
if(--R.GAS > 0) {
$z3129331294 = $f3129931300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3129931300,
"from":L[2109]});
}
} catch($e3129131292) {
if(R.isCont($e3129131292)) {
var $ss3129531296 = {"from":L[2109],
"go":function(anf_arg447331302) {
return $Hanf_arg999831303(anf_arg447331302,anf_arg447131289,self55911510,_plus55,torepr65);
}};
$e3129131292.stack[R.EXN_STACKHEIGHT++] = $ss3129531296;
}
if(R.isPyretException($e3129131292)) {
$e3129131292.pyretStack.push(L[2109]);
}
throw $e3129131292;
}
var $ret3129731298 = $Hanf_arg999831303($z3129331294,anf_arg447131289,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3129731298;
};
var $Hanf_arg999831303 = function(anf_arg447331302,anf_arg447131289,self55911510,_plus55,torepr65) {
var $z3130631307 = D;
var $f3131231313 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg447331302):R.ffi.throwNonFunApp(L[2109],_plus55,[(", "),anf_arg447331302]);
};
try {
if(--R.GAS > 0) {
$z3130631307 = $f3131231313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3131231313,
"from":L[2109]});
}
} catch($e3130431305) {
if(R.isCont($e3130431305)) {
var $ss3130831309 = {"from":L[2109],
"go":function(anf_arg447431314) {
return $Hanf_arg999731315(anf_arg447431314,anf_arg447131289,self55911510,_plus55,torepr65);
}};
$e3130431305.stack[R.EXN_STACKHEIGHT++] = $ss3130831309;
}
if(R.isPyretException($e3130431305)) {
$e3130431305.pyretStack.push(L[2109]);
}
throw $e3130431305;
}
var $ret3131031311 = $Hanf_arg999731315($z3130631307,anf_arg447131289,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3131031311;
};
var $Hanf_arg999731315 = function(anf_arg447431314,anf_arg447131289,self55911510,_plus55,torepr65) {
var $z3131831319 = D;
var $f3132431325 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg447131289,anf_arg447431314):R.ffi.throwNonFunApp(L[2109],_plus55,[anf_arg447131289,anf_arg447431314]);
};
try {
if(--R.GAS > 0) {
$z3131831319 = $f3132431325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3132431325,
"from":L[2109]});
}
} catch($e3131631317) {
if(R.isCont($e3131631317)) {
var $ss3132031321 = {"from":L[2109],
"go":function(anf_arg447531326) {
return $Hanf_arg999631327(anf_arg447531326,self55911510,_plus55,torepr65);
}};
$e3131631317.stack[R.EXN_STACKHEIGHT++] = $ss3132031321;
}
if(R.isPyretException($e3131631317)) {
$e3131631317.pyretStack.push(L[2109]);
}
throw $e3131631317;
}
var $ret3132231323 = $Hanf_arg999631327($z3131831319,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3132231323;
};
var $Hanf_arg999631327 = function(anf_arg447531326,self55911510,_plus55,torepr65) {
var anf_arg447631338 = G(self55911510,"body",L[2109]);
var $z3133031331 = D;
var $f3133631337 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg447631338):R.ffi.throwNonFunApp(L[2109],torepr65,[anf_arg447631338]);
};
try {
if(--R.GAS > 0) {
$z3133031331 = $f3133631337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3133631337,
"from":L[2109]});
}
} catch($e3132831329) {
if(R.isCont($e3132831329)) {
var $ss3133231333 = {"from":L[2109],
"go":function(anf_arg447731339) {
return $Hanf_arg999531340(anf_arg447731339,anf_arg447531326,self55911510,_plus55,torepr65);
}};
$e3132831329.stack[R.EXN_STACKHEIGHT++] = $ss3133231333;
}
if(R.isPyretException($e3132831329)) {
$e3132831329.pyretStack.push(L[2109]);
}
throw $e3132831329;
}
var $ret3133431335 = $Hanf_arg999531340($z3133031331,anf_arg447531326,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3133431335;
};
var $Hanf_arg999531340 = function(anf_arg447731339,anf_arg447531326,self55911510,_plus55,torepr65) {
var $z3134331344 = D;
var $f3134931350 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg447731339):R.ffi.throwNonFunApp(L[2109],_plus55,[(", "),anf_arg447731339]);
};
try {
if(--R.GAS > 0) {
$z3134331344 = $f3134931350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3134931350,
"from":L[2109]});
}
} catch($e3134131342) {
if(R.isCont($e3134131342)) {
var $ss3134531346 = {"from":L[2109],
"go":function(anf_arg447831351) {
return $Hanf_arg999431352(anf_arg447831351,anf_arg447531326,self55911510,_plus55,torepr65);
}};
$e3134131342.stack[R.EXN_STACKHEIGHT++] = $ss3134531346;
}
if(R.isPyretException($e3134131342)) {
$e3134131342.pyretStack.push(L[2109]);
}
throw $e3134131342;
}
var $ret3134731348 = $Hanf_arg999431352($z3134331344,anf_arg447531326,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3134731348;
};
var $Hanf_arg999431352 = function(anf_arg447831351,anf_arg447531326,self55911510,_plus55,torepr65) {
var $z3135531356 = D;
var $f3136131362 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg447531326,anf_arg447831351):R.ffi.throwNonFunApp(L[2109],_plus55,[anf_arg447531326,anf_arg447831351]);
};
try {
if(--R.GAS > 0) {
$z3135531356 = $f3136131362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3136131362,
"from":L[2109]});
}
} catch($e3135331354) {
if(R.isCont($e3135331354)) {
var $ss3135731358 = {"from":L[2109],
"go":function(anf_arg447931363) {
return $Hanf_arg999331364(anf_arg447931363,self55911510,_plus55,torepr65);
}};
$e3135331354.stack[R.EXN_STACKHEIGHT++] = $ss3135731358;
}
if(R.isPyretException($e3135331354)) {
$e3135331354.pyretStack.push(L[2109]);
}
throw $e3135331354;
}
var $ret3135931360 = $Hanf_arg999331364($z3135531356,self55911510,_plus55,torepr65);
++R.GAS;
return $ret3135931360;
};
var $Hanf_arg999331364 = function(anf_arg447931363,self55911510,_plus55,torepr65) {
var anf_arg448031375 = G(self55911510,"_check",L[2109]);
var $z3136731368 = D;
var $f3137331374 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg448031375):R.ffi.throwNonFunApp(L[2109],torepr65,[anf_arg448031375]);
};
try {
if(--R.GAS > 0) {
$z3136731368 = $f3137331374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3137331374,
"from":L[2109]});
}
} catch($e3136531366) {
if(R.isCont($e3136531366)) {
var $ss3136931370 = {"from":L[2109],
"go":function(anf_arg448131376) {
return $Hanf_arg999231377(anf_arg448131376,anf_arg447931363,_plus55);
}};
$e3136531366.stack[R.EXN_STACKHEIGHT++] = $ss3136931370;
}
if(R.isPyretException($e3136531366)) {
$e3136531366.pyretStack.push(L[2109]);
}
throw $e3136531366;
}
var $ret3137131372 = $Hanf_arg999231377($z3136731368,anf_arg447931363,_plus55);
++R.GAS;
return $ret3137131372;
};
var $Hanf_arg999231377 = function(anf_arg448131376,anf_arg447931363,_plus55) {
var $z3138031381 = D;
var $f3138631387 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg448131376):R.ffi.throwNonFunApp(L[2109],_plus55,[(", "),anf_arg448131376]);
};
try {
if(--R.GAS > 0) {
$z3138031381 = $f3138631387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3138631387,
"from":L[2109]});
}
} catch($e3137831379) {
if(R.isCont($e3137831379)) {
var $ss3138231383 = {"from":L[2109],
"go":function(anf_arg448231388) {
return $Hanf_arg999131389(anf_arg448231388,anf_arg447931363,_plus55);
}};
$e3137831379.stack[R.EXN_STACKHEIGHT++] = $ss3138231383;
}
if(R.isPyretException($e3137831379)) {
$e3137831379.pyretStack.push(L[2109]);
}
throw $e3137831379;
}
var $ret3138431385 = $Hanf_arg999131389($z3138031381,anf_arg447931363,_plus55);
++R.GAS;
return $ret3138431385;
};
var $Hanf_arg999131389 = function(anf_arg448231388,anf_arg447931363,_plus55) {
var $z3139231393 = D;
var $f3139831399 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg447931363,anf_arg448231388):R.ffi.throwNonFunApp(L[2109],_plus55,[anf_arg447931363,anf_arg448231388]);
};
try {
if(--R.GAS > 0) {
$z3139231393 = $f3139831399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3139831399,
"from":L[2109]});
}
} catch($e3139031391) {
if(R.isCont($e3139031391)) {
var $ss3139431395 = {"from":L[2109],
"go":function(anf_arg448331400) {
return $Hanf_arg999031401(anf_arg448331400,_plus55);
}};
$e3139031391.stack[R.EXN_STACKHEIGHT++] = $ss3139431395;
}
if(R.isPyretException($e3139031391)) {
$e3139031391.pyretStack.push(L[2109]);
}
throw $e3139031391;
}
var $ret3139631397 = $Hanf_arg999031401($z3139231393,_plus55);
++R.GAS;
return $ret3139631397;
};
var $Hanf_arg999031401 = function(anf_arg448331400,_plus55) {
var $z3140431405 = D;
var $f3141031411 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg448331400,(")")):R.ffi.throwNonFunApp(L[2109],_plus55,[anf_arg448331400,(")")]);
};
try {
if(--R.GAS > 0) {
$z3140431405 = $f3141031411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3141031411,
"from":L[2109]});
}
} catch($e3140231403) {
if(R.isCont($e3140231403)) {
var $ss3140631407 = {"from":L[2109],
"go":function(anf_arg448431412) {
return $Hanf_arg998931413(anf_arg448431412,_plus55);
}};
$e3140231403.stack[R.EXN_STACKHEIGHT++] = $ss3140631407;
}
if(R.isPyretException($e3140231403)) {
$e3140231403.pyretStack.push(L[2109]);
}
throw $e3140231403;
}
var $ret3140831409 = $Hanf_arg998931413($z3140431405,_plus55);
++R.GAS;
return $ret3140831409;
};
var $Hanf_arg998931413 = function(anf_arg448431412,_plus55) {
var $z3141631417 = D;
var $f3142231423 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg448431412):R.ffi.throwNonFunApp(L[2109],_plus55,[("("),anf_arg448431412]);
};
try {
if(--R.GAS > 0) {
$z3141631417 = $f3142231423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3142231423,
"from":L[2109]});
}
} catch($e3141431415) {
if(R.isCont($e3141431415)) {
var $ss3141831419 = {"from":L[2109],
"go":function(anf_arg448531424) {
return $Hanf_arg998831425(anf_arg448531424,_plus55);
}};
$e3141431415.stack[R.EXN_STACKHEIGHT++] = $ss3141831419;
}
if(R.isPyretException($e3141431415)) {
$e3141431415.pyretStack.push(L[2109]);
}
throw $e3141431415;
}
var $ret3142031421 = $Hanf_arg998831425($z3141631417,_plus55);
++R.GAS;
return $ret3142031421;
};
var $Hanf_arg998831425 = function(anf_arg448531424,_plus55) {
var $z3142831429 = D;
var $f3143431435 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-method-field"),anf_arg448531424):R.ffi.throwNonFunApp(L[2109],_plus55,[("s-method-field"),anf_arg448531424]);
};
try {
if(--R.GAS > 0) {
$z3142831429 = $f3143431435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3143431435,
"from":L[2109]});
}
} catch($e3142631427) {
if(R.isCont($e3142631427)) {
var $ss3143031431 = {"from":L[2109],
"go":function(ann_DASH_check_DASH_temp445731436) {
return $Hann_DASH_check_DASH_temp998731437(ann_DASH_check_DASH_temp445731436);
}};
$e3142631427.stack[R.EXN_STACKHEIGHT++] = $ss3143031431;
}
if(R.isPyretException($e3142631427)) {
$e3142631427.pyretStack.push(L[2109]);
}
throw $e3142631427;
}
var $ret3143231433 = $Hann_DASH_check_DASH_temp998731437($z3142831429);
++R.GAS;
return $ret3143231433;
};
var $Hann_DASH_check_DASH_temp998731437 = function(ann_DASH_check_DASH_temp445731436) {
return ann_DASH_check_DASH_temp445731436;
};
var $Hcont_tail_arg998511532 = function(cont_tail_arg445411530,if_helper444011531) {
if(--R.GAS > 0) {
$z3143831439 = R.isFunction(if_helper444011531)?if_helper444011531.app(cont_tail_arg445411530):R.ffi.throwNonFunApp(L[2109],if_helper444011531,[cont_tail_arg445411530]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper444011531)?if_helper444011531.app(cont_tail_arg445411530):R.ffi.throwNonFunApp(L[2109],if_helper444011531,[cont_tail_arg445411530]);
},
"from":L[2109]});
}
++R.GAS;
return $z3143831439;
};
var $Hcont_tail_arg998611547 = function(cont_tail_arg444511546,if_helper444011531) {
if(--R.GAS > 0) {
$z3144031441 = R.isFunction(if_helper444011531)?if_helper444011531.app(cont_tail_arg444511546):R.ffi.throwNonFunApp(L[2109],if_helper444011531,[cont_tail_arg444511546]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper444011531)?if_helper444011531.app(cont_tail_arg444511546):R.ffi.throwNonFunApp(L[2109],if_helper444011531,[cont_tail_arg444511546]);
},
"from":L[2109]});
}
++R.GAS;
return $z3144031441;
};
var $Hanf_arg998411570 = function(anf_arg442111568,self55311569,_plus55,torepr65) {
var anf_arg442231452 = G(self55311569,"name",L[2110]);
var $z3144431445 = D;
var $f3145031451 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg442231452):R.ffi.throwNonFunApp(L[2110],torepr65,[anf_arg442231452]);
};
try {
if(--R.GAS > 0) {
$z3144431445 = $f3145031451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3145031451,
"from":L[2110]});
}
} catch($e3144231443) {
if(R.isCont($e3144231443)) {
var $ss3144631447 = {"from":L[2110],
"go":function(anf_arg442331453) {
return $Hanf_arg998331454(anf_arg442331453,anf_arg442111568,self55311569,_plus55,torepr65);
}};
$e3144231443.stack[R.EXN_STACKHEIGHT++] = $ss3144631447;
}
if(R.isPyretException($e3144231443)) {
$e3144231443.pyretStack.push(L[2110]);
}
throw $e3144231443;
}
var $ret3144831449 = $Hanf_arg998331454($z3144431445,anf_arg442111568,self55311569,_plus55,torepr65);
++R.GAS;
return $ret3144831449;
};
var $Hanf_arg998331454 = function(anf_arg442331453,anf_arg442111568,self55311569,_plus55,torepr65) {
var $z3145731458 = D;
var $f3146331464 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg442331453):R.ffi.throwNonFunApp(L[2110],_plus55,[(", "),anf_arg442331453]);
};
try {
if(--R.GAS > 0) {
$z3145731458 = $f3146331464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3146331464,
"from":L[2110]});
}
} catch($e3145531456) {
if(R.isCont($e3145531456)) {
var $ss3145931460 = {"from":L[2110],
"go":function(anf_arg442431465) {
return $Hanf_arg998231466(anf_arg442431465,anf_arg442111568,self55311569,_plus55,torepr65);
}};
$e3145531456.stack[R.EXN_STACKHEIGHT++] = $ss3145931460;
}
if(R.isPyretException($e3145531456)) {
$e3145531456.pyretStack.push(L[2110]);
}
throw $e3145531456;
}
var $ret3146131462 = $Hanf_arg998231466($z3145731458,anf_arg442111568,self55311569,_plus55,torepr65);
++R.GAS;
return $ret3146131462;
};
var $Hanf_arg998231466 = function(anf_arg442431465,anf_arg442111568,self55311569,_plus55,torepr65) {
var $z3146931470 = D;
var $f3147531476 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg442111568,anf_arg442431465):R.ffi.throwNonFunApp(L[2110],_plus55,[anf_arg442111568,anf_arg442431465]);
};
try {
if(--R.GAS > 0) {
$z3146931470 = $f3147531476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3147531476,
"from":L[2110]});
}
} catch($e3146731468) {
if(R.isCont($e3146731468)) {
var $ss3147131472 = {"from":L[2110],
"go":function(anf_arg442531477) {
return $Hanf_arg998131478(anf_arg442531477,self55311569,_plus55,torepr65);
}};
$e3146731468.stack[R.EXN_STACKHEIGHT++] = $ss3147131472;
}
if(R.isPyretException($e3146731468)) {
$e3146731468.pyretStack.push(L[2110]);
}
throw $e3146731468;
}
var $ret3147331474 = $Hanf_arg998131478($z3146931470,self55311569,_plus55,torepr65);
++R.GAS;
return $ret3147331474;
};
var $Hanf_arg998131478 = function(anf_arg442531477,self55311569,_plus55,torepr65) {
var anf_arg442631489 = G(self55311569,"ann",L[2110]);
var $z3148131482 = D;
var $f3148731488 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg442631489):R.ffi.throwNonFunApp(L[2110],torepr65,[anf_arg442631489]);
};
try {
if(--R.GAS > 0) {
$z3148131482 = $f3148731488();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3148731488,
"from":L[2110]});
}
} catch($e3147931480) {
if(R.isCont($e3147931480)) {
var $ss3148331484 = {"from":L[2110],
"go":function(anf_arg442731490) {
return $Hanf_arg998031491(anf_arg442731490,anf_arg442531477,self55311569,_plus55,torepr65);
}};
$e3147931480.stack[R.EXN_STACKHEIGHT++] = $ss3148331484;
}
if(R.isPyretException($e3147931480)) {
$e3147931480.pyretStack.push(L[2110]);
}
throw $e3147931480;
}
var $ret3148531486 = $Hanf_arg998031491($z3148131482,anf_arg442531477,self55311569,_plus55,torepr65);
++R.GAS;
return $ret3148531486;
};
var $Hanf_arg998031491 = function(anf_arg442731490,anf_arg442531477,self55311569,_plus55,torepr65) {
var $z3149431495 = D;
var $f3150031501 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg442731490):R.ffi.throwNonFunApp(L[2110],_plus55,[(", "),anf_arg442731490]);
};
try {
if(--R.GAS > 0) {
$z3149431495 = $f3150031501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3150031501,
"from":L[2110]});
}
} catch($e3149231493) {
if(R.isCont($e3149231493)) {
var $ss3149631497 = {"from":L[2110],
"go":function(anf_arg442831502) {
return $Hanf_arg997931503(anf_arg442831502,anf_arg442531477,self55311569,_plus55,torepr65);
}};
$e3149231493.stack[R.EXN_STACKHEIGHT++] = $ss3149631497;
}
if(R.isPyretException($e3149231493)) {
$e3149231493.pyretStack.push(L[2110]);
}
throw $e3149231493;
}
var $ret3149831499 = $Hanf_arg997931503($z3149431495,anf_arg442531477,self55311569,_plus55,torepr65);
++R.GAS;
return $ret3149831499;
};
var $Hanf_arg997931503 = function(anf_arg442831502,anf_arg442531477,self55311569,_plus55,torepr65) {
var $z3150631507 = D;
var $f3151231513 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg442531477,anf_arg442831502):R.ffi.throwNonFunApp(L[2110],_plus55,[anf_arg442531477,anf_arg442831502]);
};
try {
if(--R.GAS > 0) {
$z3150631507 = $f3151231513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3151231513,
"from":L[2110]});
}
} catch($e3150431505) {
if(R.isCont($e3150431505)) {
var $ss3150831509 = {"from":L[2110],
"go":function(anf_arg442931514) {
return $Hanf_arg997831515(anf_arg442931514,self55311569,_plus55,torepr65);
}};
$e3150431505.stack[R.EXN_STACKHEIGHT++] = $ss3150831509;
}
if(R.isPyretException($e3150431505)) {
$e3150431505.pyretStack.push(L[2110]);
}
throw $e3150431505;
}
var $ret3151031511 = $Hanf_arg997831515($z3150631507,self55311569,_plus55,torepr65);
++R.GAS;
return $ret3151031511;
};
var $Hanf_arg997831515 = function(anf_arg442931514,self55311569,_plus55,torepr65) {
var anf_arg443031526 = G(self55311569,"value",L[2110]);
var $z3151831519 = D;
var $f3152431525 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg443031526):R.ffi.throwNonFunApp(L[2110],torepr65,[anf_arg443031526]);
};
try {
if(--R.GAS > 0) {
$z3151831519 = $f3152431525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3152431525,
"from":L[2110]});
}
} catch($e3151631517) {
if(R.isCont($e3151631517)) {
var $ss3152031521 = {"from":L[2110],
"go":function(anf_arg443131527) {
return $Hanf_arg997731528(anf_arg443131527,anf_arg442931514,_plus55);
}};
$e3151631517.stack[R.EXN_STACKHEIGHT++] = $ss3152031521;
}
if(R.isPyretException($e3151631517)) {
$e3151631517.pyretStack.push(L[2110]);
}
throw $e3151631517;
}
var $ret3152231523 = $Hanf_arg997731528($z3151831519,anf_arg442931514,_plus55);
++R.GAS;
return $ret3152231523;
};
var $Hanf_arg997731528 = function(anf_arg443131527,anf_arg442931514,_plus55) {
var $z3153131532 = D;
var $f3153731538 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg443131527):R.ffi.throwNonFunApp(L[2110],_plus55,[(", "),anf_arg443131527]);
};
try {
if(--R.GAS > 0) {
$z3153131532 = $f3153731538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3153731538,
"from":L[2110]});
}
} catch($e3152931530) {
if(R.isCont($e3152931530)) {
var $ss3153331534 = {"from":L[2110],
"go":function(anf_arg443231539) {
return $Hanf_arg997631540(anf_arg443231539,anf_arg442931514,_plus55);
}};
$e3152931530.stack[R.EXN_STACKHEIGHT++] = $ss3153331534;
}
if(R.isPyretException($e3152931530)) {
$e3152931530.pyretStack.push(L[2110]);
}
throw $e3152931530;
}
var $ret3153531536 = $Hanf_arg997631540($z3153131532,anf_arg442931514,_plus55);
++R.GAS;
return $ret3153531536;
};
var $Hanf_arg997631540 = function(anf_arg443231539,anf_arg442931514,_plus55) {
var $z3154331544 = D;
var $f3154931550 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg442931514,anf_arg443231539):R.ffi.throwNonFunApp(L[2110],_plus55,[anf_arg442931514,anf_arg443231539]);
};
try {
if(--R.GAS > 0) {
$z3154331544 = $f3154931550();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3154931550,
"from":L[2110]});
}
} catch($e3154131542) {
if(R.isCont($e3154131542)) {
var $ss3154531546 = {"from":L[2110],
"go":function(anf_arg443331551) {
return $Hanf_arg997531552(anf_arg443331551,_plus55);
}};
$e3154131542.stack[R.EXN_STACKHEIGHT++] = $ss3154531546;
}
if(R.isPyretException($e3154131542)) {
$e3154131542.pyretStack.push(L[2110]);
}
throw $e3154131542;
}
var $ret3154731548 = $Hanf_arg997531552($z3154331544,_plus55);
++R.GAS;
return $ret3154731548;
};
var $Hanf_arg997531552 = function(anf_arg443331551,_plus55) {
var $z3155531556 = D;
var $f3156131562 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg443331551,(")")):R.ffi.throwNonFunApp(L[2110],_plus55,[anf_arg443331551,(")")]);
};
try {
if(--R.GAS > 0) {
$z3155531556 = $f3156131562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3156131562,
"from":L[2110]});
}
} catch($e3155331554) {
if(R.isCont($e3155331554)) {
var $ss3155731558 = {"from":L[2110],
"go":function(anf_arg443431563) {
return $Hanf_arg997431564(anf_arg443431563,_plus55);
}};
$e3155331554.stack[R.EXN_STACKHEIGHT++] = $ss3155731558;
}
if(R.isPyretException($e3155331554)) {
$e3155331554.pyretStack.push(L[2110]);
}
throw $e3155331554;
}
var $ret3155931560 = $Hanf_arg997431564($z3155531556,_plus55);
++R.GAS;
return $ret3155931560;
};
var $Hanf_arg997431564 = function(anf_arg443431563,_plus55) {
var $z3156731568 = D;
var $f3157331574 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg443431563):R.ffi.throwNonFunApp(L[2110],_plus55,[("("),anf_arg443431563]);
};
try {
if(--R.GAS > 0) {
$z3156731568 = $f3157331574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3157331574,
"from":L[2110]});
}
} catch($e3156531566) {
if(R.isCont($e3156531566)) {
var $ss3156931570 = {"from":L[2110],
"go":function(anf_arg443531575) {
return $Hanf_arg997331576(anf_arg443531575,_plus55);
}};
$e3156531566.stack[R.EXN_STACKHEIGHT++] = $ss3156931570;
}
if(R.isPyretException($e3156531566)) {
$e3156531566.pyretStack.push(L[2110]);
}
throw $e3156531566;
}
var $ret3157131572 = $Hanf_arg997331576($z3156731568,_plus55);
++R.GAS;
return $ret3157131572;
};
var $Hanf_arg997331576 = function(anf_arg443531575,_plus55) {
var $z3157931580 = D;
var $f3158531586 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-once-field"),anf_arg443531575):R.ffi.throwNonFunApp(L[2110],_plus55,[("s-once-field"),anf_arg443531575]);
};
try {
if(--R.GAS > 0) {
$z3157931580 = $f3158531586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3158531586,
"from":L[2110]});
}
} catch($e3157731578) {
if(R.isCont($e3157731578)) {
var $ss3158131582 = {"from":L[2110],
"go":function(ann_DASH_check_DASH_temp441931587) {
return $Hann_DASH_check_DASH_temp997231588(ann_DASH_check_DASH_temp441931587);
}};
$e3157731578.stack[R.EXN_STACKHEIGHT++] = $ss3158131582;
}
if(R.isPyretException($e3157731578)) {
$e3157731578.pyretStack.push(L[2110]);
}
throw $e3157731578;
}
var $ret3158331584 = $Hann_DASH_check_DASH_temp997231588($z3157931580);
++R.GAS;
return $ret3158331584;
};
var $Hann_DASH_check_DASH_temp997231588 = function(ann_DASH_check_DASH_temp441931587) {
return ann_DASH_check_DASH_temp441931587;
};
var $Hcont_tail_arg997011588 = function(cont_tail_arg441611586,if_helper440511587) {
if(--R.GAS > 0) {
$z3158931590 = R.isFunction(if_helper440511587)?if_helper440511587.app(cont_tail_arg441611586):R.ffi.throwNonFunApp(L[2110],if_helper440511587,[cont_tail_arg441611586]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper440511587)?if_helper440511587.app(cont_tail_arg441611586):R.ffi.throwNonFunApp(L[2110],if_helper440511587,[cont_tail_arg441611586]);
},
"from":L[2110]});
}
++R.GAS;
return $z3158931590;
};
var $Hcont_tail_arg997111603 = function(cont_tail_arg441011602,if_helper440511587) {
if(--R.GAS > 0) {
$z3159131592 = R.isFunction(if_helper440511587)?if_helper440511587.app(cont_tail_arg441011602):R.ffi.throwNonFunApp(L[2110],if_helper440511587,[cont_tail_arg441011602]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper440511587)?if_helper440511587.app(cont_tail_arg441011602):R.ffi.throwNonFunApp(L[2110],if_helper440511587,[cont_tail_arg441011602]);
},
"from":L[2110]});
}
++R.GAS;
return $z3159131592;
};
var $Hanf_arg996911625 = function(anf_arg439111622,INDENT118169,anf_fun438811623,self102711624,str_DASH_coloncolon135377,str_DASH_colonspace136390,str_DASH_mutable159689,_plus55) {
var $z3159531596 = D;
var $f3160131602 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_mutable159689,anf_arg439111622):R.ffi.throwNonFunApp(L[4119],_plus55,[str_DASH_mutable159689,anf_arg439111622]);
};
try {
if(--R.GAS > 0) {
$z3159531596 = $f3160131602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3160131602,
"from":L[4119]});
}
} catch($e3159331594) {
if(R.isCont($e3159331594)) {
var $ss3159731598 = {"from":L[4119],
"go":function(anf_arg439231603) {
return $Hanf_arg996831604(anf_arg439231603,INDENT118169,anf_fun438811623,self102711624,str_DASH_coloncolon135377,str_DASH_colonspace136390,_plus55);
}};
$e3159331594.stack[R.EXN_STACKHEIGHT++] = $ss3159731598;
}
if(R.isPyretException($e3159331594)) {
$e3159331594.pyretStack.push(L[4119]);
}
throw $e3159331594;
}
var $ret3159931600 = $Hanf_arg996831604($z3159531596,INDENT118169,anf_fun438811623,self102711624,str_DASH_coloncolon135377,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3159931600;
};
var $Hanf_arg996831604 = function(anf_arg439231603,INDENT118169,anf_fun438811623,self102711624,str_DASH_coloncolon135377,str_DASH_colonspace136390,_plus55) {
var $z3160731608 = D;
var $f3161331614 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg439231603,str_DASH_coloncolon135377):R.ffi.throwNonFunApp(L[4119],_plus55,[anf_arg439231603,str_DASH_coloncolon135377]);
};
try {
if(--R.GAS > 0) {
$z3160731608 = $f3161331614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3161331614,
"from":L[4119]});
}
} catch($e3160531606) {
if(R.isCont($e3160531606)) {
var $ss3160931610 = {"from":L[4119],
"go":function(anf_arg439331615) {
return $Hanf_arg996731616(anf_arg439331615,INDENT118169,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55);
}};
$e3160531606.stack[R.EXN_STACKHEIGHT++] = $ss3160931610;
}
if(R.isPyretException($e3160531606)) {
$e3160531606.pyretStack.push(L[4119]);
}
throw $e3160531606;
}
var $ret3161131612 = $Hanf_arg996731616($z3160731608,INDENT118169,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3161131612;
};
var $Hanf_arg996731616 = function(anf_arg439331615,INDENT118169,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55) {
var anf_bracket439431630 = G(self102711624,"ann",L[4122]);
var anf_fun439531627 = G(anf_bracket439431630,"tosource",L[4121]);
var $z3161931620 = D;
var $f3162531626 = function(_) {
return R.isFunction(anf_fun439531627)?anf_fun439531627.app():R.ffi.throwNonFunApp(L[4120],anf_fun439531627,[]);
};
try {
if(--R.GAS > 0) {
$z3161931620 = $f3162531626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3162531626,
"from":L[4120]});
}
} catch($e3161731618) {
if(R.isCont($e3161731618)) {
var $ss3162131622 = {"from":L[4120],
"go":function(anf_arg439631628) {
return $Hanf_arg996631629(anf_arg439631628,INDENT118169,anf_arg439331615,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55);
}};
$e3161731618.stack[R.EXN_STACKHEIGHT++] = $ss3162131622;
}
if(R.isPyretException($e3161731618)) {
$e3161731618.pyretStack.push(L[4120]);
}
throw $e3161731618;
}
var $ret3162331624 = $Hanf_arg996631629($z3161931620,INDENT118169,anf_arg439331615,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3162331624;
};
var $Hanf_arg996631629 = function(anf_arg439631628,INDENT118169,anf_arg439331615,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55) {
var $z3163331634 = D;
var $f3163931640 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg439331615,anf_arg439631628):R.ffi.throwNonFunApp(L[4119],_plus55,[anf_arg439331615,anf_arg439631628]);
};
try {
if(--R.GAS > 0) {
$z3163331634 = $f3163931640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3163931640,
"from":L[4119]});
}
} catch($e3163131632) {
if(R.isCont($e3163131632)) {
var $ss3163531636 = {"from":L[4119],
"go":function(anf_arg439731641) {
return $Hanf_arg996531642(anf_arg439731641,INDENT118169,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55);
}};
$e3163131632.stack[R.EXN_STACKHEIGHT++] = $ss3163531636;
}
if(R.isPyretException($e3163131632)) {
$e3163131632.pyretStack.push(L[4119]);
}
throw $e3163131632;
}
var $ret3163731638 = $Hanf_arg996531642($z3163331634,INDENT118169,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3163731638;
};
var $Hanf_arg996531642 = function(anf_arg439731641,INDENT118169,anf_fun438811623,self102711624,str_DASH_colonspace136390,_plus55) {
var $z3164531646 = D;
var $f3165131652 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg439731641,str_DASH_colonspace136390):R.ffi.throwNonFunApp(L[4119],_plus55,[anf_arg439731641,str_DASH_colonspace136390]);
};
try {
if(--R.GAS > 0) {
$z3164531646 = $f3165131652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3165131652,
"from":L[4119]});
}
} catch($e3164331644) {
if(R.isCont($e3164331644)) {
var $ss3164731648 = {"from":L[4119],
"go":function(anf_arg439831653) {
return $Hanf_arg996431654(anf_arg439831653,INDENT118169,anf_fun438811623,self102711624,_plus55);
}};
$e3164331644.stack[R.EXN_STACKHEIGHT++] = $ss3164731648;
}
if(R.isPyretException($e3164331644)) {
$e3164331644.pyretStack.push(L[4119]);
}
throw $e3164331644;
}
var $ret3164931650 = $Hanf_arg996431654($z3164531646,INDENT118169,anf_fun438811623,self102711624,_plus55);
++R.GAS;
return $ret3164931650;
};
var $Hanf_arg996431654 = function(anf_arg439831653,INDENT118169,anf_fun438811623,self102711624,_plus55) {
var anf_bracket439931668 = G(self102711624,"value",L[4125]);
var anf_fun440031665 = G(anf_bracket439931668,"tosource",L[4124]);
var $z3165731658 = D;
var $f3166331664 = function(_) {
return R.isFunction(anf_fun440031665)?anf_fun440031665.app():R.ffi.throwNonFunApp(L[4123],anf_fun440031665,[]);
};
try {
if(--R.GAS > 0) {
$z3165731658 = $f3166331664();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3166331664,
"from":L[4123]});
}
} catch($e3165531656) {
if(R.isCont($e3165531656)) {
var $ss3165931660 = {"from":L[4123],
"go":function(anf_arg440131666) {
return $Hanf_arg996331667(anf_arg440131666,INDENT118169,anf_arg439831653,anf_fun438811623,_plus55);
}};
$e3165531656.stack[R.EXN_STACKHEIGHT++] = $ss3165931660;
}
if(R.isPyretException($e3165531656)) {
$e3165531656.pyretStack.push(L[4123]);
}
throw $e3165531656;
}
var $ret3166131662 = $Hanf_arg996331667($z3165731658,INDENT118169,anf_arg439831653,anf_fun438811623,_plus55);
++R.GAS;
return $ret3166131662;
};
var $Hanf_arg996331667 = function(anf_arg440131666,INDENT118169,anf_arg439831653,anf_fun438811623,_plus55) {
var $z3167131672 = D;
var $f3167731678 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg439831653,anf_arg440131666):R.ffi.throwNonFunApp(L[4119],_plus55,[anf_arg439831653,anf_arg440131666]);
};
try {
if(--R.GAS > 0) {
$z3167131672 = $f3167731678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3167731678,
"from":L[4119]});
}
} catch($e3166931670) {
if(R.isCont($e3166931670)) {
var $ss3167331674 = {"from":L[4119],
"go":function(anf_arg440231679) {
return $Hanf_arg996231680(anf_arg440231679,INDENT118169,anf_fun438811623);
}};
$e3166931670.stack[R.EXN_STACKHEIGHT++] = $ss3167331674;
}
if(R.isPyretException($e3166931670)) {
$e3166931670.pyretStack.push(L[4119]);
}
throw $e3166931670;
}
var $ret3167531676 = $Hanf_arg996231680($z3167131672,INDENT118169,anf_fun438811623);
++R.GAS;
return $ret3167531676;
};
var $Hanf_arg996231680 = function(anf_arg440231679,INDENT118169,anf_fun438811623) {
var $z3168331684 = D;
var $f3168931690 = function(_) {
return R.isFunction(anf_fun438811623)?anf_fun438811623.app(INDENT118169,anf_arg440231679):R.ffi.throwNonFunApp(L[2161],anf_fun438811623,[INDENT118169,anf_arg440231679]);
};
try {
if(--R.GAS > 0) {
$z3168331684 = $f3168931690();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3168931690,
"from":L[2161]});
}
} catch($e3168131682) {
if(R.isCont($e3168131682)) {
var $ss3168531686 = {"from":L[2161],
"go":function(ann_DASH_check_DASH_temp438731691) {
return $Hann_DASH_check_DASH_temp996131692(ann_DASH_check_DASH_temp438731691);
}};
$e3168131682.stack[R.EXN_STACKHEIGHT++] = $ss3168531686;
}
if(R.isPyretException($e3168131682)) {
$e3168131682.pyretStack.push(L[2161]);
}
throw $e3168131682;
}
var $ret3168731688 = $Hann_DASH_check_DASH_temp996131692($z3168331684);
++R.GAS;
return $ret3168731688;
};
var $Hann_DASH_check_DASH_temp996131692 = function(ann_DASH_check_DASH_temp438731691) {
return ann_DASH_check_DASH_temp438731691;
};
var $Hanf_arg996011642 = function(anf_arg436911640,self54711641,_plus55,torepr65) {
var anf_arg437031703 = G(self54711641,"name",L[2111]);
var $z3169531696 = D;
var $f3170131702 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg437031703):R.ffi.throwNonFunApp(L[2111],torepr65,[anf_arg437031703]);
};
try {
if(--R.GAS > 0) {
$z3169531696 = $f3170131702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3170131702,
"from":L[2111]});
}
} catch($e3169331694) {
if(R.isCont($e3169331694)) {
var $ss3169731698 = {"from":L[2111],
"go":function(anf_arg437131704) {
return $Hanf_arg995931705(anf_arg437131704,anf_arg436911640,self54711641,_plus55,torepr65);
}};
$e3169331694.stack[R.EXN_STACKHEIGHT++] = $ss3169731698;
}
if(R.isPyretException($e3169331694)) {
$e3169331694.pyretStack.push(L[2111]);
}
throw $e3169331694;
}
var $ret3169931700 = $Hanf_arg995931705($z3169531696,anf_arg436911640,self54711641,_plus55,torepr65);
++R.GAS;
return $ret3169931700;
};
var $Hanf_arg995931705 = function(anf_arg437131704,anf_arg436911640,self54711641,_plus55,torepr65) {
var $z3170831709 = D;
var $f3171431715 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg437131704):R.ffi.throwNonFunApp(L[2111],_plus55,[(", "),anf_arg437131704]);
};
try {
if(--R.GAS > 0) {
$z3170831709 = $f3171431715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3171431715,
"from":L[2111]});
}
} catch($e3170631707) {
if(R.isCont($e3170631707)) {
var $ss3171031711 = {"from":L[2111],
"go":function(anf_arg437231716) {
return $Hanf_arg995831717(anf_arg437231716,anf_arg436911640,self54711641,_plus55,torepr65);
}};
$e3170631707.stack[R.EXN_STACKHEIGHT++] = $ss3171031711;
}
if(R.isPyretException($e3170631707)) {
$e3170631707.pyretStack.push(L[2111]);
}
throw $e3170631707;
}
var $ret3171231713 = $Hanf_arg995831717($z3170831709,anf_arg436911640,self54711641,_plus55,torepr65);
++R.GAS;
return $ret3171231713;
};
var $Hanf_arg995831717 = function(anf_arg437231716,anf_arg436911640,self54711641,_plus55,torepr65) {
var $z3172031721 = D;
var $f3172631727 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg436911640,anf_arg437231716):R.ffi.throwNonFunApp(L[2111],_plus55,[anf_arg436911640,anf_arg437231716]);
};
try {
if(--R.GAS > 0) {
$z3172031721 = $f3172631727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3172631727,
"from":L[2111]});
}
} catch($e3171831719) {
if(R.isCont($e3171831719)) {
var $ss3172231723 = {"from":L[2111],
"go":function(anf_arg437331728) {
return $Hanf_arg995731729(anf_arg437331728,self54711641,_plus55,torepr65);
}};
$e3171831719.stack[R.EXN_STACKHEIGHT++] = $ss3172231723;
}
if(R.isPyretException($e3171831719)) {
$e3171831719.pyretStack.push(L[2111]);
}
throw $e3171831719;
}
var $ret3172431725 = $Hanf_arg995731729($z3172031721,self54711641,_plus55,torepr65);
++R.GAS;
return $ret3172431725;
};
var $Hanf_arg995731729 = function(anf_arg437331728,self54711641,_plus55,torepr65) {
var anf_arg437431740 = G(self54711641,"ann",L[2111]);
var $z3173231733 = D;
var $f3173831739 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg437431740):R.ffi.throwNonFunApp(L[2111],torepr65,[anf_arg437431740]);
};
try {
if(--R.GAS > 0) {
$z3173231733 = $f3173831739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3173831739,
"from":L[2111]});
}
} catch($e3173031731) {
if(R.isCont($e3173031731)) {
var $ss3173431735 = {"from":L[2111],
"go":function(anf_arg437531741) {
return $Hanf_arg995631742(anf_arg437531741,anf_arg437331728,self54711641,_plus55,torepr65);
}};
$e3173031731.stack[R.EXN_STACKHEIGHT++] = $ss3173431735;
}
if(R.isPyretException($e3173031731)) {
$e3173031731.pyretStack.push(L[2111]);
}
throw $e3173031731;
}
var $ret3173631737 = $Hanf_arg995631742($z3173231733,anf_arg437331728,self54711641,_plus55,torepr65);
++R.GAS;
return $ret3173631737;
};
var $Hanf_arg995631742 = function(anf_arg437531741,anf_arg437331728,self54711641,_plus55,torepr65) {
var $z3174531746 = D;
var $f3175131752 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg437531741):R.ffi.throwNonFunApp(L[2111],_plus55,[(", "),anf_arg437531741]);
};
try {
if(--R.GAS > 0) {
$z3174531746 = $f3175131752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3175131752,
"from":L[2111]});
}
} catch($e3174331744) {
if(R.isCont($e3174331744)) {
var $ss3174731748 = {"from":L[2111],
"go":function(anf_arg437631753) {
return $Hanf_arg995531754(anf_arg437631753,anf_arg437331728,self54711641,_plus55,torepr65);
}};
$e3174331744.stack[R.EXN_STACKHEIGHT++] = $ss3174731748;
}
if(R.isPyretException($e3174331744)) {
$e3174331744.pyretStack.push(L[2111]);
}
throw $e3174331744;
}
var $ret3174931750 = $Hanf_arg995531754($z3174531746,anf_arg437331728,self54711641,_plus55,torepr65);
++R.GAS;
return $ret3174931750;
};
var $Hanf_arg995531754 = function(anf_arg437631753,anf_arg437331728,self54711641,_plus55,torepr65) {
var $z3175731758 = D;
var $f3176331764 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg437331728,anf_arg437631753):R.ffi.throwNonFunApp(L[2111],_plus55,[anf_arg437331728,anf_arg437631753]);
};
try {
if(--R.GAS > 0) {
$z3175731758 = $f3176331764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3176331764,
"from":L[2111]});
}
} catch($e3175531756) {
if(R.isCont($e3175531756)) {
var $ss3175931760 = {"from":L[2111],
"go":function(anf_arg437731765) {
return $Hanf_arg995431766(anf_arg437731765,self54711641,_plus55,torepr65);
}};
$e3175531756.stack[R.EXN_STACKHEIGHT++] = $ss3175931760;
}
if(R.isPyretException($e3175531756)) {
$e3175531756.pyretStack.push(L[2111]);
}
throw $e3175531756;
}
var $ret3176131762 = $Hanf_arg995431766($z3175731758,self54711641,_plus55,torepr65);
++R.GAS;
return $ret3176131762;
};
var $Hanf_arg995431766 = function(anf_arg437731765,self54711641,_plus55,torepr65) {
var anf_arg437831777 = G(self54711641,"value",L[2111]);
var $z3176931770 = D;
var $f3177531776 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg437831777):R.ffi.throwNonFunApp(L[2111],torepr65,[anf_arg437831777]);
};
try {
if(--R.GAS > 0) {
$z3176931770 = $f3177531776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3177531776,
"from":L[2111]});
}
} catch($e3176731768) {
if(R.isCont($e3176731768)) {
var $ss3177131772 = {"from":L[2111],
"go":function(anf_arg437931778) {
return $Hanf_arg995331779(anf_arg437931778,anf_arg437731765,_plus55);
}};
$e3176731768.stack[R.EXN_STACKHEIGHT++] = $ss3177131772;
}
if(R.isPyretException($e3176731768)) {
$e3176731768.pyretStack.push(L[2111]);
}
throw $e3176731768;
}
var $ret3177331774 = $Hanf_arg995331779($z3176931770,anf_arg437731765,_plus55);
++R.GAS;
return $ret3177331774;
};
var $Hanf_arg995331779 = function(anf_arg437931778,anf_arg437731765,_plus55) {
var $z3178231783 = D;
var $f3178831789 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg437931778):R.ffi.throwNonFunApp(L[2111],_plus55,[(", "),anf_arg437931778]);
};
try {
if(--R.GAS > 0) {
$z3178231783 = $f3178831789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3178831789,
"from":L[2111]});
}
} catch($e3178031781) {
if(R.isCont($e3178031781)) {
var $ss3178431785 = {"from":L[2111],
"go":function(anf_arg438031790) {
return $Hanf_arg995231791(anf_arg438031790,anf_arg437731765,_plus55);
}};
$e3178031781.stack[R.EXN_STACKHEIGHT++] = $ss3178431785;
}
if(R.isPyretException($e3178031781)) {
$e3178031781.pyretStack.push(L[2111]);
}
throw $e3178031781;
}
var $ret3178631787 = $Hanf_arg995231791($z3178231783,anf_arg437731765,_plus55);
++R.GAS;
return $ret3178631787;
};
var $Hanf_arg995231791 = function(anf_arg438031790,anf_arg437731765,_plus55) {
var $z3179431795 = D;
var $f3180031801 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg437731765,anf_arg438031790):R.ffi.throwNonFunApp(L[2111],_plus55,[anf_arg437731765,anf_arg438031790]);
};
try {
if(--R.GAS > 0) {
$z3179431795 = $f3180031801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3180031801,
"from":L[2111]});
}
} catch($e3179231793) {
if(R.isCont($e3179231793)) {
var $ss3179631797 = {"from":L[2111],
"go":function(anf_arg438131802) {
return $Hanf_arg995131803(anf_arg438131802,_plus55);
}};
$e3179231793.stack[R.EXN_STACKHEIGHT++] = $ss3179631797;
}
if(R.isPyretException($e3179231793)) {
$e3179231793.pyretStack.push(L[2111]);
}
throw $e3179231793;
}
var $ret3179831799 = $Hanf_arg995131803($z3179431795,_plus55);
++R.GAS;
return $ret3179831799;
};
var $Hanf_arg995131803 = function(anf_arg438131802,_plus55) {
var $z3180631807 = D;
var $f3181231813 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg438131802,(")")):R.ffi.throwNonFunApp(L[2111],_plus55,[anf_arg438131802,(")")]);
};
try {
if(--R.GAS > 0) {
$z3180631807 = $f3181231813();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3181231813,
"from":L[2111]});
}
} catch($e3180431805) {
if(R.isCont($e3180431805)) {
var $ss3180831809 = {"from":L[2111],
"go":function(anf_arg438231814) {
return $Hanf_arg995031815(anf_arg438231814,_plus55);
}};
$e3180431805.stack[R.EXN_STACKHEIGHT++] = $ss3180831809;
}
if(R.isPyretException($e3180431805)) {
$e3180431805.pyretStack.push(L[2111]);
}
throw $e3180431805;
}
var $ret3181031811 = $Hanf_arg995031815($z3180631807,_plus55);
++R.GAS;
return $ret3181031811;
};
var $Hanf_arg995031815 = function(anf_arg438231814,_plus55) {
var $z3181831819 = D;
var $f3182431825 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg438231814):R.ffi.throwNonFunApp(L[2111],_plus55,[("("),anf_arg438231814]);
};
try {
if(--R.GAS > 0) {
$z3181831819 = $f3182431825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3182431825,
"from":L[2111]});
}
} catch($e3181631817) {
if(R.isCont($e3181631817)) {
var $ss3182031821 = {"from":L[2111],
"go":function(anf_arg438331826) {
return $Hanf_arg994931827(anf_arg438331826,_plus55);
}};
$e3181631817.stack[R.EXN_STACKHEIGHT++] = $ss3182031821;
}
if(R.isPyretException($e3181631817)) {
$e3181631817.pyretStack.push(L[2111]);
}
throw $e3181631817;
}
var $ret3182231823 = $Hanf_arg994931827($z3181831819,_plus55);
++R.GAS;
return $ret3182231823;
};
var $Hanf_arg994931827 = function(anf_arg438331826,_plus55) {
var $z3183031831 = D;
var $f3183631837 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-mutable-field"),anf_arg438331826):R.ffi.throwNonFunApp(L[2111],_plus55,[("s-mutable-field"),anf_arg438331826]);
};
try {
if(--R.GAS > 0) {
$z3183031831 = $f3183631837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3183631837,
"from":L[2111]});
}
} catch($e3182831829) {
if(R.isCont($e3182831829)) {
var $ss3183231833 = {"from":L[2111],
"go":function(ann_DASH_check_DASH_temp436731838) {
return $Hann_DASH_check_DASH_temp994831839(ann_DASH_check_DASH_temp436731838);
}};
$e3182831829.stack[R.EXN_STACKHEIGHT++] = $ss3183231833;
}
if(R.isPyretException($e3182831829)) {
$e3182831829.pyretStack.push(L[2111]);
}
throw $e3182831829;
}
var $ret3183431835 = $Hann_DASH_check_DASH_temp994831839($z3183031831);
++R.GAS;
return $ret3183431835;
};
var $Hann_DASH_check_DASH_temp994831839 = function(ann_DASH_check_DASH_temp436731838) {
return ann_DASH_check_DASH_temp436731838;
};
var $Hcont_tail_arg994611660 = function(cont_tail_arg436411658,if_helper435311659) {
if(--R.GAS > 0) {
$z3184031841 = R.isFunction(if_helper435311659)?if_helper435311659.app(cont_tail_arg436411658):R.ffi.throwNonFunApp(L[2111],if_helper435311659,[cont_tail_arg436411658]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper435311659)?if_helper435311659.app(cont_tail_arg436411658):R.ffi.throwNonFunApp(L[2111],if_helper435311659,[cont_tail_arg436411658]);
},
"from":L[2111]});
}
++R.GAS;
return $z3184031841;
};
var $Hcont_tail_arg994711675 = function(cont_tail_arg435811674,if_helper435311659) {
if(--R.GAS > 0) {
$z3184231843 = R.isFunction(if_helper435311659)?if_helper435311659.app(cont_tail_arg435811674):R.ffi.throwNonFunApp(L[2111],if_helper435311659,[cont_tail_arg435811674]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper435311659)?if_helper435311659.app(cont_tail_arg435811674):R.ffi.throwNonFunApp(L[2111],if_helper435311659,[cont_tail_arg435811674]);
},
"from":L[2111]});
}
++R.GAS;
return $z3184231843;
};
var $Hanf_arg994511697 = function(anf_arg434511694,INDENT118169,anf_fun434211695,self102111696,str_DASH_colonspace136390,_plus55) {
var $z3184631847 = D;
var $f3185231853 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg434511694,str_DASH_colonspace136390):R.ffi.throwNonFunApp(L[4126],_plus55,[anf_arg434511694,str_DASH_colonspace136390]);
};
try {
if(--R.GAS > 0) {
$z3184631847 = $f3185231853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3185231853,
"from":L[4126]});
}
} catch($e3184431845) {
if(R.isCont($e3184431845)) {
var $ss3184831849 = {"from":L[4126],
"go":function(anf_arg434631854) {
return $Hanf_arg994431855(anf_arg434631854,INDENT118169,anf_fun434211695,self102111696,_plus55);
}};
$e3184431845.stack[R.EXN_STACKHEIGHT++] = $ss3184831849;
}
if(R.isPyretException($e3184431845)) {
$e3184431845.pyretStack.push(L[4126]);
}
throw $e3184431845;
}
var $ret3185031851 = $Hanf_arg994431855($z3184631847,INDENT118169,anf_fun434211695,self102111696,_plus55);
++R.GAS;
return $ret3185031851;
};
var $Hanf_arg994431855 = function(anf_arg434631854,INDENT118169,anf_fun434211695,self102111696,_plus55) {
var anf_bracket434731869 = G(self102111696,"value",L[4129]);
var anf_fun434831866 = G(anf_bracket434731869,"tosource",L[4128]);
var $z3185831859 = D;
var $f3186431865 = function(_) {
return R.isFunction(anf_fun434831866)?anf_fun434831866.app():R.ffi.throwNonFunApp(L[4127],anf_fun434831866,[]);
};
try {
if(--R.GAS > 0) {
$z3185831859 = $f3186431865();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3186431865,
"from":L[4127]});
}
} catch($e3185631857) {
if(R.isCont($e3185631857)) {
var $ss3186031861 = {"from":L[4127],
"go":function(anf_arg434931867) {
return $Hanf_arg994331868(anf_arg434931867,INDENT118169,anf_arg434631854,anf_fun434211695,_plus55);
}};
$e3185631857.stack[R.EXN_STACKHEIGHT++] = $ss3186031861;
}
if(R.isPyretException($e3185631857)) {
$e3185631857.pyretStack.push(L[4127]);
}
throw $e3185631857;
}
var $ret3186231863 = $Hanf_arg994331868($z3185831859,INDENT118169,anf_arg434631854,anf_fun434211695,_plus55);
++R.GAS;
return $ret3186231863;
};
var $Hanf_arg994331868 = function(anf_arg434931867,INDENT118169,anf_arg434631854,anf_fun434211695,_plus55) {
var $z3187231873 = D;
var $f3187831879 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg434631854,anf_arg434931867):R.ffi.throwNonFunApp(L[4126],_plus55,[anf_arg434631854,anf_arg434931867]);
};
try {
if(--R.GAS > 0) {
$z3187231873 = $f3187831879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3187831879,
"from":L[4126]});
}
} catch($e3187031871) {
if(R.isCont($e3187031871)) {
var $ss3187431875 = {"from":L[4126],
"go":function(anf_arg435031880) {
return $Hanf_arg994231881(anf_arg435031880,INDENT118169,anf_fun434211695);
}};
$e3187031871.stack[R.EXN_STACKHEIGHT++] = $ss3187431875;
}
if(R.isPyretException($e3187031871)) {
$e3187031871.pyretStack.push(L[4126]);
}
throw $e3187031871;
}
var $ret3187631877 = $Hanf_arg994231881($z3187231873,INDENT118169,anf_fun434211695);
++R.GAS;
return $ret3187631877;
};
var $Hanf_arg994231881 = function(anf_arg435031880,INDENT118169,anf_fun434211695) {
var $z3188431885 = D;
var $f3189031891 = function(_) {
return R.isFunction(anf_fun434211695)?anf_fun434211695.app(INDENT118169,anf_arg435031880):R.ffi.throwNonFunApp(L[2171],anf_fun434211695,[INDENT118169,anf_arg435031880]);
};
try {
if(--R.GAS > 0) {
$z3188431885 = $f3189031891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3189031891,
"from":L[2171]});
}
} catch($e3188231883) {
if(R.isCont($e3188231883)) {
var $ss3188631887 = {"from":L[2171],
"go":function(ann_DASH_check_DASH_temp434131892) {
return $Hann_DASH_check_DASH_temp994131893(ann_DASH_check_DASH_temp434131892);
}};
$e3188231883.stack[R.EXN_STACKHEIGHT++] = $ss3188631887;
}
if(R.isPyretException($e3188231883)) {
$e3188231883.pyretStack.push(L[2171]);
}
throw $e3188231883;
}
var $ret3188831889 = $Hann_DASH_check_DASH_temp994131893($z3188431885);
++R.GAS;
return $ret3188831889;
};
var $Hann_DASH_check_DASH_temp994131893 = function(ann_DASH_check_DASH_temp434131892) {
return ann_DASH_check_DASH_temp434131892;
};
var $Hanf_arg994011714 = function(anf_arg432711712,self54111713,_plus55,torepr65) {
var anf_arg432831904 = G(self54111713,"name",L[2112]);
var $z3189631897 = D;
var $f3190231903 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg432831904):R.ffi.throwNonFunApp(L[2112],torepr65,[anf_arg432831904]);
};
try {
if(--R.GAS > 0) {
$z3189631897 = $f3190231903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3190231903,
"from":L[2112]});
}
} catch($e3189431895) {
if(R.isCont($e3189431895)) {
var $ss3189831899 = {"from":L[2112],
"go":function(anf_arg432931905) {
return $Hanf_arg993931906(anf_arg432931905,anf_arg432711712,self54111713,_plus55,torepr65);
}};
$e3189431895.stack[R.EXN_STACKHEIGHT++] = $ss3189831899;
}
if(R.isPyretException($e3189431895)) {
$e3189431895.pyretStack.push(L[2112]);
}
throw $e3189431895;
}
var $ret3190031901 = $Hanf_arg993931906($z3189631897,anf_arg432711712,self54111713,_plus55,torepr65);
++R.GAS;
return $ret3190031901;
};
var $Hanf_arg993931906 = function(anf_arg432931905,anf_arg432711712,self54111713,_plus55,torepr65) {
var $z3190931910 = D;
var $f3191531916 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg432931905):R.ffi.throwNonFunApp(L[2112],_plus55,[(", "),anf_arg432931905]);
};
try {
if(--R.GAS > 0) {
$z3190931910 = $f3191531916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3191531916,
"from":L[2112]});
}
} catch($e3190731908) {
if(R.isCont($e3190731908)) {
var $ss3191131912 = {"from":L[2112],
"go":function(anf_arg433031917) {
return $Hanf_arg993831918(anf_arg433031917,anf_arg432711712,self54111713,_plus55,torepr65);
}};
$e3190731908.stack[R.EXN_STACKHEIGHT++] = $ss3191131912;
}
if(R.isPyretException($e3190731908)) {
$e3190731908.pyretStack.push(L[2112]);
}
throw $e3190731908;
}
var $ret3191331914 = $Hanf_arg993831918($z3190931910,anf_arg432711712,self54111713,_plus55,torepr65);
++R.GAS;
return $ret3191331914;
};
var $Hanf_arg993831918 = function(anf_arg433031917,anf_arg432711712,self54111713,_plus55,torepr65) {
var $z3192131922 = D;
var $f3192731928 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg432711712,anf_arg433031917):R.ffi.throwNonFunApp(L[2112],_plus55,[anf_arg432711712,anf_arg433031917]);
};
try {
if(--R.GAS > 0) {
$z3192131922 = $f3192731928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3192731928,
"from":L[2112]});
}
} catch($e3191931920) {
if(R.isCont($e3191931920)) {
var $ss3192331924 = {"from":L[2112],
"go":function(anf_arg433131929) {
return $Hanf_arg993731930(anf_arg433131929,self54111713,_plus55,torepr65);
}};
$e3191931920.stack[R.EXN_STACKHEIGHT++] = $ss3192331924;
}
if(R.isPyretException($e3191931920)) {
$e3191931920.pyretStack.push(L[2112]);
}
throw $e3191931920;
}
var $ret3192531926 = $Hanf_arg993731930($z3192131922,self54111713,_plus55,torepr65);
++R.GAS;
return $ret3192531926;
};
var $Hanf_arg993731930 = function(anf_arg433131929,self54111713,_plus55,torepr65) {
var anf_arg433231941 = G(self54111713,"value",L[2112]);
var $z3193331934 = D;
var $f3193931940 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg433231941):R.ffi.throwNonFunApp(L[2112],torepr65,[anf_arg433231941]);
};
try {
if(--R.GAS > 0) {
$z3193331934 = $f3193931940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3193931940,
"from":L[2112]});
}
} catch($e3193131932) {
if(R.isCont($e3193131932)) {
var $ss3193531936 = {"from":L[2112],
"go":function(anf_arg433331942) {
return $Hanf_arg993631943(anf_arg433331942,anf_arg433131929,_plus55);
}};
$e3193131932.stack[R.EXN_STACKHEIGHT++] = $ss3193531936;
}
if(R.isPyretException($e3193131932)) {
$e3193131932.pyretStack.push(L[2112]);
}
throw $e3193131932;
}
var $ret3193731938 = $Hanf_arg993631943($z3193331934,anf_arg433131929,_plus55);
++R.GAS;
return $ret3193731938;
};
var $Hanf_arg993631943 = function(anf_arg433331942,anf_arg433131929,_plus55) {
var $z3194631947 = D;
var $f3195231953 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg433331942):R.ffi.throwNonFunApp(L[2112],_plus55,[(", "),anf_arg433331942]);
};
try {
if(--R.GAS > 0) {
$z3194631947 = $f3195231953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3195231953,
"from":L[2112]});
}
} catch($e3194431945) {
if(R.isCont($e3194431945)) {
var $ss3194831949 = {"from":L[2112],
"go":function(anf_arg433431954) {
return $Hanf_arg993531955(anf_arg433431954,anf_arg433131929,_plus55);
}};
$e3194431945.stack[R.EXN_STACKHEIGHT++] = $ss3194831949;
}
if(R.isPyretException($e3194431945)) {
$e3194431945.pyretStack.push(L[2112]);
}
throw $e3194431945;
}
var $ret3195031951 = $Hanf_arg993531955($z3194631947,anf_arg433131929,_plus55);
++R.GAS;
return $ret3195031951;
};
var $Hanf_arg993531955 = function(anf_arg433431954,anf_arg433131929,_plus55) {
var $z3195831959 = D;
var $f3196431965 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg433131929,anf_arg433431954):R.ffi.throwNonFunApp(L[2112],_plus55,[anf_arg433131929,anf_arg433431954]);
};
try {
if(--R.GAS > 0) {
$z3195831959 = $f3196431965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3196431965,
"from":L[2112]});
}
} catch($e3195631957) {
if(R.isCont($e3195631957)) {
var $ss3196031961 = {"from":L[2112],
"go":function(anf_arg433531966) {
return $Hanf_arg993431967(anf_arg433531966,_plus55);
}};
$e3195631957.stack[R.EXN_STACKHEIGHT++] = $ss3196031961;
}
if(R.isPyretException($e3195631957)) {
$e3195631957.pyretStack.push(L[2112]);
}
throw $e3195631957;
}
var $ret3196231963 = $Hanf_arg993431967($z3195831959,_plus55);
++R.GAS;
return $ret3196231963;
};
var $Hanf_arg993431967 = function(anf_arg433531966,_plus55) {
var $z3197031971 = D;
var $f3197631977 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg433531966,(")")):R.ffi.throwNonFunApp(L[2112],_plus55,[anf_arg433531966,(")")]);
};
try {
if(--R.GAS > 0) {
$z3197031971 = $f3197631977();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3197631977,
"from":L[2112]});
}
} catch($e3196831969) {
if(R.isCont($e3196831969)) {
var $ss3197231973 = {"from":L[2112],
"go":function(anf_arg433631978) {
return $Hanf_arg993331979(anf_arg433631978,_plus55);
}};
$e3196831969.stack[R.EXN_STACKHEIGHT++] = $ss3197231973;
}
if(R.isPyretException($e3196831969)) {
$e3196831969.pyretStack.push(L[2112]);
}
throw $e3196831969;
}
var $ret3197431975 = $Hanf_arg993331979($z3197031971,_plus55);
++R.GAS;
return $ret3197431975;
};
var $Hanf_arg993331979 = function(anf_arg433631978,_plus55) {
var $z3198231983 = D;
var $f3198831989 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg433631978):R.ffi.throwNonFunApp(L[2112],_plus55,[("("),anf_arg433631978]);
};
try {
if(--R.GAS > 0) {
$z3198231983 = $f3198831989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3198831989,
"from":L[2112]});
}
} catch($e3198031981) {
if(R.isCont($e3198031981)) {
var $ss3198431985 = {"from":L[2112],
"go":function(anf_arg433731990) {
return $Hanf_arg993231991(anf_arg433731990,_plus55);
}};
$e3198031981.stack[R.EXN_STACKHEIGHT++] = $ss3198431985;
}
if(R.isPyretException($e3198031981)) {
$e3198031981.pyretStack.push(L[2112]);
}
throw $e3198031981;
}
var $ret3198631987 = $Hanf_arg993231991($z3198231983,_plus55);
++R.GAS;
return $ret3198631987;
};
var $Hanf_arg993231991 = function(anf_arg433731990,_plus55) {
var $z3199431995 = D;
var $f3200032001 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-data-field"),anf_arg433731990):R.ffi.throwNonFunApp(L[2112],_plus55,[("s-data-field"),anf_arg433731990]);
};
try {
if(--R.GAS > 0) {
$z3199431995 = $f3200032001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3200032001,
"from":L[2112]});
}
} catch($e3199231993) {
if(R.isCont($e3199231993)) {
var $ss3199631997 = {"from":L[2112],
"go":function(ann_DASH_check_DASH_temp432532002) {
return $Hann_DASH_check_DASH_temp993132003(ann_DASH_check_DASH_temp432532002);
}};
$e3199231993.stack[R.EXN_STACKHEIGHT++] = $ss3199631997;
}
if(R.isPyretException($e3199231993)) {
$e3199231993.pyretStack.push(L[2112]);
}
throw $e3199231993;
}
var $ret3199831999 = $Hann_DASH_check_DASH_temp993132003($z3199431995);
++R.GAS;
return $ret3199831999;
};
var $Hann_DASH_check_DASH_temp993132003 = function(ann_DASH_check_DASH_temp432532002) {
return ann_DASH_check_DASH_temp432532002;
};
var $Hcont_tail_arg992911731 = function(cont_tail_arg432211729,if_helper431211730) {
if(--R.GAS > 0) {
$z3200432005 = R.isFunction(if_helper431211730)?if_helper431211730.app(cont_tail_arg432211729):R.ffi.throwNonFunApp(L[2112],if_helper431211730,[cont_tail_arg432211729]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper431211730)?if_helper431211730.app(cont_tail_arg432211729):R.ffi.throwNonFunApp(L[2112],if_helper431211730,[cont_tail_arg432211729]);
},
"from":L[2112]});
}
++R.GAS;
return $z3200432005;
};
var $Hcont_tail_arg993011746 = function(cont_tail_arg431711745,if_helper431211730) {
if(--R.GAS > 0) {
$z3200632007 = R.isFunction(if_helper431211730)?if_helper431211730.app(cont_tail_arg431711745):R.ffi.throwNonFunApp(L[2112],if_helper431211730,[cont_tail_arg431711745]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper431211730)?if_helper431211730.app(cont_tail_arg431711745):R.ffi.throwNonFunApp(L[2112],if_helper431211730,[cont_tail_arg431711745]);
},
"from":L[2112]});
}
++R.GAS;
return $z3200632007;
};
var $Hann_DASH_check_DASH_temp992811768 = function(ann_DASH_check_DASH_temp430311767) {
return ann_DASH_check_DASH_temp430311767;
};
var $Hanf_arg992711781 = function(anf_arg430711780,_plus55,raise62) {
var $z3201032011 = D;
var $f3201632017 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg430711780):R.ffi.throwNonFunApp(L[4130],_plus55,[("No visitor field for "),anf_arg430711780]);
};
try {
if(--R.GAS > 0) {
$z3201032011 = $f3201632017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3201632017,
"from":L[4130]});
}
} catch($e3200832009) {
if(R.isCont($e3200832009)) {
var $ss3201232013 = {"from":L[4130],
"go":function(anf_arg430832018) {
return $Hanf_arg992632019(anf_arg430832018,raise62);
}};
$e3200832009.stack[R.EXN_STACKHEIGHT++] = $ss3201232013;
}
if(R.isPyretException($e3200832009)) {
$e3200832009.pyretStack.push(L[4130]);
}
throw $e3200832009;
}
var $ret3201432015 = $Hanf_arg992632019($z3201032011,raise62);
++R.GAS;
return $ret3201432015;
};
var $Hanf_arg992632019 = function(anf_arg430832018,raise62) {
var $z3202232023 = D;
var $f3202832029 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg430832018):R.ffi.throwNonFunApp(L[2177],raise62,[anf_arg430832018]);
};
try {
if(--R.GAS > 0) {
$z3202232023 = $f3202832029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3202832029,
"from":L[2177]});
}
} catch($e3202032021) {
if(R.isCont($e3202032021)) {
var $ss3202432025 = {"from":L[2177],
"go":function(ann_DASH_check_DASH_temp430532030) {
return $Hann_DASH_check_DASH_temp992532031(ann_DASH_check_DASH_temp430532030);
}};
$e3202032021.stack[R.EXN_STACKHEIGHT++] = $ss3202432025;
}
if(R.isPyretException($e3202032021)) {
$e3202032021.pyretStack.push(L[2177]);
}
throw $e3202032021;
}
var $ret3202632027 = $Hann_DASH_check_DASH_temp992532031($z3202232023);
++R.GAS;
return $ret3202632027;
};
var $Hann_DASH_check_DASH_temp992532031 = function(ann_DASH_check_DASH_temp430532030) {
return ann_DASH_check_DASH_temp430532030;
};
var $Hif_DASH_992411812 = function(if_DASH_53511810,INDENT118169,PP170,self101311811,str_DASH_coloncolon135377,_plus55) {
var if_helper425232044 = R.makeFunction(function(if_helper_arg425332103) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2190],1,arguments);
}
var ann_DASH_check_DASH_temp425032104 = if_helper_arg425332103;
return ann_DASH_check_DASH_temp425032104;
});
var anf_if425632102 = R.isBoolean(if_DASH_53511810);
if(R.isPyretTrue(anf_if425632102)) {
if(R.isPyretTrue(if_DASH_53511810)) {
var if_DASH_53632060 = G(self101311811,"shadows",L[4136]);
var anf_if428332064 = R.isBoolean(if_DASH_53632060);
if(R.isPyretTrue(anf_if428332064)) {
if(R.isPyretTrue(if_DASH_53632060)) {
var anf_fun428832042 = G(PP170,"str",L[4132]);
var $z3203432035 = D;
var $f3204032041 = function(_) {
return R.isFunction(anf_fun428832042)?anf_fun428832042.app(("shadow ")):R.ffi.throwNonFunApp(L[4131],anf_fun428832042,[("shadow ")]);
};
try {
if(--R.GAS > 0) {
$z3203432035 = $f3204032041();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3204032041,
"from":L[4131]});
}
} catch($e3203232033) {
if(R.isCont($e3203232033)) {
var $ss3203632037 = {"from":L[4131],
"go":function(anf_arg428932043) {
return $Hanf_arg991432045(anf_arg428932043,if_helper425232044,self101311811,_plus55);
}};
$e3203232033.stack[R.EXN_STACKHEIGHT++] = $ss3203632037;
}
if(R.isPyretException($e3203232033)) {
$e3203232033.pyretStack.push(L[4131]);
}
throw $e3203232033;
}
var $ret3203832039 = $Hanf_arg991432045($z3203432035,if_helper425232044,self101311811,_plus55);
++R.GAS;
return $ret3203832039;
} else {
var anf_bracket428432059 = G(self101311811,"id",L[4135]);
var anf_fun428532056 = G(anf_bracket428432059,"tosource",L[4134]);
var $z3204832049 = D;
var $f3205432055 = function(_) {
return R.isFunction(anf_fun428532056)?anf_fun428532056.app():R.ffi.throwNonFunApp(L[4133],anf_fun428532056,[]);
};
try {
if(--R.GAS > 0) {
$z3204832049 = $f3205432055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3205432055,
"from":L[4133]});
}
} catch($e3204632047) {
if(R.isCont($e3204632047)) {
var $ss3205032051 = {"from":L[4133],
"go":function(cont_tail_arg428632057) {
return $Hcont_tail_arg991532058(cont_tail_arg428632057,if_helper425232044);
}};
$e3204632047.stack[R.EXN_STACKHEIGHT++] = $ss3205032051;
}
if(R.isPyretException($e3204632047)) {
$e3204632047.pyretStack.push(L[4133]);
}
throw $e3204632047;
}
var $ret3205232053 = $Hcont_tail_arg991532058($z3204832049,if_helper425232044);
++R.GAS;
return $ret3205232053;
}
} else {
var cont_tail_arg428132063 = R.throwNonBooleanCondition(L[4136],("if"),if_DASH_53632060);
if(--R.GAS > 0) {
$z3206132062 = R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg428132063):R.ffi.throwNonFunApp(L[4136],if_helper425232044,[cont_tail_arg428132063]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg428132063):R.ffi.throwNonFunApp(L[4136],if_helper425232044,[cont_tail_arg428132063]);
},
"from":L[4136]});
}
++R.GAS;
return $z3206132062;
}
} else {
var if_DASH_53432094 = G(self101311811,"shadows",L[4144]);
var anf_if425932098 = R.isBoolean(if_DASH_53432094);
if(R.isPyretTrue(anf_if425932098)) {
if(R.isPyretTrue(if_DASH_53432094)) {
var anf_fun426932077 = G(PP170,"infix",L[4139]);
var anf_fun427032075 = G(PP170,"str",L[4138]);
var $z3206732068 = D;
var $f3207332074 = function(_) {
return R.isFunction(anf_fun427032075)?anf_fun427032075.app(("shadow ")):R.ffi.throwNonFunApp(L[4137],anf_fun427032075,[("shadow ")]);
};
try {
if(--R.GAS > 0) {
$z3206732068 = $f3207332074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3207332074,
"from":L[4137]});
}
} catch($e3206532066) {
if(R.isCont($e3206532066)) {
var $ss3206932070 = {"from":L[4137],
"go":function(anf_arg427132076) {
return $Hanf_arg992032078(anf_arg427132076,INDENT118169,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377,_plus55);
}};
$e3206532066.stack[R.EXN_STACKHEIGHT++] = $ss3206932070;
}
if(R.isPyretException($e3206532066)) {
$e3206532066.pyretStack.push(L[4137]);
}
throw $e3206532066;
}
var $ret3207132072 = $Hanf_arg992032078($z3206732068,INDENT118169,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377,_plus55);
++R.GAS;
return $ret3207132072;
} else {
var anf_fun426032091 = G(PP170,"infix",L[4143]);
var anf_bracket426132093 = G(self101311811,"id",L[4142]);
var anf_fun426232089 = G(anf_bracket426132093,"tosource",L[4141]);
var $z3208132082 = D;
var $f3208732088 = function(_) {
return R.isFunction(anf_fun426232089)?anf_fun426232089.app():R.ffi.throwNonFunApp(L[4140],anf_fun426232089,[]);
};
try {
if(--R.GAS > 0) {
$z3208132082 = $f3208732088();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3208732088,
"from":L[4140]});
}
} catch($e3207932080) {
if(R.isCont($e3207932080)) {
var $ss3208332084 = {"from":L[4140],
"go":function(anf_arg426332090) {
return $Hanf_arg992332092(anf_arg426332090,INDENT118169,anf_fun426032091,if_helper425232044,self101311811,str_DASH_coloncolon135377);
}};
$e3207932080.stack[R.EXN_STACKHEIGHT++] = $ss3208332084;
}
if(R.isPyretException($e3207932080)) {
$e3207932080.pyretStack.push(L[4140]);
}
throw $e3207932080;
}
var $ret3208532086 = $Hanf_arg992332092($z3208132082,INDENT118169,anf_fun426032091,if_helper425232044,self101311811,str_DASH_coloncolon135377);
++R.GAS;
return $ret3208532086;
}
} else {
var cont_tail_arg425732097 = R.throwNonBooleanCondition(L[4144],("if"),if_DASH_53432094);
if(--R.GAS > 0) {
$z3209532096 = R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg425732097):R.ffi.throwNonFunApp(L[4144],if_helper425232044,[cont_tail_arg425732097]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg425732097):R.ffi.throwNonFunApp(L[4144],if_helper425232044,[cont_tail_arg425732097]);
},
"from":L[4144]});
}
++R.GAS;
return $z3209532096;
}
}
} else {
var cont_tail_arg425432101 = R.throwNonBooleanCondition(L[2190],("if"),if_DASH_53511810);
if(--R.GAS > 0) {
$z3209932100 = R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg425432101):R.ffi.throwNonFunApp(L[2190],if_helper425232044,[cont_tail_arg425432101]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg425432101):R.ffi.throwNonFunApp(L[2190],if_helper425232044,[cont_tail_arg425432101]);
},
"from":L[2190]});
}
++R.GAS;
return $z3209932100;
}
};
var $Hanf_arg991432045 = function(anf_arg428932043,if_helper425232044,self101311811,_plus55) {
var anf_bracket429032118 = G(self101311811,"id",L[4147]);
var anf_fun429132115 = G(anf_bracket429032118,"tosource",L[4146]);
var $z3210732108 = D;
var $f3211332114 = function(_) {
return R.isFunction(anf_fun429132115)?anf_fun429132115.app():R.ffi.throwNonFunApp(L[4145],anf_fun429132115,[]);
};
try {
if(--R.GAS > 0) {
$z3210732108 = $f3211332114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3211332114,
"from":L[4145]});
}
} catch($e3210532106) {
if(R.isCont($e3210532106)) {
var $ss3210932110 = {"from":L[4145],
"go":function(anf_arg429232116) {
return $Hanf_arg991332117(anf_arg429232116,anf_arg428932043,if_helper425232044,_plus55);
}};
$e3210532106.stack[R.EXN_STACKHEIGHT++] = $ss3210932110;
}
if(R.isPyretException($e3210532106)) {
$e3210532106.pyretStack.push(L[4145]);
}
throw $e3210532106;
}
var $ret3211132112 = $Hanf_arg991332117($z3210732108,anf_arg428932043,if_helper425232044,_plus55);
++R.GAS;
return $ret3211132112;
};
var $Hanf_arg991332117 = function(anf_arg429232116,anf_arg428932043,if_helper425232044,_plus55) {
var $z3212132122 = D;
var $f3212732128 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg428932043,anf_arg429232116):R.ffi.throwNonFunApp(L[4148],_plus55,[anf_arg428932043,anf_arg429232116]);
};
try {
if(--R.GAS > 0) {
$z3212132122 = $f3212732128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3212732128,
"from":L[4148]});
}
} catch($e3211932120) {
if(R.isCont($e3211932120)) {
var $ss3212332124 = {"from":L[4148],
"go":function(cont_tail_arg429332129) {
return $Hcont_tail_arg991232130(cont_tail_arg429332129,if_helper425232044);
}};
$e3211932120.stack[R.EXN_STACKHEIGHT++] = $ss3212332124;
}
if(R.isPyretException($e3211932120)) {
$e3211932120.pyretStack.push(L[4148]);
}
throw $e3211932120;
}
var $ret3212532126 = $Hcont_tail_arg991232130($z3212132122,if_helper425232044);
++R.GAS;
return $ret3212532126;
};
var $Hcont_tail_arg991232130 = function(cont_tail_arg429332129,if_helper425232044) {
if(--R.GAS > 0) {
$z3213132132 = R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg429332129):R.ffi.throwNonFunApp(L[4148],if_helper425232044,[cont_tail_arg429332129]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg429332129):R.ffi.throwNonFunApp(L[4148],if_helper425232044,[cont_tail_arg429332129]);
},
"from":L[4148]});
}
++R.GAS;
return $z3213132132;
};
var $Hcont_tail_arg991532058 = function(cont_tail_arg428632057,if_helper425232044) {
if(--R.GAS > 0) {
$z3213332134 = R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg428632057):R.ffi.throwNonFunApp(L[4133],if_helper425232044,[cont_tail_arg428632057]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg428632057):R.ffi.throwNonFunApp(L[4133],if_helper425232044,[cont_tail_arg428632057]);
},
"from":L[4133]});
}
++R.GAS;
return $z3213332134;
};
var $Hanf_arg992032078 = function(anf_arg427132076,INDENT118169,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377,_plus55) {
var anf_bracket427232148 = G(self101311811,"id",L[4151]);
var anf_fun427332145 = G(anf_bracket427232148,"tosource",L[4150]);
var $z3213732138 = D;
var $f3214332144 = function(_) {
return R.isFunction(anf_fun427332145)?anf_fun427332145.app():R.ffi.throwNonFunApp(L[4149],anf_fun427332145,[]);
};
try {
if(--R.GAS > 0) {
$z3213732138 = $f3214332144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3214332144,
"from":L[4149]});
}
} catch($e3213532136) {
if(R.isCont($e3213532136)) {
var $ss3213932140 = {"from":L[4149],
"go":function(anf_arg427432146) {
return $Hanf_arg991932147(anf_arg427432146,INDENT118169,anf_arg427132076,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377,_plus55);
}};
$e3213532136.stack[R.EXN_STACKHEIGHT++] = $ss3213932140;
}
if(R.isPyretException($e3213532136)) {
$e3213532136.pyretStack.push(L[4149]);
}
throw $e3213532136;
}
var $ret3214132142 = $Hanf_arg991932147($z3213732138,INDENT118169,anf_arg427132076,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377,_plus55);
++R.GAS;
return $ret3214132142;
};
var $Hanf_arg991932147 = function(anf_arg427432146,INDENT118169,anf_arg427132076,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377,_plus55) {
var $z3215132152 = D;
var $f3215732158 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg427132076,anf_arg427432146):R.ffi.throwNonFunApp(L[4152],_plus55,[anf_arg427132076,anf_arg427432146]);
};
try {
if(--R.GAS > 0) {
$z3215132152 = $f3215732158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3215732158,
"from":L[4152]});
}
} catch($e3214932150) {
if(R.isCont($e3214932150)) {
var $ss3215332154 = {"from":L[4152],
"go":function(anf_arg427532159) {
return $Hanf_arg991832160(anf_arg427532159,INDENT118169,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377);
}};
$e3214932150.stack[R.EXN_STACKHEIGHT++] = $ss3215332154;
}
if(R.isPyretException($e3214932150)) {
$e3214932150.pyretStack.push(L[4152]);
}
throw $e3214932150;
}
var $ret3215532156 = $Hanf_arg991832160($z3215132152,INDENT118169,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377);
++R.GAS;
return $ret3215532156;
};
var $Hanf_arg991832160 = function(anf_arg427532159,INDENT118169,anf_fun426932077,if_helper425232044,self101311811,str_DASH_coloncolon135377) {
var anf_bracket427632174 = G(self101311811,"ann",L[4155]);
var anf_fun427732171 = G(anf_bracket427632174,"tosource",L[4154]);
var $z3216332164 = D;
var $f3216932170 = function(_) {
return R.isFunction(anf_fun427732171)?anf_fun427732171.app():R.ffi.throwNonFunApp(L[4153],anf_fun427732171,[]);
};
try {
if(--R.GAS > 0) {
$z3216332164 = $f3216932170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3216932170,
"from":L[4153]});
}
} catch($e3216132162) {
if(R.isCont($e3216132162)) {
var $ss3216532166 = {"from":L[4153],
"go":function(anf_arg427832172) {
return $Hanf_arg991732173(anf_arg427832172,INDENT118169,anf_arg427532159,anf_fun426932077,if_helper425232044,str_DASH_coloncolon135377);
}};
$e3216132162.stack[R.EXN_STACKHEIGHT++] = $ss3216532166;
}
if(R.isPyretException($e3216132162)) {
$e3216132162.pyretStack.push(L[4153]);
}
throw $e3216132162;
}
var $ret3216732168 = $Hanf_arg991732173($z3216332164,INDENT118169,anf_arg427532159,anf_fun426932077,if_helper425232044,str_DASH_coloncolon135377);
++R.GAS;
return $ret3216732168;
};
var $Hanf_arg991732173 = function(anf_arg427832172,INDENT118169,anf_arg427532159,anf_fun426932077,if_helper425232044,str_DASH_coloncolon135377) {
var $z3217732178 = D;
var $f3218332184 = function(_) {
return R.isFunction(anf_fun426932077)?anf_fun426932077.app(INDENT118169,(1),str_DASH_coloncolon135377,anf_arg427532159,anf_arg427832172):R.ffi.throwNonFunApp(L[4156],anf_fun426932077,[INDENT118169,(1),str_DASH_coloncolon135377,anf_arg427532159,anf_arg427832172]);
};
try {
if(--R.GAS > 0) {
$z3217732178 = $f3218332184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3218332184,
"from":L[4156]});
}
} catch($e3217532176) {
if(R.isCont($e3217532176)) {
var $ss3217932180 = {"from":L[4156],
"go":function(cont_tail_arg427932185) {
return $Hcont_tail_arg991632186(cont_tail_arg427932185,if_helper425232044);
}};
$e3217532176.stack[R.EXN_STACKHEIGHT++] = $ss3217932180;
}
if(R.isPyretException($e3217532176)) {
$e3217532176.pyretStack.push(L[4156]);
}
throw $e3217532176;
}
var $ret3218132182 = $Hcont_tail_arg991632186($z3217732178,if_helper425232044);
++R.GAS;
return $ret3218132182;
};
var $Hcont_tail_arg991632186 = function(cont_tail_arg427932185,if_helper425232044) {
if(--R.GAS > 0) {
$z3218732188 = R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg427932185):R.ffi.throwNonFunApp(L[4156],if_helper425232044,[cont_tail_arg427932185]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg427932185):R.ffi.throwNonFunApp(L[4156],if_helper425232044,[cont_tail_arg427932185]);
},
"from":L[4156]});
}
++R.GAS;
return $z3218732188;
};
var $Hanf_arg992332092 = function(anf_arg426332090,INDENT118169,anf_fun426032091,if_helper425232044,self101311811,str_DASH_coloncolon135377) {
var anf_bracket426432202 = G(self101311811,"ann",L[4159]);
var anf_fun426532199 = G(anf_bracket426432202,"tosource",L[4158]);
var $z3219132192 = D;
var $f3219732198 = function(_) {
return R.isFunction(anf_fun426532199)?anf_fun426532199.app():R.ffi.throwNonFunApp(L[4157],anf_fun426532199,[]);
};
try {
if(--R.GAS > 0) {
$z3219132192 = $f3219732198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3219732198,
"from":L[4157]});
}
} catch($e3218932190) {
if(R.isCont($e3218932190)) {
var $ss3219332194 = {"from":L[4157],
"go":function(anf_arg426632200) {
return $Hanf_arg992232201(anf_arg426632200,INDENT118169,anf_arg426332090,anf_fun426032091,if_helper425232044,str_DASH_coloncolon135377);
}};
$e3218932190.stack[R.EXN_STACKHEIGHT++] = $ss3219332194;
}
if(R.isPyretException($e3218932190)) {
$e3218932190.pyretStack.push(L[4157]);
}
throw $e3218932190;
}
var $ret3219532196 = $Hanf_arg992232201($z3219132192,INDENT118169,anf_arg426332090,anf_fun426032091,if_helper425232044,str_DASH_coloncolon135377);
++R.GAS;
return $ret3219532196;
};
var $Hanf_arg992232201 = function(anf_arg426632200,INDENT118169,anf_arg426332090,anf_fun426032091,if_helper425232044,str_DASH_coloncolon135377) {
var $z3220532206 = D;
var $f3221132212 = function(_) {
return R.isFunction(anf_fun426032091)?anf_fun426032091.app(INDENT118169,(1),str_DASH_coloncolon135377,anf_arg426332090,anf_arg426632200):R.ffi.throwNonFunApp(L[4160],anf_fun426032091,[INDENT118169,(1),str_DASH_coloncolon135377,anf_arg426332090,anf_arg426632200]);
};
try {
if(--R.GAS > 0) {
$z3220532206 = $f3221132212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3221132212,
"from":L[4160]});
}
} catch($e3220332204) {
if(R.isCont($e3220332204)) {
var $ss3220732208 = {"from":L[4160],
"go":function(cont_tail_arg426732213) {
return $Hcont_tail_arg992132214(cont_tail_arg426732213,if_helper425232044);
}};
$e3220332204.stack[R.EXN_STACKHEIGHT++] = $ss3220732208;
}
if(R.isPyretException($e3220332204)) {
$e3220332204.pyretStack.push(L[4160]);
}
throw $e3220332204;
}
var $ret3220932210 = $Hcont_tail_arg992132214($z3220532206,if_helper425232044);
++R.GAS;
return $ret3220932210;
};
var $Hcont_tail_arg992132214 = function(cont_tail_arg426732213,if_helper425232044) {
if(--R.GAS > 0) {
$z3221532216 = R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg426732213):R.ffi.throwNonFunApp(L[4160],if_helper425232044,[cont_tail_arg426732213]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper425232044)?if_helper425232044.app(cont_tail_arg426732213):R.ffi.throwNonFunApp(L[4160],if_helper425232044,[cont_tail_arg426732213]);
},
"from":L[4160]});
}
++R.GAS;
return $z3221532216;
};
var $Hanf_arg991111826 = function(anf_arg423411824,self53211825,_plus55,torepr65) {
var anf_arg423532227 = G(self53211825,"shadows",L[2181]);
var $z3221932220 = D;
var $f3222532226 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg423532227):R.ffi.throwNonFunApp(L[2181],torepr65,[anf_arg423532227]);
};
try {
if(--R.GAS > 0) {
$z3221932220 = $f3222532226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3222532226,
"from":L[2181]});
}
} catch($e3221732218) {
if(R.isCont($e3221732218)) {
var $ss3222132222 = {"from":L[2181],
"go":function(anf_arg423632228) {
return $Hanf_arg991032229(anf_arg423632228,anf_arg423411824,self53211825,_plus55,torepr65);
}};
$e3221732218.stack[R.EXN_STACKHEIGHT++] = $ss3222132222;
}
if(R.isPyretException($e3221732218)) {
$e3221732218.pyretStack.push(L[2181]);
}
throw $e3221732218;
}
var $ret3222332224 = $Hanf_arg991032229($z3221932220,anf_arg423411824,self53211825,_plus55,torepr65);
++R.GAS;
return $ret3222332224;
};
var $Hanf_arg991032229 = function(anf_arg423632228,anf_arg423411824,self53211825,_plus55,torepr65) {
var $z3223232233 = D;
var $f3223832239 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg423632228):R.ffi.throwNonFunApp(L[2181],_plus55,[(", "),anf_arg423632228]);
};
try {
if(--R.GAS > 0) {
$z3223232233 = $f3223832239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3223832239,
"from":L[2181]});
}
} catch($e3223032231) {
if(R.isCont($e3223032231)) {
var $ss3223432235 = {"from":L[2181],
"go":function(anf_arg423732240) {
return $Hanf_arg990932241(anf_arg423732240,anf_arg423411824,self53211825,_plus55,torepr65);
}};
$e3223032231.stack[R.EXN_STACKHEIGHT++] = $ss3223432235;
}
if(R.isPyretException($e3223032231)) {
$e3223032231.pyretStack.push(L[2181]);
}
throw $e3223032231;
}
var $ret3223632237 = $Hanf_arg990932241($z3223232233,anf_arg423411824,self53211825,_plus55,torepr65);
++R.GAS;
return $ret3223632237;
};
var $Hanf_arg990932241 = function(anf_arg423732240,anf_arg423411824,self53211825,_plus55,torepr65) {
var $z3224432245 = D;
var $f3225032251 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg423411824,anf_arg423732240):R.ffi.throwNonFunApp(L[2181],_plus55,[anf_arg423411824,anf_arg423732240]);
};
try {
if(--R.GAS > 0) {
$z3224432245 = $f3225032251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3225032251,
"from":L[2181]});
}
} catch($e3224232243) {
if(R.isCont($e3224232243)) {
var $ss3224632247 = {"from":L[2181],
"go":function(anf_arg423832252) {
return $Hanf_arg990832253(anf_arg423832252,self53211825,_plus55,torepr65);
}};
$e3224232243.stack[R.EXN_STACKHEIGHT++] = $ss3224632247;
}
if(R.isPyretException($e3224232243)) {
$e3224232243.pyretStack.push(L[2181]);
}
throw $e3224232243;
}
var $ret3224832249 = $Hanf_arg990832253($z3224432245,self53211825,_plus55,torepr65);
++R.GAS;
return $ret3224832249;
};
var $Hanf_arg990832253 = function(anf_arg423832252,self53211825,_plus55,torepr65) {
var anf_arg423932264 = G(self53211825,"id",L[2181]);
var $z3225632257 = D;
var $f3226232263 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg423932264):R.ffi.throwNonFunApp(L[2181],torepr65,[anf_arg423932264]);
};
try {
if(--R.GAS > 0) {
$z3225632257 = $f3226232263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3226232263,
"from":L[2181]});
}
} catch($e3225432255) {
if(R.isCont($e3225432255)) {
var $ss3225832259 = {"from":L[2181],
"go":function(anf_arg424032265) {
return $Hanf_arg990732266(anf_arg424032265,anf_arg423832252,self53211825,_plus55,torepr65);
}};
$e3225432255.stack[R.EXN_STACKHEIGHT++] = $ss3225832259;
}
if(R.isPyretException($e3225432255)) {
$e3225432255.pyretStack.push(L[2181]);
}
throw $e3225432255;
}
var $ret3226032261 = $Hanf_arg990732266($z3225632257,anf_arg423832252,self53211825,_plus55,torepr65);
++R.GAS;
return $ret3226032261;
};
var $Hanf_arg990732266 = function(anf_arg424032265,anf_arg423832252,self53211825,_plus55,torepr65) {
var $z3226932270 = D;
var $f3227532276 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg424032265):R.ffi.throwNonFunApp(L[2181],_plus55,[(", "),anf_arg424032265]);
};
try {
if(--R.GAS > 0) {
$z3226932270 = $f3227532276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3227532276,
"from":L[2181]});
}
} catch($e3226732268) {
if(R.isCont($e3226732268)) {
var $ss3227132272 = {"from":L[2181],
"go":function(anf_arg424132277) {
return $Hanf_arg990632278(anf_arg424132277,anf_arg423832252,self53211825,_plus55,torepr65);
}};
$e3226732268.stack[R.EXN_STACKHEIGHT++] = $ss3227132272;
}
if(R.isPyretException($e3226732268)) {
$e3226732268.pyretStack.push(L[2181]);
}
throw $e3226732268;
}
var $ret3227332274 = $Hanf_arg990632278($z3226932270,anf_arg423832252,self53211825,_plus55,torepr65);
++R.GAS;
return $ret3227332274;
};
var $Hanf_arg990632278 = function(anf_arg424132277,anf_arg423832252,self53211825,_plus55,torepr65) {
var $z3228132282 = D;
var $f3228732288 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg423832252,anf_arg424132277):R.ffi.throwNonFunApp(L[2181],_plus55,[anf_arg423832252,anf_arg424132277]);
};
try {
if(--R.GAS > 0) {
$z3228132282 = $f3228732288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3228732288,
"from":L[2181]});
}
} catch($e3227932280) {
if(R.isCont($e3227932280)) {
var $ss3228332284 = {"from":L[2181],
"go":function(anf_arg424232289) {
return $Hanf_arg990532290(anf_arg424232289,self53211825,_plus55,torepr65);
}};
$e3227932280.stack[R.EXN_STACKHEIGHT++] = $ss3228332284;
}
if(R.isPyretException($e3227932280)) {
$e3227932280.pyretStack.push(L[2181]);
}
throw $e3227932280;
}
var $ret3228532286 = $Hanf_arg990532290($z3228132282,self53211825,_plus55,torepr65);
++R.GAS;
return $ret3228532286;
};
var $Hanf_arg990532290 = function(anf_arg424232289,self53211825,_plus55,torepr65) {
var anf_arg424332301 = G(self53211825,"ann",L[2181]);
var $z3229332294 = D;
var $f3229932300 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg424332301):R.ffi.throwNonFunApp(L[2181],torepr65,[anf_arg424332301]);
};
try {
if(--R.GAS > 0) {
$z3229332294 = $f3229932300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3229932300,
"from":L[2181]});
}
} catch($e3229132292) {
if(R.isCont($e3229132292)) {
var $ss3229532296 = {"from":L[2181],
"go":function(anf_arg424432302) {
return $Hanf_arg990432303(anf_arg424432302,anf_arg424232289,_plus55);
}};
$e3229132292.stack[R.EXN_STACKHEIGHT++] = $ss3229532296;
}
if(R.isPyretException($e3229132292)) {
$e3229132292.pyretStack.push(L[2181]);
}
throw $e3229132292;
}
var $ret3229732298 = $Hanf_arg990432303($z3229332294,anf_arg424232289,_plus55);
++R.GAS;
return $ret3229732298;
};
var $Hanf_arg990432303 = function(anf_arg424432302,anf_arg424232289,_plus55) {
var $z3230632307 = D;
var $f3231232313 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg424432302):R.ffi.throwNonFunApp(L[2181],_plus55,[(", "),anf_arg424432302]);
};
try {
if(--R.GAS > 0) {
$z3230632307 = $f3231232313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3231232313,
"from":L[2181]});
}
} catch($e3230432305) {
if(R.isCont($e3230432305)) {
var $ss3230832309 = {"from":L[2181],
"go":function(anf_arg424532314) {
return $Hanf_arg990332315(anf_arg424532314,anf_arg424232289,_plus55);
}};
$e3230432305.stack[R.EXN_STACKHEIGHT++] = $ss3230832309;
}
if(R.isPyretException($e3230432305)) {
$e3230432305.pyretStack.push(L[2181]);
}
throw $e3230432305;
}
var $ret3231032311 = $Hanf_arg990332315($z3230632307,anf_arg424232289,_plus55);
++R.GAS;
return $ret3231032311;
};
var $Hanf_arg990332315 = function(anf_arg424532314,anf_arg424232289,_plus55) {
var $z3231832319 = D;
var $f3232432325 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg424232289,anf_arg424532314):R.ffi.throwNonFunApp(L[2181],_plus55,[anf_arg424232289,anf_arg424532314]);
};
try {
if(--R.GAS > 0) {
$z3231832319 = $f3232432325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3232432325,
"from":L[2181]});
}
} catch($e3231632317) {
if(R.isCont($e3231632317)) {
var $ss3232032321 = {"from":L[2181],
"go":function(anf_arg424632326) {
return $Hanf_arg990232327(anf_arg424632326,_plus55);
}};
$e3231632317.stack[R.EXN_STACKHEIGHT++] = $ss3232032321;
}
if(R.isPyretException($e3231632317)) {
$e3231632317.pyretStack.push(L[2181]);
}
throw $e3231632317;
}
var $ret3232232323 = $Hanf_arg990232327($z3231832319,_plus55);
++R.GAS;
return $ret3232232323;
};
var $Hanf_arg990232327 = function(anf_arg424632326,_plus55) {
var $z3233032331 = D;
var $f3233632337 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg424632326,(")")):R.ffi.throwNonFunApp(L[2181],_plus55,[anf_arg424632326,(")")]);
};
try {
if(--R.GAS > 0) {
$z3233032331 = $f3233632337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3233632337,
"from":L[2181]});
}
} catch($e3232832329) {
if(R.isCont($e3232832329)) {
var $ss3233232333 = {"from":L[2181],
"go":function(anf_arg424732338) {
return $Hanf_arg990132339(anf_arg424732338,_plus55);
}};
$e3232832329.stack[R.EXN_STACKHEIGHT++] = $ss3233232333;
}
if(R.isPyretException($e3232832329)) {
$e3232832329.pyretStack.push(L[2181]);
}
throw $e3232832329;
}
var $ret3233432335 = $Hanf_arg990132339($z3233032331,_plus55);
++R.GAS;
return $ret3233432335;
};
var $Hanf_arg990132339 = function(anf_arg424732338,_plus55) {
var $z3234232343 = D;
var $f3234832349 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg424732338):R.ffi.throwNonFunApp(L[2181],_plus55,[("("),anf_arg424732338]);
};
try {
if(--R.GAS > 0) {
$z3234232343 = $f3234832349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3234832349,
"from":L[2181]});
}
} catch($e3234032341) {
if(R.isCont($e3234032341)) {
var $ss3234432345 = {"from":L[2181],
"go":function(anf_arg424832350) {
return $Hanf_arg990032351(anf_arg424832350,_plus55);
}};
$e3234032341.stack[R.EXN_STACKHEIGHT++] = $ss3234432345;
}
if(R.isPyretException($e3234032341)) {
$e3234032341.pyretStack.push(L[2181]);
}
throw $e3234032341;
}
var $ret3234632347 = $Hanf_arg990032351($z3234232343,_plus55);
++R.GAS;
return $ret3234632347;
};
var $Hanf_arg990032351 = function(anf_arg424832350,_plus55) {
var $z3235432355 = D;
var $f3236032361 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-bind"),anf_arg424832350):R.ffi.throwNonFunApp(L[2181],_plus55,[("s-bind"),anf_arg424832350]);
};
try {
if(--R.GAS > 0) {
$z3235432355 = $f3236032361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3236032361,
"from":L[2181]});
}
} catch($e3235232353) {
if(R.isCont($e3235232353)) {
var $ss3235632357 = {"from":L[2181],
"go":function(ann_DASH_check_DASH_temp423232362) {
return $Hann_DASH_check_DASH_temp989932363(ann_DASH_check_DASH_temp423232362);
}};
$e3235232353.stack[R.EXN_STACKHEIGHT++] = $ss3235632357;
}
if(R.isPyretException($e3235232353)) {
$e3235232353.pyretStack.push(L[2181]);
}
throw $e3235232353;
}
var $ret3235832359 = $Hann_DASH_check_DASH_temp989932363($z3235432355);
++R.GAS;
return $ret3235832359;
};
var $Hann_DASH_check_DASH_temp989932363 = function(ann_DASH_check_DASH_temp423232362) {
return ann_DASH_check_DASH_temp423232362;
};
var $Hcont_tail_arg989711844 = function(cont_tail_arg422911842,if_helper421811843) {
if(--R.GAS > 0) {
$z3236432365 = R.isFunction(if_helper421811843)?if_helper421811843.app(cont_tail_arg422911842):R.ffi.throwNonFunApp(L[2181],if_helper421811843,[cont_tail_arg422911842]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper421811843)?if_helper421811843.app(cont_tail_arg422911842):R.ffi.throwNonFunApp(L[2181],if_helper421811843,[cont_tail_arg422911842]);
},
"from":L[2181]});
}
++R.GAS;
return $z3236432365;
};
var $Hcont_tail_arg989811859 = function(cont_tail_arg422311858,if_helper421811843) {
if(--R.GAS > 0) {
$z3236632367 = R.isFunction(if_helper421811843)?if_helper421811843.app(cont_tail_arg422311858):R.ffi.throwNonFunApp(L[2181],if_helper421811843,[cont_tail_arg422311858]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper421811843)?if_helper421811843.app(cont_tail_arg422311858):R.ffi.throwNonFunApp(L[2181],if_helper421811843,[cont_tail_arg422311858]);
},
"from":L[2181]});
}
++R.GAS;
return $z3236632367;
};
var $Hann_DASH_check_DASH_temp989611881 = function(ann_DASH_check_DASH_temp420911880) {
return ann_DASH_check_DASH_temp420911880;
};
var $Hanf_arg989511894 = function(anf_arg421311893,_plus55,raise62) {
var $z3237032371 = D;
var $f3237632377 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg421311893):R.ffi.throwNonFunApp(L[4161],_plus55,[("No visitor field for "),anf_arg421311893]);
};
try {
if(--R.GAS > 0) {
$z3237032371 = $f3237632377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3237632377,
"from":L[4161]});
}
} catch($e3236832369) {
if(R.isCont($e3236832369)) {
var $ss3237232373 = {"from":L[4161],
"go":function(anf_arg421432378) {
return $Hanf_arg989432379(anf_arg421432378,raise62);
}};
$e3236832369.stack[R.EXN_STACKHEIGHT++] = $ss3237232373;
}
if(R.isPyretException($e3236832369)) {
$e3236832369.pyretStack.push(L[4161]);
}
throw $e3236832369;
}
var $ret3237432375 = $Hanf_arg989432379($z3237032371,raise62);
++R.GAS;
return $ret3237432375;
};
var $Hanf_arg989432379 = function(anf_arg421432378,raise62) {
var $z3238232383 = D;
var $f3238832389 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg421432378):R.ffi.throwNonFunApp(L[2198],raise62,[anf_arg421432378]);
};
try {
if(--R.GAS > 0) {
$z3238232383 = $f3238832389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3238832389,
"from":L[2198]});
}
} catch($e3238032381) {
if(R.isCont($e3238032381)) {
var $ss3238432385 = {"from":L[2198],
"go":function(ann_DASH_check_DASH_temp421132390) {
return $Hann_DASH_check_DASH_temp989332391(ann_DASH_check_DASH_temp421132390);
}};
$e3238032381.stack[R.EXN_STACKHEIGHT++] = $ss3238432385;
}
if(R.isPyretException($e3238032381)) {
$e3238032381.pyretStack.push(L[2198]);
}
throw $e3238032381;
}
var $ret3238632387 = $Hann_DASH_check_DASH_temp989332391($z3238232383);
++R.GAS;
return $ret3238632387;
};
var $Hann_DASH_check_DASH_temp989332391 = function(ann_DASH_check_DASH_temp421132390) {
return ann_DASH_check_DASH_temp421132390;
};
var $Hann_DASH_check_DASH_temp989211927 = function(ann_DASH_check_DASH_temp419911926) {
return ann_DASH_check_DASH_temp419911926;
};
var $Hcont_tail_arg989011946 = function(cont_tail_arg419211944,if_helper418511945) {
if(--R.GAS > 0) {
$z3239232393 = R.isFunction(if_helper418511945)?if_helper418511945.app(cont_tail_arg419211944):R.ffi.throwNonFunApp(L[2202],if_helper418511945,[cont_tail_arg419211944]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper418511945)?if_helper418511945.app(cont_tail_arg419211944):R.ffi.throwNonFunApp(L[2202],if_helper418511945,[cont_tail_arg419211944]);
},
"from":L[2202]});
}
++R.GAS;
return $z3239232393;
};
var $Hcont_tail_arg989111960 = function(cont_tail_arg419011959,if_helper418511945) {
if(--R.GAS > 0) {
$z3239432395 = R.isFunction(if_helper418511945)?if_helper418511945.app(cont_tail_arg419011959):R.ffi.throwNonFunApp(L[2202],if_helper418511945,[cont_tail_arg419011959]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper418511945)?if_helper418511945.app(cont_tail_arg419011959):R.ffi.throwNonFunApp(L[2202],if_helper418511945,[cont_tail_arg419011959]);
},
"from":L[2202]});
}
++R.GAS;
return $z3239432395;
};
var $Hcont_tail_arg988811988 = function(cont_tail_arg417511986,if_helper416811987) {
if(--R.GAS > 0) {
$z3239632397 = R.isFunction(if_helper416811987)?if_helper416811987.app(cont_tail_arg417511986):R.ffi.throwNonFunApp(L[2203],if_helper416811987,[cont_tail_arg417511986]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper416811987)?if_helper416811987.app(cont_tail_arg417511986):R.ffi.throwNonFunApp(L[2203],if_helper416811987,[cont_tail_arg417511986]);
},
"from":L[2203]});
}
++R.GAS;
return $z3239632397;
};
var $Hcont_tail_arg988912002 = function(cont_tail_arg417312001,if_helper416811987) {
if(--R.GAS > 0) {
$z3239832399 = R.isFunction(if_helper416811987)?if_helper416811987.app(cont_tail_arg417312001):R.ffi.throwNonFunApp(L[2203],if_helper416811987,[cont_tail_arg417312001]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper416811987)?if_helper416811987.app(cont_tail_arg417312001):R.ffi.throwNonFunApp(L[2203],if_helper416811987,[cont_tail_arg417312001]);
},
"from":L[2203]});
}
++R.GAS;
return $z3239832399;
};
var $Hann_DASH_check_DASH_temp988712025 = function(ann_DASH_check_DASH_temp415912024) {
return ann_DASH_check_DASH_temp415912024;
};
var $Hanf_arg988612038 = function(anf_arg416312037,_plus55,raise62) {
var $z3240232403 = D;
var $f3240832409 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg416312037):R.ffi.throwNonFunApp(L[4162],_plus55,[("No visitor field for "),anf_arg416312037]);
};
try {
if(--R.GAS > 0) {
$z3240232403 = $f3240832409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3240832409,
"from":L[4162]});
}
} catch($e3240032401) {
if(R.isCont($e3240032401)) {
var $ss3240432405 = {"from":L[4162],
"go":function(anf_arg416432410) {
return $Hanf_arg988532411(anf_arg416432410,raise62);
}};
$e3240032401.stack[R.EXN_STACKHEIGHT++] = $ss3240432405;
}
if(R.isPyretException($e3240032401)) {
$e3240032401.pyretStack.push(L[4162]);
}
throw $e3240032401;
}
var $ret3240632407 = $Hanf_arg988532411($z3240232403,raise62);
++R.GAS;
return $ret3240632407;
};
var $Hanf_arg988532411 = function(anf_arg416432410,raise62) {
var $z3241432415 = D;
var $f3242032421 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg416432410):R.ffi.throwNonFunApp(L[2212],raise62,[anf_arg416432410]);
};
try {
if(--R.GAS > 0) {
$z3241432415 = $f3242032421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3242032421,
"from":L[2212]});
}
} catch($e3241232413) {
if(R.isCont($e3241232413)) {
var $ss3241632417 = {"from":L[2212],
"go":function(ann_DASH_check_DASH_temp416132422) {
return $Hann_DASH_check_DASH_temp988432423(ann_DASH_check_DASH_temp416132422);
}};
$e3241232413.stack[R.EXN_STACKHEIGHT++] = $ss3241632417;
}
if(R.isPyretException($e3241232413)) {
$e3241232413.pyretStack.push(L[2212]);
}
throw $e3241232413;
}
var $ret3241832419 = $Hann_DASH_check_DASH_temp988432423($z3241432415);
++R.GAS;
return $ret3241832419;
};
var $Hann_DASH_check_DASH_temp988432423 = function(ann_DASH_check_DASH_temp416132422) {
return ann_DASH_check_DASH_temp416132422;
};
var $Hann_DASH_check_DASH_temp988312730 = function(ann_DASH_check_DASH_temp400612729) {
return ann_DASH_check_DASH_temp400612729;
};
var $Hcont_tail_arg988112748 = function(cont_tail_arg403912746,if_helper402312747) {
if(--R.GAS > 0) {
$z3242432425 = R.isFunction(if_helper402312747)?if_helper402312747.app(cont_tail_arg403912746):R.ffi.throwNonFunApp(L[2512],if_helper402312747,[cont_tail_arg403912746]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper402312747)?if_helper402312747.app(cont_tail_arg403912746):R.ffi.throwNonFunApp(L[2512],if_helper402312747,[cont_tail_arg403912746]);
},
"from":L[2512]});
}
++R.GAS;
return $z3242432425;
};
var $Hcont_tail_arg988212761 = function(cont_tail_arg403612760,if_helper402312747) {
if(--R.GAS > 0) {
$z3242632427 = R.isFunction(if_helper402312747)?if_helper402312747.app(cont_tail_arg403612760):R.ffi.throwNonFunApp(L[2514],if_helper402312747,[cont_tail_arg403612760]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper402312747)?if_helper402312747.app(cont_tail_arg403612760):R.ffi.throwNonFunApp(L[2514],if_helper402312747,[cont_tail_arg403612760]);
},
"from":L[2514]});
}
++R.GAS;
return $z3242632427;
};
var $Hanf_arg988012782 = function(anf_arg402612779,INDENT118169,anf_fun402212780,if_helper_arg402412767,self99912781,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z3243032431 = D;
var $f3243632437 = function(_) {
return R.isFunction(_plus55)?_plus55.app(if_helper_arg402412767,anf_arg402612779):R.ffi.throwNonFunApp(L[4163],_plus55,[if_helper_arg402412767,anf_arg402612779]);
};
try {
if(--R.GAS > 0) {
$z3243032431 = $f3243632437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3243632437,
"from":L[4163]});
}
} catch($e3242832429) {
if(R.isCont($e3242832429)) {
var $ss3243232433 = {"from":L[4163],
"go":function(anf_arg402732438) {
return $Hanf_arg987932439(anf_arg402732438,INDENT118169,anf_fun402212780,self99912781,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e3242832429.stack[R.EXN_STACKHEIGHT++] = $ss3243232433;
}
if(R.isPyretException($e3242832429)) {
$e3242832429.pyretStack.push(L[4163]);
}
throw $e3242832429;
}
var $ret3243432435 = $Hanf_arg987932439($z3243032431,INDENT118169,anf_fun402212780,self99912781,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3243432435;
};
var $Hanf_arg987932439 = function(anf_arg402732438,INDENT118169,anf_fun402212780,self99912781,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z3244232443 = D;
var $f3244832449 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg402732438,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4163],_plus55,[anf_arg402732438,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z3244232443 = $f3244832449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3244832449,
"from":L[4163]});
}
} catch($e3244032441) {
if(R.isCont($e3244032441)) {
var $ss3244432445 = {"from":L[4163],
"go":function(anf_arg402832450) {
return $Hanf_arg987832451(anf_arg402832450,INDENT118169,anf_fun402212780,self99912781,str_DASH_end148546);
}};
$e3244032441.stack[R.EXN_STACKHEIGHT++] = $ss3244432445;
}
if(R.isPyretException($e3244032441)) {
$e3244032441.pyretStack.push(L[4163]);
}
throw $e3244032441;
}
var $ret3244632447 = $Hanf_arg987832451($z3244232443,INDENT118169,anf_fun402212780,self99912781,str_DASH_end148546);
++R.GAS;
return $ret3244632447;
};
var $Hanf_arg987832451 = function(anf_arg402832450,INDENT118169,anf_fun402212780,self99912781,str_DASH_end148546) {
var anf_bracket402932465 = G(self99912781,"body",L[4166]);
var anf_fun403032462 = G(anf_bracket402932465,"tosource",L[4165]);
var $z3245432455 = D;
var $f3246032461 = function(_) {
return R.isFunction(anf_fun403032462)?anf_fun403032462.app():R.ffi.throwNonFunApp(L[4164],anf_fun403032462,[]);
};
try {
if(--R.GAS > 0) {
$z3245432455 = $f3246032461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3246032461,
"from":L[4164]});
}
} catch($e3245232453) {
if(R.isCont($e3245232453)) {
var $ss3245632457 = {"from":L[4164],
"go":function(anf_arg403132463) {
return $Hanf_arg987732464(anf_arg403132463,INDENT118169,anf_arg402832450,anf_fun402212780,str_DASH_end148546);
}};
$e3245232453.stack[R.EXN_STACKHEIGHT++] = $ss3245632457;
}
if(R.isPyretException($e3245232453)) {
$e3245232453.pyretStack.push(L[4164]);
}
throw $e3245232453;
}
var $ret3245832459 = $Hanf_arg987732464($z3245432455,INDENT118169,anf_arg402832450,anf_fun402212780,str_DASH_end148546);
++R.GAS;
return $ret3245832459;
};
var $Hanf_arg987732464 = function(anf_arg403132463,INDENT118169,anf_arg402832450,anf_fun402212780,str_DASH_end148546) {
var $z3246832469 = D;
var $f3247432475 = function(_) {
return R.isFunction(anf_fun402212780)?anf_fun402212780.app(INDENT118169,(1),anf_arg402832450,anf_arg403132463,str_DASH_end148546):R.ffi.throwNonFunApp(L[2511],anf_fun402212780,[INDENT118169,(1),anf_arg402832450,anf_arg403132463,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z3246832469 = $f3247432475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3247432475,
"from":L[2511]});
}
} catch($e3246632467) {
if(R.isCont($e3246632467)) {
var $ss3247032471 = {"from":L[2511],
"go":function(ann_DASH_check_DASH_temp402132476) {
return $Hann_DASH_check_DASH_temp987632477(ann_DASH_check_DASH_temp402132476);
}};
$e3246632467.stack[R.EXN_STACKHEIGHT++] = $ss3247032471;
}
if(R.isPyretException($e3246632467)) {
$e3246632467.pyretStack.push(L[2511]);
}
throw $e3246632467;
}
var $ret3247232473 = $Hann_DASH_check_DASH_temp987632477($z3246832469);
++R.GAS;
return $ret3247232473;
};
var $Hann_DASH_check_DASH_temp987632477 = function(ann_DASH_check_DASH_temp402132476) {
return ann_DASH_check_DASH_temp402132476;
};
var $Hcont_tail_app987412795 = function(cont_tail_app401912794) {
return cont_tail_app401912794;
};
var $Hcont_tail_app987512807 = function(cont_tail_app401812806) {
return cont_tail_app401812806;
};
var $Hanf_arg987312827 = function(anf_arg401412825,INDENT118169,anf_fun400912826,if_helper_arg401112813,str_DASH_end148546) {
var $z3248032481 = D;
var $f3248632487 = function(_) {
return R.isFunction(anf_fun400912826)?anf_fun400912826.app(INDENT118169,(1),if_helper_arg401112813,anf_arg401412825,str_DASH_end148546):R.ffi.throwNonFunApp(L[2520],anf_fun400912826,[INDENT118169,(1),if_helper_arg401112813,anf_arg401412825,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z3248032481 = $f3248632487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3248632487,
"from":L[2520]});
}
} catch($e3247832479) {
if(R.isCont($e3247832479)) {
var $ss3248232483 = {"from":L[2520],
"go":function(ann_DASH_check_DASH_temp400832488) {
return $Hann_DASH_check_DASH_temp987232489(ann_DASH_check_DASH_temp400832488);
}};
$e3247832479.stack[R.EXN_STACKHEIGHT++] = $ss3248232483;
}
if(R.isPyretException($e3247832479)) {
$e3247832479.pyretStack.push(L[2520]);
}
throw $e3247832479;
}
var $ret3248432485 = $Hann_DASH_check_DASH_temp987232489($z3248032481);
++R.GAS;
return $ret3248432485;
};
var $Hann_DASH_check_DASH_temp987232489 = function(ann_DASH_check_DASH_temp400832488) {
return ann_DASH_check_DASH_temp400832488;
};
var $Hanf_arg987112845 = function(anf_arg398812843,self51112844,_plus55,torepr65) {
var anf_arg398932500 = G(self51112844,"name",L[2216]);
var $z3249232493 = D;
var $f3249832499 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg398932500):R.ffi.throwNonFunApp(L[2216],torepr65,[anf_arg398932500]);
};
try {
if(--R.GAS > 0) {
$z3249232493 = $f3249832499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3249832499,
"from":L[2216]});
}
} catch($e3249032491) {
if(R.isCont($e3249032491)) {
var $ss3249432495 = {"from":L[2216],
"go":function(anf_arg399032501) {
return $Hanf_arg987032502(anf_arg399032501,anf_arg398812843,self51112844,_plus55,torepr65);
}};
$e3249032491.stack[R.EXN_STACKHEIGHT++] = $ss3249432495;
}
if(R.isPyretException($e3249032491)) {
$e3249032491.pyretStack.push(L[2216]);
}
throw $e3249032491;
}
var $ret3249632497 = $Hanf_arg987032502($z3249232493,anf_arg398812843,self51112844,_plus55,torepr65);
++R.GAS;
return $ret3249632497;
};
var $Hanf_arg987032502 = function(anf_arg399032501,anf_arg398812843,self51112844,_plus55,torepr65) {
var $z3250532506 = D;
var $f3251132512 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg399032501):R.ffi.throwNonFunApp(L[2216],_plus55,[(", "),anf_arg399032501]);
};
try {
if(--R.GAS > 0) {
$z3250532506 = $f3251132512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3251132512,
"from":L[2216]});
}
} catch($e3250332504) {
if(R.isCont($e3250332504)) {
var $ss3250732508 = {"from":L[2216],
"go":function(anf_arg399132513) {
return $Hanf_arg986932514(anf_arg399132513,anf_arg398812843,self51112844,_plus55,torepr65);
}};
$e3250332504.stack[R.EXN_STACKHEIGHT++] = $ss3250732508;
}
if(R.isPyretException($e3250332504)) {
$e3250332504.pyretStack.push(L[2216]);
}
throw $e3250332504;
}
var $ret3250932510 = $Hanf_arg986932514($z3250532506,anf_arg398812843,self51112844,_plus55,torepr65);
++R.GAS;
return $ret3250932510;
};
var $Hanf_arg986932514 = function(anf_arg399132513,anf_arg398812843,self51112844,_plus55,torepr65) {
var $z3251732518 = D;
var $f3252332524 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg398812843,anf_arg399132513):R.ffi.throwNonFunApp(L[2216],_plus55,[anf_arg398812843,anf_arg399132513]);
};
try {
if(--R.GAS > 0) {
$z3251732518 = $f3252332524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3252332524,
"from":L[2216]});
}
} catch($e3251532516) {
if(R.isCont($e3251532516)) {
var $ss3251932520 = {"from":L[2216],
"go":function(anf_arg399232525) {
return $Hanf_arg986832526(anf_arg399232525,self51112844,_plus55,torepr65);
}};
$e3251532516.stack[R.EXN_STACKHEIGHT++] = $ss3251932520;
}
if(R.isPyretException($e3251532516)) {
$e3251532516.pyretStack.push(L[2216]);
}
throw $e3251532516;
}
var $ret3252132522 = $Hanf_arg986832526($z3251732518,self51112844,_plus55,torepr65);
++R.GAS;
return $ret3252132522;
};
var $Hanf_arg986832526 = function(anf_arg399232525,self51112844,_plus55,torepr65) {
var anf_arg399332537 = G(self51112844,"body",L[2216]);
var $z3252932530 = D;
var $f3253532536 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg399332537):R.ffi.throwNonFunApp(L[2216],torepr65,[anf_arg399332537]);
};
try {
if(--R.GAS > 0) {
$z3252932530 = $f3253532536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3253532536,
"from":L[2216]});
}
} catch($e3252732528) {
if(R.isCont($e3252732528)) {
var $ss3253132532 = {"from":L[2216],
"go":function(anf_arg399432538) {
return $Hanf_arg986732539(anf_arg399432538,anf_arg399232525,self51112844,_plus55,torepr65);
}};
$e3252732528.stack[R.EXN_STACKHEIGHT++] = $ss3253132532;
}
if(R.isPyretException($e3252732528)) {
$e3252732528.pyretStack.push(L[2216]);
}
throw $e3252732528;
}
var $ret3253332534 = $Hanf_arg986732539($z3252932530,anf_arg399232525,self51112844,_plus55,torepr65);
++R.GAS;
return $ret3253332534;
};
var $Hanf_arg986732539 = function(anf_arg399432538,anf_arg399232525,self51112844,_plus55,torepr65) {
var $z3254232543 = D;
var $f3254832549 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg399432538):R.ffi.throwNonFunApp(L[2216],_plus55,[(", "),anf_arg399432538]);
};
try {
if(--R.GAS > 0) {
$z3254232543 = $f3254832549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3254832549,
"from":L[2216]});
}
} catch($e3254032541) {
if(R.isCont($e3254032541)) {
var $ss3254432545 = {"from":L[2216],
"go":function(anf_arg399532550) {
return $Hanf_arg986632551(anf_arg399532550,anf_arg399232525,self51112844,_plus55,torepr65);
}};
$e3254032541.stack[R.EXN_STACKHEIGHT++] = $ss3254432545;
}
if(R.isPyretException($e3254032541)) {
$e3254032541.pyretStack.push(L[2216]);
}
throw $e3254032541;
}
var $ret3254632547 = $Hanf_arg986632551($z3254232543,anf_arg399232525,self51112844,_plus55,torepr65);
++R.GAS;
return $ret3254632547;
};
var $Hanf_arg986632551 = function(anf_arg399532550,anf_arg399232525,self51112844,_plus55,torepr65) {
var $z3255432555 = D;
var $f3256032561 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg399232525,anf_arg399532550):R.ffi.throwNonFunApp(L[2216],_plus55,[anf_arg399232525,anf_arg399532550]);
};
try {
if(--R.GAS > 0) {
$z3255432555 = $f3256032561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3256032561,
"from":L[2216]});
}
} catch($e3255232553) {
if(R.isCont($e3255232553)) {
var $ss3255632557 = {"from":L[2216],
"go":function(anf_arg399632562) {
return $Hanf_arg986532563(anf_arg399632562,self51112844,_plus55,torepr65);
}};
$e3255232553.stack[R.EXN_STACKHEIGHT++] = $ss3255632557;
}
if(R.isPyretException($e3255232553)) {
$e3255232553.pyretStack.push(L[2216]);
}
throw $e3255232553;
}
var $ret3255832559 = $Hanf_arg986532563($z3255432555,self51112844,_plus55,torepr65);
++R.GAS;
return $ret3255832559;
};
var $Hanf_arg986532563 = function(anf_arg399632562,self51112844,_plus55,torepr65) {
var anf_arg399732574 = G(self51112844,"keyword-check",L[2216]);
var $z3256632567 = D;
var $f3257232573 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg399732574):R.ffi.throwNonFunApp(L[2216],torepr65,[anf_arg399732574]);
};
try {
if(--R.GAS > 0) {
$z3256632567 = $f3257232573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3257232573,
"from":L[2216]});
}
} catch($e3256432565) {
if(R.isCont($e3256432565)) {
var $ss3256832569 = {"from":L[2216],
"go":function(anf_arg399832575) {
return $Hanf_arg986432576(anf_arg399832575,anf_arg399632562,_plus55);
}};
$e3256432565.stack[R.EXN_STACKHEIGHT++] = $ss3256832569;
}
if(R.isPyretException($e3256432565)) {
$e3256432565.pyretStack.push(L[2216]);
}
throw $e3256432565;
}
var $ret3257032571 = $Hanf_arg986432576($z3256632567,anf_arg399632562,_plus55);
++R.GAS;
return $ret3257032571;
};
var $Hanf_arg986432576 = function(anf_arg399832575,anf_arg399632562,_plus55) {
var $z3257932580 = D;
var $f3258532586 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg399832575):R.ffi.throwNonFunApp(L[2216],_plus55,[(", "),anf_arg399832575]);
};
try {
if(--R.GAS > 0) {
$z3257932580 = $f3258532586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3258532586,
"from":L[2216]});
}
} catch($e3257732578) {
if(R.isCont($e3257732578)) {
var $ss3258132582 = {"from":L[2216],
"go":function(anf_arg399932587) {
return $Hanf_arg986332588(anf_arg399932587,anf_arg399632562,_plus55);
}};
$e3257732578.stack[R.EXN_STACKHEIGHT++] = $ss3258132582;
}
if(R.isPyretException($e3257732578)) {
$e3257732578.pyretStack.push(L[2216]);
}
throw $e3257732578;
}
var $ret3258332584 = $Hanf_arg986332588($z3257932580,anf_arg399632562,_plus55);
++R.GAS;
return $ret3258332584;
};
var $Hanf_arg986332588 = function(anf_arg399932587,anf_arg399632562,_plus55) {
var $z3259132592 = D;
var $f3259732598 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg399632562,anf_arg399932587):R.ffi.throwNonFunApp(L[2216],_plus55,[anf_arg399632562,anf_arg399932587]);
};
try {
if(--R.GAS > 0) {
$z3259132592 = $f3259732598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3259732598,
"from":L[2216]});
}
} catch($e3258932590) {
if(R.isCont($e3258932590)) {
var $ss3259332594 = {"from":L[2216],
"go":function(anf_arg400032599) {
return $Hanf_arg986232600(anf_arg400032599,_plus55);
}};
$e3258932590.stack[R.EXN_STACKHEIGHT++] = $ss3259332594;
}
if(R.isPyretException($e3258932590)) {
$e3258932590.pyretStack.push(L[2216]);
}
throw $e3258932590;
}
var $ret3259532596 = $Hanf_arg986232600($z3259132592,_plus55);
++R.GAS;
return $ret3259532596;
};
var $Hanf_arg986232600 = function(anf_arg400032599,_plus55) {
var $z3260332604 = D;
var $f3260932610 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg400032599,(")")):R.ffi.throwNonFunApp(L[2216],_plus55,[anf_arg400032599,(")")]);
};
try {
if(--R.GAS > 0) {
$z3260332604 = $f3260932610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3260932610,
"from":L[2216]});
}
} catch($e3260132602) {
if(R.isCont($e3260132602)) {
var $ss3260532606 = {"from":L[2216],
"go":function(anf_arg400132611) {
return $Hanf_arg986132612(anf_arg400132611,_plus55);
}};
$e3260132602.stack[R.EXN_STACKHEIGHT++] = $ss3260532606;
}
if(R.isPyretException($e3260132602)) {
$e3260132602.pyretStack.push(L[2216]);
}
throw $e3260132602;
}
var $ret3260732608 = $Hanf_arg986132612($z3260332604,_plus55);
++R.GAS;
return $ret3260732608;
};
var $Hanf_arg986132612 = function(anf_arg400132611,_plus55) {
var $z3261532616 = D;
var $f3262132622 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg400132611):R.ffi.throwNonFunApp(L[2216],_plus55,[("("),anf_arg400132611]);
};
try {
if(--R.GAS > 0) {
$z3261532616 = $f3262132622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3262132622,
"from":L[2216]});
}
} catch($e3261332614) {
if(R.isCont($e3261332614)) {
var $ss3261732618 = {"from":L[2216],
"go":function(anf_arg400232623) {
return $Hanf_arg986032624(anf_arg400232623,_plus55);
}};
$e3261332614.stack[R.EXN_STACKHEIGHT++] = $ss3261732618;
}
if(R.isPyretException($e3261332614)) {
$e3261332614.pyretStack.push(L[2216]);
}
throw $e3261332614;
}
var $ret3261932620 = $Hanf_arg986032624($z3261532616,_plus55);
++R.GAS;
return $ret3261932620;
};
var $Hanf_arg986032624 = function(anf_arg400232623,_plus55) {
var $z3262732628 = D;
var $f3263332634 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-check"),anf_arg400232623):R.ffi.throwNonFunApp(L[2216],_plus55,[("s-check"),anf_arg400232623]);
};
try {
if(--R.GAS > 0) {
$z3262732628 = $f3263332634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3263332634,
"from":L[2216]});
}
} catch($e3262532626) {
if(R.isCont($e3262532626)) {
var $ss3262932630 = {"from":L[2216],
"go":function(ann_DASH_check_DASH_temp398632635) {
return $Hann_DASH_check_DASH_temp985932636(ann_DASH_check_DASH_temp398632635);
}};
$e3262532626.stack[R.EXN_STACKHEIGHT++] = $ss3262932630;
}
if(R.isPyretException($e3262532626)) {
$e3262532626.pyretStack.push(L[2216]);
}
throw $e3262532626;
}
var $ret3263132632 = $Hann_DASH_check_DASH_temp985932636($z3262732628);
++R.GAS;
return $ret3263132632;
};
var $Hann_DASH_check_DASH_temp985932636 = function(ann_DASH_check_DASH_temp398632635) {
return ann_DASH_check_DASH_temp398632635;
};
var $Hcont_tail_arg985712863 = function(cont_tail_arg398312861,if_helper397212862) {
if(--R.GAS > 0) {
$z3263732638 = R.isFunction(if_helper397212862)?if_helper397212862.app(cont_tail_arg398312861):R.ffi.throwNonFunApp(L[2216],if_helper397212862,[cont_tail_arg398312861]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper397212862)?if_helper397212862.app(cont_tail_arg398312861):R.ffi.throwNonFunApp(L[2216],if_helper397212862,[cont_tail_arg398312861]);
},
"from":L[2216]});
}
++R.GAS;
return $z3263732638;
};
var $Hcont_tail_arg985812878 = function(cont_tail_arg397712877,if_helper397212862) {
if(--R.GAS > 0) {
$z3263932640 = R.isFunction(if_helper397212862)?if_helper397212862.app(cont_tail_arg397712877):R.ffi.throwNonFunApp(L[2216],if_helper397212862,[cont_tail_arg397712877]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper397212862)?if_helper397212862.app(cont_tail_arg397712877):R.ffi.throwNonFunApp(L[2216],if_helper397212862,[cont_tail_arg397712877]);
},
"from":L[2216]});
}
++R.GAS;
return $z3263932640;
};
var $Hanf_arg985612900 = function(anf_arg393512897,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,str_DASH_for150572,_plus55,_times56) {
var $z3264332644 = D;
var $f3264932650 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_for150572,anf_arg393512897):R.ffi.throwNonFunApp(L[4167],_plus55,[str_DASH_for150572,anf_arg393512897]);
};
try {
if(--R.GAS > 0) {
$z3264332644 = $f3264932650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3264932650,
"from":L[4167]});
}
} catch($e3264132642) {
if(R.isCont($e3264132642)) {
var $ss3264532646 = {"from":L[4167],
"go":function(anf_arg393632651) {
return $Hanf_arg985532652(anf_arg393632651,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
}};
$e3264132642.stack[R.EXN_STACKHEIGHT++] = $ss3264532646;
}
if(R.isPyretException($e3264132642)) {
$e3264132642.pyretStack.push(L[4167]);
}
throw $e3264132642;
}
var $ret3264732648 = $Hanf_arg985532652($z3264332644,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
++R.GAS;
return $ret3264732648;
};
var $Hanf_arg985532652 = function(anf_arg393632651,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56) {
var anf_fun393732664 = G(PP170,"surround-separate",L[4169]);
var $z3265532656 = D;
var $f3266132662 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[4168],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z3265532656 = $f3266132662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3266132662,
"from":L[4168]});
}
} catch($e3265332654) {
if(R.isCont($e3265332654)) {
var $ss3265732658 = {"from":L[4168],
"go":function(anf_arg393832663) {
return $Hanf_arg985432665(anf_arg393832663,INDENT118169,PP170,anf_arg393632651,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
}};
$e3265332654.stack[R.EXN_STACKHEIGHT++] = $ss3265732658;
}
if(R.isPyretException($e3265332654)) {
$e3265332654.pyretStack.push(L[4168]);
}
throw $e3265332654;
}
var $ret3265932660 = $Hanf_arg985432665($z3265532656,INDENT118169,PP170,anf_arg393632651,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
++R.GAS;
return $ret3265932660;
};
var $Hanf_arg985432665 = function(anf_arg393832663,INDENT118169,PP170,anf_arg393632651,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56) {
var anf_arg393932676 = G(PP170,"lparen",L[4172]);
var anf_arg394032677 = G(PP170,"rparen",L[4171]);
var $z3266832669 = D;
var $f3267432675 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg393932676,anf_arg394032677):R.ffi.throwNonFunApp(L[4170],_plus55,[anf_arg393932676,anf_arg394032677]);
};
try {
if(--R.GAS > 0) {
$z3266832669 = $f3267432675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3267432675,
"from":L[4170]});
}
} catch($e3266632667) {
if(R.isCont($e3266632667)) {
var $ss3267032671 = {"from":L[4170],
"go":function(anf_arg394132678) {
return $Hanf_arg985332679(anf_arg394132678,INDENT118169,PP170,anf_arg393632651,anf_arg393832663,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
}};
$e3266632667.stack[R.EXN_STACKHEIGHT++] = $ss3267032671;
}
if(R.isPyretException($e3266632667)) {
$e3266632667.pyretStack.push(L[4170]);
}
throw $e3266632667;
}
var $ret3267232673 = $Hanf_arg985332679($z3266832669,INDENT118169,PP170,anf_arg393632651,anf_arg393832663,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
++R.GAS;
return $ret3267232673;
};
var $Hanf_arg985332679 = function(anf_arg394132678,INDENT118169,PP170,anf_arg393632651,anf_arg393832663,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56) {
var anf_arg394232693 = G(PP170,"lparen",L[4180]);
var anf_arg394332694 = G(PP170,"commabreak",L[4179]);
var anf_arg394432695 = G(PP170,"rparen",L[4178]);
var anf_bracket394532711 = G(self99112899,"bindings",L[4177]);
var anf_fun394632690 = G(anf_bracket394532711,"map",L[4176]);
var anf_arg394932691 = R.makeFunction(function(b99332697) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4174],1,arguments);
}
var anf_fun394832708 = G(b99332697,"tosource",L[4175]);
var $z3270032701 = D;
var $f3270632707 = function(_) {
return R.isFunction(anf_fun394832708)?anf_fun394832708.app():R.ffi.throwNonFunApp(L[4174],anf_fun394832708,[]);
};
try {
if(--R.GAS > 0) {
$z3270032701 = $f3270632707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3270632707,
"from":L[4174]});
}
} catch($e3269832699) {
if(R.isCont($e3269832699)) {
var $ss3270232703 = {"from":L[4174],
"go":function(ann_DASH_check_DASH_temp394732709) {
return $Hann_DASH_check_DASH_temp983732710(ann_DASH_check_DASH_temp394732709);
}};
$e3269832699.stack[R.EXN_STACKHEIGHT++] = $ss3270232703;
}
if(R.isPyretException($e3269832699)) {
$e3269832699.pyretStack.push(L[4174]);
}
throw $e3269832699;
}
var $ret3270432705 = $Hann_DASH_check_DASH_temp983732710($z3270032701);
++R.GAS;
return $ret3270432705;
});
var $z3268232683 = D;
var $f3268832689 = function(_) {
return R.isFunction(anf_fun394632690)?anf_fun394632690.app(anf_arg394932691):R.ffi.throwNonFunApp(L[4173],anf_fun394632690,[anf_arg394932691]);
};
try {
if(--R.GAS > 0) {
$z3268232683 = $f3268832689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3268832689,
"from":L[4173]});
}
} catch($e3268032681) {
if(R.isCont($e3268032681)) {
var $ss3268432685 = {"from":L[4173],
"go":function(anf_arg395032692) {
return $Hanf_arg985232696(anf_arg395032692,INDENT118169,PP170,anf_arg393632651,anf_arg393832663,anf_arg394132678,anf_arg394232693,anf_arg394332694,anf_arg394432695,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
}};
$e3268032681.stack[R.EXN_STACKHEIGHT++] = $ss3268432685;
}
if(R.isPyretException($e3268032681)) {
$e3268032681.pyretStack.push(L[4173]);
}
throw $e3268032681;
}
var $ret3268632687 = $Hanf_arg985232696($z3268232683,INDENT118169,PP170,anf_arg393632651,anf_arg393832663,anf_arg394132678,anf_arg394232693,anf_arg394332694,anf_arg394432695,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
++R.GAS;
return $ret3268632687;
};
var $Hanf_arg985232696 = function(anf_arg395032692,INDENT118169,PP170,anf_arg393632651,anf_arg393832663,anf_arg394132678,anf_arg394232693,anf_arg394332694,anf_arg394432695,anf_fun393212898,anf_fun393732664,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56) {
var $z3271432715 = D;
var $f3272032721 = function(_) {
return R.isFunction(anf_fun393732664)?anf_fun393732664.app(anf_arg393832663,(0),anf_arg394132678,anf_arg394232693,anf_arg394332694,anf_arg394432695,anf_arg395032692):R.ffi.throwNonFunApp(L[4181],anf_fun393732664,[anf_arg393832663,(0),anf_arg394132678,anf_arg394232693,anf_arg394332694,anf_arg394432695,anf_arg395032692]);
};
try {
if(--R.GAS > 0) {
$z3271432715 = $f3272032721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3272032721,
"from":L[4181]});
}
} catch($e3271232713) {
if(R.isCont($e3271232713)) {
var $ss3271632717 = {"from":L[4181],
"go":function(anf_arg395132722) {
return $Hanf_arg985132723(anf_arg395132722,INDENT118169,PP170,anf_arg393632651,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
}};
$e3271232713.stack[R.EXN_STACKHEIGHT++] = $ss3271632717;
}
if(R.isPyretException($e3271232713)) {
$e3271232713.pyretStack.push(L[4181]);
}
throw $e3271232713;
}
var $ret3271832719 = $Hanf_arg985132723($z3271432715,INDENT118169,PP170,anf_arg393632651,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
++R.GAS;
return $ret3271832719;
};
var $Hanf_arg985132723 = function(anf_arg395132722,INDENT118169,PP170,anf_arg393632651,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56) {
var $z3272632727 = D;
var $f3273232733 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg393632651,anf_arg395132722):R.ffi.throwNonFunApp(L[4167],_plus55,[anf_arg393632651,anf_arg395132722]);
};
try {
if(--R.GAS > 0) {
$z3272632727 = $f3273232733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3273232733,
"from":L[4167]});
}
} catch($e3272432725) {
if(R.isCont($e3272432725)) {
var $ss3272832729 = {"from":L[4167],
"go":function(anf_arg395232734) {
return $Hanf_arg985032735(anf_arg395232734,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
}};
$e3272432725.stack[R.EXN_STACKHEIGHT++] = $ss3272832729;
}
if(R.isPyretException($e3272432725)) {
$e3272432725.pyretStack.push(L[4167]);
}
throw $e3272432725;
}
var $ret3273032731 = $Hanf_arg985032735($z3272632727,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56);
++R.GAS;
return $ret3273032731;
};
var $Hanf_arg985032735 = function(anf_arg395232734,INDENT118169,PP170,anf_fun393212898,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55,_times56) {
var anf_fun395332747 = G(PP170,"group",L[4184]);
var anf_fun395432748 = G(PP170,"nest",L[4183]);
var $z3273832739 = D;
var $f3274432745 = function(_) {
return R.isFunction(_times56)?_times56.app((2),INDENT118169):R.ffi.throwNonFunApp(L[4182],_times56,[(2),INDENT118169]);
};
try {
if(--R.GAS > 0) {
$z3273832739 = $f3274432745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3274432745,
"from":L[4182]});
}
} catch($e3273632737) {
if(R.isCont($e3273632737)) {
var $ss3274032741 = {"from":L[4182],
"go":function(anf_arg395532746) {
return $Hanf_arg984932749(anf_arg395532746,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,anf_fun395332747,anf_fun395432748,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e3273632737.stack[R.EXN_STACKHEIGHT++] = $ss3274032741;
}
if(R.isPyretException($e3273632737)) {
$e3273632737.pyretStack.push(L[4182]);
}
throw $e3273632737;
}
var $ret3274232743 = $Hanf_arg984932749($z3273832739,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,anf_fun395332747,anf_fun395432748,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3274232743;
};
var $Hanf_arg984932749 = function(anf_arg395532746,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,anf_fun395332747,anf_fun395432748,break_DASH_one119168,self99112899,str_DASH_arrow121195,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z3275232753 = D;
var $f3275832759 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_arrow121195):R.ffi.throwNonFunApp(L[4185],_plus55,[break_DASH_one119168,str_DASH_arrow121195]);
};
try {
if(--R.GAS > 0) {
$z3275232753 = $f3275832759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3275832759,
"from":L[4185]});
}
} catch($e3275032751) {
if(R.isCont($e3275032751)) {
var $ss3275432755 = {"from":L[4185],
"go":function(anf_arg395632760) {
return $Hanf_arg984832761(anf_arg395632760,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,break_DASH_one119168,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e3275032751.stack[R.EXN_STACKHEIGHT++] = $ss3275432755;
}
if(R.isPyretException($e3275032751)) {
$e3275032751.pyretStack.push(L[4185]);
}
throw $e3275032751;
}
var $ret3275632757 = $Hanf_arg984832761($z3275232753,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,break_DASH_one119168,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3275632757;
};
var $Hanf_arg984832761 = function(anf_arg395632760,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,break_DASH_one119168,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z3276432765 = D;
var $f3277032771 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg395632760,break_DASH_one119168):R.ffi.throwNonFunApp(L[4185],_plus55,[anf_arg395632760,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3276432765 = $f3277032771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3277032771,
"from":L[4185]});
}
} catch($e3276232763) {
if(R.isCont($e3276232763)) {
var $ss3276632767 = {"from":L[4185],
"go":function(anf_arg395732772) {
return $Hanf_arg984732773(anf_arg395732772,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e3276232763.stack[R.EXN_STACKHEIGHT++] = $ss3276632767;
}
if(R.isPyretException($e3276232763)) {
$e3276232763.pyretStack.push(L[4185]);
}
throw $e3276232763;
}
var $ret3276832769 = $Hanf_arg984732773($z3276432765,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3276832769;
};
var $Hanf_arg984732773 = function(anf_arg395732772,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var anf_bracket395832787 = G(self99112899,"ann",L[4188]);
var anf_fun395932784 = G(anf_bracket395832787,"tosource",L[4187]);
var $z3277632777 = D;
var $f3278232783 = function(_) {
return R.isFunction(anf_fun395932784)?anf_fun395932784.app():R.ffi.throwNonFunApp(L[4186],anf_fun395932784,[]);
};
try {
if(--R.GAS > 0) {
$z3277632777 = $f3278232783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3278232783,
"from":L[4186]});
}
} catch($e3277432775) {
if(R.isCont($e3277432775)) {
var $ss3277832779 = {"from":L[4186],
"go":function(anf_arg396032785) {
return $Hanf_arg984632786(anf_arg396032785,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_arg395732772,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e3277432775.stack[R.EXN_STACKHEIGHT++] = $ss3277832779;
}
if(R.isPyretException($e3277432775)) {
$e3277432775.pyretStack.push(L[4186]);
}
throw $e3277432775;
}
var $ret3278032781 = $Hanf_arg984632786($z3277632777,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_arg395732772,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3278032781;
};
var $Hanf_arg984632786 = function(anf_arg396032785,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_arg395732772,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z3279032791 = D;
var $f3279632797 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg395732772,anf_arg396032785):R.ffi.throwNonFunApp(L[4185],_plus55,[anf_arg395732772,anf_arg396032785]);
};
try {
if(--R.GAS > 0) {
$z3279032791 = $f3279632797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3279632797,
"from":L[4185]});
}
} catch($e3278832789) {
if(R.isCont($e3278832789)) {
var $ss3279232793 = {"from":L[4185],
"go":function(anf_arg396132798) {
return $Hanf_arg984532799(anf_arg396132798,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e3278832789.stack[R.EXN_STACKHEIGHT++] = $ss3279232793;
}
if(R.isPyretException($e3278832789)) {
$e3278832789.pyretStack.push(L[4185]);
}
throw $e3278832789;
}
var $ret3279432795 = $Hanf_arg984532799($z3279032791,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3279432795;
};
var $Hanf_arg984532799 = function(anf_arg396132798,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z3280232803 = D;
var $f3280832809 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg396132798,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4185],_plus55,[anf_arg396132798,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z3280232803 = $f3280832809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3280832809,
"from":L[4185]});
}
} catch($e3280032801) {
if(R.isCont($e3280032801)) {
var $ss3280432805 = {"from":L[4185],
"go":function(anf_arg396232810) {
return $Hanf_arg984432811(anf_arg396232810,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_end148546,_plus55);
}};
$e3280032801.stack[R.EXN_STACKHEIGHT++] = $ss3280432805;
}
if(R.isPyretException($e3280032801)) {
$e3280032801.pyretStack.push(L[4185]);
}
throw $e3280032801;
}
var $ret3280632807 = $Hanf_arg984432811($z3280232803,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3280632807;
};
var $Hanf_arg984432811 = function(anf_arg396232810,INDENT118169,PP170,anf_arg395232734,anf_arg395532746,anf_fun393212898,anf_fun395332747,anf_fun395432748,self99112899,str_DASH_end148546,_plus55) {
var $z3281432815 = D;
var $f3282032821 = function(_) {
return R.isFunction(anf_fun395432748)?anf_fun395432748.app(anf_arg395532746,anf_arg396232810):R.ffi.throwNonFunApp(L[4189],anf_fun395432748,[anf_arg395532746,anf_arg396232810]);
};
try {
if(--R.GAS > 0) {
$z3281432815 = $f3282032821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3282032821,
"from":L[4189]});
}
} catch($e3281232813) {
if(R.isCont($e3281232813)) {
var $ss3281632817 = {"from":L[4189],
"go":function(anf_arg396332822) {
return $Hanf_arg984332823(anf_arg396332822,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,anf_fun395332747,self99112899,str_DASH_end148546,_plus55);
}};
$e3281232813.stack[R.EXN_STACKHEIGHT++] = $ss3281632817;
}
if(R.isPyretException($e3281232813)) {
$e3281232813.pyretStack.push(L[4189]);
}
throw $e3281232813;
}
var $ret3281832819 = $Hanf_arg984332823($z3281432815,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,anf_fun395332747,self99112899,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3281832819;
};
var $Hanf_arg984332823 = function(anf_arg396332822,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,anf_fun395332747,self99112899,str_DASH_end148546,_plus55) {
var $z3282632827 = D;
var $f3283232833 = function(_) {
return R.isFunction(anf_fun395332747)?anf_fun395332747.app(anf_arg396332822):R.ffi.throwNonFunApp(L[4190],anf_fun395332747,[anf_arg396332822]);
};
try {
if(--R.GAS > 0) {
$z3282632827 = $f3283232833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3283232833,
"from":L[4190]});
}
} catch($e3282432825) {
if(R.isCont($e3282432825)) {
var $ss3282832829 = {"from":L[4190],
"go":function(anf_arg396432834) {
return $Hanf_arg984232835(anf_arg396432834,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,self99112899,str_DASH_end148546,_plus55);
}};
$e3282432825.stack[R.EXN_STACKHEIGHT++] = $ss3282832829;
}
if(R.isPyretException($e3282432825)) {
$e3282432825.pyretStack.push(L[4190]);
}
throw $e3282432825;
}
var $ret3283032831 = $Hanf_arg984232835($z3282632827,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,self99112899,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3283032831;
};
var $Hanf_arg984232835 = function(anf_arg396432834,INDENT118169,PP170,anf_arg395232734,anf_fun393212898,self99112899,str_DASH_end148546,_plus55) {
var $z3283832839 = D;
var $f3284432845 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg395232734,anf_arg396432834):R.ffi.throwNonFunApp(L[4167],_plus55,[anf_arg395232734,anf_arg396432834]);
};
try {
if(--R.GAS > 0) {
$z3283832839 = $f3284432845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3284432845,
"from":L[4167]});
}
} catch($e3283632837) {
if(R.isCont($e3283632837)) {
var $ss3284032841 = {"from":L[4167],
"go":function(anf_arg396532846) {
return $Hanf_arg984132847(anf_arg396532846,INDENT118169,PP170,anf_fun393212898,self99112899,str_DASH_end148546);
}};
$e3283632837.stack[R.EXN_STACKHEIGHT++] = $ss3284032841;
}
if(R.isPyretException($e3283632837)) {
$e3283632837.pyretStack.push(L[4167]);
}
throw $e3283632837;
}
var $ret3284232843 = $Hanf_arg984132847($z3283832839,INDENT118169,PP170,anf_fun393212898,self99112899,str_DASH_end148546);
++R.GAS;
return $ret3284232843;
};
var $Hanf_arg984132847 = function(anf_arg396532846,INDENT118169,PP170,anf_fun393212898,self99112899,str_DASH_end148546) {
var $z3285032851 = D;
var $f3285632857 = function(_) {
return R.isFunction(anf_fun393212898)?anf_fun393212898.app(anf_arg396532846):R.ffi.throwNonFunApp(L[4191],anf_fun393212898,[anf_arg396532846]);
};
try {
if(--R.GAS > 0) {
$z3285032851 = $f3285632857();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3285632857,
"from":L[4191]});
}
} catch($e3284832849) {
if(R.isCont($e3284832849)) {
var $ss3285232853 = {"from":L[4191],
"go":function(header99232858) {
return $Hheader984032859(header99232858,INDENT118169,PP170,self99112899,str_DASH_end148546);
}};
$e3284832849.stack[R.EXN_STACKHEIGHT++] = $ss3285232853;
}
if(R.isPyretException($e3284832849)) {
$e3284832849.pyretStack.push(L[4191]);
}
throw $e3284832849;
}
var $ret3285432855 = $Hheader984032859($z3285032851,INDENT118169,PP170,self99112899,str_DASH_end148546);
++R.GAS;
return $ret3285432855;
};
var $Hheader984032859 = function(header99232858,INDENT118169,PP170,self99112899,str_DASH_end148546) {
var anf_fun396632872 = G(PP170,"surround",L[4195]);
var anf_bracket396732874 = G(self99112899,"body",L[4194]);
var anf_fun396832870 = G(anf_bracket396732874,"tosource",L[4193]);
var $z3286232863 = D;
var $f3286832869 = function(_) {
return R.isFunction(anf_fun396832870)?anf_fun396832870.app():R.ffi.throwNonFunApp(L[4192],anf_fun396832870,[]);
};
try {
if(--R.GAS > 0) {
$z3286232863 = $f3286832869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3286832869,
"from":L[4192]});
}
} catch($e3286032861) {
if(R.isCont($e3286032861)) {
var $ss3286432865 = {"from":L[4192],
"go":function(anf_arg396932871) {
return $Hanf_arg983932873(anf_arg396932871,INDENT118169,anf_fun396632872,header99232858,str_DASH_end148546);
}};
$e3286032861.stack[R.EXN_STACKHEIGHT++] = $ss3286432865;
}
if(R.isPyretException($e3286032861)) {
$e3286032861.pyretStack.push(L[4192]);
}
throw $e3286032861;
}
var $ret3286632867 = $Hanf_arg983932873($z3286232863,INDENT118169,anf_fun396632872,header99232858,str_DASH_end148546);
++R.GAS;
return $ret3286632867;
};
var $Hanf_arg983932873 = function(anf_arg396932871,INDENT118169,anf_fun396632872,header99232858,str_DASH_end148546) {
var $z3287732878 = D;
var $f3288332884 = function(_) {
return R.isFunction(anf_fun396632872)?anf_fun396632872.app(INDENT118169,(1),header99232858,anf_arg396932871,str_DASH_end148546):R.ffi.throwNonFunApp(L[2538],anf_fun396632872,[INDENT118169,(1),header99232858,anf_arg396932871,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z3287732878 = $f3288332884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3288332884,
"from":L[2538]});
}
} catch($e3287532876) {
if(R.isCont($e3287532876)) {
var $ss3287932880 = {"from":L[2538],
"go":function(ann_DASH_check_DASH_temp393132885) {
return $Hann_DASH_check_DASH_temp983832886(ann_DASH_check_DASH_temp393132885);
}};
$e3287532876.stack[R.EXN_STACKHEIGHT++] = $ss3287932880;
}
if(R.isPyretException($e3287532876)) {
$e3287532876.pyretStack.push(L[2538]);
}
throw $e3287532876;
}
var $ret3288132882 = $Hann_DASH_check_DASH_temp983832886($z3287732878);
++R.GAS;
return $ret3288132882;
};
var $Hann_DASH_check_DASH_temp983832886 = function(ann_DASH_check_DASH_temp393132885) {
return ann_DASH_check_DASH_temp393132885;
};
var $Hann_DASH_check_DASH_temp983732710 = function(ann_DASH_check_DASH_temp394732709) {
return ann_DASH_check_DASH_temp394732709;
};
var $Hanf_arg983612917 = function(anf_arg390912915,self50512916,_plus55,torepr65) {
var anf_arg391032897 = G(self50512916,"iterator",L[2217]);
var $z3288932890 = D;
var $f3289532896 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg391032897):R.ffi.throwNonFunApp(L[2217],torepr65,[anf_arg391032897]);
};
try {
if(--R.GAS > 0) {
$z3288932890 = $f3289532896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3289532896,
"from":L[2217]});
}
} catch($e3288732888) {
if(R.isCont($e3288732888)) {
var $ss3289132892 = {"from":L[2217],
"go":function(anf_arg391132898) {
return $Hanf_arg983532899(anf_arg391132898,anf_arg390912915,self50512916,_plus55,torepr65);
}};
$e3288732888.stack[R.EXN_STACKHEIGHT++] = $ss3289132892;
}
if(R.isPyretException($e3288732888)) {
$e3288732888.pyretStack.push(L[2217]);
}
throw $e3288732888;
}
var $ret3289332894 = $Hanf_arg983532899($z3288932890,anf_arg390912915,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3289332894;
};
var $Hanf_arg983532899 = function(anf_arg391132898,anf_arg390912915,self50512916,_plus55,torepr65) {
var $z3290232903 = D;
var $f3290832909 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg391132898):R.ffi.throwNonFunApp(L[2217],_plus55,[(", "),anf_arg391132898]);
};
try {
if(--R.GAS > 0) {
$z3290232903 = $f3290832909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3290832909,
"from":L[2217]});
}
} catch($e3290032901) {
if(R.isCont($e3290032901)) {
var $ss3290432905 = {"from":L[2217],
"go":function(anf_arg391232910) {
return $Hanf_arg983432911(anf_arg391232910,anf_arg390912915,self50512916,_plus55,torepr65);
}};
$e3290032901.stack[R.EXN_STACKHEIGHT++] = $ss3290432905;
}
if(R.isPyretException($e3290032901)) {
$e3290032901.pyretStack.push(L[2217]);
}
throw $e3290032901;
}
var $ret3290632907 = $Hanf_arg983432911($z3290232903,anf_arg390912915,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3290632907;
};
var $Hanf_arg983432911 = function(anf_arg391232910,anf_arg390912915,self50512916,_plus55,torepr65) {
var $z3291432915 = D;
var $f3292032921 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg390912915,anf_arg391232910):R.ffi.throwNonFunApp(L[2217],_plus55,[anf_arg390912915,anf_arg391232910]);
};
try {
if(--R.GAS > 0) {
$z3291432915 = $f3292032921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3292032921,
"from":L[2217]});
}
} catch($e3291232913) {
if(R.isCont($e3291232913)) {
var $ss3291632917 = {"from":L[2217],
"go":function(anf_arg391332922) {
return $Hanf_arg983332923(anf_arg391332922,self50512916,_plus55,torepr65);
}};
$e3291232913.stack[R.EXN_STACKHEIGHT++] = $ss3291632917;
}
if(R.isPyretException($e3291232913)) {
$e3291232913.pyretStack.push(L[2217]);
}
throw $e3291232913;
}
var $ret3291832919 = $Hanf_arg983332923($z3291432915,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3291832919;
};
var $Hanf_arg983332923 = function(anf_arg391332922,self50512916,_plus55,torepr65) {
var anf_arg391432934 = G(self50512916,"bindings",L[2217]);
var $z3292632927 = D;
var $f3293232933 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg391432934):R.ffi.throwNonFunApp(L[2217],torepr65,[anf_arg391432934]);
};
try {
if(--R.GAS > 0) {
$z3292632927 = $f3293232933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3293232933,
"from":L[2217]});
}
} catch($e3292432925) {
if(R.isCont($e3292432925)) {
var $ss3292832929 = {"from":L[2217],
"go":function(anf_arg391532935) {
return $Hanf_arg983232936(anf_arg391532935,anf_arg391332922,self50512916,_plus55,torepr65);
}};
$e3292432925.stack[R.EXN_STACKHEIGHT++] = $ss3292832929;
}
if(R.isPyretException($e3292432925)) {
$e3292432925.pyretStack.push(L[2217]);
}
throw $e3292432925;
}
var $ret3293032931 = $Hanf_arg983232936($z3292632927,anf_arg391332922,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3293032931;
};
var $Hanf_arg983232936 = function(anf_arg391532935,anf_arg391332922,self50512916,_plus55,torepr65) {
var $z3293932940 = D;
var $f3294532946 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg391532935):R.ffi.throwNonFunApp(L[2217],_plus55,[(", "),anf_arg391532935]);
};
try {
if(--R.GAS > 0) {
$z3293932940 = $f3294532946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3294532946,
"from":L[2217]});
}
} catch($e3293732938) {
if(R.isCont($e3293732938)) {
var $ss3294132942 = {"from":L[2217],
"go":function(anf_arg391632947) {
return $Hanf_arg983132948(anf_arg391632947,anf_arg391332922,self50512916,_plus55,torepr65);
}};
$e3293732938.stack[R.EXN_STACKHEIGHT++] = $ss3294132942;
}
if(R.isPyretException($e3293732938)) {
$e3293732938.pyretStack.push(L[2217]);
}
throw $e3293732938;
}
var $ret3294332944 = $Hanf_arg983132948($z3293932940,anf_arg391332922,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3294332944;
};
var $Hanf_arg983132948 = function(anf_arg391632947,anf_arg391332922,self50512916,_plus55,torepr65) {
var $z3295132952 = D;
var $f3295732958 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg391332922,anf_arg391632947):R.ffi.throwNonFunApp(L[2217],_plus55,[anf_arg391332922,anf_arg391632947]);
};
try {
if(--R.GAS > 0) {
$z3295132952 = $f3295732958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3295732958,
"from":L[2217]});
}
} catch($e3294932950) {
if(R.isCont($e3294932950)) {
var $ss3295332954 = {"from":L[2217],
"go":function(anf_arg391732959) {
return $Hanf_arg983032960(anf_arg391732959,self50512916,_plus55,torepr65);
}};
$e3294932950.stack[R.EXN_STACKHEIGHT++] = $ss3295332954;
}
if(R.isPyretException($e3294932950)) {
$e3294932950.pyretStack.push(L[2217]);
}
throw $e3294932950;
}
var $ret3295532956 = $Hanf_arg983032960($z3295132952,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3295532956;
};
var $Hanf_arg983032960 = function(anf_arg391732959,self50512916,_plus55,torepr65) {
var anf_arg391832971 = G(self50512916,"ann",L[2217]);
var $z3296332964 = D;
var $f3296932970 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg391832971):R.ffi.throwNonFunApp(L[2217],torepr65,[anf_arg391832971]);
};
try {
if(--R.GAS > 0) {
$z3296332964 = $f3296932970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3296932970,
"from":L[2217]});
}
} catch($e3296132962) {
if(R.isCont($e3296132962)) {
var $ss3296532966 = {"from":L[2217],
"go":function(anf_arg391932972) {
return $Hanf_arg982932973(anf_arg391932972,anf_arg391732959,self50512916,_plus55,torepr65);
}};
$e3296132962.stack[R.EXN_STACKHEIGHT++] = $ss3296532966;
}
if(R.isPyretException($e3296132962)) {
$e3296132962.pyretStack.push(L[2217]);
}
throw $e3296132962;
}
var $ret3296732968 = $Hanf_arg982932973($z3296332964,anf_arg391732959,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3296732968;
};
var $Hanf_arg982932973 = function(anf_arg391932972,anf_arg391732959,self50512916,_plus55,torepr65) {
var $z3297632977 = D;
var $f3298232983 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg391932972):R.ffi.throwNonFunApp(L[2217],_plus55,[(", "),anf_arg391932972]);
};
try {
if(--R.GAS > 0) {
$z3297632977 = $f3298232983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3298232983,
"from":L[2217]});
}
} catch($e3297432975) {
if(R.isCont($e3297432975)) {
var $ss3297832979 = {"from":L[2217],
"go":function(anf_arg392032984) {
return $Hanf_arg982832985(anf_arg392032984,anf_arg391732959,self50512916,_plus55,torepr65);
}};
$e3297432975.stack[R.EXN_STACKHEIGHT++] = $ss3297832979;
}
if(R.isPyretException($e3297432975)) {
$e3297432975.pyretStack.push(L[2217]);
}
throw $e3297432975;
}
var $ret3298032981 = $Hanf_arg982832985($z3297632977,anf_arg391732959,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3298032981;
};
var $Hanf_arg982832985 = function(anf_arg392032984,anf_arg391732959,self50512916,_plus55,torepr65) {
var $z3298832989 = D;
var $f3299432995 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg391732959,anf_arg392032984):R.ffi.throwNonFunApp(L[2217],_plus55,[anf_arg391732959,anf_arg392032984]);
};
try {
if(--R.GAS > 0) {
$z3298832989 = $f3299432995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3299432995,
"from":L[2217]});
}
} catch($e3298632987) {
if(R.isCont($e3298632987)) {
var $ss3299032991 = {"from":L[2217],
"go":function(anf_arg392132996) {
return $Hanf_arg982732997(anf_arg392132996,self50512916,_plus55,torepr65);
}};
$e3298632987.stack[R.EXN_STACKHEIGHT++] = $ss3299032991;
}
if(R.isPyretException($e3298632987)) {
$e3298632987.pyretStack.push(L[2217]);
}
throw $e3298632987;
}
var $ret3299232993 = $Hanf_arg982732997($z3298832989,self50512916,_plus55,torepr65);
++R.GAS;
return $ret3299232993;
};
var $Hanf_arg982732997 = function(anf_arg392132996,self50512916,_plus55,torepr65) {
var anf_arg392233008 = G(self50512916,"body",L[2217]);
var $z3300033001 = D;
var $f3300633007 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg392233008):R.ffi.throwNonFunApp(L[2217],torepr65,[anf_arg392233008]);
};
try {
if(--R.GAS > 0) {
$z3300033001 = $f3300633007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3300633007,
"from":L[2217]});
}
} catch($e3299832999) {
if(R.isCont($e3299832999)) {
var $ss3300233003 = {"from":L[2217],
"go":function(anf_arg392333009) {
return $Hanf_arg982633010(anf_arg392333009,anf_arg392132996,_plus55);
}};
$e3299832999.stack[R.EXN_STACKHEIGHT++] = $ss3300233003;
}
if(R.isPyretException($e3299832999)) {
$e3299832999.pyretStack.push(L[2217]);
}
throw $e3299832999;
}
var $ret3300433005 = $Hanf_arg982633010($z3300033001,anf_arg392132996,_plus55);
++R.GAS;
return $ret3300433005;
};
var $Hanf_arg982633010 = function(anf_arg392333009,anf_arg392132996,_plus55) {
var $z3301333014 = D;
var $f3301933020 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg392333009):R.ffi.throwNonFunApp(L[2217],_plus55,[(", "),anf_arg392333009]);
};
try {
if(--R.GAS > 0) {
$z3301333014 = $f3301933020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3301933020,
"from":L[2217]});
}
} catch($e3301133012) {
if(R.isCont($e3301133012)) {
var $ss3301533016 = {"from":L[2217],
"go":function(anf_arg392433021) {
return $Hanf_arg982533022(anf_arg392433021,anf_arg392132996,_plus55);
}};
$e3301133012.stack[R.EXN_STACKHEIGHT++] = $ss3301533016;
}
if(R.isPyretException($e3301133012)) {
$e3301133012.pyretStack.push(L[2217]);
}
throw $e3301133012;
}
var $ret3301733018 = $Hanf_arg982533022($z3301333014,anf_arg392132996,_plus55);
++R.GAS;
return $ret3301733018;
};
var $Hanf_arg982533022 = function(anf_arg392433021,anf_arg392132996,_plus55) {
var $z3302533026 = D;
var $f3303133032 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg392132996,anf_arg392433021):R.ffi.throwNonFunApp(L[2217],_plus55,[anf_arg392132996,anf_arg392433021]);
};
try {
if(--R.GAS > 0) {
$z3302533026 = $f3303133032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3303133032,
"from":L[2217]});
}
} catch($e3302333024) {
if(R.isCont($e3302333024)) {
var $ss3302733028 = {"from":L[2217],
"go":function(anf_arg392533033) {
return $Hanf_arg982433034(anf_arg392533033,_plus55);
}};
$e3302333024.stack[R.EXN_STACKHEIGHT++] = $ss3302733028;
}
if(R.isPyretException($e3302333024)) {
$e3302333024.pyretStack.push(L[2217]);
}
throw $e3302333024;
}
var $ret3302933030 = $Hanf_arg982433034($z3302533026,_plus55);
++R.GAS;
return $ret3302933030;
};
var $Hanf_arg982433034 = function(anf_arg392533033,_plus55) {
var $z3303733038 = D;
var $f3304333044 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg392533033,(")")):R.ffi.throwNonFunApp(L[2217],_plus55,[anf_arg392533033,(")")]);
};
try {
if(--R.GAS > 0) {
$z3303733038 = $f3304333044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3304333044,
"from":L[2217]});
}
} catch($e3303533036) {
if(R.isCont($e3303533036)) {
var $ss3303933040 = {"from":L[2217],
"go":function(anf_arg392633045) {
return $Hanf_arg982333046(anf_arg392633045,_plus55);
}};
$e3303533036.stack[R.EXN_STACKHEIGHT++] = $ss3303933040;
}
if(R.isPyretException($e3303533036)) {
$e3303533036.pyretStack.push(L[2217]);
}
throw $e3303533036;
}
var $ret3304133042 = $Hanf_arg982333046($z3303733038,_plus55);
++R.GAS;
return $ret3304133042;
};
var $Hanf_arg982333046 = function(anf_arg392633045,_plus55) {
var $z3304933050 = D;
var $f3305533056 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg392633045):R.ffi.throwNonFunApp(L[2217],_plus55,[("("),anf_arg392633045]);
};
try {
if(--R.GAS > 0) {
$z3304933050 = $f3305533056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3305533056,
"from":L[2217]});
}
} catch($e3304733048) {
if(R.isCont($e3304733048)) {
var $ss3305133052 = {"from":L[2217],
"go":function(anf_arg392733057) {
return $Hanf_arg982233058(anf_arg392733057,_plus55);
}};
$e3304733048.stack[R.EXN_STACKHEIGHT++] = $ss3305133052;
}
if(R.isPyretException($e3304733048)) {
$e3304733048.pyretStack.push(L[2217]);
}
throw $e3304733048;
}
var $ret3305333054 = $Hanf_arg982233058($z3304933050,_plus55);
++R.GAS;
return $ret3305333054;
};
var $Hanf_arg982233058 = function(anf_arg392733057,_plus55) {
var $z3306133062 = D;
var $f3306733068 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-for"),anf_arg392733057):R.ffi.throwNonFunApp(L[2217],_plus55,[("s-for"),anf_arg392733057]);
};
try {
if(--R.GAS > 0) {
$z3306133062 = $f3306733068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3306733068,
"from":L[2217]});
}
} catch($e3305933060) {
if(R.isCont($e3305933060)) {
var $ss3306333064 = {"from":L[2217],
"go":function(ann_DASH_check_DASH_temp390733069) {
return $Hann_DASH_check_DASH_temp982133070(ann_DASH_check_DASH_temp390733069);
}};
$e3305933060.stack[R.EXN_STACKHEIGHT++] = $ss3306333064;
}
if(R.isPyretException($e3305933060)) {
$e3305933060.pyretStack.push(L[2217]);
}
throw $e3305933060;
}
var $ret3306533066 = $Hann_DASH_check_DASH_temp982133070($z3306133062);
++R.GAS;
return $ret3306533066;
};
var $Hann_DASH_check_DASH_temp982133070 = function(ann_DASH_check_DASH_temp390733069) {
return ann_DASH_check_DASH_temp390733069;
};
var $Hcont_tail_arg981912936 = function(cont_tail_arg390412934,if_helper389212935) {
if(--R.GAS > 0) {
$z3307133072 = R.isFunction(if_helper389212935)?if_helper389212935.app(cont_tail_arg390412934):R.ffi.throwNonFunApp(L[2217],if_helper389212935,[cont_tail_arg390412934]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper389212935)?if_helper389212935.app(cont_tail_arg390412934):R.ffi.throwNonFunApp(L[2217],if_helper389212935,[cont_tail_arg390412934]);
},
"from":L[2217]});
}
++R.GAS;
return $z3307133072;
};
var $Hcont_tail_arg982012951 = function(cont_tail_arg389712950,if_helper389212935) {
if(--R.GAS > 0) {
$z3307333074 = R.isFunction(if_helper389212935)?if_helper389212935.app(cont_tail_arg389712950):R.ffi.throwNonFunApp(L[2217],if_helper389212935,[cont_tail_arg389712950]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper389212935)?if_helper389212935.app(cont_tail_arg389712950):R.ffi.throwNonFunApp(L[2217],if_helper389212935,[cont_tail_arg389712950]);
},
"from":L[2217]});
}
++R.GAS;
return $z3307333074;
};
var $Hanf_arg981812974 = function(anf_arg381612971,INDENT118169,PP170,anf_fun381512972,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_arg381733088 = G(PP170,"mt-doc",L[4203]);
var anf_arg381833089 = G(PP170,"langle",L[4202]);
var anf_arg381933090 = G(PP170,"commabreak",L[4201]);
var anf_arg382033091 = G(PP170,"rangle",L[4200]);
var anf_bracket382133107 = G(self97012973,"params",L[4199]);
var anf_fun382233085 = G(anf_bracket382133107,"map",L[4198]);
var anf_arg382533086 = R.makeFunction(function(recv_DASH_49833093) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4197],1,arguments);
}
var anf_fun382433104 = G(recv_DASH_49833093,"tosource",L[4197]);
var $z3309633097 = D;
var $f3310233103 = function(_) {
return R.isFunction(anf_fun382433104)?anf_fun382433104.app():R.ffi.throwNonFunApp(L[4197],anf_fun382433104,[]);
};
try {
if(--R.GAS > 0) {
$z3309633097 = $f3310233103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3310233103,
"from":L[4197]});
}
} catch($e3309433095) {
if(R.isCont($e3309433095)) {
var $ss3309833099 = {"from":L[4197],
"go":function(ann_DASH_check_DASH_temp382333105) {
return $Hann_DASH_check_DASH_temp978233106(ann_DASH_check_DASH_temp382333105);
}};
$e3309433095.stack[R.EXN_STACKHEIGHT++] = $ss3309833099;
}
if(R.isPyretException($e3309433095)) {
$e3309433095.pyretStack.push(L[4197]);
}
throw $e3309433095;
}
var $ret3310033101 = $Hann_DASH_check_DASH_temp978233106($z3309633097);
++R.GAS;
return $ret3310033101;
});
var $z3307733078 = D;
var $f3308333084 = function(_) {
return R.isFunction(anf_fun382233085)?anf_fun382233085.app(anf_arg382533086):R.ffi.throwNonFunApp(L[4196],anf_fun382233085,[anf_arg382533086]);
};
try {
if(--R.GAS > 0) {
$z3307733078 = $f3308333084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3308333084,
"from":L[4196]});
}
} catch($e3307533076) {
if(R.isCont($e3307533076)) {
var $ss3307933080 = {"from":L[4196],
"go":function(anf_arg382633087) {
return $Hanf_arg981733092(anf_arg382633087,INDENT118169,PP170,anf_arg381612971,anf_arg381733088,anf_arg381833089,anf_arg381933090,anf_arg382033091,anf_fun381512972,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3307533076.stack[R.EXN_STACKHEIGHT++] = $ss3307933080;
}
if(R.isPyretException($e3307533076)) {
$e3307533076.pyretStack.push(L[4196]);
}
throw $e3307533076;
}
var $ret3308133082 = $Hanf_arg981733092($z3307733078,INDENT118169,PP170,anf_arg381612971,anf_arg381733088,anf_arg381833089,anf_arg381933090,anf_arg382033091,anf_fun381512972,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3308133082;
};
var $Hanf_arg981733092 = function(anf_arg382633087,INDENT118169,PP170,anf_arg381612971,anf_arg381733088,anf_arg381833089,anf_arg381933090,anf_arg382033091,anf_fun381512972,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var $z3311033111 = D;
var $f3311633117 = function(_) {
return R.isFunction(anf_fun381512972)?anf_fun381512972.app(anf_arg381612971,(0),anf_arg381733088,anf_arg381833089,anf_arg381933090,anf_arg382033091,anf_arg382633087):R.ffi.throwNonFunApp(L[4204],anf_fun381512972,[anf_arg381612971,(0),anf_arg381733088,anf_arg381833089,anf_arg381933090,anf_arg382033091,anf_arg382633087]);
};
try {
if(--R.GAS > 0) {
$z3311033111 = $f3311633117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3311633117,
"from":L[4204]});
}
} catch($e3310833109) {
if(R.isCont($e3310833109)) {
var $ss3311233113 = {"from":L[4204],
"go":function(tys97433118) {
return $Htys981633119(tys97433118,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3310833109.stack[R.EXN_STACKHEIGHT++] = $ss3311233113;
}
if(R.isPyretException($e3310833109)) {
$e3310833109.pyretStack.push(L[4204]);
}
throw $e3310833109;
}
var $ret3311433115 = $Htys981633119($z3311033111,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3311433115;
};
var $Htys981633119 = function(tys97433118,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun382733130 = G(PP170,"str",L[4207]);
var anf_arg382833131 = G(self97012973,"name",L[4206]);
var $z3312233123 = D;
var $f3312833129 = function(_) {
return R.isFunction(anf_fun382733130)?anf_fun382733130.app(anf_arg382833131):R.ffi.throwNonFunApp(L[4205],anf_fun382733130,[anf_arg382833131]);
};
try {
if(--R.GAS > 0) {
$z3312233123 = $f3312833129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3312833129,
"from":L[4205]});
}
} catch($e3312033121) {
if(R.isCont($e3312033121)) {
var $ss3312433125 = {"from":L[4205],
"go":function(anf_arg382933132) {
return $Hanf_arg981533133(anf_arg382933132,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
}};
$e3312033121.stack[R.EXN_STACKHEIGHT++] = $ss3312433125;
}
if(R.isPyretException($e3312033121)) {
$e3312033121.pyretStack.push(L[4205]);
}
throw $e3312033121;
}
var $ret3312633127 = $Hanf_arg981533133($z3312233123,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
++R.GAS;
return $ret3312633127;
};
var $Hanf_arg981533133 = function(anf_arg382933132,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data_DASH_expr140442,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55) {
var $z3313633137 = D;
var $f3314233143 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_data_DASH_expr140442,anf_arg382933132):R.ffi.throwNonFunApp(L[4208],_plus55,[str_DASH_data_DASH_expr140442,anf_arg382933132]);
};
try {
if(--R.GAS > 0) {
$z3313633137 = $f3314233143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3314233143,
"from":L[4208]});
}
} catch($e3313433135) {
if(R.isCont($e3313433135)) {
var $ss3313833139 = {"from":L[4208],
"go":function(anf_arg383033144) {
return $Hanf_arg981433145(anf_arg383033144,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
}};
$e3313433135.stack[R.EXN_STACKHEIGHT++] = $ss3313833139;
}
if(R.isPyretException($e3313433135)) {
$e3313433135.pyretStack.push(L[4208]);
}
throw $e3313433135;
}
var $ret3314033141 = $Hanf_arg981433145($z3313633137,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
++R.GAS;
return $ret3314033141;
};
var $Hanf_arg981433145 = function(anf_arg383033144,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55) {
var anf_arg383133156 = G(PP170,"comma",L[4209]);
var $z3314833149 = D;
var $f3315433155 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg383033144,anf_arg383133156):R.ffi.throwNonFunApp(L[4208],_plus55,[anf_arg383033144,anf_arg383133156]);
};
try {
if(--R.GAS > 0) {
$z3314833149 = $f3315433155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3315433155,
"from":L[4208]});
}
} catch($e3314633147) {
if(R.isCont($e3314633147)) {
var $ss3315033151 = {"from":L[4208],
"go":function(anf_arg383233157) {
return $Hanf_arg981333158(anf_arg383233157,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
}};
$e3314633147.stack[R.EXN_STACKHEIGHT++] = $ss3315033151;
}
if(R.isPyretException($e3314633147)) {
$e3314633147.pyretStack.push(L[4208]);
}
throw $e3314633147;
}
var $ret3315233153 = $Hanf_arg981333158($z3314833149,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
++R.GAS;
return $ret3315233153;
};
var $Hanf_arg981333158 = function(anf_arg383233157,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55) {
var anf_bracket383333172 = G(self97012973,"namet",L[4212]);
var anf_fun383433169 = G(anf_bracket383333172,"tosource",L[4211]);
var $z3316133162 = D;
var $f3316733168 = function(_) {
return R.isFunction(anf_fun383433169)?anf_fun383433169.app():R.ffi.throwNonFunApp(L[4210],anf_fun383433169,[]);
};
try {
if(--R.GAS > 0) {
$z3316133162 = $f3316733168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3316733168,
"from":L[4210]});
}
} catch($e3315933160) {
if(R.isCont($e3315933160)) {
var $ss3316333164 = {"from":L[4210],
"go":function(anf_arg383533170) {
return $Hanf_arg981233171(anf_arg383533170,INDENT118169,PP170,anf_arg383233157,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
}};
$e3315933160.stack[R.EXN_STACKHEIGHT++] = $ss3316333164;
}
if(R.isPyretException($e3315933160)) {
$e3315933160.pyretStack.push(L[4210]);
}
throw $e3315933160;
}
var $ret3316533166 = $Hanf_arg981233171($z3316133162,INDENT118169,PP170,anf_arg383233157,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
++R.GAS;
return $ret3316533166;
};
var $Hanf_arg981233171 = function(anf_arg383533170,INDENT118169,PP170,anf_arg383233157,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55) {
var $z3317533176 = D;
var $f3318133182 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg383233157,anf_arg383533170):R.ffi.throwNonFunApp(L[4208],_plus55,[anf_arg383233157,anf_arg383533170]);
};
try {
if(--R.GAS > 0) {
$z3317533176 = $f3318133182();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3318133182,
"from":L[4208]});
}
} catch($e3317333174) {
if(R.isCont($e3317333174)) {
var $ss3317733178 = {"from":L[4208],
"go":function(anf_arg383633183) {
return $Hanf_arg981133184(anf_arg383633183,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
}};
$e3317333174.stack[R.EXN_STACKHEIGHT++] = $ss3317733178;
}
if(R.isPyretException($e3317333174)) {
$e3317333174.pyretStack.push(L[4208]);
}
throw $e3317333174;
}
var $ret3317933180 = $Hanf_arg981133184($z3317533176,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55);
++R.GAS;
return $ret3317933180;
};
var $Hanf_arg981133184 = function(anf_arg383633183,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys97433118,_plus55) {
var $z3318733188 = D;
var $f3319333194 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg383633183,tys97433118):R.ffi.throwNonFunApp(L[4208],_plus55,[anf_arg383633183,tys97433118]);
};
try {
if(--R.GAS > 0) {
$z3318733188 = $f3319333194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3319333194,
"from":L[4208]});
}
} catch($e3318533186) {
if(R.isCont($e3318533186)) {
var $ss3318933190 = {"from":L[4208],
"go":function(anf_arg383733195) {
return $Hanf_arg981033196(anf_arg383733195,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3318533186.stack[R.EXN_STACKHEIGHT++] = $ss3318933190;
}
if(R.isPyretException($e3318533186)) {
$e3318533186.pyretStack.push(L[4208]);
}
throw $e3318533186;
}
var $ret3319133192 = $Hanf_arg981033196($z3318733188,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3319133192;
};
var $Hanf_arg981033196 = function(anf_arg383733195,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var $z3319933200 = D;
var $f3320533206 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg383733195,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4213],_plus55,[anf_arg383733195,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z3319933200 = $f3320533206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3320533206,
"from":L[4213]});
}
} catch($e3319733198) {
if(R.isCont($e3319733198)) {
var $ss3320133202 = {"from":L[4213],
"go":function(header97533207) {
return $Hheader980933208(header97533207,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3319733198.stack[R.EXN_STACKHEIGHT++] = $ss3320133202;
}
if(R.isPyretException($e3319733198)) {
$e3319733198.pyretStack.push(L[4213]);
}
throw $e3319733198;
}
var $ret3320333204 = $Hheader980933208($z3319933200,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3320333204;
};
var $Hheader980933208 = function(header97533207,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun383833221 = G(PP170,"surround-separate",L[4216]);
var anf_arg383933220 = G(PP170,"mt-doc",L[4215]);
var $z3321133212 = D;
var $f3321733218 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_deriving142468):R.ffi.throwNonFunApp(L[4214],_plus55,[break_DASH_one119168,str_DASH_deriving142468]);
};
try {
if(--R.GAS > 0) {
$z3321133212 = $f3321733218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3321733218,
"from":L[4214]});
}
} catch($e3320933210) {
if(R.isCont($e3320933210)) {
var $ss3321333214 = {"from":L[4214],
"go":function(anf_arg384033219) {
return $Hanf_arg980833222(anf_arg384033219,INDENT118169,PP170,anf_arg383933220,anf_fun383833221,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3320933210.stack[R.EXN_STACKHEIGHT++] = $ss3321333214;
}
if(R.isPyretException($e3320933210)) {
$e3320933210.pyretStack.push(L[4214]);
}
throw $e3320933210;
}
var $ret3321533216 = $Hanf_arg980833222($z3321133212,INDENT118169,PP170,anf_arg383933220,anf_fun383833221,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3321533216;
};
var $Hanf_arg980833222 = function(anf_arg384033219,INDENT118169,PP170,anf_arg383933220,anf_fun383833221,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_arg384133236 = G(PP170,"commabreak",L[4223]);
var anf_arg384233237 = G(PP170,"mt-doc",L[4222]);
var anf_bracket384333253 = G(self97012973,"mixins",L[4221]);
var anf_fun384433233 = G(anf_bracket384333253,"map",L[4220]);
var anf_arg384733234 = R.makeFunction(function(m97733239) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4218],1,arguments);
}
var anf_fun384633250 = G(m97733239,"tosource",L[4219]);
var $z3324233243 = D;
var $f3324833249 = function(_) {
return R.isFunction(anf_fun384633250)?anf_fun384633250.app():R.ffi.throwNonFunApp(L[4218],anf_fun384633250,[]);
};
try {
if(--R.GAS > 0) {
$z3324233243 = $f3324833249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3324833249,
"from":L[4218]});
}
} catch($e3324033241) {
if(R.isCont($e3324033241)) {
var $ss3324433245 = {"from":L[4218],
"go":function(ann_DASH_check_DASH_temp384533251) {
return $Hann_DASH_check_DASH_temp978333252(ann_DASH_check_DASH_temp384533251);
}};
$e3324033241.stack[R.EXN_STACKHEIGHT++] = $ss3324433245;
}
if(R.isPyretException($e3324033241)) {
$e3324033241.pyretStack.push(L[4218]);
}
throw $e3324033241;
}
var $ret3324633247 = $Hann_DASH_check_DASH_temp978333252($z3324233243);
++R.GAS;
return $ret3324633247;
});
var $z3322533226 = D;
var $f3323133232 = function(_) {
return R.isFunction(anf_fun384433233)?anf_fun384433233.app(anf_arg384733234):R.ffi.throwNonFunApp(L[4217],anf_fun384433233,[anf_arg384733234]);
};
try {
if(--R.GAS > 0) {
$z3322533226 = $f3323133232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3323133232,
"from":L[4217]});
}
} catch($e3322333224) {
if(R.isCont($e3322333224)) {
var $ss3322733228 = {"from":L[4217],
"go":function(anf_arg384833235) {
return $Hanf_arg980733238(anf_arg384833235,INDENT118169,PP170,anf_arg383933220,anf_arg384033219,anf_arg384133236,anf_arg384233237,anf_fun383833221,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3322333224.stack[R.EXN_STACKHEIGHT++] = $ss3322733228;
}
if(R.isPyretException($e3322333224)) {
$e3322333224.pyretStack.push(L[4217]);
}
throw $e3322333224;
}
var $ret3322933230 = $Hanf_arg980733238($z3322533226,INDENT118169,PP170,anf_arg383933220,anf_arg384033219,anf_arg384133236,anf_arg384233237,anf_fun383833221,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3322933230;
};
var $Hanf_arg980733238 = function(anf_arg384833235,INDENT118169,PP170,anf_arg383933220,anf_arg384033219,anf_arg384133236,anf_arg384233237,anf_fun383833221,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var $z3325633257 = D;
var $f3326233263 = function(_) {
return R.isFunction(anf_fun383833221)?anf_fun383833221.app(INDENT118169,(0),anf_arg383933220,anf_arg384033219,anf_arg384133236,anf_arg384233237,anf_arg384833235):R.ffi.throwNonFunApp(L[4224],anf_fun383833221,[INDENT118169,(0),anf_arg383933220,anf_arg384033219,anf_arg384133236,anf_arg384233237,anf_arg384833235]);
};
try {
if(--R.GAS > 0) {
$z3325633257 = $f3326233263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3326233263,
"from":L[4224]});
}
} catch($e3325433255) {
if(R.isCont($e3325433255)) {
var $ss3325833259 = {"from":L[4224],
"go":function(_deriving97633264) {
return $H_deriving980633265(_deriving97633264,INDENT118169,PP170,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3325433255.stack[R.EXN_STACKHEIGHT++] = $ss3325833259;
}
if(R.isPyretException($e3325433255)) {
$e3325433255.pyretStack.push(L[4224]);
}
throw $e3325433255;
}
var $ret3326033261 = $H_deriving980633265($z3325633257,INDENT118169,PP170,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3326033261;
};
var $H_deriving980633265 = function(_deriving97633264,INDENT118169,PP170,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun384933277 = G(PP170,"separate",L[4226]);
var $z3326833269 = D;
var $f3327433275 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_pipespace162728):R.ffi.throwNonFunApp(L[4225],_plus55,[break_DASH_one119168,str_DASH_pipespace162728]);
};
try {
if(--R.GAS > 0) {
$z3326833269 = $f3327433275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3327433275,
"from":L[4225]});
}
} catch($e3326633267) {
if(R.isCont($e3326633267)) {
var $ss3327033271 = {"from":L[4225],
"go":function(anf_arg385033276) {
return $Hanf_arg980533278(anf_arg385033276,INDENT118169,PP170,_deriving97633264,anf_fun384933277,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3326633267.stack[R.EXN_STACKHEIGHT++] = $ss3327033271;
}
if(R.isPyretException($e3326633267)) {
$e3326633267.pyretStack.push(L[4225]);
}
throw $e3326633267;
}
var $ret3327233273 = $Hanf_arg980533278($z3326833269,INDENT118169,PP170,_deriving97633264,anf_fun384933277,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3327233273;
};
var $Hanf_arg980533278 = function(anf_arg385033276,INDENT118169,PP170,_deriving97633264,anf_fun384933277,break_DASH_one119168,header97533207,lists974,optional_DASH_section97112959,self97012973,str_DASH_blank124234,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun386133289 = R.makeFunction(function(arg_DASH_49933292) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4227],1,arguments);
}
var anf_fun385233306 = G(lists974,"link",L[4235]);
var anf_bracket385333323 = G(self97012973,"variants",L[4234]);
var anf_fun385433303 = G(anf_bracket385333323,"map",L[4233]);
var anf_arg385933304 = R.makeFunction(function(v97933308) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4229],1,arguments);
}
var anf_fun385633321 = G(PP170,"nest",L[4232]);
var anf_fun385733319 = G(v97933308,"tosource",L[4231]);
var $z3331133312 = D;
var $f3331733318 = function(_) {
return R.isFunction(anf_fun385733319)?anf_fun385733319.app():R.ffi.throwNonFunApp(L[4230],anf_fun385733319,[]);
};
try {
if(--R.GAS > 0) {
$z3331133312 = $f3331733318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3331733318,
"from":L[4230]});
}
} catch($e3330933310) {
if(R.isCont($e3330933310)) {
var $ss3331333314 = {"from":L[4230],
"go":function(anf_arg385833320) {
return $Hanf_arg978533322(anf_arg385833320,INDENT118169,anf_fun385633321);
}};
$e3330933310.stack[R.EXN_STACKHEIGHT++] = $ss3331333314;
}
if(R.isPyretException($e3330933310)) {
$e3330933310.pyretStack.push(L[4230]);
}
throw $e3330933310;
}
var $ret3331533316 = $Hanf_arg978533322($z3331133312,INDENT118169,anf_fun385633321);
++R.GAS;
return $ret3331533316;
});
var $z3329533296 = D;
var $f3330133302 = function(_) {
return R.isFunction(anf_fun385433303)?anf_fun385433303.app(anf_arg385933304):R.ffi.throwNonFunApp(L[4228],anf_fun385433303,[anf_arg385933304]);
};
try {
if(--R.GAS > 0) {
$z3329533296 = $f3330133302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3330133302,
"from":L[4228]});
}
} catch($e3329333294) {
if(R.isCont($e3329333294)) {
var $ss3329733298 = {"from":L[4228],
"go":function(anf_arg386033305) {
return $Hanf_arg978733307(anf_arg386033305,anf_fun385233306,arg_DASH_49933292);
}};
$e3329333294.stack[R.EXN_STACKHEIGHT++] = $ss3329733298;
}
if(R.isPyretException($e3329333294)) {
$e3329333294.pyretStack.push(L[4228]);
}
throw $e3329333294;
}
var $ret3329933300 = $Hanf_arg978733307($z3329533296,anf_fun385233306,arg_DASH_49933292);
++R.GAS;
return $ret3329933300;
});
var $z3328133282 = D;
var $f3328733288 = function(_) {
return R.isFunction(anf_fun386133289)?anf_fun386133289.app(str_DASH_blank124234):R.ffi.throwNonFunApp(L[4227],anf_fun386133289,[str_DASH_blank124234]);
};
try {
if(--R.GAS > 0) {
$z3328133282 = $f3328733288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3328733288,
"from":L[4227]});
}
} catch($e3327933280) {
if(R.isCont($e3327933280)) {
var $ss3328333284 = {"from":L[4227],
"go":function(anf_arg386233290) {
return $Hanf_arg980433291(anf_arg386233290,INDENT118169,PP170,_deriving97633264,anf_arg385033276,anf_fun384933277,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3327933280.stack[R.EXN_STACKHEIGHT++] = $ss3328333284;
}
if(R.isPyretException($e3327933280)) {
$e3327933280.pyretStack.push(L[4227]);
}
throw $e3327933280;
}
var $ret3328533286 = $Hanf_arg980433291($z3328133282,INDENT118169,PP170,_deriving97633264,anf_arg385033276,anf_fun384933277,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3328533286;
};
var $Hanf_arg980433291 = function(anf_arg386233290,INDENT118169,PP170,_deriving97633264,anf_arg385033276,anf_fun384933277,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var $z3332633327 = D;
var $f3333233333 = function(_) {
return R.isFunction(anf_fun384933277)?anf_fun384933277.app(anf_arg385033276,anf_arg386233290):R.ffi.throwNonFunApp(L[4236],anf_fun384933277,[anf_arg385033276,anf_arg386233290]);
};
try {
if(--R.GAS > 0) {
$z3332633327 = $f3333233333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3333233333,
"from":L[4236]});
}
} catch($e3332433325) {
if(R.isCont($e3332433325)) {
var $ss3332833329 = {"from":L[4236],
"go":function(variants97833334) {
return $Hvariants980333335(variants97833334,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3332433325.stack[R.EXN_STACKHEIGHT++] = $ss3332833329;
}
if(R.isPyretException($e3332433325)) {
$e3332433325.pyretStack.push(L[4236]);
}
throw $e3332433325;
}
var $ret3333033331 = $Hvariants980333335($z3332633327,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3333033331;
};
var $Hvariants980333335 = function(variants97833334,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun386333350 = G(PP170,"separate",L[4243]);
var anf_arg386433349 = G(PP170,"commabreak",L[4242]);
var anf_bracket386533366 = G(self97012973,"shared-members",L[4241]);
var anf_fun386633346 = G(anf_bracket386533366,"map",L[4240]);
var anf_arg386933347 = R.makeFunction(function(s98133352) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4238],1,arguments);
}
var anf_fun386833363 = G(s98133352,"tosource",L[4239]);
var $z3335533356 = D;
var $f3336133362 = function(_) {
return R.isFunction(anf_fun386833363)?anf_fun386833363.app():R.ffi.throwNonFunApp(L[4238],anf_fun386833363,[]);
};
try {
if(--R.GAS > 0) {
$z3335533356 = $f3336133362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3336133362,
"from":L[4238]});
}
} catch($e3335333354) {
if(R.isCont($e3335333354)) {
var $ss3335733358 = {"from":L[4238],
"go":function(ann_DASH_check_DASH_temp386733364) {
return $Hann_DASH_check_DASH_temp978833365(ann_DASH_check_DASH_temp386733364);
}};
$e3335333354.stack[R.EXN_STACKHEIGHT++] = $ss3335733358;
}
if(R.isPyretException($e3335333354)) {
$e3335333354.pyretStack.push(L[4238]);
}
throw $e3335333354;
}
var $ret3335933360 = $Hann_DASH_check_DASH_temp978833365($z3335533356);
++R.GAS;
return $ret3335933360;
});
var $z3333833339 = D;
var $f3334433345 = function(_) {
return R.isFunction(anf_fun386633346)?anf_fun386633346.app(anf_arg386933347):R.ffi.throwNonFunApp(L[4237],anf_fun386633346,[anf_arg386933347]);
};
try {
if(--R.GAS > 0) {
$z3333833339 = $f3334433345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3334433345,
"from":L[4237]});
}
} catch($e3333633337) {
if(R.isCont($e3333633337)) {
var $ss3334033341 = {"from":L[4237],
"go":function(anf_arg387033348) {
return $Hanf_arg980233351(anf_arg387033348,INDENT118169,PP170,_deriving97633264,anf_arg386433349,anf_fun386333350,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants97833334,_plus55);
}};
$e3333633337.stack[R.EXN_STACKHEIGHT++] = $ss3334033341;
}
if(R.isPyretException($e3333633337)) {
$e3333633337.pyretStack.push(L[4237]);
}
throw $e3333633337;
}
var $ret3334233343 = $Hanf_arg980233351($z3333833339,INDENT118169,PP170,_deriving97633264,anf_arg386433349,anf_fun386333350,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants97833334,_plus55);
++R.GAS;
return $ret3334233343;
};
var $Hanf_arg980233351 = function(anf_arg387033348,INDENT118169,PP170,_deriving97633264,anf_arg386433349,anf_fun386333350,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants97833334,_plus55) {
var $z3336933370 = D;
var $f3337533376 = function(_) {
return R.isFunction(anf_fun386333350)?anf_fun386333350.app(anf_arg386433349,anf_arg387033348):R.ffi.throwNonFunApp(L[4244],anf_fun386333350,[anf_arg386433349,anf_arg387033348]);
};
try {
if(--R.GAS > 0) {
$z3336933370 = $f3337533376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3337533376,
"from":L[4244]});
}
} catch($e3336733368) {
if(R.isCont($e3336733368)) {
var $ss3337133372 = {"from":L[4244],
"go":function(anf_arg387133377) {
return $Hanf_arg980133378(anf_arg387133377,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants97833334,_plus55);
}};
$e3336733368.stack[R.EXN_STACKHEIGHT++] = $ss3337133372;
}
if(R.isPyretException($e3336733368)) {
$e3336733368.pyretStack.push(L[4244]);
}
throw $e3336733368;
}
var $ret3337333374 = $Hanf_arg980133378($z3336933370,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants97833334,_plus55);
++R.GAS;
return $ret3337333374;
};
var $Hanf_arg980133378 = function(anf_arg387133377,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants97833334,_plus55) {
var $z3338133382 = D;
var $f3338733388 = function(_) {
return R.isFunction(optional_DASH_section97112959.$var)?optional_DASH_section97112959.$var.app(str_DASH_sharing167793,anf_arg387133377):R.ffi.throwNonFunApp(L[4245],optional_DASH_section97112959.$var,[str_DASH_sharing167793,anf_arg387133377]);
};
try {
if(--R.GAS > 0) {
$z3338133382 = $f3338733388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3338733388,
"from":L[4245]});
}
} catch($e3337933380) {
if(R.isCont($e3337933380)) {
var $ss3338333384 = {"from":L[4245],
"go":function(shared98033389) {
return $Hshared980033390(shared98033389,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_where182988,variants97833334,_plus55);
}};
$e3337933380.stack[R.EXN_STACKHEIGHT++] = $ss3338333384;
}
if(R.isPyretException($e3337933380)) {
$e3337933380.pyretStack.push(L[4245]);
}
throw $e3337933380;
}
var $ret3338533386 = $Hshared980033390($z3338133382,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_where182988,variants97833334,_plus55);
++R.GAS;
return $ret3338533386;
};
var $Hshared980033390 = function(shared98033389,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,optional_DASH_section97112959,self97012973,str_DASH_end148546,str_DASH_where182988,variants97833334,_plus55) {
var cases_DASH_val50033424 = G(self97012973,"_check",L[4253]);
var anf_fun387233401 = G(cases_DASH_val50033424,"_match",L[4247]);
var anf_obj387433407 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4251],0,arguments);
}
var ann_DASH_check_DASH_temp387333423 = G(PP170,"mt-doc",L[4252]);
return ann_DASH_check_DASH_temp387333423;
});
var anf_obj387833408 = R.makeFunction(function(chk98333409) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4248],1,arguments);
}
var anf_fun387633420 = G(chk98333409,"tosource",L[4250]);
var $z3341233413 = D;
var $f3341833419 = function(_) {
return R.isFunction(anf_fun387633420)?anf_fun387633420.app():R.ffi.throwNonFunApp(L[4249],anf_fun387633420,[]);
};
try {
if(--R.GAS > 0) {
$z3341233413 = $f3341833419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3341833419,
"from":L[4249]});
}
} catch($e3341033411) {
if(R.isCont($e3341033411)) {
var $ss3341433415 = {"from":L[4249],
"go":function(anf_arg387733421) {
return $Hanf_arg979033422(anf_arg387733421,optional_DASH_section97112959,str_DASH_where182988);
}};
$e3341033411.stack[R.EXN_STACKHEIGHT++] = $ss3341433415;
}
if(R.isPyretException($e3341033411)) {
$e3341033411.pyretStack.push(L[4249]);
}
throw $e3341033411;
}
var $ret3341633417 = $Hanf_arg979033422($z3341233413,optional_DASH_section97112959,str_DASH_where182988);
++R.GAS;
return $ret3341633417;
});
var anf_arg387933402 = R.makeObject({"none":anf_obj387433407,
"some":anf_obj387833408});
var anf_arg388133403 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4247],0,arguments);
}
var ann_DASH_check_DASH_temp388033406 = R.throwNoBranchesMatched(L[4247],("cases"));
return ann_DASH_check_DASH_temp388033406;
});
var $z3339333394 = D;
var $f3339933400 = function(_) {
return R.isFunction(anf_fun387233401)?anf_fun387233401.app(anf_arg387933402,anf_arg388133403):R.ffi.throwNonFunApp(L[4246],anf_fun387233401,[anf_arg387933402,anf_arg388133403]);
};
try {
if(--R.GAS > 0) {
$z3339333394 = $f3339933400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3339933400,
"from":L[4246]});
}
} catch($e3339133392) {
if(R.isCont($e3339133392)) {
var $ss3339533396 = {"from":L[4246],
"go":function(_check98233404) {
return $H_check979933405(_check98233404,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,shared98033389,str_DASH_end148546,variants97833334,_plus55);
}};
$e3339133392.stack[R.EXN_STACKHEIGHT++] = $ss3339533396;
}
if(R.isPyretException($e3339133392)) {
$e3339133392.pyretStack.push(L[4246]);
}
throw $e3339133392;
}
var $ret3339733398 = $H_check979933405($z3339333394,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,shared98033389,str_DASH_end148546,variants97833334,_plus55);
++R.GAS;
return $ret3339733398;
};
var $H_check979933405 = function(_check98233404,INDENT118169,PP170,_deriving97633264,break_DASH_one119168,header97533207,shared98033389,str_DASH_end148546,variants97833334,_plus55) {
var $z3342733428 = D;
var $f3343333434 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_end148546):R.ffi.throwNonFunApp(L[4254],_plus55,[break_DASH_one119168,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z3342733428 = $f3343333434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3343333434,
"from":L[4254]});
}
} catch($e3342533426) {
if(R.isCont($e3342533426)) {
var $ss3342933430 = {"from":L[4254],
"go":function(footer98433435) {
return $Hfooter979833436(footer98433435,INDENT118169,PP170,_check98233404,_deriving97633264,header97533207,shared98033389,variants97833334,_plus55);
}};
$e3342533426.stack[R.EXN_STACKHEIGHT++] = $ss3342933430;
}
if(R.isPyretException($e3342533426)) {
$e3342533426.pyretStack.push(L[4254]);
}
throw $e3342533426;
}
var $ret3343133432 = $Hfooter979833436($z3342733428,INDENT118169,PP170,_check98233404,_deriving97633264,header97533207,shared98033389,variants97833334,_plus55);
++R.GAS;
return $ret3343133432;
};
var $Hfooter979833436 = function(footer98433435,INDENT118169,PP170,_check98233404,_deriving97633264,header97533207,shared98033389,variants97833334,_plus55) {
var $z3343933440 = D;
var $f3344533446 = function(_) {
return R.isFunction(_plus55)?_plus55.app(header97533207,_deriving97633264):R.ffi.throwNonFunApp(L[4255],_plus55,[header97533207,_deriving97633264]);
};
try {
if(--R.GAS > 0) {
$z3343933440 = $f3344533446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3344533446,
"from":L[4255]});
}
} catch($e3343733438) {
if(R.isCont($e3343733438)) {
var $ss3344133442 = {"from":L[4255],
"go":function(anf_arg388233447) {
return $Hanf_arg979733448(anf_arg388233447,INDENT118169,PP170,_check98233404,footer98433435,shared98033389,variants97833334,_plus55);
}};
$e3343733438.stack[R.EXN_STACKHEIGHT++] = $ss3344133442;
}
if(R.isPyretException($e3343733438)) {
$e3343733438.pyretStack.push(L[4255]);
}
throw $e3343733438;
}
var $ret3344333444 = $Hanf_arg979733448($z3343933440,INDENT118169,PP170,_check98233404,footer98433435,shared98033389,variants97833334,_plus55);
++R.GAS;
return $ret3344333444;
};
var $Hanf_arg979733448 = function(anf_arg388233447,INDENT118169,PP170,_check98233404,footer98433435,shared98033389,variants97833334,_plus55) {
var anf_fun388333461 = G(PP170,"group",L[4258]);
var anf_fun388433459 = G(PP170,"nest",L[4257]);
var $z3345133452 = D;
var $f3345733458 = function(_) {
return R.isFunction(anf_fun388433459)?anf_fun388433459.app(INDENT118169,variants97833334):R.ffi.throwNonFunApp(L[4256],anf_fun388433459,[INDENT118169,variants97833334]);
};
try {
if(--R.GAS > 0) {
$z3345133452 = $f3345733458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3345733458,
"from":L[4256]});
}
} catch($e3344933450) {
if(R.isCont($e3344933450)) {
var $ss3345333454 = {"from":L[4256],
"go":function(anf_arg388533460) {
return $Hanf_arg979633462(anf_arg388533460,_check98233404,anf_arg388233447,anf_fun388333461,footer98433435,shared98033389,_plus55);
}};
$e3344933450.stack[R.EXN_STACKHEIGHT++] = $ss3345333454;
}
if(R.isPyretException($e3344933450)) {
$e3344933450.pyretStack.push(L[4256]);
}
throw $e3344933450;
}
var $ret3345533456 = $Hanf_arg979633462($z3345133452,_check98233404,anf_arg388233447,anf_fun388333461,footer98433435,shared98033389,_plus55);
++R.GAS;
return $ret3345533456;
};
var $Hanf_arg979633462 = function(anf_arg388533460,_check98233404,anf_arg388233447,anf_fun388333461,footer98433435,shared98033389,_plus55) {
var $z3346533466 = D;
var $f3347133472 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg388533460,shared98033389):R.ffi.throwNonFunApp(L[4259],_plus55,[anf_arg388533460,shared98033389]);
};
try {
if(--R.GAS > 0) {
$z3346533466 = $f3347133472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3347133472,
"from":L[4259]});
}
} catch($e3346333464) {
if(R.isCont($e3346333464)) {
var $ss3346733468 = {"from":L[4259],
"go":function(anf_arg388633473) {
return $Hanf_arg979533474(anf_arg388633473,_check98233404,anf_arg388233447,anf_fun388333461,footer98433435,_plus55);
}};
$e3346333464.stack[R.EXN_STACKHEIGHT++] = $ss3346733468;
}
if(R.isPyretException($e3346333464)) {
$e3346333464.pyretStack.push(L[4259]);
}
throw $e3346333464;
}
var $ret3346933470 = $Hanf_arg979533474($z3346533466,_check98233404,anf_arg388233447,anf_fun388333461,footer98433435,_plus55);
++R.GAS;
return $ret3346933470;
};
var $Hanf_arg979533474 = function(anf_arg388633473,_check98233404,anf_arg388233447,anf_fun388333461,footer98433435,_plus55) {
var $z3347733478 = D;
var $f3348333484 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg388633473,_check98233404):R.ffi.throwNonFunApp(L[4259],_plus55,[anf_arg388633473,_check98233404]);
};
try {
if(--R.GAS > 0) {
$z3347733478 = $f3348333484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3348333484,
"from":L[4259]});
}
} catch($e3347533476) {
if(R.isCont($e3347533476)) {
var $ss3347933480 = {"from":L[4259],
"go":function(anf_arg388733485) {
return $Hanf_arg979433486(anf_arg388733485,anf_arg388233447,anf_fun388333461,footer98433435,_plus55);
}};
$e3347533476.stack[R.EXN_STACKHEIGHT++] = $ss3347933480;
}
if(R.isPyretException($e3347533476)) {
$e3347533476.pyretStack.push(L[4259]);
}
throw $e3347533476;
}
var $ret3348133482 = $Hanf_arg979433486($z3347733478,anf_arg388233447,anf_fun388333461,footer98433435,_plus55);
++R.GAS;
return $ret3348133482;
};
var $Hanf_arg979433486 = function(anf_arg388733485,anf_arg388233447,anf_fun388333461,footer98433435,_plus55) {
var $z3348933490 = D;
var $f3349533496 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg388733485,footer98433435):R.ffi.throwNonFunApp(L[4259],_plus55,[anf_arg388733485,footer98433435]);
};
try {
if(--R.GAS > 0) {
$z3348933490 = $f3349533496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3349533496,
"from":L[4259]});
}
} catch($e3348733488) {
if(R.isCont($e3348733488)) {
var $ss3349133492 = {"from":L[4259],
"go":function(anf_arg388833497) {
return $Hanf_arg979333498(anf_arg388833497,anf_arg388233447,anf_fun388333461,_plus55);
}};
$e3348733488.stack[R.EXN_STACKHEIGHT++] = $ss3349133492;
}
if(R.isPyretException($e3348733488)) {
$e3348733488.pyretStack.push(L[4259]);
}
throw $e3348733488;
}
var $ret3349333494 = $Hanf_arg979333498($z3348933490,anf_arg388233447,anf_fun388333461,_plus55);
++R.GAS;
return $ret3349333494;
};
var $Hanf_arg979333498 = function(anf_arg388833497,anf_arg388233447,anf_fun388333461,_plus55) {
var $z3350133502 = D;
var $f3350733508 = function(_) {
return R.isFunction(anf_fun388333461)?anf_fun388333461.app(anf_arg388833497):R.ffi.throwNonFunApp(L[4260],anf_fun388333461,[anf_arg388833497]);
};
try {
if(--R.GAS > 0) {
$z3350133502 = $f3350733508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3350733508,
"from":L[4260]});
}
} catch($e3349933500) {
if(R.isCont($e3349933500)) {
var $ss3350333504 = {"from":L[4260],
"go":function(anf_arg388933509) {
return $Hanf_arg979233510(anf_arg388933509,anf_arg388233447,_plus55);
}};
$e3349933500.stack[R.EXN_STACKHEIGHT++] = $ss3350333504;
}
if(R.isPyretException($e3349933500)) {
$e3349933500.pyretStack.push(L[4260]);
}
throw $e3349933500;
}
var $ret3350533506 = $Hanf_arg979233510($z3350133502,anf_arg388233447,_plus55);
++R.GAS;
return $ret3350533506;
};
var $Hanf_arg979233510 = function(anf_arg388933509,anf_arg388233447,_plus55) {
var $z3351333514 = D;
var $f3351933520 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg388233447,anf_arg388933509):R.ffi.throwNonFunApp(L[2550],_plus55,[anf_arg388233447,anf_arg388933509]);
};
try {
if(--R.GAS > 0) {
$z3351333514 = $f3351933520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3351933520,
"from":L[2550]});
}
} catch($e3351133512) {
if(R.isCont($e3351133512)) {
var $ss3351533516 = {"from":L[2550],
"go":function(ann_DASH_check_DASH_temp379633521) {
return $Hann_DASH_check_DASH_temp979133522(ann_DASH_check_DASH_temp379633521);
}};
$e3351133512.stack[R.EXN_STACKHEIGHT++] = $ss3351533516;
}
if(R.isPyretException($e3351133512)) {
$e3351133512.pyretStack.push(L[2550]);
}
throw $e3351133512;
}
var $ret3351733518 = $Hann_DASH_check_DASH_temp979133522($z3351333514);
++R.GAS;
return $ret3351733518;
};
var $Hann_DASH_check_DASH_temp979133522 = function(ann_DASH_check_DASH_temp379633521) {
return ann_DASH_check_DASH_temp379633521;
};
var $Hanf_arg979033422 = function(anf_arg387733421,optional_DASH_section97112959,str_DASH_where182988) {
var $z3352533526 = D;
var $f3353133532 = function(_) {
return R.isFunction(optional_DASH_section97112959.$var)?optional_DASH_section97112959.$var.app(str_DASH_where182988,anf_arg387733421):R.ffi.throwNonFunApp(L[4248],optional_DASH_section97112959.$var,[str_DASH_where182988,anf_arg387733421]);
};
try {
if(--R.GAS > 0) {
$z3352533526 = $f3353133532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3353133532,
"from":L[4248]});
}
} catch($e3352333524) {
if(R.isCont($e3352333524)) {
var $ss3352733528 = {"from":L[4248],
"go":function(ann_DASH_check_DASH_temp387533533) {
return $Hann_DASH_check_DASH_temp978933534(ann_DASH_check_DASH_temp387533533);
}};
$e3352333524.stack[R.EXN_STACKHEIGHT++] = $ss3352733528;
}
if(R.isPyretException($e3352333524)) {
$e3352333524.pyretStack.push(L[4248]);
}
throw $e3352333524;
}
var $ret3352933530 = $Hann_DASH_check_DASH_temp978933534($z3352533526);
++R.GAS;
return $ret3352933530;
};
var $Hann_DASH_check_DASH_temp978933534 = function(ann_DASH_check_DASH_temp387533533) {
return ann_DASH_check_DASH_temp387533533;
};
var $Hann_DASH_check_DASH_temp978833365 = function(ann_DASH_check_DASH_temp386733364) {
return ann_DASH_check_DASH_temp386733364;
};
var $Hanf_arg978733307 = function(anf_arg386033305,anf_fun385233306,arg_DASH_49933292) {
var $z3353733538 = D;
var $f3354333544 = function(_) {
return R.isFunction(anf_fun385233306)?anf_fun385233306.app(arg_DASH_49933292,anf_arg386033305):R.ffi.throwNonFunApp(L[4227],anf_fun385233306,[arg_DASH_49933292,anf_arg386033305]);
};
try {
if(--R.GAS > 0) {
$z3353733538 = $f3354333544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3354333544,
"from":L[4227]});
}
} catch($e3353533536) {
if(R.isCont($e3353533536)) {
var $ss3353933540 = {"from":L[4227],
"go":function(ann_DASH_check_DASH_temp385133545) {
return $Hann_DASH_check_DASH_temp978633546(ann_DASH_check_DASH_temp385133545);
}};
$e3353533536.stack[R.EXN_STACKHEIGHT++] = $ss3353933540;
}
if(R.isPyretException($e3353533536)) {
$e3353533536.pyretStack.push(L[4227]);
}
throw $e3353533536;
}
var $ret3354133542 = $Hann_DASH_check_DASH_temp978633546($z3353733538);
++R.GAS;
return $ret3354133542;
};
var $Hann_DASH_check_DASH_temp978633546 = function(ann_DASH_check_DASH_temp385133545) {
return ann_DASH_check_DASH_temp385133545;
};
var $Hanf_arg978533322 = function(anf_arg385833320,INDENT118169,anf_fun385633321) {
var $z3354933550 = D;
var $f3355533556 = function(_) {
return R.isFunction(anf_fun385633321)?anf_fun385633321.app(INDENT118169,anf_arg385833320):R.ffi.throwNonFunApp(L[4229],anf_fun385633321,[INDENT118169,anf_arg385833320]);
};
try {
if(--R.GAS > 0) {
$z3354933550 = $f3355533556();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3355533556,
"from":L[4229]});
}
} catch($e3354733548) {
if(R.isCont($e3354733548)) {
var $ss3355133552 = {"from":L[4229],
"go":function(ann_DASH_check_DASH_temp385533557) {
return $Hann_DASH_check_DASH_temp978433558(ann_DASH_check_DASH_temp385533557);
}};
$e3354733548.stack[R.EXN_STACKHEIGHT++] = $ss3355133552;
}
if(R.isPyretException($e3354733548)) {
$e3354733548.pyretStack.push(L[4229]);
}
throw $e3354733548;
}
var $ret3355333554 = $Hann_DASH_check_DASH_temp978433558($z3354933550);
++R.GAS;
return $ret3355333554;
};
var $Hann_DASH_check_DASH_temp978433558 = function(ann_DASH_check_DASH_temp385533557) {
return ann_DASH_check_DASH_temp385533557;
};
var $Hann_DASH_check_DASH_temp978333252 = function(ann_DASH_check_DASH_temp384533251) {
return ann_DASH_check_DASH_temp384533251;
};
var $Hann_DASH_check_DASH_temp978233106 = function(ann_DASH_check_DASH_temp382333105) {
return ann_DASH_check_DASH_temp382333105;
};
var $Hif_DASH_978112989 = function(if_DASH_49712988,INDENT118169,PP170,break_DASH_one119168,lbl97212975,section97312976,_plus55) {
var if_helper379933561 = R.makeFunction(function(if_helper_arg380033581) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2548],1,arguments);
}
var ann_DASH_check_DASH_temp379733582 = if_helper_arg380033581;
return ann_DASH_check_DASH_temp379733582;
});
var anf_if380333580 = R.isBoolean(if_DASH_49712988);
if(R.isPyretTrue(anf_if380333580)) {
if(R.isPyretTrue(if_DASH_49712988)) {
var cont_tail_arg381233562 = G(PP170,"mt-doc",L[4261]);
if(--R.GAS > 0) {
$z3355933560 = R.isFunction(if_helper379933561)?if_helper379933561.app(cont_tail_arg381233562):R.ffi.throwNonFunApp(L[4261],if_helper379933561,[cont_tail_arg381233562]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper379933561)?if_helper379933561.app(cont_tail_arg381233562):R.ffi.throwNonFunApp(L[4261],if_helper379933561,[cont_tail_arg381233562]);
},
"from":L[4261]});
}
++R.GAS;
return $z3355933560;
} else {
var anf_fun380433574 = G(PP170,"group",L[4264]);
var anf_fun380533575 = G(PP170,"nest",L[4263]);
var $z3356533566 = D;
var $f3357133572 = function(_) {
return R.isFunction(_plus55)?_plus55.app(lbl97212975,break_DASH_one119168):R.ffi.throwNonFunApp(L[4262],_plus55,[lbl97212975,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3356533566 = $f3357133572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3357133572,
"from":L[4262]});
}
} catch($e3356333564) {
if(R.isCont($e3356333564)) {
var $ss3356733568 = {"from":L[4262],
"go":function(anf_arg380633573) {
return $Hanf_arg978033576(anf_arg380633573,INDENT118169,anf_fun380433574,anf_fun380533575,break_DASH_one119168,if_helper379933561,section97312976,_plus55);
}};
$e3356333564.stack[R.EXN_STACKHEIGHT++] = $ss3356733568;
}
if(R.isPyretException($e3356333564)) {
$e3356333564.pyretStack.push(L[4262]);
}
throw $e3356333564;
}
var $ret3356933570 = $Hanf_arg978033576($z3356533566,INDENT118169,anf_fun380433574,anf_fun380533575,break_DASH_one119168,if_helper379933561,section97312976,_plus55);
++R.GAS;
return $ret3356933570;
}
} else {
var cont_tail_arg380133579 = R.throwNonBooleanCondition(L[2548],("if"),if_DASH_49712988);
if(--R.GAS > 0) {
$z3357733578 = R.isFunction(if_helper379933561)?if_helper379933561.app(cont_tail_arg380133579):R.ffi.throwNonFunApp(L[2548],if_helper379933561,[cont_tail_arg380133579]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper379933561)?if_helper379933561.app(cont_tail_arg380133579):R.ffi.throwNonFunApp(L[2548],if_helper379933561,[cont_tail_arg380133579]);
},
"from":L[2548]});
}
++R.GAS;
return $z3357733578;
}
};
var $Hanf_arg978033576 = function(anf_arg380633573,INDENT118169,anf_fun380433574,anf_fun380533575,break_DASH_one119168,if_helper379933561,section97312976,_plus55) {
var $z3358533586 = D;
var $f3359133592 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg380633573,section97312976):R.ffi.throwNonFunApp(L[4262],_plus55,[anf_arg380633573,section97312976]);
};
try {
if(--R.GAS > 0) {
$z3358533586 = $f3359133592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3359133592,
"from":L[4262]});
}
} catch($e3358333584) {
if(R.isCont($e3358333584)) {
var $ss3358733588 = {"from":L[4262],
"go":function(anf_arg380733593) {
return $Hanf_arg977933594(anf_arg380733593,INDENT118169,anf_fun380433574,anf_fun380533575,break_DASH_one119168,if_helper379933561,_plus55);
}};
$e3358333584.stack[R.EXN_STACKHEIGHT++] = $ss3358733588;
}
if(R.isPyretException($e3358333584)) {
$e3358333584.pyretStack.push(L[4262]);
}
throw $e3358333584;
}
var $ret3358933590 = $Hanf_arg977933594($z3358533586,INDENT118169,anf_fun380433574,anf_fun380533575,break_DASH_one119168,if_helper379933561,_plus55);
++R.GAS;
return $ret3358933590;
};
var $Hanf_arg977933594 = function(anf_arg380733593,INDENT118169,anf_fun380433574,anf_fun380533575,break_DASH_one119168,if_helper379933561,_plus55) {
var $z3359733598 = D;
var $f3360333604 = function(_) {
return R.isFunction(anf_fun380533575)?anf_fun380533575.app(INDENT118169,anf_arg380733593):R.ffi.throwNonFunApp(L[4265],anf_fun380533575,[INDENT118169,anf_arg380733593]);
};
try {
if(--R.GAS > 0) {
$z3359733598 = $f3360333604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3360333604,
"from":L[4265]});
}
} catch($e3359533596) {
if(R.isCont($e3359533596)) {
var $ss3359933600 = {"from":L[4265],
"go":function(anf_arg380833605) {
return $Hanf_arg977833606(anf_arg380833605,anf_fun380433574,break_DASH_one119168,if_helper379933561,_plus55);
}};
$e3359533596.stack[R.EXN_STACKHEIGHT++] = $ss3359933600;
}
if(R.isPyretException($e3359533596)) {
$e3359533596.pyretStack.push(L[4265]);
}
throw $e3359533596;
}
var $ret3360133602 = $Hanf_arg977833606($z3359733598,anf_fun380433574,break_DASH_one119168,if_helper379933561,_plus55);
++R.GAS;
return $ret3360133602;
};
var $Hanf_arg977833606 = function(anf_arg380833605,anf_fun380433574,break_DASH_one119168,if_helper379933561,_plus55) {
var $z3360933610 = D;
var $f3361533616 = function(_) {
return R.isFunction(anf_fun380433574)?anf_fun380433574.app(anf_arg380833605):R.ffi.throwNonFunApp(L[4266],anf_fun380433574,[anf_arg380833605]);
};
try {
if(--R.GAS > 0) {
$z3360933610 = $f3361533616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3361533616,
"from":L[4266]});
}
} catch($e3360733608) {
if(R.isCont($e3360733608)) {
var $ss3361133612 = {"from":L[4266],
"go":function(anf_arg380933617) {
return $Hanf_arg977733618(anf_arg380933617,break_DASH_one119168,if_helper379933561,_plus55);
}};
$e3360733608.stack[R.EXN_STACKHEIGHT++] = $ss3361133612;
}
if(R.isPyretException($e3360733608)) {
$e3360733608.pyretStack.push(L[4266]);
}
throw $e3360733608;
}
var $ret3361333614 = $Hanf_arg977733618($z3360933610,break_DASH_one119168,if_helper379933561,_plus55);
++R.GAS;
return $ret3361333614;
};
var $Hanf_arg977733618 = function(anf_arg380933617,break_DASH_one119168,if_helper379933561,_plus55) {
var $z3362133622 = D;
var $f3362733628 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,anf_arg380933617):R.ffi.throwNonFunApp(L[4267],_plus55,[break_DASH_one119168,anf_arg380933617]);
};
try {
if(--R.GAS > 0) {
$z3362133622 = $f3362733628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3362733628,
"from":L[4267]});
}
} catch($e3361933620) {
if(R.isCont($e3361933620)) {
var $ss3362333624 = {"from":L[4267],
"go":function(cont_tail_arg381033629) {
return $Hcont_tail_arg977633630(cont_tail_arg381033629,if_helper379933561);
}};
$e3361933620.stack[R.EXN_STACKHEIGHT++] = $ss3362333624;
}
if(R.isPyretException($e3361933620)) {
$e3361933620.pyretStack.push(L[4267]);
}
throw $e3361933620;
}
var $ret3362533626 = $Hcont_tail_arg977633630($z3362133622,if_helper379933561);
++R.GAS;
return $ret3362533626;
};
var $Hcont_tail_arg977633630 = function(cont_tail_arg381033629,if_helper379933561) {
if(--R.GAS > 0) {
$z3363133632 = R.isFunction(if_helper379933561)?if_helper379933561.app(cont_tail_arg381033629):R.ffi.throwNonFunApp(L[4267],if_helper379933561,[cont_tail_arg381033629]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper379933561)?if_helper379933561.app(cont_tail_arg381033629):R.ffi.throwNonFunApp(L[4267],if_helper379933561,[cont_tail_arg381033629]);
},
"from":L[4267]});
}
++R.GAS;
return $z3363133632;
};
var $Hanf_arg977513005 = function(anf_arg376213003,self49513004,_plus55,torepr65) {
var anf_arg376333643 = G(self49513004,"name",L[2218]);
var $z3363533636 = D;
var $f3364133642 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg376333643):R.ffi.throwNonFunApp(L[2218],torepr65,[anf_arg376333643]);
};
try {
if(--R.GAS > 0) {
$z3363533636 = $f3364133642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3364133642,
"from":L[2218]});
}
} catch($e3363333634) {
if(R.isCont($e3363333634)) {
var $ss3363733638 = {"from":L[2218],
"go":function(anf_arg376433644) {
return $Hanf_arg977433645(anf_arg376433644,anf_arg376213003,self49513004,_plus55,torepr65);
}};
$e3363333634.stack[R.EXN_STACKHEIGHT++] = $ss3363733638;
}
if(R.isPyretException($e3363333634)) {
$e3363333634.pyretStack.push(L[2218]);
}
throw $e3363333634;
}
var $ret3363933640 = $Hanf_arg977433645($z3363533636,anf_arg376213003,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3363933640;
};
var $Hanf_arg977433645 = function(anf_arg376433644,anf_arg376213003,self49513004,_plus55,torepr65) {
var $z3364833649 = D;
var $f3365433655 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg376433644):R.ffi.throwNonFunApp(L[2218],_plus55,[(", "),anf_arg376433644]);
};
try {
if(--R.GAS > 0) {
$z3364833649 = $f3365433655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3365433655,
"from":L[2218]});
}
} catch($e3364633647) {
if(R.isCont($e3364633647)) {
var $ss3365033651 = {"from":L[2218],
"go":function(anf_arg376533656) {
return $Hanf_arg977333657(anf_arg376533656,anf_arg376213003,self49513004,_plus55,torepr65);
}};
$e3364633647.stack[R.EXN_STACKHEIGHT++] = $ss3365033651;
}
if(R.isPyretException($e3364633647)) {
$e3364633647.pyretStack.push(L[2218]);
}
throw $e3364633647;
}
var $ret3365233653 = $Hanf_arg977333657($z3364833649,anf_arg376213003,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3365233653;
};
var $Hanf_arg977333657 = function(anf_arg376533656,anf_arg376213003,self49513004,_plus55,torepr65) {
var $z3366033661 = D;
var $f3366633667 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg376213003,anf_arg376533656):R.ffi.throwNonFunApp(L[2218],_plus55,[anf_arg376213003,anf_arg376533656]);
};
try {
if(--R.GAS > 0) {
$z3366033661 = $f3366633667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3366633667,
"from":L[2218]});
}
} catch($e3365833659) {
if(R.isCont($e3365833659)) {
var $ss3366233663 = {"from":L[2218],
"go":function(anf_arg376633668) {
return $Hanf_arg977233669(anf_arg376633668,self49513004,_plus55,torepr65);
}};
$e3365833659.stack[R.EXN_STACKHEIGHT++] = $ss3366233663;
}
if(R.isPyretException($e3365833659)) {
$e3365833659.pyretStack.push(L[2218]);
}
throw $e3365833659;
}
var $ret3366433665 = $Hanf_arg977233669($z3366033661,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3366433665;
};
var $Hanf_arg977233669 = function(anf_arg376633668,self49513004,_plus55,torepr65) {
var anf_arg376733680 = G(self49513004,"namet",L[2218]);
var $z3367233673 = D;
var $f3367833679 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg376733680):R.ffi.throwNonFunApp(L[2218],torepr65,[anf_arg376733680]);
};
try {
if(--R.GAS > 0) {
$z3367233673 = $f3367833679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3367833679,
"from":L[2218]});
}
} catch($e3367033671) {
if(R.isCont($e3367033671)) {
var $ss3367433675 = {"from":L[2218],
"go":function(anf_arg376833681) {
return $Hanf_arg977133682(anf_arg376833681,anf_arg376633668,self49513004,_plus55,torepr65);
}};
$e3367033671.stack[R.EXN_STACKHEIGHT++] = $ss3367433675;
}
if(R.isPyretException($e3367033671)) {
$e3367033671.pyretStack.push(L[2218]);
}
throw $e3367033671;
}
var $ret3367633677 = $Hanf_arg977133682($z3367233673,anf_arg376633668,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3367633677;
};
var $Hanf_arg977133682 = function(anf_arg376833681,anf_arg376633668,self49513004,_plus55,torepr65) {
var $z3368533686 = D;
var $f3369133692 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg376833681):R.ffi.throwNonFunApp(L[2218],_plus55,[(", "),anf_arg376833681]);
};
try {
if(--R.GAS > 0) {
$z3368533686 = $f3369133692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3369133692,
"from":L[2218]});
}
} catch($e3368333684) {
if(R.isCont($e3368333684)) {
var $ss3368733688 = {"from":L[2218],
"go":function(anf_arg376933693) {
return $Hanf_arg977033694(anf_arg376933693,anf_arg376633668,self49513004,_plus55,torepr65);
}};
$e3368333684.stack[R.EXN_STACKHEIGHT++] = $ss3368733688;
}
if(R.isPyretException($e3368333684)) {
$e3368333684.pyretStack.push(L[2218]);
}
throw $e3368333684;
}
var $ret3368933690 = $Hanf_arg977033694($z3368533686,anf_arg376633668,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3368933690;
};
var $Hanf_arg977033694 = function(anf_arg376933693,anf_arg376633668,self49513004,_plus55,torepr65) {
var $z3369733698 = D;
var $f3370333704 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg376633668,anf_arg376933693):R.ffi.throwNonFunApp(L[2218],_plus55,[anf_arg376633668,anf_arg376933693]);
};
try {
if(--R.GAS > 0) {
$z3369733698 = $f3370333704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3370333704,
"from":L[2218]});
}
} catch($e3369533696) {
if(R.isCont($e3369533696)) {
var $ss3369933700 = {"from":L[2218],
"go":function(anf_arg377033705) {
return $Hanf_arg976933706(anf_arg377033705,self49513004,_plus55,torepr65);
}};
$e3369533696.stack[R.EXN_STACKHEIGHT++] = $ss3369933700;
}
if(R.isPyretException($e3369533696)) {
$e3369533696.pyretStack.push(L[2218]);
}
throw $e3369533696;
}
var $ret3370133702 = $Hanf_arg976933706($z3369733698,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3370133702;
};
var $Hanf_arg976933706 = function(anf_arg377033705,self49513004,_plus55,torepr65) {
var anf_arg377133717 = G(self49513004,"params",L[2218]);
var $z3370933710 = D;
var $f3371533716 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg377133717):R.ffi.throwNonFunApp(L[2218],torepr65,[anf_arg377133717]);
};
try {
if(--R.GAS > 0) {
$z3370933710 = $f3371533716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3371533716,
"from":L[2218]});
}
} catch($e3370733708) {
if(R.isCont($e3370733708)) {
var $ss3371133712 = {"from":L[2218],
"go":function(anf_arg377233718) {
return $Hanf_arg976833719(anf_arg377233718,anf_arg377033705,self49513004,_plus55,torepr65);
}};
$e3370733708.stack[R.EXN_STACKHEIGHT++] = $ss3371133712;
}
if(R.isPyretException($e3370733708)) {
$e3370733708.pyretStack.push(L[2218]);
}
throw $e3370733708;
}
var $ret3371333714 = $Hanf_arg976833719($z3370933710,anf_arg377033705,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3371333714;
};
var $Hanf_arg976833719 = function(anf_arg377233718,anf_arg377033705,self49513004,_plus55,torepr65) {
var $z3372233723 = D;
var $f3372833729 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg377233718):R.ffi.throwNonFunApp(L[2218],_plus55,[(", "),anf_arg377233718]);
};
try {
if(--R.GAS > 0) {
$z3372233723 = $f3372833729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3372833729,
"from":L[2218]});
}
} catch($e3372033721) {
if(R.isCont($e3372033721)) {
var $ss3372433725 = {"from":L[2218],
"go":function(anf_arg377333730) {
return $Hanf_arg976733731(anf_arg377333730,anf_arg377033705,self49513004,_plus55,torepr65);
}};
$e3372033721.stack[R.EXN_STACKHEIGHT++] = $ss3372433725;
}
if(R.isPyretException($e3372033721)) {
$e3372033721.pyretStack.push(L[2218]);
}
throw $e3372033721;
}
var $ret3372633727 = $Hanf_arg976733731($z3372233723,anf_arg377033705,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3372633727;
};
var $Hanf_arg976733731 = function(anf_arg377333730,anf_arg377033705,self49513004,_plus55,torepr65) {
var $z3373433735 = D;
var $f3374033741 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg377033705,anf_arg377333730):R.ffi.throwNonFunApp(L[2218],_plus55,[anf_arg377033705,anf_arg377333730]);
};
try {
if(--R.GAS > 0) {
$z3373433735 = $f3374033741();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3374033741,
"from":L[2218]});
}
} catch($e3373233733) {
if(R.isCont($e3373233733)) {
var $ss3373633737 = {"from":L[2218],
"go":function(anf_arg377433742) {
return $Hanf_arg976633743(anf_arg377433742,self49513004,_plus55,torepr65);
}};
$e3373233733.stack[R.EXN_STACKHEIGHT++] = $ss3373633737;
}
if(R.isPyretException($e3373233733)) {
$e3373233733.pyretStack.push(L[2218]);
}
throw $e3373233733;
}
var $ret3373833739 = $Hanf_arg976633743($z3373433735,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3373833739;
};
var $Hanf_arg976633743 = function(anf_arg377433742,self49513004,_plus55,torepr65) {
var anf_arg377533754 = G(self49513004,"mixins",L[2218]);
var $z3374633747 = D;
var $f3375233753 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg377533754):R.ffi.throwNonFunApp(L[2218],torepr65,[anf_arg377533754]);
};
try {
if(--R.GAS > 0) {
$z3374633747 = $f3375233753();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3375233753,
"from":L[2218]});
}
} catch($e3374433745) {
if(R.isCont($e3374433745)) {
var $ss3374833749 = {"from":L[2218],
"go":function(anf_arg377633755) {
return $Hanf_arg976533756(anf_arg377633755,anf_arg377433742,self49513004,_plus55,torepr65);
}};
$e3374433745.stack[R.EXN_STACKHEIGHT++] = $ss3374833749;
}
if(R.isPyretException($e3374433745)) {
$e3374433745.pyretStack.push(L[2218]);
}
throw $e3374433745;
}
var $ret3375033751 = $Hanf_arg976533756($z3374633747,anf_arg377433742,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3375033751;
};
var $Hanf_arg976533756 = function(anf_arg377633755,anf_arg377433742,self49513004,_plus55,torepr65) {
var $z3375933760 = D;
var $f3376533766 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg377633755):R.ffi.throwNonFunApp(L[2218],_plus55,[(", "),anf_arg377633755]);
};
try {
if(--R.GAS > 0) {
$z3375933760 = $f3376533766();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3376533766,
"from":L[2218]});
}
} catch($e3375733758) {
if(R.isCont($e3375733758)) {
var $ss3376133762 = {"from":L[2218],
"go":function(anf_arg377733767) {
return $Hanf_arg976433768(anf_arg377733767,anf_arg377433742,self49513004,_plus55,torepr65);
}};
$e3375733758.stack[R.EXN_STACKHEIGHT++] = $ss3376133762;
}
if(R.isPyretException($e3375733758)) {
$e3375733758.pyretStack.push(L[2218]);
}
throw $e3375733758;
}
var $ret3376333764 = $Hanf_arg976433768($z3375933760,anf_arg377433742,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3376333764;
};
var $Hanf_arg976433768 = function(anf_arg377733767,anf_arg377433742,self49513004,_plus55,torepr65) {
var $z3377133772 = D;
var $f3377733778 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg377433742,anf_arg377733767):R.ffi.throwNonFunApp(L[2218],_plus55,[anf_arg377433742,anf_arg377733767]);
};
try {
if(--R.GAS > 0) {
$z3377133772 = $f3377733778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3377733778,
"from":L[2218]});
}
} catch($e3376933770) {
if(R.isCont($e3376933770)) {
var $ss3377333774 = {"from":L[2218],
"go":function(anf_arg377833779) {
return $Hanf_arg976333780(anf_arg377833779,self49513004,_plus55,torepr65);
}};
$e3376933770.stack[R.EXN_STACKHEIGHT++] = $ss3377333774;
}
if(R.isPyretException($e3376933770)) {
$e3376933770.pyretStack.push(L[2218]);
}
throw $e3376933770;
}
var $ret3377533776 = $Hanf_arg976333780($z3377133772,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3377533776;
};
var $Hanf_arg976333780 = function(anf_arg377833779,self49513004,_plus55,torepr65) {
var anf_arg377933791 = G(self49513004,"variants",L[2218]);
var $z3378333784 = D;
var $f3378933790 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg377933791):R.ffi.throwNonFunApp(L[2218],torepr65,[anf_arg377933791]);
};
try {
if(--R.GAS > 0) {
$z3378333784 = $f3378933790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3378933790,
"from":L[2218]});
}
} catch($e3378133782) {
if(R.isCont($e3378133782)) {
var $ss3378533786 = {"from":L[2218],
"go":function(anf_arg378033792) {
return $Hanf_arg976233793(anf_arg378033792,anf_arg377833779,self49513004,_plus55,torepr65);
}};
$e3378133782.stack[R.EXN_STACKHEIGHT++] = $ss3378533786;
}
if(R.isPyretException($e3378133782)) {
$e3378133782.pyretStack.push(L[2218]);
}
throw $e3378133782;
}
var $ret3378733788 = $Hanf_arg976233793($z3378333784,anf_arg377833779,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3378733788;
};
var $Hanf_arg976233793 = function(anf_arg378033792,anf_arg377833779,self49513004,_plus55,torepr65) {
var $z3379633797 = D;
var $f3380233803 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg378033792):R.ffi.throwNonFunApp(L[2218],_plus55,[(", "),anf_arg378033792]);
};
try {
if(--R.GAS > 0) {
$z3379633797 = $f3380233803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3380233803,
"from":L[2218]});
}
} catch($e3379433795) {
if(R.isCont($e3379433795)) {
var $ss3379833799 = {"from":L[2218],
"go":function(anf_arg378133804) {
return $Hanf_arg976133805(anf_arg378133804,anf_arg377833779,self49513004,_plus55,torepr65);
}};
$e3379433795.stack[R.EXN_STACKHEIGHT++] = $ss3379833799;
}
if(R.isPyretException($e3379433795)) {
$e3379433795.pyretStack.push(L[2218]);
}
throw $e3379433795;
}
var $ret3380033801 = $Hanf_arg976133805($z3379633797,anf_arg377833779,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3380033801;
};
var $Hanf_arg976133805 = function(anf_arg378133804,anf_arg377833779,self49513004,_plus55,torepr65) {
var $z3380833809 = D;
var $f3381433815 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg377833779,anf_arg378133804):R.ffi.throwNonFunApp(L[2218],_plus55,[anf_arg377833779,anf_arg378133804]);
};
try {
if(--R.GAS > 0) {
$z3380833809 = $f3381433815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3381433815,
"from":L[2218]});
}
} catch($e3380633807) {
if(R.isCont($e3380633807)) {
var $ss3381033811 = {"from":L[2218],
"go":function(anf_arg378233816) {
return $Hanf_arg976033817(anf_arg378233816,self49513004,_plus55,torepr65);
}};
$e3380633807.stack[R.EXN_STACKHEIGHT++] = $ss3381033811;
}
if(R.isPyretException($e3380633807)) {
$e3380633807.pyretStack.push(L[2218]);
}
throw $e3380633807;
}
var $ret3381233813 = $Hanf_arg976033817($z3380833809,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3381233813;
};
var $Hanf_arg976033817 = function(anf_arg378233816,self49513004,_plus55,torepr65) {
var anf_arg378333828 = G(self49513004,"shared-members",L[2218]);
var $z3382033821 = D;
var $f3382633827 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg378333828):R.ffi.throwNonFunApp(L[2218],torepr65,[anf_arg378333828]);
};
try {
if(--R.GAS > 0) {
$z3382033821 = $f3382633827();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3382633827,
"from":L[2218]});
}
} catch($e3381833819) {
if(R.isCont($e3381833819)) {
var $ss3382233823 = {"from":L[2218],
"go":function(anf_arg378433829) {
return $Hanf_arg975933830(anf_arg378433829,anf_arg378233816,self49513004,_plus55,torepr65);
}};
$e3381833819.stack[R.EXN_STACKHEIGHT++] = $ss3382233823;
}
if(R.isPyretException($e3381833819)) {
$e3381833819.pyretStack.push(L[2218]);
}
throw $e3381833819;
}
var $ret3382433825 = $Hanf_arg975933830($z3382033821,anf_arg378233816,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3382433825;
};
var $Hanf_arg975933830 = function(anf_arg378433829,anf_arg378233816,self49513004,_plus55,torepr65) {
var $z3383333834 = D;
var $f3383933840 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg378433829):R.ffi.throwNonFunApp(L[2218],_plus55,[(", "),anf_arg378433829]);
};
try {
if(--R.GAS > 0) {
$z3383333834 = $f3383933840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3383933840,
"from":L[2218]});
}
} catch($e3383133832) {
if(R.isCont($e3383133832)) {
var $ss3383533836 = {"from":L[2218],
"go":function(anf_arg378533841) {
return $Hanf_arg975833842(anf_arg378533841,anf_arg378233816,self49513004,_plus55,torepr65);
}};
$e3383133832.stack[R.EXN_STACKHEIGHT++] = $ss3383533836;
}
if(R.isPyretException($e3383133832)) {
$e3383133832.pyretStack.push(L[2218]);
}
throw $e3383133832;
}
var $ret3383733838 = $Hanf_arg975833842($z3383333834,anf_arg378233816,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3383733838;
};
var $Hanf_arg975833842 = function(anf_arg378533841,anf_arg378233816,self49513004,_plus55,torepr65) {
var $z3384533846 = D;
var $f3385133852 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg378233816,anf_arg378533841):R.ffi.throwNonFunApp(L[2218],_plus55,[anf_arg378233816,anf_arg378533841]);
};
try {
if(--R.GAS > 0) {
$z3384533846 = $f3385133852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3385133852,
"from":L[2218]});
}
} catch($e3384333844) {
if(R.isCont($e3384333844)) {
var $ss3384733848 = {"from":L[2218],
"go":function(anf_arg378633853) {
return $Hanf_arg975733854(anf_arg378633853,self49513004,_plus55,torepr65);
}};
$e3384333844.stack[R.EXN_STACKHEIGHT++] = $ss3384733848;
}
if(R.isPyretException($e3384333844)) {
$e3384333844.pyretStack.push(L[2218]);
}
throw $e3384333844;
}
var $ret3384933850 = $Hanf_arg975733854($z3384533846,self49513004,_plus55,torepr65);
++R.GAS;
return $ret3384933850;
};
var $Hanf_arg975733854 = function(anf_arg378633853,self49513004,_plus55,torepr65) {
var anf_arg378733865 = G(self49513004,"_check",L[2218]);
var $z3385733858 = D;
var $f3386333864 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg378733865):R.ffi.throwNonFunApp(L[2218],torepr65,[anf_arg378733865]);
};
try {
if(--R.GAS > 0) {
$z3385733858 = $f3386333864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3386333864,
"from":L[2218]});
}
} catch($e3385533856) {
if(R.isCont($e3385533856)) {
var $ss3385933860 = {"from":L[2218],
"go":function(anf_arg378833866) {
return $Hanf_arg975633867(anf_arg378833866,anf_arg378633853,_plus55);
}};
$e3385533856.stack[R.EXN_STACKHEIGHT++] = $ss3385933860;
}
if(R.isPyretException($e3385533856)) {
$e3385533856.pyretStack.push(L[2218]);
}
throw $e3385533856;
}
var $ret3386133862 = $Hanf_arg975633867($z3385733858,anf_arg378633853,_plus55);
++R.GAS;
return $ret3386133862;
};
var $Hanf_arg975633867 = function(anf_arg378833866,anf_arg378633853,_plus55) {
var $z3387033871 = D;
var $f3387633877 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg378833866):R.ffi.throwNonFunApp(L[2218],_plus55,[(", "),anf_arg378833866]);
};
try {
if(--R.GAS > 0) {
$z3387033871 = $f3387633877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3387633877,
"from":L[2218]});
}
} catch($e3386833869) {
if(R.isCont($e3386833869)) {
var $ss3387233873 = {"from":L[2218],
"go":function(anf_arg378933878) {
return $Hanf_arg975533879(anf_arg378933878,anf_arg378633853,_plus55);
}};
$e3386833869.stack[R.EXN_STACKHEIGHT++] = $ss3387233873;
}
if(R.isPyretException($e3386833869)) {
$e3386833869.pyretStack.push(L[2218]);
}
throw $e3386833869;
}
var $ret3387433875 = $Hanf_arg975533879($z3387033871,anf_arg378633853,_plus55);
++R.GAS;
return $ret3387433875;
};
var $Hanf_arg975533879 = function(anf_arg378933878,anf_arg378633853,_plus55) {
var $z3388233883 = D;
var $f3388833889 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg378633853,anf_arg378933878):R.ffi.throwNonFunApp(L[2218],_plus55,[anf_arg378633853,anf_arg378933878]);
};
try {
if(--R.GAS > 0) {
$z3388233883 = $f3388833889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3388833889,
"from":L[2218]});
}
} catch($e3388033881) {
if(R.isCont($e3388033881)) {
var $ss3388433885 = {"from":L[2218],
"go":function(anf_arg379033890) {
return $Hanf_arg975433891(anf_arg379033890,_plus55);
}};
$e3388033881.stack[R.EXN_STACKHEIGHT++] = $ss3388433885;
}
if(R.isPyretException($e3388033881)) {
$e3388033881.pyretStack.push(L[2218]);
}
throw $e3388033881;
}
var $ret3388633887 = $Hanf_arg975433891($z3388233883,_plus55);
++R.GAS;
return $ret3388633887;
};
var $Hanf_arg975433891 = function(anf_arg379033890,_plus55) {
var $z3389433895 = D;
var $f3390033901 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg379033890,(")")):R.ffi.throwNonFunApp(L[2218],_plus55,[anf_arg379033890,(")")]);
};
try {
if(--R.GAS > 0) {
$z3389433895 = $f3390033901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3390033901,
"from":L[2218]});
}
} catch($e3389233893) {
if(R.isCont($e3389233893)) {
var $ss3389633897 = {"from":L[2218],
"go":function(anf_arg379133902) {
return $Hanf_arg975333903(anf_arg379133902,_plus55);
}};
$e3389233893.stack[R.EXN_STACKHEIGHT++] = $ss3389633897;
}
if(R.isPyretException($e3389233893)) {
$e3389233893.pyretStack.push(L[2218]);
}
throw $e3389233893;
}
var $ret3389833899 = $Hanf_arg975333903($z3389433895,_plus55);
++R.GAS;
return $ret3389833899;
};
var $Hanf_arg975333903 = function(anf_arg379133902,_plus55) {
var $z3390633907 = D;
var $f3391233913 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg379133902):R.ffi.throwNonFunApp(L[2218],_plus55,[("("),anf_arg379133902]);
};
try {
if(--R.GAS > 0) {
$z3390633907 = $f3391233913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3391233913,
"from":L[2218]});
}
} catch($e3390433905) {
if(R.isCont($e3390433905)) {
var $ss3390833909 = {"from":L[2218],
"go":function(anf_arg379233914) {
return $Hanf_arg975233915(anf_arg379233914,_plus55);
}};
$e3390433905.stack[R.EXN_STACKHEIGHT++] = $ss3390833909;
}
if(R.isPyretException($e3390433905)) {
$e3390433905.pyretStack.push(L[2218]);
}
throw $e3390433905;
}
var $ret3391033911 = $Hanf_arg975233915($z3390633907,_plus55);
++R.GAS;
return $ret3391033911;
};
var $Hanf_arg975233915 = function(anf_arg379233914,_plus55) {
var $z3391833919 = D;
var $f3392433925 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-data-expr"),anf_arg379233914):R.ffi.throwNonFunApp(L[2218],_plus55,[("s-data-expr"),anf_arg379233914]);
};
try {
if(--R.GAS > 0) {
$z3391833919 = $f3392433925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3392433925,
"from":L[2218]});
}
} catch($e3391633917) {
if(R.isCont($e3391633917)) {
var $ss3392033921 = {"from":L[2218],
"go":function(ann_DASH_check_DASH_temp376033926) {
return $Hann_DASH_check_DASH_temp975133927(ann_DASH_check_DASH_temp376033926);
}};
$e3391633917.stack[R.EXN_STACKHEIGHT++] = $ss3392033921;
}
if(R.isPyretException($e3391633917)) {
$e3391633917.pyretStack.push(L[2218]);
}
throw $e3391633917;
}
var $ret3392233923 = $Hann_DASH_check_DASH_temp975133927($z3391833919);
++R.GAS;
return $ret3392233923;
};
var $Hann_DASH_check_DASH_temp975133927 = function(ann_DASH_check_DASH_temp376033926) {
return ann_DASH_check_DASH_temp376033926;
};
var $Hcont_tail_arg974913027 = function(cont_tail_arg375713025,if_helper374213026) {
if(--R.GAS > 0) {
$z3392833929 = R.isFunction(if_helper374213026)?if_helper374213026.app(cont_tail_arg375713025):R.ffi.throwNonFunApp(L[2218],if_helper374213026,[cont_tail_arg375713025]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper374213026)?if_helper374213026.app(cont_tail_arg375713025):R.ffi.throwNonFunApp(L[2218],if_helper374213026,[cont_tail_arg375713025]);
},
"from":L[2218]});
}
++R.GAS;
return $z3392833929;
};
var $Hcont_tail_arg975013042 = function(cont_tail_arg374713041,if_helper374213026) {
if(--R.GAS > 0) {
$z3393033931 = R.isFunction(if_helper374213026)?if_helper374213026.app(cont_tail_arg374713041):R.ffi.throwNonFunApp(L[2218],if_helper374213026,[cont_tail_arg374713041]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper374213026)?if_helper374213026.app(cont_tail_arg374713041):R.ffi.throwNonFunApp(L[2218],if_helper374213026,[cont_tail_arg374713041]);
},
"from":L[2218]});
}
++R.GAS;
return $z3393033931;
};
var $Hanf_arg974813065 = function(anf_arg367213062,INDENT118169,PP170,anf_fun367113063,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_arg367333945 = G(PP170,"mt-doc",L[4275]);
var anf_arg367433946 = G(PP170,"langle",L[4274]);
var anf_arg367533947 = G(PP170,"commabreak",L[4273]);
var anf_arg367633948 = G(PP170,"rangle",L[4272]);
var anf_bracket367733964 = G(self94613064,"params",L[4271]);
var anf_fun367833942 = G(anf_bracket367733964,"map",L[4270]);
var anf_arg368133943 = R.makeFunction(function(recv_DASH_48833950) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4269],1,arguments);
}
var anf_fun368033961 = G(recv_DASH_48833950,"tosource",L[4269]);
var $z3395333954 = D;
var $f3395933960 = function(_) {
return R.isFunction(anf_fun368033961)?anf_fun368033961.app():R.ffi.throwNonFunApp(L[4269],anf_fun368033961,[]);
};
try {
if(--R.GAS > 0) {
$z3395333954 = $f3395933960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3395933960,
"from":L[4269]});
}
} catch($e3395133952) {
if(R.isCont($e3395133952)) {
var $ss3395533956 = {"from":L[4269],
"go":function(ann_DASH_check_DASH_temp367933962) {
return $Hann_DASH_check_DASH_temp971533963(ann_DASH_check_DASH_temp367933962);
}};
$e3395133952.stack[R.EXN_STACKHEIGHT++] = $ss3395533956;
}
if(R.isPyretException($e3395133952)) {
$e3395133952.pyretStack.push(L[4269]);
}
throw $e3395133952;
}
var $ret3395733958 = $Hann_DASH_check_DASH_temp971533963($z3395333954);
++R.GAS;
return $ret3395733958;
});
var $z3393433935 = D;
var $f3394033941 = function(_) {
return R.isFunction(anf_fun367833942)?anf_fun367833942.app(anf_arg368133943):R.ffi.throwNonFunApp(L[4268],anf_fun367833942,[anf_arg368133943]);
};
try {
if(--R.GAS > 0) {
$z3393433935 = $f3394033941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3394033941,
"from":L[4268]});
}
} catch($e3393233933) {
if(R.isCont($e3393233933)) {
var $ss3393633937 = {"from":L[4268],
"go":function(anf_arg368233944) {
return $Hanf_arg974733949(anf_arg368233944,INDENT118169,PP170,anf_arg367213062,anf_arg367333945,anf_arg367433946,anf_arg367533947,anf_arg367633948,anf_fun367113063,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3393233933.stack[R.EXN_STACKHEIGHT++] = $ss3393633937;
}
if(R.isPyretException($e3393233933)) {
$e3393233933.pyretStack.push(L[4268]);
}
throw $e3393233933;
}
var $ret3393833939 = $Hanf_arg974733949($z3393433935,INDENT118169,PP170,anf_arg367213062,anf_arg367333945,anf_arg367433946,anf_arg367533947,anf_arg367633948,anf_fun367113063,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3393833939;
};
var $Hanf_arg974733949 = function(anf_arg368233944,INDENT118169,PP170,anf_arg367213062,anf_arg367333945,anf_arg367433946,anf_arg367533947,anf_arg367633948,anf_fun367113063,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var $z3396733968 = D;
var $f3397333974 = function(_) {
return R.isFunction(anf_fun367113063)?anf_fun367113063.app(anf_arg367213062,(0),anf_arg367333945,anf_arg367433946,anf_arg367533947,anf_arg367633948,anf_arg368233944):R.ffi.throwNonFunApp(L[4276],anf_fun367113063,[anf_arg367213062,(0),anf_arg367333945,anf_arg367433946,anf_arg367533947,anf_arg367633948,anf_arg368233944]);
};
try {
if(--R.GAS > 0) {
$z3396733968 = $f3397333974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3397333974,
"from":L[4276]});
}
} catch($e3396533966) {
if(R.isCont($e3396533966)) {
var $ss3396933970 = {"from":L[4276],
"go":function(tys95033975) {
return $Htys974633976(tys95033975,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3396533966.stack[R.EXN_STACKHEIGHT++] = $ss3396933970;
}
if(R.isPyretException($e3396533966)) {
$e3396533966.pyretStack.push(L[4276]);
}
throw $e3396533966;
}
var $ret3397133972 = $Htys974633976($z3396733968,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3397133972;
};
var $Htys974633976 = function(tys95033975,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun368333987 = G(PP170,"str",L[4279]);
var anf_arg368433988 = G(self94613064,"name",L[4278]);
var $z3397933980 = D;
var $f3398533986 = function(_) {
return R.isFunction(anf_fun368333987)?anf_fun368333987.app(anf_arg368433988):R.ffi.throwNonFunApp(L[4277],anf_fun368333987,[anf_arg368433988]);
};
try {
if(--R.GAS > 0) {
$z3397933980 = $f3398533986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3398533986,
"from":L[4277]});
}
} catch($e3397733978) {
if(R.isCont($e3397733978)) {
var $ss3398133982 = {"from":L[4277],
"go":function(anf_arg368533989) {
return $Hanf_arg974533990(anf_arg368533989,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys95033975,_plus55);
}};
$e3397733978.stack[R.EXN_STACKHEIGHT++] = $ss3398133982;
}
if(R.isPyretException($e3397733978)) {
$e3397733978.pyretStack.push(L[4277]);
}
throw $e3397733978;
}
var $ret3398333984 = $Hanf_arg974533990($z3397933980,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys95033975,_plus55);
++R.GAS;
return $ret3398333984;
};
var $Hanf_arg974533990 = function(anf_arg368533989,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_data139429,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys95033975,_plus55) {
var $z3399333994 = D;
var $f3399934000 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_data139429,anf_arg368533989):R.ffi.throwNonFunApp(L[4280],_plus55,[str_DASH_data139429,anf_arg368533989]);
};
try {
if(--R.GAS > 0) {
$z3399333994 = $f3399934000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3399934000,
"from":L[4280]});
}
} catch($e3399133992) {
if(R.isCont($e3399133992)) {
var $ss3399533996 = {"from":L[4280],
"go":function(anf_arg368634001) {
return $Hanf_arg974434002(anf_arg368634001,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys95033975,_plus55);
}};
$e3399133992.stack[R.EXN_STACKHEIGHT++] = $ss3399533996;
}
if(R.isPyretException($e3399133992)) {
$e3399133992.pyretStack.push(L[4280]);
}
throw $e3399133992;
}
var $ret3399733998 = $Hanf_arg974434002($z3399333994,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys95033975,_plus55);
++R.GAS;
return $ret3399733998;
};
var $Hanf_arg974434002 = function(anf_arg368634001,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,tys95033975,_plus55) {
var $z3400534006 = D;
var $f3401134012 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg368634001,tys95033975):R.ffi.throwNonFunApp(L[4280],_plus55,[anf_arg368634001,tys95033975]);
};
try {
if(--R.GAS > 0) {
$z3400534006 = $f3401134012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3401134012,
"from":L[4280]});
}
} catch($e3400334004) {
if(R.isCont($e3400334004)) {
var $ss3400734008 = {"from":L[4280],
"go":function(anf_arg368734013) {
return $Hanf_arg974334014(anf_arg368734013,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3400334004.stack[R.EXN_STACKHEIGHT++] = $ss3400734008;
}
if(R.isPyretException($e3400334004)) {
$e3400334004.pyretStack.push(L[4280]);
}
throw $e3400334004;
}
var $ret3400934010 = $Hanf_arg974334014($z3400534006,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3400934010;
};
var $Hanf_arg974334014 = function(anf_arg368734013,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_colon134364,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var $z3401734018 = D;
var $f3402334024 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg368734013,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4281],_plus55,[anf_arg368734013,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z3401734018 = $f3402334024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3402334024,
"from":L[4281]});
}
} catch($e3401534016) {
if(R.isCont($e3401534016)) {
var $ss3401934020 = {"from":L[4281],
"go":function(header95134025) {
return $Hheader974234026(header95134025,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3401534016.stack[R.EXN_STACKHEIGHT++] = $ss3401934020;
}
if(R.isPyretException($e3401534016)) {
$e3401534016.pyretStack.push(L[4281]);
}
throw $e3401534016;
}
var $ret3402134022 = $Hheader974234026($z3401734018,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3402134022;
};
var $Hheader974234026 = function(header95134025,INDENT118169,PP170,break_DASH_one119168,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_deriving142468,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun368834039 = G(PP170,"surround-separate",L[4284]);
var anf_arg368934038 = G(PP170,"mt-doc",L[4283]);
var $z3402934030 = D;
var $f3403534036 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_deriving142468):R.ffi.throwNonFunApp(L[4282],_plus55,[break_DASH_one119168,str_DASH_deriving142468]);
};
try {
if(--R.GAS > 0) {
$z3402934030 = $f3403534036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3403534036,
"from":L[4282]});
}
} catch($e3402734028) {
if(R.isCont($e3402734028)) {
var $ss3403134032 = {"from":L[4282],
"go":function(anf_arg369034037) {
return $Hanf_arg974134040(anf_arg369034037,INDENT118169,PP170,anf_arg368934038,anf_fun368834039,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3402734028.stack[R.EXN_STACKHEIGHT++] = $ss3403134032;
}
if(R.isPyretException($e3402734028)) {
$e3402734028.pyretStack.push(L[4282]);
}
throw $e3402734028;
}
var $ret3403334034 = $Hanf_arg974134040($z3402934030,INDENT118169,PP170,anf_arg368934038,anf_fun368834039,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3403334034;
};
var $Hanf_arg974134040 = function(anf_arg369034037,INDENT118169,PP170,anf_arg368934038,anf_fun368834039,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_arg369134054 = G(PP170,"commabreak",L[4291]);
var anf_arg369234055 = G(PP170,"mt-doc",L[4290]);
var anf_bracket369334071 = G(self94613064,"mixins",L[4289]);
var anf_fun369434051 = G(anf_bracket369334071,"map",L[4288]);
var anf_arg369734052 = R.makeFunction(function(m95334057) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4286],1,arguments);
}
var anf_fun369634068 = G(m95334057,"tosource",L[4287]);
var $z3406034061 = D;
var $f3406634067 = function(_) {
return R.isFunction(anf_fun369634068)?anf_fun369634068.app():R.ffi.throwNonFunApp(L[4286],anf_fun369634068,[]);
};
try {
if(--R.GAS > 0) {
$z3406034061 = $f3406634067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3406634067,
"from":L[4286]});
}
} catch($e3405834059) {
if(R.isCont($e3405834059)) {
var $ss3406234063 = {"from":L[4286],
"go":function(ann_DASH_check_DASH_temp369534069) {
return $Hann_DASH_check_DASH_temp971634070(ann_DASH_check_DASH_temp369534069);
}};
$e3405834059.stack[R.EXN_STACKHEIGHT++] = $ss3406234063;
}
if(R.isPyretException($e3405834059)) {
$e3405834059.pyretStack.push(L[4286]);
}
throw $e3405834059;
}
var $ret3406434065 = $Hann_DASH_check_DASH_temp971634070($z3406034061);
++R.GAS;
return $ret3406434065;
});
var $z3404334044 = D;
var $f3404934050 = function(_) {
return R.isFunction(anf_fun369434051)?anf_fun369434051.app(anf_arg369734052):R.ffi.throwNonFunApp(L[4285],anf_fun369434051,[anf_arg369734052]);
};
try {
if(--R.GAS > 0) {
$z3404334044 = $f3404934050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3404934050,
"from":L[4285]});
}
} catch($e3404134042) {
if(R.isCont($e3404134042)) {
var $ss3404534046 = {"from":L[4285],
"go":function(anf_arg369834053) {
return $Hanf_arg974034056(anf_arg369834053,INDENT118169,PP170,anf_arg368934038,anf_arg369034037,anf_arg369134054,anf_arg369234055,anf_fun368834039,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3404134042.stack[R.EXN_STACKHEIGHT++] = $ss3404534046;
}
if(R.isPyretException($e3404134042)) {
$e3404134042.pyretStack.push(L[4285]);
}
throw $e3404134042;
}
var $ret3404734048 = $Hanf_arg974034056($z3404334044,INDENT118169,PP170,anf_arg368934038,anf_arg369034037,anf_arg369134054,anf_arg369234055,anf_fun368834039,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3404734048;
};
var $Hanf_arg974034056 = function(anf_arg369834053,INDENT118169,PP170,anf_arg368934038,anf_arg369034037,anf_arg369134054,anf_arg369234055,anf_fun368834039,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var $z3407434075 = D;
var $f3408034081 = function(_) {
return R.isFunction(anf_fun368834039)?anf_fun368834039.app(INDENT118169,(0),anf_arg368934038,anf_arg369034037,anf_arg369134054,anf_arg369234055,anf_arg369834053):R.ffi.throwNonFunApp(L[4292],anf_fun368834039,[INDENT118169,(0),anf_arg368934038,anf_arg369034037,anf_arg369134054,anf_arg369234055,anf_arg369834053]);
};
try {
if(--R.GAS > 0) {
$z3407434075 = $f3408034081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3408034081,
"from":L[4292]});
}
} catch($e3407234073) {
if(R.isCont($e3407234073)) {
var $ss3407634077 = {"from":L[4292],
"go":function(_deriving95234082) {
return $H_deriving973934083(_deriving95234082,INDENT118169,PP170,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3407234073.stack[R.EXN_STACKHEIGHT++] = $ss3407634077;
}
if(R.isPyretException($e3407234073)) {
$e3407234073.pyretStack.push(L[4292]);
}
throw $e3407234073;
}
var $ret3407834079 = $H_deriving973934083($z3407434075,INDENT118169,PP170,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3407834079;
};
var $H_deriving973934083 = function(_deriving95234082,INDENT118169,PP170,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_pipespace162728,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun369934095 = G(PP170,"separate",L[4294]);
var $z3408634087 = D;
var $f3409234093 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_pipespace162728):R.ffi.throwNonFunApp(L[4293],_plus55,[break_DASH_one119168,str_DASH_pipespace162728]);
};
try {
if(--R.GAS > 0) {
$z3408634087 = $f3409234093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3409234093,
"from":L[4293]});
}
} catch($e3408434085) {
if(R.isCont($e3408434085)) {
var $ss3408834089 = {"from":L[4293],
"go":function(anf_arg370034094) {
return $Hanf_arg973834096(anf_arg370034094,INDENT118169,PP170,_deriving95234082,anf_fun369934095,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3408434085.stack[R.EXN_STACKHEIGHT++] = $ss3408834089;
}
if(R.isPyretException($e3408434085)) {
$e3408434085.pyretStack.push(L[4293]);
}
throw $e3408434085;
}
var $ret3409034091 = $Hanf_arg973834096($z3408634087,INDENT118169,PP170,_deriving95234082,anf_fun369934095,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3409034091;
};
var $Hanf_arg973834096 = function(anf_arg370034094,INDENT118169,PP170,_deriving95234082,anf_fun369934095,break_DASH_one119168,header95134025,lists974,optional_DASH_section94713050,self94613064,str_DASH_blank124234,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun371134107 = R.makeFunction(function(arg_DASH_48934110) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4295],1,arguments);
}
var anf_fun370234124 = G(lists974,"link",L[4303]);
var anf_bracket370334141 = G(self94613064,"variants",L[4302]);
var anf_fun370434121 = G(anf_bracket370334141,"map",L[4301]);
var anf_arg370934122 = R.makeFunction(function(v95534126) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4297],1,arguments);
}
var anf_fun370634139 = G(PP170,"nest",L[4300]);
var anf_fun370734137 = G(v95534126,"tosource",L[4299]);
var $z3412934130 = D;
var $f3413534136 = function(_) {
return R.isFunction(anf_fun370734137)?anf_fun370734137.app():R.ffi.throwNonFunApp(L[4298],anf_fun370734137,[]);
};
try {
if(--R.GAS > 0) {
$z3412934130 = $f3413534136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3413534136,
"from":L[4298]});
}
} catch($e3412734128) {
if(R.isCont($e3412734128)) {
var $ss3413134132 = {"from":L[4298],
"go":function(anf_arg370834138) {
return $Hanf_arg971834140(anf_arg370834138,INDENT118169,anf_fun370634139);
}};
$e3412734128.stack[R.EXN_STACKHEIGHT++] = $ss3413134132;
}
if(R.isPyretException($e3412734128)) {
$e3412734128.pyretStack.push(L[4298]);
}
throw $e3412734128;
}
var $ret3413334134 = $Hanf_arg971834140($z3412934130,INDENT118169,anf_fun370634139);
++R.GAS;
return $ret3413334134;
});
var $z3411334114 = D;
var $f3411934120 = function(_) {
return R.isFunction(anf_fun370434121)?anf_fun370434121.app(anf_arg370934122):R.ffi.throwNonFunApp(L[4296],anf_fun370434121,[anf_arg370934122]);
};
try {
if(--R.GAS > 0) {
$z3411334114 = $f3411934120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3411934120,
"from":L[4296]});
}
} catch($e3411134112) {
if(R.isCont($e3411134112)) {
var $ss3411534116 = {"from":L[4296],
"go":function(anf_arg371034123) {
return $Hanf_arg972034125(anf_arg371034123,anf_fun370234124,arg_DASH_48934110);
}};
$e3411134112.stack[R.EXN_STACKHEIGHT++] = $ss3411534116;
}
if(R.isPyretException($e3411134112)) {
$e3411134112.pyretStack.push(L[4296]);
}
throw $e3411134112;
}
var $ret3411734118 = $Hanf_arg972034125($z3411334114,anf_fun370234124,arg_DASH_48934110);
++R.GAS;
return $ret3411734118;
});
var $z3409934100 = D;
var $f3410534106 = function(_) {
return R.isFunction(anf_fun371134107)?anf_fun371134107.app(str_DASH_blank124234):R.ffi.throwNonFunApp(L[4295],anf_fun371134107,[str_DASH_blank124234]);
};
try {
if(--R.GAS > 0) {
$z3409934100 = $f3410534106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3410534106,
"from":L[4295]});
}
} catch($e3409734098) {
if(R.isCont($e3409734098)) {
var $ss3410134102 = {"from":L[4295],
"go":function(anf_arg371234108) {
return $Hanf_arg973734109(anf_arg371234108,INDENT118169,PP170,_deriving95234082,anf_arg370034094,anf_fun369934095,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3409734098.stack[R.EXN_STACKHEIGHT++] = $ss3410134102;
}
if(R.isPyretException($e3409734098)) {
$e3409734098.pyretStack.push(L[4295]);
}
throw $e3409734098;
}
var $ret3410334104 = $Hanf_arg973734109($z3409934100,INDENT118169,PP170,_deriving95234082,anf_arg370034094,anf_fun369934095,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3410334104;
};
var $Hanf_arg973734109 = function(anf_arg371234108,INDENT118169,PP170,_deriving95234082,anf_arg370034094,anf_fun369934095,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var $z3414434145 = D;
var $f3415034151 = function(_) {
return R.isFunction(anf_fun369934095)?anf_fun369934095.app(anf_arg370034094,anf_arg371234108):R.ffi.throwNonFunApp(L[4304],anf_fun369934095,[anf_arg370034094,anf_arg371234108]);
};
try {
if(--R.GAS > 0) {
$z3414434145 = $f3415034151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3415034151,
"from":L[4304]});
}
} catch($e3414234143) {
if(R.isCont($e3414234143)) {
var $ss3414634147 = {"from":L[4304],
"go":function(variants95434152) {
return $Hvariants973634153(variants95434152,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
}};
$e3414234143.stack[R.EXN_STACKHEIGHT++] = $ss3414634147;
}
if(R.isPyretException($e3414234143)) {
$e3414234143.pyretStack.push(L[4304]);
}
throw $e3414234143;
}
var $ret3414834149 = $Hvariants973634153($z3414434145,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55);
++R.GAS;
return $ret3414834149;
};
var $Hvariants973634153 = function(variants95434152,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,_plus55) {
var anf_fun371334168 = G(PP170,"separate",L[4311]);
var anf_arg371434167 = G(PP170,"commabreak",L[4310]);
var anf_bracket371534184 = G(self94613064,"shared-members",L[4309]);
var anf_fun371634164 = G(anf_bracket371534184,"map",L[4308]);
var anf_arg371934165 = R.makeFunction(function(s95734170) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4306],1,arguments);
}
var anf_fun371834181 = G(s95734170,"tosource",L[4307]);
var $z3417334174 = D;
var $f3417934180 = function(_) {
return R.isFunction(anf_fun371834181)?anf_fun371834181.app():R.ffi.throwNonFunApp(L[4306],anf_fun371834181,[]);
};
try {
if(--R.GAS > 0) {
$z3417334174 = $f3417934180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3417934180,
"from":L[4306]});
}
} catch($e3417134172) {
if(R.isCont($e3417134172)) {
var $ss3417534176 = {"from":L[4306],
"go":function(ann_DASH_check_DASH_temp371734182) {
return $Hann_DASH_check_DASH_temp972134183(ann_DASH_check_DASH_temp371734182);
}};
$e3417134172.stack[R.EXN_STACKHEIGHT++] = $ss3417534176;
}
if(R.isPyretException($e3417134172)) {
$e3417134172.pyretStack.push(L[4306]);
}
throw $e3417134172;
}
var $ret3417734178 = $Hann_DASH_check_DASH_temp972134183($z3417334174);
++R.GAS;
return $ret3417734178;
});
var $z3415634157 = D;
var $f3416234163 = function(_) {
return R.isFunction(anf_fun371634164)?anf_fun371634164.app(anf_arg371934165):R.ffi.throwNonFunApp(L[4305],anf_fun371634164,[anf_arg371934165]);
};
try {
if(--R.GAS > 0) {
$z3415634157 = $f3416234163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3416234163,
"from":L[4305]});
}
} catch($e3415434155) {
if(R.isCont($e3415434155)) {
var $ss3415834159 = {"from":L[4305],
"go":function(anf_arg372034166) {
return $Hanf_arg973534169(anf_arg372034166,INDENT118169,PP170,_deriving95234082,anf_arg371434167,anf_fun371334168,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants95434152,_plus55);
}};
$e3415434155.stack[R.EXN_STACKHEIGHT++] = $ss3415834159;
}
if(R.isPyretException($e3415434155)) {
$e3415434155.pyretStack.push(L[4305]);
}
throw $e3415434155;
}
var $ret3416034161 = $Hanf_arg973534169($z3415634157,INDENT118169,PP170,_deriving95234082,anf_arg371434167,anf_fun371334168,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants95434152,_plus55);
++R.GAS;
return $ret3416034161;
};
var $Hanf_arg973534169 = function(anf_arg372034166,INDENT118169,PP170,_deriving95234082,anf_arg371434167,anf_fun371334168,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants95434152,_plus55) {
var $z3418734188 = D;
var $f3419334194 = function(_) {
return R.isFunction(anf_fun371334168)?anf_fun371334168.app(anf_arg371434167,anf_arg372034166):R.ffi.throwNonFunApp(L[4312],anf_fun371334168,[anf_arg371434167,anf_arg372034166]);
};
try {
if(--R.GAS > 0) {
$z3418734188 = $f3419334194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3419334194,
"from":L[4312]});
}
} catch($e3418534186) {
if(R.isCont($e3418534186)) {
var $ss3418934190 = {"from":L[4312],
"go":function(anf_arg372134195) {
return $Hanf_arg973434196(anf_arg372134195,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants95434152,_plus55);
}};
$e3418534186.stack[R.EXN_STACKHEIGHT++] = $ss3418934190;
}
if(R.isPyretException($e3418534186)) {
$e3418534186.pyretStack.push(L[4312]);
}
throw $e3418534186;
}
var $ret3419134192 = $Hanf_arg973434196($z3418734188,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants95434152,_plus55);
++R.GAS;
return $ret3419134192;
};
var $Hanf_arg973434196 = function(anf_arg372134195,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_sharing167793,str_DASH_where182988,variants95434152,_plus55) {
var $z3419934200 = D;
var $f3420534206 = function(_) {
return R.isFunction(optional_DASH_section94713050.$var)?optional_DASH_section94713050.$var.app(str_DASH_sharing167793,anf_arg372134195):R.ffi.throwNonFunApp(L[4313],optional_DASH_section94713050.$var,[str_DASH_sharing167793,anf_arg372134195]);
};
try {
if(--R.GAS > 0) {
$z3419934200 = $f3420534206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3420534206,
"from":L[4313]});
}
} catch($e3419734198) {
if(R.isCont($e3419734198)) {
var $ss3420134202 = {"from":L[4313],
"go":function(shared95634207) {
return $Hshared973334208(shared95634207,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_where182988,variants95434152,_plus55);
}};
$e3419734198.stack[R.EXN_STACKHEIGHT++] = $ss3420134202;
}
if(R.isPyretException($e3419734198)) {
$e3419734198.pyretStack.push(L[4313]);
}
throw $e3419734198;
}
var $ret3420334204 = $Hshared973334208($z3419934200,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_where182988,variants95434152,_plus55);
++R.GAS;
return $ret3420334204;
};
var $Hshared973334208 = function(shared95634207,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,optional_DASH_section94713050,self94613064,str_DASH_end148546,str_DASH_where182988,variants95434152,_plus55) {
var cases_DASH_val49034242 = G(self94613064,"_check",L[4321]);
var anf_fun372234219 = G(cases_DASH_val49034242,"_match",L[4315]);
var anf_obj372434225 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4319],0,arguments);
}
var ann_DASH_check_DASH_temp372334241 = G(PP170,"mt-doc",L[4320]);
return ann_DASH_check_DASH_temp372334241;
});
var anf_obj372834226 = R.makeFunction(function(chk95934227) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4316],1,arguments);
}
var anf_fun372634238 = G(chk95934227,"tosource",L[4318]);
var $z3423034231 = D;
var $f3423634237 = function(_) {
return R.isFunction(anf_fun372634238)?anf_fun372634238.app():R.ffi.throwNonFunApp(L[4317],anf_fun372634238,[]);
};
try {
if(--R.GAS > 0) {
$z3423034231 = $f3423634237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3423634237,
"from":L[4317]});
}
} catch($e3422834229) {
if(R.isCont($e3422834229)) {
var $ss3423234233 = {"from":L[4317],
"go":function(anf_arg372734239) {
return $Hanf_arg972334240(anf_arg372734239,optional_DASH_section94713050,str_DASH_where182988);
}};
$e3422834229.stack[R.EXN_STACKHEIGHT++] = $ss3423234233;
}
if(R.isPyretException($e3422834229)) {
$e3422834229.pyretStack.push(L[4317]);
}
throw $e3422834229;
}
var $ret3423434235 = $Hanf_arg972334240($z3423034231,optional_DASH_section94713050,str_DASH_where182988);
++R.GAS;
return $ret3423434235;
});
var anf_arg372934220 = R.makeObject({"none":anf_obj372434225,
"some":anf_obj372834226});
var anf_arg373134221 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4315],0,arguments);
}
var ann_DASH_check_DASH_temp373034224 = R.throwNoBranchesMatched(L[4315],("cases"));
return ann_DASH_check_DASH_temp373034224;
});
var $z3421134212 = D;
var $f3421734218 = function(_) {
return R.isFunction(anf_fun372234219)?anf_fun372234219.app(anf_arg372934220,anf_arg373134221):R.ffi.throwNonFunApp(L[4314],anf_fun372234219,[anf_arg372934220,anf_arg373134221]);
};
try {
if(--R.GAS > 0) {
$z3421134212 = $f3421734218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3421734218,
"from":L[4314]});
}
} catch($e3420934210) {
if(R.isCont($e3420934210)) {
var $ss3421334214 = {"from":L[4314],
"go":function(_check95834222) {
return $H_check973234223(_check95834222,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,shared95634207,str_DASH_end148546,variants95434152,_plus55);
}};
$e3420934210.stack[R.EXN_STACKHEIGHT++] = $ss3421334214;
}
if(R.isPyretException($e3420934210)) {
$e3420934210.pyretStack.push(L[4314]);
}
throw $e3420934210;
}
var $ret3421534216 = $H_check973234223($z3421134212,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,shared95634207,str_DASH_end148546,variants95434152,_plus55);
++R.GAS;
return $ret3421534216;
};
var $H_check973234223 = function(_check95834222,INDENT118169,PP170,_deriving95234082,break_DASH_one119168,header95134025,shared95634207,str_DASH_end148546,variants95434152,_plus55) {
var $z3424534246 = D;
var $f3425134252 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_end148546):R.ffi.throwNonFunApp(L[4322],_plus55,[break_DASH_one119168,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z3424534246 = $f3425134252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3425134252,
"from":L[4322]});
}
} catch($e3424334244) {
if(R.isCont($e3424334244)) {
var $ss3424734248 = {"from":L[4322],
"go":function(footer96034253) {
return $Hfooter973134254(footer96034253,INDENT118169,PP170,_check95834222,_deriving95234082,header95134025,shared95634207,variants95434152,_plus55);
}};
$e3424334244.stack[R.EXN_STACKHEIGHT++] = $ss3424734248;
}
if(R.isPyretException($e3424334244)) {
$e3424334244.pyretStack.push(L[4322]);
}
throw $e3424334244;
}
var $ret3424934250 = $Hfooter973134254($z3424534246,INDENT118169,PP170,_check95834222,_deriving95234082,header95134025,shared95634207,variants95434152,_plus55);
++R.GAS;
return $ret3424934250;
};
var $Hfooter973134254 = function(footer96034253,INDENT118169,PP170,_check95834222,_deriving95234082,header95134025,shared95634207,variants95434152,_plus55) {
var $z3425734258 = D;
var $f3426334264 = function(_) {
return R.isFunction(_plus55)?_plus55.app(header95134025,_deriving95234082):R.ffi.throwNonFunApp(L[4323],_plus55,[header95134025,_deriving95234082]);
};
try {
if(--R.GAS > 0) {
$z3425734258 = $f3426334264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3426334264,
"from":L[4323]});
}
} catch($e3425534256) {
if(R.isCont($e3425534256)) {
var $ss3425934260 = {"from":L[4323],
"go":function(anf_arg373234265) {
return $Hanf_arg973034266(anf_arg373234265,INDENT118169,PP170,_check95834222,footer96034253,shared95634207,variants95434152,_plus55);
}};
$e3425534256.stack[R.EXN_STACKHEIGHT++] = $ss3425934260;
}
if(R.isPyretException($e3425534256)) {
$e3425534256.pyretStack.push(L[4323]);
}
throw $e3425534256;
}
var $ret3426134262 = $Hanf_arg973034266($z3425734258,INDENT118169,PP170,_check95834222,footer96034253,shared95634207,variants95434152,_plus55);
++R.GAS;
return $ret3426134262;
};
var $Hanf_arg973034266 = function(anf_arg373234265,INDENT118169,PP170,_check95834222,footer96034253,shared95634207,variants95434152,_plus55) {
var anf_fun373334279 = G(PP170,"group",L[4326]);
var anf_fun373434277 = G(PP170,"nest",L[4325]);
var $z3426934270 = D;
var $f3427534276 = function(_) {
return R.isFunction(anf_fun373434277)?anf_fun373434277.app(INDENT118169,variants95434152):R.ffi.throwNonFunApp(L[4324],anf_fun373434277,[INDENT118169,variants95434152]);
};
try {
if(--R.GAS > 0) {
$z3426934270 = $f3427534276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3427534276,
"from":L[4324]});
}
} catch($e3426734268) {
if(R.isCont($e3426734268)) {
var $ss3427134272 = {"from":L[4324],
"go":function(anf_arg373534278) {
return $Hanf_arg972934280(anf_arg373534278,_check95834222,anf_arg373234265,anf_fun373334279,footer96034253,shared95634207,_plus55);
}};
$e3426734268.stack[R.EXN_STACKHEIGHT++] = $ss3427134272;
}
if(R.isPyretException($e3426734268)) {
$e3426734268.pyretStack.push(L[4324]);
}
throw $e3426734268;
}
var $ret3427334274 = $Hanf_arg972934280($z3426934270,_check95834222,anf_arg373234265,anf_fun373334279,footer96034253,shared95634207,_plus55);
++R.GAS;
return $ret3427334274;
};
var $Hanf_arg972934280 = function(anf_arg373534278,_check95834222,anf_arg373234265,anf_fun373334279,footer96034253,shared95634207,_plus55) {
var $z3428334284 = D;
var $f3428934290 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg373534278,shared95634207):R.ffi.throwNonFunApp(L[4327],_plus55,[anf_arg373534278,shared95634207]);
};
try {
if(--R.GAS > 0) {
$z3428334284 = $f3428934290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3428934290,
"from":L[4327]});
}
} catch($e3428134282) {
if(R.isCont($e3428134282)) {
var $ss3428534286 = {"from":L[4327],
"go":function(anf_arg373634291) {
return $Hanf_arg972834292(anf_arg373634291,_check95834222,anf_arg373234265,anf_fun373334279,footer96034253,_plus55);
}};
$e3428134282.stack[R.EXN_STACKHEIGHT++] = $ss3428534286;
}
if(R.isPyretException($e3428134282)) {
$e3428134282.pyretStack.push(L[4327]);
}
throw $e3428134282;
}
var $ret3428734288 = $Hanf_arg972834292($z3428334284,_check95834222,anf_arg373234265,anf_fun373334279,footer96034253,_plus55);
++R.GAS;
return $ret3428734288;
};
var $Hanf_arg972834292 = function(anf_arg373634291,_check95834222,anf_arg373234265,anf_fun373334279,footer96034253,_plus55) {
var $z3429534296 = D;
var $f3430134302 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg373634291,_check95834222):R.ffi.throwNonFunApp(L[4327],_plus55,[anf_arg373634291,_check95834222]);
};
try {
if(--R.GAS > 0) {
$z3429534296 = $f3430134302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3430134302,
"from":L[4327]});
}
} catch($e3429334294) {
if(R.isCont($e3429334294)) {
var $ss3429734298 = {"from":L[4327],
"go":function(anf_arg373734303) {
return $Hanf_arg972734304(anf_arg373734303,anf_arg373234265,anf_fun373334279,footer96034253,_plus55);
}};
$e3429334294.stack[R.EXN_STACKHEIGHT++] = $ss3429734298;
}
if(R.isPyretException($e3429334294)) {
$e3429334294.pyretStack.push(L[4327]);
}
throw $e3429334294;
}
var $ret3429934300 = $Hanf_arg972734304($z3429534296,anf_arg373234265,anf_fun373334279,footer96034253,_plus55);
++R.GAS;
return $ret3429934300;
};
var $Hanf_arg972734304 = function(anf_arg373734303,anf_arg373234265,anf_fun373334279,footer96034253,_plus55) {
var $z3430734308 = D;
var $f3431334314 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg373734303,footer96034253):R.ffi.throwNonFunApp(L[4327],_plus55,[anf_arg373734303,footer96034253]);
};
try {
if(--R.GAS > 0) {
$z3430734308 = $f3431334314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3431334314,
"from":L[4327]});
}
} catch($e3430534306) {
if(R.isCont($e3430534306)) {
var $ss3430934310 = {"from":L[4327],
"go":function(anf_arg373834315) {
return $Hanf_arg972634316(anf_arg373834315,anf_arg373234265,anf_fun373334279,_plus55);
}};
$e3430534306.stack[R.EXN_STACKHEIGHT++] = $ss3430934310;
}
if(R.isPyretException($e3430534306)) {
$e3430534306.pyretStack.push(L[4327]);
}
throw $e3430534306;
}
var $ret3431134312 = $Hanf_arg972634316($z3430734308,anf_arg373234265,anf_fun373334279,_plus55);
++R.GAS;
return $ret3431134312;
};
var $Hanf_arg972634316 = function(anf_arg373834315,anf_arg373234265,anf_fun373334279,_plus55) {
var $z3431934320 = D;
var $f3432534326 = function(_) {
return R.isFunction(anf_fun373334279)?anf_fun373334279.app(anf_arg373834315):R.ffi.throwNonFunApp(L[4328],anf_fun373334279,[anf_arg373834315]);
};
try {
if(--R.GAS > 0) {
$z3431934320 = $f3432534326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3432534326,
"from":L[4328]});
}
} catch($e3431734318) {
if(R.isCont($e3431734318)) {
var $ss3432134322 = {"from":L[4328],
"go":function(anf_arg373934327) {
return $Hanf_arg972534328(anf_arg373934327,anf_arg373234265,_plus55);
}};
$e3431734318.stack[R.EXN_STACKHEIGHT++] = $ss3432134322;
}
if(R.isPyretException($e3431734318)) {
$e3431734318.pyretStack.push(L[4328]);
}
throw $e3431734318;
}
var $ret3432334324 = $Hanf_arg972534328($z3431934320,anf_arg373234265,_plus55);
++R.GAS;
return $ret3432334324;
};
var $Hanf_arg972534328 = function(anf_arg373934327,anf_arg373234265,_plus55) {
var $z3433134332 = D;
var $f3433734338 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg373234265,anf_arg373934327):R.ffi.throwNonFunApp(L[2565],_plus55,[anf_arg373234265,anf_arg373934327]);
};
try {
if(--R.GAS > 0) {
$z3433134332 = $f3433734338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3433734338,
"from":L[2565]});
}
} catch($e3432934330) {
if(R.isCont($e3432934330)) {
var $ss3433334334 = {"from":L[2565],
"go":function(ann_DASH_check_DASH_temp365234339) {
return $Hann_DASH_check_DASH_temp972434340(ann_DASH_check_DASH_temp365234339);
}};
$e3432934330.stack[R.EXN_STACKHEIGHT++] = $ss3433334334;
}
if(R.isPyretException($e3432934330)) {
$e3432934330.pyretStack.push(L[2565]);
}
throw $e3432934330;
}
var $ret3433534336 = $Hann_DASH_check_DASH_temp972434340($z3433134332);
++R.GAS;
return $ret3433534336;
};
var $Hann_DASH_check_DASH_temp972434340 = function(ann_DASH_check_DASH_temp365234339) {
return ann_DASH_check_DASH_temp365234339;
};
var $Hanf_arg972334240 = function(anf_arg372734239,optional_DASH_section94713050,str_DASH_where182988) {
var $z3434334344 = D;
var $f3434934350 = function(_) {
return R.isFunction(optional_DASH_section94713050.$var)?optional_DASH_section94713050.$var.app(str_DASH_where182988,anf_arg372734239):R.ffi.throwNonFunApp(L[4316],optional_DASH_section94713050.$var,[str_DASH_where182988,anf_arg372734239]);
};
try {
if(--R.GAS > 0) {
$z3434334344 = $f3434934350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3434934350,
"from":L[4316]});
}
} catch($e3434134342) {
if(R.isCont($e3434134342)) {
var $ss3434534346 = {"from":L[4316],
"go":function(ann_DASH_check_DASH_temp372534351) {
return $Hann_DASH_check_DASH_temp972234352(ann_DASH_check_DASH_temp372534351);
}};
$e3434134342.stack[R.EXN_STACKHEIGHT++] = $ss3434534346;
}
if(R.isPyretException($e3434134342)) {
$e3434134342.pyretStack.push(L[4316]);
}
throw $e3434134342;
}
var $ret3434734348 = $Hann_DASH_check_DASH_temp972234352($z3434334344);
++R.GAS;
return $ret3434734348;
};
var $Hann_DASH_check_DASH_temp972234352 = function(ann_DASH_check_DASH_temp372534351) {
return ann_DASH_check_DASH_temp372534351;
};
var $Hann_DASH_check_DASH_temp972134183 = function(ann_DASH_check_DASH_temp371734182) {
return ann_DASH_check_DASH_temp371734182;
};
var $Hanf_arg972034125 = function(anf_arg371034123,anf_fun370234124,arg_DASH_48934110) {
var $z3435534356 = D;
var $f3436134362 = function(_) {
return R.isFunction(anf_fun370234124)?anf_fun370234124.app(arg_DASH_48934110,anf_arg371034123):R.ffi.throwNonFunApp(L[4295],anf_fun370234124,[arg_DASH_48934110,anf_arg371034123]);
};
try {
if(--R.GAS > 0) {
$z3435534356 = $f3436134362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3436134362,
"from":L[4295]});
}
} catch($e3435334354) {
if(R.isCont($e3435334354)) {
var $ss3435734358 = {"from":L[4295],
"go":function(ann_DASH_check_DASH_temp370134363) {
return $Hann_DASH_check_DASH_temp971934364(ann_DASH_check_DASH_temp370134363);
}};
$e3435334354.stack[R.EXN_STACKHEIGHT++] = $ss3435734358;
}
if(R.isPyretException($e3435334354)) {
$e3435334354.pyretStack.push(L[4295]);
}
throw $e3435334354;
}
var $ret3435934360 = $Hann_DASH_check_DASH_temp971934364($z3435534356);
++R.GAS;
return $ret3435934360;
};
var $Hann_DASH_check_DASH_temp971934364 = function(ann_DASH_check_DASH_temp370134363) {
return ann_DASH_check_DASH_temp370134363;
};
var $Hanf_arg971834140 = function(anf_arg370834138,INDENT118169,anf_fun370634139) {
var $z3436734368 = D;
var $f3437334374 = function(_) {
return R.isFunction(anf_fun370634139)?anf_fun370634139.app(INDENT118169,anf_arg370834138):R.ffi.throwNonFunApp(L[4297],anf_fun370634139,[INDENT118169,anf_arg370834138]);
};
try {
if(--R.GAS > 0) {
$z3436734368 = $f3437334374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3437334374,
"from":L[4297]});
}
} catch($e3436534366) {
if(R.isCont($e3436534366)) {
var $ss3436934370 = {"from":L[4297],
"go":function(ann_DASH_check_DASH_temp370534375) {
return $Hann_DASH_check_DASH_temp971734376(ann_DASH_check_DASH_temp370534375);
}};
$e3436534366.stack[R.EXN_STACKHEIGHT++] = $ss3436934370;
}
if(R.isPyretException($e3436534366)) {
$e3436534366.pyretStack.push(L[4297]);
}
throw $e3436534366;
}
var $ret3437134372 = $Hann_DASH_check_DASH_temp971734376($z3436734368);
++R.GAS;
return $ret3437134372;
};
var $Hann_DASH_check_DASH_temp971734376 = function(ann_DASH_check_DASH_temp370534375) {
return ann_DASH_check_DASH_temp370534375;
};
var $Hann_DASH_check_DASH_temp971634070 = function(ann_DASH_check_DASH_temp369534069) {
return ann_DASH_check_DASH_temp369534069;
};
var $Hann_DASH_check_DASH_temp971533963 = function(ann_DASH_check_DASH_temp367933962) {
return ann_DASH_check_DASH_temp367933962;
};
var $Hif_DASH_971413080 = function(if_DASH_48713079,INDENT118169,PP170,break_DASH_one119168,lbl94813066,section94913067,_plus55) {
var if_helper365534379 = R.makeFunction(function(if_helper_arg365634399) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2563],1,arguments);
}
var ann_DASH_check_DASH_temp365334400 = if_helper_arg365634399;
return ann_DASH_check_DASH_temp365334400;
});
var anf_if365934398 = R.isBoolean(if_DASH_48713079);
if(R.isPyretTrue(anf_if365934398)) {
if(R.isPyretTrue(if_DASH_48713079)) {
var cont_tail_arg366834380 = G(PP170,"mt-doc",L[4329]);
if(--R.GAS > 0) {
$z3437734378 = R.isFunction(if_helper365534379)?if_helper365534379.app(cont_tail_arg366834380):R.ffi.throwNonFunApp(L[4329],if_helper365534379,[cont_tail_arg366834380]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper365534379)?if_helper365534379.app(cont_tail_arg366834380):R.ffi.throwNonFunApp(L[4329],if_helper365534379,[cont_tail_arg366834380]);
},
"from":L[4329]});
}
++R.GAS;
return $z3437734378;
} else {
var anf_fun366034392 = G(PP170,"group",L[4332]);
var anf_fun366134393 = G(PP170,"nest",L[4331]);
var $z3438334384 = D;
var $f3438934390 = function(_) {
return R.isFunction(_plus55)?_plus55.app(lbl94813066,break_DASH_one119168):R.ffi.throwNonFunApp(L[4330],_plus55,[lbl94813066,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3438334384 = $f3438934390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3438934390,
"from":L[4330]});
}
} catch($e3438134382) {
if(R.isCont($e3438134382)) {
var $ss3438534386 = {"from":L[4330],
"go":function(anf_arg366234391) {
return $Hanf_arg971334394(anf_arg366234391,INDENT118169,anf_fun366034392,anf_fun366134393,break_DASH_one119168,if_helper365534379,section94913067,_plus55);
}};
$e3438134382.stack[R.EXN_STACKHEIGHT++] = $ss3438534386;
}
if(R.isPyretException($e3438134382)) {
$e3438134382.pyretStack.push(L[4330]);
}
throw $e3438134382;
}
var $ret3438734388 = $Hanf_arg971334394($z3438334384,INDENT118169,anf_fun366034392,anf_fun366134393,break_DASH_one119168,if_helper365534379,section94913067,_plus55);
++R.GAS;
return $ret3438734388;
}
} else {
var cont_tail_arg365734397 = R.throwNonBooleanCondition(L[2563],("if"),if_DASH_48713079);
if(--R.GAS > 0) {
$z3439534396 = R.isFunction(if_helper365534379)?if_helper365534379.app(cont_tail_arg365734397):R.ffi.throwNonFunApp(L[2563],if_helper365534379,[cont_tail_arg365734397]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper365534379)?if_helper365534379.app(cont_tail_arg365734397):R.ffi.throwNonFunApp(L[2563],if_helper365534379,[cont_tail_arg365734397]);
},
"from":L[2563]});
}
++R.GAS;
return $z3439534396;
}
};
var $Hanf_arg971334394 = function(anf_arg366234391,INDENT118169,anf_fun366034392,anf_fun366134393,break_DASH_one119168,if_helper365534379,section94913067,_plus55) {
var $z3440334404 = D;
var $f3440934410 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg366234391,section94913067):R.ffi.throwNonFunApp(L[4330],_plus55,[anf_arg366234391,section94913067]);
};
try {
if(--R.GAS > 0) {
$z3440334404 = $f3440934410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3440934410,
"from":L[4330]});
}
} catch($e3440134402) {
if(R.isCont($e3440134402)) {
var $ss3440534406 = {"from":L[4330],
"go":function(anf_arg366334411) {
return $Hanf_arg971234412(anf_arg366334411,INDENT118169,anf_fun366034392,anf_fun366134393,break_DASH_one119168,if_helper365534379,_plus55);
}};
$e3440134402.stack[R.EXN_STACKHEIGHT++] = $ss3440534406;
}
if(R.isPyretException($e3440134402)) {
$e3440134402.pyretStack.push(L[4330]);
}
throw $e3440134402;
}
var $ret3440734408 = $Hanf_arg971234412($z3440334404,INDENT118169,anf_fun366034392,anf_fun366134393,break_DASH_one119168,if_helper365534379,_plus55);
++R.GAS;
return $ret3440734408;
};
var $Hanf_arg971234412 = function(anf_arg366334411,INDENT118169,anf_fun366034392,anf_fun366134393,break_DASH_one119168,if_helper365534379,_plus55) {
var $z3441534416 = D;
var $f3442134422 = function(_) {
return R.isFunction(anf_fun366134393)?anf_fun366134393.app(INDENT118169,anf_arg366334411):R.ffi.throwNonFunApp(L[4333],anf_fun366134393,[INDENT118169,anf_arg366334411]);
};
try {
if(--R.GAS > 0) {
$z3441534416 = $f3442134422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3442134422,
"from":L[4333]});
}
} catch($e3441334414) {
if(R.isCont($e3441334414)) {
var $ss3441734418 = {"from":L[4333],
"go":function(anf_arg366434423) {
return $Hanf_arg971134424(anf_arg366434423,anf_fun366034392,break_DASH_one119168,if_helper365534379,_plus55);
}};
$e3441334414.stack[R.EXN_STACKHEIGHT++] = $ss3441734418;
}
if(R.isPyretException($e3441334414)) {
$e3441334414.pyretStack.push(L[4333]);
}
throw $e3441334414;
}
var $ret3441934420 = $Hanf_arg971134424($z3441534416,anf_fun366034392,break_DASH_one119168,if_helper365534379,_plus55);
++R.GAS;
return $ret3441934420;
};
var $Hanf_arg971134424 = function(anf_arg366434423,anf_fun366034392,break_DASH_one119168,if_helper365534379,_plus55) {
var $z3442734428 = D;
var $f3443334434 = function(_) {
return R.isFunction(anf_fun366034392)?anf_fun366034392.app(anf_arg366434423):R.ffi.throwNonFunApp(L[4334],anf_fun366034392,[anf_arg366434423]);
};
try {
if(--R.GAS > 0) {
$z3442734428 = $f3443334434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3443334434,
"from":L[4334]});
}
} catch($e3442534426) {
if(R.isCont($e3442534426)) {
var $ss3442934430 = {"from":L[4334],
"go":function(anf_arg366534435) {
return $Hanf_arg971034436(anf_arg366534435,break_DASH_one119168,if_helper365534379,_plus55);
}};
$e3442534426.stack[R.EXN_STACKHEIGHT++] = $ss3442934430;
}
if(R.isPyretException($e3442534426)) {
$e3442534426.pyretStack.push(L[4334]);
}
throw $e3442534426;
}
var $ret3443134432 = $Hanf_arg971034436($z3442734428,break_DASH_one119168,if_helper365534379,_plus55);
++R.GAS;
return $ret3443134432;
};
var $Hanf_arg971034436 = function(anf_arg366534435,break_DASH_one119168,if_helper365534379,_plus55) {
var $z3443934440 = D;
var $f3444534446 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,anf_arg366534435):R.ffi.throwNonFunApp(L[4335],_plus55,[break_DASH_one119168,anf_arg366534435]);
};
try {
if(--R.GAS > 0) {
$z3443934440 = $f3444534446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3444534446,
"from":L[4335]});
}
} catch($e3443734438) {
if(R.isCont($e3443734438)) {
var $ss3444134442 = {"from":L[4335],
"go":function(cont_tail_arg366634447) {
return $Hcont_tail_arg970934448(cont_tail_arg366634447,if_helper365534379);
}};
$e3443734438.stack[R.EXN_STACKHEIGHT++] = $ss3444134442;
}
if(R.isPyretException($e3443734438)) {
$e3443734438.pyretStack.push(L[4335]);
}
throw $e3443734438;
}
var $ret3444334444 = $Hcont_tail_arg970934448($z3443934440,if_helper365534379);
++R.GAS;
return $ret3444334444;
};
var $Hcont_tail_arg970934448 = function(cont_tail_arg366634447,if_helper365534379) {
if(--R.GAS > 0) {
$z3444934450 = R.isFunction(if_helper365534379)?if_helper365534379.app(cont_tail_arg366634447):R.ffi.throwNonFunApp(L[4335],if_helper365534379,[cont_tail_arg366634447]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper365534379)?if_helper365534379.app(cont_tail_arg366634447):R.ffi.throwNonFunApp(L[4335],if_helper365534379,[cont_tail_arg366634447]);
},
"from":L[4335]});
}
++R.GAS;
return $z3444934450;
};
var $Hanf_arg970813096 = function(anf_arg362213094,self48513095,_plus55,torepr65) {
var anf_arg362334461 = G(self48513095,"name",L[2219]);
var $z3445334454 = D;
var $f3445934460 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg362334461):R.ffi.throwNonFunApp(L[2219],torepr65,[anf_arg362334461]);
};
try {
if(--R.GAS > 0) {
$z3445334454 = $f3445934460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3445934460,
"from":L[2219]});
}
} catch($e3445134452) {
if(R.isCont($e3445134452)) {
var $ss3445534456 = {"from":L[2219],
"go":function(anf_arg362434462) {
return $Hanf_arg970734463(anf_arg362434462,anf_arg362213094,self48513095,_plus55,torepr65);
}};
$e3445134452.stack[R.EXN_STACKHEIGHT++] = $ss3445534456;
}
if(R.isPyretException($e3445134452)) {
$e3445134452.pyretStack.push(L[2219]);
}
throw $e3445134452;
}
var $ret3445734458 = $Hanf_arg970734463($z3445334454,anf_arg362213094,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3445734458;
};
var $Hanf_arg970734463 = function(anf_arg362434462,anf_arg362213094,self48513095,_plus55,torepr65) {
var $z3446634467 = D;
var $f3447234473 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg362434462):R.ffi.throwNonFunApp(L[2219],_plus55,[(", "),anf_arg362434462]);
};
try {
if(--R.GAS > 0) {
$z3446634467 = $f3447234473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3447234473,
"from":L[2219]});
}
} catch($e3446434465) {
if(R.isCont($e3446434465)) {
var $ss3446834469 = {"from":L[2219],
"go":function(anf_arg362534474) {
return $Hanf_arg970634475(anf_arg362534474,anf_arg362213094,self48513095,_plus55,torepr65);
}};
$e3446434465.stack[R.EXN_STACKHEIGHT++] = $ss3446834469;
}
if(R.isPyretException($e3446434465)) {
$e3446434465.pyretStack.push(L[2219]);
}
throw $e3446434465;
}
var $ret3447034471 = $Hanf_arg970634475($z3446634467,anf_arg362213094,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3447034471;
};
var $Hanf_arg970634475 = function(anf_arg362534474,anf_arg362213094,self48513095,_plus55,torepr65) {
var $z3447834479 = D;
var $f3448434485 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg362213094,anf_arg362534474):R.ffi.throwNonFunApp(L[2219],_plus55,[anf_arg362213094,anf_arg362534474]);
};
try {
if(--R.GAS > 0) {
$z3447834479 = $f3448434485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3448434485,
"from":L[2219]});
}
} catch($e3447634477) {
if(R.isCont($e3447634477)) {
var $ss3448034481 = {"from":L[2219],
"go":function(anf_arg362634486) {
return $Hanf_arg970534487(anf_arg362634486,self48513095,_plus55,torepr65);
}};
$e3447634477.stack[R.EXN_STACKHEIGHT++] = $ss3448034481;
}
if(R.isPyretException($e3447634477)) {
$e3447634477.pyretStack.push(L[2219]);
}
throw $e3447634477;
}
var $ret3448234483 = $Hanf_arg970534487($z3447834479,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3448234483;
};
var $Hanf_arg970534487 = function(anf_arg362634486,self48513095,_plus55,torepr65) {
var anf_arg362734498 = G(self48513095,"params",L[2219]);
var $z3449034491 = D;
var $f3449634497 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg362734498):R.ffi.throwNonFunApp(L[2219],torepr65,[anf_arg362734498]);
};
try {
if(--R.GAS > 0) {
$z3449034491 = $f3449634497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3449634497,
"from":L[2219]});
}
} catch($e3448834489) {
if(R.isCont($e3448834489)) {
var $ss3449234493 = {"from":L[2219],
"go":function(anf_arg362834499) {
return $Hanf_arg970434500(anf_arg362834499,anf_arg362634486,self48513095,_plus55,torepr65);
}};
$e3448834489.stack[R.EXN_STACKHEIGHT++] = $ss3449234493;
}
if(R.isPyretException($e3448834489)) {
$e3448834489.pyretStack.push(L[2219]);
}
throw $e3448834489;
}
var $ret3449434495 = $Hanf_arg970434500($z3449034491,anf_arg362634486,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3449434495;
};
var $Hanf_arg970434500 = function(anf_arg362834499,anf_arg362634486,self48513095,_plus55,torepr65) {
var $z3450334504 = D;
var $f3450934510 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg362834499):R.ffi.throwNonFunApp(L[2219],_plus55,[(", "),anf_arg362834499]);
};
try {
if(--R.GAS > 0) {
$z3450334504 = $f3450934510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3450934510,
"from":L[2219]});
}
} catch($e3450134502) {
if(R.isCont($e3450134502)) {
var $ss3450534506 = {"from":L[2219],
"go":function(anf_arg362934511) {
return $Hanf_arg970334512(anf_arg362934511,anf_arg362634486,self48513095,_plus55,torepr65);
}};
$e3450134502.stack[R.EXN_STACKHEIGHT++] = $ss3450534506;
}
if(R.isPyretException($e3450134502)) {
$e3450134502.pyretStack.push(L[2219]);
}
throw $e3450134502;
}
var $ret3450734508 = $Hanf_arg970334512($z3450334504,anf_arg362634486,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3450734508;
};
var $Hanf_arg970334512 = function(anf_arg362934511,anf_arg362634486,self48513095,_plus55,torepr65) {
var $z3451534516 = D;
var $f3452134522 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg362634486,anf_arg362934511):R.ffi.throwNonFunApp(L[2219],_plus55,[anf_arg362634486,anf_arg362934511]);
};
try {
if(--R.GAS > 0) {
$z3451534516 = $f3452134522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3452134522,
"from":L[2219]});
}
} catch($e3451334514) {
if(R.isCont($e3451334514)) {
var $ss3451734518 = {"from":L[2219],
"go":function(anf_arg363034523) {
return $Hanf_arg970234524(anf_arg363034523,self48513095,_plus55,torepr65);
}};
$e3451334514.stack[R.EXN_STACKHEIGHT++] = $ss3451734518;
}
if(R.isPyretException($e3451334514)) {
$e3451334514.pyretStack.push(L[2219]);
}
throw $e3451334514;
}
var $ret3451934520 = $Hanf_arg970234524($z3451534516,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3451934520;
};
var $Hanf_arg970234524 = function(anf_arg363034523,self48513095,_plus55,torepr65) {
var anf_arg363134535 = G(self48513095,"mixins",L[2219]);
var $z3452734528 = D;
var $f3453334534 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg363134535):R.ffi.throwNonFunApp(L[2219],torepr65,[anf_arg363134535]);
};
try {
if(--R.GAS > 0) {
$z3452734528 = $f3453334534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3453334534,
"from":L[2219]});
}
} catch($e3452534526) {
if(R.isCont($e3452534526)) {
var $ss3452934530 = {"from":L[2219],
"go":function(anf_arg363234536) {
return $Hanf_arg970134537(anf_arg363234536,anf_arg363034523,self48513095,_plus55,torepr65);
}};
$e3452534526.stack[R.EXN_STACKHEIGHT++] = $ss3452934530;
}
if(R.isPyretException($e3452534526)) {
$e3452534526.pyretStack.push(L[2219]);
}
throw $e3452534526;
}
var $ret3453134532 = $Hanf_arg970134537($z3452734528,anf_arg363034523,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3453134532;
};
var $Hanf_arg970134537 = function(anf_arg363234536,anf_arg363034523,self48513095,_plus55,torepr65) {
var $z3454034541 = D;
var $f3454634547 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg363234536):R.ffi.throwNonFunApp(L[2219],_plus55,[(", "),anf_arg363234536]);
};
try {
if(--R.GAS > 0) {
$z3454034541 = $f3454634547();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3454634547,
"from":L[2219]});
}
} catch($e3453834539) {
if(R.isCont($e3453834539)) {
var $ss3454234543 = {"from":L[2219],
"go":function(anf_arg363334548) {
return $Hanf_arg970034549(anf_arg363334548,anf_arg363034523,self48513095,_plus55,torepr65);
}};
$e3453834539.stack[R.EXN_STACKHEIGHT++] = $ss3454234543;
}
if(R.isPyretException($e3453834539)) {
$e3453834539.pyretStack.push(L[2219]);
}
throw $e3453834539;
}
var $ret3454434545 = $Hanf_arg970034549($z3454034541,anf_arg363034523,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3454434545;
};
var $Hanf_arg970034549 = function(anf_arg363334548,anf_arg363034523,self48513095,_plus55,torepr65) {
var $z3455234553 = D;
var $f3455834559 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg363034523,anf_arg363334548):R.ffi.throwNonFunApp(L[2219],_plus55,[anf_arg363034523,anf_arg363334548]);
};
try {
if(--R.GAS > 0) {
$z3455234553 = $f3455834559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3455834559,
"from":L[2219]});
}
} catch($e3455034551) {
if(R.isCont($e3455034551)) {
var $ss3455434555 = {"from":L[2219],
"go":function(anf_arg363434560) {
return $Hanf_arg969934561(anf_arg363434560,self48513095,_plus55,torepr65);
}};
$e3455034551.stack[R.EXN_STACKHEIGHT++] = $ss3455434555;
}
if(R.isPyretException($e3455034551)) {
$e3455034551.pyretStack.push(L[2219]);
}
throw $e3455034551;
}
var $ret3455634557 = $Hanf_arg969934561($z3455234553,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3455634557;
};
var $Hanf_arg969934561 = function(anf_arg363434560,self48513095,_plus55,torepr65) {
var anf_arg363534572 = G(self48513095,"variants",L[2219]);
var $z3456434565 = D;
var $f3457034571 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg363534572):R.ffi.throwNonFunApp(L[2219],torepr65,[anf_arg363534572]);
};
try {
if(--R.GAS > 0) {
$z3456434565 = $f3457034571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3457034571,
"from":L[2219]});
}
} catch($e3456234563) {
if(R.isCont($e3456234563)) {
var $ss3456634567 = {"from":L[2219],
"go":function(anf_arg363634573) {
return $Hanf_arg969834574(anf_arg363634573,anf_arg363434560,self48513095,_plus55,torepr65);
}};
$e3456234563.stack[R.EXN_STACKHEIGHT++] = $ss3456634567;
}
if(R.isPyretException($e3456234563)) {
$e3456234563.pyretStack.push(L[2219]);
}
throw $e3456234563;
}
var $ret3456834569 = $Hanf_arg969834574($z3456434565,anf_arg363434560,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3456834569;
};
var $Hanf_arg969834574 = function(anf_arg363634573,anf_arg363434560,self48513095,_plus55,torepr65) {
var $z3457734578 = D;
var $f3458334584 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg363634573):R.ffi.throwNonFunApp(L[2219],_plus55,[(", "),anf_arg363634573]);
};
try {
if(--R.GAS > 0) {
$z3457734578 = $f3458334584();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3458334584,
"from":L[2219]});
}
} catch($e3457534576) {
if(R.isCont($e3457534576)) {
var $ss3457934580 = {"from":L[2219],
"go":function(anf_arg363734585) {
return $Hanf_arg969734586(anf_arg363734585,anf_arg363434560,self48513095,_plus55,torepr65);
}};
$e3457534576.stack[R.EXN_STACKHEIGHT++] = $ss3457934580;
}
if(R.isPyretException($e3457534576)) {
$e3457534576.pyretStack.push(L[2219]);
}
throw $e3457534576;
}
var $ret3458134582 = $Hanf_arg969734586($z3457734578,anf_arg363434560,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3458134582;
};
var $Hanf_arg969734586 = function(anf_arg363734585,anf_arg363434560,self48513095,_plus55,torepr65) {
var $z3458934590 = D;
var $f3459534596 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg363434560,anf_arg363734585):R.ffi.throwNonFunApp(L[2219],_plus55,[anf_arg363434560,anf_arg363734585]);
};
try {
if(--R.GAS > 0) {
$z3458934590 = $f3459534596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3459534596,
"from":L[2219]});
}
} catch($e3458734588) {
if(R.isCont($e3458734588)) {
var $ss3459134592 = {"from":L[2219],
"go":function(anf_arg363834597) {
return $Hanf_arg969634598(anf_arg363834597,self48513095,_plus55,torepr65);
}};
$e3458734588.stack[R.EXN_STACKHEIGHT++] = $ss3459134592;
}
if(R.isPyretException($e3458734588)) {
$e3458734588.pyretStack.push(L[2219]);
}
throw $e3458734588;
}
var $ret3459334594 = $Hanf_arg969634598($z3458934590,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3459334594;
};
var $Hanf_arg969634598 = function(anf_arg363834597,self48513095,_plus55,torepr65) {
var anf_arg363934609 = G(self48513095,"shared-members",L[2219]);
var $z3460134602 = D;
var $f3460734608 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg363934609):R.ffi.throwNonFunApp(L[2219],torepr65,[anf_arg363934609]);
};
try {
if(--R.GAS > 0) {
$z3460134602 = $f3460734608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3460734608,
"from":L[2219]});
}
} catch($e3459934600) {
if(R.isCont($e3459934600)) {
var $ss3460334604 = {"from":L[2219],
"go":function(anf_arg364034610) {
return $Hanf_arg969534611(anf_arg364034610,anf_arg363834597,self48513095,_plus55,torepr65);
}};
$e3459934600.stack[R.EXN_STACKHEIGHT++] = $ss3460334604;
}
if(R.isPyretException($e3459934600)) {
$e3459934600.pyretStack.push(L[2219]);
}
throw $e3459934600;
}
var $ret3460534606 = $Hanf_arg969534611($z3460134602,anf_arg363834597,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3460534606;
};
var $Hanf_arg969534611 = function(anf_arg364034610,anf_arg363834597,self48513095,_plus55,torepr65) {
var $z3461434615 = D;
var $f3462034621 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg364034610):R.ffi.throwNonFunApp(L[2219],_plus55,[(", "),anf_arg364034610]);
};
try {
if(--R.GAS > 0) {
$z3461434615 = $f3462034621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3462034621,
"from":L[2219]});
}
} catch($e3461234613) {
if(R.isCont($e3461234613)) {
var $ss3461634617 = {"from":L[2219],
"go":function(anf_arg364134622) {
return $Hanf_arg969434623(anf_arg364134622,anf_arg363834597,self48513095,_plus55,torepr65);
}};
$e3461234613.stack[R.EXN_STACKHEIGHT++] = $ss3461634617;
}
if(R.isPyretException($e3461234613)) {
$e3461234613.pyretStack.push(L[2219]);
}
throw $e3461234613;
}
var $ret3461834619 = $Hanf_arg969434623($z3461434615,anf_arg363834597,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3461834619;
};
var $Hanf_arg969434623 = function(anf_arg364134622,anf_arg363834597,self48513095,_plus55,torepr65) {
var $z3462634627 = D;
var $f3463234633 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg363834597,anf_arg364134622):R.ffi.throwNonFunApp(L[2219],_plus55,[anf_arg363834597,anf_arg364134622]);
};
try {
if(--R.GAS > 0) {
$z3462634627 = $f3463234633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3463234633,
"from":L[2219]});
}
} catch($e3462434625) {
if(R.isCont($e3462434625)) {
var $ss3462834629 = {"from":L[2219],
"go":function(anf_arg364234634) {
return $Hanf_arg969334635(anf_arg364234634,self48513095,_plus55,torepr65);
}};
$e3462434625.stack[R.EXN_STACKHEIGHT++] = $ss3462834629;
}
if(R.isPyretException($e3462434625)) {
$e3462434625.pyretStack.push(L[2219]);
}
throw $e3462434625;
}
var $ret3463034631 = $Hanf_arg969334635($z3462634627,self48513095,_plus55,torepr65);
++R.GAS;
return $ret3463034631;
};
var $Hanf_arg969334635 = function(anf_arg364234634,self48513095,_plus55,torepr65) {
var anf_arg364334646 = G(self48513095,"_check",L[2219]);
var $z3463834639 = D;
var $f3464434645 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg364334646):R.ffi.throwNonFunApp(L[2219],torepr65,[anf_arg364334646]);
};
try {
if(--R.GAS > 0) {
$z3463834639 = $f3464434645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3464434645,
"from":L[2219]});
}
} catch($e3463634637) {
if(R.isCont($e3463634637)) {
var $ss3464034641 = {"from":L[2219],
"go":function(anf_arg364434647) {
return $Hanf_arg969234648(anf_arg364434647,anf_arg364234634,_plus55);
}};
$e3463634637.stack[R.EXN_STACKHEIGHT++] = $ss3464034641;
}
if(R.isPyretException($e3463634637)) {
$e3463634637.pyretStack.push(L[2219]);
}
throw $e3463634637;
}
var $ret3464234643 = $Hanf_arg969234648($z3463834639,anf_arg364234634,_plus55);
++R.GAS;
return $ret3464234643;
};
var $Hanf_arg969234648 = function(anf_arg364434647,anf_arg364234634,_plus55) {
var $z3465134652 = D;
var $f3465734658 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg364434647):R.ffi.throwNonFunApp(L[2219],_plus55,[(", "),anf_arg364434647]);
};
try {
if(--R.GAS > 0) {
$z3465134652 = $f3465734658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3465734658,
"from":L[2219]});
}
} catch($e3464934650) {
if(R.isCont($e3464934650)) {
var $ss3465334654 = {"from":L[2219],
"go":function(anf_arg364534659) {
return $Hanf_arg969134660(anf_arg364534659,anf_arg364234634,_plus55);
}};
$e3464934650.stack[R.EXN_STACKHEIGHT++] = $ss3465334654;
}
if(R.isPyretException($e3464934650)) {
$e3464934650.pyretStack.push(L[2219]);
}
throw $e3464934650;
}
var $ret3465534656 = $Hanf_arg969134660($z3465134652,anf_arg364234634,_plus55);
++R.GAS;
return $ret3465534656;
};
var $Hanf_arg969134660 = function(anf_arg364534659,anf_arg364234634,_plus55) {
var $z3466334664 = D;
var $f3466934670 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg364234634,anf_arg364534659):R.ffi.throwNonFunApp(L[2219],_plus55,[anf_arg364234634,anf_arg364534659]);
};
try {
if(--R.GAS > 0) {
$z3466334664 = $f3466934670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3466934670,
"from":L[2219]});
}
} catch($e3466134662) {
if(R.isCont($e3466134662)) {
var $ss3466534666 = {"from":L[2219],
"go":function(anf_arg364634671) {
return $Hanf_arg969034672(anf_arg364634671,_plus55);
}};
$e3466134662.stack[R.EXN_STACKHEIGHT++] = $ss3466534666;
}
if(R.isPyretException($e3466134662)) {
$e3466134662.pyretStack.push(L[2219]);
}
throw $e3466134662;
}
var $ret3466734668 = $Hanf_arg969034672($z3466334664,_plus55);
++R.GAS;
return $ret3466734668;
};
var $Hanf_arg969034672 = function(anf_arg364634671,_plus55) {
var $z3467534676 = D;
var $f3468134682 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg364634671,(")")):R.ffi.throwNonFunApp(L[2219],_plus55,[anf_arg364634671,(")")]);
};
try {
if(--R.GAS > 0) {
$z3467534676 = $f3468134682();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3468134682,
"from":L[2219]});
}
} catch($e3467334674) {
if(R.isCont($e3467334674)) {
var $ss3467734678 = {"from":L[2219],
"go":function(anf_arg364734683) {
return $Hanf_arg968934684(anf_arg364734683,_plus55);
}};
$e3467334674.stack[R.EXN_STACKHEIGHT++] = $ss3467734678;
}
if(R.isPyretException($e3467334674)) {
$e3467334674.pyretStack.push(L[2219]);
}
throw $e3467334674;
}
var $ret3467934680 = $Hanf_arg968934684($z3467534676,_plus55);
++R.GAS;
return $ret3467934680;
};
var $Hanf_arg968934684 = function(anf_arg364734683,_plus55) {
var $z3468734688 = D;
var $f3469334694 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg364734683):R.ffi.throwNonFunApp(L[2219],_plus55,[("("),anf_arg364734683]);
};
try {
if(--R.GAS > 0) {
$z3468734688 = $f3469334694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3469334694,
"from":L[2219]});
}
} catch($e3468534686) {
if(R.isCont($e3468534686)) {
var $ss3468934690 = {"from":L[2219],
"go":function(anf_arg364834695) {
return $Hanf_arg968834696(anf_arg364834695,_plus55);
}};
$e3468534686.stack[R.EXN_STACKHEIGHT++] = $ss3468934690;
}
if(R.isPyretException($e3468534686)) {
$e3468534686.pyretStack.push(L[2219]);
}
throw $e3468534686;
}
var $ret3469134692 = $Hanf_arg968834696($z3468734688,_plus55);
++R.GAS;
return $ret3469134692;
};
var $Hanf_arg968834696 = function(anf_arg364834695,_plus55) {
var $z3469934700 = D;
var $f3470534706 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-data"),anf_arg364834695):R.ffi.throwNonFunApp(L[2219],_plus55,[("s-data"),anf_arg364834695]);
};
try {
if(--R.GAS > 0) {
$z3469934700 = $f3470534706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3470534706,
"from":L[2219]});
}
} catch($e3469734698) {
if(R.isCont($e3469734698)) {
var $ss3470134702 = {"from":L[2219],
"go":function(ann_DASH_check_DASH_temp362034707) {
return $Hann_DASH_check_DASH_temp968734708(ann_DASH_check_DASH_temp362034707);
}};
$e3469734698.stack[R.EXN_STACKHEIGHT++] = $ss3470134702;
}
if(R.isPyretException($e3469734698)) {
$e3469734698.pyretStack.push(L[2219]);
}
throw $e3469734698;
}
var $ret3470334704 = $Hann_DASH_check_DASH_temp968734708($z3469934700);
++R.GAS;
return $ret3470334704;
};
var $Hann_DASH_check_DASH_temp968734708 = function(ann_DASH_check_DASH_temp362034707) {
return ann_DASH_check_DASH_temp362034707;
};
var $Hcont_tail_arg968513117 = function(cont_tail_arg361713115,if_helper360313116) {
if(--R.GAS > 0) {
$z3470934710 = R.isFunction(if_helper360313116)?if_helper360313116.app(cont_tail_arg361713115):R.ffi.throwNonFunApp(L[2219],if_helper360313116,[cont_tail_arg361713115]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper360313116)?if_helper360313116.app(cont_tail_arg361713115):R.ffi.throwNonFunApp(L[2219],if_helper360313116,[cont_tail_arg361713115]);
},
"from":L[2219]});
}
++R.GAS;
return $z3470934710;
};
var $Hcont_tail_arg968613132 = function(cont_tail_arg360813131,if_helper360313116) {
if(--R.GAS > 0) {
$z3471134712 = R.isFunction(if_helper360313116)?if_helper360313116.app(cont_tail_arg360813131):R.ffi.throwNonFunApp(L[2219],if_helper360313116,[cont_tail_arg360813131]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper360313116)?if_helper360313116.app(cont_tail_arg360813131):R.ffi.throwNonFunApp(L[2219],if_helper360313116,[cont_tail_arg360813131]);
},
"from":L[2219]});
}
++R.GAS;
return $z3471134712;
};
var $Hanf_arg968413154 = function(anf_arg359313151,INDENT118169,PP170,anf_fun359013152,self93713153,str_DASH_period160702) {
var anf_fun359434726 = G(PP170,"surround",L[4340]);
var anf_arg359534725 = G(PP170,"lbrack",L[4339]);
var anf_bracket359634728 = G(self93713153,"field",L[4338]);
var anf_fun359734723 = G(anf_bracket359634728,"tosource",L[4337]);
var $z3471534716 = D;
var $f3472134722 = function(_) {
return R.isFunction(anf_fun359734723)?anf_fun359734723.app():R.ffi.throwNonFunApp(L[4336],anf_fun359734723,[]);
};
try {
if(--R.GAS > 0) {
$z3471534716 = $f3472134722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3472134722,
"from":L[4336]});
}
} catch($e3471334714) {
if(R.isCont($e3471334714)) {
var $ss3471734718 = {"from":L[4336],
"go":function(anf_arg359834724) {
return $Hanf_arg968334727(anf_arg359834724,INDENT118169,PP170,anf_arg359313151,anf_arg359534725,anf_fun359013152,anf_fun359434726,str_DASH_period160702);
}};
$e3471334714.stack[R.EXN_STACKHEIGHT++] = $ss3471734718;
}
if(R.isPyretException($e3471334714)) {
$e3471334714.pyretStack.push(L[4336]);
}
throw $e3471334714;
}
var $ret3471934720 = $Hanf_arg968334727($z3471534716,INDENT118169,PP170,anf_arg359313151,anf_arg359534725,anf_fun359013152,anf_fun359434726,str_DASH_period160702);
++R.GAS;
return $ret3471934720;
};
var $Hanf_arg968334727 = function(anf_arg359834724,INDENT118169,PP170,anf_arg359313151,anf_arg359534725,anf_fun359013152,anf_fun359434726,str_DASH_period160702) {
var anf_arg359934739 = G(PP170,"rbrack",L[4342]);
var $z3473134732 = D;
var $f3473734738 = function(_) {
return R.isFunction(anf_fun359434726)?anf_fun359434726.app(INDENT118169,(0),anf_arg359534725,anf_arg359834724,anf_arg359934739):R.ffi.throwNonFunApp(L[4341],anf_fun359434726,[INDENT118169,(0),anf_arg359534725,anf_arg359834724,anf_arg359934739]);
};
try {
if(--R.GAS > 0) {
$z3473134732 = $f3473734738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3473734738,
"from":L[4341]});
}
} catch($e3472934730) {
if(R.isCont($e3472934730)) {
var $ss3473334734 = {"from":L[4341],
"go":function(anf_arg360034740) {
return $Hanf_arg968234741(anf_arg360034740,INDENT118169,anf_arg359313151,anf_fun359013152,str_DASH_period160702);
}};
$e3472934730.stack[R.EXN_STACKHEIGHT++] = $ss3473334734;
}
if(R.isPyretException($e3472934730)) {
$e3472934730.pyretStack.push(L[4341]);
}
throw $e3472934730;
}
var $ret3473534736 = $Hanf_arg968234741($z3473134732,INDENT118169,anf_arg359313151,anf_fun359013152,str_DASH_period160702);
++R.GAS;
return $ret3473534736;
};
var $Hanf_arg968234741 = function(anf_arg360034740,INDENT118169,anf_arg359313151,anf_fun359013152,str_DASH_period160702) {
var $z3474434745 = D;
var $f3475034751 = function(_) {
return R.isFunction(anf_fun359013152)?anf_fun359013152.app(INDENT118169,(0),str_DASH_period160702,anf_arg359313151,anf_arg360034740):R.ffi.throwNonFunApp(L[2578],anf_fun359013152,[INDENT118169,(0),str_DASH_period160702,anf_arg359313151,anf_arg360034740]);
};
try {
if(--R.GAS > 0) {
$z3474434745 = $f3475034751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3475034751,
"from":L[2578]});
}
} catch($e3474234743) {
if(R.isCont($e3474234743)) {
var $ss3474634747 = {"from":L[2578],
"go":function(ann_DASH_check_DASH_temp358934752) {
return $Hann_DASH_check_DASH_temp968134753(ann_DASH_check_DASH_temp358934752);
}};
$e3474234743.stack[R.EXN_STACKHEIGHT++] = $ss3474634747;
}
if(R.isPyretException($e3474234743)) {
$e3474234743.pyretStack.push(L[2578]);
}
throw $e3474234743;
}
var $ret3474834749 = $Hann_DASH_check_DASH_temp968134753($z3474434745);
++R.GAS;
return $ret3474834749;
};
var $Hann_DASH_check_DASH_temp968134753 = function(ann_DASH_check_DASH_temp358934752) {
return ann_DASH_check_DASH_temp358934752;
};
var $Hanf_arg968013171 = function(anf_arg357513169,self47913170,_plus55,torepr65) {
var anf_arg357634764 = G(self47913170,"obj",L[2220]);
var $z3475634757 = D;
var $f3476234763 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg357634764):R.ffi.throwNonFunApp(L[2220],torepr65,[anf_arg357634764]);
};
try {
if(--R.GAS > 0) {
$z3475634757 = $f3476234763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3476234763,
"from":L[2220]});
}
} catch($e3475434755) {
if(R.isCont($e3475434755)) {
var $ss3475834759 = {"from":L[2220],
"go":function(anf_arg357734765) {
return $Hanf_arg967934766(anf_arg357734765,anf_arg357513169,self47913170,_plus55,torepr65);
}};
$e3475434755.stack[R.EXN_STACKHEIGHT++] = $ss3475834759;
}
if(R.isPyretException($e3475434755)) {
$e3475434755.pyretStack.push(L[2220]);
}
throw $e3475434755;
}
var $ret3476034761 = $Hanf_arg967934766($z3475634757,anf_arg357513169,self47913170,_plus55,torepr65);
++R.GAS;
return $ret3476034761;
};
var $Hanf_arg967934766 = function(anf_arg357734765,anf_arg357513169,self47913170,_plus55,torepr65) {
var $z3476934770 = D;
var $f3477534776 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg357734765):R.ffi.throwNonFunApp(L[2220],_plus55,[(", "),anf_arg357734765]);
};
try {
if(--R.GAS > 0) {
$z3476934770 = $f3477534776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3477534776,
"from":L[2220]});
}
} catch($e3476734768) {
if(R.isCont($e3476734768)) {
var $ss3477134772 = {"from":L[2220],
"go":function(anf_arg357834777) {
return $Hanf_arg967834778(anf_arg357834777,anf_arg357513169,self47913170,_plus55,torepr65);
}};
$e3476734768.stack[R.EXN_STACKHEIGHT++] = $ss3477134772;
}
if(R.isPyretException($e3476734768)) {
$e3476734768.pyretStack.push(L[2220]);
}
throw $e3476734768;
}
var $ret3477334774 = $Hanf_arg967834778($z3476934770,anf_arg357513169,self47913170,_plus55,torepr65);
++R.GAS;
return $ret3477334774;
};
var $Hanf_arg967834778 = function(anf_arg357834777,anf_arg357513169,self47913170,_plus55,torepr65) {
var $z3478134782 = D;
var $f3478734788 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg357513169,anf_arg357834777):R.ffi.throwNonFunApp(L[2220],_plus55,[anf_arg357513169,anf_arg357834777]);
};
try {
if(--R.GAS > 0) {
$z3478134782 = $f3478734788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3478734788,
"from":L[2220]});
}
} catch($e3477934780) {
if(R.isCont($e3477934780)) {
var $ss3478334784 = {"from":L[2220],
"go":function(anf_arg357934789) {
return $Hanf_arg967734790(anf_arg357934789,self47913170,_plus55,torepr65);
}};
$e3477934780.stack[R.EXN_STACKHEIGHT++] = $ss3478334784;
}
if(R.isPyretException($e3477934780)) {
$e3477934780.pyretStack.push(L[2220]);
}
throw $e3477934780;
}
var $ret3478534786 = $Hanf_arg967734790($z3478134782,self47913170,_plus55,torepr65);
++R.GAS;
return $ret3478534786;
};
var $Hanf_arg967734790 = function(anf_arg357934789,self47913170,_plus55,torepr65) {
var anf_arg358034801 = G(self47913170,"field",L[2220]);
var $z3479334794 = D;
var $f3479934800 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg358034801):R.ffi.throwNonFunApp(L[2220],torepr65,[anf_arg358034801]);
};
try {
if(--R.GAS > 0) {
$z3479334794 = $f3479934800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3479934800,
"from":L[2220]});
}
} catch($e3479134792) {
if(R.isCont($e3479134792)) {
var $ss3479534796 = {"from":L[2220],
"go":function(anf_arg358134802) {
return $Hanf_arg967634803(anf_arg358134802,anf_arg357934789,_plus55);
}};
$e3479134792.stack[R.EXN_STACKHEIGHT++] = $ss3479534796;
}
if(R.isPyretException($e3479134792)) {
$e3479134792.pyretStack.push(L[2220]);
}
throw $e3479134792;
}
var $ret3479734798 = $Hanf_arg967634803($z3479334794,anf_arg357934789,_plus55);
++R.GAS;
return $ret3479734798;
};
var $Hanf_arg967634803 = function(anf_arg358134802,anf_arg357934789,_plus55) {
var $z3480634807 = D;
var $f3481234813 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg358134802):R.ffi.throwNonFunApp(L[2220],_plus55,[(", "),anf_arg358134802]);
};
try {
if(--R.GAS > 0) {
$z3480634807 = $f3481234813();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3481234813,
"from":L[2220]});
}
} catch($e3480434805) {
if(R.isCont($e3480434805)) {
var $ss3480834809 = {"from":L[2220],
"go":function(anf_arg358234814) {
return $Hanf_arg967534815(anf_arg358234814,anf_arg357934789,_plus55);
}};
$e3480434805.stack[R.EXN_STACKHEIGHT++] = $ss3480834809;
}
if(R.isPyretException($e3480434805)) {
$e3480434805.pyretStack.push(L[2220]);
}
throw $e3480434805;
}
var $ret3481034811 = $Hanf_arg967534815($z3480634807,anf_arg357934789,_plus55);
++R.GAS;
return $ret3481034811;
};
var $Hanf_arg967534815 = function(anf_arg358234814,anf_arg357934789,_plus55) {
var $z3481834819 = D;
var $f3482434825 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg357934789,anf_arg358234814):R.ffi.throwNonFunApp(L[2220],_plus55,[anf_arg357934789,anf_arg358234814]);
};
try {
if(--R.GAS > 0) {
$z3481834819 = $f3482434825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3482434825,
"from":L[2220]});
}
} catch($e3481634817) {
if(R.isCont($e3481634817)) {
var $ss3482034821 = {"from":L[2220],
"go":function(anf_arg358334826) {
return $Hanf_arg967434827(anf_arg358334826,_plus55);
}};
$e3481634817.stack[R.EXN_STACKHEIGHT++] = $ss3482034821;
}
if(R.isPyretException($e3481634817)) {
$e3481634817.pyretStack.push(L[2220]);
}
throw $e3481634817;
}
var $ret3482234823 = $Hanf_arg967434827($z3481834819,_plus55);
++R.GAS;
return $ret3482234823;
};
var $Hanf_arg967434827 = function(anf_arg358334826,_plus55) {
var $z3483034831 = D;
var $f3483634837 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg358334826,(")")):R.ffi.throwNonFunApp(L[2220],_plus55,[anf_arg358334826,(")")]);
};
try {
if(--R.GAS > 0) {
$z3483034831 = $f3483634837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3483634837,
"from":L[2220]});
}
} catch($e3482834829) {
if(R.isCont($e3482834829)) {
var $ss3483234833 = {"from":L[2220],
"go":function(anf_arg358434838) {
return $Hanf_arg967334839(anf_arg358434838,_plus55);
}};
$e3482834829.stack[R.EXN_STACKHEIGHT++] = $ss3483234833;
}
if(R.isPyretException($e3482834829)) {
$e3482834829.pyretStack.push(L[2220]);
}
throw $e3482834829;
}
var $ret3483434835 = $Hanf_arg967334839($z3483034831,_plus55);
++R.GAS;
return $ret3483434835;
};
var $Hanf_arg967334839 = function(anf_arg358434838,_plus55) {
var $z3484234843 = D;
var $f3484834849 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg358434838):R.ffi.throwNonFunApp(L[2220],_plus55,[("("),anf_arg358434838]);
};
try {
if(--R.GAS > 0) {
$z3484234843 = $f3484834849();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3484834849,
"from":L[2220]});
}
} catch($e3484034841) {
if(R.isCont($e3484034841)) {
var $ss3484434845 = {"from":L[2220],
"go":function(anf_arg358534850) {
return $Hanf_arg967234851(anf_arg358534850,_plus55);
}};
$e3484034841.stack[R.EXN_STACKHEIGHT++] = $ss3484434845;
}
if(R.isPyretException($e3484034841)) {
$e3484034841.pyretStack.push(L[2220]);
}
throw $e3484034841;
}
var $ret3484634847 = $Hanf_arg967234851($z3484234843,_plus55);
++R.GAS;
return $ret3484634847;
};
var $Hanf_arg967234851 = function(anf_arg358534850,_plus55) {
var $z3485434855 = D;
var $f3486034861 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-bracket"),anf_arg358534850):R.ffi.throwNonFunApp(L[2220],_plus55,[("s-bracket"),anf_arg358534850]);
};
try {
if(--R.GAS > 0) {
$z3485434855 = $f3486034861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3486034861,
"from":L[2220]});
}
} catch($e3485234853) {
if(R.isCont($e3485234853)) {
var $ss3485634857 = {"from":L[2220],
"go":function(ann_DASH_check_DASH_temp357334862) {
return $Hann_DASH_check_DASH_temp967134863(ann_DASH_check_DASH_temp357334862);
}};
$e3485234853.stack[R.EXN_STACKHEIGHT++] = $ss3485634857;
}
if(R.isPyretException($e3485234853)) {
$e3485234853.pyretStack.push(L[2220]);
}
throw $e3485234853;
}
var $ret3485834859 = $Hann_DASH_check_DASH_temp967134863($z3485434855);
++R.GAS;
return $ret3485834859;
};
var $Hann_DASH_check_DASH_temp967134863 = function(ann_DASH_check_DASH_temp357334862) {
return ann_DASH_check_DASH_temp357334862;
};
var $Hcont_tail_arg966913188 = function(cont_tail_arg357013186,if_helper356013187) {
if(--R.GAS > 0) {
$z3486434865 = R.isFunction(if_helper356013187)?if_helper356013187.app(cont_tail_arg357013186):R.ffi.throwNonFunApp(L[2220],if_helper356013187,[cont_tail_arg357013186]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper356013187)?if_helper356013187.app(cont_tail_arg357013186):R.ffi.throwNonFunApp(L[2220],if_helper356013187,[cont_tail_arg357013186]);
},
"from":L[2220]});
}
++R.GAS;
return $z3486434865;
};
var $Hcont_tail_arg967013203 = function(cont_tail_arg356513202,if_helper356013187) {
if(--R.GAS > 0) {
$z3486634867 = R.isFunction(if_helper356013187)?if_helper356013187.app(cont_tail_arg356513202):R.ffi.throwNonFunApp(L[2220],if_helper356013187,[cont_tail_arg356513202]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper356013187)?if_helper356013187.app(cont_tail_arg356513202):R.ffi.throwNonFunApp(L[2220],if_helper356013187,[cont_tail_arg356513202]);
},
"from":L[2220]});
}
++R.GAS;
return $z3486634867;
};
var $Hanf_arg966813225 = function(anf_arg355413222,INDENT118169,PP170,anf_fun355113223,self93213224,str_DASH_bang161715) {
var anf_fun355534878 = G(PP170,"str",L[4345]);
var anf_arg355634879 = G(self93213224,"field",L[4344]);
var $z3487034871 = D;
var $f3487634877 = function(_) {
return R.isFunction(anf_fun355534878)?anf_fun355534878.app(anf_arg355634879):R.ffi.throwNonFunApp(L[4343],anf_fun355534878,[anf_arg355634879]);
};
try {
if(--R.GAS > 0) {
$z3487034871 = $f3487634877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3487634877,
"from":L[4343]});
}
} catch($e3486834869) {
if(R.isCont($e3486834869)) {
var $ss3487234873 = {"from":L[4343],
"go":function(anf_arg355734880) {
return $Hanf_arg966734881(anf_arg355734880,INDENT118169,anf_arg355413222,anf_fun355113223,str_DASH_bang161715);
}};
$e3486834869.stack[R.EXN_STACKHEIGHT++] = $ss3487234873;
}
if(R.isPyretException($e3486834869)) {
$e3486834869.pyretStack.push(L[4343]);
}
throw $e3486834869;
}
var $ret3487434875 = $Hanf_arg966734881($z3487034871,INDENT118169,anf_arg355413222,anf_fun355113223,str_DASH_bang161715);
++R.GAS;
return $ret3487434875;
};
var $Hanf_arg966734881 = function(anf_arg355734880,INDENT118169,anf_arg355413222,anf_fun355113223,str_DASH_bang161715) {
var $z3488434885 = D;
var $f3489034891 = function(_) {
return R.isFunction(anf_fun355113223)?anf_fun355113223.app(INDENT118169,(0),str_DASH_bang161715,anf_arg355413222,anf_arg355734880):R.ffi.throwNonFunApp(L[2587],anf_fun355113223,[INDENT118169,(0),str_DASH_bang161715,anf_arg355413222,anf_arg355734880]);
};
try {
if(--R.GAS > 0) {
$z3488434885 = $f3489034891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3489034891,
"from":L[2587]});
}
} catch($e3488234883) {
if(R.isCont($e3488234883)) {
var $ss3488634887 = {"from":L[2587],
"go":function(ann_DASH_check_DASH_temp355034892) {
return $Hann_DASH_check_DASH_temp966634893(ann_DASH_check_DASH_temp355034892);
}};
$e3488234883.stack[R.EXN_STACKHEIGHT++] = $ss3488634887;
}
if(R.isPyretException($e3488234883)) {
$e3488234883.pyretStack.push(L[2587]);
}
throw $e3488234883;
}
var $ret3488834889 = $Hann_DASH_check_DASH_temp966634893($z3488434885);
++R.GAS;
return $ret3488834889;
};
var $Hann_DASH_check_DASH_temp966634893 = function(ann_DASH_check_DASH_temp355034892) {
return ann_DASH_check_DASH_temp355034892;
};
var $Hanf_arg966513242 = function(anf_arg353613240,self47313241,_plus55,torepr65) {
var anf_arg353734904 = G(self47313241,"obj",L[2221]);
var $z3489634897 = D;
var $f3490234903 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg353734904):R.ffi.throwNonFunApp(L[2221],torepr65,[anf_arg353734904]);
};
try {
if(--R.GAS > 0) {
$z3489634897 = $f3490234903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3490234903,
"from":L[2221]});
}
} catch($e3489434895) {
if(R.isCont($e3489434895)) {
var $ss3489834899 = {"from":L[2221],
"go":function(anf_arg353834905) {
return $Hanf_arg966434906(anf_arg353834905,anf_arg353613240,self47313241,_plus55,torepr65);
}};
$e3489434895.stack[R.EXN_STACKHEIGHT++] = $ss3489834899;
}
if(R.isPyretException($e3489434895)) {
$e3489434895.pyretStack.push(L[2221]);
}
throw $e3489434895;
}
var $ret3490034901 = $Hanf_arg966434906($z3489634897,anf_arg353613240,self47313241,_plus55,torepr65);
++R.GAS;
return $ret3490034901;
};
var $Hanf_arg966434906 = function(anf_arg353834905,anf_arg353613240,self47313241,_plus55,torepr65) {
var $z3490934910 = D;
var $f3491534916 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg353834905):R.ffi.throwNonFunApp(L[2221],_plus55,[(", "),anf_arg353834905]);
};
try {
if(--R.GAS > 0) {
$z3490934910 = $f3491534916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3491534916,
"from":L[2221]});
}
} catch($e3490734908) {
if(R.isCont($e3490734908)) {
var $ss3491134912 = {"from":L[2221],
"go":function(anf_arg353934917) {
return $Hanf_arg966334918(anf_arg353934917,anf_arg353613240,self47313241,_plus55,torepr65);
}};
$e3490734908.stack[R.EXN_STACKHEIGHT++] = $ss3491134912;
}
if(R.isPyretException($e3490734908)) {
$e3490734908.pyretStack.push(L[2221]);
}
throw $e3490734908;
}
var $ret3491334914 = $Hanf_arg966334918($z3490934910,anf_arg353613240,self47313241,_plus55,torepr65);
++R.GAS;
return $ret3491334914;
};
var $Hanf_arg966334918 = function(anf_arg353934917,anf_arg353613240,self47313241,_plus55,torepr65) {
var $z3492134922 = D;
var $f3492734928 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg353613240,anf_arg353934917):R.ffi.throwNonFunApp(L[2221],_plus55,[anf_arg353613240,anf_arg353934917]);
};
try {
if(--R.GAS > 0) {
$z3492134922 = $f3492734928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3492734928,
"from":L[2221]});
}
} catch($e3491934920) {
if(R.isCont($e3491934920)) {
var $ss3492334924 = {"from":L[2221],
"go":function(anf_arg354034929) {
return $Hanf_arg966234930(anf_arg354034929,self47313241,_plus55,torepr65);
}};
$e3491934920.stack[R.EXN_STACKHEIGHT++] = $ss3492334924;
}
if(R.isPyretException($e3491934920)) {
$e3491934920.pyretStack.push(L[2221]);
}
throw $e3491934920;
}
var $ret3492534926 = $Hanf_arg966234930($z3492134922,self47313241,_plus55,torepr65);
++R.GAS;
return $ret3492534926;
};
var $Hanf_arg966234930 = function(anf_arg354034929,self47313241,_plus55,torepr65) {
var anf_arg354134941 = G(self47313241,"field",L[2221]);
var $z3493334934 = D;
var $f3493934940 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg354134941):R.ffi.throwNonFunApp(L[2221],torepr65,[anf_arg354134941]);
};
try {
if(--R.GAS > 0) {
$z3493334934 = $f3493934940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3493934940,
"from":L[2221]});
}
} catch($e3493134932) {
if(R.isCont($e3493134932)) {
var $ss3493534936 = {"from":L[2221],
"go":function(anf_arg354234942) {
return $Hanf_arg966134943(anf_arg354234942,anf_arg354034929,_plus55);
}};
$e3493134932.stack[R.EXN_STACKHEIGHT++] = $ss3493534936;
}
if(R.isPyretException($e3493134932)) {
$e3493134932.pyretStack.push(L[2221]);
}
throw $e3493134932;
}
var $ret3493734938 = $Hanf_arg966134943($z3493334934,anf_arg354034929,_plus55);
++R.GAS;
return $ret3493734938;
};
var $Hanf_arg966134943 = function(anf_arg354234942,anf_arg354034929,_plus55) {
var $z3494634947 = D;
var $f3495234953 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg354234942):R.ffi.throwNonFunApp(L[2221],_plus55,[(", "),anf_arg354234942]);
};
try {
if(--R.GAS > 0) {
$z3494634947 = $f3495234953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3495234953,
"from":L[2221]});
}
} catch($e3494434945) {
if(R.isCont($e3494434945)) {
var $ss3494834949 = {"from":L[2221],
"go":function(anf_arg354334954) {
return $Hanf_arg966034955(anf_arg354334954,anf_arg354034929,_plus55);
}};
$e3494434945.stack[R.EXN_STACKHEIGHT++] = $ss3494834949;
}
if(R.isPyretException($e3494434945)) {
$e3494434945.pyretStack.push(L[2221]);
}
throw $e3494434945;
}
var $ret3495034951 = $Hanf_arg966034955($z3494634947,anf_arg354034929,_plus55);
++R.GAS;
return $ret3495034951;
};
var $Hanf_arg966034955 = function(anf_arg354334954,anf_arg354034929,_plus55) {
var $z3495834959 = D;
var $f3496434965 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg354034929,anf_arg354334954):R.ffi.throwNonFunApp(L[2221],_plus55,[anf_arg354034929,anf_arg354334954]);
};
try {
if(--R.GAS > 0) {
$z3495834959 = $f3496434965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3496434965,
"from":L[2221]});
}
} catch($e3495634957) {
if(R.isCont($e3495634957)) {
var $ss3496034961 = {"from":L[2221],
"go":function(anf_arg354434966) {
return $Hanf_arg965934967(anf_arg354434966,_plus55);
}};
$e3495634957.stack[R.EXN_STACKHEIGHT++] = $ss3496034961;
}
if(R.isPyretException($e3495634957)) {
$e3495634957.pyretStack.push(L[2221]);
}
throw $e3495634957;
}
var $ret3496234963 = $Hanf_arg965934967($z3495834959,_plus55);
++R.GAS;
return $ret3496234963;
};
var $Hanf_arg965934967 = function(anf_arg354434966,_plus55) {
var $z3497034971 = D;
var $f3497634977 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg354434966,(")")):R.ffi.throwNonFunApp(L[2221],_plus55,[anf_arg354434966,(")")]);
};
try {
if(--R.GAS > 0) {
$z3497034971 = $f3497634977();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3497634977,
"from":L[2221]});
}
} catch($e3496834969) {
if(R.isCont($e3496834969)) {
var $ss3497234973 = {"from":L[2221],
"go":function(anf_arg354534978) {
return $Hanf_arg965834979(anf_arg354534978,_plus55);
}};
$e3496834969.stack[R.EXN_STACKHEIGHT++] = $ss3497234973;
}
if(R.isPyretException($e3496834969)) {
$e3496834969.pyretStack.push(L[2221]);
}
throw $e3496834969;
}
var $ret3497434975 = $Hanf_arg965834979($z3497034971,_plus55);
++R.GAS;
return $ret3497434975;
};
var $Hanf_arg965834979 = function(anf_arg354534978,_plus55) {
var $z3498234983 = D;
var $f3498834989 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg354534978):R.ffi.throwNonFunApp(L[2221],_plus55,[("("),anf_arg354534978]);
};
try {
if(--R.GAS > 0) {
$z3498234983 = $f3498834989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3498834989,
"from":L[2221]});
}
} catch($e3498034981) {
if(R.isCont($e3498034981)) {
var $ss3498434985 = {"from":L[2221],
"go":function(anf_arg354634990) {
return $Hanf_arg965734991(anf_arg354634990,_plus55);
}};
$e3498034981.stack[R.EXN_STACKHEIGHT++] = $ss3498434985;
}
if(R.isPyretException($e3498034981)) {
$e3498034981.pyretStack.push(L[2221]);
}
throw $e3498034981;
}
var $ret3498634987 = $Hanf_arg965734991($z3498234983,_plus55);
++R.GAS;
return $ret3498634987;
};
var $Hanf_arg965734991 = function(anf_arg354634990,_plus55) {
var $z3499434995 = D;
var $f3500035001 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-get-bang"),anf_arg354634990):R.ffi.throwNonFunApp(L[2221],_plus55,[("s-get-bang"),anf_arg354634990]);
};
try {
if(--R.GAS > 0) {
$z3499434995 = $f3500035001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3500035001,
"from":L[2221]});
}
} catch($e3499234993) {
if(R.isCont($e3499234993)) {
var $ss3499634997 = {"from":L[2221],
"go":function(ann_DASH_check_DASH_temp353435002) {
return $Hann_DASH_check_DASH_temp965635003(ann_DASH_check_DASH_temp353435002);
}};
$e3499234993.stack[R.EXN_STACKHEIGHT++] = $ss3499634997;
}
if(R.isPyretException($e3499234993)) {
$e3499234993.pyretStack.push(L[2221]);
}
throw $e3499234993;
}
var $ret3499834999 = $Hann_DASH_check_DASH_temp965635003($z3499434995);
++R.GAS;
return $ret3499834999;
};
var $Hann_DASH_check_DASH_temp965635003 = function(ann_DASH_check_DASH_temp353435002) {
return ann_DASH_check_DASH_temp353435002;
};
var $Hcont_tail_arg965413259 = function(cont_tail_arg353113257,if_helper352113258) {
if(--R.GAS > 0) {
$z3500435005 = R.isFunction(if_helper352113258)?if_helper352113258.app(cont_tail_arg353113257):R.ffi.throwNonFunApp(L[2221],if_helper352113258,[cont_tail_arg353113257]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper352113258)?if_helper352113258.app(cont_tail_arg353113257):R.ffi.throwNonFunApp(L[2221],if_helper352113258,[cont_tail_arg353113257]);
},
"from":L[2221]});
}
++R.GAS;
return $z3500435005;
};
var $Hcont_tail_arg965513274 = function(cont_tail_arg352613273,if_helper352113258) {
if(--R.GAS > 0) {
$z3500635007 = R.isFunction(if_helper352113258)?if_helper352113258.app(cont_tail_arg352613273):R.ffi.throwNonFunApp(L[2221],if_helper352113258,[cont_tail_arg352613273]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper352113258)?if_helper352113258.app(cont_tail_arg352613273):R.ffi.throwNonFunApp(L[2221],if_helper352113258,[cont_tail_arg352613273]);
},
"from":L[2221]});
}
++R.GAS;
return $z3500635007;
};
var $Hanf_arg965313296 = function(anf_arg351513293,INDENT118169,PP170,anf_fun351213294,self92713295,str_DASH_period160702) {
var anf_fun351635018 = G(PP170,"str",L[4348]);
var anf_arg351735019 = G(self92713295,"field",L[4347]);
var $z3501035011 = D;
var $f3501635017 = function(_) {
return R.isFunction(anf_fun351635018)?anf_fun351635018.app(anf_arg351735019):R.ffi.throwNonFunApp(L[4346],anf_fun351635018,[anf_arg351735019]);
};
try {
if(--R.GAS > 0) {
$z3501035011 = $f3501635017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3501635017,
"from":L[4346]});
}
} catch($e3500835009) {
if(R.isCont($e3500835009)) {
var $ss3501235013 = {"from":L[4346],
"go":function(anf_arg351835020) {
return $Hanf_arg965235021(anf_arg351835020,INDENT118169,anf_arg351513293,anf_fun351213294,str_DASH_period160702);
}};
$e3500835009.stack[R.EXN_STACKHEIGHT++] = $ss3501235013;
}
if(R.isPyretException($e3500835009)) {
$e3500835009.pyretStack.push(L[4346]);
}
throw $e3500835009;
}
var $ret3501435015 = $Hanf_arg965235021($z3501035011,INDENT118169,anf_arg351513293,anf_fun351213294,str_DASH_period160702);
++R.GAS;
return $ret3501435015;
};
var $Hanf_arg965235021 = function(anf_arg351835020,INDENT118169,anf_arg351513293,anf_fun351213294,str_DASH_period160702) {
var $z3502435025 = D;
var $f3503035031 = function(_) {
return R.isFunction(anf_fun351213294)?anf_fun351213294.app(INDENT118169,(0),str_DASH_period160702,anf_arg351513293,anf_arg351835020):R.ffi.throwNonFunApp(L[2596],anf_fun351213294,[INDENT118169,(0),str_DASH_period160702,anf_arg351513293,anf_arg351835020]);
};
try {
if(--R.GAS > 0) {
$z3502435025 = $f3503035031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3503035031,
"from":L[2596]});
}
} catch($e3502235023) {
if(R.isCont($e3502235023)) {
var $ss3502635027 = {"from":L[2596],
"go":function(ann_DASH_check_DASH_temp351135032) {
return $Hann_DASH_check_DASH_temp965135033(ann_DASH_check_DASH_temp351135032);
}};
$e3502235023.stack[R.EXN_STACKHEIGHT++] = $ss3502635027;
}
if(R.isPyretException($e3502235023)) {
$e3502235023.pyretStack.push(L[2596]);
}
throw $e3502235023;
}
var $ret3502835029 = $Hann_DASH_check_DASH_temp965135033($z3502435025);
++R.GAS;
return $ret3502835029;
};
var $Hann_DASH_check_DASH_temp965135033 = function(ann_DASH_check_DASH_temp351135032) {
return ann_DASH_check_DASH_temp351135032;
};
var $Hanf_arg965013313 = function(anf_arg349713311,self46713312,_plus55,torepr65) {
var anf_arg349835044 = G(self46713312,"obj",L[2222]);
var $z3503635037 = D;
var $f3504235043 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg349835044):R.ffi.throwNonFunApp(L[2222],torepr65,[anf_arg349835044]);
};
try {
if(--R.GAS > 0) {
$z3503635037 = $f3504235043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3504235043,
"from":L[2222]});
}
} catch($e3503435035) {
if(R.isCont($e3503435035)) {
var $ss3503835039 = {"from":L[2222],
"go":function(anf_arg349935045) {
return $Hanf_arg964935046(anf_arg349935045,anf_arg349713311,self46713312,_plus55,torepr65);
}};
$e3503435035.stack[R.EXN_STACKHEIGHT++] = $ss3503835039;
}
if(R.isPyretException($e3503435035)) {
$e3503435035.pyretStack.push(L[2222]);
}
throw $e3503435035;
}
var $ret3504035041 = $Hanf_arg964935046($z3503635037,anf_arg349713311,self46713312,_plus55,torepr65);
++R.GAS;
return $ret3504035041;
};
var $Hanf_arg964935046 = function(anf_arg349935045,anf_arg349713311,self46713312,_plus55,torepr65) {
var $z3504935050 = D;
var $f3505535056 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg349935045):R.ffi.throwNonFunApp(L[2222],_plus55,[(", "),anf_arg349935045]);
};
try {
if(--R.GAS > 0) {
$z3504935050 = $f3505535056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3505535056,
"from":L[2222]});
}
} catch($e3504735048) {
if(R.isCont($e3504735048)) {
var $ss3505135052 = {"from":L[2222],
"go":function(anf_arg350035057) {
return $Hanf_arg964835058(anf_arg350035057,anf_arg349713311,self46713312,_plus55,torepr65);
}};
$e3504735048.stack[R.EXN_STACKHEIGHT++] = $ss3505135052;
}
if(R.isPyretException($e3504735048)) {
$e3504735048.pyretStack.push(L[2222]);
}
throw $e3504735048;
}
var $ret3505335054 = $Hanf_arg964835058($z3504935050,anf_arg349713311,self46713312,_plus55,torepr65);
++R.GAS;
return $ret3505335054;
};
var $Hanf_arg964835058 = function(anf_arg350035057,anf_arg349713311,self46713312,_plus55,torepr65) {
var $z3506135062 = D;
var $f3506735068 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg349713311,anf_arg350035057):R.ffi.throwNonFunApp(L[2222],_plus55,[anf_arg349713311,anf_arg350035057]);
};
try {
if(--R.GAS > 0) {
$z3506135062 = $f3506735068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3506735068,
"from":L[2222]});
}
} catch($e3505935060) {
if(R.isCont($e3505935060)) {
var $ss3506335064 = {"from":L[2222],
"go":function(anf_arg350135069) {
return $Hanf_arg964735070(anf_arg350135069,self46713312,_plus55,torepr65);
}};
$e3505935060.stack[R.EXN_STACKHEIGHT++] = $ss3506335064;
}
if(R.isPyretException($e3505935060)) {
$e3505935060.pyretStack.push(L[2222]);
}
throw $e3505935060;
}
var $ret3506535066 = $Hanf_arg964735070($z3506135062,self46713312,_plus55,torepr65);
++R.GAS;
return $ret3506535066;
};
var $Hanf_arg964735070 = function(anf_arg350135069,self46713312,_plus55,torepr65) {
var anf_arg350235081 = G(self46713312,"field",L[2222]);
var $z3507335074 = D;
var $f3507935080 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg350235081):R.ffi.throwNonFunApp(L[2222],torepr65,[anf_arg350235081]);
};
try {
if(--R.GAS > 0) {
$z3507335074 = $f3507935080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3507935080,
"from":L[2222]});
}
} catch($e3507135072) {
if(R.isCont($e3507135072)) {
var $ss3507535076 = {"from":L[2222],
"go":function(anf_arg350335082) {
return $Hanf_arg964635083(anf_arg350335082,anf_arg350135069,_plus55);
}};
$e3507135072.stack[R.EXN_STACKHEIGHT++] = $ss3507535076;
}
if(R.isPyretException($e3507135072)) {
$e3507135072.pyretStack.push(L[2222]);
}
throw $e3507135072;
}
var $ret3507735078 = $Hanf_arg964635083($z3507335074,anf_arg350135069,_plus55);
++R.GAS;
return $ret3507735078;
};
var $Hanf_arg964635083 = function(anf_arg350335082,anf_arg350135069,_plus55) {
var $z3508635087 = D;
var $f3509235093 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg350335082):R.ffi.throwNonFunApp(L[2222],_plus55,[(", "),anf_arg350335082]);
};
try {
if(--R.GAS > 0) {
$z3508635087 = $f3509235093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3509235093,
"from":L[2222]});
}
} catch($e3508435085) {
if(R.isCont($e3508435085)) {
var $ss3508835089 = {"from":L[2222],
"go":function(anf_arg350435094) {
return $Hanf_arg964535095(anf_arg350435094,anf_arg350135069,_plus55);
}};
$e3508435085.stack[R.EXN_STACKHEIGHT++] = $ss3508835089;
}
if(R.isPyretException($e3508435085)) {
$e3508435085.pyretStack.push(L[2222]);
}
throw $e3508435085;
}
var $ret3509035091 = $Hanf_arg964535095($z3508635087,anf_arg350135069,_plus55);
++R.GAS;
return $ret3509035091;
};
var $Hanf_arg964535095 = function(anf_arg350435094,anf_arg350135069,_plus55) {
var $z3509835099 = D;
var $f3510435105 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg350135069,anf_arg350435094):R.ffi.throwNonFunApp(L[2222],_plus55,[anf_arg350135069,anf_arg350435094]);
};
try {
if(--R.GAS > 0) {
$z3509835099 = $f3510435105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3510435105,
"from":L[2222]});
}
} catch($e3509635097) {
if(R.isCont($e3509635097)) {
var $ss3510035101 = {"from":L[2222],
"go":function(anf_arg350535106) {
return $Hanf_arg964435107(anf_arg350535106,_plus55);
}};
$e3509635097.stack[R.EXN_STACKHEIGHT++] = $ss3510035101;
}
if(R.isPyretException($e3509635097)) {
$e3509635097.pyretStack.push(L[2222]);
}
throw $e3509635097;
}
var $ret3510235103 = $Hanf_arg964435107($z3509835099,_plus55);
++R.GAS;
return $ret3510235103;
};
var $Hanf_arg964435107 = function(anf_arg350535106,_plus55) {
var $z3511035111 = D;
var $f3511635117 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg350535106,(")")):R.ffi.throwNonFunApp(L[2222],_plus55,[anf_arg350535106,(")")]);
};
try {
if(--R.GAS > 0) {
$z3511035111 = $f3511635117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3511635117,
"from":L[2222]});
}
} catch($e3510835109) {
if(R.isCont($e3510835109)) {
var $ss3511235113 = {"from":L[2222],
"go":function(anf_arg350635118) {
return $Hanf_arg964335119(anf_arg350635118,_plus55);
}};
$e3510835109.stack[R.EXN_STACKHEIGHT++] = $ss3511235113;
}
if(R.isPyretException($e3510835109)) {
$e3510835109.pyretStack.push(L[2222]);
}
throw $e3510835109;
}
var $ret3511435115 = $Hanf_arg964335119($z3511035111,_plus55);
++R.GAS;
return $ret3511435115;
};
var $Hanf_arg964335119 = function(anf_arg350635118,_plus55) {
var $z3512235123 = D;
var $f3512835129 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg350635118):R.ffi.throwNonFunApp(L[2222],_plus55,[("("),anf_arg350635118]);
};
try {
if(--R.GAS > 0) {
$z3512235123 = $f3512835129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3512835129,
"from":L[2222]});
}
} catch($e3512035121) {
if(R.isCont($e3512035121)) {
var $ss3512435125 = {"from":L[2222],
"go":function(anf_arg350735130) {
return $Hanf_arg964235131(anf_arg350735130,_plus55);
}};
$e3512035121.stack[R.EXN_STACKHEIGHT++] = $ss3512435125;
}
if(R.isPyretException($e3512035121)) {
$e3512035121.pyretStack.push(L[2222]);
}
throw $e3512035121;
}
var $ret3512635127 = $Hanf_arg964235131($z3512235123,_plus55);
++R.GAS;
return $ret3512635127;
};
var $Hanf_arg964235131 = function(anf_arg350735130,_plus55) {
var $z3513435135 = D;
var $f3514035141 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-dot"),anf_arg350735130):R.ffi.throwNonFunApp(L[2222],_plus55,[("s-dot"),anf_arg350735130]);
};
try {
if(--R.GAS > 0) {
$z3513435135 = $f3514035141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3514035141,
"from":L[2222]});
}
} catch($e3513235133) {
if(R.isCont($e3513235133)) {
var $ss3513635137 = {"from":L[2222],
"go":function(ann_DASH_check_DASH_temp349535142) {
return $Hann_DASH_check_DASH_temp964135143(ann_DASH_check_DASH_temp349535142);
}};
$e3513235133.stack[R.EXN_STACKHEIGHT++] = $ss3513635137;
}
if(R.isPyretException($e3513235133)) {
$e3513235133.pyretStack.push(L[2222]);
}
throw $e3513235133;
}
var $ret3513835139 = $Hann_DASH_check_DASH_temp964135143($z3513435135);
++R.GAS;
return $ret3513835139;
};
var $Hann_DASH_check_DASH_temp964135143 = function(ann_DASH_check_DASH_temp349535142) {
return ann_DASH_check_DASH_temp349535142;
};
var $Hcont_tail_arg963913330 = function(cont_tail_arg349213328,if_helper348213329) {
if(--R.GAS > 0) {
$z3514435145 = R.isFunction(if_helper348213329)?if_helper348213329.app(cont_tail_arg349213328):R.ffi.throwNonFunApp(L[2222],if_helper348213329,[cont_tail_arg349213328]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper348213329)?if_helper348213329.app(cont_tail_arg349213328):R.ffi.throwNonFunApp(L[2222],if_helper348213329,[cont_tail_arg349213328]);
},
"from":L[2222]});
}
++R.GAS;
return $z3514435145;
};
var $Hcont_tail_arg964013345 = function(cont_tail_arg348713344,if_helper348213329) {
if(--R.GAS > 0) {
$z3514635147 = R.isFunction(if_helper348213329)?if_helper348213329.app(cont_tail_arg348713344):R.ffi.throwNonFunApp(L[2222],if_helper348213329,[cont_tail_arg348713344]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper348213329)?if_helper348213329.app(cont_tail_arg348713344):R.ffi.throwNonFunApp(L[2222],if_helper348213329,[cont_tail_arg348713344]);
},
"from":L[2222]});
}
++R.GAS;
return $z3514635147;
};
var $Hanf_arg963813366 = function(anf_arg347913364,anf_fun347713365) {
var $z3515035151 = D;
var $f3515635157 = function(_) {
return R.isFunction(anf_fun347713365)?anf_fun347713365.app(anf_arg347913364):R.ffi.throwNonFunApp(L[2604],anf_fun347713365,[anf_arg347913364]);
};
try {
if(--R.GAS > 0) {
$z3515035151 = $f3515635157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3515635157,
"from":L[2604]});
}
} catch($e3514835149) {
if(R.isCont($e3514835149)) {
var $ss3515235153 = {"from":L[2604],
"go":function(ann_DASH_check_DASH_temp347635158) {
return $Hann_DASH_check_DASH_temp963735159(ann_DASH_check_DASH_temp347635158);
}};
$e3514835149.stack[R.EXN_STACKHEIGHT++] = $ss3515235153;
}
if(R.isPyretException($e3514835149)) {
$e3514835149.pyretStack.push(L[2604]);
}
throw $e3514835149;
}
var $ret3515435155 = $Hann_DASH_check_DASH_temp963735159($z3515035151);
++R.GAS;
return $ret3515435155;
};
var $Hann_DASH_check_DASH_temp963735159 = function(ann_DASH_check_DASH_temp347635158) {
return ann_DASH_check_DASH_temp347635158;
};
var $Hanf_arg963613383 = function(anf_arg346613381,self46113382,_plus55,torepr65) {
var anf_arg346735170 = G(self46113382,"s",L[2223]);
var $z3516235163 = D;
var $f3516835169 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg346735170):R.ffi.throwNonFunApp(L[2223],torepr65,[anf_arg346735170]);
};
try {
if(--R.GAS > 0) {
$z3516235163 = $f3516835169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3516835169,
"from":L[2223]});
}
} catch($e3516035161) {
if(R.isCont($e3516035161)) {
var $ss3516435165 = {"from":L[2223],
"go":function(anf_arg346835171) {
return $Hanf_arg963535172(anf_arg346835171,anf_arg346613381,_plus55);
}};
$e3516035161.stack[R.EXN_STACKHEIGHT++] = $ss3516435165;
}
if(R.isPyretException($e3516035161)) {
$e3516035161.pyretStack.push(L[2223]);
}
throw $e3516035161;
}
var $ret3516635167 = $Hanf_arg963535172($z3516235163,anf_arg346613381,_plus55);
++R.GAS;
return $ret3516635167;
};
var $Hanf_arg963535172 = function(anf_arg346835171,anf_arg346613381,_plus55) {
var $z3517535176 = D;
var $f3518135182 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg346835171):R.ffi.throwNonFunApp(L[2223],_plus55,[(", "),anf_arg346835171]);
};
try {
if(--R.GAS > 0) {
$z3517535176 = $f3518135182();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3518135182,
"from":L[2223]});
}
} catch($e3517335174) {
if(R.isCont($e3517335174)) {
var $ss3517735178 = {"from":L[2223],
"go":function(anf_arg346935183) {
return $Hanf_arg963435184(anf_arg346935183,anf_arg346613381,_plus55);
}};
$e3517335174.stack[R.EXN_STACKHEIGHT++] = $ss3517735178;
}
if(R.isPyretException($e3517335174)) {
$e3517335174.pyretStack.push(L[2223]);
}
throw $e3517335174;
}
var $ret3517935180 = $Hanf_arg963435184($z3517535176,anf_arg346613381,_plus55);
++R.GAS;
return $ret3517935180;
};
var $Hanf_arg963435184 = function(anf_arg346935183,anf_arg346613381,_plus55) {
var $z3518735188 = D;
var $f3519335194 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg346613381,anf_arg346935183):R.ffi.throwNonFunApp(L[2223],_plus55,[anf_arg346613381,anf_arg346935183]);
};
try {
if(--R.GAS > 0) {
$z3518735188 = $f3519335194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3519335194,
"from":L[2223]});
}
} catch($e3518535186) {
if(R.isCont($e3518535186)) {
var $ss3518935190 = {"from":L[2223],
"go":function(anf_arg347035195) {
return $Hanf_arg963335196(anf_arg347035195,_plus55);
}};
$e3518535186.stack[R.EXN_STACKHEIGHT++] = $ss3518935190;
}
if(R.isPyretException($e3518535186)) {
$e3518535186.pyretStack.push(L[2223]);
}
throw $e3518535186;
}
var $ret3519135192 = $Hanf_arg963335196($z3518735188,_plus55);
++R.GAS;
return $ret3519135192;
};
var $Hanf_arg963335196 = function(anf_arg347035195,_plus55) {
var $z3519935200 = D;
var $f3520535206 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg347035195,(")")):R.ffi.throwNonFunApp(L[2223],_plus55,[anf_arg347035195,(")")]);
};
try {
if(--R.GAS > 0) {
$z3519935200 = $f3520535206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3520535206,
"from":L[2223]});
}
} catch($e3519735198) {
if(R.isCont($e3519735198)) {
var $ss3520135202 = {"from":L[2223],
"go":function(anf_arg347135207) {
return $Hanf_arg963235208(anf_arg347135207,_plus55);
}};
$e3519735198.stack[R.EXN_STACKHEIGHT++] = $ss3520135202;
}
if(R.isPyretException($e3519735198)) {
$e3519735198.pyretStack.push(L[2223]);
}
throw $e3519735198;
}
var $ret3520335204 = $Hanf_arg963235208($z3519935200,_plus55);
++R.GAS;
return $ret3520335204;
};
var $Hanf_arg963235208 = function(anf_arg347135207,_plus55) {
var $z3521135212 = D;
var $f3521735218 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg347135207):R.ffi.throwNonFunApp(L[2223],_plus55,[("("),anf_arg347135207]);
};
try {
if(--R.GAS > 0) {
$z3521135212 = $f3521735218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3521735218,
"from":L[2223]});
}
} catch($e3520935210) {
if(R.isCont($e3520935210)) {
var $ss3521335214 = {"from":L[2223],
"go":function(anf_arg347235219) {
return $Hanf_arg963135220(anf_arg347235219,_plus55);
}};
$e3520935210.stack[R.EXN_STACKHEIGHT++] = $ss3521335214;
}
if(R.isPyretException($e3520935210)) {
$e3520935210.pyretStack.push(L[2223]);
}
throw $e3520935210;
}
var $ret3521535216 = $Hanf_arg963135220($z3521135212,_plus55);
++R.GAS;
return $ret3521535216;
};
var $Hanf_arg963135220 = function(anf_arg347235219,_plus55) {
var $z3522335224 = D;
var $f3522935230 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-str"),anf_arg347235219):R.ffi.throwNonFunApp(L[2223],_plus55,[("s-str"),anf_arg347235219]);
};
try {
if(--R.GAS > 0) {
$z3522335224 = $f3522935230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3522935230,
"from":L[2223]});
}
} catch($e3522135222) {
if(R.isCont($e3522135222)) {
var $ss3522535226 = {"from":L[2223],
"go":function(ann_DASH_check_DASH_temp346435231) {
return $Hann_DASH_check_DASH_temp963035232(ann_DASH_check_DASH_temp346435231);
}};
$e3522135222.stack[R.EXN_STACKHEIGHT++] = $ss3522535226;
}
if(R.isPyretException($e3522135222)) {
$e3522135222.pyretStack.push(L[2223]);
}
throw $e3522135222;
}
var $ret3522735228 = $Hann_DASH_check_DASH_temp963035232($z3522335224);
++R.GAS;
return $ret3522735228;
};
var $Hann_DASH_check_DASH_temp963035232 = function(ann_DASH_check_DASH_temp346435231) {
return ann_DASH_check_DASH_temp346435231;
};
var $Hcont_tail_arg962813399 = function(cont_tail_arg346113397,if_helper345213398) {
if(--R.GAS > 0) {
$z3523335234 = R.isFunction(if_helper345213398)?if_helper345213398.app(cont_tail_arg346113397):R.ffi.throwNonFunApp(L[2223],if_helper345213398,[cont_tail_arg346113397]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper345213398)?if_helper345213398.app(cont_tail_arg346113397):R.ffi.throwNonFunApp(L[2223],if_helper345213398,[cont_tail_arg346113397]);
},
"from":L[2223]});
}
++R.GAS;
return $z3523335234;
};
var $Hcont_tail_arg962913414 = function(cont_tail_arg345713413,if_helper345213398) {
if(--R.GAS > 0) {
$z3523535236 = R.isFunction(if_helper345213398)?if_helper345213398.app(cont_tail_arg345713413):R.ffi.throwNonFunApp(L[2223],if_helper345213398,[cont_tail_arg345713413]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper345213398)?if_helper345213398.app(cont_tail_arg345713413):R.ffi.throwNonFunApp(L[2223],if_helper345213398,[cont_tail_arg345713413]);
},
"from":L[2223]});
}
++R.GAS;
return $z3523535236;
};
var $Hanf_arg962713435 = function(anf_arg344913433,anf_fun344713434) {
var $z3523935240 = D;
var $f3524535246 = function(_) {
return R.isFunction(anf_fun344713434)?anf_fun344713434.app(anf_arg344913433):R.ffi.throwNonFunApp(L[2611],anf_fun344713434,[anf_arg344913433]);
};
try {
if(--R.GAS > 0) {
$z3523935240 = $f3524535246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3524535246,
"from":L[2611]});
}
} catch($e3523735238) {
if(R.isCont($e3523735238)) {
var $ss3524135242 = {"from":L[2611],
"go":function(ann_DASH_check_DASH_temp344635247) {
return $Hann_DASH_check_DASH_temp962635248(ann_DASH_check_DASH_temp344635247);
}};
$e3523735238.stack[R.EXN_STACKHEIGHT++] = $ss3524135242;
}
if(R.isPyretException($e3523735238)) {
$e3523735238.pyretStack.push(L[2611]);
}
throw $e3523735238;
}
var $ret3524335244 = $Hann_DASH_check_DASH_temp962635248($z3523935240);
++R.GAS;
return $ret3524335244;
};
var $Hann_DASH_check_DASH_temp962635248 = function(ann_DASH_check_DASH_temp344635247) {
return ann_DASH_check_DASH_temp344635247;
};
var $Hanf_arg962513452 = function(anf_arg343613450,self45513451,_plus55,torepr65) {
var anf_arg343735259 = G(self45513451,"b",L[2224]);
var $z3525135252 = D;
var $f3525735258 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg343735259):R.ffi.throwNonFunApp(L[2224],torepr65,[anf_arg343735259]);
};
try {
if(--R.GAS > 0) {
$z3525135252 = $f3525735258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3525735258,
"from":L[2224]});
}
} catch($e3524935250) {
if(R.isCont($e3524935250)) {
var $ss3525335254 = {"from":L[2224],
"go":function(anf_arg343835260) {
return $Hanf_arg962435261(anf_arg343835260,anf_arg343613450,_plus55);
}};
$e3524935250.stack[R.EXN_STACKHEIGHT++] = $ss3525335254;
}
if(R.isPyretException($e3524935250)) {
$e3524935250.pyretStack.push(L[2224]);
}
throw $e3524935250;
}
var $ret3525535256 = $Hanf_arg962435261($z3525135252,anf_arg343613450,_plus55);
++R.GAS;
return $ret3525535256;
};
var $Hanf_arg962435261 = function(anf_arg343835260,anf_arg343613450,_plus55) {
var $z3526435265 = D;
var $f3527035271 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg343835260):R.ffi.throwNonFunApp(L[2224],_plus55,[(", "),anf_arg343835260]);
};
try {
if(--R.GAS > 0) {
$z3526435265 = $f3527035271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3527035271,
"from":L[2224]});
}
} catch($e3526235263) {
if(R.isCont($e3526235263)) {
var $ss3526635267 = {"from":L[2224],
"go":function(anf_arg343935272) {
return $Hanf_arg962335273(anf_arg343935272,anf_arg343613450,_plus55);
}};
$e3526235263.stack[R.EXN_STACKHEIGHT++] = $ss3526635267;
}
if(R.isPyretException($e3526235263)) {
$e3526235263.pyretStack.push(L[2224]);
}
throw $e3526235263;
}
var $ret3526835269 = $Hanf_arg962335273($z3526435265,anf_arg343613450,_plus55);
++R.GAS;
return $ret3526835269;
};
var $Hanf_arg962335273 = function(anf_arg343935272,anf_arg343613450,_plus55) {
var $z3527635277 = D;
var $f3528235283 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg343613450,anf_arg343935272):R.ffi.throwNonFunApp(L[2224],_plus55,[anf_arg343613450,anf_arg343935272]);
};
try {
if(--R.GAS > 0) {
$z3527635277 = $f3528235283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3528235283,
"from":L[2224]});
}
} catch($e3527435275) {
if(R.isCont($e3527435275)) {
var $ss3527835279 = {"from":L[2224],
"go":function(anf_arg344035284) {
return $Hanf_arg962235285(anf_arg344035284,_plus55);
}};
$e3527435275.stack[R.EXN_STACKHEIGHT++] = $ss3527835279;
}
if(R.isPyretException($e3527435275)) {
$e3527435275.pyretStack.push(L[2224]);
}
throw $e3527435275;
}
var $ret3528035281 = $Hanf_arg962235285($z3527635277,_plus55);
++R.GAS;
return $ret3528035281;
};
var $Hanf_arg962235285 = function(anf_arg344035284,_plus55) {
var $z3528835289 = D;
var $f3529435295 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg344035284,(")")):R.ffi.throwNonFunApp(L[2224],_plus55,[anf_arg344035284,(")")]);
};
try {
if(--R.GAS > 0) {
$z3528835289 = $f3529435295();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3529435295,
"from":L[2224]});
}
} catch($e3528635287) {
if(R.isCont($e3528635287)) {
var $ss3529035291 = {"from":L[2224],
"go":function(anf_arg344135296) {
return $Hanf_arg962135297(anf_arg344135296,_plus55);
}};
$e3528635287.stack[R.EXN_STACKHEIGHT++] = $ss3529035291;
}
if(R.isPyretException($e3528635287)) {
$e3528635287.pyretStack.push(L[2224]);
}
throw $e3528635287;
}
var $ret3529235293 = $Hanf_arg962135297($z3528835289,_plus55);
++R.GAS;
return $ret3529235293;
};
var $Hanf_arg962135297 = function(anf_arg344135296,_plus55) {
var $z3530035301 = D;
var $f3530635307 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg344135296):R.ffi.throwNonFunApp(L[2224],_plus55,[("("),anf_arg344135296]);
};
try {
if(--R.GAS > 0) {
$z3530035301 = $f3530635307();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3530635307,
"from":L[2224]});
}
} catch($e3529835299) {
if(R.isCont($e3529835299)) {
var $ss3530235303 = {"from":L[2224],
"go":function(anf_arg344235308) {
return $Hanf_arg962035309(anf_arg344235308,_plus55);
}};
$e3529835299.stack[R.EXN_STACKHEIGHT++] = $ss3530235303;
}
if(R.isPyretException($e3529835299)) {
$e3529835299.pyretStack.push(L[2224]);
}
throw $e3529835299;
}
var $ret3530435305 = $Hanf_arg962035309($z3530035301,_plus55);
++R.GAS;
return $ret3530435305;
};
var $Hanf_arg962035309 = function(anf_arg344235308,_plus55) {
var $z3531235313 = D;
var $f3531835319 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-bool"),anf_arg344235308):R.ffi.throwNonFunApp(L[2224],_plus55,[("s-bool"),anf_arg344235308]);
};
try {
if(--R.GAS > 0) {
$z3531235313 = $f3531835319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3531835319,
"from":L[2224]});
}
} catch($e3531035311) {
if(R.isCont($e3531035311)) {
var $ss3531435315 = {"from":L[2224],
"go":function(ann_DASH_check_DASH_temp343435320) {
return $Hann_DASH_check_DASH_temp961935321(ann_DASH_check_DASH_temp343435320);
}};
$e3531035311.stack[R.EXN_STACKHEIGHT++] = $ss3531435315;
}
if(R.isPyretException($e3531035311)) {
$e3531035311.pyretStack.push(L[2224]);
}
throw $e3531035311;
}
var $ret3531635317 = $Hann_DASH_check_DASH_temp961935321($z3531235313);
++R.GAS;
return $ret3531635317;
};
var $Hann_DASH_check_DASH_temp961935321 = function(ann_DASH_check_DASH_temp343435320) {
return ann_DASH_check_DASH_temp343435320;
};
var $Hcont_tail_arg961713468 = function(cont_tail_arg343113466,if_helper342213467) {
if(--R.GAS > 0) {
$z3532235323 = R.isFunction(if_helper342213467)?if_helper342213467.app(cont_tail_arg343113466):R.ffi.throwNonFunApp(L[2224],if_helper342213467,[cont_tail_arg343113466]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper342213467)?if_helper342213467.app(cont_tail_arg343113466):R.ffi.throwNonFunApp(L[2224],if_helper342213467,[cont_tail_arg343113466]);
},
"from":L[2224]});
}
++R.GAS;
return $z3532235323;
};
var $Hcont_tail_arg961813483 = function(cont_tail_arg342713482,if_helper342213467) {
if(--R.GAS > 0) {
$z3532435325 = R.isFunction(if_helper342213467)?if_helper342213467.app(cont_tail_arg342713482):R.ffi.throwNonFunApp(L[2224],if_helper342213467,[cont_tail_arg342713482]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper342213467)?if_helper342213467.app(cont_tail_arg342713482):R.ffi.throwNonFunApp(L[2224],if_helper342213467,[cont_tail_arg342713482]);
},
"from":L[2224]});
}
++R.GAS;
return $z3532435325;
};
var $Hanf_arg961613505 = function(anf_arg341313503,PP170,self91413504,_plus55) {
var anf_fun341435336 = G(PP170,"str",L[4350]);
var $z3532835329 = D;
var $f3533435335 = function(_) {
return R.isFunction(anf_fun341435336)?anf_fun341435336.app(("/")):R.ffi.throwNonFunApp(L[4349],anf_fun341435336,[("/")]);
};
try {
if(--R.GAS > 0) {
$z3532835329 = $f3533435335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3533435335,
"from":L[4349]});
}
} catch($e3532635327) {
if(R.isCont($e3532635327)) {
var $ss3533035331 = {"from":L[4349],
"go":function(anf_arg341535337) {
return $Hanf_arg961535338(anf_arg341535337,PP170,anf_arg341313503,self91413504,_plus55);
}};
$e3532635327.stack[R.EXN_STACKHEIGHT++] = $ss3533035331;
}
if(R.isPyretException($e3532635327)) {
$e3532635327.pyretStack.push(L[4349]);
}
throw $e3532635327;
}
var $ret3533235333 = $Hanf_arg961535338($z3532835329,PP170,anf_arg341313503,self91413504,_plus55);
++R.GAS;
return $ret3533235333;
};
var $Hanf_arg961535338 = function(anf_arg341535337,PP170,anf_arg341313503,self91413504,_plus55) {
var $z3534135342 = D;
var $f3534735348 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg341313503,anf_arg341535337):R.ffi.throwNonFunApp(L[4351],_plus55,[anf_arg341313503,anf_arg341535337]);
};
try {
if(--R.GAS > 0) {
$z3534135342 = $f3534735348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3534735348,
"from":L[4351]});
}
} catch($e3533935340) {
if(R.isCont($e3533935340)) {
var $ss3534335344 = {"from":L[4351],
"go":function(anf_arg341635349) {
return $Hanf_arg961435350(anf_arg341635349,PP170,self91413504,_plus55);
}};
$e3533935340.stack[R.EXN_STACKHEIGHT++] = $ss3534335344;
}
if(R.isPyretException($e3533935340)) {
$e3533935340.pyretStack.push(L[4351]);
}
throw $e3533935340;
}
var $ret3534535346 = $Hanf_arg961435350($z3534135342,PP170,self91413504,_plus55);
++R.GAS;
return $ret3534535346;
};
var $Hanf_arg961435350 = function(anf_arg341635349,PP170,self91413504,_plus55) {
var anf_fun341735361 = G(PP170,"number",L[4354]);
var anf_arg341835362 = G(self91413504,"den",L[4353]);
var $z3535335354 = D;
var $f3535935360 = function(_) {
return R.isFunction(anf_fun341735361)?anf_fun341735361.app(anf_arg341835362):R.ffi.throwNonFunApp(L[4352],anf_fun341735361,[anf_arg341835362]);
};
try {
if(--R.GAS > 0) {
$z3535335354 = $f3535935360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3535935360,
"from":L[4352]});
}
} catch($e3535135352) {
if(R.isCont($e3535135352)) {
var $ss3535535356 = {"from":L[4352],
"go":function(anf_arg341935363) {
return $Hanf_arg961335364(anf_arg341935363,anf_arg341635349,_plus55);
}};
$e3535135352.stack[R.EXN_STACKHEIGHT++] = $ss3535535356;
}
if(R.isPyretException($e3535135352)) {
$e3535135352.pyretStack.push(L[4352]);
}
throw $e3535135352;
}
var $ret3535735358 = $Hanf_arg961335364($z3535335354,anf_arg341635349,_plus55);
++R.GAS;
return $ret3535735358;
};
var $Hanf_arg961335364 = function(anf_arg341935363,anf_arg341635349,_plus55) {
var $z3536735368 = D;
var $f3537335374 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg341635349,anf_arg341935363):R.ffi.throwNonFunApp(L[2618],_plus55,[anf_arg341635349,anf_arg341935363]);
};
try {
if(--R.GAS > 0) {
$z3536735368 = $f3537335374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3537335374,
"from":L[2618]});
}
} catch($e3536535366) {
if(R.isCont($e3536535366)) {
var $ss3536935370 = {"from":L[2618],
"go":function(ann_DASH_check_DASH_temp341035375) {
return $Hann_DASH_check_DASH_temp961235376(ann_DASH_check_DASH_temp341035375);
}};
$e3536535366.stack[R.EXN_STACKHEIGHT++] = $ss3536935370;
}
if(R.isPyretException($e3536535366)) {
$e3536535366.pyretStack.push(L[2618]);
}
throw $e3536535366;
}
var $ret3537135372 = $Hann_DASH_check_DASH_temp961235376($z3536735368);
++R.GAS;
return $ret3537135372;
};
var $Hann_DASH_check_DASH_temp961235376 = function(ann_DASH_check_DASH_temp341035375) {
return ann_DASH_check_DASH_temp341035375;
};
var $Hanf_arg961113521 = function(anf_arg339613519,self44913520,_plus55,torepr65) {
var anf_arg339735387 = G(self44913520,"num",L[2225]);
var $z3537935380 = D;
var $f3538535386 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg339735387):R.ffi.throwNonFunApp(L[2225],torepr65,[anf_arg339735387]);
};
try {
if(--R.GAS > 0) {
$z3537935380 = $f3538535386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3538535386,
"from":L[2225]});
}
} catch($e3537735378) {
if(R.isCont($e3537735378)) {
var $ss3538135382 = {"from":L[2225],
"go":function(anf_arg339835388) {
return $Hanf_arg961035389(anf_arg339835388,anf_arg339613519,self44913520,_plus55,torepr65);
}};
$e3537735378.stack[R.EXN_STACKHEIGHT++] = $ss3538135382;
}
if(R.isPyretException($e3537735378)) {
$e3537735378.pyretStack.push(L[2225]);
}
throw $e3537735378;
}
var $ret3538335384 = $Hanf_arg961035389($z3537935380,anf_arg339613519,self44913520,_plus55,torepr65);
++R.GAS;
return $ret3538335384;
};
var $Hanf_arg961035389 = function(anf_arg339835388,anf_arg339613519,self44913520,_plus55,torepr65) {
var $z3539235393 = D;
var $f3539835399 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg339835388):R.ffi.throwNonFunApp(L[2225],_plus55,[(", "),anf_arg339835388]);
};
try {
if(--R.GAS > 0) {
$z3539235393 = $f3539835399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3539835399,
"from":L[2225]});
}
} catch($e3539035391) {
if(R.isCont($e3539035391)) {
var $ss3539435395 = {"from":L[2225],
"go":function(anf_arg339935400) {
return $Hanf_arg960935401(anf_arg339935400,anf_arg339613519,self44913520,_plus55,torepr65);
}};
$e3539035391.stack[R.EXN_STACKHEIGHT++] = $ss3539435395;
}
if(R.isPyretException($e3539035391)) {
$e3539035391.pyretStack.push(L[2225]);
}
throw $e3539035391;
}
var $ret3539635397 = $Hanf_arg960935401($z3539235393,anf_arg339613519,self44913520,_plus55,torepr65);
++R.GAS;
return $ret3539635397;
};
var $Hanf_arg960935401 = function(anf_arg339935400,anf_arg339613519,self44913520,_plus55,torepr65) {
var $z3540435405 = D;
var $f3541035411 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg339613519,anf_arg339935400):R.ffi.throwNonFunApp(L[2225],_plus55,[anf_arg339613519,anf_arg339935400]);
};
try {
if(--R.GAS > 0) {
$z3540435405 = $f3541035411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3541035411,
"from":L[2225]});
}
} catch($e3540235403) {
if(R.isCont($e3540235403)) {
var $ss3540635407 = {"from":L[2225],
"go":function(anf_arg340035412) {
return $Hanf_arg960835413(anf_arg340035412,self44913520,_plus55,torepr65);
}};
$e3540235403.stack[R.EXN_STACKHEIGHT++] = $ss3540635407;
}
if(R.isPyretException($e3540235403)) {
$e3540235403.pyretStack.push(L[2225]);
}
throw $e3540235403;
}
var $ret3540835409 = $Hanf_arg960835413($z3540435405,self44913520,_plus55,torepr65);
++R.GAS;
return $ret3540835409;
};
var $Hanf_arg960835413 = function(anf_arg340035412,self44913520,_plus55,torepr65) {
var anf_arg340135424 = G(self44913520,"den",L[2225]);
var $z3541635417 = D;
var $f3542235423 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg340135424):R.ffi.throwNonFunApp(L[2225],torepr65,[anf_arg340135424]);
};
try {
if(--R.GAS > 0) {
$z3541635417 = $f3542235423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3542235423,
"from":L[2225]});
}
} catch($e3541435415) {
if(R.isCont($e3541435415)) {
var $ss3541835419 = {"from":L[2225],
"go":function(anf_arg340235425) {
return $Hanf_arg960735426(anf_arg340235425,anf_arg340035412,_plus55);
}};
$e3541435415.stack[R.EXN_STACKHEIGHT++] = $ss3541835419;
}
if(R.isPyretException($e3541435415)) {
$e3541435415.pyretStack.push(L[2225]);
}
throw $e3541435415;
}
var $ret3542035421 = $Hanf_arg960735426($z3541635417,anf_arg340035412,_plus55);
++R.GAS;
return $ret3542035421;
};
var $Hanf_arg960735426 = function(anf_arg340235425,anf_arg340035412,_plus55) {
var $z3542935430 = D;
var $f3543535436 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg340235425):R.ffi.throwNonFunApp(L[2225],_plus55,[(", "),anf_arg340235425]);
};
try {
if(--R.GAS > 0) {
$z3542935430 = $f3543535436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3543535436,
"from":L[2225]});
}
} catch($e3542735428) {
if(R.isCont($e3542735428)) {
var $ss3543135432 = {"from":L[2225],
"go":function(anf_arg340335437) {
return $Hanf_arg960635438(anf_arg340335437,anf_arg340035412,_plus55);
}};
$e3542735428.stack[R.EXN_STACKHEIGHT++] = $ss3543135432;
}
if(R.isPyretException($e3542735428)) {
$e3542735428.pyretStack.push(L[2225]);
}
throw $e3542735428;
}
var $ret3543335434 = $Hanf_arg960635438($z3542935430,anf_arg340035412,_plus55);
++R.GAS;
return $ret3543335434;
};
var $Hanf_arg960635438 = function(anf_arg340335437,anf_arg340035412,_plus55) {
var $z3544135442 = D;
var $f3544735448 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg340035412,anf_arg340335437):R.ffi.throwNonFunApp(L[2225],_plus55,[anf_arg340035412,anf_arg340335437]);
};
try {
if(--R.GAS > 0) {
$z3544135442 = $f3544735448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3544735448,
"from":L[2225]});
}
} catch($e3543935440) {
if(R.isCont($e3543935440)) {
var $ss3544335444 = {"from":L[2225],
"go":function(anf_arg340435449) {
return $Hanf_arg960535450(anf_arg340435449,_plus55);
}};
$e3543935440.stack[R.EXN_STACKHEIGHT++] = $ss3544335444;
}
if(R.isPyretException($e3543935440)) {
$e3543935440.pyretStack.push(L[2225]);
}
throw $e3543935440;
}
var $ret3544535446 = $Hanf_arg960535450($z3544135442,_plus55);
++R.GAS;
return $ret3544535446;
};
var $Hanf_arg960535450 = function(anf_arg340435449,_plus55) {
var $z3545335454 = D;
var $f3545935460 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg340435449,(")")):R.ffi.throwNonFunApp(L[2225],_plus55,[anf_arg340435449,(")")]);
};
try {
if(--R.GAS > 0) {
$z3545335454 = $f3545935460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3545935460,
"from":L[2225]});
}
} catch($e3545135452) {
if(R.isCont($e3545135452)) {
var $ss3545535456 = {"from":L[2225],
"go":function(anf_arg340535461) {
return $Hanf_arg960435462(anf_arg340535461,_plus55);
}};
$e3545135452.stack[R.EXN_STACKHEIGHT++] = $ss3545535456;
}
if(R.isPyretException($e3545135452)) {
$e3545135452.pyretStack.push(L[2225]);
}
throw $e3545135452;
}
var $ret3545735458 = $Hanf_arg960435462($z3545335454,_plus55);
++R.GAS;
return $ret3545735458;
};
var $Hanf_arg960435462 = function(anf_arg340535461,_plus55) {
var $z3546535466 = D;
var $f3547135472 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg340535461):R.ffi.throwNonFunApp(L[2225],_plus55,[("("),anf_arg340535461]);
};
try {
if(--R.GAS > 0) {
$z3546535466 = $f3547135472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3547135472,
"from":L[2225]});
}
} catch($e3546335464) {
if(R.isCont($e3546335464)) {
var $ss3546735468 = {"from":L[2225],
"go":function(anf_arg340635473) {
return $Hanf_arg960335474(anf_arg340635473,_plus55);
}};
$e3546335464.stack[R.EXN_STACKHEIGHT++] = $ss3546735468;
}
if(R.isPyretException($e3546335464)) {
$e3546335464.pyretStack.push(L[2225]);
}
throw $e3546335464;
}
var $ret3546935470 = $Hanf_arg960335474($z3546535466,_plus55);
++R.GAS;
return $ret3546935470;
};
var $Hanf_arg960335474 = function(anf_arg340635473,_plus55) {
var $z3547735478 = D;
var $f3548335484 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-frac"),anf_arg340635473):R.ffi.throwNonFunApp(L[2225],_plus55,[("s-frac"),anf_arg340635473]);
};
try {
if(--R.GAS > 0) {
$z3547735478 = $f3548335484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3548335484,
"from":L[2225]});
}
} catch($e3547535476) {
if(R.isCont($e3547535476)) {
var $ss3547935480 = {"from":L[2225],
"go":function(ann_DASH_check_DASH_temp339435485) {
return $Hann_DASH_check_DASH_temp960235486(ann_DASH_check_DASH_temp339435485);
}};
$e3547535476.stack[R.EXN_STACKHEIGHT++] = $ss3547935480;
}
if(R.isPyretException($e3547535476)) {
$e3547535476.pyretStack.push(L[2225]);
}
throw $e3547535476;
}
var $ret3548135482 = $Hann_DASH_check_DASH_temp960235486($z3547735478);
++R.GAS;
return $ret3548135482;
};
var $Hann_DASH_check_DASH_temp960235486 = function(ann_DASH_check_DASH_temp339435485) {
return ann_DASH_check_DASH_temp339435485;
};
var $Hcont_tail_arg960013538 = function(cont_tail_arg339113536,if_helper338113537) {
if(--R.GAS > 0) {
$z3548735488 = R.isFunction(if_helper338113537)?if_helper338113537.app(cont_tail_arg339113536):R.ffi.throwNonFunApp(L[2225],if_helper338113537,[cont_tail_arg339113536]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper338113537)?if_helper338113537.app(cont_tail_arg339113536):R.ffi.throwNonFunApp(L[2225],if_helper338113537,[cont_tail_arg339113536]);
},
"from":L[2225]});
}
++R.GAS;
return $z3548735488;
};
var $Hcont_tail_arg960113553 = function(cont_tail_arg338613552,if_helper338113537) {
if(--R.GAS > 0) {
$z3548935490 = R.isFunction(if_helper338113537)?if_helper338113537.app(cont_tail_arg338613552):R.ffi.throwNonFunApp(L[2225],if_helper338113537,[cont_tail_arg338613552]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper338113537)?if_helper338113537.app(cont_tail_arg338613552):R.ffi.throwNonFunApp(L[2225],if_helper338113537,[cont_tail_arg338613552]);
},
"from":L[2225]});
}
++R.GAS;
return $z3548935490;
};
var $Hann_DASH_check_DASH_temp959913574 = function(ann_DASH_check_DASH_temp337613573) {
return ann_DASH_check_DASH_temp337613573;
};
var $Hanf_arg959813591 = function(anf_arg336613589,self44313590,_plus55,torepr65) {
var anf_arg336735501 = G(self44313590,"n",L[2226]);
var $z3549335494 = D;
var $f3549935500 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg336735501):R.ffi.throwNonFunApp(L[2226],torepr65,[anf_arg336735501]);
};
try {
if(--R.GAS > 0) {
$z3549335494 = $f3549935500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3549935500,
"from":L[2226]});
}
} catch($e3549135492) {
if(R.isCont($e3549135492)) {
var $ss3549535496 = {"from":L[2226],
"go":function(anf_arg336835502) {
return $Hanf_arg959735503(anf_arg336835502,anf_arg336613589,_plus55);
}};
$e3549135492.stack[R.EXN_STACKHEIGHT++] = $ss3549535496;
}
if(R.isPyretException($e3549135492)) {
$e3549135492.pyretStack.push(L[2226]);
}
throw $e3549135492;
}
var $ret3549735498 = $Hanf_arg959735503($z3549335494,anf_arg336613589,_plus55);
++R.GAS;
return $ret3549735498;
};
var $Hanf_arg959735503 = function(anf_arg336835502,anf_arg336613589,_plus55) {
var $z3550635507 = D;
var $f3551235513 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg336835502):R.ffi.throwNonFunApp(L[2226],_plus55,[(", "),anf_arg336835502]);
};
try {
if(--R.GAS > 0) {
$z3550635507 = $f3551235513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3551235513,
"from":L[2226]});
}
} catch($e3550435505) {
if(R.isCont($e3550435505)) {
var $ss3550835509 = {"from":L[2226],
"go":function(anf_arg336935514) {
return $Hanf_arg959635515(anf_arg336935514,anf_arg336613589,_plus55);
}};
$e3550435505.stack[R.EXN_STACKHEIGHT++] = $ss3550835509;
}
if(R.isPyretException($e3550435505)) {
$e3550435505.pyretStack.push(L[2226]);
}
throw $e3550435505;
}
var $ret3551035511 = $Hanf_arg959635515($z3550635507,anf_arg336613589,_plus55);
++R.GAS;
return $ret3551035511;
};
var $Hanf_arg959635515 = function(anf_arg336935514,anf_arg336613589,_plus55) {
var $z3551835519 = D;
var $f3552435525 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg336613589,anf_arg336935514):R.ffi.throwNonFunApp(L[2226],_plus55,[anf_arg336613589,anf_arg336935514]);
};
try {
if(--R.GAS > 0) {
$z3551835519 = $f3552435525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3552435525,
"from":L[2226]});
}
} catch($e3551635517) {
if(R.isCont($e3551635517)) {
var $ss3552035521 = {"from":L[2226],
"go":function(anf_arg337035526) {
return $Hanf_arg959535527(anf_arg337035526,_plus55);
}};
$e3551635517.stack[R.EXN_STACKHEIGHT++] = $ss3552035521;
}
if(R.isPyretException($e3551635517)) {
$e3551635517.pyretStack.push(L[2226]);
}
throw $e3551635517;
}
var $ret3552235523 = $Hanf_arg959535527($z3551835519,_plus55);
++R.GAS;
return $ret3552235523;
};
var $Hanf_arg959535527 = function(anf_arg337035526,_plus55) {
var $z3553035531 = D;
var $f3553635537 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg337035526,(")")):R.ffi.throwNonFunApp(L[2226],_plus55,[anf_arg337035526,(")")]);
};
try {
if(--R.GAS > 0) {
$z3553035531 = $f3553635537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3553635537,
"from":L[2226]});
}
} catch($e3552835529) {
if(R.isCont($e3552835529)) {
var $ss3553235533 = {"from":L[2226],
"go":function(anf_arg337135538) {
return $Hanf_arg959435539(anf_arg337135538,_plus55);
}};
$e3552835529.stack[R.EXN_STACKHEIGHT++] = $ss3553235533;
}
if(R.isPyretException($e3552835529)) {
$e3552835529.pyretStack.push(L[2226]);
}
throw $e3552835529;
}
var $ret3553435535 = $Hanf_arg959435539($z3553035531,_plus55);
++R.GAS;
return $ret3553435535;
};
var $Hanf_arg959435539 = function(anf_arg337135538,_plus55) {
var $z3554235543 = D;
var $f3554835549 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg337135538):R.ffi.throwNonFunApp(L[2226],_plus55,[("("),anf_arg337135538]);
};
try {
if(--R.GAS > 0) {
$z3554235543 = $f3554835549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3554835549,
"from":L[2226]});
}
} catch($e3554035541) {
if(R.isCont($e3554035541)) {
var $ss3554435545 = {"from":L[2226],
"go":function(anf_arg337235550) {
return $Hanf_arg959335551(anf_arg337235550,_plus55);
}};
$e3554035541.stack[R.EXN_STACKHEIGHT++] = $ss3554435545;
}
if(R.isPyretException($e3554035541)) {
$e3554035541.pyretStack.push(L[2226]);
}
throw $e3554035541;
}
var $ret3554635547 = $Hanf_arg959335551($z3554235543,_plus55);
++R.GAS;
return $ret3554635547;
};
var $Hanf_arg959335551 = function(anf_arg337235550,_plus55) {
var $z3555435555 = D;
var $f3556035561 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-num"),anf_arg337235550):R.ffi.throwNonFunApp(L[2226],_plus55,[("s-num"),anf_arg337235550]);
};
try {
if(--R.GAS > 0) {
$z3555435555 = $f3556035561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3556035561,
"from":L[2226]});
}
} catch($e3555235553) {
if(R.isCont($e3555235553)) {
var $ss3555635557 = {"from":L[2226],
"go":function(ann_DASH_check_DASH_temp336435562) {
return $Hann_DASH_check_DASH_temp959235563(ann_DASH_check_DASH_temp336435562);
}};
$e3555235553.stack[R.EXN_STACKHEIGHT++] = $ss3555635557;
}
if(R.isPyretException($e3555235553)) {
$e3555235553.pyretStack.push(L[2226]);
}
throw $e3555235553;
}
var $ret3555835559 = $Hann_DASH_check_DASH_temp959235563($z3555435555);
++R.GAS;
return $ret3555835559;
};
var $Hann_DASH_check_DASH_temp959235563 = function(ann_DASH_check_DASH_temp336435562) {
return ann_DASH_check_DASH_temp336435562;
};
var $Hcont_tail_arg959013607 = function(cont_tail_arg336113605,if_helper335213606) {
if(--R.GAS > 0) {
$z3556435565 = R.isFunction(if_helper335213606)?if_helper335213606.app(cont_tail_arg336113605):R.ffi.throwNonFunApp(L[2226],if_helper335213606,[cont_tail_arg336113605]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper335213606)?if_helper335213606.app(cont_tail_arg336113605):R.ffi.throwNonFunApp(L[2226],if_helper335213606,[cont_tail_arg336113605]);
},
"from":L[2226]});
}
++R.GAS;
return $z3556435565;
};
var $Hcont_tail_arg959113622 = function(cont_tail_arg335713621,if_helper335213606) {
if(--R.GAS > 0) {
$z3556635567 = R.isFunction(if_helper335213606)?if_helper335213606.app(cont_tail_arg335713621):R.ffi.throwNonFunApp(L[2226],if_helper335213606,[cont_tail_arg335713621]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper335213606)?if_helper335213606.app(cont_tail_arg335713621):R.ffi.throwNonFunApp(L[2226],if_helper335213606,[cont_tail_arg335713621]);
},
"from":L[2226]});
}
++R.GAS;
return $z3556635567;
};
var $Hanf_arg958913643 = function(anf_arg334913641,anf_fun334713642) {
var $z3557035571 = D;
var $f3557635577 = function(_) {
return R.isFunction(anf_fun334713642)?anf_fun334713642.app(anf_arg334913641):R.ffi.throwNonFunApp(L[2632],anf_fun334713642,[anf_arg334913641]);
};
try {
if(--R.GAS > 0) {
$z3557035571 = $f3557635577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3557635577,
"from":L[2632]});
}
} catch($e3556835569) {
if(R.isCont($e3556835569)) {
var $ss3557235573 = {"from":L[2632],
"go":function(ann_DASH_check_DASH_temp334635578) {
return $Hann_DASH_check_DASH_temp958835579(ann_DASH_check_DASH_temp334635578);
}};
$e3556835569.stack[R.EXN_STACKHEIGHT++] = $ss3557235573;
}
if(R.isPyretException($e3556835569)) {
$e3556835569.pyretStack.push(L[2632]);
}
throw $e3556835569;
}
var $ret3557435575 = $Hann_DASH_check_DASH_temp958835579($z3557035571);
++R.GAS;
return $ret3557435575;
};
var $Hann_DASH_check_DASH_temp958835579 = function(ann_DASH_check_DASH_temp334635578) {
return ann_DASH_check_DASH_temp334635578;
};
var $Hanf_arg958713660 = function(anf_arg333613658,self43713659,_plus55,torepr65) {
var anf_arg333735590 = G(self43713659,"loc",L[2227]);
var $z3558235583 = D;
var $f3558835589 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg333735590):R.ffi.throwNonFunApp(L[2227],torepr65,[anf_arg333735590]);
};
try {
if(--R.GAS > 0) {
$z3558235583 = $f3558835589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3558835589,
"from":L[2227]});
}
} catch($e3558035581) {
if(R.isCont($e3558035581)) {
var $ss3558435585 = {"from":L[2227],
"go":function(anf_arg333835591) {
return $Hanf_arg958635592(anf_arg333835591,anf_arg333613658,_plus55);
}};
$e3558035581.stack[R.EXN_STACKHEIGHT++] = $ss3558435585;
}
if(R.isPyretException($e3558035581)) {
$e3558035581.pyretStack.push(L[2227]);
}
throw $e3558035581;
}
var $ret3558635587 = $Hanf_arg958635592($z3558235583,anf_arg333613658,_plus55);
++R.GAS;
return $ret3558635587;
};
var $Hanf_arg958635592 = function(anf_arg333835591,anf_arg333613658,_plus55) {
var $z3559535596 = D;
var $f3560135602 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg333835591):R.ffi.throwNonFunApp(L[2227],_plus55,[(", "),anf_arg333835591]);
};
try {
if(--R.GAS > 0) {
$z3559535596 = $f3560135602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3560135602,
"from":L[2227]});
}
} catch($e3559335594) {
if(R.isCont($e3559335594)) {
var $ss3559735598 = {"from":L[2227],
"go":function(anf_arg333935603) {
return $Hanf_arg958535604(anf_arg333935603,anf_arg333613658,_plus55);
}};
$e3559335594.stack[R.EXN_STACKHEIGHT++] = $ss3559735598;
}
if(R.isPyretException($e3559335594)) {
$e3559335594.pyretStack.push(L[2227]);
}
throw $e3559335594;
}
var $ret3559935600 = $Hanf_arg958535604($z3559535596,anf_arg333613658,_plus55);
++R.GAS;
return $ret3559935600;
};
var $Hanf_arg958535604 = function(anf_arg333935603,anf_arg333613658,_plus55) {
var $z3560735608 = D;
var $f3561335614 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg333613658,anf_arg333935603):R.ffi.throwNonFunApp(L[2227],_plus55,[anf_arg333613658,anf_arg333935603]);
};
try {
if(--R.GAS > 0) {
$z3560735608 = $f3561335614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3561335614,
"from":L[2227]});
}
} catch($e3560535606) {
if(R.isCont($e3560535606)) {
var $ss3560935610 = {"from":L[2227],
"go":function(anf_arg334035615) {
return $Hanf_arg958435616(anf_arg334035615,_plus55);
}};
$e3560535606.stack[R.EXN_STACKHEIGHT++] = $ss3560935610;
}
if(R.isPyretException($e3560535606)) {
$e3560535606.pyretStack.push(L[2227]);
}
throw $e3560535606;
}
var $ret3561135612 = $Hanf_arg958435616($z3560735608,_plus55);
++R.GAS;
return $ret3561135612;
};
var $Hanf_arg958435616 = function(anf_arg334035615,_plus55) {
var $z3561935620 = D;
var $f3562535626 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg334035615,(")")):R.ffi.throwNonFunApp(L[2227],_plus55,[anf_arg334035615,(")")]);
};
try {
if(--R.GAS > 0) {
$z3561935620 = $f3562535626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3562535626,
"from":L[2227]});
}
} catch($e3561735618) {
if(R.isCont($e3561735618)) {
var $ss3562135622 = {"from":L[2227],
"go":function(anf_arg334135627) {
return $Hanf_arg958335628(anf_arg334135627,_plus55);
}};
$e3561735618.stack[R.EXN_STACKHEIGHT++] = $ss3562135622;
}
if(R.isPyretException($e3561735618)) {
$e3561735618.pyretStack.push(L[2227]);
}
throw $e3561735618;
}
var $ret3562335624 = $Hanf_arg958335628($z3561935620,_plus55);
++R.GAS;
return $ret3562335624;
};
var $Hanf_arg958335628 = function(anf_arg334135627,_plus55) {
var $z3563135632 = D;
var $f3563735638 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg334135627):R.ffi.throwNonFunApp(L[2227],_plus55,[("("),anf_arg334135627]);
};
try {
if(--R.GAS > 0) {
$z3563135632 = $f3563735638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3563735638,
"from":L[2227]});
}
} catch($e3562935630) {
if(R.isCont($e3562935630)) {
var $ss3563335634 = {"from":L[2227],
"go":function(anf_arg334235639) {
return $Hanf_arg958235640(anf_arg334235639,_plus55);
}};
$e3562935630.stack[R.EXN_STACKHEIGHT++] = $ss3563335634;
}
if(R.isPyretException($e3562935630)) {
$e3562935630.pyretStack.push(L[2227]);
}
throw $e3562935630;
}
var $ret3563535636 = $Hanf_arg958235640($z3563135632,_plus55);
++R.GAS;
return $ret3563535636;
};
var $Hanf_arg958235640 = function(anf_arg334235639,_plus55) {
var $z3564335644 = D;
var $f3564935650 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-srcloc"),anf_arg334235639):R.ffi.throwNonFunApp(L[2227],_plus55,[("s-srcloc"),anf_arg334235639]);
};
try {
if(--R.GAS > 0) {
$z3564335644 = $f3564935650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3564935650,
"from":L[2227]});
}
} catch($e3564135642) {
if(R.isCont($e3564135642)) {
var $ss3564535646 = {"from":L[2227],
"go":function(ann_DASH_check_DASH_temp333435651) {
return $Hann_DASH_check_DASH_temp958135652(ann_DASH_check_DASH_temp333435651);
}};
$e3564135642.stack[R.EXN_STACKHEIGHT++] = $ss3564535646;
}
if(R.isPyretException($e3564135642)) {
$e3564135642.pyretStack.push(L[2227]);
}
throw $e3564135642;
}
var $ret3564735648 = $Hann_DASH_check_DASH_temp958135652($z3564335644);
++R.GAS;
return $ret3564735648;
};
var $Hann_DASH_check_DASH_temp958135652 = function(ann_DASH_check_DASH_temp333435651) {
return ann_DASH_check_DASH_temp333435651;
};
var $Hcont_tail_arg957913676 = function(cont_tail_arg333113674,if_helper332213675) {
if(--R.GAS > 0) {
$z3565335654 = R.isFunction(if_helper332213675)?if_helper332213675.app(cont_tail_arg333113674):R.ffi.throwNonFunApp(L[2227],if_helper332213675,[cont_tail_arg333113674]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper332213675)?if_helper332213675.app(cont_tail_arg333113674):R.ffi.throwNonFunApp(L[2227],if_helper332213675,[cont_tail_arg333113674]);
},
"from":L[2227]});
}
++R.GAS;
return $z3565335654;
};
var $Hcont_tail_arg958013691 = function(cont_tail_arg332713690,if_helper332213675) {
if(--R.GAS > 0) {
$z3565535656 = R.isFunction(if_helper332213675)?if_helper332213675.app(cont_tail_arg332713690):R.ffi.throwNonFunApp(L[2227],if_helper332213675,[cont_tail_arg332713690]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper332213675)?if_helper332213675.app(cont_tail_arg332713690):R.ffi.throwNonFunApp(L[2227],if_helper332213675,[cont_tail_arg332713690]);
},
"from":L[2227]});
}
++R.GAS;
return $z3565535656;
};
var $Hann_DASH_check_DASH_temp957813711 = function(ann_DASH_check_DASH_temp331813710) {
return ann_DASH_check_DASH_temp331813710;
};
var $Hanf_arg957713727 = function(anf_arg331213726,_plus55) {
var $z3565935660 = D;
var $f3566535666 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg331213726,(")")):R.ffi.throwNonFunApp(L[2228],_plus55,[anf_arg331213726,(")")]);
};
try {
if(--R.GAS > 0) {
$z3565935660 = $f3566535666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3566535666,
"from":L[2228]});
}
} catch($e3565735658) {
if(R.isCont($e3565735658)) {
var $ss3566135662 = {"from":L[2228],
"go":function(anf_arg331335667) {
return $Hanf_arg957635668(anf_arg331335667,_plus55);
}};
$e3565735658.stack[R.EXN_STACKHEIGHT++] = $ss3566135662;
}
if(R.isPyretException($e3565735658)) {
$e3565735658.pyretStack.push(L[2228]);
}
throw $e3565735658;
}
var $ret3566335664 = $Hanf_arg957635668($z3565935660,_plus55);
++R.GAS;
return $ret3566335664;
};
var $Hanf_arg957635668 = function(anf_arg331335667,_plus55) {
var $z3567135672 = D;
var $f3567735678 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg331335667):R.ffi.throwNonFunApp(L[2228],_plus55,[("("),anf_arg331335667]);
};
try {
if(--R.GAS > 0) {
$z3567135672 = $f3567735678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3567735678,
"from":L[2228]});
}
} catch($e3566935670) {
if(R.isCont($e3566935670)) {
var $ss3567335674 = {"from":L[2228],
"go":function(anf_arg331435679) {
return $Hanf_arg957535680(anf_arg331435679,_plus55);
}};
$e3566935670.stack[R.EXN_STACKHEIGHT++] = $ss3567335674;
}
if(R.isPyretException($e3566935670)) {
$e3566935670.pyretStack.push(L[2228]);
}
throw $e3566935670;
}
var $ret3567535676 = $Hanf_arg957535680($z3567135672,_plus55);
++R.GAS;
return $ret3567535676;
};
var $Hanf_arg957535680 = function(anf_arg331435679,_plus55) {
var $z3568335684 = D;
var $f3568935690 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-undefined"),anf_arg331435679):R.ffi.throwNonFunApp(L[2228],_plus55,[("s-undefined"),anf_arg331435679]);
};
try {
if(--R.GAS > 0) {
$z3568335684 = $f3568935690();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3568935690,
"from":L[2228]});
}
} catch($e3568135682) {
if(R.isCont($e3568135682)) {
var $ss3568535686 = {"from":L[2228],
"go":function(ann_DASH_check_DASH_temp331035691) {
return $Hann_DASH_check_DASH_temp957435692(ann_DASH_check_DASH_temp331035691);
}};
$e3568135682.stack[R.EXN_STACKHEIGHT++] = $ss3568535686;
}
if(R.isPyretException($e3568135682)) {
$e3568135682.pyretStack.push(L[2228]);
}
throw $e3568135682;
}
var $ret3568735688 = $Hann_DASH_check_DASH_temp957435692($z3568335684);
++R.GAS;
return $ret3568735688;
};
var $Hann_DASH_check_DASH_temp957435692 = function(ann_DASH_check_DASH_temp331035691) {
return ann_DASH_check_DASH_temp331035691;
};
var $Hcont_tail_arg957213743 = function(cont_tail_arg330713741,if_helper329913742) {
if(--R.GAS > 0) {
$z3569335694 = R.isFunction(if_helper329913742)?if_helper329913742.app(cont_tail_arg330713741):R.ffi.throwNonFunApp(L[2228],if_helper329913742,[cont_tail_arg330713741]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper329913742)?if_helper329913742.app(cont_tail_arg330713741):R.ffi.throwNonFunApp(L[2228],if_helper329913742,[cont_tail_arg330713741]);
},
"from":L[2228]});
}
++R.GAS;
return $z3569335694;
};
var $Hcont_tail_arg957313758 = function(cont_tail_arg330413757,if_helper329913742) {
if(--R.GAS > 0) {
$z3569535696 = R.isFunction(if_helper329913742)?if_helper329913742.app(cont_tail_arg330413757):R.ffi.throwNonFunApp(L[2228],if_helper329913742,[cont_tail_arg330413757]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper329913742)?if_helper329913742.app(cont_tail_arg330413757):R.ffi.throwNonFunApp(L[2228],if_helper329913742,[cont_tail_arg330413757]);
},
"from":L[2228]});
}
++R.GAS;
return $z3569535696;
};
var $Hanf_arg957113779 = function(anf_arg329313777,self89813778,_plus55) {
var anf_bracket329435710 = G(self89813778,"id",L[4357]);
var anf_fun329535707 = G(anf_bracket329435710,"tosource",L[4356]);
var $z3569935700 = D;
var $f3570535706 = function(_) {
return R.isFunction(anf_fun329535707)?anf_fun329535707.app():R.ffi.throwNonFunApp(L[4355],anf_fun329535707,[]);
};
try {
if(--R.GAS > 0) {
$z3569935700 = $f3570535706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3570535706,
"from":L[4355]});
}
} catch($e3569735698) {
if(R.isCont($e3569735698)) {
var $ss3570135702 = {"from":L[4355],
"go":function(anf_arg329635708) {
return $Hanf_arg957035709(anf_arg329635708,anf_arg329313777,_plus55);
}};
$e3569735698.stack[R.EXN_STACKHEIGHT++] = $ss3570135702;
}
if(R.isPyretException($e3569735698)) {
$e3569735698.pyretStack.push(L[4355]);
}
throw $e3569735698;
}
var $ret3570335704 = $Hanf_arg957035709($z3569935700,anf_arg329313777,_plus55);
++R.GAS;
return $ret3570335704;
};
var $Hanf_arg957035709 = function(anf_arg329635708,anf_arg329313777,_plus55) {
var $z3571335714 = D;
var $f3571935720 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg329313777,anf_arg329635708):R.ffi.throwNonFunApp(L[2642],_plus55,[anf_arg329313777,anf_arg329635708]);
};
try {
if(--R.GAS > 0) {
$z3571335714 = $f3571935720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3571935720,
"from":L[2642]});
}
} catch($e3571135712) {
if(R.isCont($e3571135712)) {
var $ss3571535716 = {"from":L[2642],
"go":function(ann_DASH_check_DASH_temp329135721) {
return $Hann_DASH_check_DASH_temp956935722(ann_DASH_check_DASH_temp329135721);
}};
$e3571135712.stack[R.EXN_STACKHEIGHT++] = $ss3571535716;
}
if(R.isPyretException($e3571135712)) {
$e3571135712.pyretStack.push(L[2642]);
}
throw $e3571135712;
}
var $ret3571735718 = $Hann_DASH_check_DASH_temp956935722($z3571335714);
++R.GAS;
return $ret3571735718;
};
var $Hann_DASH_check_DASH_temp956935722 = function(ann_DASH_check_DASH_temp329135721) {
return ann_DASH_check_DASH_temp329135721;
};
var $Hanf_arg956813795 = function(anf_arg327713793,self42513794,_plus55,torepr65) {
var anf_arg327835733 = G(self42513794,"id",L[2229]);
var $z3572535726 = D;
var $f3573135732 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg327835733):R.ffi.throwNonFunApp(L[2229],torepr65,[anf_arg327835733]);
};
try {
if(--R.GAS > 0) {
$z3572535726 = $f3573135732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3573135732,
"from":L[2229]});
}
} catch($e3572335724) {
if(R.isCont($e3572335724)) {
var $ss3572735728 = {"from":L[2229],
"go":function(anf_arg327935734) {
return $Hanf_arg956735735(anf_arg327935734,anf_arg327713793,self42513794,_plus55,torepr65);
}};
$e3572335724.stack[R.EXN_STACKHEIGHT++] = $ss3572735728;
}
if(R.isPyretException($e3572335724)) {
$e3572335724.pyretStack.push(L[2229]);
}
throw $e3572335724;
}
var $ret3572935730 = $Hanf_arg956735735($z3572535726,anf_arg327713793,self42513794,_plus55,torepr65);
++R.GAS;
return $ret3572935730;
};
var $Hanf_arg956735735 = function(anf_arg327935734,anf_arg327713793,self42513794,_plus55,torepr65) {
var $z3573835739 = D;
var $f3574435745 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg327935734):R.ffi.throwNonFunApp(L[2229],_plus55,[(", "),anf_arg327935734]);
};
try {
if(--R.GAS > 0) {
$z3573835739 = $f3574435745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3574435745,
"from":L[2229]});
}
} catch($e3573635737) {
if(R.isCont($e3573635737)) {
var $ss3574035741 = {"from":L[2229],
"go":function(anf_arg328035746) {
return $Hanf_arg956635747(anf_arg328035746,anf_arg327713793,self42513794,_plus55,torepr65);
}};
$e3573635737.stack[R.EXN_STACKHEIGHT++] = $ss3574035741;
}
if(R.isPyretException($e3573635737)) {
$e3573635737.pyretStack.push(L[2229]);
}
throw $e3573635737;
}
var $ret3574235743 = $Hanf_arg956635747($z3573835739,anf_arg327713793,self42513794,_plus55,torepr65);
++R.GAS;
return $ret3574235743;
};
var $Hanf_arg956635747 = function(anf_arg328035746,anf_arg327713793,self42513794,_plus55,torepr65) {
var $z3575035751 = D;
var $f3575635757 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg327713793,anf_arg328035746):R.ffi.throwNonFunApp(L[2229],_plus55,[anf_arg327713793,anf_arg328035746]);
};
try {
if(--R.GAS > 0) {
$z3575035751 = $f3575635757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3575635757,
"from":L[2229]});
}
} catch($e3574835749) {
if(R.isCont($e3574835749)) {
var $ss3575235753 = {"from":L[2229],
"go":function(anf_arg328135758) {
return $Hanf_arg956535759(anf_arg328135758,self42513794,_plus55,torepr65);
}};
$e3574835749.stack[R.EXN_STACKHEIGHT++] = $ss3575235753;
}
if(R.isPyretException($e3574835749)) {
$e3574835749.pyretStack.push(L[2229]);
}
throw $e3574835749;
}
var $ret3575435755 = $Hanf_arg956535759($z3575035751,self42513794,_plus55,torepr65);
++R.GAS;
return $ret3575435755;
};
var $Hanf_arg956535759 = function(anf_arg328135758,self42513794,_plus55,torepr65) {
var anf_arg328235770 = G(self42513794,"safe",L[2229]);
var $z3576235763 = D;
var $f3576835769 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg328235770):R.ffi.throwNonFunApp(L[2229],torepr65,[anf_arg328235770]);
};
try {
if(--R.GAS > 0) {
$z3576235763 = $f3576835769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3576835769,
"from":L[2229]});
}
} catch($e3576035761) {
if(R.isCont($e3576035761)) {
var $ss3576435765 = {"from":L[2229],
"go":function(anf_arg328335771) {
return $Hanf_arg956435772(anf_arg328335771,anf_arg328135758,_plus55);
}};
$e3576035761.stack[R.EXN_STACKHEIGHT++] = $ss3576435765;
}
if(R.isPyretException($e3576035761)) {
$e3576035761.pyretStack.push(L[2229]);
}
throw $e3576035761;
}
var $ret3576635767 = $Hanf_arg956435772($z3576235763,anf_arg328135758,_plus55);
++R.GAS;
return $ret3576635767;
};
var $Hanf_arg956435772 = function(anf_arg328335771,anf_arg328135758,_plus55) {
var $z3577535776 = D;
var $f3578135782 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg328335771):R.ffi.throwNonFunApp(L[2229],_plus55,[(", "),anf_arg328335771]);
};
try {
if(--R.GAS > 0) {
$z3577535776 = $f3578135782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3578135782,
"from":L[2229]});
}
} catch($e3577335774) {
if(R.isCont($e3577335774)) {
var $ss3577735778 = {"from":L[2229],
"go":function(anf_arg328435783) {
return $Hanf_arg956335784(anf_arg328435783,anf_arg328135758,_plus55);
}};
$e3577335774.stack[R.EXN_STACKHEIGHT++] = $ss3577735778;
}
if(R.isPyretException($e3577335774)) {
$e3577335774.pyretStack.push(L[2229]);
}
throw $e3577335774;
}
var $ret3577935780 = $Hanf_arg956335784($z3577535776,anf_arg328135758,_plus55);
++R.GAS;
return $ret3577935780;
};
var $Hanf_arg956335784 = function(anf_arg328435783,anf_arg328135758,_plus55) {
var $z3578735788 = D;
var $f3579335794 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg328135758,anf_arg328435783):R.ffi.throwNonFunApp(L[2229],_plus55,[anf_arg328135758,anf_arg328435783]);
};
try {
if(--R.GAS > 0) {
$z3578735788 = $f3579335794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3579335794,
"from":L[2229]});
}
} catch($e3578535786) {
if(R.isCont($e3578535786)) {
var $ss3578935790 = {"from":L[2229],
"go":function(anf_arg328535795) {
return $Hanf_arg956235796(anf_arg328535795,_plus55);
}};
$e3578535786.stack[R.EXN_STACKHEIGHT++] = $ss3578935790;
}
if(R.isPyretException($e3578535786)) {
$e3578535786.pyretStack.push(L[2229]);
}
throw $e3578535786;
}
var $ret3579135792 = $Hanf_arg956235796($z3578735788,_plus55);
++R.GAS;
return $ret3579135792;
};
var $Hanf_arg956235796 = function(anf_arg328535795,_plus55) {
var $z3579935800 = D;
var $f3580535806 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg328535795,(")")):R.ffi.throwNonFunApp(L[2229],_plus55,[anf_arg328535795,(")")]);
};
try {
if(--R.GAS > 0) {
$z3579935800 = $f3580535806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3580535806,
"from":L[2229]});
}
} catch($e3579735798) {
if(R.isCont($e3579735798)) {
var $ss3580135802 = {"from":L[2229],
"go":function(anf_arg328635807) {
return $Hanf_arg956135808(anf_arg328635807,_plus55);
}};
$e3579735798.stack[R.EXN_STACKHEIGHT++] = $ss3580135802;
}
if(R.isPyretException($e3579735798)) {
$e3579735798.pyretStack.push(L[2229]);
}
throw $e3579735798;
}
var $ret3580335804 = $Hanf_arg956135808($z3579935800,_plus55);
++R.GAS;
return $ret3580335804;
};
var $Hanf_arg956135808 = function(anf_arg328635807,_plus55) {
var $z3581135812 = D;
var $f3581735818 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg328635807):R.ffi.throwNonFunApp(L[2229],_plus55,[("("),anf_arg328635807]);
};
try {
if(--R.GAS > 0) {
$z3581135812 = $f3581735818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3581735818,
"from":L[2229]});
}
} catch($e3580935810) {
if(R.isCont($e3580935810)) {
var $ss3581335814 = {"from":L[2229],
"go":function(anf_arg328735819) {
return $Hanf_arg956035820(anf_arg328735819,_plus55);
}};
$e3580935810.stack[R.EXN_STACKHEIGHT++] = $ss3581335814;
}
if(R.isPyretException($e3580935810)) {
$e3580935810.pyretStack.push(L[2229]);
}
throw $e3580935810;
}
var $ret3581535816 = $Hanf_arg956035820($z3581135812,_plus55);
++R.GAS;
return $ret3581535816;
};
var $Hanf_arg956035820 = function(anf_arg328735819,_plus55) {
var $z3582335824 = D;
var $f3582935830 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-id-letrec"),anf_arg328735819):R.ffi.throwNonFunApp(L[2229],_plus55,[("s-id-letrec"),anf_arg328735819]);
};
try {
if(--R.GAS > 0) {
$z3582335824 = $f3582935830();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3582935830,
"from":L[2229]});
}
} catch($e3582135822) {
if(R.isCont($e3582135822)) {
var $ss3582535826 = {"from":L[2229],
"go":function(ann_DASH_check_DASH_temp327535831) {
return $Hann_DASH_check_DASH_temp955935832(ann_DASH_check_DASH_temp327535831);
}};
$e3582135822.stack[R.EXN_STACKHEIGHT++] = $ss3582535826;
}
if(R.isPyretException($e3582135822)) {
$e3582135822.pyretStack.push(L[2229]);
}
throw $e3582135822;
}
var $ret3582735828 = $Hann_DASH_check_DASH_temp955935832($z3582335824);
++R.GAS;
return $ret3582735828;
};
var $Hann_DASH_check_DASH_temp955935832 = function(ann_DASH_check_DASH_temp327535831) {
return ann_DASH_check_DASH_temp327535831;
};
var $Hcont_tail_arg955713812 = function(cont_tail_arg327213810,if_helper326213811) {
if(--R.GAS > 0) {
$z3583335834 = R.isFunction(if_helper326213811)?if_helper326213811.app(cont_tail_arg327213810):R.ffi.throwNonFunApp(L[2229],if_helper326213811,[cont_tail_arg327213810]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper326213811)?if_helper326213811.app(cont_tail_arg327213810):R.ffi.throwNonFunApp(L[2229],if_helper326213811,[cont_tail_arg327213810]);
},
"from":L[2229]});
}
++R.GAS;
return $z3583335834;
};
var $Hcont_tail_arg955813827 = function(cont_tail_arg326713826,if_helper326213811) {
if(--R.GAS > 0) {
$z3583535836 = R.isFunction(if_helper326213811)?if_helper326213811.app(cont_tail_arg326713826):R.ffi.throwNonFunApp(L[2229],if_helper326213811,[cont_tail_arg326713826]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper326213811)?if_helper326213811.app(cont_tail_arg326713826):R.ffi.throwNonFunApp(L[2229],if_helper326213811,[cont_tail_arg326713826]);
},
"from":L[2229]});
}
++R.GAS;
return $z3583535836;
};
var $Hanf_arg955613848 = function(anf_arg325613846,self89313847,_plus55) {
var anf_bracket325735850 = G(self89313847,"id",L[4360]);
var anf_fun325835847 = G(anf_bracket325735850,"tosource",L[4359]);
var $z3583935840 = D;
var $f3584535846 = function(_) {
return R.isFunction(anf_fun325835847)?anf_fun325835847.app():R.ffi.throwNonFunApp(L[4358],anf_fun325835847,[]);
};
try {
if(--R.GAS > 0) {
$z3583935840 = $f3584535846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3584535846,
"from":L[4358]});
}
} catch($e3583735838) {
if(R.isCont($e3583735838)) {
var $ss3584135842 = {"from":L[4358],
"go":function(anf_arg325935848) {
return $Hanf_arg955535849(anf_arg325935848,anf_arg325613846,_plus55);
}};
$e3583735838.stack[R.EXN_STACKHEIGHT++] = $ss3584135842;
}
if(R.isPyretException($e3583735838)) {
$e3583735838.pyretStack.push(L[4358]);
}
throw $e3583735838;
}
var $ret3584335844 = $Hanf_arg955535849($z3583935840,anf_arg325613846,_plus55);
++R.GAS;
return $ret3584335844;
};
var $Hanf_arg955535849 = function(anf_arg325935848,anf_arg325613846,_plus55) {
var $z3585335854 = D;
var $f3585935860 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg325613846,anf_arg325935848):R.ffi.throwNonFunApp(L[2649],_plus55,[anf_arg325613846,anf_arg325935848]);
};
try {
if(--R.GAS > 0) {
$z3585335854 = $f3585935860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3585935860,
"from":L[2649]});
}
} catch($e3585135852) {
if(R.isCont($e3585135852)) {
var $ss3585535856 = {"from":L[2649],
"go":function(ann_DASH_check_DASH_temp325435861) {
return $Hann_DASH_check_DASH_temp955435862(ann_DASH_check_DASH_temp325435861);
}};
$e3585135852.stack[R.EXN_STACKHEIGHT++] = $ss3585535856;
}
if(R.isPyretException($e3585135852)) {
$e3585135852.pyretStack.push(L[2649]);
}
throw $e3585135852;
}
var $ret3585735858 = $Hann_DASH_check_DASH_temp955435862($z3585335854);
++R.GAS;
return $ret3585735858;
};
var $Hann_DASH_check_DASH_temp955435862 = function(ann_DASH_check_DASH_temp325435861) {
return ann_DASH_check_DASH_temp325435861;
};
var $Hanf_arg955313864 = function(anf_arg324413862,self41913863,_plus55,torepr65) {
var anf_arg324535873 = G(self41913863,"id",L[2230]);
var $z3586535866 = D;
var $f3587135872 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg324535873):R.ffi.throwNonFunApp(L[2230],torepr65,[anf_arg324535873]);
};
try {
if(--R.GAS > 0) {
$z3586535866 = $f3587135872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3587135872,
"from":L[2230]});
}
} catch($e3586335864) {
if(R.isCont($e3586335864)) {
var $ss3586735868 = {"from":L[2230],
"go":function(anf_arg324635874) {
return $Hanf_arg955235875(anf_arg324635874,anf_arg324413862,_plus55);
}};
$e3586335864.stack[R.EXN_STACKHEIGHT++] = $ss3586735868;
}
if(R.isPyretException($e3586335864)) {
$e3586335864.pyretStack.push(L[2230]);
}
throw $e3586335864;
}
var $ret3586935870 = $Hanf_arg955235875($z3586535866,anf_arg324413862,_plus55);
++R.GAS;
return $ret3586935870;
};
var $Hanf_arg955235875 = function(anf_arg324635874,anf_arg324413862,_plus55) {
var $z3587835879 = D;
var $f3588435885 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg324635874):R.ffi.throwNonFunApp(L[2230],_plus55,[(", "),anf_arg324635874]);
};
try {
if(--R.GAS > 0) {
$z3587835879 = $f3588435885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3588435885,
"from":L[2230]});
}
} catch($e3587635877) {
if(R.isCont($e3587635877)) {
var $ss3588035881 = {"from":L[2230],
"go":function(anf_arg324735886) {
return $Hanf_arg955135887(anf_arg324735886,anf_arg324413862,_plus55);
}};
$e3587635877.stack[R.EXN_STACKHEIGHT++] = $ss3588035881;
}
if(R.isPyretException($e3587635877)) {
$e3587635877.pyretStack.push(L[2230]);
}
throw $e3587635877;
}
var $ret3588235883 = $Hanf_arg955135887($z3587835879,anf_arg324413862,_plus55);
++R.GAS;
return $ret3588235883;
};
var $Hanf_arg955135887 = function(anf_arg324735886,anf_arg324413862,_plus55) {
var $z3589035891 = D;
var $f3589635897 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg324413862,anf_arg324735886):R.ffi.throwNonFunApp(L[2230],_plus55,[anf_arg324413862,anf_arg324735886]);
};
try {
if(--R.GAS > 0) {
$z3589035891 = $f3589635897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3589635897,
"from":L[2230]});
}
} catch($e3588835889) {
if(R.isCont($e3588835889)) {
var $ss3589235893 = {"from":L[2230],
"go":function(anf_arg324835898) {
return $Hanf_arg955035899(anf_arg324835898,_plus55);
}};
$e3588835889.stack[R.EXN_STACKHEIGHT++] = $ss3589235893;
}
if(R.isPyretException($e3588835889)) {
$e3588835889.pyretStack.push(L[2230]);
}
throw $e3588835889;
}
var $ret3589435895 = $Hanf_arg955035899($z3589035891,_plus55);
++R.GAS;
return $ret3589435895;
};
var $Hanf_arg955035899 = function(anf_arg324835898,_plus55) {
var $z3590235903 = D;
var $f3590835909 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg324835898,(")")):R.ffi.throwNonFunApp(L[2230],_plus55,[anf_arg324835898,(")")]);
};
try {
if(--R.GAS > 0) {
$z3590235903 = $f3590835909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3590835909,
"from":L[2230]});
}
} catch($e3590035901) {
if(R.isCont($e3590035901)) {
var $ss3590435905 = {"from":L[2230],
"go":function(anf_arg324935910) {
return $Hanf_arg954935911(anf_arg324935910,_plus55);
}};
$e3590035901.stack[R.EXN_STACKHEIGHT++] = $ss3590435905;
}
if(R.isPyretException($e3590035901)) {
$e3590035901.pyretStack.push(L[2230]);
}
throw $e3590035901;
}
var $ret3590635907 = $Hanf_arg954935911($z3590235903,_plus55);
++R.GAS;
return $ret3590635907;
};
var $Hanf_arg954935911 = function(anf_arg324935910,_plus55) {
var $z3591435915 = D;
var $f3592035921 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg324935910):R.ffi.throwNonFunApp(L[2230],_plus55,[("("),anf_arg324935910]);
};
try {
if(--R.GAS > 0) {
$z3591435915 = $f3592035921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3592035921,
"from":L[2230]});
}
} catch($e3591235913) {
if(R.isCont($e3591235913)) {
var $ss3591635917 = {"from":L[2230],
"go":function(anf_arg325035922) {
return $Hanf_arg954835923(anf_arg325035922,_plus55);
}};
$e3591235913.stack[R.EXN_STACKHEIGHT++] = $ss3591635917;
}
if(R.isPyretException($e3591235913)) {
$e3591235913.pyretStack.push(L[2230]);
}
throw $e3591235913;
}
var $ret3591835919 = $Hanf_arg954835923($z3591435915,_plus55);
++R.GAS;
return $ret3591835919;
};
var $Hanf_arg954835923 = function(anf_arg325035922,_plus55) {
var $z3592635927 = D;
var $f3593235933 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-id-var"),anf_arg325035922):R.ffi.throwNonFunApp(L[2230],_plus55,[("s-id-var"),anf_arg325035922]);
};
try {
if(--R.GAS > 0) {
$z3592635927 = $f3593235933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3593235933,
"from":L[2230]});
}
} catch($e3592435925) {
if(R.isCont($e3592435925)) {
var $ss3592835929 = {"from":L[2230],
"go":function(ann_DASH_check_DASH_temp324235934) {
return $Hann_DASH_check_DASH_temp954735935(ann_DASH_check_DASH_temp324235934);
}};
$e3592435925.stack[R.EXN_STACKHEIGHT++] = $ss3592835929;
}
if(R.isPyretException($e3592435925)) {
$e3592435925.pyretStack.push(L[2230]);
}
throw $e3592435925;
}
var $ret3593035931 = $Hann_DASH_check_DASH_temp954735935($z3592635927);
++R.GAS;
return $ret3593035931;
};
var $Hann_DASH_check_DASH_temp954735935 = function(ann_DASH_check_DASH_temp324235934) {
return ann_DASH_check_DASH_temp324235934;
};
var $Hcont_tail_arg954513880 = function(cont_tail_arg323913878,if_helper323013879) {
if(--R.GAS > 0) {
$z3593635937 = R.isFunction(if_helper323013879)?if_helper323013879.app(cont_tail_arg323913878):R.ffi.throwNonFunApp(L[2230],if_helper323013879,[cont_tail_arg323913878]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper323013879)?if_helper323013879.app(cont_tail_arg323913878):R.ffi.throwNonFunApp(L[2230],if_helper323013879,[cont_tail_arg323913878]);
},
"from":L[2230]});
}
++R.GAS;
return $z3593635937;
};
var $Hcont_tail_arg954613895 = function(cont_tail_arg323513894,if_helper323013879) {
if(--R.GAS > 0) {
$z3593835939 = R.isFunction(if_helper323013879)?if_helper323013879.app(cont_tail_arg323513894):R.ffi.throwNonFunApp(L[2230],if_helper323013879,[cont_tail_arg323513894]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper323013879)?if_helper323013879.app(cont_tail_arg323513894):R.ffi.throwNonFunApp(L[2230],if_helper323013879,[cont_tail_arg323513894]);
},
"from":L[2230]});
}
++R.GAS;
return $z3593835939;
};
var $Hann_DASH_check_DASH_temp954413915 = function(ann_DASH_check_DASH_temp322513914) {
return ann_DASH_check_DASH_temp322513914;
};
var $Hanf_arg954313933 = function(anf_arg321513931,self41313932,_plus55,torepr65) {
var anf_arg321635950 = G(self41313932,"id",L[2231]);
var $z3594235943 = D;
var $f3594835949 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg321635950):R.ffi.throwNonFunApp(L[2231],torepr65,[anf_arg321635950]);
};
try {
if(--R.GAS > 0) {
$z3594235943 = $f3594835949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3594835949,
"from":L[2231]});
}
} catch($e3594035941) {
if(R.isCont($e3594035941)) {
var $ss3594435945 = {"from":L[2231],
"go":function(anf_arg321735951) {
return $Hanf_arg954235952(anf_arg321735951,anf_arg321513931,_plus55);
}};
$e3594035941.stack[R.EXN_STACKHEIGHT++] = $ss3594435945;
}
if(R.isPyretException($e3594035941)) {
$e3594035941.pyretStack.push(L[2231]);
}
throw $e3594035941;
}
var $ret3594635947 = $Hanf_arg954235952($z3594235943,anf_arg321513931,_plus55);
++R.GAS;
return $ret3594635947;
};
var $Hanf_arg954235952 = function(anf_arg321735951,anf_arg321513931,_plus55) {
var $z3595535956 = D;
var $f3596135962 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg321735951):R.ffi.throwNonFunApp(L[2231],_plus55,[(", "),anf_arg321735951]);
};
try {
if(--R.GAS > 0) {
$z3595535956 = $f3596135962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3596135962,
"from":L[2231]});
}
} catch($e3595335954) {
if(R.isCont($e3595335954)) {
var $ss3595735958 = {"from":L[2231],
"go":function(anf_arg321835963) {
return $Hanf_arg954135964(anf_arg321835963,anf_arg321513931,_plus55);
}};
$e3595335954.stack[R.EXN_STACKHEIGHT++] = $ss3595735958;
}
if(R.isPyretException($e3595335954)) {
$e3595335954.pyretStack.push(L[2231]);
}
throw $e3595335954;
}
var $ret3595935960 = $Hanf_arg954135964($z3595535956,anf_arg321513931,_plus55);
++R.GAS;
return $ret3595935960;
};
var $Hanf_arg954135964 = function(anf_arg321835963,anf_arg321513931,_plus55) {
var $z3596735968 = D;
var $f3597335974 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg321513931,anf_arg321835963):R.ffi.throwNonFunApp(L[2231],_plus55,[anf_arg321513931,anf_arg321835963]);
};
try {
if(--R.GAS > 0) {
$z3596735968 = $f3597335974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3597335974,
"from":L[2231]});
}
} catch($e3596535966) {
if(R.isCont($e3596535966)) {
var $ss3596935970 = {"from":L[2231],
"go":function(anf_arg321935975) {
return $Hanf_arg954035976(anf_arg321935975,_plus55);
}};
$e3596535966.stack[R.EXN_STACKHEIGHT++] = $ss3596935970;
}
if(R.isPyretException($e3596535966)) {
$e3596535966.pyretStack.push(L[2231]);
}
throw $e3596535966;
}
var $ret3597135972 = $Hanf_arg954035976($z3596735968,_plus55);
++R.GAS;
return $ret3597135972;
};
var $Hanf_arg954035976 = function(anf_arg321935975,_plus55) {
var $z3597935980 = D;
var $f3598535986 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg321935975,(")")):R.ffi.throwNonFunApp(L[2231],_plus55,[anf_arg321935975,(")")]);
};
try {
if(--R.GAS > 0) {
$z3597935980 = $f3598535986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3598535986,
"from":L[2231]});
}
} catch($e3597735978) {
if(R.isCont($e3597735978)) {
var $ss3598135982 = {"from":L[2231],
"go":function(anf_arg322035987) {
return $Hanf_arg953935988(anf_arg322035987,_plus55);
}};
$e3597735978.stack[R.EXN_STACKHEIGHT++] = $ss3598135982;
}
if(R.isPyretException($e3597735978)) {
$e3597735978.pyretStack.push(L[2231]);
}
throw $e3597735978;
}
var $ret3598335984 = $Hanf_arg953935988($z3597935980,_plus55);
++R.GAS;
return $ret3598335984;
};
var $Hanf_arg953935988 = function(anf_arg322035987,_plus55) {
var $z3599135992 = D;
var $f3599735998 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg322035987):R.ffi.throwNonFunApp(L[2231],_plus55,[("("),anf_arg322035987]);
};
try {
if(--R.GAS > 0) {
$z3599135992 = $f3599735998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3599735998,
"from":L[2231]});
}
} catch($e3598935990) {
if(R.isCont($e3598935990)) {
var $ss3599335994 = {"from":L[2231],
"go":function(anf_arg322135999) {
return $Hanf_arg953836000(anf_arg322135999,_plus55);
}};
$e3598935990.stack[R.EXN_STACKHEIGHT++] = $ss3599335994;
}
if(R.isPyretException($e3598935990)) {
$e3598935990.pyretStack.push(L[2231]);
}
throw $e3598935990;
}
var $ret3599535996 = $Hanf_arg953836000($z3599135992,_plus55);
++R.GAS;
return $ret3599535996;
};
var $Hanf_arg953836000 = function(anf_arg322135999,_plus55) {
var $z3600336004 = D;
var $f3600936010 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-id"),anf_arg322135999):R.ffi.throwNonFunApp(L[2231],_plus55,[("s-id"),anf_arg322135999]);
};
try {
if(--R.GAS > 0) {
$z3600336004 = $f3600936010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3600936010,
"from":L[2231]});
}
} catch($e3600136002) {
if(R.isCont($e3600136002)) {
var $ss3600536006 = {"from":L[2231],
"go":function(ann_DASH_check_DASH_temp321336011) {
return $Hann_DASH_check_DASH_temp953736012(ann_DASH_check_DASH_temp321336011);
}};
$e3600136002.stack[R.EXN_STACKHEIGHT++] = $ss3600536006;
}
if(R.isPyretException($e3600136002)) {
$e3600136002.pyretStack.push(L[2231]);
}
throw $e3600136002;
}
var $ret3600736008 = $Hann_DASH_check_DASH_temp953736012($z3600336004);
++R.GAS;
return $ret3600736008;
};
var $Hann_DASH_check_DASH_temp953736012 = function(ann_DASH_check_DASH_temp321336011) {
return ann_DASH_check_DASH_temp321336011;
};
var $Hcont_tail_arg953513949 = function(cont_tail_arg321013947,if_helper320113948) {
if(--R.GAS > 0) {
$z3601336014 = R.isFunction(if_helper320113948)?if_helper320113948.app(cont_tail_arg321013947):R.ffi.throwNonFunApp(L[2231],if_helper320113948,[cont_tail_arg321013947]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper320113948)?if_helper320113948.app(cont_tail_arg321013947):R.ffi.throwNonFunApp(L[2231],if_helper320113948,[cont_tail_arg321013947]);
},
"from":L[2231]});
}
++R.GAS;
return $z3601336014;
};
var $Hcont_tail_arg953613964 = function(cont_tail_arg320613963,if_helper320113948) {
if(--R.GAS > 0) {
$z3601536016 = R.isFunction(if_helper320113948)?if_helper320113948.app(cont_tail_arg320613963):R.ffi.throwNonFunApp(L[2231],if_helper320113948,[cont_tail_arg320613963]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper320113948)?if_helper320113948.app(cont_tail_arg320613963):R.ffi.throwNonFunApp(L[2231],if_helper320113948,[cont_tail_arg320613963]);
},
"from":L[2231]});
}
++R.GAS;
return $z3601536016;
};
var $Hann_DASH_check_DASH_temp953413985 = function(ann_DASH_check_DASH_temp319613984) {
return ann_DASH_check_DASH_temp319613984;
};
var $Hanf_arg953314002 = function(anf_arg318614000,self40714001,_plus55,torepr65) {
var anf_arg318736027 = G(self40714001,"name",L[2232]);
var $z3601936020 = D;
var $f3602536026 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg318736027):R.ffi.throwNonFunApp(L[2232],torepr65,[anf_arg318736027]);
};
try {
if(--R.GAS > 0) {
$z3601936020 = $f3602536026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3602536026,
"from":L[2232]});
}
} catch($e3601736018) {
if(R.isCont($e3601736018)) {
var $ss3602136022 = {"from":L[2232],
"go":function(anf_arg318836028) {
return $Hanf_arg953236029(anf_arg318836028,anf_arg318614000,_plus55);
}};
$e3601736018.stack[R.EXN_STACKHEIGHT++] = $ss3602136022;
}
if(R.isPyretException($e3601736018)) {
$e3601736018.pyretStack.push(L[2232]);
}
throw $e3601736018;
}
var $ret3602336024 = $Hanf_arg953236029($z3601936020,anf_arg318614000,_plus55);
++R.GAS;
return $ret3602336024;
};
var $Hanf_arg953236029 = function(anf_arg318836028,anf_arg318614000,_plus55) {
var $z3603236033 = D;
var $f3603836039 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg318836028):R.ffi.throwNonFunApp(L[2232],_plus55,[(", "),anf_arg318836028]);
};
try {
if(--R.GAS > 0) {
$z3603236033 = $f3603836039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3603836039,
"from":L[2232]});
}
} catch($e3603036031) {
if(R.isCont($e3603036031)) {
var $ss3603436035 = {"from":L[2232],
"go":function(anf_arg318936040) {
return $Hanf_arg953136041(anf_arg318936040,anf_arg318614000,_plus55);
}};
$e3603036031.stack[R.EXN_STACKHEIGHT++] = $ss3603436035;
}
if(R.isPyretException($e3603036031)) {
$e3603036031.pyretStack.push(L[2232]);
}
throw $e3603036031;
}
var $ret3603636037 = $Hanf_arg953136041($z3603236033,anf_arg318614000,_plus55);
++R.GAS;
return $ret3603636037;
};
var $Hanf_arg953136041 = function(anf_arg318936040,anf_arg318614000,_plus55) {
var $z3604436045 = D;
var $f3605036051 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg318614000,anf_arg318936040):R.ffi.throwNonFunApp(L[2232],_plus55,[anf_arg318614000,anf_arg318936040]);
};
try {
if(--R.GAS > 0) {
$z3604436045 = $f3605036051();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3605036051,
"from":L[2232]});
}
} catch($e3604236043) {
if(R.isCont($e3604236043)) {
var $ss3604636047 = {"from":L[2232],
"go":function(anf_arg319036052) {
return $Hanf_arg953036053(anf_arg319036052,_plus55);
}};
$e3604236043.stack[R.EXN_STACKHEIGHT++] = $ss3604636047;
}
if(R.isPyretException($e3604236043)) {
$e3604236043.pyretStack.push(L[2232]);
}
throw $e3604236043;
}
var $ret3604836049 = $Hanf_arg953036053($z3604436045,_plus55);
++R.GAS;
return $ret3604836049;
};
var $Hanf_arg953036053 = function(anf_arg319036052,_plus55) {
var $z3605636057 = D;
var $f3606236063 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg319036052,(")")):R.ffi.throwNonFunApp(L[2232],_plus55,[anf_arg319036052,(")")]);
};
try {
if(--R.GAS > 0) {
$z3605636057 = $f3606236063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3606236063,
"from":L[2232]});
}
} catch($e3605436055) {
if(R.isCont($e3605436055)) {
var $ss3605836059 = {"from":L[2232],
"go":function(anf_arg319136064) {
return $Hanf_arg952936065(anf_arg319136064,_plus55);
}};
$e3605436055.stack[R.EXN_STACKHEIGHT++] = $ss3605836059;
}
if(R.isPyretException($e3605436055)) {
$e3605436055.pyretStack.push(L[2232]);
}
throw $e3605436055;
}
var $ret3606036061 = $Hanf_arg952936065($z3605636057,_plus55);
++R.GAS;
return $ret3606036061;
};
var $Hanf_arg952936065 = function(anf_arg319136064,_plus55) {
var $z3606836069 = D;
var $f3607436075 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg319136064):R.ffi.throwNonFunApp(L[2232],_plus55,[("("),anf_arg319136064]);
};
try {
if(--R.GAS > 0) {
$z3606836069 = $f3607436075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3607436075,
"from":L[2232]});
}
} catch($e3606636067) {
if(R.isCont($e3606636067)) {
var $ss3607036071 = {"from":L[2232],
"go":function(anf_arg319236076) {
return $Hanf_arg952836077(anf_arg319236076,_plus55);
}};
$e3606636067.stack[R.EXN_STACKHEIGHT++] = $ss3607036071;
}
if(R.isPyretException($e3606636067)) {
$e3606636067.pyretStack.push(L[2232]);
}
throw $e3606636067;
}
var $ret3607236073 = $Hanf_arg952836077($z3606836069,_plus55);
++R.GAS;
return $ret3607236073;
};
var $Hanf_arg952836077 = function(anf_arg319236076,_plus55) {
var $z3608036081 = D;
var $f3608636087 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-prim-val"),anf_arg319236076):R.ffi.throwNonFunApp(L[2232],_plus55,[("s-prim-val"),anf_arg319236076]);
};
try {
if(--R.GAS > 0) {
$z3608036081 = $f3608636087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3608636087,
"from":L[2232]});
}
} catch($e3607836079) {
if(R.isCont($e3607836079)) {
var $ss3608236083 = {"from":L[2232],
"go":function(ann_DASH_check_DASH_temp318436088) {
return $Hann_DASH_check_DASH_temp952736089(ann_DASH_check_DASH_temp318436088);
}};
$e3607836079.stack[R.EXN_STACKHEIGHT++] = $ss3608236083;
}
if(R.isPyretException($e3607836079)) {
$e3607836079.pyretStack.push(L[2232]);
}
throw $e3607836079;
}
var $ret3608436085 = $Hann_DASH_check_DASH_temp952736089($z3608036081);
++R.GAS;
return $ret3608436085;
};
var $Hann_DASH_check_DASH_temp952736089 = function(ann_DASH_check_DASH_temp318436088) {
return ann_DASH_check_DASH_temp318436088;
};
var $Hcont_tail_arg952514018 = function(cont_tail_arg318114016,if_helper317214017) {
if(--R.GAS > 0) {
$z3609036091 = R.isFunction(if_helper317214017)?if_helper317214017.app(cont_tail_arg318114016):R.ffi.throwNonFunApp(L[2232],if_helper317214017,[cont_tail_arg318114016]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper317214017)?if_helper317214017.app(cont_tail_arg318114016):R.ffi.throwNonFunApp(L[2232],if_helper317214017,[cont_tail_arg318114016]);
},
"from":L[2232]});
}
++R.GAS;
return $z3609036091;
};
var $Hcont_tail_arg952614033 = function(cont_tail_arg317714032,if_helper317214017) {
if(--R.GAS > 0) {
$z3609236093 = R.isFunction(if_helper317214017)?if_helper317214017.app(cont_tail_arg317714032):R.ffi.throwNonFunApp(L[2232],if_helper317214017,[cont_tail_arg317714032]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper317214017)?if_helper317214017.app(cont_tail_arg317714032):R.ffi.throwNonFunApp(L[2232],if_helper317214017,[cont_tail_arg317714032]);
},
"from":L[2232]});
}
++R.GAS;
return $z3609236093;
};
var $Hanf_arg952414056 = function(anf_arg315514053,INDENT118169,PP170,anf_fun315214054,self88114055,_plus55) {
var anf_fun315636108 = G(PP170,"parens",L[4368]);
var anf_fun315736109 = G(PP170,"nest",L[4367]);
var anf_fun315836110 = G(PP170,"separate",L[4366]);
var anf_arg315936107 = G(PP170,"commabreak",L[4365]);
var anf_bracket316036126 = G(self88114055,"args",L[4364]);
var anf_fun316136104 = G(anf_bracket316036126,"map",L[4363]);
var anf_arg316436105 = R.makeFunction(function(recv_DASH_40236112) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4362],1,arguments);
}
var anf_fun316336123 = G(recv_DASH_40236112,"tosource",L[4362]);
var $z3611536116 = D;
var $f3612136122 = function(_) {
return R.isFunction(anf_fun316336123)?anf_fun316336123.app():R.ffi.throwNonFunApp(L[4362],anf_fun316336123,[]);
};
try {
if(--R.GAS > 0) {
$z3611536116 = $f3612136122();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3612136122,
"from":L[4362]});
}
} catch($e3611336114) {
if(R.isCont($e3611336114)) {
var $ss3611736118 = {"from":L[4362],
"go":function(ann_DASH_check_DASH_temp316236124) {
return $Hann_DASH_check_DASH_temp951736125(ann_DASH_check_DASH_temp316236124);
}};
$e3611336114.stack[R.EXN_STACKHEIGHT++] = $ss3611736118;
}
if(R.isPyretException($e3611336114)) {
$e3611336114.pyretStack.push(L[4362]);
}
throw $e3611336114;
}
var $ret3611936120 = $Hann_DASH_check_DASH_temp951736125($z3611536116);
++R.GAS;
return $ret3611936120;
});
var $z3609636097 = D;
var $f3610236103 = function(_) {
return R.isFunction(anf_fun316136104)?anf_fun316136104.app(anf_arg316436105):R.ffi.throwNonFunApp(L[4361],anf_fun316136104,[anf_arg316436105]);
};
try {
if(--R.GAS > 0) {
$z3609636097 = $f3610236103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3610236103,
"from":L[4361]});
}
} catch($e3609436095) {
if(R.isCont($e3609436095)) {
var $ss3609836099 = {"from":L[4361],
"go":function(anf_arg316536106) {
return $Hanf_arg952336111(anf_arg316536106,INDENT118169,anf_arg315514053,anf_arg315936107,anf_fun315214054,anf_fun315636108,anf_fun315736109,anf_fun315836110,_plus55);
}};
$e3609436095.stack[R.EXN_STACKHEIGHT++] = $ss3609836099;
}
if(R.isPyretException($e3609436095)) {
$e3609436095.pyretStack.push(L[4361]);
}
throw $e3609436095;
}
var $ret3610036101 = $Hanf_arg952336111($z3609636097,INDENT118169,anf_arg315514053,anf_arg315936107,anf_fun315214054,anf_fun315636108,anf_fun315736109,anf_fun315836110,_plus55);
++R.GAS;
return $ret3610036101;
};
var $Hanf_arg952336111 = function(anf_arg316536106,INDENT118169,anf_arg315514053,anf_arg315936107,anf_fun315214054,anf_fun315636108,anf_fun315736109,anf_fun315836110,_plus55) {
var $z3612936130 = D;
var $f3613536136 = function(_) {
return R.isFunction(anf_fun315836110)?anf_fun315836110.app(anf_arg315936107,anf_arg316536106):R.ffi.throwNonFunApp(L[4369],anf_fun315836110,[anf_arg315936107,anf_arg316536106]);
};
try {
if(--R.GAS > 0) {
$z3612936130 = $f3613536136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3613536136,
"from":L[4369]});
}
} catch($e3612736128) {
if(R.isCont($e3612736128)) {
var $ss3613136132 = {"from":L[4369],
"go":function(anf_arg316636137) {
return $Hanf_arg952236138(anf_arg316636137,INDENT118169,anf_arg315514053,anf_fun315214054,anf_fun315636108,anf_fun315736109,_plus55);
}};
$e3612736128.stack[R.EXN_STACKHEIGHT++] = $ss3613136132;
}
if(R.isPyretException($e3612736128)) {
$e3612736128.pyretStack.push(L[4369]);
}
throw $e3612736128;
}
var $ret3613336134 = $Hanf_arg952236138($z3612936130,INDENT118169,anf_arg315514053,anf_fun315214054,anf_fun315636108,anf_fun315736109,_plus55);
++R.GAS;
return $ret3613336134;
};
var $Hanf_arg952236138 = function(anf_arg316636137,INDENT118169,anf_arg315514053,anf_fun315214054,anf_fun315636108,anf_fun315736109,_plus55) {
var $z3614136142 = D;
var $f3614736148 = function(_) {
return R.isFunction(anf_fun315736109)?anf_fun315736109.app(INDENT118169,anf_arg316636137):R.ffi.throwNonFunApp(L[4370],anf_fun315736109,[INDENT118169,anf_arg316636137]);
};
try {
if(--R.GAS > 0) {
$z3614136142 = $f3614736148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3614736148,
"from":L[4370]});
}
} catch($e3613936140) {
if(R.isCont($e3613936140)) {
var $ss3614336144 = {"from":L[4370],
"go":function(anf_arg316736149) {
return $Hanf_arg952136150(anf_arg316736149,anf_arg315514053,anf_fun315214054,anf_fun315636108,_plus55);
}};
$e3613936140.stack[R.EXN_STACKHEIGHT++] = $ss3614336144;
}
if(R.isPyretException($e3613936140)) {
$e3613936140.pyretStack.push(L[4370]);
}
throw $e3613936140;
}
var $ret3614536146 = $Hanf_arg952136150($z3614136142,anf_arg315514053,anf_fun315214054,anf_fun315636108,_plus55);
++R.GAS;
return $ret3614536146;
};
var $Hanf_arg952136150 = function(anf_arg316736149,anf_arg315514053,anf_fun315214054,anf_fun315636108,_plus55) {
var $z3615336154 = D;
var $f3615936160 = function(_) {
return R.isFunction(anf_fun315636108)?anf_fun315636108.app(anf_arg316736149):R.ffi.throwNonFunApp(L[4371],anf_fun315636108,[anf_arg316736149]);
};
try {
if(--R.GAS > 0) {
$z3615336154 = $f3615936160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3615936160,
"from":L[4371]});
}
} catch($e3615136152) {
if(R.isCont($e3615136152)) {
var $ss3615536156 = {"from":L[4371],
"go":function(anf_arg316836161) {
return $Hanf_arg952036162(anf_arg316836161,anf_arg315514053,anf_fun315214054,_plus55);
}};
$e3615136152.stack[R.EXN_STACKHEIGHT++] = $ss3615536156;
}
if(R.isPyretException($e3615136152)) {
$e3615136152.pyretStack.push(L[4371]);
}
throw $e3615136152;
}
var $ret3615736158 = $Hanf_arg952036162($z3615336154,anf_arg315514053,anf_fun315214054,_plus55);
++R.GAS;
return $ret3615736158;
};
var $Hanf_arg952036162 = function(anf_arg316836161,anf_arg315514053,anf_fun315214054,_plus55) {
var $z3616536166 = D;
var $f3617136172 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg315514053,anf_arg316836161):R.ffi.throwNonFunApp(L[4372],_plus55,[anf_arg315514053,anf_arg316836161]);
};
try {
if(--R.GAS > 0) {
$z3616536166 = $f3617136172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3617136172,
"from":L[4372]});
}
} catch($e3616336164) {
if(R.isCont($e3616336164)) {
var $ss3616736168 = {"from":L[4372],
"go":function(anf_arg316936173) {
return $Hanf_arg951936174(anf_arg316936173,anf_fun315214054);
}};
$e3616336164.stack[R.EXN_STACKHEIGHT++] = $ss3616736168;
}
if(R.isPyretException($e3616336164)) {
$e3616336164.pyretStack.push(L[4372]);
}
throw $e3616336164;
}
var $ret3616936170 = $Hanf_arg951936174($z3616536166,anf_fun315214054);
++R.GAS;
return $ret3616936170;
};
var $Hanf_arg951936174 = function(anf_arg316936173,anf_fun315214054) {
var $z3617736178 = D;
var $f3618336184 = function(_) {
return R.isFunction(anf_fun315214054)?anf_fun315214054.app(anf_arg316936173):R.ffi.throwNonFunApp(L[2669],anf_fun315214054,[anf_arg316936173]);
};
try {
if(--R.GAS > 0) {
$z3617736178 = $f3618336184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3618336184,
"from":L[2669]});
}
} catch($e3617536176) {
if(R.isCont($e3617536176)) {
var $ss3617936180 = {"from":L[2669],
"go":function(ann_DASH_check_DASH_temp315136185) {
return $Hann_DASH_check_DASH_temp951836186(ann_DASH_check_DASH_temp315136185);
}};
$e3617536176.stack[R.EXN_STACKHEIGHT++] = $ss3617936180;
}
if(R.isPyretException($e3617536176)) {
$e3617536176.pyretStack.push(L[2669]);
}
throw $e3617536176;
}
var $ret3618136182 = $Hann_DASH_check_DASH_temp951836186($z3617736178);
++R.GAS;
return $ret3618136182;
};
var $Hann_DASH_check_DASH_temp951836186 = function(ann_DASH_check_DASH_temp315136185) {
return ann_DASH_check_DASH_temp315136185;
};
var $Hann_DASH_check_DASH_temp951736125 = function(ann_DASH_check_DASH_temp316236124) {
return ann_DASH_check_DASH_temp316236124;
};
var $Hanf_arg951614072 = function(anf_arg313714070,self40014071,_plus55,torepr65) {
var anf_arg313836197 = G(self40014071,"_fun",L[2233]);
var $z3618936190 = D;
var $f3619536196 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg313836197):R.ffi.throwNonFunApp(L[2233],torepr65,[anf_arg313836197]);
};
try {
if(--R.GAS > 0) {
$z3618936190 = $f3619536196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3619536196,
"from":L[2233]});
}
} catch($e3618736188) {
if(R.isCont($e3618736188)) {
var $ss3619136192 = {"from":L[2233],
"go":function(anf_arg313936198) {
return $Hanf_arg951536199(anf_arg313936198,anf_arg313714070,self40014071,_plus55,torepr65);
}};
$e3618736188.stack[R.EXN_STACKHEIGHT++] = $ss3619136192;
}
if(R.isPyretException($e3618736188)) {
$e3618736188.pyretStack.push(L[2233]);
}
throw $e3618736188;
}
var $ret3619336194 = $Hanf_arg951536199($z3618936190,anf_arg313714070,self40014071,_plus55,torepr65);
++R.GAS;
return $ret3619336194;
};
var $Hanf_arg951536199 = function(anf_arg313936198,anf_arg313714070,self40014071,_plus55,torepr65) {
var $z3620236203 = D;
var $f3620836209 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg313936198):R.ffi.throwNonFunApp(L[2233],_plus55,[(", "),anf_arg313936198]);
};
try {
if(--R.GAS > 0) {
$z3620236203 = $f3620836209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3620836209,
"from":L[2233]});
}
} catch($e3620036201) {
if(R.isCont($e3620036201)) {
var $ss3620436205 = {"from":L[2233],
"go":function(anf_arg314036210) {
return $Hanf_arg951436211(anf_arg314036210,anf_arg313714070,self40014071,_plus55,torepr65);
}};
$e3620036201.stack[R.EXN_STACKHEIGHT++] = $ss3620436205;
}
if(R.isPyretException($e3620036201)) {
$e3620036201.pyretStack.push(L[2233]);
}
throw $e3620036201;
}
var $ret3620636207 = $Hanf_arg951436211($z3620236203,anf_arg313714070,self40014071,_plus55,torepr65);
++R.GAS;
return $ret3620636207;
};
var $Hanf_arg951436211 = function(anf_arg314036210,anf_arg313714070,self40014071,_plus55,torepr65) {
var $z3621436215 = D;
var $f3622036221 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg313714070,anf_arg314036210):R.ffi.throwNonFunApp(L[2233],_plus55,[anf_arg313714070,anf_arg314036210]);
};
try {
if(--R.GAS > 0) {
$z3621436215 = $f3622036221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3622036221,
"from":L[2233]});
}
} catch($e3621236213) {
if(R.isCont($e3621236213)) {
var $ss3621636217 = {"from":L[2233],
"go":function(anf_arg314136222) {
return $Hanf_arg951336223(anf_arg314136222,self40014071,_plus55,torepr65);
}};
$e3621236213.stack[R.EXN_STACKHEIGHT++] = $ss3621636217;
}
if(R.isPyretException($e3621236213)) {
$e3621236213.pyretStack.push(L[2233]);
}
throw $e3621236213;
}
var $ret3621836219 = $Hanf_arg951336223($z3621436215,self40014071,_plus55,torepr65);
++R.GAS;
return $ret3621836219;
};
var $Hanf_arg951336223 = function(anf_arg314136222,self40014071,_plus55,torepr65) {
var anf_arg314236234 = G(self40014071,"args",L[2233]);
var $z3622636227 = D;
var $f3623236233 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg314236234):R.ffi.throwNonFunApp(L[2233],torepr65,[anf_arg314236234]);
};
try {
if(--R.GAS > 0) {
$z3622636227 = $f3623236233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3623236233,
"from":L[2233]});
}
} catch($e3622436225) {
if(R.isCont($e3622436225)) {
var $ss3622836229 = {"from":L[2233],
"go":function(anf_arg314336235) {
return $Hanf_arg951236236(anf_arg314336235,anf_arg314136222,_plus55);
}};
$e3622436225.stack[R.EXN_STACKHEIGHT++] = $ss3622836229;
}
if(R.isPyretException($e3622436225)) {
$e3622436225.pyretStack.push(L[2233]);
}
throw $e3622436225;
}
var $ret3623036231 = $Hanf_arg951236236($z3622636227,anf_arg314136222,_plus55);
++R.GAS;
return $ret3623036231;
};
var $Hanf_arg951236236 = function(anf_arg314336235,anf_arg314136222,_plus55) {
var $z3623936240 = D;
var $f3624536246 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg314336235):R.ffi.throwNonFunApp(L[2233],_plus55,[(", "),anf_arg314336235]);
};
try {
if(--R.GAS > 0) {
$z3623936240 = $f3624536246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3624536246,
"from":L[2233]});
}
} catch($e3623736238) {
if(R.isCont($e3623736238)) {
var $ss3624136242 = {"from":L[2233],
"go":function(anf_arg314436247) {
return $Hanf_arg951136248(anf_arg314436247,anf_arg314136222,_plus55);
}};
$e3623736238.stack[R.EXN_STACKHEIGHT++] = $ss3624136242;
}
if(R.isPyretException($e3623736238)) {
$e3623736238.pyretStack.push(L[2233]);
}
throw $e3623736238;
}
var $ret3624336244 = $Hanf_arg951136248($z3623936240,anf_arg314136222,_plus55);
++R.GAS;
return $ret3624336244;
};
var $Hanf_arg951136248 = function(anf_arg314436247,anf_arg314136222,_plus55) {
var $z3625136252 = D;
var $f3625736258 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg314136222,anf_arg314436247):R.ffi.throwNonFunApp(L[2233],_plus55,[anf_arg314136222,anf_arg314436247]);
};
try {
if(--R.GAS > 0) {
$z3625136252 = $f3625736258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3625736258,
"from":L[2233]});
}
} catch($e3624936250) {
if(R.isCont($e3624936250)) {
var $ss3625336254 = {"from":L[2233],
"go":function(anf_arg314536259) {
return $Hanf_arg951036260(anf_arg314536259,_plus55);
}};
$e3624936250.stack[R.EXN_STACKHEIGHT++] = $ss3625336254;
}
if(R.isPyretException($e3624936250)) {
$e3624936250.pyretStack.push(L[2233]);
}
throw $e3624936250;
}
var $ret3625536256 = $Hanf_arg951036260($z3625136252,_plus55);
++R.GAS;
return $ret3625536256;
};
var $Hanf_arg951036260 = function(anf_arg314536259,_plus55) {
var $z3626336264 = D;
var $f3626936270 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg314536259,(")")):R.ffi.throwNonFunApp(L[2233],_plus55,[anf_arg314536259,(")")]);
};
try {
if(--R.GAS > 0) {
$z3626336264 = $f3626936270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3626936270,
"from":L[2233]});
}
} catch($e3626136262) {
if(R.isCont($e3626136262)) {
var $ss3626536266 = {"from":L[2233],
"go":function(anf_arg314636271) {
return $Hanf_arg950936272(anf_arg314636271,_plus55);
}};
$e3626136262.stack[R.EXN_STACKHEIGHT++] = $ss3626536266;
}
if(R.isPyretException($e3626136262)) {
$e3626136262.pyretStack.push(L[2233]);
}
throw $e3626136262;
}
var $ret3626736268 = $Hanf_arg950936272($z3626336264,_plus55);
++R.GAS;
return $ret3626736268;
};
var $Hanf_arg950936272 = function(anf_arg314636271,_plus55) {
var $z3627536276 = D;
var $f3628136282 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg314636271):R.ffi.throwNonFunApp(L[2233],_plus55,[("("),anf_arg314636271]);
};
try {
if(--R.GAS > 0) {
$z3627536276 = $f3628136282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3628136282,
"from":L[2233]});
}
} catch($e3627336274) {
if(R.isCont($e3627336274)) {
var $ss3627736278 = {"from":L[2233],
"go":function(anf_arg314736283) {
return $Hanf_arg950836284(anf_arg314736283,_plus55);
}};
$e3627336274.stack[R.EXN_STACKHEIGHT++] = $ss3627736278;
}
if(R.isPyretException($e3627336274)) {
$e3627336274.pyretStack.push(L[2233]);
}
throw $e3627336274;
}
var $ret3627936280 = $Hanf_arg950836284($z3627536276,_plus55);
++R.GAS;
return $ret3627936280;
};
var $Hanf_arg950836284 = function(anf_arg314736283,_plus55) {
var $z3628736288 = D;
var $f3629336294 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-prim-app"),anf_arg314736283):R.ffi.throwNonFunApp(L[2233],_plus55,[("s-prim-app"),anf_arg314736283]);
};
try {
if(--R.GAS > 0) {
$z3628736288 = $f3629336294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3629336294,
"from":L[2233]});
}
} catch($e3628536286) {
if(R.isCont($e3628536286)) {
var $ss3628936290 = {"from":L[2233],
"go":function(ann_DASH_check_DASH_temp313536295) {
return $Hann_DASH_check_DASH_temp950736296(ann_DASH_check_DASH_temp313536295);
}};
$e3628536286.stack[R.EXN_STACKHEIGHT++] = $ss3628936290;
}
if(R.isPyretException($e3628536286)) {
$e3628536286.pyretStack.push(L[2233]);
}
throw $e3628536286;
}
var $ret3629136292 = $Hann_DASH_check_DASH_temp950736296($z3628736288);
++R.GAS;
return $ret3629136292;
};
var $Hann_DASH_check_DASH_temp950736296 = function(ann_DASH_check_DASH_temp313536295) {
return ann_DASH_check_DASH_temp313536295;
};
var $Hcont_tail_arg950514089 = function(cont_tail_arg313214087,if_helper312214088) {
if(--R.GAS > 0) {
$z3629736298 = R.isFunction(if_helper312214088)?if_helper312214088.app(cont_tail_arg313214087):R.ffi.throwNonFunApp(L[2233],if_helper312214088,[cont_tail_arg313214087]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper312214088)?if_helper312214088.app(cont_tail_arg313214087):R.ffi.throwNonFunApp(L[2233],if_helper312214088,[cont_tail_arg313214087]);
},
"from":L[2233]});
}
++R.GAS;
return $z3629736298;
};
var $Hcont_tail_arg950614104 = function(cont_tail_arg312714103,if_helper312214088) {
if(--R.GAS > 0) {
$z3629936300 = R.isFunction(if_helper312214088)?if_helper312214088.app(cont_tail_arg312714103):R.ffi.throwNonFunApp(L[2233],if_helper312214088,[cont_tail_arg312714103]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper312214088)?if_helper312214088.app(cont_tail_arg312714103):R.ffi.throwNonFunApp(L[2233],if_helper312214088,[cont_tail_arg312714103]);
},
"from":L[2233]});
}
++R.GAS;
return $z3629936300;
};
var $Hanf_arg950414126 = function(anf_arg310514123,INDENT118169,PP170,anf_fun310214124,self87614125,_plus55) {
var anf_fun310636315 = G(PP170,"parens",L[4380]);
var anf_fun310736316 = G(PP170,"nest",L[4379]);
var anf_fun310836317 = G(PP170,"separate",L[4378]);
var anf_arg310936314 = G(PP170,"commabreak",L[4377]);
var anf_bracket311036333 = G(self87614125,"args",L[4376]);
var anf_fun311136311 = G(anf_bracket311036333,"map",L[4375]);
var anf_arg311436312 = R.makeFunction(function(recv_DASH_39536319) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4374],1,arguments);
}
var anf_fun311336330 = G(recv_DASH_39536319,"tosource",L[4374]);
var $z3632236323 = D;
var $f3632836329 = function(_) {
return R.isFunction(anf_fun311336330)?anf_fun311336330.app():R.ffi.throwNonFunApp(L[4374],anf_fun311336330,[]);
};
try {
if(--R.GAS > 0) {
$z3632236323 = $f3632836329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3632836329,
"from":L[4374]});
}
} catch($e3632036321) {
if(R.isCont($e3632036321)) {
var $ss3632436325 = {"from":L[4374],
"go":function(ann_DASH_check_DASH_temp311236331) {
return $Hann_DASH_check_DASH_temp949736332(ann_DASH_check_DASH_temp311236331);
}};
$e3632036321.stack[R.EXN_STACKHEIGHT++] = $ss3632436325;
}
if(R.isPyretException($e3632036321)) {
$e3632036321.pyretStack.push(L[4374]);
}
throw $e3632036321;
}
var $ret3632636327 = $Hann_DASH_check_DASH_temp949736332($z3632236323);
++R.GAS;
return $ret3632636327;
});
var $z3630336304 = D;
var $f3630936310 = function(_) {
return R.isFunction(anf_fun311136311)?anf_fun311136311.app(anf_arg311436312):R.ffi.throwNonFunApp(L[4373],anf_fun311136311,[anf_arg311436312]);
};
try {
if(--R.GAS > 0) {
$z3630336304 = $f3630936310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3630936310,
"from":L[4373]});
}
} catch($e3630136302) {
if(R.isCont($e3630136302)) {
var $ss3630536306 = {"from":L[4373],
"go":function(anf_arg311536313) {
return $Hanf_arg950336318(anf_arg311536313,INDENT118169,anf_arg310514123,anf_arg310936314,anf_fun310214124,anf_fun310636315,anf_fun310736316,anf_fun310836317,_plus55);
}};
$e3630136302.stack[R.EXN_STACKHEIGHT++] = $ss3630536306;
}
if(R.isPyretException($e3630136302)) {
$e3630136302.pyretStack.push(L[4373]);
}
throw $e3630136302;
}
var $ret3630736308 = $Hanf_arg950336318($z3630336304,INDENT118169,anf_arg310514123,anf_arg310936314,anf_fun310214124,anf_fun310636315,anf_fun310736316,anf_fun310836317,_plus55);
++R.GAS;
return $ret3630736308;
};
var $Hanf_arg950336318 = function(anf_arg311536313,INDENT118169,anf_arg310514123,anf_arg310936314,anf_fun310214124,anf_fun310636315,anf_fun310736316,anf_fun310836317,_plus55) {
var $z3633636337 = D;
var $f3634236343 = function(_) {
return R.isFunction(anf_fun310836317)?anf_fun310836317.app(anf_arg310936314,anf_arg311536313):R.ffi.throwNonFunApp(L[4381],anf_fun310836317,[anf_arg310936314,anf_arg311536313]);
};
try {
if(--R.GAS > 0) {
$z3633636337 = $f3634236343();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3634236343,
"from":L[4381]});
}
} catch($e3633436335) {
if(R.isCont($e3633436335)) {
var $ss3633836339 = {"from":L[4381],
"go":function(anf_arg311636344) {
return $Hanf_arg950236345(anf_arg311636344,INDENT118169,anf_arg310514123,anf_fun310214124,anf_fun310636315,anf_fun310736316,_plus55);
}};
$e3633436335.stack[R.EXN_STACKHEIGHT++] = $ss3633836339;
}
if(R.isPyretException($e3633436335)) {
$e3633436335.pyretStack.push(L[4381]);
}
throw $e3633436335;
}
var $ret3634036341 = $Hanf_arg950236345($z3633636337,INDENT118169,anf_arg310514123,anf_fun310214124,anf_fun310636315,anf_fun310736316,_plus55);
++R.GAS;
return $ret3634036341;
};
var $Hanf_arg950236345 = function(anf_arg311636344,INDENT118169,anf_arg310514123,anf_fun310214124,anf_fun310636315,anf_fun310736316,_plus55) {
var $z3634836349 = D;
var $f3635436355 = function(_) {
return R.isFunction(anf_fun310736316)?anf_fun310736316.app(INDENT118169,anf_arg311636344):R.ffi.throwNonFunApp(L[4382],anf_fun310736316,[INDENT118169,anf_arg311636344]);
};
try {
if(--R.GAS > 0) {
$z3634836349 = $f3635436355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3635436355,
"from":L[4382]});
}
} catch($e3634636347) {
if(R.isCont($e3634636347)) {
var $ss3635036351 = {"from":L[4382],
"go":function(anf_arg311736356) {
return $Hanf_arg950136357(anf_arg311736356,anf_arg310514123,anf_fun310214124,anf_fun310636315,_plus55);
}};
$e3634636347.stack[R.EXN_STACKHEIGHT++] = $ss3635036351;
}
if(R.isPyretException($e3634636347)) {
$e3634636347.pyretStack.push(L[4382]);
}
throw $e3634636347;
}
var $ret3635236353 = $Hanf_arg950136357($z3634836349,anf_arg310514123,anf_fun310214124,anf_fun310636315,_plus55);
++R.GAS;
return $ret3635236353;
};
var $Hanf_arg950136357 = function(anf_arg311736356,anf_arg310514123,anf_fun310214124,anf_fun310636315,_plus55) {
var $z3636036361 = D;
var $f3636636367 = function(_) {
return R.isFunction(anf_fun310636315)?anf_fun310636315.app(anf_arg311736356):R.ffi.throwNonFunApp(L[4383],anf_fun310636315,[anf_arg311736356]);
};
try {
if(--R.GAS > 0) {
$z3636036361 = $f3636636367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3636636367,
"from":L[4383]});
}
} catch($e3635836359) {
if(R.isCont($e3635836359)) {
var $ss3636236363 = {"from":L[4383],
"go":function(anf_arg311836368) {
return $Hanf_arg950036369(anf_arg311836368,anf_arg310514123,anf_fun310214124,_plus55);
}};
$e3635836359.stack[R.EXN_STACKHEIGHT++] = $ss3636236363;
}
if(R.isPyretException($e3635836359)) {
$e3635836359.pyretStack.push(L[4383]);
}
throw $e3635836359;
}
var $ret3636436365 = $Hanf_arg950036369($z3636036361,anf_arg310514123,anf_fun310214124,_plus55);
++R.GAS;
return $ret3636436365;
};
var $Hanf_arg950036369 = function(anf_arg311836368,anf_arg310514123,anf_fun310214124,_plus55) {
var $z3637236373 = D;
var $f3637836379 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg310514123,anf_arg311836368):R.ffi.throwNonFunApp(L[4384],_plus55,[anf_arg310514123,anf_arg311836368]);
};
try {
if(--R.GAS > 0) {
$z3637236373 = $f3637836379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3637836379,
"from":L[4384]});
}
} catch($e3637036371) {
if(R.isCont($e3637036371)) {
var $ss3637436375 = {"from":L[4384],
"go":function(anf_arg311936380) {
return $Hanf_arg949936381(anf_arg311936380,anf_fun310214124);
}};
$e3637036371.stack[R.EXN_STACKHEIGHT++] = $ss3637436375;
}
if(R.isPyretException($e3637036371)) {
$e3637036371.pyretStack.push(L[4384]);
}
throw $e3637036371;
}
var $ret3637636377 = $Hanf_arg949936381($z3637236373,anf_fun310214124);
++R.GAS;
return $ret3637636377;
};
var $Hanf_arg949936381 = function(anf_arg311936380,anf_fun310214124) {
var $z3638436385 = D;
var $f3639036391 = function(_) {
return R.isFunction(anf_fun310214124)?anf_fun310214124.app(anf_arg311936380):R.ffi.throwNonFunApp(L[2678],anf_fun310214124,[anf_arg311936380]);
};
try {
if(--R.GAS > 0) {
$z3638436385 = $f3639036391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3639036391,
"from":L[2678]});
}
} catch($e3638236383) {
if(R.isCont($e3638236383)) {
var $ss3638636387 = {"from":L[2678],
"go":function(ann_DASH_check_DASH_temp310136392) {
return $Hann_DASH_check_DASH_temp949836393(ann_DASH_check_DASH_temp310136392);
}};
$e3638236383.stack[R.EXN_STACKHEIGHT++] = $ss3638636387;
}
if(R.isPyretException($e3638236383)) {
$e3638236383.pyretStack.push(L[2678]);
}
throw $e3638236383;
}
var $ret3638836389 = $Hann_DASH_check_DASH_temp949836393($z3638436385);
++R.GAS;
return $ret3638836389;
};
var $Hann_DASH_check_DASH_temp949836393 = function(ann_DASH_check_DASH_temp310136392) {
return ann_DASH_check_DASH_temp310136392;
};
var $Hann_DASH_check_DASH_temp949736332 = function(ann_DASH_check_DASH_temp311236331) {
return ann_DASH_check_DASH_temp311236331;
};
var $Hanf_arg949614143 = function(anf_arg308714141,self39314142,_plus55,torepr65) {
var anf_arg308836404 = G(self39314142,"_fun",L[2234]);
var $z3639636397 = D;
var $f3640236403 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg308836404):R.ffi.throwNonFunApp(L[2234],torepr65,[anf_arg308836404]);
};
try {
if(--R.GAS > 0) {
$z3639636397 = $f3640236403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3640236403,
"from":L[2234]});
}
} catch($e3639436395) {
if(R.isCont($e3639436395)) {
var $ss3639836399 = {"from":L[2234],
"go":function(anf_arg308936405) {
return $Hanf_arg949536406(anf_arg308936405,anf_arg308714141,self39314142,_plus55,torepr65);
}};
$e3639436395.stack[R.EXN_STACKHEIGHT++] = $ss3639836399;
}
if(R.isPyretException($e3639436395)) {
$e3639436395.pyretStack.push(L[2234]);
}
throw $e3639436395;
}
var $ret3640036401 = $Hanf_arg949536406($z3639636397,anf_arg308714141,self39314142,_plus55,torepr65);
++R.GAS;
return $ret3640036401;
};
var $Hanf_arg949536406 = function(anf_arg308936405,anf_arg308714141,self39314142,_plus55,torepr65) {
var $z3640936410 = D;
var $f3641536416 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg308936405):R.ffi.throwNonFunApp(L[2234],_plus55,[(", "),anf_arg308936405]);
};
try {
if(--R.GAS > 0) {
$z3640936410 = $f3641536416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3641536416,
"from":L[2234]});
}
} catch($e3640736408) {
if(R.isCont($e3640736408)) {
var $ss3641136412 = {"from":L[2234],
"go":function(anf_arg309036417) {
return $Hanf_arg949436418(anf_arg309036417,anf_arg308714141,self39314142,_plus55,torepr65);
}};
$e3640736408.stack[R.EXN_STACKHEIGHT++] = $ss3641136412;
}
if(R.isPyretException($e3640736408)) {
$e3640736408.pyretStack.push(L[2234]);
}
throw $e3640736408;
}
var $ret3641336414 = $Hanf_arg949436418($z3640936410,anf_arg308714141,self39314142,_plus55,torepr65);
++R.GAS;
return $ret3641336414;
};
var $Hanf_arg949436418 = function(anf_arg309036417,anf_arg308714141,self39314142,_plus55,torepr65) {
var $z3642136422 = D;
var $f3642736428 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg308714141,anf_arg309036417):R.ffi.throwNonFunApp(L[2234],_plus55,[anf_arg308714141,anf_arg309036417]);
};
try {
if(--R.GAS > 0) {
$z3642136422 = $f3642736428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3642736428,
"from":L[2234]});
}
} catch($e3641936420) {
if(R.isCont($e3641936420)) {
var $ss3642336424 = {"from":L[2234],
"go":function(anf_arg309136429) {
return $Hanf_arg949336430(anf_arg309136429,self39314142,_plus55,torepr65);
}};
$e3641936420.stack[R.EXN_STACKHEIGHT++] = $ss3642336424;
}
if(R.isPyretException($e3641936420)) {
$e3641936420.pyretStack.push(L[2234]);
}
throw $e3641936420;
}
var $ret3642536426 = $Hanf_arg949336430($z3642136422,self39314142,_plus55,torepr65);
++R.GAS;
return $ret3642536426;
};
var $Hanf_arg949336430 = function(anf_arg309136429,self39314142,_plus55,torepr65) {
var anf_arg309236441 = G(self39314142,"args",L[2234]);
var $z3643336434 = D;
var $f3643936440 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg309236441):R.ffi.throwNonFunApp(L[2234],torepr65,[anf_arg309236441]);
};
try {
if(--R.GAS > 0) {
$z3643336434 = $f3643936440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3643936440,
"from":L[2234]});
}
} catch($e3643136432) {
if(R.isCont($e3643136432)) {
var $ss3643536436 = {"from":L[2234],
"go":function(anf_arg309336442) {
return $Hanf_arg949236443(anf_arg309336442,anf_arg309136429,_plus55);
}};
$e3643136432.stack[R.EXN_STACKHEIGHT++] = $ss3643536436;
}
if(R.isPyretException($e3643136432)) {
$e3643136432.pyretStack.push(L[2234]);
}
throw $e3643136432;
}
var $ret3643736438 = $Hanf_arg949236443($z3643336434,anf_arg309136429,_plus55);
++R.GAS;
return $ret3643736438;
};
var $Hanf_arg949236443 = function(anf_arg309336442,anf_arg309136429,_plus55) {
var $z3644636447 = D;
var $f3645236453 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg309336442):R.ffi.throwNonFunApp(L[2234],_plus55,[(", "),anf_arg309336442]);
};
try {
if(--R.GAS > 0) {
$z3644636447 = $f3645236453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3645236453,
"from":L[2234]});
}
} catch($e3644436445) {
if(R.isCont($e3644436445)) {
var $ss3644836449 = {"from":L[2234],
"go":function(anf_arg309436454) {
return $Hanf_arg949136455(anf_arg309436454,anf_arg309136429,_plus55);
}};
$e3644436445.stack[R.EXN_STACKHEIGHT++] = $ss3644836449;
}
if(R.isPyretException($e3644436445)) {
$e3644436445.pyretStack.push(L[2234]);
}
throw $e3644436445;
}
var $ret3645036451 = $Hanf_arg949136455($z3644636447,anf_arg309136429,_plus55);
++R.GAS;
return $ret3645036451;
};
var $Hanf_arg949136455 = function(anf_arg309436454,anf_arg309136429,_plus55) {
var $z3645836459 = D;
var $f3646436465 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg309136429,anf_arg309436454):R.ffi.throwNonFunApp(L[2234],_plus55,[anf_arg309136429,anf_arg309436454]);
};
try {
if(--R.GAS > 0) {
$z3645836459 = $f3646436465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3646436465,
"from":L[2234]});
}
} catch($e3645636457) {
if(R.isCont($e3645636457)) {
var $ss3646036461 = {"from":L[2234],
"go":function(anf_arg309536466) {
return $Hanf_arg949036467(anf_arg309536466,_plus55);
}};
$e3645636457.stack[R.EXN_STACKHEIGHT++] = $ss3646036461;
}
if(R.isPyretException($e3645636457)) {
$e3645636457.pyretStack.push(L[2234]);
}
throw $e3645636457;
}
var $ret3646236463 = $Hanf_arg949036467($z3645836459,_plus55);
++R.GAS;
return $ret3646236463;
};
var $Hanf_arg949036467 = function(anf_arg309536466,_plus55) {
var $z3647036471 = D;
var $f3647636477 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg309536466,(")")):R.ffi.throwNonFunApp(L[2234],_plus55,[anf_arg309536466,(")")]);
};
try {
if(--R.GAS > 0) {
$z3647036471 = $f3647636477();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3647636477,
"from":L[2234]});
}
} catch($e3646836469) {
if(R.isCont($e3646836469)) {
var $ss3647236473 = {"from":L[2234],
"go":function(anf_arg309636478) {
return $Hanf_arg948936479(anf_arg309636478,_plus55);
}};
$e3646836469.stack[R.EXN_STACKHEIGHT++] = $ss3647236473;
}
if(R.isPyretException($e3646836469)) {
$e3646836469.pyretStack.push(L[2234]);
}
throw $e3646836469;
}
var $ret3647436475 = $Hanf_arg948936479($z3647036471,_plus55);
++R.GAS;
return $ret3647436475;
};
var $Hanf_arg948936479 = function(anf_arg309636478,_plus55) {
var $z3648236483 = D;
var $f3648836489 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg309636478):R.ffi.throwNonFunApp(L[2234],_plus55,[("("),anf_arg309636478]);
};
try {
if(--R.GAS > 0) {
$z3648236483 = $f3648836489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3648836489,
"from":L[2234]});
}
} catch($e3648036481) {
if(R.isCont($e3648036481)) {
var $ss3648436485 = {"from":L[2234],
"go":function(anf_arg309736490) {
return $Hanf_arg948836491(anf_arg309736490,_plus55);
}};
$e3648036481.stack[R.EXN_STACKHEIGHT++] = $ss3648436485;
}
if(R.isPyretException($e3648036481)) {
$e3648036481.pyretStack.push(L[2234]);
}
throw $e3648036481;
}
var $ret3648636487 = $Hanf_arg948836491($z3648236483,_plus55);
++R.GAS;
return $ret3648636487;
};
var $Hanf_arg948836491 = function(anf_arg309736490,_plus55) {
var $z3649436495 = D;
var $f3650036501 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-app"),anf_arg309736490):R.ffi.throwNonFunApp(L[2234],_plus55,[("s-app"),anf_arg309736490]);
};
try {
if(--R.GAS > 0) {
$z3649436495 = $f3650036501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3650036501,
"from":L[2234]});
}
} catch($e3649236493) {
if(R.isCont($e3649236493)) {
var $ss3649636497 = {"from":L[2234],
"go":function(ann_DASH_check_DASH_temp308536502) {
return $Hann_DASH_check_DASH_temp948736503(ann_DASH_check_DASH_temp308536502);
}};
$e3649236493.stack[R.EXN_STACKHEIGHT++] = $ss3649636497;
}
if(R.isPyretException($e3649236493)) {
$e3649236493.pyretStack.push(L[2234]);
}
throw $e3649236493;
}
var $ret3649836499 = $Hann_DASH_check_DASH_temp948736503($z3649436495);
++R.GAS;
return $ret3649836499;
};
var $Hann_DASH_check_DASH_temp948736503 = function(ann_DASH_check_DASH_temp308536502) {
return ann_DASH_check_DASH_temp308536502;
};
var $Hcont_tail_arg948514160 = function(cont_tail_arg308214158,if_helper307214159) {
if(--R.GAS > 0) {
$z3650436505 = R.isFunction(if_helper307214159)?if_helper307214159.app(cont_tail_arg308214158):R.ffi.throwNonFunApp(L[2234],if_helper307214159,[cont_tail_arg308214158]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper307214159)?if_helper307214159.app(cont_tail_arg308214158):R.ffi.throwNonFunApp(L[2234],if_helper307214159,[cont_tail_arg308214158]);
},
"from":L[2234]});
}
++R.GAS;
return $z3650436505;
};
var $Hcont_tail_arg948614175 = function(cont_tail_arg307714174,if_helper307214159) {
if(--R.GAS > 0) {
$z3650636507 = R.isFunction(if_helper307214159)?if_helper307214159.app(cont_tail_arg307714174):R.ffi.throwNonFunApp(L[2234],if_helper307214159,[cont_tail_arg307714174]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper307214159)?if_helper307214159.app(cont_tail_arg307714174):R.ffi.throwNonFunApp(L[2234],if_helper307214159,[cont_tail_arg307714174]);
},
"from":L[2234]});
}
++R.GAS;
return $z3650636507;
};
var $Hanf_array_val948414198 = function(anf_array_val306514194,anf_fun306114195,anf_fun306214196,self87114197,str_DASH_as123221,str_DASH_bless178936) {
var anf_bracket306636521 = G(self87114197,"typ",L[4387]);
var anf_fun306736518 = G(anf_bracket306636521,"tosource",L[4386]);
var $z3651036511 = D;
var $f3651636517 = function(_) {
return R.isFunction(anf_fun306736518)?anf_fun306736518.app():R.ffi.throwNonFunApp(L[4385],anf_fun306736518,[]);
};
try {
if(--R.GAS > 0) {
$z3651036511 = $f3651636517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3651636517,
"from":L[4385]});
}
} catch($e3650836509) {
if(R.isCont($e3650836509)) {
var $ss3651236513 = {"from":L[4385],
"go":function(anf_array_val306836519) {
return $Hanf_array_val948336520(anf_array_val306836519,anf_array_val306514194,anf_fun306114195,anf_fun306214196,str_DASH_as123221,str_DASH_bless178936);
}};
$e3650836509.stack[R.EXN_STACKHEIGHT++] = $ss3651236513;
}
if(R.isPyretException($e3650836509)) {
$e3650836509.pyretStack.push(L[4385]);
}
throw $e3650836509;
}
var $ret3651436515 = $Hanf_array_val948336520($z3651036511,anf_array_val306514194,anf_fun306114195,anf_fun306214196,str_DASH_as123221,str_DASH_bless178936);
++R.GAS;
return $ret3651436515;
};
var $Hanf_array_val948336520 = function(anf_array_val306836519,anf_array_val306514194,anf_fun306114195,anf_fun306214196,str_DASH_as123221,str_DASH_bless178936) {
var $z3652436525 = D;
var $f3653036531 = function(_) {
return R.isFunction(anf_fun306214196)?anf_fun306214196.app([str_DASH_bless178936,anf_array_val306514194,str_DASH_as123221,anf_array_val306836519]):R.ffi.throwNonFunApp(L[2686],anf_fun306214196,[[str_DASH_bless178936,anf_array_val306514194,str_DASH_as123221,anf_array_val306836519]]);
};
try {
if(--R.GAS > 0) {
$z3652436525 = $f3653036531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3653036531,
"from":L[2686]});
}
} catch($e3652236523) {
if(R.isCont($e3652236523)) {
var $ss3652636527 = {"from":L[2686],
"go":function(anf_arg306936532) {
return $Hanf_arg948236533(anf_arg306936532,anf_fun306114195);
}};
$e3652236523.stack[R.EXN_STACKHEIGHT++] = $ss3652636527;
}
if(R.isPyretException($e3652236523)) {
$e3652236523.pyretStack.push(L[2686]);
}
throw $e3652236523;
}
var $ret3652836529 = $Hanf_arg948236533($z3652436525,anf_fun306114195);
++R.GAS;
return $ret3652836529;
};
var $Hanf_arg948236533 = function(anf_arg306936532,anf_fun306114195) {
var $z3653636537 = D;
var $f3654236543 = function(_) {
return R.isFunction(anf_fun306114195)?anf_fun306114195.app(anf_arg306936532):R.ffi.throwNonFunApp(L[2688],anf_fun306114195,[anf_arg306936532]);
};
try {
if(--R.GAS > 0) {
$z3653636537 = $f3654236543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3654236543,
"from":L[2688]});
}
} catch($e3653436535) {
if(R.isCont($e3653436535)) {
var $ss3653836539 = {"from":L[2688],
"go":function(ann_DASH_check_DASH_temp306036544) {
return $Hann_DASH_check_DASH_temp948136545(ann_DASH_check_DASH_temp306036544);
}};
$e3653436535.stack[R.EXN_STACKHEIGHT++] = $ss3653836539;
}
if(R.isPyretException($e3653436535)) {
$e3653436535.pyretStack.push(L[2688]);
}
throw $e3653436535;
}
var $ret3654036541 = $Hann_DASH_check_DASH_temp948136545($z3653636537);
++R.GAS;
return $ret3654036541;
};
var $Hann_DASH_check_DASH_temp948136545 = function(ann_DASH_check_DASH_temp306036544) {
return ann_DASH_check_DASH_temp306036544;
};
var $Hanf_arg948014215 = function(anf_arg304614213,self38714214,_plus55,torepr65) {
var anf_arg304736556 = G(self38714214,"expr",L[2235]);
var $z3654836549 = D;
var $f3655436555 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg304736556):R.ffi.throwNonFunApp(L[2235],torepr65,[anf_arg304736556]);
};
try {
if(--R.GAS > 0) {
$z3654836549 = $f3655436555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3655436555,
"from":L[2235]});
}
} catch($e3654636547) {
if(R.isCont($e3654636547)) {
var $ss3655036551 = {"from":L[2235],
"go":function(anf_arg304836557) {
return $Hanf_arg947936558(anf_arg304836557,anf_arg304614213,self38714214,_plus55,torepr65);
}};
$e3654636547.stack[R.EXN_STACKHEIGHT++] = $ss3655036551;
}
if(R.isPyretException($e3654636547)) {
$e3654636547.pyretStack.push(L[2235]);
}
throw $e3654636547;
}
var $ret3655236553 = $Hanf_arg947936558($z3654836549,anf_arg304614213,self38714214,_plus55,torepr65);
++R.GAS;
return $ret3655236553;
};
var $Hanf_arg947936558 = function(anf_arg304836557,anf_arg304614213,self38714214,_plus55,torepr65) {
var $z3656136562 = D;
var $f3656736568 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg304836557):R.ffi.throwNonFunApp(L[2235],_plus55,[(", "),anf_arg304836557]);
};
try {
if(--R.GAS > 0) {
$z3656136562 = $f3656736568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3656736568,
"from":L[2235]});
}
} catch($e3655936560) {
if(R.isCont($e3655936560)) {
var $ss3656336564 = {"from":L[2235],
"go":function(anf_arg304936569) {
return $Hanf_arg947836570(anf_arg304936569,anf_arg304614213,self38714214,_plus55,torepr65);
}};
$e3655936560.stack[R.EXN_STACKHEIGHT++] = $ss3656336564;
}
if(R.isPyretException($e3655936560)) {
$e3655936560.pyretStack.push(L[2235]);
}
throw $e3655936560;
}
var $ret3656536566 = $Hanf_arg947836570($z3656136562,anf_arg304614213,self38714214,_plus55,torepr65);
++R.GAS;
return $ret3656536566;
};
var $Hanf_arg947836570 = function(anf_arg304936569,anf_arg304614213,self38714214,_plus55,torepr65) {
var $z3657336574 = D;
var $f3657936580 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg304614213,anf_arg304936569):R.ffi.throwNonFunApp(L[2235],_plus55,[anf_arg304614213,anf_arg304936569]);
};
try {
if(--R.GAS > 0) {
$z3657336574 = $f3657936580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3657936580,
"from":L[2235]});
}
} catch($e3657136572) {
if(R.isCont($e3657136572)) {
var $ss3657536576 = {"from":L[2235],
"go":function(anf_arg305036581) {
return $Hanf_arg947736582(anf_arg305036581,self38714214,_plus55,torepr65);
}};
$e3657136572.stack[R.EXN_STACKHEIGHT++] = $ss3657536576;
}
if(R.isPyretException($e3657136572)) {
$e3657136572.pyretStack.push(L[2235]);
}
throw $e3657136572;
}
var $ret3657736578 = $Hanf_arg947736582($z3657336574,self38714214,_plus55,torepr65);
++R.GAS;
return $ret3657736578;
};
var $Hanf_arg947736582 = function(anf_arg305036581,self38714214,_plus55,torepr65) {
var anf_arg305136593 = G(self38714214,"typ",L[2235]);
var $z3658536586 = D;
var $f3659136592 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg305136593):R.ffi.throwNonFunApp(L[2235],torepr65,[anf_arg305136593]);
};
try {
if(--R.GAS > 0) {
$z3658536586 = $f3659136592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3659136592,
"from":L[2235]});
}
} catch($e3658336584) {
if(R.isCont($e3658336584)) {
var $ss3658736588 = {"from":L[2235],
"go":function(anf_arg305236594) {
return $Hanf_arg947636595(anf_arg305236594,anf_arg305036581,_plus55);
}};
$e3658336584.stack[R.EXN_STACKHEIGHT++] = $ss3658736588;
}
if(R.isPyretException($e3658336584)) {
$e3658336584.pyretStack.push(L[2235]);
}
throw $e3658336584;
}
var $ret3658936590 = $Hanf_arg947636595($z3658536586,anf_arg305036581,_plus55);
++R.GAS;
return $ret3658936590;
};
var $Hanf_arg947636595 = function(anf_arg305236594,anf_arg305036581,_plus55) {
var $z3659836599 = D;
var $f3660436605 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg305236594):R.ffi.throwNonFunApp(L[2235],_plus55,[(", "),anf_arg305236594]);
};
try {
if(--R.GAS > 0) {
$z3659836599 = $f3660436605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3660436605,
"from":L[2235]});
}
} catch($e3659636597) {
if(R.isCont($e3659636597)) {
var $ss3660036601 = {"from":L[2235],
"go":function(anf_arg305336606) {
return $Hanf_arg947536607(anf_arg305336606,anf_arg305036581,_plus55);
}};
$e3659636597.stack[R.EXN_STACKHEIGHT++] = $ss3660036601;
}
if(R.isPyretException($e3659636597)) {
$e3659636597.pyretStack.push(L[2235]);
}
throw $e3659636597;
}
var $ret3660236603 = $Hanf_arg947536607($z3659836599,anf_arg305036581,_plus55);
++R.GAS;
return $ret3660236603;
};
var $Hanf_arg947536607 = function(anf_arg305336606,anf_arg305036581,_plus55) {
var $z3661036611 = D;
var $f3661636617 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg305036581,anf_arg305336606):R.ffi.throwNonFunApp(L[2235],_plus55,[anf_arg305036581,anf_arg305336606]);
};
try {
if(--R.GAS > 0) {
$z3661036611 = $f3661636617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3661636617,
"from":L[2235]});
}
} catch($e3660836609) {
if(R.isCont($e3660836609)) {
var $ss3661236613 = {"from":L[2235],
"go":function(anf_arg305436618) {
return $Hanf_arg947436619(anf_arg305436618,_plus55);
}};
$e3660836609.stack[R.EXN_STACKHEIGHT++] = $ss3661236613;
}
if(R.isPyretException($e3660836609)) {
$e3660836609.pyretStack.push(L[2235]);
}
throw $e3660836609;
}
var $ret3661436615 = $Hanf_arg947436619($z3661036611,_plus55);
++R.GAS;
return $ret3661436615;
};
var $Hanf_arg947436619 = function(anf_arg305436618,_plus55) {
var $z3662236623 = D;
var $f3662836629 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg305436618,(")")):R.ffi.throwNonFunApp(L[2235],_plus55,[anf_arg305436618,(")")]);
};
try {
if(--R.GAS > 0) {
$z3662236623 = $f3662836629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3662836629,
"from":L[2235]});
}
} catch($e3662036621) {
if(R.isCont($e3662036621)) {
var $ss3662436625 = {"from":L[2235],
"go":function(anf_arg305536630) {
return $Hanf_arg947336631(anf_arg305536630,_plus55);
}};
$e3662036621.stack[R.EXN_STACKHEIGHT++] = $ss3662436625;
}
if(R.isPyretException($e3662036621)) {
$e3662036621.pyretStack.push(L[2235]);
}
throw $e3662036621;
}
var $ret3662636627 = $Hanf_arg947336631($z3662236623,_plus55);
++R.GAS;
return $ret3662636627;
};
var $Hanf_arg947336631 = function(anf_arg305536630,_plus55) {
var $z3663436635 = D;
var $f3664036641 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg305536630):R.ffi.throwNonFunApp(L[2235],_plus55,[("("),anf_arg305536630]);
};
try {
if(--R.GAS > 0) {
$z3663436635 = $f3664036641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3664036641,
"from":L[2235]});
}
} catch($e3663236633) {
if(R.isCont($e3663236633)) {
var $ss3663636637 = {"from":L[2235],
"go":function(anf_arg305636642) {
return $Hanf_arg947236643(anf_arg305636642,_plus55);
}};
$e3663236633.stack[R.EXN_STACKHEIGHT++] = $ss3663636637;
}
if(R.isPyretException($e3663236633)) {
$e3663236633.pyretStack.push(L[2235]);
}
throw $e3663236633;
}
var $ret3663836639 = $Hanf_arg947236643($z3663436635,_plus55);
++R.GAS;
return $ret3663836639;
};
var $Hanf_arg947236643 = function(anf_arg305636642,_plus55) {
var $z3664636647 = D;
var $f3665236653 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-bless"),anf_arg305636642):R.ffi.throwNonFunApp(L[2235],_plus55,[("s-bless"),anf_arg305636642]);
};
try {
if(--R.GAS > 0) {
$z3664636647 = $f3665236653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3665236653,
"from":L[2235]});
}
} catch($e3664436645) {
if(R.isCont($e3664436645)) {
var $ss3664836649 = {"from":L[2235],
"go":function(ann_DASH_check_DASH_temp304436654) {
return $Hann_DASH_check_DASH_temp947136655(ann_DASH_check_DASH_temp304436654);
}};
$e3664436645.stack[R.EXN_STACKHEIGHT++] = $ss3664836649;
}
if(R.isPyretException($e3664436645)) {
$e3664436645.pyretStack.push(L[2235]);
}
throw $e3664436645;
}
var $ret3665036651 = $Hann_DASH_check_DASH_temp947136655($z3664636647);
++R.GAS;
return $ret3665036651;
};
var $Hann_DASH_check_DASH_temp947136655 = function(ann_DASH_check_DASH_temp304436654) {
return ann_DASH_check_DASH_temp304436654;
};
var $Hcont_tail_arg946914232 = function(cont_tail_arg304114230,if_helper303114231) {
if(--R.GAS > 0) {
$z3665636657 = R.isFunction(if_helper303114231)?if_helper303114231.app(cont_tail_arg304114230):R.ffi.throwNonFunApp(L[2235],if_helper303114231,[cont_tail_arg304114230]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper303114231)?if_helper303114231.app(cont_tail_arg304114230):R.ffi.throwNonFunApp(L[2235],if_helper303114231,[cont_tail_arg304114230]);
},
"from":L[2235]});
}
++R.GAS;
return $z3665636657;
};
var $Hcont_tail_arg947014247 = function(cont_tail_arg303614246,if_helper303114231) {
if(--R.GAS > 0) {
$z3665836659 = R.isFunction(if_helper303114231)?if_helper303114231.app(cont_tail_arg303614246):R.ffi.throwNonFunApp(L[2235],if_helper303114231,[cont_tail_arg303614246]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper303114231)?if_helper303114231.app(cont_tail_arg303614246):R.ffi.throwNonFunApp(L[2235],if_helper303114231,[cont_tail_arg303614246]);
},
"from":L[2235]});
}
++R.GAS;
return $z3665836659;
};
var $Hanf_array_val946814270 = function(anf_array_val302414266,anf_fun302014267,anf_fun302114268,self86614269,str_DASH_as123221,str_DASH_confirm179949) {
var anf_bracket302536673 = G(self86614269,"typ",L[4390]);
var anf_fun302636670 = G(anf_bracket302536673,"tosource",L[4389]);
var $z3666236663 = D;
var $f3666836669 = function(_) {
return R.isFunction(anf_fun302636670)?anf_fun302636670.app():R.ffi.throwNonFunApp(L[4388],anf_fun302636670,[]);
};
try {
if(--R.GAS > 0) {
$z3666236663 = $f3666836669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3666836669,
"from":L[4388]});
}
} catch($e3666036661) {
if(R.isCont($e3666036661)) {
var $ss3666436665 = {"from":L[4388],
"go":function(anf_array_val302736671) {
return $Hanf_array_val946736672(anf_array_val302736671,anf_array_val302414266,anf_fun302014267,anf_fun302114268,str_DASH_as123221,str_DASH_confirm179949);
}};
$e3666036661.stack[R.EXN_STACKHEIGHT++] = $ss3666436665;
}
if(R.isPyretException($e3666036661)) {
$e3666036661.pyretStack.push(L[4388]);
}
throw $e3666036661;
}
var $ret3666636667 = $Hanf_array_val946736672($z3666236663,anf_array_val302414266,anf_fun302014267,anf_fun302114268,str_DASH_as123221,str_DASH_confirm179949);
++R.GAS;
return $ret3666636667;
};
var $Hanf_array_val946736672 = function(anf_array_val302736671,anf_array_val302414266,anf_fun302014267,anf_fun302114268,str_DASH_as123221,str_DASH_confirm179949) {
var $z3667636677 = D;
var $f3668236683 = function(_) {
return R.isFunction(anf_fun302114268)?anf_fun302114268.app([str_DASH_confirm179949,anf_array_val302414266,str_DASH_as123221,anf_array_val302736671]):R.ffi.throwNonFunApp(L[2696],anf_fun302114268,[[str_DASH_confirm179949,anf_array_val302414266,str_DASH_as123221,anf_array_val302736671]]);
};
try {
if(--R.GAS > 0) {
$z3667636677 = $f3668236683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3668236683,
"from":L[2696]});
}
} catch($e3667436675) {
if(R.isCont($e3667436675)) {
var $ss3667836679 = {"from":L[2696],
"go":function(anf_arg302836684) {
return $Hanf_arg946636685(anf_arg302836684,anf_fun302014267);
}};
$e3667436675.stack[R.EXN_STACKHEIGHT++] = $ss3667836679;
}
if(R.isPyretException($e3667436675)) {
$e3667436675.pyretStack.push(L[2696]);
}
throw $e3667436675;
}
var $ret3668036681 = $Hanf_arg946636685($z3667636677,anf_fun302014267);
++R.GAS;
return $ret3668036681;
};
var $Hanf_arg946636685 = function(anf_arg302836684,anf_fun302014267) {
var $z3668836689 = D;
var $f3669436695 = function(_) {
return R.isFunction(anf_fun302014267)?anf_fun302014267.app(anf_arg302836684):R.ffi.throwNonFunApp(L[2698],anf_fun302014267,[anf_arg302836684]);
};
try {
if(--R.GAS > 0) {
$z3668836689 = $f3669436695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3669436695,
"from":L[2698]});
}
} catch($e3668636687) {
if(R.isCont($e3668636687)) {
var $ss3669036691 = {"from":L[2698],
"go":function(ann_DASH_check_DASH_temp301936696) {
return $Hann_DASH_check_DASH_temp946536697(ann_DASH_check_DASH_temp301936696);
}};
$e3668636687.stack[R.EXN_STACKHEIGHT++] = $ss3669036691;
}
if(R.isPyretException($e3668636687)) {
$e3668636687.pyretStack.push(L[2698]);
}
throw $e3668636687;
}
var $ret3669236693 = $Hann_DASH_check_DASH_temp946536697($z3668836689);
++R.GAS;
return $ret3669236693;
};
var $Hann_DASH_check_DASH_temp946536697 = function(ann_DASH_check_DASH_temp301936696) {
return ann_DASH_check_DASH_temp301936696;
};
var $Hanf_arg946414287 = function(anf_arg300514285,self38114286,_plus55,torepr65) {
var anf_arg300636708 = G(self38114286,"expr",L[2236]);
var $z3670036701 = D;
var $f3670636707 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg300636708):R.ffi.throwNonFunApp(L[2236],torepr65,[anf_arg300636708]);
};
try {
if(--R.GAS > 0) {
$z3670036701 = $f3670636707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3670636707,
"from":L[2236]});
}
} catch($e3669836699) {
if(R.isCont($e3669836699)) {
var $ss3670236703 = {"from":L[2236],
"go":function(anf_arg300736709) {
return $Hanf_arg946336710(anf_arg300736709,anf_arg300514285,self38114286,_plus55,torepr65);
}};
$e3669836699.stack[R.EXN_STACKHEIGHT++] = $ss3670236703;
}
if(R.isPyretException($e3669836699)) {
$e3669836699.pyretStack.push(L[2236]);
}
throw $e3669836699;
}
var $ret3670436705 = $Hanf_arg946336710($z3670036701,anf_arg300514285,self38114286,_plus55,torepr65);
++R.GAS;
return $ret3670436705;
};
var $Hanf_arg946336710 = function(anf_arg300736709,anf_arg300514285,self38114286,_plus55,torepr65) {
var $z3671336714 = D;
var $f3671936720 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg300736709):R.ffi.throwNonFunApp(L[2236],_plus55,[(", "),anf_arg300736709]);
};
try {
if(--R.GAS > 0) {
$z3671336714 = $f3671936720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3671936720,
"from":L[2236]});
}
} catch($e3671136712) {
if(R.isCont($e3671136712)) {
var $ss3671536716 = {"from":L[2236],
"go":function(anf_arg300836721) {
return $Hanf_arg946236722(anf_arg300836721,anf_arg300514285,self38114286,_plus55,torepr65);
}};
$e3671136712.stack[R.EXN_STACKHEIGHT++] = $ss3671536716;
}
if(R.isPyretException($e3671136712)) {
$e3671136712.pyretStack.push(L[2236]);
}
throw $e3671136712;
}
var $ret3671736718 = $Hanf_arg946236722($z3671336714,anf_arg300514285,self38114286,_plus55,torepr65);
++R.GAS;
return $ret3671736718;
};
var $Hanf_arg946236722 = function(anf_arg300836721,anf_arg300514285,self38114286,_plus55,torepr65) {
var $z3672536726 = D;
var $f3673136732 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg300514285,anf_arg300836721):R.ffi.throwNonFunApp(L[2236],_plus55,[anf_arg300514285,anf_arg300836721]);
};
try {
if(--R.GAS > 0) {
$z3672536726 = $f3673136732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3673136732,
"from":L[2236]});
}
} catch($e3672336724) {
if(R.isCont($e3672336724)) {
var $ss3672736728 = {"from":L[2236],
"go":function(anf_arg300936733) {
return $Hanf_arg946136734(anf_arg300936733,self38114286,_plus55,torepr65);
}};
$e3672336724.stack[R.EXN_STACKHEIGHT++] = $ss3672736728;
}
if(R.isPyretException($e3672336724)) {
$e3672336724.pyretStack.push(L[2236]);
}
throw $e3672336724;
}
var $ret3672936730 = $Hanf_arg946136734($z3672536726,self38114286,_plus55,torepr65);
++R.GAS;
return $ret3672936730;
};
var $Hanf_arg946136734 = function(anf_arg300936733,self38114286,_plus55,torepr65) {
var anf_arg301036745 = G(self38114286,"typ",L[2236]);
var $z3673736738 = D;
var $f3674336744 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg301036745):R.ffi.throwNonFunApp(L[2236],torepr65,[anf_arg301036745]);
};
try {
if(--R.GAS > 0) {
$z3673736738 = $f3674336744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3674336744,
"from":L[2236]});
}
} catch($e3673536736) {
if(R.isCont($e3673536736)) {
var $ss3673936740 = {"from":L[2236],
"go":function(anf_arg301136746) {
return $Hanf_arg946036747(anf_arg301136746,anf_arg300936733,_plus55);
}};
$e3673536736.stack[R.EXN_STACKHEIGHT++] = $ss3673936740;
}
if(R.isPyretException($e3673536736)) {
$e3673536736.pyretStack.push(L[2236]);
}
throw $e3673536736;
}
var $ret3674136742 = $Hanf_arg946036747($z3673736738,anf_arg300936733,_plus55);
++R.GAS;
return $ret3674136742;
};
var $Hanf_arg946036747 = function(anf_arg301136746,anf_arg300936733,_plus55) {
var $z3675036751 = D;
var $f3675636757 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg301136746):R.ffi.throwNonFunApp(L[2236],_plus55,[(", "),anf_arg301136746]);
};
try {
if(--R.GAS > 0) {
$z3675036751 = $f3675636757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3675636757,
"from":L[2236]});
}
} catch($e3674836749) {
if(R.isCont($e3674836749)) {
var $ss3675236753 = {"from":L[2236],
"go":function(anf_arg301236758) {
return $Hanf_arg945936759(anf_arg301236758,anf_arg300936733,_plus55);
}};
$e3674836749.stack[R.EXN_STACKHEIGHT++] = $ss3675236753;
}
if(R.isPyretException($e3674836749)) {
$e3674836749.pyretStack.push(L[2236]);
}
throw $e3674836749;
}
var $ret3675436755 = $Hanf_arg945936759($z3675036751,anf_arg300936733,_plus55);
++R.GAS;
return $ret3675436755;
};
var $Hanf_arg945936759 = function(anf_arg301236758,anf_arg300936733,_plus55) {
var $z3676236763 = D;
var $f3676836769 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg300936733,anf_arg301236758):R.ffi.throwNonFunApp(L[2236],_plus55,[anf_arg300936733,anf_arg301236758]);
};
try {
if(--R.GAS > 0) {
$z3676236763 = $f3676836769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3676836769,
"from":L[2236]});
}
} catch($e3676036761) {
if(R.isCont($e3676036761)) {
var $ss3676436765 = {"from":L[2236],
"go":function(anf_arg301336770) {
return $Hanf_arg945836771(anf_arg301336770,_plus55);
}};
$e3676036761.stack[R.EXN_STACKHEIGHT++] = $ss3676436765;
}
if(R.isPyretException($e3676036761)) {
$e3676036761.pyretStack.push(L[2236]);
}
throw $e3676036761;
}
var $ret3676636767 = $Hanf_arg945836771($z3676236763,_plus55);
++R.GAS;
return $ret3676636767;
};
var $Hanf_arg945836771 = function(anf_arg301336770,_plus55) {
var $z3677436775 = D;
var $f3678036781 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg301336770,(")")):R.ffi.throwNonFunApp(L[2236],_plus55,[anf_arg301336770,(")")]);
};
try {
if(--R.GAS > 0) {
$z3677436775 = $f3678036781();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3678036781,
"from":L[2236]});
}
} catch($e3677236773) {
if(R.isCont($e3677236773)) {
var $ss3677636777 = {"from":L[2236],
"go":function(anf_arg301436782) {
return $Hanf_arg945736783(anf_arg301436782,_plus55);
}};
$e3677236773.stack[R.EXN_STACKHEIGHT++] = $ss3677636777;
}
if(R.isPyretException($e3677236773)) {
$e3677236773.pyretStack.push(L[2236]);
}
throw $e3677236773;
}
var $ret3677836779 = $Hanf_arg945736783($z3677436775,_plus55);
++R.GAS;
return $ret3677836779;
};
var $Hanf_arg945736783 = function(anf_arg301436782,_plus55) {
var $z3678636787 = D;
var $f3679236793 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg301436782):R.ffi.throwNonFunApp(L[2236],_plus55,[("("),anf_arg301436782]);
};
try {
if(--R.GAS > 0) {
$z3678636787 = $f3679236793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3679236793,
"from":L[2236]});
}
} catch($e3678436785) {
if(R.isCont($e3678436785)) {
var $ss3678836789 = {"from":L[2236],
"go":function(anf_arg301536794) {
return $Hanf_arg945636795(anf_arg301536794,_plus55);
}};
$e3678436785.stack[R.EXN_STACKHEIGHT++] = $ss3678836789;
}
if(R.isPyretException($e3678436785)) {
$e3678436785.pyretStack.push(L[2236]);
}
throw $e3678436785;
}
var $ret3679036791 = $Hanf_arg945636795($z3678636787,_plus55);
++R.GAS;
return $ret3679036791;
};
var $Hanf_arg945636795 = function(anf_arg301536794,_plus55) {
var $z3679836799 = D;
var $f3680436805 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-confirm"),anf_arg301536794):R.ffi.throwNonFunApp(L[2236],_plus55,[("s-confirm"),anf_arg301536794]);
};
try {
if(--R.GAS > 0) {
$z3679836799 = $f3680436805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3680436805,
"from":L[2236]});
}
} catch($e3679636797) {
if(R.isCont($e3679636797)) {
var $ss3680036801 = {"from":L[2236],
"go":function(ann_DASH_check_DASH_temp300336806) {
return $Hann_DASH_check_DASH_temp945536807(ann_DASH_check_DASH_temp300336806);
}};
$e3679636797.stack[R.EXN_STACKHEIGHT++] = $ss3680036801;
}
if(R.isPyretException($e3679636797)) {
$e3679636797.pyretStack.push(L[2236]);
}
throw $e3679636797;
}
var $ret3680236803 = $Hann_DASH_check_DASH_temp945536807($z3679836799);
++R.GAS;
return $ret3680236803;
};
var $Hann_DASH_check_DASH_temp945536807 = function(ann_DASH_check_DASH_temp300336806) {
return ann_DASH_check_DASH_temp300336806;
};
var $Hcont_tail_arg945314304 = function(cont_tail_arg300014302,if_helper299014303) {
if(--R.GAS > 0) {
$z3680836809 = R.isFunction(if_helper299014303)?if_helper299014303.app(cont_tail_arg300014302):R.ffi.throwNonFunApp(L[2236],if_helper299014303,[cont_tail_arg300014302]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper299014303)?if_helper299014303.app(cont_tail_arg300014302):R.ffi.throwNonFunApp(L[2236],if_helper299014303,[cont_tail_arg300014302]);
},
"from":L[2236]});
}
++R.GAS;
return $z3680836809;
};
var $Hcont_tail_arg945414319 = function(cont_tail_arg299514318,if_helper299014303) {
if(--R.GAS > 0) {
$z3681036811 = R.isFunction(if_helper299014303)?if_helper299014303.app(cont_tail_arg299514318):R.ffi.throwNonFunApp(L[2236],if_helper299014303,[cont_tail_arg299514318]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper299014303)?if_helper299014303.app(cont_tail_arg299514318):R.ffi.throwNonFunApp(L[2236],if_helper299014303,[cont_tail_arg299514318]);
},
"from":L[2236]});
}
++R.GAS;
return $z3681036811;
};
var $Hanf_arg945214343 = function(anf_arg295414338,INDENT118169,PP170,anf_arg295014339,anf_fun295114340,anf_fun295214341,is_DASH_empty26152,list25154,self86014342,str_DASH_colonspace136390,_plus55) {
var anf_fun295536824 = G(list25154,"make",L[4394]);
var anf_bracket295636826 = G(self86014342,"modifier",L[4393]);
var anf_fun295736822 = G(anf_bracket295636826,"tosource",L[4392]);
var $z3681436815 = D;
var $f3682036821 = function(_) {
return R.isFunction(anf_fun295736822)?anf_fun295736822.app():R.ffi.throwNonFunApp(L[4391],anf_fun295736822,[]);
};
try {
if(--R.GAS > 0) {
$z3681436815 = $f3682036821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3682036821,
"from":L[4391]});
}
} catch($e3681236813) {
if(R.isCont($e3681236813)) {
var $ss3681636817 = {"from":L[4391],
"go":function(anf_array_val295836823) {
return $Hanf_array_val945136825(anf_array_val295836823,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_fun295114340,anf_fun295214341,anf_fun295536824,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
}};
$e3681236813.stack[R.EXN_STACKHEIGHT++] = $ss3681636817;
}
if(R.isPyretException($e3681236813)) {
$e3681236813.pyretStack.push(L[4391]);
}
throw $e3681236813;
}
var $ret3681836819 = $Hanf_array_val945136825($z3681436815,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_fun295114340,anf_fun295214341,anf_fun295536824,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3681836819;
};
var $Hanf_array_val945136825 = function(anf_array_val295836823,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_fun295114340,anf_fun295214341,anf_fun295536824,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55) {
var anf_bracket295936840 = G(self86014342,"constructor",L[4397]);
var anf_fun296036837 = G(anf_bracket295936840,"tosource",L[4396]);
var $z3682936830 = D;
var $f3683536836 = function(_) {
return R.isFunction(anf_fun296036837)?anf_fun296036837.app():R.ffi.throwNonFunApp(L[4395],anf_fun296036837,[]);
};
try {
if(--R.GAS > 0) {
$z3682936830 = $f3683536836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3683536836,
"from":L[4395]});
}
} catch($e3682736828) {
if(R.isCont($e3682736828)) {
var $ss3683136832 = {"from":L[4395],
"go":function(anf_array_val296136838) {
return $Hanf_array_val945036839(anf_array_val296136838,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_array_val295836823,anf_fun295114340,anf_fun295214341,anf_fun295536824,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
}};
$e3682736828.stack[R.EXN_STACKHEIGHT++] = $ss3683136832;
}
if(R.isPyretException($e3682736828)) {
$e3682736828.pyretStack.push(L[4395]);
}
throw $e3682736828;
}
var $ret3683336834 = $Hanf_array_val945036839($z3682936830,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_array_val295836823,anf_fun295114340,anf_fun295214341,anf_fun295536824,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3683336834;
};
var $Hanf_array_val945036839 = function(anf_array_val296136838,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_array_val295836823,anf_fun295114340,anf_fun295214341,anf_fun295536824,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55) {
var $z3684336844 = D;
var $f3684936850 = function(_) {
return R.isFunction(anf_fun295536824)?anf_fun295536824.app([anf_array_val295836823,anf_array_val296136838]):R.ffi.throwNonFunApp(L[4394],anf_fun295536824,[[anf_array_val295836823,anf_array_val296136838]]);
};
try {
if(--R.GAS > 0) {
$z3684336844 = $f3684936850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3684936850,
"from":L[4394]});
}
} catch($e3684136842) {
if(R.isCont($e3684136842)) {
var $ss3684536846 = {"from":L[4394],
"go":function(anf_arg296236851) {
return $Hanf_arg944936852(anf_arg296236851,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_fun295114340,anf_fun295214341,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
}};
$e3684136842.stack[R.EXN_STACKHEIGHT++] = $ss3684536846;
}
if(R.isPyretException($e3684136842)) {
$e3684136842.pyretStack.push(L[4394]);
}
throw $e3684136842;
}
var $ret3684736848 = $Hanf_arg944936852($z3684336844,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_fun295114340,anf_fun295214341,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3684736848;
};
var $Hanf_arg944936852 = function(anf_arg296236851,INDENT118169,PP170,anf_arg295014339,anf_arg295414338,anf_fun295114340,anf_fun295214341,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55) {
var $z3685536856 = D;
var $f3686136862 = function(_) {
return R.isFunction(anf_fun295214341)?anf_fun295214341.app(anf_arg295414338,anf_arg296236851):R.ffi.throwNonFunApp(L[4398],anf_fun295214341,[anf_arg295414338,anf_arg296236851]);
};
try {
if(--R.GAS > 0) {
$z3685536856 = $f3686136862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3686136862,
"from":L[4398]});
}
} catch($e3685336854) {
if(R.isCont($e3685336854)) {
var $ss3685736858 = {"from":L[4398],
"go":function(anf_arg296336863) {
return $Hanf_arg944836864(anf_arg296336863,INDENT118169,PP170,anf_arg295014339,anf_fun295114340,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
}};
$e3685336854.stack[R.EXN_STACKHEIGHT++] = $ss3685736858;
}
if(R.isPyretException($e3685336854)) {
$e3685336854.pyretStack.push(L[4398]);
}
throw $e3685336854;
}
var $ret3685936860 = $Hanf_arg944836864($z3685536856,INDENT118169,PP170,anf_arg295014339,anf_fun295114340,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3685936860;
};
var $Hanf_arg944836864 = function(anf_arg296336863,INDENT118169,PP170,anf_arg295014339,anf_fun295114340,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55) {
var $z3686736868 = D;
var $f3687336874 = function(_) {
return R.isFunction(anf_fun295114340)?anf_fun295114340.app(anf_arg296336863):R.ffi.throwNonFunApp(L[4399],anf_fun295114340,[anf_arg296336863]);
};
try {
if(--R.GAS > 0) {
$z3686736868 = $f3687336874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3687336874,
"from":L[4399]});
}
} catch($e3686536866) {
if(R.isCont($e3686536866)) {
var $ss3686936870 = {"from":L[4399],
"go":function(anf_arg296436875) {
return $Hanf_arg944736876(anf_arg296436875,INDENT118169,PP170,anf_arg295014339,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
}};
$e3686536866.stack[R.EXN_STACKHEIGHT++] = $ss3686936870;
}
if(R.isPyretException($e3686536866)) {
$e3686536866.pyretStack.push(L[4399]);
}
throw $e3686536866;
}
var $ret3687136872 = $Hanf_arg944736876($z3686736868,INDENT118169,PP170,anf_arg295014339,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3687136872;
};
var $Hanf_arg944736876 = function(anf_arg296436875,INDENT118169,PP170,anf_arg295014339,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55) {
var $z3687936880 = D;
var $f3688536886 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg295014339,anf_arg296436875):R.ffi.throwNonFunApp(L[4400],_plus55,[anf_arg295014339,anf_arg296436875]);
};
try {
if(--R.GAS > 0) {
$z3687936880 = $f3688536886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3688536886,
"from":L[4400]});
}
} catch($e3687736878) {
if(R.isCont($e3687736878)) {
var $ss3688136882 = {"from":L[4400],
"go":function(anf_arg296536887) {
return $Hanf_arg944636888(anf_arg296536887,INDENT118169,PP170,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
}};
$e3687736878.stack[R.EXN_STACKHEIGHT++] = $ss3688136882;
}
if(R.isPyretException($e3687736878)) {
$e3687736878.pyretStack.push(L[4400]);
}
throw $e3687736878;
}
var $ret3688336884 = $Hanf_arg944636888($z3687936880,INDENT118169,PP170,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55);
++R.GAS;
return $ret3688336884;
};
var $Hanf_arg944636888 = function(anf_arg296536887,INDENT118169,PP170,is_DASH_empty26152,self86014342,str_DASH_colonspace136390,_plus55) {
var $z3689136892 = D;
var $f3689736898 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg296536887,str_DASH_colonspace136390):R.ffi.throwNonFunApp(L[4401],_plus55,[anf_arg296536887,str_DASH_colonspace136390]);
};
try {
if(--R.GAS > 0) {
$z3689136892 = $f3689736898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3689736898,
"from":L[4401]});
}
} catch($e3688936890) {
if(R.isCont($e3688936890)) {
var $ss3689336894 = {"from":L[4401],
"go":function(prefix86136899) {
return $Hprefix944536900(prefix86136899,INDENT118169,PP170,is_DASH_empty26152,self86014342,_plus55);
}};
$e3688936890.stack[R.EXN_STACKHEIGHT++] = $ss3689336894;
}
if(R.isPyretException($e3688936890)) {
$e3688936890.pyretStack.push(L[4401]);
}
throw $e3688936890;
}
var $ret3689536896 = $Hprefix944536900($z3689136892,INDENT118169,PP170,is_DASH_empty26152,self86014342,_plus55);
++R.GAS;
return $ret3689536896;
};
var $Hprefix944536900 = function(prefix86136899,INDENT118169,PP170,is_DASH_empty26152,self86014342,_plus55) {
var anf_arg296636911 = G(self86014342,"values",L[4403]);
var $z3690336904 = D;
var $f3690936910 = function(_) {
return R.isFunction(is_DASH_empty26152)?is_DASH_empty26152.app(anf_arg296636911):R.ffi.throwNonFunApp(L[4402],is_DASH_empty26152,[anf_arg296636911]);
};
try {
if(--R.GAS > 0) {
$z3690336904 = $f3690936910();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3690936910,
"from":L[4402]});
}
} catch($e3690136902) {
if(R.isCont($e3690136902)) {
var $ss3690536906 = {"from":L[4402],
"go":function(if_DASH_37636912) {
return $Hif_DASH_944436913(if_DASH_37636912,INDENT118169,PP170,prefix86136899,self86014342,_plus55);
}};
$e3690136902.stack[R.EXN_STACKHEIGHT++] = $ss3690536906;
}
if(R.isPyretException($e3690136902)) {
$e3690136902.pyretStack.push(L[4402]);
}
throw $e3690136902;
}
var $ret3690736908 = $Hif_DASH_944436913($z3690336904,INDENT118169,PP170,prefix86136899,self86014342,_plus55);
++R.GAS;
return $ret3690736908;
};
var $Hif_DASH_944436913 = function(if_DASH_37636912,INDENT118169,PP170,prefix86136899,self86014342,_plus55) {
var if_helper296736926 = R.makeFunction(function(if_helper_arg296836964) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4402],1,arguments);
}
var ann_DASH_check_DASH_temp294936965 = if_helper_arg296836964;
return ann_DASH_check_DASH_temp294936965;
});
var anf_if297136963 = R.isBoolean(if_DASH_37636912);
if(R.isPyretTrue(anf_if297136963)) {
if(R.isPyretTrue(if_DASH_37636912)) {
var anf_arg298536924 = G(PP170,"rbrack",L[4405]);
var $z3691636917 = D;
var $f3692236923 = function(_) {
return R.isFunction(_plus55)?_plus55.app(prefix86136899,anf_arg298536924):R.ffi.throwNonFunApp(L[4404],_plus55,[prefix86136899,anf_arg298536924]);
};
try {
if(--R.GAS > 0) {
$z3691636917 = $f3692236923();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3692236923,
"from":L[4404]});
}
} catch($e3691436915) {
if(R.isCont($e3691436915)) {
var $ss3691836919 = {"from":L[4404],
"go":function(cont_tail_arg298636925) {
return $Hcont_tail_arg943936927(cont_tail_arg298636925,if_helper296736926);
}};
$e3691436915.stack[R.EXN_STACKHEIGHT++] = $ss3691836919;
}
if(R.isPyretException($e3691436915)) {
$e3691436915.pyretStack.push(L[4404]);
}
throw $e3691436915;
}
var $ret3692036921 = $Hcont_tail_arg943936927($z3691636917,if_helper296736926);
++R.GAS;
return $ret3692036921;
} else {
var anf_fun297236942 = G(PP170,"surround",L[4412]);
var anf_fun297336943 = G(PP170,"separate",L[4411]);
var anf_arg297436941 = G(PP170,"commabreak",L[4410]);
var anf_bracket297536959 = G(self86014342,"values",L[4409]);
var anf_fun297636938 = G(anf_bracket297536959,"map",L[4408]);
var anf_arg297936939 = R.makeFunction(function(recv_DASH_37536945) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4407],1,arguments);
}
var anf_fun297836956 = G(recv_DASH_37536945,"tosource",L[4407]);
var $z3694836949 = D;
var $f3695436955 = function(_) {
return R.isFunction(anf_fun297836956)?anf_fun297836956.app():R.ffi.throwNonFunApp(L[4407],anf_fun297836956,[]);
};
try {
if(--R.GAS > 0) {
$z3694836949 = $f3695436955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3695436955,
"from":L[4407]});
}
} catch($e3694636947) {
if(R.isCont($e3694636947)) {
var $ss3695036951 = {"from":L[4407],
"go":function(ann_DASH_check_DASH_temp297736957) {
return $Hann_DASH_check_DASH_temp944036958(ann_DASH_check_DASH_temp297736957);
}};
$e3694636947.stack[R.EXN_STACKHEIGHT++] = $ss3695036951;
}
if(R.isPyretException($e3694636947)) {
$e3694636947.pyretStack.push(L[4407]);
}
throw $e3694636947;
}
var $ret3695236953 = $Hann_DASH_check_DASH_temp944036958($z3694836949);
++R.GAS;
return $ret3695236953;
});
var $z3693036931 = D;
var $f3693636937 = function(_) {
return R.isFunction(anf_fun297636938)?anf_fun297636938.app(anf_arg297936939):R.ffi.throwNonFunApp(L[4406],anf_fun297636938,[anf_arg297936939]);
};
try {
if(--R.GAS > 0) {
$z3693036931 = $f3693636937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3693636937,
"from":L[4406]});
}
} catch($e3692836929) {
if(R.isCont($e3692836929)) {
var $ss3693236933 = {"from":L[4406],
"go":function(anf_arg298036940) {
return $Hanf_arg944336944(anf_arg298036940,INDENT118169,PP170,anf_arg297436941,anf_fun297236942,anf_fun297336943,if_helper296736926,prefix86136899);
}};
$e3692836929.stack[R.EXN_STACKHEIGHT++] = $ss3693236933;
}
if(R.isPyretException($e3692836929)) {
$e3692836929.pyretStack.push(L[4406]);
}
throw $e3692836929;
}
var $ret3693436935 = $Hanf_arg944336944($z3693036931,INDENT118169,PP170,anf_arg297436941,anf_fun297236942,anf_fun297336943,if_helper296736926,prefix86136899);
++R.GAS;
return $ret3693436935;
}
} else {
var cont_tail_arg296936962 = R.throwNonBooleanCondition(L[4402],("if"),if_DASH_37636912);
if(--R.GAS > 0) {
$z3696036961 = R.isFunction(if_helper296736926)?if_helper296736926.app(cont_tail_arg296936962):R.ffi.throwNonFunApp(L[4402],if_helper296736926,[cont_tail_arg296936962]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper296736926)?if_helper296736926.app(cont_tail_arg296936962):R.ffi.throwNonFunApp(L[4402],if_helper296736926,[cont_tail_arg296936962]);
},
"from":L[4402]});
}
++R.GAS;
return $z3696036961;
}
};
var $Hcont_tail_arg943936927 = function(cont_tail_arg298636925,if_helper296736926) {
if(--R.GAS > 0) {
$z3696636967 = R.isFunction(if_helper296736926)?if_helper296736926.app(cont_tail_arg298636925):R.ffi.throwNonFunApp(L[4404],if_helper296736926,[cont_tail_arg298636925]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper296736926)?if_helper296736926.app(cont_tail_arg298636925):R.ffi.throwNonFunApp(L[4404],if_helper296736926,[cont_tail_arg298636925]);
},
"from":L[4404]});
}
++R.GAS;
return $z3696636967;
};
var $Hanf_arg944336944 = function(anf_arg298036940,INDENT118169,PP170,anf_arg297436941,anf_fun297236942,anf_fun297336943,if_helper296736926,prefix86136899) {
var $z3697036971 = D;
var $f3697636977 = function(_) {
return R.isFunction(anf_fun297336943)?anf_fun297336943.app(anf_arg297436941,anf_arg298036940):R.ffi.throwNonFunApp(L[4413],anf_fun297336943,[anf_arg297436941,anf_arg298036940]);
};
try {
if(--R.GAS > 0) {
$z3697036971 = $f3697636977();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3697636977,
"from":L[4413]});
}
} catch($e3696836969) {
if(R.isCont($e3696836969)) {
var $ss3697236973 = {"from":L[4413],
"go":function(anf_arg298136978) {
return $Hanf_arg944236979(anf_arg298136978,INDENT118169,PP170,anf_fun297236942,if_helper296736926,prefix86136899);
}};
$e3696836969.stack[R.EXN_STACKHEIGHT++] = $ss3697236973;
}
if(R.isPyretException($e3696836969)) {
$e3696836969.pyretStack.push(L[4413]);
}
throw $e3696836969;
}
var $ret3697436975 = $Hanf_arg944236979($z3697036971,INDENT118169,PP170,anf_fun297236942,if_helper296736926,prefix86136899);
++R.GAS;
return $ret3697436975;
};
var $Hanf_arg944236979 = function(anf_arg298136978,INDENT118169,PP170,anf_fun297236942,if_helper296736926,prefix86136899) {
var anf_arg298236990 = G(PP170,"rbrack",L[4415]);
var $z3698236983 = D;
var $f3698836989 = function(_) {
return R.isFunction(anf_fun297236942)?anf_fun297236942.app(INDENT118169,(0),prefix86136899,anf_arg298136978,anf_arg298236990):R.ffi.throwNonFunApp(L[4414],anf_fun297236942,[INDENT118169,(0),prefix86136899,anf_arg298136978,anf_arg298236990]);
};
try {
if(--R.GAS > 0) {
$z3698236983 = $f3698836989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3698836989,
"from":L[4414]});
}
} catch($e3698036981) {
if(R.isCont($e3698036981)) {
var $ss3698436985 = {"from":L[4414],
"go":function(cont_tail_arg298336991) {
return $Hcont_tail_arg944136992(cont_tail_arg298336991,if_helper296736926);
}};
$e3698036981.stack[R.EXN_STACKHEIGHT++] = $ss3698436985;
}
if(R.isPyretException($e3698036981)) {
$e3698036981.pyretStack.push(L[4414]);
}
throw $e3698036981;
}
var $ret3698636987 = $Hcont_tail_arg944136992($z3698236983,if_helper296736926);
++R.GAS;
return $ret3698636987;
};
var $Hcont_tail_arg944136992 = function(cont_tail_arg298336991,if_helper296736926) {
if(--R.GAS > 0) {
$z3699336994 = R.isFunction(if_helper296736926)?if_helper296736926.app(cont_tail_arg298336991):R.ffi.throwNonFunApp(L[4414],if_helper296736926,[cont_tail_arg298336991]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper296736926)?if_helper296736926.app(cont_tail_arg298336991):R.ffi.throwNonFunApp(L[4414],if_helper296736926,[cont_tail_arg298336991]);
},
"from":L[4414]});
}
++R.GAS;
return $z3699336994;
};
var $Hann_DASH_check_DASH_temp944036958 = function(ann_DASH_check_DASH_temp297736957) {
return ann_DASH_check_DASH_temp297736957;
};
var $Hanf_arg943814359 = function(anf_arg293114357,self37314358,_plus55,torepr65) {
var anf_arg293237005 = G(self37314358,"modifier",L[2237]);
var $z3699736998 = D;
var $f3700337004 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg293237005):R.ffi.throwNonFunApp(L[2237],torepr65,[anf_arg293237005]);
};
try {
if(--R.GAS > 0) {
$z3699736998 = $f3700337004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3700337004,
"from":L[2237]});
}
} catch($e3699536996) {
if(R.isCont($e3699536996)) {
var $ss3699937000 = {"from":L[2237],
"go":function(anf_arg293337006) {
return $Hanf_arg943737007(anf_arg293337006,anf_arg293114357,self37314358,_plus55,torepr65);
}};
$e3699536996.stack[R.EXN_STACKHEIGHT++] = $ss3699937000;
}
if(R.isPyretException($e3699536996)) {
$e3699536996.pyretStack.push(L[2237]);
}
throw $e3699536996;
}
var $ret3700137002 = $Hanf_arg943737007($z3699736998,anf_arg293114357,self37314358,_plus55,torepr65);
++R.GAS;
return $ret3700137002;
};
var $Hanf_arg943737007 = function(anf_arg293337006,anf_arg293114357,self37314358,_plus55,torepr65) {
var $z3701037011 = D;
var $f3701637017 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg293337006):R.ffi.throwNonFunApp(L[2237],_plus55,[(", "),anf_arg293337006]);
};
try {
if(--R.GAS > 0) {
$z3701037011 = $f3701637017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3701637017,
"from":L[2237]});
}
} catch($e3700837009) {
if(R.isCont($e3700837009)) {
var $ss3701237013 = {"from":L[2237],
"go":function(anf_arg293437018) {
return $Hanf_arg943637019(anf_arg293437018,anf_arg293114357,self37314358,_plus55,torepr65);
}};
$e3700837009.stack[R.EXN_STACKHEIGHT++] = $ss3701237013;
}
if(R.isPyretException($e3700837009)) {
$e3700837009.pyretStack.push(L[2237]);
}
throw $e3700837009;
}
var $ret3701437015 = $Hanf_arg943637019($z3701037011,anf_arg293114357,self37314358,_plus55,torepr65);
++R.GAS;
return $ret3701437015;
};
var $Hanf_arg943637019 = function(anf_arg293437018,anf_arg293114357,self37314358,_plus55,torepr65) {
var $z3702237023 = D;
var $f3702837029 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg293114357,anf_arg293437018):R.ffi.throwNonFunApp(L[2237],_plus55,[anf_arg293114357,anf_arg293437018]);
};
try {
if(--R.GAS > 0) {
$z3702237023 = $f3702837029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3702837029,
"from":L[2237]});
}
} catch($e3702037021) {
if(R.isCont($e3702037021)) {
var $ss3702437025 = {"from":L[2237],
"go":function(anf_arg293537030) {
return $Hanf_arg943537031(anf_arg293537030,self37314358,_plus55,torepr65);
}};
$e3702037021.stack[R.EXN_STACKHEIGHT++] = $ss3702437025;
}
if(R.isPyretException($e3702037021)) {
$e3702037021.pyretStack.push(L[2237]);
}
throw $e3702037021;
}
var $ret3702637027 = $Hanf_arg943537031($z3702237023,self37314358,_plus55,torepr65);
++R.GAS;
return $ret3702637027;
};
var $Hanf_arg943537031 = function(anf_arg293537030,self37314358,_plus55,torepr65) {
var anf_arg293637042 = G(self37314358,"constructor",L[2237]);
var $z3703437035 = D;
var $f3704037041 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg293637042):R.ffi.throwNonFunApp(L[2237],torepr65,[anf_arg293637042]);
};
try {
if(--R.GAS > 0) {
$z3703437035 = $f3704037041();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3704037041,
"from":L[2237]});
}
} catch($e3703237033) {
if(R.isCont($e3703237033)) {
var $ss3703637037 = {"from":L[2237],
"go":function(anf_arg293737043) {
return $Hanf_arg943437044(anf_arg293737043,anf_arg293537030,self37314358,_plus55,torepr65);
}};
$e3703237033.stack[R.EXN_STACKHEIGHT++] = $ss3703637037;
}
if(R.isPyretException($e3703237033)) {
$e3703237033.pyretStack.push(L[2237]);
}
throw $e3703237033;
}
var $ret3703837039 = $Hanf_arg943437044($z3703437035,anf_arg293537030,self37314358,_plus55,torepr65);
++R.GAS;
return $ret3703837039;
};
var $Hanf_arg943437044 = function(anf_arg293737043,anf_arg293537030,self37314358,_plus55,torepr65) {
var $z3704737048 = D;
var $f3705337054 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg293737043):R.ffi.throwNonFunApp(L[2237],_plus55,[(", "),anf_arg293737043]);
};
try {
if(--R.GAS > 0) {
$z3704737048 = $f3705337054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3705337054,
"from":L[2237]});
}
} catch($e3704537046) {
if(R.isCont($e3704537046)) {
var $ss3704937050 = {"from":L[2237],
"go":function(anf_arg293837055) {
return $Hanf_arg943337056(anf_arg293837055,anf_arg293537030,self37314358,_plus55,torepr65);
}};
$e3704537046.stack[R.EXN_STACKHEIGHT++] = $ss3704937050;
}
if(R.isPyretException($e3704537046)) {
$e3704537046.pyretStack.push(L[2237]);
}
throw $e3704537046;
}
var $ret3705137052 = $Hanf_arg943337056($z3704737048,anf_arg293537030,self37314358,_plus55,torepr65);
++R.GAS;
return $ret3705137052;
};
var $Hanf_arg943337056 = function(anf_arg293837055,anf_arg293537030,self37314358,_plus55,torepr65) {
var $z3705937060 = D;
var $f3706537066 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg293537030,anf_arg293837055):R.ffi.throwNonFunApp(L[2237],_plus55,[anf_arg293537030,anf_arg293837055]);
};
try {
if(--R.GAS > 0) {
$z3705937060 = $f3706537066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3706537066,
"from":L[2237]});
}
} catch($e3705737058) {
if(R.isCont($e3705737058)) {
var $ss3706137062 = {"from":L[2237],
"go":function(anf_arg293937067) {
return $Hanf_arg943237068(anf_arg293937067,self37314358,_plus55,torepr65);
}};
$e3705737058.stack[R.EXN_STACKHEIGHT++] = $ss3706137062;
}
if(R.isPyretException($e3705737058)) {
$e3705737058.pyretStack.push(L[2237]);
}
throw $e3705737058;
}
var $ret3706337064 = $Hanf_arg943237068($z3705937060,self37314358,_plus55,torepr65);
++R.GAS;
return $ret3706337064;
};
var $Hanf_arg943237068 = function(anf_arg293937067,self37314358,_plus55,torepr65) {
var anf_arg294037079 = G(self37314358,"values",L[2237]);
var $z3707137072 = D;
var $f3707737078 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg294037079):R.ffi.throwNonFunApp(L[2237],torepr65,[anf_arg294037079]);
};
try {
if(--R.GAS > 0) {
$z3707137072 = $f3707737078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3707737078,
"from":L[2237]});
}
} catch($e3706937070) {
if(R.isCont($e3706937070)) {
var $ss3707337074 = {"from":L[2237],
"go":function(anf_arg294137080) {
return $Hanf_arg943137081(anf_arg294137080,anf_arg293937067,_plus55);
}};
$e3706937070.stack[R.EXN_STACKHEIGHT++] = $ss3707337074;
}
if(R.isPyretException($e3706937070)) {
$e3706937070.pyretStack.push(L[2237]);
}
throw $e3706937070;
}
var $ret3707537076 = $Hanf_arg943137081($z3707137072,anf_arg293937067,_plus55);
++R.GAS;
return $ret3707537076;
};
var $Hanf_arg943137081 = function(anf_arg294137080,anf_arg293937067,_plus55) {
var $z3708437085 = D;
var $f3709037091 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg294137080):R.ffi.throwNonFunApp(L[2237],_plus55,[(", "),anf_arg294137080]);
};
try {
if(--R.GAS > 0) {
$z3708437085 = $f3709037091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3709037091,
"from":L[2237]});
}
} catch($e3708237083) {
if(R.isCont($e3708237083)) {
var $ss3708637087 = {"from":L[2237],
"go":function(anf_arg294237092) {
return $Hanf_arg943037093(anf_arg294237092,anf_arg293937067,_plus55);
}};
$e3708237083.stack[R.EXN_STACKHEIGHT++] = $ss3708637087;
}
if(R.isPyretException($e3708237083)) {
$e3708237083.pyretStack.push(L[2237]);
}
throw $e3708237083;
}
var $ret3708837089 = $Hanf_arg943037093($z3708437085,anf_arg293937067,_plus55);
++R.GAS;
return $ret3708837089;
};
var $Hanf_arg943037093 = function(anf_arg294237092,anf_arg293937067,_plus55) {
var $z3709637097 = D;
var $f3710237103 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg293937067,anf_arg294237092):R.ffi.throwNonFunApp(L[2237],_plus55,[anf_arg293937067,anf_arg294237092]);
};
try {
if(--R.GAS > 0) {
$z3709637097 = $f3710237103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3710237103,
"from":L[2237]});
}
} catch($e3709437095) {
if(R.isCont($e3709437095)) {
var $ss3709837099 = {"from":L[2237],
"go":function(anf_arg294337104) {
return $Hanf_arg942937105(anf_arg294337104,_plus55);
}};
$e3709437095.stack[R.EXN_STACKHEIGHT++] = $ss3709837099;
}
if(R.isPyretException($e3709437095)) {
$e3709437095.pyretStack.push(L[2237]);
}
throw $e3709437095;
}
var $ret3710037101 = $Hanf_arg942937105($z3709637097,_plus55);
++R.GAS;
return $ret3710037101;
};
var $Hanf_arg942937105 = function(anf_arg294337104,_plus55) {
var $z3710837109 = D;
var $f3711437115 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg294337104,(")")):R.ffi.throwNonFunApp(L[2237],_plus55,[anf_arg294337104,(")")]);
};
try {
if(--R.GAS > 0) {
$z3710837109 = $f3711437115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3711437115,
"from":L[2237]});
}
} catch($e3710637107) {
if(R.isCont($e3710637107)) {
var $ss3711037111 = {"from":L[2237],
"go":function(anf_arg294437116) {
return $Hanf_arg942837117(anf_arg294437116,_plus55);
}};
$e3710637107.stack[R.EXN_STACKHEIGHT++] = $ss3711037111;
}
if(R.isPyretException($e3710637107)) {
$e3710637107.pyretStack.push(L[2237]);
}
throw $e3710637107;
}
var $ret3711237113 = $Hanf_arg942837117($z3710837109,_plus55);
++R.GAS;
return $ret3711237113;
};
var $Hanf_arg942837117 = function(anf_arg294437116,_plus55) {
var $z3712037121 = D;
var $f3712637127 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg294437116):R.ffi.throwNonFunApp(L[2237],_plus55,[("("),anf_arg294437116]);
};
try {
if(--R.GAS > 0) {
$z3712037121 = $f3712637127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3712637127,
"from":L[2237]});
}
} catch($e3711837119) {
if(R.isCont($e3711837119)) {
var $ss3712237123 = {"from":L[2237],
"go":function(anf_arg294537128) {
return $Hanf_arg942737129(anf_arg294537128,_plus55);
}};
$e3711837119.stack[R.EXN_STACKHEIGHT++] = $ss3712237123;
}
if(R.isPyretException($e3711837119)) {
$e3711837119.pyretStack.push(L[2237]);
}
throw $e3711837119;
}
var $ret3712437125 = $Hanf_arg942737129($z3712037121,_plus55);
++R.GAS;
return $ret3712437125;
};
var $Hanf_arg942737129 = function(anf_arg294537128,_plus55) {
var $z3713237133 = D;
var $f3713837139 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-construct"),anf_arg294537128):R.ffi.throwNonFunApp(L[2237],_plus55,[("s-construct"),anf_arg294537128]);
};
try {
if(--R.GAS > 0) {
$z3713237133 = $f3713837139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3713837139,
"from":L[2237]});
}
} catch($e3713037131) {
if(R.isCont($e3713037131)) {
var $ss3713437135 = {"from":L[2237],
"go":function(ann_DASH_check_DASH_temp292937140) {
return $Hann_DASH_check_DASH_temp942637141(ann_DASH_check_DASH_temp292937140);
}};
$e3713037131.stack[R.EXN_STACKHEIGHT++] = $ss3713437135;
}
if(R.isPyretException($e3713037131)) {
$e3713037131.pyretStack.push(L[2237]);
}
throw $e3713037131;
}
var $ret3713637137 = $Hann_DASH_check_DASH_temp942637141($z3713237133);
++R.GAS;
return $ret3713637137;
};
var $Hann_DASH_check_DASH_temp942637141 = function(ann_DASH_check_DASH_temp292937140) {
return ann_DASH_check_DASH_temp292937140;
};
var $Hcont_tail_arg942414377 = function(cont_tail_arg292614375,if_helper291514376) {
if(--R.GAS > 0) {
$z3714237143 = R.isFunction(if_helper291514376)?if_helper291514376.app(cont_tail_arg292614375):R.ffi.throwNonFunApp(L[2237],if_helper291514376,[cont_tail_arg292614375]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper291514376)?if_helper291514376.app(cont_tail_arg292614375):R.ffi.throwNonFunApp(L[2237],if_helper291514376,[cont_tail_arg292614375]);
},
"from":L[2237]});
}
++R.GAS;
return $z3714237143;
};
var $Hcont_tail_arg942514392 = function(cont_tail_arg292014391,if_helper291514376) {
if(--R.GAS > 0) {
$z3714437145 = R.isFunction(if_helper291514376)?if_helper291514376.app(cont_tail_arg292014391):R.ffi.throwNonFunApp(L[2237],if_helper291514376,[cont_tail_arg292014391]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper291514376)?if_helper291514376.app(cont_tail_arg292014391):R.ffi.throwNonFunApp(L[2237],if_helper291514376,[cont_tail_arg292014391]);
},
"from":L[2237]});
}
++R.GAS;
return $z3714437145;
};
var $Hanf_arg942314414 = function(anf_arg290214411,INDENT118169,PP170,anf_fun290014412,self85414413) {
var anf_fun290337156 = G(PP170,"str",L[4417]);
var $z3714837149 = D;
var $f3715437155 = function(_) {
return R.isFunction(anf_fun290337156)?anf_fun290337156.app(("[raw-array: ")):R.ffi.throwNonFunApp(L[4416],anf_fun290337156,[("[raw-array: ")]);
};
try {
if(--R.GAS > 0) {
$z3714837149 = $f3715437155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3715437155,
"from":L[4416]});
}
} catch($e3714637147) {
if(R.isCont($e3714637147)) {
var $ss3715037151 = {"from":L[4416],
"go":function(anf_arg290437157) {
return $Hanf_arg942237158(anf_arg290437157,INDENT118169,PP170,anf_arg290214411,anf_fun290014412,self85414413);
}};
$e3714637147.stack[R.EXN_STACKHEIGHT++] = $ss3715037151;
}
if(R.isPyretException($e3714637147)) {
$e3714637147.pyretStack.push(L[4416]);
}
throw $e3714637147;
}
var $ret3715237153 = $Hanf_arg942237158($z3714837149,INDENT118169,PP170,anf_arg290214411,anf_fun290014412,self85414413);
++R.GAS;
return $ret3715237153;
};
var $Hanf_arg942237158 = function(anf_arg290437157,INDENT118169,PP170,anf_arg290214411,anf_fun290014412,self85414413) {
var anf_arg290537172 = G(PP170,"commabreak",L[4423]);
var anf_arg290637173 = G(PP170,"rbrack",L[4422]);
var anf_bracket290737189 = G(self85414413,"values",L[4421]);
var anf_fun290837169 = G(anf_bracket290737189,"map",L[4420]);
var anf_arg291137170 = R.makeFunction(function(recv_DASH_36837175) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4419],1,arguments);
}
var anf_fun291037186 = G(recv_DASH_36837175,"tosource",L[4419]);
var $z3717837179 = D;
var $f3718437185 = function(_) {
return R.isFunction(anf_fun291037186)?anf_fun291037186.app():R.ffi.throwNonFunApp(L[4419],anf_fun291037186,[]);
};
try {
if(--R.GAS > 0) {
$z3717837179 = $f3718437185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3718437185,
"from":L[4419]});
}
} catch($e3717637177) {
if(R.isCont($e3717637177)) {
var $ss3718037181 = {"from":L[4419],
"go":function(ann_DASH_check_DASH_temp290937187) {
return $Hann_DASH_check_DASH_temp941937188(ann_DASH_check_DASH_temp290937187);
}};
$e3717637177.stack[R.EXN_STACKHEIGHT++] = $ss3718037181;
}
if(R.isPyretException($e3717637177)) {
$e3717637177.pyretStack.push(L[4419]);
}
throw $e3717637177;
}
var $ret3718237183 = $Hann_DASH_check_DASH_temp941937188($z3717837179);
++R.GAS;
return $ret3718237183;
});
var $z3716137162 = D;
var $f3716737168 = function(_) {
return R.isFunction(anf_fun290837169)?anf_fun290837169.app(anf_arg291137170):R.ffi.throwNonFunApp(L[4418],anf_fun290837169,[anf_arg291137170]);
};
try {
if(--R.GAS > 0) {
$z3716137162 = $f3716737168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3716737168,
"from":L[4418]});
}
} catch($e3715937160) {
if(R.isCont($e3715937160)) {
var $ss3716337164 = {"from":L[4418],
"go":function(anf_arg291237171) {
return $Hanf_arg942137174(anf_arg291237171,INDENT118169,anf_arg290214411,anf_arg290437157,anf_arg290537172,anf_arg290637173,anf_fun290014412);
}};
$e3715937160.stack[R.EXN_STACKHEIGHT++] = $ss3716337164;
}
if(R.isPyretException($e3715937160)) {
$e3715937160.pyretStack.push(L[4418]);
}
throw $e3715937160;
}
var $ret3716537166 = $Hanf_arg942137174($z3716137162,INDENT118169,anf_arg290214411,anf_arg290437157,anf_arg290537172,anf_arg290637173,anf_fun290014412);
++R.GAS;
return $ret3716537166;
};
var $Hanf_arg942137174 = function(anf_arg291237171,INDENT118169,anf_arg290214411,anf_arg290437157,anf_arg290537172,anf_arg290637173,anf_fun290014412) {
var $z3719237193 = D;
var $f3719837199 = function(_) {
return R.isFunction(anf_fun290014412)?anf_fun290014412.app(INDENT118169,(0),anf_arg290214411,anf_arg290437157,anf_arg290537172,anf_arg290637173,anf_arg291237171):R.ffi.throwNonFunApp(L[2717],anf_fun290014412,[INDENT118169,(0),anf_arg290214411,anf_arg290437157,anf_arg290537172,anf_arg290637173,anf_arg291237171]);
};
try {
if(--R.GAS > 0) {
$z3719237193 = $f3719837199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3719837199,
"from":L[2717]});
}
} catch($e3719037191) {
if(R.isCont($e3719037191)) {
var $ss3719437195 = {"from":L[2717],
"go":function(ann_DASH_check_DASH_temp289937200) {
return $Hann_DASH_check_DASH_temp942037201(ann_DASH_check_DASH_temp289937200);
}};
$e3719037191.stack[R.EXN_STACKHEIGHT++] = $ss3719437195;
}
if(R.isPyretException($e3719037191)) {
$e3719037191.pyretStack.push(L[2717]);
}
throw $e3719037191;
}
var $ret3719637197 = $Hann_DASH_check_DASH_temp942037201($z3719237193);
++R.GAS;
return $ret3719637197;
};
var $Hann_DASH_check_DASH_temp942037201 = function(ann_DASH_check_DASH_temp289937200) {
return ann_DASH_check_DASH_temp289937200;
};
var $Hann_DASH_check_DASH_temp941937188 = function(ann_DASH_check_DASH_temp290937187) {
return ann_DASH_check_DASH_temp290937187;
};
var $Hanf_arg941814430 = function(anf_arg288914428,self36614429,_plus55,torepr65) {
var anf_arg289037212 = G(self36614429,"values",L[2238]);
var $z3720437205 = D;
var $f3721037211 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg289037212):R.ffi.throwNonFunApp(L[2238],torepr65,[anf_arg289037212]);
};
try {
if(--R.GAS > 0) {
$z3720437205 = $f3721037211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3721037211,
"from":L[2238]});
}
} catch($e3720237203) {
if(R.isCont($e3720237203)) {
var $ss3720637207 = {"from":L[2238],
"go":function(anf_arg289137213) {
return $Hanf_arg941737214(anf_arg289137213,anf_arg288914428,_plus55);
}};
$e3720237203.stack[R.EXN_STACKHEIGHT++] = $ss3720637207;
}
if(R.isPyretException($e3720237203)) {
$e3720237203.pyretStack.push(L[2238]);
}
throw $e3720237203;
}
var $ret3720837209 = $Hanf_arg941737214($z3720437205,anf_arg288914428,_plus55);
++R.GAS;
return $ret3720837209;
};
var $Hanf_arg941737214 = function(anf_arg289137213,anf_arg288914428,_plus55) {
var $z3721737218 = D;
var $f3722337224 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg289137213):R.ffi.throwNonFunApp(L[2238],_plus55,[(", "),anf_arg289137213]);
};
try {
if(--R.GAS > 0) {
$z3721737218 = $f3722337224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3722337224,
"from":L[2238]});
}
} catch($e3721537216) {
if(R.isCont($e3721537216)) {
var $ss3721937220 = {"from":L[2238],
"go":function(anf_arg289237225) {
return $Hanf_arg941637226(anf_arg289237225,anf_arg288914428,_plus55);
}};
$e3721537216.stack[R.EXN_STACKHEIGHT++] = $ss3721937220;
}
if(R.isPyretException($e3721537216)) {
$e3721537216.pyretStack.push(L[2238]);
}
throw $e3721537216;
}
var $ret3722137222 = $Hanf_arg941637226($z3721737218,anf_arg288914428,_plus55);
++R.GAS;
return $ret3722137222;
};
var $Hanf_arg941637226 = function(anf_arg289237225,anf_arg288914428,_plus55) {
var $z3722937230 = D;
var $f3723537236 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg288914428,anf_arg289237225):R.ffi.throwNonFunApp(L[2238],_plus55,[anf_arg288914428,anf_arg289237225]);
};
try {
if(--R.GAS > 0) {
$z3722937230 = $f3723537236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3723537236,
"from":L[2238]});
}
} catch($e3722737228) {
if(R.isCont($e3722737228)) {
var $ss3723137232 = {"from":L[2238],
"go":function(anf_arg289337237) {
return $Hanf_arg941537238(anf_arg289337237,_plus55);
}};
$e3722737228.stack[R.EXN_STACKHEIGHT++] = $ss3723137232;
}
if(R.isPyretException($e3722737228)) {
$e3722737228.pyretStack.push(L[2238]);
}
throw $e3722737228;
}
var $ret3723337234 = $Hanf_arg941537238($z3722937230,_plus55);
++R.GAS;
return $ret3723337234;
};
var $Hanf_arg941537238 = function(anf_arg289337237,_plus55) {
var $z3724137242 = D;
var $f3724737248 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg289337237,(")")):R.ffi.throwNonFunApp(L[2238],_plus55,[anf_arg289337237,(")")]);
};
try {
if(--R.GAS > 0) {
$z3724137242 = $f3724737248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3724737248,
"from":L[2238]});
}
} catch($e3723937240) {
if(R.isCont($e3723937240)) {
var $ss3724337244 = {"from":L[2238],
"go":function(anf_arg289437249) {
return $Hanf_arg941437250(anf_arg289437249,_plus55);
}};
$e3723937240.stack[R.EXN_STACKHEIGHT++] = $ss3724337244;
}
if(R.isPyretException($e3723937240)) {
$e3723937240.pyretStack.push(L[2238]);
}
throw $e3723937240;
}
var $ret3724537246 = $Hanf_arg941437250($z3724137242,_plus55);
++R.GAS;
return $ret3724537246;
};
var $Hanf_arg941437250 = function(anf_arg289437249,_plus55) {
var $z3725337254 = D;
var $f3725937260 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg289437249):R.ffi.throwNonFunApp(L[2238],_plus55,[("("),anf_arg289437249]);
};
try {
if(--R.GAS > 0) {
$z3725337254 = $f3725937260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3725937260,
"from":L[2238]});
}
} catch($e3725137252) {
if(R.isCont($e3725137252)) {
var $ss3725537256 = {"from":L[2238],
"go":function(anf_arg289537261) {
return $Hanf_arg941337262(anf_arg289537261,_plus55);
}};
$e3725137252.stack[R.EXN_STACKHEIGHT++] = $ss3725537256;
}
if(R.isPyretException($e3725137252)) {
$e3725137252.pyretStack.push(L[2238]);
}
throw $e3725137252;
}
var $ret3725737258 = $Hanf_arg941337262($z3725337254,_plus55);
++R.GAS;
return $ret3725737258;
};
var $Hanf_arg941337262 = function(anf_arg289537261,_plus55) {
var $z3726537266 = D;
var $f3727137272 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-array"),anf_arg289537261):R.ffi.throwNonFunApp(L[2238],_plus55,[("s-array"),anf_arg289537261]);
};
try {
if(--R.GAS > 0) {
$z3726537266 = $f3727137272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3727137272,
"from":L[2238]});
}
} catch($e3726337264) {
if(R.isCont($e3726337264)) {
var $ss3726737268 = {"from":L[2238],
"go":function(ann_DASH_check_DASH_temp288737273) {
return $Hann_DASH_check_DASH_temp941237274(ann_DASH_check_DASH_temp288737273);
}};
$e3726337264.stack[R.EXN_STACKHEIGHT++] = $ss3726737268;
}
if(R.isPyretException($e3726337264)) {
$e3726337264.pyretStack.push(L[2238]);
}
throw $e3726337264;
}
var $ret3726937270 = $Hann_DASH_check_DASH_temp941237274($z3726537266);
++R.GAS;
return $ret3726937270;
};
var $Hann_DASH_check_DASH_temp941237274 = function(ann_DASH_check_DASH_temp288737273) {
return ann_DASH_check_DASH_temp288737273;
};
var $Hcont_tail_arg941014446 = function(cont_tail_arg288414444,if_helper287514445) {
if(--R.GAS > 0) {
$z3727537276 = R.isFunction(if_helper287514445)?if_helper287514445.app(cont_tail_arg288414444):R.ffi.throwNonFunApp(L[2238],if_helper287514445,[cont_tail_arg288414444]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper287514445)?if_helper287514445.app(cont_tail_arg288414444):R.ffi.throwNonFunApp(L[2238],if_helper287514445,[cont_tail_arg288414444]);
},
"from":L[2238]});
}
++R.GAS;
return $z3727537276;
};
var $Hcont_tail_arg941114461 = function(cont_tail_arg288014460,if_helper287514445) {
if(--R.GAS > 0) {
$z3727737278 = R.isFunction(if_helper287514445)?if_helper287514445.app(cont_tail_arg288014460):R.ffi.throwNonFunApp(L[2238],if_helper287514445,[cont_tail_arg288014460]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper287514445)?if_helper287514445.app(cont_tail_arg288014460):R.ffi.throwNonFunApp(L[2238],if_helper287514445,[cont_tail_arg288014460]);
},
"from":L[2238]});
}
++R.GAS;
return $z3727737278;
};
var $Hanf_arg940914484 = function(anf_arg286314481,INDENT118169,PP170,anf_fun286014482,self85014483) {
var anf_arg286437292 = G(PP170,"lbrace",L[4430]);
var anf_arg286537293 = G(PP170,"commabreak",L[4429]);
var anf_arg286637294 = G(PP170,"rbrace",L[4428]);
var anf_bracket286737310 = G(self85014483,"fields",L[4427]);
var anf_fun286837289 = G(anf_bracket286737310,"map",L[4426]);
var anf_arg287137290 = R.makeFunction(function(recv_DASH_36137296) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4425],1,arguments);
}
var anf_fun287037307 = G(recv_DASH_36137296,"tosource",L[4425]);
var $z3729937300 = D;
var $f3730537306 = function(_) {
return R.isFunction(anf_fun287037307)?anf_fun287037307.app():R.ffi.throwNonFunApp(L[4425],anf_fun287037307,[]);
};
try {
if(--R.GAS > 0) {
$z3729937300 = $f3730537306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3730537306,
"from":L[4425]});
}
} catch($e3729737298) {
if(R.isCont($e3729737298)) {
var $ss3730137302 = {"from":L[4425],
"go":function(ann_DASH_check_DASH_temp286937308) {
return $Hann_DASH_check_DASH_temp940637309(ann_DASH_check_DASH_temp286937308);
}};
$e3729737298.stack[R.EXN_STACKHEIGHT++] = $ss3730137302;
}
if(R.isPyretException($e3729737298)) {
$e3729737298.pyretStack.push(L[4425]);
}
throw $e3729737298;
}
var $ret3730337304 = $Hann_DASH_check_DASH_temp940637309($z3729937300);
++R.GAS;
return $ret3730337304;
});
var $z3728137282 = D;
var $f3728737288 = function(_) {
return R.isFunction(anf_fun286837289)?anf_fun286837289.app(anf_arg287137290):R.ffi.throwNonFunApp(L[4424],anf_fun286837289,[anf_arg287137290]);
};
try {
if(--R.GAS > 0) {
$z3728137282 = $f3728737288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3728737288,
"from":L[4424]});
}
} catch($e3727937280) {
if(R.isCont($e3727937280)) {
var $ss3728337284 = {"from":L[4424],
"go":function(anf_arg287237291) {
return $Hanf_arg940837295(anf_arg287237291,INDENT118169,anf_arg286314481,anf_arg286437292,anf_arg286537293,anf_arg286637294,anf_fun286014482);
}};
$e3727937280.stack[R.EXN_STACKHEIGHT++] = $ss3728337284;
}
if(R.isPyretException($e3727937280)) {
$e3727937280.pyretStack.push(L[4424]);
}
throw $e3727937280;
}
var $ret3728537286 = $Hanf_arg940837295($z3728137282,INDENT118169,anf_arg286314481,anf_arg286437292,anf_arg286537293,anf_arg286637294,anf_fun286014482);
++R.GAS;
return $ret3728537286;
};
var $Hanf_arg940837295 = function(anf_arg287237291,INDENT118169,anf_arg286314481,anf_arg286437292,anf_arg286537293,anf_arg286637294,anf_fun286014482) {
var $z3731337314 = D;
var $f3731937320 = function(_) {
return R.isFunction(anf_fun286014482)?anf_fun286014482.app(INDENT118169,(1),anf_arg286314481,anf_arg286437292,anf_arg286537293,anf_arg286637294,anf_arg287237291):R.ffi.throwNonFunApp(L[2725],anf_fun286014482,[INDENT118169,(1),anf_arg286314481,anf_arg286437292,anf_arg286537293,anf_arg286637294,anf_arg287237291]);
};
try {
if(--R.GAS > 0) {
$z3731337314 = $f3731937320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3731937320,
"from":L[2725]});
}
} catch($e3731137312) {
if(R.isCont($e3731137312)) {
var $ss3731537316 = {"from":L[2725],
"go":function(ann_DASH_check_DASH_temp285937321) {
return $Hann_DASH_check_DASH_temp940737322(ann_DASH_check_DASH_temp285937321);
}};
$e3731137312.stack[R.EXN_STACKHEIGHT++] = $ss3731537316;
}
if(R.isPyretException($e3731137312)) {
$e3731137312.pyretStack.push(L[2725]);
}
throw $e3731137312;
}
var $ret3731737318 = $Hann_DASH_check_DASH_temp940737322($z3731337314);
++R.GAS;
return $ret3731737318;
};
var $Hann_DASH_check_DASH_temp940737322 = function(ann_DASH_check_DASH_temp285937321) {
return ann_DASH_check_DASH_temp285937321;
};
var $Hann_DASH_check_DASH_temp940637309 = function(ann_DASH_check_DASH_temp286937308) {
return ann_DASH_check_DASH_temp286937308;
};
var $Hanf_arg940514500 = function(anf_arg284914498,self35914499,_plus55,torepr65) {
var anf_arg285037333 = G(self35914499,"fields",L[2239]);
var $z3732537326 = D;
var $f3733137332 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg285037333):R.ffi.throwNonFunApp(L[2239],torepr65,[anf_arg285037333]);
};
try {
if(--R.GAS > 0) {
$z3732537326 = $f3733137332();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3733137332,
"from":L[2239]});
}
} catch($e3732337324) {
if(R.isCont($e3732337324)) {
var $ss3732737328 = {"from":L[2239],
"go":function(anf_arg285137334) {
return $Hanf_arg940437335(anf_arg285137334,anf_arg284914498,_plus55);
}};
$e3732337324.stack[R.EXN_STACKHEIGHT++] = $ss3732737328;
}
if(R.isPyretException($e3732337324)) {
$e3732337324.pyretStack.push(L[2239]);
}
throw $e3732337324;
}
var $ret3732937330 = $Hanf_arg940437335($z3732537326,anf_arg284914498,_plus55);
++R.GAS;
return $ret3732937330;
};
var $Hanf_arg940437335 = function(anf_arg285137334,anf_arg284914498,_plus55) {
var $z3733837339 = D;
var $f3734437345 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg285137334):R.ffi.throwNonFunApp(L[2239],_plus55,[(", "),anf_arg285137334]);
};
try {
if(--R.GAS > 0) {
$z3733837339 = $f3734437345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3734437345,
"from":L[2239]});
}
} catch($e3733637337) {
if(R.isCont($e3733637337)) {
var $ss3734037341 = {"from":L[2239],
"go":function(anf_arg285237346) {
return $Hanf_arg940337347(anf_arg285237346,anf_arg284914498,_plus55);
}};
$e3733637337.stack[R.EXN_STACKHEIGHT++] = $ss3734037341;
}
if(R.isPyretException($e3733637337)) {
$e3733637337.pyretStack.push(L[2239]);
}
throw $e3733637337;
}
var $ret3734237343 = $Hanf_arg940337347($z3733837339,anf_arg284914498,_plus55);
++R.GAS;
return $ret3734237343;
};
var $Hanf_arg940337347 = function(anf_arg285237346,anf_arg284914498,_plus55) {
var $z3735037351 = D;
var $f3735637357 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg284914498,anf_arg285237346):R.ffi.throwNonFunApp(L[2239],_plus55,[anf_arg284914498,anf_arg285237346]);
};
try {
if(--R.GAS > 0) {
$z3735037351 = $f3735637357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3735637357,
"from":L[2239]});
}
} catch($e3734837349) {
if(R.isCont($e3734837349)) {
var $ss3735237353 = {"from":L[2239],
"go":function(anf_arg285337358) {
return $Hanf_arg940237359(anf_arg285337358,_plus55);
}};
$e3734837349.stack[R.EXN_STACKHEIGHT++] = $ss3735237353;
}
if(R.isPyretException($e3734837349)) {
$e3734837349.pyretStack.push(L[2239]);
}
throw $e3734837349;
}
var $ret3735437355 = $Hanf_arg940237359($z3735037351,_plus55);
++R.GAS;
return $ret3735437355;
};
var $Hanf_arg940237359 = function(anf_arg285337358,_plus55) {
var $z3736237363 = D;
var $f3736837369 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg285337358,(")")):R.ffi.throwNonFunApp(L[2239],_plus55,[anf_arg285337358,(")")]);
};
try {
if(--R.GAS > 0) {
$z3736237363 = $f3736837369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3736837369,
"from":L[2239]});
}
} catch($e3736037361) {
if(R.isCont($e3736037361)) {
var $ss3736437365 = {"from":L[2239],
"go":function(anf_arg285437370) {
return $Hanf_arg940137371(anf_arg285437370,_plus55);
}};
$e3736037361.stack[R.EXN_STACKHEIGHT++] = $ss3736437365;
}
if(R.isPyretException($e3736037361)) {
$e3736037361.pyretStack.push(L[2239]);
}
throw $e3736037361;
}
var $ret3736637367 = $Hanf_arg940137371($z3736237363,_plus55);
++R.GAS;
return $ret3736637367;
};
var $Hanf_arg940137371 = function(anf_arg285437370,_plus55) {
var $z3737437375 = D;
var $f3738037381 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg285437370):R.ffi.throwNonFunApp(L[2239],_plus55,[("("),anf_arg285437370]);
};
try {
if(--R.GAS > 0) {
$z3737437375 = $f3738037381();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3738037381,
"from":L[2239]});
}
} catch($e3737237373) {
if(R.isCont($e3737237373)) {
var $ss3737637377 = {"from":L[2239],
"go":function(anf_arg285537382) {
return $Hanf_arg940037383(anf_arg285537382,_plus55);
}};
$e3737237373.stack[R.EXN_STACKHEIGHT++] = $ss3737637377;
}
if(R.isPyretException($e3737237373)) {
$e3737237373.pyretStack.push(L[2239]);
}
throw $e3737237373;
}
var $ret3737837379 = $Hanf_arg940037383($z3737437375,_plus55);
++R.GAS;
return $ret3737837379;
};
var $Hanf_arg940037383 = function(anf_arg285537382,_plus55) {
var $z3738637387 = D;
var $f3739237393 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-obj"),anf_arg285537382):R.ffi.throwNonFunApp(L[2239],_plus55,[("s-obj"),anf_arg285537382]);
};
try {
if(--R.GAS > 0) {
$z3738637387 = $f3739237393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3739237393,
"from":L[2239]});
}
} catch($e3738437385) {
if(R.isCont($e3738437385)) {
var $ss3738837389 = {"from":L[2239],
"go":function(ann_DASH_check_DASH_temp284737394) {
return $Hann_DASH_check_DASH_temp939937395(ann_DASH_check_DASH_temp284737394);
}};
$e3738437385.stack[R.EXN_STACKHEIGHT++] = $ss3738837389;
}
if(R.isPyretException($e3738437385)) {
$e3738437385.pyretStack.push(L[2239]);
}
throw $e3738437385;
}
var $ret3739037391 = $Hann_DASH_check_DASH_temp939937395($z3738637387);
++R.GAS;
return $ret3739037391;
};
var $Hann_DASH_check_DASH_temp939937395 = function(ann_DASH_check_DASH_temp284737394) {
return ann_DASH_check_DASH_temp284737394;
};
var $Hcont_tail_arg939714516 = function(cont_tail_arg284414514,if_helper283514515) {
if(--R.GAS > 0) {
$z3739637397 = R.isFunction(if_helper283514515)?if_helper283514515.app(cont_tail_arg284414514):R.ffi.throwNonFunApp(L[2239],if_helper283514515,[cont_tail_arg284414514]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper283514515)?if_helper283514515.app(cont_tail_arg284414514):R.ffi.throwNonFunApp(L[2239],if_helper283514515,[cont_tail_arg284414514]);
},
"from":L[2239]});
}
++R.GAS;
return $z3739637397;
};
var $Hcont_tail_arg939814531 = function(cont_tail_arg284014530,if_helper283514515) {
if(--R.GAS > 0) {
$z3739837399 = R.isFunction(if_helper283514515)?if_helper283514515.app(cont_tail_arg284014530):R.ffi.throwNonFunApp(L[2239],if_helper283514515,[cont_tail_arg284014530]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper283514515)?if_helper283514515.app(cont_tail_arg284014530):R.ffi.throwNonFunApp(L[2239],if_helper283514515,[cont_tail_arg284014530]);
},
"from":L[2239]});
}
++R.GAS;
return $z3739837399;
};
var $Hanf_arg939614554 = function(anf_arg282014552,self35314553,_plus55,torepr65) {
var anf_arg282137410 = G(self35314553,"supe",L[2240]);
var $z3740237403 = D;
var $f3740837409 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg282137410):R.ffi.throwNonFunApp(L[2240],torepr65,[anf_arg282137410]);
};
try {
if(--R.GAS > 0) {
$z3740237403 = $f3740837409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3740837409,
"from":L[2240]});
}
} catch($e3740037401) {
if(R.isCont($e3740037401)) {
var $ss3740437405 = {"from":L[2240],
"go":function(anf_arg282237411) {
return $Hanf_arg939537412(anf_arg282237411,anf_arg282014552,self35314553,_plus55,torepr65);
}};
$e3740037401.stack[R.EXN_STACKHEIGHT++] = $ss3740437405;
}
if(R.isPyretException($e3740037401)) {
$e3740037401.pyretStack.push(L[2240]);
}
throw $e3740037401;
}
var $ret3740637407 = $Hanf_arg939537412($z3740237403,anf_arg282014552,self35314553,_plus55,torepr65);
++R.GAS;
return $ret3740637407;
};
var $Hanf_arg939537412 = function(anf_arg282237411,anf_arg282014552,self35314553,_plus55,torepr65) {
var $z3741537416 = D;
var $f3742137422 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg282237411):R.ffi.throwNonFunApp(L[2240],_plus55,[(", "),anf_arg282237411]);
};
try {
if(--R.GAS > 0) {
$z3741537416 = $f3742137422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3742137422,
"from":L[2240]});
}
} catch($e3741337414) {
if(R.isCont($e3741337414)) {
var $ss3741737418 = {"from":L[2240],
"go":function(anf_arg282337423) {
return $Hanf_arg939437424(anf_arg282337423,anf_arg282014552,self35314553,_plus55,torepr65);
}};
$e3741337414.stack[R.EXN_STACKHEIGHT++] = $ss3741737418;
}
if(R.isPyretException($e3741337414)) {
$e3741337414.pyretStack.push(L[2240]);
}
throw $e3741337414;
}
var $ret3741937420 = $Hanf_arg939437424($z3741537416,anf_arg282014552,self35314553,_plus55,torepr65);
++R.GAS;
return $ret3741937420;
};
var $Hanf_arg939437424 = function(anf_arg282337423,anf_arg282014552,self35314553,_plus55,torepr65) {
var $z3742737428 = D;
var $f3743337434 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg282014552,anf_arg282337423):R.ffi.throwNonFunApp(L[2240],_plus55,[anf_arg282014552,anf_arg282337423]);
};
try {
if(--R.GAS > 0) {
$z3742737428 = $f3743337434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3743337434,
"from":L[2240]});
}
} catch($e3742537426) {
if(R.isCont($e3742537426)) {
var $ss3742937430 = {"from":L[2240],
"go":function(anf_arg282437435) {
return $Hanf_arg939337436(anf_arg282437435,self35314553,_plus55,torepr65);
}};
$e3742537426.stack[R.EXN_STACKHEIGHT++] = $ss3742937430;
}
if(R.isPyretException($e3742537426)) {
$e3742537426.pyretStack.push(L[2240]);
}
throw $e3742537426;
}
var $ret3743137432 = $Hanf_arg939337436($z3742737428,self35314553,_plus55,torepr65);
++R.GAS;
return $ret3743137432;
};
var $Hanf_arg939337436 = function(anf_arg282437435,self35314553,_plus55,torepr65) {
var anf_arg282537447 = G(self35314553,"fields",L[2240]);
var $z3743937440 = D;
var $f3744537446 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg282537447):R.ffi.throwNonFunApp(L[2240],torepr65,[anf_arg282537447]);
};
try {
if(--R.GAS > 0) {
$z3743937440 = $f3744537446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3744537446,
"from":L[2240]});
}
} catch($e3743737438) {
if(R.isCont($e3743737438)) {
var $ss3744137442 = {"from":L[2240],
"go":function(anf_arg282637448) {
return $Hanf_arg939237449(anf_arg282637448,anf_arg282437435,_plus55);
}};
$e3743737438.stack[R.EXN_STACKHEIGHT++] = $ss3744137442;
}
if(R.isPyretException($e3743737438)) {
$e3743737438.pyretStack.push(L[2240]);
}
throw $e3743737438;
}
var $ret3744337444 = $Hanf_arg939237449($z3743937440,anf_arg282437435,_plus55);
++R.GAS;
return $ret3744337444;
};
var $Hanf_arg939237449 = function(anf_arg282637448,anf_arg282437435,_plus55) {
var $z3745237453 = D;
var $f3745837459 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg282637448):R.ffi.throwNonFunApp(L[2240],_plus55,[(", "),anf_arg282637448]);
};
try {
if(--R.GAS > 0) {
$z3745237453 = $f3745837459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3745837459,
"from":L[2240]});
}
} catch($e3745037451) {
if(R.isCont($e3745037451)) {
var $ss3745437455 = {"from":L[2240],
"go":function(anf_arg282737460) {
return $Hanf_arg939137461(anf_arg282737460,anf_arg282437435,_plus55);
}};
$e3745037451.stack[R.EXN_STACKHEIGHT++] = $ss3745437455;
}
if(R.isPyretException($e3745037451)) {
$e3745037451.pyretStack.push(L[2240]);
}
throw $e3745037451;
}
var $ret3745637457 = $Hanf_arg939137461($z3745237453,anf_arg282437435,_plus55);
++R.GAS;
return $ret3745637457;
};
var $Hanf_arg939137461 = function(anf_arg282737460,anf_arg282437435,_plus55) {
var $z3746437465 = D;
var $f3747037471 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg282437435,anf_arg282737460):R.ffi.throwNonFunApp(L[2240],_plus55,[anf_arg282437435,anf_arg282737460]);
};
try {
if(--R.GAS > 0) {
$z3746437465 = $f3747037471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3747037471,
"from":L[2240]});
}
} catch($e3746237463) {
if(R.isCont($e3746237463)) {
var $ss3746637467 = {"from":L[2240],
"go":function(anf_arg282837472) {
return $Hanf_arg939037473(anf_arg282837472,_plus55);
}};
$e3746237463.stack[R.EXN_STACKHEIGHT++] = $ss3746637467;
}
if(R.isPyretException($e3746237463)) {
$e3746237463.pyretStack.push(L[2240]);
}
throw $e3746237463;
}
var $ret3746837469 = $Hanf_arg939037473($z3746437465,_plus55);
++R.GAS;
return $ret3746837469;
};
var $Hanf_arg939037473 = function(anf_arg282837472,_plus55) {
var $z3747637477 = D;
var $f3748237483 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg282837472,(")")):R.ffi.throwNonFunApp(L[2240],_plus55,[anf_arg282837472,(")")]);
};
try {
if(--R.GAS > 0) {
$z3747637477 = $f3748237483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3748237483,
"from":L[2240]});
}
} catch($e3747437475) {
if(R.isCont($e3747437475)) {
var $ss3747837479 = {"from":L[2240],
"go":function(anf_arg282937484) {
return $Hanf_arg938937485(anf_arg282937484,_plus55);
}};
$e3747437475.stack[R.EXN_STACKHEIGHT++] = $ss3747837479;
}
if(R.isPyretException($e3747437475)) {
$e3747437475.pyretStack.push(L[2240]);
}
throw $e3747437475;
}
var $ret3748037481 = $Hanf_arg938937485($z3747637477,_plus55);
++R.GAS;
return $ret3748037481;
};
var $Hanf_arg938937485 = function(anf_arg282937484,_plus55) {
var $z3748837489 = D;
var $f3749437495 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg282937484):R.ffi.throwNonFunApp(L[2240],_plus55,[("("),anf_arg282937484]);
};
try {
if(--R.GAS > 0) {
$z3748837489 = $f3749437495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3749437495,
"from":L[2240]});
}
} catch($e3748637487) {
if(R.isCont($e3748637487)) {
var $ss3749037491 = {"from":L[2240],
"go":function(anf_arg283037496) {
return $Hanf_arg938837497(anf_arg283037496,_plus55);
}};
$e3748637487.stack[R.EXN_STACKHEIGHT++] = $ss3749037491;
}
if(R.isPyretException($e3748637487)) {
$e3748637487.pyretStack.push(L[2240]);
}
throw $e3748637487;
}
var $ret3749237493 = $Hanf_arg938837497($z3748837489,_plus55);
++R.GAS;
return $ret3749237493;
};
var $Hanf_arg938837497 = function(anf_arg283037496,_plus55) {
var $z3750037501 = D;
var $f3750637507 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-update"),anf_arg283037496):R.ffi.throwNonFunApp(L[2240],_plus55,[("s-update"),anf_arg283037496]);
};
try {
if(--R.GAS > 0) {
$z3750037501 = $f3750637507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3750637507,
"from":L[2240]});
}
} catch($e3749837499) {
if(R.isCont($e3749837499)) {
var $ss3750237503 = {"from":L[2240],
"go":function(ann_DASH_check_DASH_temp281837508) {
return $Hann_DASH_check_DASH_temp938737509(ann_DASH_check_DASH_temp281837508);
}};
$e3749837499.stack[R.EXN_STACKHEIGHT++] = $ss3750237503;
}
if(R.isPyretException($e3749837499)) {
$e3749837499.pyretStack.push(L[2240]);
}
throw $e3749837499;
}
var $ret3750437505 = $Hann_DASH_check_DASH_temp938737509($z3750037501);
++R.GAS;
return $ret3750437505;
};
var $Hann_DASH_check_DASH_temp938737509 = function(ann_DASH_check_DASH_temp281837508) {
return ann_DASH_check_DASH_temp281837508;
};
var $Hcont_tail_arg938514571 = function(cont_tail_arg281514569,if_helper280514570) {
if(--R.GAS > 0) {
$z3751037511 = R.isFunction(if_helper280514570)?if_helper280514570.app(cont_tail_arg281514569):R.ffi.throwNonFunApp(L[2240],if_helper280514570,[cont_tail_arg281514569]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper280514570)?if_helper280514570.app(cont_tail_arg281514569):R.ffi.throwNonFunApp(L[2240],if_helper280514570,[cont_tail_arg281514569]);
},
"from":L[2240]});
}
++R.GAS;
return $z3751037511;
};
var $Hcont_tail_arg938614586 = function(cont_tail_arg281014585,if_helper280514570) {
if(--R.GAS > 0) {
$z3751237513 = R.isFunction(if_helper280514570)?if_helper280514570.app(cont_tail_arg281014585):R.ffi.throwNonFunApp(L[2240],if_helper280514570,[cont_tail_arg281014585]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper280514570)?if_helper280514570.app(cont_tail_arg281014585):R.ffi.throwNonFunApp(L[2240],if_helper280514570,[cont_tail_arg281014585]);
},
"from":L[2240]});
}
++R.GAS;
return $z3751237513;
};
var $Hanf_arg938414608 = function(anf_arg278614605,INDENT118169,PP170,anf_fun278314606,self84214607,str_DASH_period160702,_plus55) {
var $z3751637517 = D;
var $f3752237523 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg278614605,str_DASH_period160702):R.ffi.throwNonFunApp(L[4431],_plus55,[anf_arg278614605,str_DASH_period160702]);
};
try {
if(--R.GAS > 0) {
$z3751637517 = $f3752237523();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3752237523,
"from":L[4431]});
}
} catch($e3751437515) {
if(R.isCont($e3751437515)) {
var $ss3751837519 = {"from":L[4431],
"go":function(anf_arg278737524) {
return $Hanf_arg938337525(anf_arg278737524,INDENT118169,PP170,anf_fun278314606,self84214607,_plus55);
}};
$e3751437515.stack[R.EXN_STACKHEIGHT++] = $ss3751837519;
}
if(R.isPyretException($e3751437515)) {
$e3751437515.pyretStack.push(L[4431]);
}
throw $e3751437515;
}
var $ret3752037521 = $Hanf_arg938337525($z3751637517,INDENT118169,PP170,anf_fun278314606,self84214607,_plus55);
++R.GAS;
return $ret3752037521;
};
var $Hanf_arg938337525 = function(anf_arg278737524,INDENT118169,PP170,anf_fun278314606,self84214607,_plus55) {
var anf_fun278837539 = G(PP170,"surround-separate",L[4435]);
var anf_arg278937536 = G(PP170,"lbrace",L[4434]);
var anf_arg279037537 = G(PP170,"rbrace",L[4433]);
var $z3752837529 = D;
var $f3753437535 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg278937536,anf_arg279037537):R.ffi.throwNonFunApp(L[4432],_plus55,[anf_arg278937536,anf_arg279037537]);
};
try {
if(--R.GAS > 0) {
$z3752837529 = $f3753437535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3753437535,
"from":L[4432]});
}
} catch($e3752637527) {
if(R.isCont($e3752637527)) {
var $ss3753037531 = {"from":L[4432],
"go":function(anf_arg279137538) {
return $Hanf_arg938237540(anf_arg279137538,INDENT118169,PP170,anf_arg278737524,anf_fun278314606,anf_fun278837539,self84214607,_plus55);
}};
$e3752637527.stack[R.EXN_STACKHEIGHT++] = $ss3753037531;
}
if(R.isPyretException($e3752637527)) {
$e3752637527.pyretStack.push(L[4432]);
}
throw $e3752637527;
}
var $ret3753237533 = $Hanf_arg938237540($z3752837529,INDENT118169,PP170,anf_arg278737524,anf_fun278314606,anf_fun278837539,self84214607,_plus55);
++R.GAS;
return $ret3753237533;
};
var $Hanf_arg938237540 = function(anf_arg279137538,INDENT118169,PP170,anf_arg278737524,anf_fun278314606,anf_fun278837539,self84214607,_plus55) {
var anf_arg279237554 = G(PP170,"lbrace",L[4442]);
var anf_arg279337555 = G(PP170,"commabreak",L[4441]);
var anf_arg279437556 = G(PP170,"rbrace",L[4440]);
var anf_bracket279537572 = G(self84214607,"fields",L[4439]);
var anf_fun279637551 = G(anf_bracket279537572,"map",L[4438]);
var anf_arg279937552 = R.makeFunction(function(recv_DASH_34837558) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4437],1,arguments);
}
var anf_fun279837569 = G(recv_DASH_34837558,"tosource",L[4437]);
var $z3756137562 = D;
var $f3756737568 = function(_) {
return R.isFunction(anf_fun279837569)?anf_fun279837569.app():R.ffi.throwNonFunApp(L[4437],anf_fun279837569,[]);
};
try {
if(--R.GAS > 0) {
$z3756137562 = $f3756737568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3756737568,
"from":L[4437]});
}
} catch($e3755937560) {
if(R.isCont($e3755937560)) {
var $ss3756337564 = {"from":L[4437],
"go":function(ann_DASH_check_DASH_temp279737570) {
return $Hann_DASH_check_DASH_temp937737571(ann_DASH_check_DASH_temp279737570);
}};
$e3755937560.stack[R.EXN_STACKHEIGHT++] = $ss3756337564;
}
if(R.isPyretException($e3755937560)) {
$e3755937560.pyretStack.push(L[4437]);
}
throw $e3755937560;
}
var $ret3756537566 = $Hann_DASH_check_DASH_temp937737571($z3756137562);
++R.GAS;
return $ret3756537566;
});
var $z3754337544 = D;
var $f3754937550 = function(_) {
return R.isFunction(anf_fun279637551)?anf_fun279637551.app(anf_arg279937552):R.ffi.throwNonFunApp(L[4436],anf_fun279637551,[anf_arg279937552]);
};
try {
if(--R.GAS > 0) {
$z3754337544 = $f3754937550();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3754937550,
"from":L[4436]});
}
} catch($e3754137542) {
if(R.isCont($e3754137542)) {
var $ss3754537546 = {"from":L[4436],
"go":function(anf_arg280037553) {
return $Hanf_arg938137557(anf_arg280037553,INDENT118169,anf_arg278737524,anf_arg279137538,anf_arg279237554,anf_arg279337555,anf_arg279437556,anf_fun278314606,anf_fun278837539,_plus55);
}};
$e3754137542.stack[R.EXN_STACKHEIGHT++] = $ss3754537546;
}
if(R.isPyretException($e3754137542)) {
$e3754137542.pyretStack.push(L[4436]);
}
throw $e3754137542;
}
var $ret3754737548 = $Hanf_arg938137557($z3754337544,INDENT118169,anf_arg278737524,anf_arg279137538,anf_arg279237554,anf_arg279337555,anf_arg279437556,anf_fun278314606,anf_fun278837539,_plus55);
++R.GAS;
return $ret3754737548;
};
var $Hanf_arg938137557 = function(anf_arg280037553,INDENT118169,anf_arg278737524,anf_arg279137538,anf_arg279237554,anf_arg279337555,anf_arg279437556,anf_fun278314606,anf_fun278837539,_plus55) {
var $z3757537576 = D;
var $f3758137582 = function(_) {
return R.isFunction(anf_fun278837539)?anf_fun278837539.app(INDENT118169,(1),anf_arg279137538,anf_arg279237554,anf_arg279337555,anf_arg279437556,anf_arg280037553):R.ffi.throwNonFunApp(L[4443],anf_fun278837539,[INDENT118169,(1),anf_arg279137538,anf_arg279237554,anf_arg279337555,anf_arg279437556,anf_arg280037553]);
};
try {
if(--R.GAS > 0) {
$z3757537576 = $f3758137582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3758137582,
"from":L[4443]});
}
} catch($e3757337574) {
if(R.isCont($e3757337574)) {
var $ss3757737578 = {"from":L[4443],
"go":function(anf_arg280137583) {
return $Hanf_arg938037584(anf_arg280137583,anf_arg278737524,anf_fun278314606,_plus55);
}};
$e3757337574.stack[R.EXN_STACKHEIGHT++] = $ss3757737578;
}
if(R.isPyretException($e3757337574)) {
$e3757337574.pyretStack.push(L[4443]);
}
throw $e3757337574;
}
var $ret3757937580 = $Hanf_arg938037584($z3757537576,anf_arg278737524,anf_fun278314606,_plus55);
++R.GAS;
return $ret3757937580;
};
var $Hanf_arg938037584 = function(anf_arg280137583,anf_arg278737524,anf_fun278314606,_plus55) {
var $z3758737588 = D;
var $f3759337594 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg278737524,anf_arg280137583):R.ffi.throwNonFunApp(L[4431],_plus55,[anf_arg278737524,anf_arg280137583]);
};
try {
if(--R.GAS > 0) {
$z3758737588 = $f3759337594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3759337594,
"from":L[4431]});
}
} catch($e3758537586) {
if(R.isCont($e3758537586)) {
var $ss3758937590 = {"from":L[4431],
"go":function(anf_arg280237595) {
return $Hanf_arg937937596(anf_arg280237595,anf_fun278314606);
}};
$e3758537586.stack[R.EXN_STACKHEIGHT++] = $ss3758937590;
}
if(R.isPyretException($e3758537586)) {
$e3758537586.pyretStack.push(L[4431]);
}
throw $e3758537586;
}
var $ret3759137592 = $Hanf_arg937937596($z3758737588,anf_fun278314606);
++R.GAS;
return $ret3759137592;
};
var $Hanf_arg937937596 = function(anf_arg280237595,anf_fun278314606) {
var $z3759937600 = D;
var $f3760537606 = function(_) {
return R.isFunction(anf_fun278314606)?anf_fun278314606.app(anf_arg280237595):R.ffi.throwNonFunApp(L[2737],anf_fun278314606,[anf_arg280237595]);
};
try {
if(--R.GAS > 0) {
$z3759937600 = $f3760537606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3760537606,
"from":L[2737]});
}
} catch($e3759737598) {
if(R.isCont($e3759737598)) {
var $ss3760137602 = {"from":L[2737],
"go":function(ann_DASH_check_DASH_temp278237607) {
return $Hann_DASH_check_DASH_temp937837608(ann_DASH_check_DASH_temp278237607);
}};
$e3759737598.stack[R.EXN_STACKHEIGHT++] = $ss3760137602;
}
if(R.isPyretException($e3759737598)) {
$e3759737598.pyretStack.push(L[2737]);
}
throw $e3759737598;
}
var $ret3760337604 = $Hann_DASH_check_DASH_temp937837608($z3759937600);
++R.GAS;
return $ret3760337604;
};
var $Hann_DASH_check_DASH_temp937837608 = function(ann_DASH_check_DASH_temp278237607) {
return ann_DASH_check_DASH_temp278237607;
};
var $Hann_DASH_check_DASH_temp937737571 = function(ann_DASH_check_DASH_temp279737570) {
return ann_DASH_check_DASH_temp279737570;
};
var $Hanf_arg937614625 = function(anf_arg276814623,self34614624,_plus55,torepr65) {
var anf_arg276937619 = G(self34614624,"supe",L[2241]);
var $z3761137612 = D;
var $f3761737618 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg276937619):R.ffi.throwNonFunApp(L[2241],torepr65,[anf_arg276937619]);
};
try {
if(--R.GAS > 0) {
$z3761137612 = $f3761737618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3761737618,
"from":L[2241]});
}
} catch($e3760937610) {
if(R.isCont($e3760937610)) {
var $ss3761337614 = {"from":L[2241],
"go":function(anf_arg277037620) {
return $Hanf_arg937537621(anf_arg277037620,anf_arg276814623,self34614624,_plus55,torepr65);
}};
$e3760937610.stack[R.EXN_STACKHEIGHT++] = $ss3761337614;
}
if(R.isPyretException($e3760937610)) {
$e3760937610.pyretStack.push(L[2241]);
}
throw $e3760937610;
}
var $ret3761537616 = $Hanf_arg937537621($z3761137612,anf_arg276814623,self34614624,_plus55,torepr65);
++R.GAS;
return $ret3761537616;
};
var $Hanf_arg937537621 = function(anf_arg277037620,anf_arg276814623,self34614624,_plus55,torepr65) {
var $z3762437625 = D;
var $f3763037631 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg277037620):R.ffi.throwNonFunApp(L[2241],_plus55,[(", "),anf_arg277037620]);
};
try {
if(--R.GAS > 0) {
$z3762437625 = $f3763037631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3763037631,
"from":L[2241]});
}
} catch($e3762237623) {
if(R.isCont($e3762237623)) {
var $ss3762637627 = {"from":L[2241],
"go":function(anf_arg277137632) {
return $Hanf_arg937437633(anf_arg277137632,anf_arg276814623,self34614624,_plus55,torepr65);
}};
$e3762237623.stack[R.EXN_STACKHEIGHT++] = $ss3762637627;
}
if(R.isPyretException($e3762237623)) {
$e3762237623.pyretStack.push(L[2241]);
}
throw $e3762237623;
}
var $ret3762837629 = $Hanf_arg937437633($z3762437625,anf_arg276814623,self34614624,_plus55,torepr65);
++R.GAS;
return $ret3762837629;
};
var $Hanf_arg937437633 = function(anf_arg277137632,anf_arg276814623,self34614624,_plus55,torepr65) {
var $z3763637637 = D;
var $f3764237643 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg276814623,anf_arg277137632):R.ffi.throwNonFunApp(L[2241],_plus55,[anf_arg276814623,anf_arg277137632]);
};
try {
if(--R.GAS > 0) {
$z3763637637 = $f3764237643();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3764237643,
"from":L[2241]});
}
} catch($e3763437635) {
if(R.isCont($e3763437635)) {
var $ss3763837639 = {"from":L[2241],
"go":function(anf_arg277237644) {
return $Hanf_arg937337645(anf_arg277237644,self34614624,_plus55,torepr65);
}};
$e3763437635.stack[R.EXN_STACKHEIGHT++] = $ss3763837639;
}
if(R.isPyretException($e3763437635)) {
$e3763437635.pyretStack.push(L[2241]);
}
throw $e3763437635;
}
var $ret3764037641 = $Hanf_arg937337645($z3763637637,self34614624,_plus55,torepr65);
++R.GAS;
return $ret3764037641;
};
var $Hanf_arg937337645 = function(anf_arg277237644,self34614624,_plus55,torepr65) {
var anf_arg277337656 = G(self34614624,"fields",L[2241]);
var $z3764837649 = D;
var $f3765437655 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg277337656):R.ffi.throwNonFunApp(L[2241],torepr65,[anf_arg277337656]);
};
try {
if(--R.GAS > 0) {
$z3764837649 = $f3765437655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3765437655,
"from":L[2241]});
}
} catch($e3764637647) {
if(R.isCont($e3764637647)) {
var $ss3765037651 = {"from":L[2241],
"go":function(anf_arg277437657) {
return $Hanf_arg937237658(anf_arg277437657,anf_arg277237644,_plus55);
}};
$e3764637647.stack[R.EXN_STACKHEIGHT++] = $ss3765037651;
}
if(R.isPyretException($e3764637647)) {
$e3764637647.pyretStack.push(L[2241]);
}
throw $e3764637647;
}
var $ret3765237653 = $Hanf_arg937237658($z3764837649,anf_arg277237644,_plus55);
++R.GAS;
return $ret3765237653;
};
var $Hanf_arg937237658 = function(anf_arg277437657,anf_arg277237644,_plus55) {
var $z3766137662 = D;
var $f3766737668 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg277437657):R.ffi.throwNonFunApp(L[2241],_plus55,[(", "),anf_arg277437657]);
};
try {
if(--R.GAS > 0) {
$z3766137662 = $f3766737668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3766737668,
"from":L[2241]});
}
} catch($e3765937660) {
if(R.isCont($e3765937660)) {
var $ss3766337664 = {"from":L[2241],
"go":function(anf_arg277537669) {
return $Hanf_arg937137670(anf_arg277537669,anf_arg277237644,_plus55);
}};
$e3765937660.stack[R.EXN_STACKHEIGHT++] = $ss3766337664;
}
if(R.isPyretException($e3765937660)) {
$e3765937660.pyretStack.push(L[2241]);
}
throw $e3765937660;
}
var $ret3766537666 = $Hanf_arg937137670($z3766137662,anf_arg277237644,_plus55);
++R.GAS;
return $ret3766537666;
};
var $Hanf_arg937137670 = function(anf_arg277537669,anf_arg277237644,_plus55) {
var $z3767337674 = D;
var $f3767937680 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg277237644,anf_arg277537669):R.ffi.throwNonFunApp(L[2241],_plus55,[anf_arg277237644,anf_arg277537669]);
};
try {
if(--R.GAS > 0) {
$z3767337674 = $f3767937680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3767937680,
"from":L[2241]});
}
} catch($e3767137672) {
if(R.isCont($e3767137672)) {
var $ss3767537676 = {"from":L[2241],
"go":function(anf_arg277637681) {
return $Hanf_arg937037682(anf_arg277637681,_plus55);
}};
$e3767137672.stack[R.EXN_STACKHEIGHT++] = $ss3767537676;
}
if(R.isPyretException($e3767137672)) {
$e3767137672.pyretStack.push(L[2241]);
}
throw $e3767137672;
}
var $ret3767737678 = $Hanf_arg937037682($z3767337674,_plus55);
++R.GAS;
return $ret3767737678;
};
var $Hanf_arg937037682 = function(anf_arg277637681,_plus55) {
var $z3768537686 = D;
var $f3769137692 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg277637681,(")")):R.ffi.throwNonFunApp(L[2241],_plus55,[anf_arg277637681,(")")]);
};
try {
if(--R.GAS > 0) {
$z3768537686 = $f3769137692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3769137692,
"from":L[2241]});
}
} catch($e3768337684) {
if(R.isCont($e3768337684)) {
var $ss3768737688 = {"from":L[2241],
"go":function(anf_arg277737693) {
return $Hanf_arg936937694(anf_arg277737693,_plus55);
}};
$e3768337684.stack[R.EXN_STACKHEIGHT++] = $ss3768737688;
}
if(R.isPyretException($e3768337684)) {
$e3768337684.pyretStack.push(L[2241]);
}
throw $e3768337684;
}
var $ret3768937690 = $Hanf_arg936937694($z3768537686,_plus55);
++R.GAS;
return $ret3768937690;
};
var $Hanf_arg936937694 = function(anf_arg277737693,_plus55) {
var $z3769737698 = D;
var $f3770337704 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg277737693):R.ffi.throwNonFunApp(L[2241],_plus55,[("("),anf_arg277737693]);
};
try {
if(--R.GAS > 0) {
$z3769737698 = $f3770337704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3770337704,
"from":L[2241]});
}
} catch($e3769537696) {
if(R.isCont($e3769537696)) {
var $ss3769937700 = {"from":L[2241],
"go":function(anf_arg277837705) {
return $Hanf_arg936837706(anf_arg277837705,_plus55);
}};
$e3769537696.stack[R.EXN_STACKHEIGHT++] = $ss3769937700;
}
if(R.isPyretException($e3769537696)) {
$e3769537696.pyretStack.push(L[2241]);
}
throw $e3769537696;
}
var $ret3770137702 = $Hanf_arg936837706($z3769737698,_plus55);
++R.GAS;
return $ret3770137702;
};
var $Hanf_arg936837706 = function(anf_arg277837705,_plus55) {
var $z3770937710 = D;
var $f3771537716 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-extend"),anf_arg277837705):R.ffi.throwNonFunApp(L[2241],_plus55,[("s-extend"),anf_arg277837705]);
};
try {
if(--R.GAS > 0) {
$z3770937710 = $f3771537716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3771537716,
"from":L[2241]});
}
} catch($e3770737708) {
if(R.isCont($e3770737708)) {
var $ss3771137712 = {"from":L[2241],
"go":function(ann_DASH_check_DASH_temp276637717) {
return $Hann_DASH_check_DASH_temp936737718(ann_DASH_check_DASH_temp276637717);
}};
$e3770737708.stack[R.EXN_STACKHEIGHT++] = $ss3771137712;
}
if(R.isPyretException($e3770737708)) {
$e3770737708.pyretStack.push(L[2241]);
}
throw $e3770737708;
}
var $ret3771337714 = $Hann_DASH_check_DASH_temp936737718($z3770937710);
++R.GAS;
return $ret3771337714;
};
var $Hann_DASH_check_DASH_temp936737718 = function(ann_DASH_check_DASH_temp276637717) {
return ann_DASH_check_DASH_temp276637717;
};
var $Hcont_tail_arg936514642 = function(cont_tail_arg276314640,if_helper275314641) {
if(--R.GAS > 0) {
$z3771937720 = R.isFunction(if_helper275314641)?if_helper275314641.app(cont_tail_arg276314640):R.ffi.throwNonFunApp(L[2241],if_helper275314641,[cont_tail_arg276314640]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper275314641)?if_helper275314641.app(cont_tail_arg276314640):R.ffi.throwNonFunApp(L[2241],if_helper275314641,[cont_tail_arg276314640]);
},
"from":L[2241]});
}
++R.GAS;
return $z3771937720;
};
var $Hcont_tail_arg936614657 = function(cont_tail_arg275814656,if_helper275314641) {
if(--R.GAS > 0) {
$z3772137722 = R.isFunction(if_helper275314641)?if_helper275314641.app(cont_tail_arg275814656):R.ffi.throwNonFunApp(L[2241],if_helper275314641,[cont_tail_arg275814656]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper275314641)?if_helper275314641.app(cont_tail_arg275814656):R.ffi.throwNonFunApp(L[2241],if_helper275314641,[cont_tail_arg275814656]);
},
"from":L[2241]});
}
++R.GAS;
return $z3772137722;
};
var $Hann_DASH_check_DASH_temp936414681 = function(ann_DASH_check_DASH_temp274514680) {
return ann_DASH_check_DASH_temp274514680;
};
var $Hanf_arg936314698 = function(anf_arg271914696,self34014697,_plus55,torepr65) {
var anf_arg272037733 = G(self34014697,"args",L[2242]);
var $z3772537726 = D;
var $f3773137732 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg272037733):R.ffi.throwNonFunApp(L[2242],torepr65,[anf_arg272037733]);
};
try {
if(--R.GAS > 0) {
$z3772537726 = $f3773137732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3773137732,
"from":L[2242]});
}
} catch($e3772337724) {
if(R.isCont($e3772337724)) {
var $ss3772737728 = {"from":L[2242],
"go":function(anf_arg272137734) {
return $Hanf_arg936237735(anf_arg272137734,anf_arg271914696,self34014697,_plus55,torepr65);
}};
$e3772337724.stack[R.EXN_STACKHEIGHT++] = $ss3772737728;
}
if(R.isPyretException($e3772337724)) {
$e3772337724.pyretStack.push(L[2242]);
}
throw $e3772337724;
}
var $ret3772937730 = $Hanf_arg936237735($z3772537726,anf_arg271914696,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3772937730;
};
var $Hanf_arg936237735 = function(anf_arg272137734,anf_arg271914696,self34014697,_plus55,torepr65) {
var $z3773837739 = D;
var $f3774437745 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg272137734):R.ffi.throwNonFunApp(L[2242],_plus55,[(", "),anf_arg272137734]);
};
try {
if(--R.GAS > 0) {
$z3773837739 = $f3774437745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3774437745,
"from":L[2242]});
}
} catch($e3773637737) {
if(R.isCont($e3773637737)) {
var $ss3774037741 = {"from":L[2242],
"go":function(anf_arg272237746) {
return $Hanf_arg936137747(anf_arg272237746,anf_arg271914696,self34014697,_plus55,torepr65);
}};
$e3773637737.stack[R.EXN_STACKHEIGHT++] = $ss3774037741;
}
if(R.isPyretException($e3773637737)) {
$e3773637737.pyretStack.push(L[2242]);
}
throw $e3773637737;
}
var $ret3774237743 = $Hanf_arg936137747($z3773837739,anf_arg271914696,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3774237743;
};
var $Hanf_arg936137747 = function(anf_arg272237746,anf_arg271914696,self34014697,_plus55,torepr65) {
var $z3775037751 = D;
var $f3775637757 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg271914696,anf_arg272237746):R.ffi.throwNonFunApp(L[2242],_plus55,[anf_arg271914696,anf_arg272237746]);
};
try {
if(--R.GAS > 0) {
$z3775037751 = $f3775637757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3775637757,
"from":L[2242]});
}
} catch($e3774837749) {
if(R.isCont($e3774837749)) {
var $ss3775237753 = {"from":L[2242],
"go":function(anf_arg272337758) {
return $Hanf_arg936037759(anf_arg272337758,self34014697,_plus55,torepr65);
}};
$e3774837749.stack[R.EXN_STACKHEIGHT++] = $ss3775237753;
}
if(R.isPyretException($e3774837749)) {
$e3774837749.pyretStack.push(L[2242]);
}
throw $e3774837749;
}
var $ret3775437755 = $Hanf_arg936037759($z3775037751,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3775437755;
};
var $Hanf_arg936037759 = function(anf_arg272337758,self34014697,_plus55,torepr65) {
var anf_arg272437770 = G(self34014697,"ann",L[2242]);
var $z3776237763 = D;
var $f3776837769 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg272437770):R.ffi.throwNonFunApp(L[2242],torepr65,[anf_arg272437770]);
};
try {
if(--R.GAS > 0) {
$z3776237763 = $f3776837769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3776837769,
"from":L[2242]});
}
} catch($e3776037761) {
if(R.isCont($e3776037761)) {
var $ss3776437765 = {"from":L[2242],
"go":function(anf_arg272537771) {
return $Hanf_arg935937772(anf_arg272537771,anf_arg272337758,self34014697,_plus55,torepr65);
}};
$e3776037761.stack[R.EXN_STACKHEIGHT++] = $ss3776437765;
}
if(R.isPyretException($e3776037761)) {
$e3776037761.pyretStack.push(L[2242]);
}
throw $e3776037761;
}
var $ret3776637767 = $Hanf_arg935937772($z3776237763,anf_arg272337758,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3776637767;
};
var $Hanf_arg935937772 = function(anf_arg272537771,anf_arg272337758,self34014697,_plus55,torepr65) {
var $z3777537776 = D;
var $f3778137782 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg272537771):R.ffi.throwNonFunApp(L[2242],_plus55,[(", "),anf_arg272537771]);
};
try {
if(--R.GAS > 0) {
$z3777537776 = $f3778137782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3778137782,
"from":L[2242]});
}
} catch($e3777337774) {
if(R.isCont($e3777337774)) {
var $ss3777737778 = {"from":L[2242],
"go":function(anf_arg272637783) {
return $Hanf_arg935837784(anf_arg272637783,anf_arg272337758,self34014697,_plus55,torepr65);
}};
$e3777337774.stack[R.EXN_STACKHEIGHT++] = $ss3777737778;
}
if(R.isPyretException($e3777337774)) {
$e3777337774.pyretStack.push(L[2242]);
}
throw $e3777337774;
}
var $ret3777937780 = $Hanf_arg935837784($z3777537776,anf_arg272337758,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3777937780;
};
var $Hanf_arg935837784 = function(anf_arg272637783,anf_arg272337758,self34014697,_plus55,torepr65) {
var $z3778737788 = D;
var $f3779337794 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg272337758,anf_arg272637783):R.ffi.throwNonFunApp(L[2242],_plus55,[anf_arg272337758,anf_arg272637783]);
};
try {
if(--R.GAS > 0) {
$z3778737788 = $f3779337794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3779337794,
"from":L[2242]});
}
} catch($e3778537786) {
if(R.isCont($e3778537786)) {
var $ss3778937790 = {"from":L[2242],
"go":function(anf_arg272737795) {
return $Hanf_arg935737796(anf_arg272737795,self34014697,_plus55,torepr65);
}};
$e3778537786.stack[R.EXN_STACKHEIGHT++] = $ss3778937790;
}
if(R.isPyretException($e3778537786)) {
$e3778537786.pyretStack.push(L[2242]);
}
throw $e3778537786;
}
var $ret3779137792 = $Hanf_arg935737796($z3778737788,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3779137792;
};
var $Hanf_arg935737796 = function(anf_arg272737795,self34014697,_plus55,torepr65) {
var anf_arg272837807 = G(self34014697,"doc",L[2242]);
var $z3779937800 = D;
var $f3780537806 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg272837807):R.ffi.throwNonFunApp(L[2242],torepr65,[anf_arg272837807]);
};
try {
if(--R.GAS > 0) {
$z3779937800 = $f3780537806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3780537806,
"from":L[2242]});
}
} catch($e3779737798) {
if(R.isCont($e3779737798)) {
var $ss3780137802 = {"from":L[2242],
"go":function(anf_arg272937808) {
return $Hanf_arg935637809(anf_arg272937808,anf_arg272737795,self34014697,_plus55,torepr65);
}};
$e3779737798.stack[R.EXN_STACKHEIGHT++] = $ss3780137802;
}
if(R.isPyretException($e3779737798)) {
$e3779737798.pyretStack.push(L[2242]);
}
throw $e3779737798;
}
var $ret3780337804 = $Hanf_arg935637809($z3779937800,anf_arg272737795,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3780337804;
};
var $Hanf_arg935637809 = function(anf_arg272937808,anf_arg272737795,self34014697,_plus55,torepr65) {
var $z3781237813 = D;
var $f3781837819 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg272937808):R.ffi.throwNonFunApp(L[2242],_plus55,[(", "),anf_arg272937808]);
};
try {
if(--R.GAS > 0) {
$z3781237813 = $f3781837819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3781837819,
"from":L[2242]});
}
} catch($e3781037811) {
if(R.isCont($e3781037811)) {
var $ss3781437815 = {"from":L[2242],
"go":function(anf_arg273037820) {
return $Hanf_arg935537821(anf_arg273037820,anf_arg272737795,self34014697,_plus55,torepr65);
}};
$e3781037811.stack[R.EXN_STACKHEIGHT++] = $ss3781437815;
}
if(R.isPyretException($e3781037811)) {
$e3781037811.pyretStack.push(L[2242]);
}
throw $e3781037811;
}
var $ret3781637817 = $Hanf_arg935537821($z3781237813,anf_arg272737795,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3781637817;
};
var $Hanf_arg935537821 = function(anf_arg273037820,anf_arg272737795,self34014697,_plus55,torepr65) {
var $z3782437825 = D;
var $f3783037831 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg272737795,anf_arg273037820):R.ffi.throwNonFunApp(L[2242],_plus55,[anf_arg272737795,anf_arg273037820]);
};
try {
if(--R.GAS > 0) {
$z3782437825 = $f3783037831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3783037831,
"from":L[2242]});
}
} catch($e3782237823) {
if(R.isCont($e3782237823)) {
var $ss3782637827 = {"from":L[2242],
"go":function(anf_arg273137832) {
return $Hanf_arg935437833(anf_arg273137832,self34014697,_plus55,torepr65);
}};
$e3782237823.stack[R.EXN_STACKHEIGHT++] = $ss3782637827;
}
if(R.isPyretException($e3782237823)) {
$e3782237823.pyretStack.push(L[2242]);
}
throw $e3782237823;
}
var $ret3782837829 = $Hanf_arg935437833($z3782437825,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3782837829;
};
var $Hanf_arg935437833 = function(anf_arg273137832,self34014697,_plus55,torepr65) {
var anf_arg273237844 = G(self34014697,"body",L[2242]);
var $z3783637837 = D;
var $f3784237843 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg273237844):R.ffi.throwNonFunApp(L[2242],torepr65,[anf_arg273237844]);
};
try {
if(--R.GAS > 0) {
$z3783637837 = $f3784237843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3784237843,
"from":L[2242]});
}
} catch($e3783437835) {
if(R.isCont($e3783437835)) {
var $ss3783837839 = {"from":L[2242],
"go":function(anf_arg273337845) {
return $Hanf_arg935337846(anf_arg273337845,anf_arg273137832,self34014697,_plus55,torepr65);
}};
$e3783437835.stack[R.EXN_STACKHEIGHT++] = $ss3783837839;
}
if(R.isPyretException($e3783437835)) {
$e3783437835.pyretStack.push(L[2242]);
}
throw $e3783437835;
}
var $ret3784037841 = $Hanf_arg935337846($z3783637837,anf_arg273137832,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3784037841;
};
var $Hanf_arg935337846 = function(anf_arg273337845,anf_arg273137832,self34014697,_plus55,torepr65) {
var $z3784937850 = D;
var $f3785537856 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg273337845):R.ffi.throwNonFunApp(L[2242],_plus55,[(", "),anf_arg273337845]);
};
try {
if(--R.GAS > 0) {
$z3784937850 = $f3785537856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3785537856,
"from":L[2242]});
}
} catch($e3784737848) {
if(R.isCont($e3784737848)) {
var $ss3785137852 = {"from":L[2242],
"go":function(anf_arg273437857) {
return $Hanf_arg935237858(anf_arg273437857,anf_arg273137832,self34014697,_plus55,torepr65);
}};
$e3784737848.stack[R.EXN_STACKHEIGHT++] = $ss3785137852;
}
if(R.isPyretException($e3784737848)) {
$e3784737848.pyretStack.push(L[2242]);
}
throw $e3784737848;
}
var $ret3785337854 = $Hanf_arg935237858($z3784937850,anf_arg273137832,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3785337854;
};
var $Hanf_arg935237858 = function(anf_arg273437857,anf_arg273137832,self34014697,_plus55,torepr65) {
var $z3786137862 = D;
var $f3786737868 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg273137832,anf_arg273437857):R.ffi.throwNonFunApp(L[2242],_plus55,[anf_arg273137832,anf_arg273437857]);
};
try {
if(--R.GAS > 0) {
$z3786137862 = $f3786737868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3786737868,
"from":L[2242]});
}
} catch($e3785937860) {
if(R.isCont($e3785937860)) {
var $ss3786337864 = {"from":L[2242],
"go":function(anf_arg273537869) {
return $Hanf_arg935137870(anf_arg273537869,self34014697,_plus55,torepr65);
}};
$e3785937860.stack[R.EXN_STACKHEIGHT++] = $ss3786337864;
}
if(R.isPyretException($e3785937860)) {
$e3785937860.pyretStack.push(L[2242]);
}
throw $e3785937860;
}
var $ret3786537866 = $Hanf_arg935137870($z3786137862,self34014697,_plus55,torepr65);
++R.GAS;
return $ret3786537866;
};
var $Hanf_arg935137870 = function(anf_arg273537869,self34014697,_plus55,torepr65) {
var anf_arg273637881 = G(self34014697,"_check",L[2242]);
var $z3787337874 = D;
var $f3787937880 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg273637881):R.ffi.throwNonFunApp(L[2242],torepr65,[anf_arg273637881]);
};
try {
if(--R.GAS > 0) {
$z3787337874 = $f3787937880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3787937880,
"from":L[2242]});
}
} catch($e3787137872) {
if(R.isCont($e3787137872)) {
var $ss3787537876 = {"from":L[2242],
"go":function(anf_arg273737882) {
return $Hanf_arg935037883(anf_arg273737882,anf_arg273537869,_plus55);
}};
$e3787137872.stack[R.EXN_STACKHEIGHT++] = $ss3787537876;
}
if(R.isPyretException($e3787137872)) {
$e3787137872.pyretStack.push(L[2242]);
}
throw $e3787137872;
}
var $ret3787737878 = $Hanf_arg935037883($z3787337874,anf_arg273537869,_plus55);
++R.GAS;
return $ret3787737878;
};
var $Hanf_arg935037883 = function(anf_arg273737882,anf_arg273537869,_plus55) {
var $z3788637887 = D;
var $f3789237893 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg273737882):R.ffi.throwNonFunApp(L[2242],_plus55,[(", "),anf_arg273737882]);
};
try {
if(--R.GAS > 0) {
$z3788637887 = $f3789237893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3789237893,
"from":L[2242]});
}
} catch($e3788437885) {
if(R.isCont($e3788437885)) {
var $ss3788837889 = {"from":L[2242],
"go":function(anf_arg273837894) {
return $Hanf_arg934937895(anf_arg273837894,anf_arg273537869,_plus55);
}};
$e3788437885.stack[R.EXN_STACKHEIGHT++] = $ss3788837889;
}
if(R.isPyretException($e3788437885)) {
$e3788437885.pyretStack.push(L[2242]);
}
throw $e3788437885;
}
var $ret3789037891 = $Hanf_arg934937895($z3788637887,anf_arg273537869,_plus55);
++R.GAS;
return $ret3789037891;
};
var $Hanf_arg934937895 = function(anf_arg273837894,anf_arg273537869,_plus55) {
var $z3789837899 = D;
var $f3790437905 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg273537869,anf_arg273837894):R.ffi.throwNonFunApp(L[2242],_plus55,[anf_arg273537869,anf_arg273837894]);
};
try {
if(--R.GAS > 0) {
$z3789837899 = $f3790437905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3790437905,
"from":L[2242]});
}
} catch($e3789637897) {
if(R.isCont($e3789637897)) {
var $ss3790037901 = {"from":L[2242],
"go":function(anf_arg273937906) {
return $Hanf_arg934837907(anf_arg273937906,_plus55);
}};
$e3789637897.stack[R.EXN_STACKHEIGHT++] = $ss3790037901;
}
if(R.isPyretException($e3789637897)) {
$e3789637897.pyretStack.push(L[2242]);
}
throw $e3789637897;
}
var $ret3790237903 = $Hanf_arg934837907($z3789837899,_plus55);
++R.GAS;
return $ret3790237903;
};
var $Hanf_arg934837907 = function(anf_arg273937906,_plus55) {
var $z3791037911 = D;
var $f3791637917 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg273937906,(")")):R.ffi.throwNonFunApp(L[2242],_plus55,[anf_arg273937906,(")")]);
};
try {
if(--R.GAS > 0) {
$z3791037911 = $f3791637917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3791637917,
"from":L[2242]});
}
} catch($e3790837909) {
if(R.isCont($e3790837909)) {
var $ss3791237913 = {"from":L[2242],
"go":function(anf_arg274037918) {
return $Hanf_arg934737919(anf_arg274037918,_plus55);
}};
$e3790837909.stack[R.EXN_STACKHEIGHT++] = $ss3791237913;
}
if(R.isPyretException($e3790837909)) {
$e3790837909.pyretStack.push(L[2242]);
}
throw $e3790837909;
}
var $ret3791437915 = $Hanf_arg934737919($z3791037911,_plus55);
++R.GAS;
return $ret3791437915;
};
var $Hanf_arg934737919 = function(anf_arg274037918,_plus55) {
var $z3792237923 = D;
var $f3792837929 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg274037918):R.ffi.throwNonFunApp(L[2242],_plus55,[("("),anf_arg274037918]);
};
try {
if(--R.GAS > 0) {
$z3792237923 = $f3792837929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3792837929,
"from":L[2242]});
}
} catch($e3792037921) {
if(R.isCont($e3792037921)) {
var $ss3792437925 = {"from":L[2242],
"go":function(anf_arg274137930) {
return $Hanf_arg934637931(anf_arg274137930,_plus55);
}};
$e3792037921.stack[R.EXN_STACKHEIGHT++] = $ss3792437925;
}
if(R.isPyretException($e3792037921)) {
$e3792037921.pyretStack.push(L[2242]);
}
throw $e3792037921;
}
var $ret3792637927 = $Hanf_arg934637931($z3792237923,_plus55);
++R.GAS;
return $ret3792637927;
};
var $Hanf_arg934637931 = function(anf_arg274137930,_plus55) {
var $z3793437935 = D;
var $f3794037941 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-method"),anf_arg274137930):R.ffi.throwNonFunApp(L[2242],_plus55,[("s-method"),anf_arg274137930]);
};
try {
if(--R.GAS > 0) {
$z3793437935 = $f3794037941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3794037941,
"from":L[2242]});
}
} catch($e3793237933) {
if(R.isCont($e3793237933)) {
var $ss3793637937 = {"from":L[2242],
"go":function(ann_DASH_check_DASH_temp271737942) {
return $Hann_DASH_check_DASH_temp934537943(ann_DASH_check_DASH_temp271737942);
}};
$e3793237933.stack[R.EXN_STACKHEIGHT++] = $ss3793637937;
}
if(R.isPyretException($e3793237933)) {
$e3793237933.pyretStack.push(L[2242]);
}
throw $e3793237933;
}
var $ret3793837939 = $Hann_DASH_check_DASH_temp934537943($z3793437935);
++R.GAS;
return $ret3793837939;
};
var $Hann_DASH_check_DASH_temp934537943 = function(ann_DASH_check_DASH_temp271737942) {
return ann_DASH_check_DASH_temp271737942;
};
var $Hcont_tail_arg934314718 = function(cont_tail_arg271414716,if_helper270114717) {
if(--R.GAS > 0) {
$z3794437945 = R.isFunction(if_helper270114717)?if_helper270114717.app(cont_tail_arg271414716):R.ffi.throwNonFunApp(L[2242],if_helper270114717,[cont_tail_arg271414716]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper270114717)?if_helper270114717.app(cont_tail_arg271414716):R.ffi.throwNonFunApp(L[2242],if_helper270114717,[cont_tail_arg271414716]);
},
"from":L[2242]});
}
++R.GAS;
return $z3794437945;
};
var $Hcont_tail_arg934414733 = function(cont_tail_arg270614732,if_helper270114717) {
if(--R.GAS > 0) {
$z3794637947 = R.isFunction(if_helper270114717)?if_helper270114717.app(cont_tail_arg270614732):R.ffi.throwNonFunApp(L[2242],if_helper270114717,[cont_tail_arg270614732]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper270114717)?if_helper270114717.app(cont_tail_arg270614732):R.ffi.throwNonFunApp(L[2242],if_helper270114717,[cont_tail_arg270614732]);
},
"from":L[2242]});
}
++R.GAS;
return $z3794637947;
};
var $Hann_DASH_check_DASH_temp934214758 = function(ann_DASH_check_DASH_temp269214757) {
return ann_DASH_check_DASH_temp269214757;
};
var $Hanf_arg934114775 = function(anf_arg266214773,self33414774,_plus55,torepr65) {
var anf_arg266337958 = G(self33414774,"params",L[2243]);
var $z3795037951 = D;
var $f3795637957 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg266337958):R.ffi.throwNonFunApp(L[2243],torepr65,[anf_arg266337958]);
};
try {
if(--R.GAS > 0) {
$z3795037951 = $f3795637957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3795637957,
"from":L[2243]});
}
} catch($e3794837949) {
if(R.isCont($e3794837949)) {
var $ss3795237953 = {"from":L[2243],
"go":function(anf_arg266437959) {
return $Hanf_arg934037960(anf_arg266437959,anf_arg266214773,self33414774,_plus55,torepr65);
}};
$e3794837949.stack[R.EXN_STACKHEIGHT++] = $ss3795237953;
}
if(R.isPyretException($e3794837949)) {
$e3794837949.pyretStack.push(L[2243]);
}
throw $e3794837949;
}
var $ret3795437955 = $Hanf_arg934037960($z3795037951,anf_arg266214773,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3795437955;
};
var $Hanf_arg934037960 = function(anf_arg266437959,anf_arg266214773,self33414774,_plus55,torepr65) {
var $z3796337964 = D;
var $f3796937970 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg266437959):R.ffi.throwNonFunApp(L[2243],_plus55,[(", "),anf_arg266437959]);
};
try {
if(--R.GAS > 0) {
$z3796337964 = $f3796937970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3796937970,
"from":L[2243]});
}
} catch($e3796137962) {
if(R.isCont($e3796137962)) {
var $ss3796537966 = {"from":L[2243],
"go":function(anf_arg266537971) {
return $Hanf_arg933937972(anf_arg266537971,anf_arg266214773,self33414774,_plus55,torepr65);
}};
$e3796137962.stack[R.EXN_STACKHEIGHT++] = $ss3796537966;
}
if(R.isPyretException($e3796137962)) {
$e3796137962.pyretStack.push(L[2243]);
}
throw $e3796137962;
}
var $ret3796737968 = $Hanf_arg933937972($z3796337964,anf_arg266214773,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3796737968;
};
var $Hanf_arg933937972 = function(anf_arg266537971,anf_arg266214773,self33414774,_plus55,torepr65) {
var $z3797537976 = D;
var $f3798137982 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg266214773,anf_arg266537971):R.ffi.throwNonFunApp(L[2243],_plus55,[anf_arg266214773,anf_arg266537971]);
};
try {
if(--R.GAS > 0) {
$z3797537976 = $f3798137982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3798137982,
"from":L[2243]});
}
} catch($e3797337974) {
if(R.isCont($e3797337974)) {
var $ss3797737978 = {"from":L[2243],
"go":function(anf_arg266637983) {
return $Hanf_arg933837984(anf_arg266637983,self33414774,_plus55,torepr65);
}};
$e3797337974.stack[R.EXN_STACKHEIGHT++] = $ss3797737978;
}
if(R.isPyretException($e3797337974)) {
$e3797337974.pyretStack.push(L[2243]);
}
throw $e3797337974;
}
var $ret3797937980 = $Hanf_arg933837984($z3797537976,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3797937980;
};
var $Hanf_arg933837984 = function(anf_arg266637983,self33414774,_plus55,torepr65) {
var anf_arg266737995 = G(self33414774,"args",L[2243]);
var $z3798737988 = D;
var $f3799337994 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg266737995):R.ffi.throwNonFunApp(L[2243],torepr65,[anf_arg266737995]);
};
try {
if(--R.GAS > 0) {
$z3798737988 = $f3799337994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3799337994,
"from":L[2243]});
}
} catch($e3798537986) {
if(R.isCont($e3798537986)) {
var $ss3798937990 = {"from":L[2243],
"go":function(anf_arg266837996) {
return $Hanf_arg933737997(anf_arg266837996,anf_arg266637983,self33414774,_plus55,torepr65);
}};
$e3798537986.stack[R.EXN_STACKHEIGHT++] = $ss3798937990;
}
if(R.isPyretException($e3798537986)) {
$e3798537986.pyretStack.push(L[2243]);
}
throw $e3798537986;
}
var $ret3799137992 = $Hanf_arg933737997($z3798737988,anf_arg266637983,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3799137992;
};
var $Hanf_arg933737997 = function(anf_arg266837996,anf_arg266637983,self33414774,_plus55,torepr65) {
var $z3800038001 = D;
var $f3800638007 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg266837996):R.ffi.throwNonFunApp(L[2243],_plus55,[(", "),anf_arg266837996]);
};
try {
if(--R.GAS > 0) {
$z3800038001 = $f3800638007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3800638007,
"from":L[2243]});
}
} catch($e3799837999) {
if(R.isCont($e3799837999)) {
var $ss3800238003 = {"from":L[2243],
"go":function(anf_arg266938008) {
return $Hanf_arg933638009(anf_arg266938008,anf_arg266637983,self33414774,_plus55,torepr65);
}};
$e3799837999.stack[R.EXN_STACKHEIGHT++] = $ss3800238003;
}
if(R.isPyretException($e3799837999)) {
$e3799837999.pyretStack.push(L[2243]);
}
throw $e3799837999;
}
var $ret3800438005 = $Hanf_arg933638009($z3800038001,anf_arg266637983,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3800438005;
};
var $Hanf_arg933638009 = function(anf_arg266938008,anf_arg266637983,self33414774,_plus55,torepr65) {
var $z3801238013 = D;
var $f3801838019 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg266637983,anf_arg266938008):R.ffi.throwNonFunApp(L[2243],_plus55,[anf_arg266637983,anf_arg266938008]);
};
try {
if(--R.GAS > 0) {
$z3801238013 = $f3801838019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3801838019,
"from":L[2243]});
}
} catch($e3801038011) {
if(R.isCont($e3801038011)) {
var $ss3801438015 = {"from":L[2243],
"go":function(anf_arg267038020) {
return $Hanf_arg933538021(anf_arg267038020,self33414774,_plus55,torepr65);
}};
$e3801038011.stack[R.EXN_STACKHEIGHT++] = $ss3801438015;
}
if(R.isPyretException($e3801038011)) {
$e3801038011.pyretStack.push(L[2243]);
}
throw $e3801038011;
}
var $ret3801638017 = $Hanf_arg933538021($z3801238013,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3801638017;
};
var $Hanf_arg933538021 = function(anf_arg267038020,self33414774,_plus55,torepr65) {
var anf_arg267138032 = G(self33414774,"ann",L[2243]);
var $z3802438025 = D;
var $f3803038031 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg267138032):R.ffi.throwNonFunApp(L[2243],torepr65,[anf_arg267138032]);
};
try {
if(--R.GAS > 0) {
$z3802438025 = $f3803038031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3803038031,
"from":L[2243]});
}
} catch($e3802238023) {
if(R.isCont($e3802238023)) {
var $ss3802638027 = {"from":L[2243],
"go":function(anf_arg267238033) {
return $Hanf_arg933438034(anf_arg267238033,anf_arg267038020,self33414774,_plus55,torepr65);
}};
$e3802238023.stack[R.EXN_STACKHEIGHT++] = $ss3802638027;
}
if(R.isPyretException($e3802238023)) {
$e3802238023.pyretStack.push(L[2243]);
}
throw $e3802238023;
}
var $ret3802838029 = $Hanf_arg933438034($z3802438025,anf_arg267038020,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3802838029;
};
var $Hanf_arg933438034 = function(anf_arg267238033,anf_arg267038020,self33414774,_plus55,torepr65) {
var $z3803738038 = D;
var $f3804338044 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg267238033):R.ffi.throwNonFunApp(L[2243],_plus55,[(", "),anf_arg267238033]);
};
try {
if(--R.GAS > 0) {
$z3803738038 = $f3804338044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3804338044,
"from":L[2243]});
}
} catch($e3803538036) {
if(R.isCont($e3803538036)) {
var $ss3803938040 = {"from":L[2243],
"go":function(anf_arg267338045) {
return $Hanf_arg933338046(anf_arg267338045,anf_arg267038020,self33414774,_plus55,torepr65);
}};
$e3803538036.stack[R.EXN_STACKHEIGHT++] = $ss3803938040;
}
if(R.isPyretException($e3803538036)) {
$e3803538036.pyretStack.push(L[2243]);
}
throw $e3803538036;
}
var $ret3804138042 = $Hanf_arg933338046($z3803738038,anf_arg267038020,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3804138042;
};
var $Hanf_arg933338046 = function(anf_arg267338045,anf_arg267038020,self33414774,_plus55,torepr65) {
var $z3804938050 = D;
var $f3805538056 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg267038020,anf_arg267338045):R.ffi.throwNonFunApp(L[2243],_plus55,[anf_arg267038020,anf_arg267338045]);
};
try {
if(--R.GAS > 0) {
$z3804938050 = $f3805538056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3805538056,
"from":L[2243]});
}
} catch($e3804738048) {
if(R.isCont($e3804738048)) {
var $ss3805138052 = {"from":L[2243],
"go":function(anf_arg267438057) {
return $Hanf_arg933238058(anf_arg267438057,self33414774,_plus55,torepr65);
}};
$e3804738048.stack[R.EXN_STACKHEIGHT++] = $ss3805138052;
}
if(R.isPyretException($e3804738048)) {
$e3804738048.pyretStack.push(L[2243]);
}
throw $e3804738048;
}
var $ret3805338054 = $Hanf_arg933238058($z3804938050,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3805338054;
};
var $Hanf_arg933238058 = function(anf_arg267438057,self33414774,_plus55,torepr65) {
var anf_arg267538069 = G(self33414774,"doc",L[2243]);
var $z3806138062 = D;
var $f3806738068 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg267538069):R.ffi.throwNonFunApp(L[2243],torepr65,[anf_arg267538069]);
};
try {
if(--R.GAS > 0) {
$z3806138062 = $f3806738068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3806738068,
"from":L[2243]});
}
} catch($e3805938060) {
if(R.isCont($e3805938060)) {
var $ss3806338064 = {"from":L[2243],
"go":function(anf_arg267638070) {
return $Hanf_arg933138071(anf_arg267638070,anf_arg267438057,self33414774,_plus55,torepr65);
}};
$e3805938060.stack[R.EXN_STACKHEIGHT++] = $ss3806338064;
}
if(R.isPyretException($e3805938060)) {
$e3805938060.pyretStack.push(L[2243]);
}
throw $e3805938060;
}
var $ret3806538066 = $Hanf_arg933138071($z3806138062,anf_arg267438057,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3806538066;
};
var $Hanf_arg933138071 = function(anf_arg267638070,anf_arg267438057,self33414774,_plus55,torepr65) {
var $z3807438075 = D;
var $f3808038081 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg267638070):R.ffi.throwNonFunApp(L[2243],_plus55,[(", "),anf_arg267638070]);
};
try {
if(--R.GAS > 0) {
$z3807438075 = $f3808038081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3808038081,
"from":L[2243]});
}
} catch($e3807238073) {
if(R.isCont($e3807238073)) {
var $ss3807638077 = {"from":L[2243],
"go":function(anf_arg267738082) {
return $Hanf_arg933038083(anf_arg267738082,anf_arg267438057,self33414774,_plus55,torepr65);
}};
$e3807238073.stack[R.EXN_STACKHEIGHT++] = $ss3807638077;
}
if(R.isPyretException($e3807238073)) {
$e3807238073.pyretStack.push(L[2243]);
}
throw $e3807238073;
}
var $ret3807838079 = $Hanf_arg933038083($z3807438075,anf_arg267438057,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3807838079;
};
var $Hanf_arg933038083 = function(anf_arg267738082,anf_arg267438057,self33414774,_plus55,torepr65) {
var $z3808638087 = D;
var $f3809238093 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg267438057,anf_arg267738082):R.ffi.throwNonFunApp(L[2243],_plus55,[anf_arg267438057,anf_arg267738082]);
};
try {
if(--R.GAS > 0) {
$z3808638087 = $f3809238093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3809238093,
"from":L[2243]});
}
} catch($e3808438085) {
if(R.isCont($e3808438085)) {
var $ss3808838089 = {"from":L[2243],
"go":function(anf_arg267838094) {
return $Hanf_arg932938095(anf_arg267838094,self33414774,_plus55,torepr65);
}};
$e3808438085.stack[R.EXN_STACKHEIGHT++] = $ss3808838089;
}
if(R.isPyretException($e3808438085)) {
$e3808438085.pyretStack.push(L[2243]);
}
throw $e3808438085;
}
var $ret3809038091 = $Hanf_arg932938095($z3808638087,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3809038091;
};
var $Hanf_arg932938095 = function(anf_arg267838094,self33414774,_plus55,torepr65) {
var anf_arg267938106 = G(self33414774,"body",L[2243]);
var $z3809838099 = D;
var $f3810438105 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg267938106):R.ffi.throwNonFunApp(L[2243],torepr65,[anf_arg267938106]);
};
try {
if(--R.GAS > 0) {
$z3809838099 = $f3810438105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3810438105,
"from":L[2243]});
}
} catch($e3809638097) {
if(R.isCont($e3809638097)) {
var $ss3810038101 = {"from":L[2243],
"go":function(anf_arg268038107) {
return $Hanf_arg932838108(anf_arg268038107,anf_arg267838094,self33414774,_plus55,torepr65);
}};
$e3809638097.stack[R.EXN_STACKHEIGHT++] = $ss3810038101;
}
if(R.isPyretException($e3809638097)) {
$e3809638097.pyretStack.push(L[2243]);
}
throw $e3809638097;
}
var $ret3810238103 = $Hanf_arg932838108($z3809838099,anf_arg267838094,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3810238103;
};
var $Hanf_arg932838108 = function(anf_arg268038107,anf_arg267838094,self33414774,_plus55,torepr65) {
var $z3811138112 = D;
var $f3811738118 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg268038107):R.ffi.throwNonFunApp(L[2243],_plus55,[(", "),anf_arg268038107]);
};
try {
if(--R.GAS > 0) {
$z3811138112 = $f3811738118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3811738118,
"from":L[2243]});
}
} catch($e3810938110) {
if(R.isCont($e3810938110)) {
var $ss3811338114 = {"from":L[2243],
"go":function(anf_arg268138119) {
return $Hanf_arg932738120(anf_arg268138119,anf_arg267838094,self33414774,_plus55,torepr65);
}};
$e3810938110.stack[R.EXN_STACKHEIGHT++] = $ss3811338114;
}
if(R.isPyretException($e3810938110)) {
$e3810938110.pyretStack.push(L[2243]);
}
throw $e3810938110;
}
var $ret3811538116 = $Hanf_arg932738120($z3811138112,anf_arg267838094,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3811538116;
};
var $Hanf_arg932738120 = function(anf_arg268138119,anf_arg267838094,self33414774,_plus55,torepr65) {
var $z3812338124 = D;
var $f3812938130 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg267838094,anf_arg268138119):R.ffi.throwNonFunApp(L[2243],_plus55,[anf_arg267838094,anf_arg268138119]);
};
try {
if(--R.GAS > 0) {
$z3812338124 = $f3812938130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3812938130,
"from":L[2243]});
}
} catch($e3812138122) {
if(R.isCont($e3812138122)) {
var $ss3812538126 = {"from":L[2243],
"go":function(anf_arg268238131) {
return $Hanf_arg932638132(anf_arg268238131,self33414774,_plus55,torepr65);
}};
$e3812138122.stack[R.EXN_STACKHEIGHT++] = $ss3812538126;
}
if(R.isPyretException($e3812138122)) {
$e3812138122.pyretStack.push(L[2243]);
}
throw $e3812138122;
}
var $ret3812738128 = $Hanf_arg932638132($z3812338124,self33414774,_plus55,torepr65);
++R.GAS;
return $ret3812738128;
};
var $Hanf_arg932638132 = function(anf_arg268238131,self33414774,_plus55,torepr65) {
var anf_arg268338143 = G(self33414774,"_check",L[2243]);
var $z3813538136 = D;
var $f3814138142 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg268338143):R.ffi.throwNonFunApp(L[2243],torepr65,[anf_arg268338143]);
};
try {
if(--R.GAS > 0) {
$z3813538136 = $f3814138142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3814138142,
"from":L[2243]});
}
} catch($e3813338134) {
if(R.isCont($e3813338134)) {
var $ss3813738138 = {"from":L[2243],
"go":function(anf_arg268438144) {
return $Hanf_arg932538145(anf_arg268438144,anf_arg268238131,_plus55);
}};
$e3813338134.stack[R.EXN_STACKHEIGHT++] = $ss3813738138;
}
if(R.isPyretException($e3813338134)) {
$e3813338134.pyretStack.push(L[2243]);
}
throw $e3813338134;
}
var $ret3813938140 = $Hanf_arg932538145($z3813538136,anf_arg268238131,_plus55);
++R.GAS;
return $ret3813938140;
};
var $Hanf_arg932538145 = function(anf_arg268438144,anf_arg268238131,_plus55) {
var $z3814838149 = D;
var $f3815438155 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg268438144):R.ffi.throwNonFunApp(L[2243],_plus55,[(", "),anf_arg268438144]);
};
try {
if(--R.GAS > 0) {
$z3814838149 = $f3815438155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3815438155,
"from":L[2243]});
}
} catch($e3814638147) {
if(R.isCont($e3814638147)) {
var $ss3815038151 = {"from":L[2243],
"go":function(anf_arg268538156) {
return $Hanf_arg932438157(anf_arg268538156,anf_arg268238131,_plus55);
}};
$e3814638147.stack[R.EXN_STACKHEIGHT++] = $ss3815038151;
}
if(R.isPyretException($e3814638147)) {
$e3814638147.pyretStack.push(L[2243]);
}
throw $e3814638147;
}
var $ret3815238153 = $Hanf_arg932438157($z3814838149,anf_arg268238131,_plus55);
++R.GAS;
return $ret3815238153;
};
var $Hanf_arg932438157 = function(anf_arg268538156,anf_arg268238131,_plus55) {
var $z3816038161 = D;
var $f3816638167 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg268238131,anf_arg268538156):R.ffi.throwNonFunApp(L[2243],_plus55,[anf_arg268238131,anf_arg268538156]);
};
try {
if(--R.GAS > 0) {
$z3816038161 = $f3816638167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3816638167,
"from":L[2243]});
}
} catch($e3815838159) {
if(R.isCont($e3815838159)) {
var $ss3816238163 = {"from":L[2243],
"go":function(anf_arg268638168) {
return $Hanf_arg932338169(anf_arg268638168,_plus55);
}};
$e3815838159.stack[R.EXN_STACKHEIGHT++] = $ss3816238163;
}
if(R.isPyretException($e3815838159)) {
$e3815838159.pyretStack.push(L[2243]);
}
throw $e3815838159;
}
var $ret3816438165 = $Hanf_arg932338169($z3816038161,_plus55);
++R.GAS;
return $ret3816438165;
};
var $Hanf_arg932338169 = function(anf_arg268638168,_plus55) {
var $z3817238173 = D;
var $f3817838179 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg268638168,(")")):R.ffi.throwNonFunApp(L[2243],_plus55,[anf_arg268638168,(")")]);
};
try {
if(--R.GAS > 0) {
$z3817238173 = $f3817838179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3817838179,
"from":L[2243]});
}
} catch($e3817038171) {
if(R.isCont($e3817038171)) {
var $ss3817438175 = {"from":L[2243],
"go":function(anf_arg268738180) {
return $Hanf_arg932238181(anf_arg268738180,_plus55);
}};
$e3817038171.stack[R.EXN_STACKHEIGHT++] = $ss3817438175;
}
if(R.isPyretException($e3817038171)) {
$e3817038171.pyretStack.push(L[2243]);
}
throw $e3817038171;
}
var $ret3817638177 = $Hanf_arg932238181($z3817238173,_plus55);
++R.GAS;
return $ret3817638177;
};
var $Hanf_arg932238181 = function(anf_arg268738180,_plus55) {
var $z3818438185 = D;
var $f3819038191 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg268738180):R.ffi.throwNonFunApp(L[2243],_plus55,[("("),anf_arg268738180]);
};
try {
if(--R.GAS > 0) {
$z3818438185 = $f3819038191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3819038191,
"from":L[2243]});
}
} catch($e3818238183) {
if(R.isCont($e3818238183)) {
var $ss3818638187 = {"from":L[2243],
"go":function(anf_arg268838192) {
return $Hanf_arg932138193(anf_arg268838192,_plus55);
}};
$e3818238183.stack[R.EXN_STACKHEIGHT++] = $ss3818638187;
}
if(R.isPyretException($e3818238183)) {
$e3818238183.pyretStack.push(L[2243]);
}
throw $e3818238183;
}
var $ret3818838189 = $Hanf_arg932138193($z3818438185,_plus55);
++R.GAS;
return $ret3818838189;
};
var $Hanf_arg932138193 = function(anf_arg268838192,_plus55) {
var $z3819638197 = D;
var $f3820238203 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-lam"),anf_arg268838192):R.ffi.throwNonFunApp(L[2243],_plus55,[("s-lam"),anf_arg268838192]);
};
try {
if(--R.GAS > 0) {
$z3819638197 = $f3820238203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3820238203,
"from":L[2243]});
}
} catch($e3819438195) {
if(R.isCont($e3819438195)) {
var $ss3819838199 = {"from":L[2243],
"go":function(ann_DASH_check_DASH_temp266038204) {
return $Hann_DASH_check_DASH_temp932038205(ann_DASH_check_DASH_temp266038204);
}};
$e3819438195.stack[R.EXN_STACKHEIGHT++] = $ss3819838199;
}
if(R.isPyretException($e3819438195)) {
$e3819438195.pyretStack.push(L[2243]);
}
throw $e3819438195;
}
var $ret3820038201 = $Hann_DASH_check_DASH_temp932038205($z3819638197);
++R.GAS;
return $ret3820038201;
};
var $Hann_DASH_check_DASH_temp932038205 = function(ann_DASH_check_DASH_temp266038204) {
return ann_DASH_check_DASH_temp266038204;
};
var $Hcont_tail_arg931814796 = function(cont_tail_arg265714794,if_helper264314795) {
if(--R.GAS > 0) {
$z3820638207 = R.isFunction(if_helper264314795)?if_helper264314795.app(cont_tail_arg265714794):R.ffi.throwNonFunApp(L[2243],if_helper264314795,[cont_tail_arg265714794]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper264314795)?if_helper264314795.app(cont_tail_arg265714794):R.ffi.throwNonFunApp(L[2243],if_helper264314795,[cont_tail_arg265714794]);
},
"from":L[2243]});
}
++R.GAS;
return $z3820638207;
};
var $Hcont_tail_arg931914811 = function(cont_tail_arg264814810,if_helper264314795) {
if(--R.GAS > 0) {
$z3820838209 = R.isFunction(if_helper264314795)?if_helper264314795.app(cont_tail_arg264814810):R.ffi.throwNonFunApp(L[2243],if_helper264314795,[cont_tail_arg264814810]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper264314795)?if_helper264314795.app(cont_tail_arg264814810):R.ffi.throwNonFunApp(L[2243],if_helper264314795,[cont_tail_arg264814810]);
},
"from":L[2243]});
}
++R.GAS;
return $z3820838209;
};
var $Hanf_arg931714832 = function(anf_arg264014830,anf_fun263714831) {
var $z3821238213 = D;
var $f3821838219 = function(_) {
return R.isFunction(anf_fun263714831)?anf_fun263714831.app(anf_arg264014830):R.ffi.throwNonFunApp(L[2774],anf_fun263714831,[anf_arg264014830]);
};
try {
if(--R.GAS > 0) {
$z3821238213 = $f3821838219();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3821838219,
"from":L[2774]});
}
} catch($e3821038211) {
if(R.isCont($e3821038211)) {
var $ss3821438215 = {"from":L[2774],
"go":function(ann_DASH_check_DASH_temp263638220) {
return $Hann_DASH_check_DASH_temp931638221(ann_DASH_check_DASH_temp263638220);
}};
$e3821038211.stack[R.EXN_STACKHEIGHT++] = $ss3821438215;
}
if(R.isPyretException($e3821038211)) {
$e3821038211.pyretStack.push(L[2774]);
}
throw $e3821038211;
}
var $ret3821638217 = $Hann_DASH_check_DASH_temp931638221($z3821238213);
++R.GAS;
return $ret3821638217;
};
var $Hann_DASH_check_DASH_temp931638221 = function(ann_DASH_check_DASH_temp263638220) {
return ann_DASH_check_DASH_temp263638220;
};
var $Hanf_arg931514850 = function(anf_arg262614848,self32814849,_plus55,torepr65) {
var anf_arg262738232 = G(self32814849,"expr",L[2244]);
var $z3822438225 = D;
var $f3823038231 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg262738232):R.ffi.throwNonFunApp(L[2244],torepr65,[anf_arg262738232]);
};
try {
if(--R.GAS > 0) {
$z3822438225 = $f3823038231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3823038231,
"from":L[2244]});
}
} catch($e3822238223) {
if(R.isCont($e3822238223)) {
var $ss3822638227 = {"from":L[2244],
"go":function(anf_arg262838233) {
return $Hanf_arg931438234(anf_arg262838233,anf_arg262614848,_plus55);
}};
$e3822238223.stack[R.EXN_STACKHEIGHT++] = $ss3822638227;
}
if(R.isPyretException($e3822238223)) {
$e3822238223.pyretStack.push(L[2244]);
}
throw $e3822238223;
}
var $ret3822838229 = $Hanf_arg931438234($z3822438225,anf_arg262614848,_plus55);
++R.GAS;
return $ret3822838229;
};
var $Hanf_arg931438234 = function(anf_arg262838233,anf_arg262614848,_plus55) {
var $z3823738238 = D;
var $f3824338244 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg262838233):R.ffi.throwNonFunApp(L[2244],_plus55,[(", "),anf_arg262838233]);
};
try {
if(--R.GAS > 0) {
$z3823738238 = $f3824338244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3824338244,
"from":L[2244]});
}
} catch($e3823538236) {
if(R.isCont($e3823538236)) {
var $ss3823938240 = {"from":L[2244],
"go":function(anf_arg262938245) {
return $Hanf_arg931338246(anf_arg262938245,anf_arg262614848,_plus55);
}};
$e3823538236.stack[R.EXN_STACKHEIGHT++] = $ss3823938240;
}
if(R.isPyretException($e3823538236)) {
$e3823538236.pyretStack.push(L[2244]);
}
throw $e3823538236;
}
var $ret3824138242 = $Hanf_arg931338246($z3823738238,anf_arg262614848,_plus55);
++R.GAS;
return $ret3824138242;
};
var $Hanf_arg931338246 = function(anf_arg262938245,anf_arg262614848,_plus55) {
var $z3824938250 = D;
var $f3825538256 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg262614848,anf_arg262938245):R.ffi.throwNonFunApp(L[2244],_plus55,[anf_arg262614848,anf_arg262938245]);
};
try {
if(--R.GAS > 0) {
$z3824938250 = $f3825538256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3825538256,
"from":L[2244]});
}
} catch($e3824738248) {
if(R.isCont($e3824738248)) {
var $ss3825138252 = {"from":L[2244],
"go":function(anf_arg263038257) {
return $Hanf_arg931238258(anf_arg263038257,_plus55);
}};
$e3824738248.stack[R.EXN_STACKHEIGHT++] = $ss3825138252;
}
if(R.isPyretException($e3824738248)) {
$e3824738248.pyretStack.push(L[2244]);
}
throw $e3824738248;
}
var $ret3825338254 = $Hanf_arg931238258($z3824938250,_plus55);
++R.GAS;
return $ret3825338254;
};
var $Hanf_arg931238258 = function(anf_arg263038257,_plus55) {
var $z3826138262 = D;
var $f3826738268 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg263038257,(")")):R.ffi.throwNonFunApp(L[2244],_plus55,[anf_arg263038257,(")")]);
};
try {
if(--R.GAS > 0) {
$z3826138262 = $f3826738268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3826738268,
"from":L[2244]});
}
} catch($e3825938260) {
if(R.isCont($e3825938260)) {
var $ss3826338264 = {"from":L[2244],
"go":function(anf_arg263138269) {
return $Hanf_arg931138270(anf_arg263138269,_plus55);
}};
$e3825938260.stack[R.EXN_STACKHEIGHT++] = $ss3826338264;
}
if(R.isPyretException($e3825938260)) {
$e3825938260.pyretStack.push(L[2244]);
}
throw $e3825938260;
}
var $ret3826538266 = $Hanf_arg931138270($z3826138262,_plus55);
++R.GAS;
return $ret3826538266;
};
var $Hanf_arg931138270 = function(anf_arg263138269,_plus55) {
var $z3827338274 = D;
var $f3827938280 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg263138269):R.ffi.throwNonFunApp(L[2244],_plus55,[("("),anf_arg263138269]);
};
try {
if(--R.GAS > 0) {
$z3827338274 = $f3827938280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3827938280,
"from":L[2244]});
}
} catch($e3827138272) {
if(R.isCont($e3827138272)) {
var $ss3827538276 = {"from":L[2244],
"go":function(anf_arg263238281) {
return $Hanf_arg931038282(anf_arg263238281,_plus55);
}};
$e3827138272.stack[R.EXN_STACKHEIGHT++] = $ss3827538276;
}
if(R.isPyretException($e3827138272)) {
$e3827138272.pyretStack.push(L[2244]);
}
throw $e3827138272;
}
var $ret3827738278 = $Hanf_arg931038282($z3827338274,_plus55);
++R.GAS;
return $ret3827738278;
};
var $Hanf_arg931038282 = function(anf_arg263238281,_plus55) {
var $z3828538286 = D;
var $f3829138292 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-paren"),anf_arg263238281):R.ffi.throwNonFunApp(L[2244],_plus55,[("s-paren"),anf_arg263238281]);
};
try {
if(--R.GAS > 0) {
$z3828538286 = $f3829138292();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3829138292,
"from":L[2244]});
}
} catch($e3828338284) {
if(R.isCont($e3828338284)) {
var $ss3828738288 = {"from":L[2244],
"go":function(ann_DASH_check_DASH_temp262438293) {
return $Hann_DASH_check_DASH_temp930938294(ann_DASH_check_DASH_temp262438293);
}};
$e3828338284.stack[R.EXN_STACKHEIGHT++] = $ss3828738288;
}
if(R.isPyretException($e3828338284)) {
$e3828338284.pyretStack.push(L[2244]);
}
throw $e3828338284;
}
var $ret3828938290 = $Hann_DASH_check_DASH_temp930938294($z3828538286);
++R.GAS;
return $ret3828938290;
};
var $Hann_DASH_check_DASH_temp930938294 = function(ann_DASH_check_DASH_temp262438293) {
return ann_DASH_check_DASH_temp262438293;
};
var $Hcont_tail_arg930714866 = function(cont_tail_arg262114864,if_helper261214865) {
if(--R.GAS > 0) {
$z3829538296 = R.isFunction(if_helper261214865)?if_helper261214865.app(cont_tail_arg262114864):R.ffi.throwNonFunApp(L[2244],if_helper261214865,[cont_tail_arg262114864]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper261214865)?if_helper261214865.app(cont_tail_arg262114864):R.ffi.throwNonFunApp(L[2244],if_helper261214865,[cont_tail_arg262114864]);
},
"from":L[2244]});
}
++R.GAS;
return $z3829538296;
};
var $Hcont_tail_arg930814881 = function(cont_tail_arg261714880,if_helper261214865) {
if(--R.GAS > 0) {
$z3829738298 = R.isFunction(if_helper261214865)?if_helper261214865.app(cont_tail_arg261714880):R.ffi.throwNonFunApp(L[2244],if_helper261214865,[cont_tail_arg261714880]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper261214865)?if_helper261214865.app(cont_tail_arg261714880):R.ffi.throwNonFunApp(L[2244],if_helper261214865,[cont_tail_arg261714880]);
},
"from":L[2244]});
}
++R.GAS;
return $z3829738298;
};
var $Hanf_arg930614905 = function(anf_arg260114900,INDENT118169,anf_arg259914901,anf_fun259714902,anf_fun259814903,self81614904,string_DASH_substring64) {
var $z3830138302 = D;
var $f3830738308 = function(_) {
return R.isFunction(string_DASH_substring64)?string_DASH_substring64.app(anf_arg259914901,(2),anf_arg260114900):R.ffi.throwNonFunApp(L[4444],string_DASH_substring64,[anf_arg259914901,(2),anf_arg260114900]);
};
try {
if(--R.GAS > 0) {
$z3830138302 = $f3830738308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3830738308,
"from":L[4444]});
}
} catch($e3829938300) {
if(R.isCont($e3829938300)) {
var $ss3830338304 = {"from":L[4444],
"go":function(anf_arg260238309) {
return $Hanf_arg930538310(anf_arg260238309,INDENT118169,anf_fun259714902,anf_fun259814903,self81614904);
}};
$e3829938300.stack[R.EXN_STACKHEIGHT++] = $ss3830338304;
}
if(R.isPyretException($e3829938300)) {
$e3829938300.pyretStack.push(L[4444]);
}
throw $e3829938300;
}
var $ret3830538306 = $Hanf_arg930538310($z3830138302,INDENT118169,anf_fun259714902,anf_fun259814903,self81614904);
++R.GAS;
return $ret3830538306;
};
var $Hanf_arg930538310 = function(anf_arg260238309,INDENT118169,anf_fun259714902,anf_fun259814903,self81614904) {
var $z3831338314 = D;
var $f3831938320 = function(_) {
return R.isFunction(anf_fun259814903)?anf_fun259814903.app(anf_arg260238309):R.ffi.throwNonFunApp(L[4445],anf_fun259814903,[anf_arg260238309]);
};
try {
if(--R.GAS > 0) {
$z3831338314 = $f3831938320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3831938320,
"from":L[4445]});
}
} catch($e3831138312) {
if(R.isCont($e3831138312)) {
var $ss3831538316 = {"from":L[4445],
"go":function(anf_arg260338321) {
return $Hanf_arg930438322(anf_arg260338321,INDENT118169,anf_fun259714902,self81614904);
}};
$e3831138312.stack[R.EXN_STACKHEIGHT++] = $ss3831538316;
}
if(R.isPyretException($e3831138312)) {
$e3831138312.pyretStack.push(L[4445]);
}
throw $e3831138312;
}
var $ret3831738318 = $Hanf_arg930438322($z3831338314,INDENT118169,anf_fun259714902,self81614904);
++R.GAS;
return $ret3831738318;
};
var $Hanf_arg930438322 = function(anf_arg260338321,INDENT118169,anf_fun259714902,self81614904) {
var anf_bracket260438336 = G(self81614904,"left",L[4448]);
var anf_fun260538333 = G(anf_bracket260438336,"tosource",L[4447]);
var $z3832538326 = D;
var $f3833138332 = function(_) {
return R.isFunction(anf_fun260538333)?anf_fun260538333.app():R.ffi.throwNonFunApp(L[4446],anf_fun260538333,[]);
};
try {
if(--R.GAS > 0) {
$z3832538326 = $f3833138332();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3833138332,
"from":L[4446]});
}
} catch($e3832338324) {
if(R.isCont($e3832338324)) {
var $ss3832738328 = {"from":L[4446],
"go":function(anf_arg260638334) {
return $Hanf_arg930338335(anf_arg260638334,INDENT118169,anf_arg260338321,anf_fun259714902,self81614904);
}};
$e3832338324.stack[R.EXN_STACKHEIGHT++] = $ss3832738328;
}
if(R.isPyretException($e3832338324)) {
$e3832338324.pyretStack.push(L[4446]);
}
throw $e3832338324;
}
var $ret3832938330 = $Hanf_arg930338335($z3832538326,INDENT118169,anf_arg260338321,anf_fun259714902,self81614904);
++R.GAS;
return $ret3832938330;
};
var $Hanf_arg930338335 = function(anf_arg260638334,INDENT118169,anf_arg260338321,anf_fun259714902,self81614904) {
var anf_bracket260738350 = G(self81614904,"right",L[4451]);
var anf_fun260838347 = G(anf_bracket260738350,"tosource",L[4450]);
var $z3833938340 = D;
var $f3834538346 = function(_) {
return R.isFunction(anf_fun260838347)?anf_fun260838347.app():R.ffi.throwNonFunApp(L[4449],anf_fun260838347,[]);
};
try {
if(--R.GAS > 0) {
$z3833938340 = $f3834538346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3834538346,
"from":L[4449]});
}
} catch($e3833738338) {
if(R.isCont($e3833738338)) {
var $ss3834138342 = {"from":L[4449],
"go":function(anf_arg260938348) {
return $Hanf_arg930238349(anf_arg260938348,INDENT118169,anf_arg260338321,anf_arg260638334,anf_fun259714902);
}};
$e3833738338.stack[R.EXN_STACKHEIGHT++] = $ss3834138342;
}
if(R.isPyretException($e3833738338)) {
$e3833738338.pyretStack.push(L[4449]);
}
throw $e3833738338;
}
var $ret3834338344 = $Hanf_arg930238349($z3833938340,INDENT118169,anf_arg260338321,anf_arg260638334,anf_fun259714902);
++R.GAS;
return $ret3834338344;
};
var $Hanf_arg930238349 = function(anf_arg260938348,INDENT118169,anf_arg260338321,anf_arg260638334,anf_fun259714902) {
var $z3835338354 = D;
var $f3835938360 = function(_) {
return R.isFunction(anf_fun259714902)?anf_fun259714902.app(INDENT118169,(1),anf_arg260338321,anf_arg260638334,anf_arg260938348):R.ffi.throwNonFunApp(L[2783],anf_fun259714902,[INDENT118169,(1),anf_arg260338321,anf_arg260638334,anf_arg260938348]);
};
try {
if(--R.GAS > 0) {
$z3835338354 = $f3835938360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3835938360,
"from":L[2783]});
}
} catch($e3835138352) {
if(R.isCont($e3835138352)) {
var $ss3835538356 = {"from":L[2783],
"go":function(ann_DASH_check_DASH_temp259638361) {
return $Hann_DASH_check_DASH_temp930138362(ann_DASH_check_DASH_temp259638361);
}};
$e3835138352.stack[R.EXN_STACKHEIGHT++] = $ss3835538356;
}
if(R.isPyretException($e3835138352)) {
$e3835138352.pyretStack.push(L[2783]);
}
throw $e3835138352;
}
var $ret3835738358 = $Hann_DASH_check_DASH_temp930138362($z3835338354);
++R.GAS;
return $ret3835738358;
};
var $Hann_DASH_check_DASH_temp930138362 = function(ann_DASH_check_DASH_temp259638361) {
return ann_DASH_check_DASH_temp259638361;
};
var $Hanf_arg930014919 = function(anf_arg258014917,self32214918,_plus55,torepr65) {
var anf_arg258138373 = G(self32214918,"op",L[2245]);
var $z3836538366 = D;
var $f3837138372 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg258138373):R.ffi.throwNonFunApp(L[2245],torepr65,[anf_arg258138373]);
};
try {
if(--R.GAS > 0) {
$z3836538366 = $f3837138372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3837138372,
"from":L[2245]});
}
} catch($e3836338364) {
if(R.isCont($e3836338364)) {
var $ss3836738368 = {"from":L[2245],
"go":function(anf_arg258238374) {
return $Hanf_arg929938375(anf_arg258238374,anf_arg258014917,self32214918,_plus55,torepr65);
}};
$e3836338364.stack[R.EXN_STACKHEIGHT++] = $ss3836738368;
}
if(R.isPyretException($e3836338364)) {
$e3836338364.pyretStack.push(L[2245]);
}
throw $e3836338364;
}
var $ret3836938370 = $Hanf_arg929938375($z3836538366,anf_arg258014917,self32214918,_plus55,torepr65);
++R.GAS;
return $ret3836938370;
};
var $Hanf_arg929938375 = function(anf_arg258238374,anf_arg258014917,self32214918,_plus55,torepr65) {
var $z3837838379 = D;
var $f3838438385 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg258238374):R.ffi.throwNonFunApp(L[2245],_plus55,[(", "),anf_arg258238374]);
};
try {
if(--R.GAS > 0) {
$z3837838379 = $f3838438385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3838438385,
"from":L[2245]});
}
} catch($e3837638377) {
if(R.isCont($e3837638377)) {
var $ss3838038381 = {"from":L[2245],
"go":function(anf_arg258338386) {
return $Hanf_arg929838387(anf_arg258338386,anf_arg258014917,self32214918,_plus55,torepr65);
}};
$e3837638377.stack[R.EXN_STACKHEIGHT++] = $ss3838038381;
}
if(R.isPyretException($e3837638377)) {
$e3837638377.pyretStack.push(L[2245]);
}
throw $e3837638377;
}
var $ret3838238383 = $Hanf_arg929838387($z3837838379,anf_arg258014917,self32214918,_plus55,torepr65);
++R.GAS;
return $ret3838238383;
};
var $Hanf_arg929838387 = function(anf_arg258338386,anf_arg258014917,self32214918,_plus55,torepr65) {
var $z3839038391 = D;
var $f3839638397 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg258014917,anf_arg258338386):R.ffi.throwNonFunApp(L[2245],_plus55,[anf_arg258014917,anf_arg258338386]);
};
try {
if(--R.GAS > 0) {
$z3839038391 = $f3839638397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3839638397,
"from":L[2245]});
}
} catch($e3838838389) {
if(R.isCont($e3838838389)) {
var $ss3839238393 = {"from":L[2245],
"go":function(anf_arg258438398) {
return $Hanf_arg929738399(anf_arg258438398,self32214918,_plus55,torepr65);
}};
$e3838838389.stack[R.EXN_STACKHEIGHT++] = $ss3839238393;
}
if(R.isPyretException($e3838838389)) {
$e3838838389.pyretStack.push(L[2245]);
}
throw $e3838838389;
}
var $ret3839438395 = $Hanf_arg929738399($z3839038391,self32214918,_plus55,torepr65);
++R.GAS;
return $ret3839438395;
};
var $Hanf_arg929738399 = function(anf_arg258438398,self32214918,_plus55,torepr65) {
var anf_arg258538410 = G(self32214918,"left",L[2245]);
var $z3840238403 = D;
var $f3840838409 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg258538410):R.ffi.throwNonFunApp(L[2245],torepr65,[anf_arg258538410]);
};
try {
if(--R.GAS > 0) {
$z3840238403 = $f3840838409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3840838409,
"from":L[2245]});
}
} catch($e3840038401) {
if(R.isCont($e3840038401)) {
var $ss3840438405 = {"from":L[2245],
"go":function(anf_arg258638411) {
return $Hanf_arg929638412(anf_arg258638411,anf_arg258438398,self32214918,_plus55,torepr65);
}};
$e3840038401.stack[R.EXN_STACKHEIGHT++] = $ss3840438405;
}
if(R.isPyretException($e3840038401)) {
$e3840038401.pyretStack.push(L[2245]);
}
throw $e3840038401;
}
var $ret3840638407 = $Hanf_arg929638412($z3840238403,anf_arg258438398,self32214918,_plus55,torepr65);
++R.GAS;
return $ret3840638407;
};
var $Hanf_arg929638412 = function(anf_arg258638411,anf_arg258438398,self32214918,_plus55,torepr65) {
var $z3841538416 = D;
var $f3842138422 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg258638411):R.ffi.throwNonFunApp(L[2245],_plus55,[(", "),anf_arg258638411]);
};
try {
if(--R.GAS > 0) {
$z3841538416 = $f3842138422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3842138422,
"from":L[2245]});
}
} catch($e3841338414) {
if(R.isCont($e3841338414)) {
var $ss3841738418 = {"from":L[2245],
"go":function(anf_arg258738423) {
return $Hanf_arg929538424(anf_arg258738423,anf_arg258438398,self32214918,_plus55,torepr65);
}};
$e3841338414.stack[R.EXN_STACKHEIGHT++] = $ss3841738418;
}
if(R.isPyretException($e3841338414)) {
$e3841338414.pyretStack.push(L[2245]);
}
throw $e3841338414;
}
var $ret3841938420 = $Hanf_arg929538424($z3841538416,anf_arg258438398,self32214918,_plus55,torepr65);
++R.GAS;
return $ret3841938420;
};
var $Hanf_arg929538424 = function(anf_arg258738423,anf_arg258438398,self32214918,_plus55,torepr65) {
var $z3842738428 = D;
var $f3843338434 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg258438398,anf_arg258738423):R.ffi.throwNonFunApp(L[2245],_plus55,[anf_arg258438398,anf_arg258738423]);
};
try {
if(--R.GAS > 0) {
$z3842738428 = $f3843338434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3843338434,
"from":L[2245]});
}
} catch($e3842538426) {
if(R.isCont($e3842538426)) {
var $ss3842938430 = {"from":L[2245],
"go":function(anf_arg258838435) {
return $Hanf_arg929438436(anf_arg258838435,self32214918,_plus55,torepr65);
}};
$e3842538426.stack[R.EXN_STACKHEIGHT++] = $ss3842938430;
}
if(R.isPyretException($e3842538426)) {
$e3842538426.pyretStack.push(L[2245]);
}
throw $e3842538426;
}
var $ret3843138432 = $Hanf_arg929438436($z3842738428,self32214918,_plus55,torepr65);
++R.GAS;
return $ret3843138432;
};
var $Hanf_arg929438436 = function(anf_arg258838435,self32214918,_plus55,torepr65) {
var anf_arg258938447 = G(self32214918,"right",L[2245]);
var $z3843938440 = D;
var $f3844538446 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg258938447):R.ffi.throwNonFunApp(L[2245],torepr65,[anf_arg258938447]);
};
try {
if(--R.GAS > 0) {
$z3843938440 = $f3844538446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3844538446,
"from":L[2245]});
}
} catch($e3843738438) {
if(R.isCont($e3843738438)) {
var $ss3844138442 = {"from":L[2245],
"go":function(anf_arg259038448) {
return $Hanf_arg929338449(anf_arg259038448,anf_arg258838435,_plus55);
}};
$e3843738438.stack[R.EXN_STACKHEIGHT++] = $ss3844138442;
}
if(R.isPyretException($e3843738438)) {
$e3843738438.pyretStack.push(L[2245]);
}
throw $e3843738438;
}
var $ret3844338444 = $Hanf_arg929338449($z3843938440,anf_arg258838435,_plus55);
++R.GAS;
return $ret3844338444;
};
var $Hanf_arg929338449 = function(anf_arg259038448,anf_arg258838435,_plus55) {
var $z3845238453 = D;
var $f3845838459 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg259038448):R.ffi.throwNonFunApp(L[2245],_plus55,[(", "),anf_arg259038448]);
};
try {
if(--R.GAS > 0) {
$z3845238453 = $f3845838459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3845838459,
"from":L[2245]});
}
} catch($e3845038451) {
if(R.isCont($e3845038451)) {
var $ss3845438455 = {"from":L[2245],
"go":function(anf_arg259138460) {
return $Hanf_arg929238461(anf_arg259138460,anf_arg258838435,_plus55);
}};
$e3845038451.stack[R.EXN_STACKHEIGHT++] = $ss3845438455;
}
if(R.isPyretException($e3845038451)) {
$e3845038451.pyretStack.push(L[2245]);
}
throw $e3845038451;
}
var $ret3845638457 = $Hanf_arg929238461($z3845238453,anf_arg258838435,_plus55);
++R.GAS;
return $ret3845638457;
};
var $Hanf_arg929238461 = function(anf_arg259138460,anf_arg258838435,_plus55) {
var $z3846438465 = D;
var $f3847038471 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg258838435,anf_arg259138460):R.ffi.throwNonFunApp(L[2245],_plus55,[anf_arg258838435,anf_arg259138460]);
};
try {
if(--R.GAS > 0) {
$z3846438465 = $f3847038471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3847038471,
"from":L[2245]});
}
} catch($e3846238463) {
if(R.isCont($e3846238463)) {
var $ss3846638467 = {"from":L[2245],
"go":function(anf_arg259238472) {
return $Hanf_arg929138473(anf_arg259238472,_plus55);
}};
$e3846238463.stack[R.EXN_STACKHEIGHT++] = $ss3846638467;
}
if(R.isPyretException($e3846238463)) {
$e3846238463.pyretStack.push(L[2245]);
}
throw $e3846238463;
}
var $ret3846838469 = $Hanf_arg929138473($z3846438465,_plus55);
++R.GAS;
return $ret3846838469;
};
var $Hanf_arg929138473 = function(anf_arg259238472,_plus55) {
var $z3847638477 = D;
var $f3848238483 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg259238472,(")")):R.ffi.throwNonFunApp(L[2245],_plus55,[anf_arg259238472,(")")]);
};
try {
if(--R.GAS > 0) {
$z3847638477 = $f3848238483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3848238483,
"from":L[2245]});
}
} catch($e3847438475) {
if(R.isCont($e3847438475)) {
var $ss3847838479 = {"from":L[2245],
"go":function(anf_arg259338484) {
return $Hanf_arg929038485(anf_arg259338484,_plus55);
}};
$e3847438475.stack[R.EXN_STACKHEIGHT++] = $ss3847838479;
}
if(R.isPyretException($e3847438475)) {
$e3847438475.pyretStack.push(L[2245]);
}
throw $e3847438475;
}
var $ret3848038481 = $Hanf_arg929038485($z3847638477,_plus55);
++R.GAS;
return $ret3848038481;
};
var $Hanf_arg929038485 = function(anf_arg259338484,_plus55) {
var $z3848838489 = D;
var $f3849438495 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg259338484):R.ffi.throwNonFunApp(L[2245],_plus55,[("("),anf_arg259338484]);
};
try {
if(--R.GAS > 0) {
$z3848838489 = $f3849438495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3849438495,
"from":L[2245]});
}
} catch($e3848638487) {
if(R.isCont($e3848638487)) {
var $ss3849038491 = {"from":L[2245],
"go":function(anf_arg259438496) {
return $Hanf_arg928938497(anf_arg259438496,_plus55);
}};
$e3848638487.stack[R.EXN_STACKHEIGHT++] = $ss3849038491;
}
if(R.isPyretException($e3848638487)) {
$e3848638487.pyretStack.push(L[2245]);
}
throw $e3848638487;
}
var $ret3849238493 = $Hanf_arg928938497($z3848838489,_plus55);
++R.GAS;
return $ret3849238493;
};
var $Hanf_arg928938497 = function(anf_arg259438496,_plus55) {
var $z3850038501 = D;
var $f3850638507 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-check-test"),anf_arg259438496):R.ffi.throwNonFunApp(L[2245],_plus55,[("s-check-test"),anf_arg259438496]);
};
try {
if(--R.GAS > 0) {
$z3850038501 = $f3850638507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3850638507,
"from":L[2245]});
}
} catch($e3849838499) {
if(R.isCont($e3849838499)) {
var $ss3850238503 = {"from":L[2245],
"go":function(ann_DASH_check_DASH_temp257838508) {
return $Hann_DASH_check_DASH_temp928838509(ann_DASH_check_DASH_temp257838508);
}};
$e3849838499.stack[R.EXN_STACKHEIGHT++] = $ss3850238503;
}
if(R.isPyretException($e3849838499)) {
$e3849838499.pyretStack.push(L[2245]);
}
throw $e3849838499;
}
var $ret3850438505 = $Hann_DASH_check_DASH_temp928838509($z3850038501);
++R.GAS;
return $ret3850438505;
};
var $Hann_DASH_check_DASH_temp928838509 = function(ann_DASH_check_DASH_temp257838508) {
return ann_DASH_check_DASH_temp257838508;
};
var $Hcont_tail_arg928614937 = function(cont_tail_arg257514935,if_helper256414936) {
if(--R.GAS > 0) {
$z3851038511 = R.isFunction(if_helper256414936)?if_helper256414936.app(cont_tail_arg257514935):R.ffi.throwNonFunApp(L[2245],if_helper256414936,[cont_tail_arg257514935]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper256414936)?if_helper256414936.app(cont_tail_arg257514935):R.ffi.throwNonFunApp(L[2245],if_helper256414936,[cont_tail_arg257514935]);
},
"from":L[2245]});
}
++R.GAS;
return $z3851038511;
};
var $Hcont_tail_arg928714952 = function(cont_tail_arg256914951,if_helper256414936) {
if(--R.GAS > 0) {
$z3851238513 = R.isFunction(if_helper256414936)?if_helper256414936.app(cont_tail_arg256914951):R.ffi.throwNonFunApp(L[2245],if_helper256414936,[cont_tail_arg256914951]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper256414936)?if_helper256414936.app(cont_tail_arg256914951):R.ffi.throwNonFunApp(L[2245],if_helper256414936,[cont_tail_arg256914951]);
},
"from":L[2245]});
}
++R.GAS;
return $z3851238513;
};
var $Hanf_arg928514975 = function(anf_arg251814973,INDENT118169,PP170,break_DASH_one119168,collect_DASH_same_DASH_operands80114960,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64) {
var anf_arg251938524 = G(self80014974,"right",L[4453]);
var $z3851638517 = D;
var $f3852238523 = function(_) {
return R.isFunction(collect_DASH_same_DASH_operands80114960.$var)?collect_DASH_same_DASH_operands80114960.$var.app(anf_arg251938524):R.ffi.throwNonFunApp(L[4452],collect_DASH_same_DASH_operands80114960.$var,[anf_arg251938524]);
};
try {
if(--R.GAS > 0) {
$z3851638517 = $f3852238523();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3852238523,
"from":L[4452]});
}
} catch($e3851438515) {
if(R.isCont($e3851438515)) {
var $ss3851838519 = {"from":L[4452],
"go":function(anf_arg252038525) {
return $Hanf_arg928438526(anf_arg252038525,INDENT118169,PP170,anf_arg251814973,break_DASH_one119168,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64);
}};
$e3851438515.stack[R.EXN_STACKHEIGHT++] = $ss3851838519;
}
if(R.isPyretException($e3851438515)) {
$e3851438515.pyretStack.push(L[4452]);
}
throw $e3851438515;
}
var $ret3852038521 = $Hanf_arg928438526($z3851638517,INDENT118169,PP170,anf_arg251814973,break_DASH_one119168,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64);
++R.GAS;
return $ret3852038521;
};
var $Hanf_arg928438526 = function(anf_arg252038525,INDENT118169,PP170,anf_arg251814973,break_DASH_one119168,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64) {
var $z3852938530 = D;
var $f3853538536 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg251814973,anf_arg252038525):R.ffi.throwNonFunApp(L[4454],_plus55,[anf_arg251814973,anf_arg252038525]);
};
try {
if(--R.GAS > 0) {
$z3852938530 = $f3853538536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3853538536,
"from":L[4454]});
}
} catch($e3852738528) {
if(R.isCont($e3852738528)) {
var $ss3853138532 = {"from":L[4454],
"go":function(operands80338537) {
return $Hoperands928338538(operands80338537,INDENT118169,PP170,break_DASH_one119168,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64);
}};
$e3852738528.stack[R.EXN_STACKHEIGHT++] = $ss3853138532;
}
if(R.isPyretException($e3852738528)) {
$e3852738528.pyretStack.push(L[4454]);
}
throw $e3852738528;
}
var $ret3853338534 = $Hoperands928338538($z3852938530,INDENT118169,PP170,break_DASH_one119168,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64);
++R.GAS;
return $ret3853338534;
};
var $Hoperands928338538 = function(operands80338537,INDENT118169,PP170,break_DASH_one119168,lists974,self80014974,_plus55,string_DASH_length63,string_DASH_substring64) {
var cases_DASH_val31738609 = operands80338537;
var anf_fun252138549 = G(cases_DASH_val31738609,"_match",L[4455]);
var anf_obj252338555 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4465],0,arguments);
}
var ann_DASH_check_DASH_temp252238608 = G(PP170,"mt-doc",L[4466]);
return ann_DASH_check_DASH_temp252238608;
});
var anf_obj255838556 = R.makeFunction(function(first80438557,rest80538558) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[4456],2,arguments);
}
var cases_DASH_val31638607 = rest80538558;
var anf_fun252538569 = G(cases_DASH_val31638607,"_match",L[4457]);
var anf_obj252838575 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4463],0,arguments);
}
var anf_fun252738604 = G(first80438557,"tosource",L[4464]);
var $z3859638597 = D;
var $f3860238603 = function(_) {
return R.isFunction(anf_fun252738604)?anf_fun252738604.app():R.ffi.throwNonFunApp(L[4463],anf_fun252738604,[]);
};
try {
if(--R.GAS > 0) {
$z3859638597 = $f3860238603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3860238603,
"from":L[4463]});
}
} catch($e3859438595) {
if(R.isCont($e3859438595)) {
var $ss3859838599 = {"from":L[4463],
"go":function(ann_DASH_check_DASH_temp252638605) {
return $Hann_DASH_check_DASH_temp926438606(ann_DASH_check_DASH_temp252638605);
}};
$e3859438595.stack[R.EXN_STACKHEIGHT++] = $ss3859838599;
}
if(R.isPyretException($e3859438595)) {
$e3859438595.pyretStack.push(L[4463]);
}
throw $e3859438595;
}
var $ret3860038601 = $Hann_DASH_check_DASH_temp926438606($z3859638597);
++R.GAS;
return $ret3860038601;
});
var anf_obj255438576 = R.makeFunction(function(second80638577,rest280738578) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[4458],2,arguments);
}
var anf_fun253038592 = G(PP170,"str",L[4462]);
var anf_arg253138591 = G(self80014974,"op",L[4461]);
var anf_arg253238589 = G(self80014974,"op",L[4460]);
var $z3858138582 = D;
var $f3858738588 = function(_) {
return R.isFunction(string_DASH_length63)?string_DASH_length63.app(anf_arg253238589):R.ffi.throwNonFunApp(L[4459],string_DASH_length63,[anf_arg253238589]);
};
try {
if(--R.GAS > 0) {
$z3858138582 = $f3858738588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3858738588,
"from":L[4459]});
}
} catch($e3857938580) {
if(R.isCont($e3857938580)) {
var $ss3858338584 = {"from":L[4459],
"go":function(anf_arg253338590) {
return $Hanf_arg928038593(anf_arg253338590,INDENT118169,PP170,anf_arg253138591,anf_fun253038592,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55,string_DASH_substring64);
}};
$e3857938580.stack[R.EXN_STACKHEIGHT++] = $ss3858338584;
}
if(R.isPyretException($e3857938580)) {
$e3857938580.pyretStack.push(L[4459]);
}
throw $e3857938580;
}
var $ret3858538586 = $Hanf_arg928038593($z3858138582,INDENT118169,PP170,anf_arg253138591,anf_fun253038592,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55,string_DASH_substring64);
++R.GAS;
return $ret3858538586;
});
var anf_arg255538570 = R.makeObject({"empty":anf_obj252838575,
"link":anf_obj255438576});
var anf_arg255738571 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4457],0,arguments);
}
var ann_DASH_check_DASH_temp255638574 = R.throwNoBranchesMatched(L[4457],("cases"));
return ann_DASH_check_DASH_temp255638574;
});
var $z3856138562 = D;
var $f3856738568 = function(_) {
return R.isFunction(anf_fun252538569)?anf_fun252538569.app(anf_arg255538570,anf_arg255738571):R.ffi.throwNonFunApp(L[4456],anf_fun252538569,[anf_arg255538570,anf_arg255738571]);
};
try {
if(--R.GAS > 0) {
$z3856138562 = $f3856738568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3856738568,
"from":L[4456]});
}
} catch($e3855938560) {
if(R.isCont($e3855938560)) {
var $ss3856338564 = {"from":L[4456],
"go":function(ann_DASH_check_DASH_temp252438572) {
return $Hann_DASH_check_DASH_temp928138573(ann_DASH_check_DASH_temp252438572);
}};
$e3855938560.stack[R.EXN_STACKHEIGHT++] = $ss3856338564;
}
if(R.isPyretException($e3855938560)) {
$e3855938560.pyretStack.push(L[4456]);
}
throw $e3855938560;
}
var $ret3856538566 = $Hann_DASH_check_DASH_temp928138573($z3856138562);
++R.GAS;
return $ret3856538566;
});
var anf_arg255938550 = R.makeObject({"empty":anf_obj252338555,
"link":anf_obj255838556});
var anf_arg256138551 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4455],0,arguments);
}
var ann_DASH_check_DASH_temp256038554 = R.throwNoBranchesMatched(L[4455],("cases"));
return ann_DASH_check_DASH_temp256038554;
});
var $z3854138542 = D;
var $f3854738548 = function(_) {
return R.isFunction(anf_fun252138549)?anf_fun252138549.app(anf_arg255938550,anf_arg256138551):R.ffi.throwNonFunApp(L[2793],anf_fun252138549,[anf_arg255938550,anf_arg256138551]);
};
try {
if(--R.GAS > 0) {
$z3854138542 = $f3854738548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3854738548,
"from":L[2793]});
}
} catch($e3853938540) {
if(R.isCont($e3853938540)) {
var $ss3854338544 = {"from":L[2793],
"go":function(ann_DASH_check_DASH_temp248838552) {
return $Hann_DASH_check_DASH_temp928238553(ann_DASH_check_DASH_temp248838552);
}};
$e3853938540.stack[R.EXN_STACKHEIGHT++] = $ss3854338544;
}
if(R.isPyretException($e3853938540)) {
$e3853938540.pyretStack.push(L[2793]);
}
throw $e3853938540;
}
var $ret3854538546 = $Hann_DASH_check_DASH_temp928238553($z3854138542);
++R.GAS;
return $ret3854538546;
};
var $Hann_DASH_check_DASH_temp928238553 = function(ann_DASH_check_DASH_temp248838552) {
return ann_DASH_check_DASH_temp248838552;
};
var $Hann_DASH_check_DASH_temp928138573 = function(ann_DASH_check_DASH_temp252438572) {
return ann_DASH_check_DASH_temp252438572;
};
var $Hanf_arg928038593 = function(anf_arg253338590,INDENT118169,PP170,anf_arg253138591,anf_fun253038592,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55,string_DASH_substring64) {
var $z3861238613 = D;
var $f3861838619 = function(_) {
return R.isFunction(string_DASH_substring64)?string_DASH_substring64.app(anf_arg253138591,(2),anf_arg253338590):R.ffi.throwNonFunApp(L[4467],string_DASH_substring64,[anf_arg253138591,(2),anf_arg253338590]);
};
try {
if(--R.GAS > 0) {
$z3861238613 = $f3861838619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3861838619,
"from":L[4467]});
}
} catch($e3861038611) {
if(R.isCont($e3861038611)) {
var $ss3861438615 = {"from":L[4467],
"go":function(anf_arg253438620) {
return $Hanf_arg927938621(anf_arg253438620,INDENT118169,PP170,anf_fun253038592,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55);
}};
$e3861038611.stack[R.EXN_STACKHEIGHT++] = $ss3861438615;
}
if(R.isPyretException($e3861038611)) {
$e3861038611.pyretStack.push(L[4467]);
}
throw $e3861038611;
}
var $ret3861638617 = $Hanf_arg927938621($z3861238613,INDENT118169,PP170,anf_fun253038592,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55);
++R.GAS;
return $ret3861638617;
};
var $Hanf_arg927938621 = function(anf_arg253438620,INDENT118169,PP170,anf_fun253038592,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55) {
var $z3862438625 = D;
var $f3863038631 = function(_) {
return R.isFunction(anf_fun253038592)?anf_fun253038592.app(anf_arg253438620):R.ffi.throwNonFunApp(L[4468],anf_fun253038592,[anf_arg253438620]);
};
try {
if(--R.GAS > 0) {
$z3862438625 = $f3863038631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3863038631,
"from":L[4468]});
}
} catch($e3862238623) {
if(R.isCont($e3862238623)) {
var $ss3862638627 = {"from":L[4468],
"go":function(anf_arg253538632) {
return $Hanf_arg927838633(anf_arg253538632,INDENT118169,PP170,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55);
}};
$e3862238623.stack[R.EXN_STACKHEIGHT++] = $ss3862638627;
}
if(R.isPyretException($e3862238623)) {
$e3862238623.pyretStack.push(L[4468]);
}
throw $e3862238623;
}
var $ret3862838629 = $Hanf_arg927838633($z3862438625,INDENT118169,PP170,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55);
++R.GAS;
return $ret3862838629;
};
var $Hanf_arg927838633 = function(anf_arg253538632,INDENT118169,PP170,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55) {
var $z3863638637 = D;
var $f3864238643 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,anf_arg253538632):R.ffi.throwNonFunApp(L[4469],_plus55,[break_DASH_one119168,anf_arg253538632]);
};
try {
if(--R.GAS > 0) {
$z3863638637 = $f3864238643();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3864238643,
"from":L[4469]});
}
} catch($e3863438635) {
if(R.isCont($e3863438635)) {
var $ss3863838639 = {"from":L[4469],
"go":function(anf_arg253638644) {
return $Hanf_arg927738645(anf_arg253638644,INDENT118169,PP170,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55);
}};
$e3863438635.stack[R.EXN_STACKHEIGHT++] = $ss3863838639;
}
if(R.isPyretException($e3863438635)) {
$e3863438635.pyretStack.push(L[4469]);
}
throw $e3863438635;
}
var $ret3864038641 = $Hanf_arg927738645($z3863638637,INDENT118169,PP170,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55);
++R.GAS;
return $ret3864038641;
};
var $Hanf_arg927738645 = function(anf_arg253638644,INDENT118169,PP170,break_DASH_one119168,first80438557,lists974,rest280738578,second80638577,_plus55) {
var $z3864838649 = D;
var $f3865438655 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg253638644,break_DASH_one119168):R.ffi.throwNonFunApp(L[4470],_plus55,[anf_arg253638644,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3864838649 = $f3865438655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3865438655,
"from":L[4470]});
}
} catch($e3864638647) {
if(R.isCont($e3864638647)) {
var $ss3865038651 = {"from":L[4470],
"go":function(op80838656) {
return $Hop927638657(op80838656,INDENT118169,PP170,first80438557,lists974,rest280738578,second80638577,_plus55);
}};
$e3864638647.stack[R.EXN_STACKHEIGHT++] = $ss3865038651;
}
if(R.isPyretException($e3864638647)) {
$e3864638647.pyretStack.push(L[4470]);
}
throw $e3864638647;
}
var $ret3865238653 = $Hop927638657($z3864838649,INDENT118169,PP170,first80438557,lists974,rest280738578,second80638577,_plus55);
++R.GAS;
return $ret3865238653;
};
var $Hop927638657 = function(op80838656,INDENT118169,PP170,first80438557,lists974,rest280738578,second80638577,_plus55) {
var anf_fun253738671 = G(lists974,"fold",L[4477]);
var anf_arg254438670 = R.makeFunction(function(acc81038673,operand81138674) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[4473],2,arguments);
}
var anf_fun253938687 = G(PP170,"group",L[4476]);
var anf_fun254038685 = G(operand81138674,"tosource",L[4475]);
var $z3867738678 = D;
var $f3868338684 = function(_) {
return R.isFunction(anf_fun254038685)?anf_fun254038685.app():R.ffi.throwNonFunApp(L[4474],anf_fun254038685,[]);
};
try {
if(--R.GAS > 0) {
$z3867738678 = $f3868338684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3868338684,
"from":L[4474]});
}
} catch($e3867538676) {
if(R.isCont($e3867538676)) {
var $ss3867938680 = {"from":L[4474],
"go":function(anf_arg254138686) {
return $Hanf_arg926838688(anf_arg254138686,acc81038673,anf_fun253938687,op80838656,_plus55);
}};
$e3867538676.stack[R.EXN_STACKHEIGHT++] = $ss3867938680;
}
if(R.isPyretException($e3867538676)) {
$e3867538676.pyretStack.push(L[4474]);
}
throw $e3867538676;
}
var $ret3868138682 = $Hanf_arg926838688($z3867738678,acc81038673,anf_fun253938687,op80838656,_plus55);
++R.GAS;
return $ret3868138682;
});
var anf_fun254538668 = G(second80638577,"tosource",L[4472]);
var $z3866038661 = D;
var $f3866638667 = function(_) {
return R.isFunction(anf_fun254538668)?anf_fun254538668.app():R.ffi.throwNonFunApp(L[4471],anf_fun254538668,[]);
};
try {
if(--R.GAS > 0) {
$z3866038661 = $f3866638667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3866638667,
"from":L[4471]});
}
} catch($e3865838659) {
if(R.isCont($e3865838659)) {
var $ss3866238663 = {"from":L[4471],
"go":function(anf_arg254638669) {
return $Hanf_arg927538672(anf_arg254638669,INDENT118169,PP170,anf_arg254438670,anf_fun253738671,first80438557,op80838656,rest280738578,_plus55);
}};
$e3865838659.stack[R.EXN_STACKHEIGHT++] = $ss3866238663;
}
if(R.isPyretException($e3865838659)) {
$e3865838659.pyretStack.push(L[4471]);
}
throw $e3865838659;
}
var $ret3866438665 = $Hanf_arg927538672($z3866038661,INDENT118169,PP170,anf_arg254438670,anf_fun253738671,first80438557,op80838656,rest280738578,_plus55);
++R.GAS;
return $ret3866438665;
};
var $Hanf_arg927538672 = function(anf_arg254638669,INDENT118169,PP170,anf_arg254438670,anf_fun253738671,first80438557,op80838656,rest280738578,_plus55) {
var $z3869138692 = D;
var $f3869738698 = function(_) {
return R.isFunction(anf_fun253738671)?anf_fun253738671.app(anf_arg254438670,anf_arg254638669,rest280738578):R.ffi.throwNonFunApp(L[4478],anf_fun253738671,[anf_arg254438670,anf_arg254638669,rest280738578]);
};
try {
if(--R.GAS > 0) {
$z3869138692 = $f3869738698();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3869738698,
"from":L[4478]});
}
} catch($e3868938690) {
if(R.isCont($e3868938690)) {
var $ss3869338694 = {"from":L[4478],
"go":function(nested80938699) {
return $Hnested927438700(nested80938699,INDENT118169,PP170,first80438557,op80838656,_plus55);
}};
$e3868938690.stack[R.EXN_STACKHEIGHT++] = $ss3869338694;
}
if(R.isPyretException($e3868938690)) {
$e3868938690.pyretStack.push(L[4478]);
}
throw $e3868938690;
}
var $ret3869538696 = $Hnested927438700($z3869138692,INDENT118169,PP170,first80438557,op80838656,_plus55);
++R.GAS;
return $ret3869538696;
};
var $Hnested927438700 = function(nested80938699,INDENT118169,PP170,first80438557,op80838656,_plus55) {
var anf_fun254738713 = G(PP170,"group",L[4481]);
var anf_fun254838711 = G(first80438557,"tosource",L[4480]);
var $z3870338704 = D;
var $f3870938710 = function(_) {
return R.isFunction(anf_fun254838711)?anf_fun254838711.app():R.ffi.throwNonFunApp(L[4479],anf_fun254838711,[]);
};
try {
if(--R.GAS > 0) {
$z3870338704 = $f3870938710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3870938710,
"from":L[4479]});
}
} catch($e3870138702) {
if(R.isCont($e3870138702)) {
var $ss3870538706 = {"from":L[4479],
"go":function(anf_arg254938712) {
return $Hanf_arg927338714(anf_arg254938712,INDENT118169,PP170,anf_fun254738713,nested80938699,op80838656,_plus55);
}};
$e3870138702.stack[R.EXN_STACKHEIGHT++] = $ss3870538706;
}
if(R.isPyretException($e3870138702)) {
$e3870138702.pyretStack.push(L[4479]);
}
throw $e3870138702;
}
var $ret3870738708 = $Hanf_arg927338714($z3870338704,INDENT118169,PP170,anf_fun254738713,nested80938699,op80838656,_plus55);
++R.GAS;
return $ret3870738708;
};
var $Hanf_arg927338714 = function(anf_arg254938712,INDENT118169,PP170,anf_fun254738713,nested80938699,op80838656,_plus55) {
var $z3871738718 = D;
var $f3872338724 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg254938712,op80838656):R.ffi.throwNonFunApp(L[4482],_plus55,[anf_arg254938712,op80838656]);
};
try {
if(--R.GAS > 0) {
$z3871738718 = $f3872338724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3872338724,
"from":L[4482]});
}
} catch($e3871538716) {
if(R.isCont($e3871538716)) {
var $ss3871938720 = {"from":L[4482],
"go":function(anf_arg255038725) {
return $Hanf_arg927238726(anf_arg255038725,INDENT118169,PP170,anf_fun254738713,nested80938699,_plus55);
}};
$e3871538716.stack[R.EXN_STACKHEIGHT++] = $ss3871938720;
}
if(R.isPyretException($e3871538716)) {
$e3871538716.pyretStack.push(L[4482]);
}
throw $e3871538716;
}
var $ret3872138722 = $Hanf_arg927238726($z3871738718,INDENT118169,PP170,anf_fun254738713,nested80938699,_plus55);
++R.GAS;
return $ret3872138722;
};
var $Hanf_arg927238726 = function(anf_arg255038725,INDENT118169,PP170,anf_fun254738713,nested80938699,_plus55) {
var anf_fun255138737 = G(PP170,"nest",L[4484]);
var $z3872938730 = D;
var $f3873538736 = function(_) {
return R.isFunction(anf_fun255138737)?anf_fun255138737.app(INDENT118169,nested80938699):R.ffi.throwNonFunApp(L[4483],anf_fun255138737,[INDENT118169,nested80938699]);
};
try {
if(--R.GAS > 0) {
$z3872938730 = $f3873538736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3873538736,
"from":L[4483]});
}
} catch($e3872738728) {
if(R.isCont($e3872738728)) {
var $ss3873138732 = {"from":L[4483],
"go":function(anf_arg255238738) {
return $Hanf_arg927138739(anf_arg255238738,anf_arg255038725,anf_fun254738713,_plus55);
}};
$e3872738728.stack[R.EXN_STACKHEIGHT++] = $ss3873138732;
}
if(R.isPyretException($e3872738728)) {
$e3872738728.pyretStack.push(L[4483]);
}
throw $e3872738728;
}
var $ret3873338734 = $Hanf_arg927138739($z3872938730,anf_arg255038725,anf_fun254738713,_plus55);
++R.GAS;
return $ret3873338734;
};
var $Hanf_arg927138739 = function(anf_arg255238738,anf_arg255038725,anf_fun254738713,_plus55) {
var $z3874238743 = D;
var $f3874838749 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg255038725,anf_arg255238738):R.ffi.throwNonFunApp(L[4482],_plus55,[anf_arg255038725,anf_arg255238738]);
};
try {
if(--R.GAS > 0) {
$z3874238743 = $f3874838749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3874838749,
"from":L[4482]});
}
} catch($e3874038741) {
if(R.isCont($e3874038741)) {
var $ss3874438745 = {"from":L[4482],
"go":function(anf_arg255338750) {
return $Hanf_arg927038751(anf_arg255338750,anf_fun254738713);
}};
$e3874038741.stack[R.EXN_STACKHEIGHT++] = $ss3874438745;
}
if(R.isPyretException($e3874038741)) {
$e3874038741.pyretStack.push(L[4482]);
}
throw $e3874038741;
}
var $ret3874638747 = $Hanf_arg927038751($z3874238743,anf_fun254738713);
++R.GAS;
return $ret3874638747;
};
var $Hanf_arg927038751 = function(anf_arg255338750,anf_fun254738713) {
var $z3875438755 = D;
var $f3876038761 = function(_) {
return R.isFunction(anf_fun254738713)?anf_fun254738713.app(anf_arg255338750):R.ffi.throwNonFunApp(L[4458],anf_fun254738713,[anf_arg255338750]);
};
try {
if(--R.GAS > 0) {
$z3875438755 = $f3876038761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3876038761,
"from":L[4458]});
}
} catch($e3875238753) {
if(R.isCont($e3875238753)) {
var $ss3875638757 = {"from":L[4458],
"go":function(ann_DASH_check_DASH_temp252938762) {
return $Hann_DASH_check_DASH_temp926938763(ann_DASH_check_DASH_temp252938762);
}};
$e3875238753.stack[R.EXN_STACKHEIGHT++] = $ss3875638757;
}
if(R.isPyretException($e3875238753)) {
$e3875238753.pyretStack.push(L[4458]);
}
throw $e3875238753;
}
var $ret3875838759 = $Hann_DASH_check_DASH_temp926938763($z3875438755);
++R.GAS;
return $ret3875838759;
};
var $Hann_DASH_check_DASH_temp926938763 = function(ann_DASH_check_DASH_temp252938762) {
return ann_DASH_check_DASH_temp252938762;
};
var $Hanf_arg926838688 = function(anf_arg254138686,acc81038673,anf_fun253938687,op80838656,_plus55) {
var $z3876638767 = D;
var $f3877238773 = function(_) {
return R.isFunction(_plus55)?_plus55.app(op80838656,anf_arg254138686):R.ffi.throwNonFunApp(L[4485],_plus55,[op80838656,anf_arg254138686]);
};
try {
if(--R.GAS > 0) {
$z3876638767 = $f3877238773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3877238773,
"from":L[4485]});
}
} catch($e3876438765) {
if(R.isCont($e3876438765)) {
var $ss3876838769 = {"from":L[4485],
"go":function(anf_arg254238774) {
return $Hanf_arg926738775(anf_arg254238774,acc81038673,anf_fun253938687,_plus55);
}};
$e3876438765.stack[R.EXN_STACKHEIGHT++] = $ss3876838769;
}
if(R.isPyretException($e3876438765)) {
$e3876438765.pyretStack.push(L[4485]);
}
throw $e3876438765;
}
var $ret3877038771 = $Hanf_arg926738775($z3876638767,acc81038673,anf_fun253938687,_plus55);
++R.GAS;
return $ret3877038771;
};
var $Hanf_arg926738775 = function(anf_arg254238774,acc81038673,anf_fun253938687,_plus55) {
var $z3877838779 = D;
var $f3878438785 = function(_) {
return R.isFunction(anf_fun253938687)?anf_fun253938687.app(anf_arg254238774):R.ffi.throwNonFunApp(L[4486],anf_fun253938687,[anf_arg254238774]);
};
try {
if(--R.GAS > 0) {
$z3877838779 = $f3878438785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3878438785,
"from":L[4486]});
}
} catch($e3877638777) {
if(R.isCont($e3877638777)) {
var $ss3878038781 = {"from":L[4486],
"go":function(anf_arg254338786) {
return $Hanf_arg926638787(anf_arg254338786,acc81038673,_plus55);
}};
$e3877638777.stack[R.EXN_STACKHEIGHT++] = $ss3878038781;
}
if(R.isPyretException($e3877638777)) {
$e3877638777.pyretStack.push(L[4486]);
}
throw $e3877638777;
}
var $ret3878238783 = $Hanf_arg926638787($z3877838779,acc81038673,_plus55);
++R.GAS;
return $ret3878238783;
};
var $Hanf_arg926638787 = function(anf_arg254338786,acc81038673,_plus55) {
var $z3879038791 = D;
var $f3879638797 = function(_) {
return R.isFunction(_plus55)?_plus55.app(acc81038673,anf_arg254338786):R.ffi.throwNonFunApp(L[4473],_plus55,[acc81038673,anf_arg254338786]);
};
try {
if(--R.GAS > 0) {
$z3879038791 = $f3879638797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3879638797,
"from":L[4473]});
}
} catch($e3878838789) {
if(R.isCont($e3878838789)) {
var $ss3879238793 = {"from":L[4473],
"go":function(ann_DASH_check_DASH_temp253838798) {
return $Hann_DASH_check_DASH_temp926538799(ann_DASH_check_DASH_temp253838798);
}};
$e3878838789.stack[R.EXN_STACKHEIGHT++] = $ss3879238793;
}
if(R.isPyretException($e3878838789)) {
$e3878838789.pyretStack.push(L[4473]);
}
throw $e3878838789;
}
var $ret3879438795 = $Hann_DASH_check_DASH_temp926538799($z3879038791);
++R.GAS;
return $ret3879438795;
};
var $Hann_DASH_check_DASH_temp926538799 = function(ann_DASH_check_DASH_temp253838798) {
return ann_DASH_check_DASH_temp253838798;
};
var $Hann_DASH_check_DASH_temp926438606 = function(ann_DASH_check_DASH_temp252638605) {
return ann_DASH_check_DASH_temp252638605;
};
var $Hand_DASH_oper_DASH_926314988 = function(and_DASH_oper_DASH_31414987,collect_DASH_same_DASH_operands80114960,exp80214976,list25154,self80014974,_plus55) {
var if_helper249038810 = R.makeFunction(function(if_helper_arg249138836) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2792],1,arguments);
}
var if_DASH_31338864 = if_helper_arg249138836;
var if_helper249238849 = R.makeFunction(function(if_helper_arg249338869) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2792],1,arguments);
}
var ann_DASH_check_DASH_temp248938870 = if_helper_arg249338869;
return ann_DASH_check_DASH_temp248938870;
});
var anf_if249638868 = R.isBoolean(if_DASH_31338864);
if(R.isPyretTrue(anf_if249638868)) {
if(R.isPyretTrue(if_DASH_31338864)) {
var anf_arg250038847 = G(exp80214976,"left",L[4492]);
var $z3883938840 = D;
var $f3884538846 = function(_) {
return R.isFunction(collect_DASH_same_DASH_operands80114960.$var)?collect_DASH_same_DASH_operands80114960.$var.app(anf_arg250038847):R.ffi.throwNonFunApp(L[4491],collect_DASH_same_DASH_operands80114960.$var,[anf_arg250038847]);
};
try {
if(--R.GAS > 0) {
$z3883938840 = $f3884538846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3884538846,
"from":L[4491]});
}
} catch($e3883738838) {
if(R.isCont($e3883738838)) {
var $ss3884138842 = {"from":L[4491],
"go":function(anf_arg250138848) {
return $Hanf_arg925938850(anf_arg250138848,collect_DASH_same_DASH_operands80114960,exp80214976,if_helper249238849,_plus55);
}};
$e3883738838.stack[R.EXN_STACKHEIGHT++] = $ss3884138842;
}
if(R.isPyretException($e3883738838)) {
$e3883738838.pyretStack.push(L[4491]);
}
throw $e3883738838;
}
var $ret3884338844 = $Hanf_arg925938850($z3883938840,collect_DASH_same_DASH_operands80114960,exp80214976,if_helper249238849,_plus55);
++R.GAS;
return $ret3884338844;
} else {
var anf_fun249738861 = G(list25154,"make",L[4493]);
var $z3885338854 = D;
var $f3885938860 = function(_) {
return R.isFunction(anf_fun249738861)?anf_fun249738861.app([exp80214976]):R.ffi.throwNonFunApp(L[4493],anf_fun249738861,[[exp80214976]]);
};
try {
if(--R.GAS > 0) {
$z3885338854 = $f3885938860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3885938860,
"from":L[4493]});
}
} catch($e3885138852) {
if(R.isCont($e3885138852)) {
var $ss3885538856 = {"from":L[4493],
"go":function(cont_tail_arg249838862) {
return $Hcont_tail_arg926038863(cont_tail_arg249838862,if_helper249238849);
}};
$e3885138852.stack[R.EXN_STACKHEIGHT++] = $ss3885538856;
}
if(R.isPyretException($e3885138852)) {
$e3885138852.pyretStack.push(L[4493]);
}
throw $e3885138852;
}
var $ret3885738858 = $Hcont_tail_arg926038863($z3885338854,if_helper249238849);
++R.GAS;
return $ret3885738858;
}
} else {
var cont_tail_arg249438867 = R.throwNonBooleanCondition(L[2792],("if"),if_DASH_31338864);
if(--R.GAS > 0) {
$z3886538866 = R.isFunction(if_helper249238849)?if_helper249238849.app(cont_tail_arg249438867):R.ffi.throwNonFunApp(L[2792],if_helper249238849,[cont_tail_arg249438867]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper249238849)?if_helper249238849.app(cont_tail_arg249438867):R.ffi.throwNonFunApp(L[2792],if_helper249238849,[cont_tail_arg249438867]);
},
"from":L[2792]});
}
++R.GAS;
return $z3886538866;
}
});
var anf_if250838835 = R.isBoolean(and_DASH_oper_DASH_31414987);
if(R.isPyretTrue(anf_if250838835)) {
if(R.isPyretTrue(and_DASH_oper_DASH_31414987)) {
var anf_arg251038818 = G(exp80214976,"op",L[4489]);
var anf_arg251138819 = G(self80014974,"op",L[4488]);
var and_DASH_oper_DASH_31538811 = R.equiv(anf_arg251038818,anf_arg251138819);
var anf_if251438817 = R.isBoolean(and_DASH_oper_DASH_31538811);
if(R.isPyretTrue(anf_if251438817)) {
var $z3880238803 = D;
var $f3880838809 = function(_) {
return R.isFunction(if_helper249038810)?if_helper249038810.app(and_DASH_oper_DASH_31538811):R.ffi.throwNonFunApp(L[2792],if_helper249038810,[and_DASH_oper_DASH_31538811]);
};
try {
if(--R.GAS > 0) {
$z3880238803 = $f3880838809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3880838809,
"from":L[2792]});
}
} catch($e3880038801) {
if(R.isCont($e3880038801)) {
var $ss3880438805 = {"from":L[2792],
"go":function(cont_tail_app251538812) {
return $Hcont_tail_app926138813(cont_tail_app251538812);
}};
$e3880038801.stack[R.EXN_STACKHEIGHT++] = $ss3880438805;
}
if(R.isPyretException($e3880038801)) {
$e3880038801.pyretStack.push(L[2792]);
}
throw $e3880038801;
}
var $ret3880638807 = $Hcont_tail_app926138813($z3880238803);
++R.GAS;
return $ret3880638807;
} else {
var cont_tail_arg251238816 = R.throwNonBooleanOp(L[4487],("second"),("and"),and_DASH_oper_DASH_31538811);
if(--R.GAS > 0) {
$z3881438815 = R.isFunction(if_helper249038810)?if_helper249038810.app(cont_tail_arg251238816):R.ffi.throwNonFunApp(L[4487],if_helper249038810,[cont_tail_arg251238816]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper249038810)?if_helper249038810.app(cont_tail_arg251238816):R.ffi.throwNonFunApp(L[4487],if_helper249038810,[cont_tail_arg251238816]);
},
"from":L[4487]});
}
++R.GAS;
return $z3881438815;
}
} else {
var $z3882238823 = D;
var $f3882838829 = function(_) {
return R.isFunction(if_helper249038810)?if_helper249038810.app((false)):R.ffi.throwNonFunApp(L[2792],if_helper249038810,[(false)]);
};
try {
if(--R.GAS > 0) {
$z3882238823 = $f3882838829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3882838829,
"from":L[2792]});
}
} catch($e3882038821) {
if(R.isCont($e3882038821)) {
var $ss3882438825 = {"from":L[2792],
"go":function(cont_tail_app250938830) {
return $Hcont_tail_app926238831(cont_tail_app250938830);
}};
$e3882038821.stack[R.EXN_STACKHEIGHT++] = $ss3882438825;
}
if(R.isPyretException($e3882038821)) {
$e3882038821.pyretStack.push(L[2792]);
}
throw $e3882038821;
}
var $ret3882638827 = $Hcont_tail_app926238831($z3882238823);
++R.GAS;
return $ret3882638827;
}
} else {
var cont_tail_arg250638834 = R.throwNonBooleanOp(L[4490],("first"),("and"),and_DASH_oper_DASH_31414987);
if(--R.GAS > 0) {
$z3883238833 = R.isFunction(if_helper249038810)?if_helper249038810.app(cont_tail_arg250638834):R.ffi.throwNonFunApp(L[4490],if_helper249038810,[cont_tail_arg250638834]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper249038810)?if_helper249038810.app(cont_tail_arg250638834):R.ffi.throwNonFunApp(L[4490],if_helper249038810,[cont_tail_arg250638834]);
},
"from":L[4490]});
}
++R.GAS;
return $z3883238833;
}
};
var $Hcont_tail_app926138813 = function(cont_tail_app251538812) {
return cont_tail_app251538812;
};
var $Hcont_tail_app926238831 = function(cont_tail_app250938830) {
return cont_tail_app250938830;
};
var $Hanf_arg925938850 = function(anf_arg250138848,collect_DASH_same_DASH_operands80114960,exp80214976,if_helper249238849,_plus55) {
var anf_arg250238881 = G(exp80214976,"right",L[4495]);
var $z3887338874 = D;
var $f3887938880 = function(_) {
return R.isFunction(collect_DASH_same_DASH_operands80114960.$var)?collect_DASH_same_DASH_operands80114960.$var.app(anf_arg250238881):R.ffi.throwNonFunApp(L[4494],collect_DASH_same_DASH_operands80114960.$var,[anf_arg250238881]);
};
try {
if(--R.GAS > 0) {
$z3887338874 = $f3887938880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3887938880,
"from":L[4494]});
}
} catch($e3887138872) {
if(R.isCont($e3887138872)) {
var $ss3887538876 = {"from":L[4494],
"go":function(anf_arg250338882) {
return $Hanf_arg925838883(anf_arg250338882,anf_arg250138848,if_helper249238849,_plus55);
}};
$e3887138872.stack[R.EXN_STACKHEIGHT++] = $ss3887538876;
}
if(R.isPyretException($e3887138872)) {
$e3887138872.pyretStack.push(L[4494]);
}
throw $e3887138872;
}
var $ret3887738878 = $Hanf_arg925838883($z3887338874,anf_arg250138848,if_helper249238849,_plus55);
++R.GAS;
return $ret3887738878;
};
var $Hanf_arg925838883 = function(anf_arg250338882,anf_arg250138848,if_helper249238849,_plus55) {
var $z3888638887 = D;
var $f3889238893 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg250138848,anf_arg250338882):R.ffi.throwNonFunApp(L[4496],_plus55,[anf_arg250138848,anf_arg250338882]);
};
try {
if(--R.GAS > 0) {
$z3888638887 = $f3889238893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3889238893,
"from":L[4496]});
}
} catch($e3888438885) {
if(R.isCont($e3888438885)) {
var $ss3888838889 = {"from":L[4496],
"go":function(cont_tail_arg250438894) {
return $Hcont_tail_arg925738895(cont_tail_arg250438894,if_helper249238849);
}};
$e3888438885.stack[R.EXN_STACKHEIGHT++] = $ss3888838889;
}
if(R.isPyretException($e3888438885)) {
$e3888438885.pyretStack.push(L[4496]);
}
throw $e3888438885;
}
var $ret3889038891 = $Hcont_tail_arg925738895($z3888638887,if_helper249238849);
++R.GAS;
return $ret3889038891;
};
var $Hcont_tail_arg925738895 = function(cont_tail_arg250438894,if_helper249238849) {
if(--R.GAS > 0) {
$z3889638897 = R.isFunction(if_helper249238849)?if_helper249238849.app(cont_tail_arg250438894):R.ffi.throwNonFunApp(L[4496],if_helper249238849,[cont_tail_arg250438894]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper249238849)?if_helper249238849.app(cont_tail_arg250438894):R.ffi.throwNonFunApp(L[4496],if_helper249238849,[cont_tail_arg250438894]);
},
"from":L[4496]});
}
++R.GAS;
return $z3889638897;
};
var $Hcont_tail_arg926038863 = function(cont_tail_arg249838862,if_helper249238849) {
if(--R.GAS > 0) {
$z3889838899 = R.isFunction(if_helper249238849)?if_helper249238849.app(cont_tail_arg249838862):R.ffi.throwNonFunApp(L[4493],if_helper249238849,[cont_tail_arg249838862]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper249238849)?if_helper249238849.app(cont_tail_arg249838862):R.ffi.throwNonFunApp(L[4493],if_helper249238849,[cont_tail_arg249838862]);
},
"from":L[4493]});
}
++R.GAS;
return $z3889838899;
};
var $Hanf_arg925615004 = function(anf_arg247015002,self31115003,_plus55,torepr65) {
var anf_arg247138910 = G(self31115003,"op",L[2246]);
var $z3890238903 = D;
var $f3890838909 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg247138910):R.ffi.throwNonFunApp(L[2246],torepr65,[anf_arg247138910]);
};
try {
if(--R.GAS > 0) {
$z3890238903 = $f3890838909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3890838909,
"from":L[2246]});
}
} catch($e3890038901) {
if(R.isCont($e3890038901)) {
var $ss3890438905 = {"from":L[2246],
"go":function(anf_arg247238911) {
return $Hanf_arg925538912(anf_arg247238911,anf_arg247015002,self31115003,_plus55,torepr65);
}};
$e3890038901.stack[R.EXN_STACKHEIGHT++] = $ss3890438905;
}
if(R.isPyretException($e3890038901)) {
$e3890038901.pyretStack.push(L[2246]);
}
throw $e3890038901;
}
var $ret3890638907 = $Hanf_arg925538912($z3890238903,anf_arg247015002,self31115003,_plus55,torepr65);
++R.GAS;
return $ret3890638907;
};
var $Hanf_arg925538912 = function(anf_arg247238911,anf_arg247015002,self31115003,_plus55,torepr65) {
var $z3891538916 = D;
var $f3892138922 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg247238911):R.ffi.throwNonFunApp(L[2246],_plus55,[(", "),anf_arg247238911]);
};
try {
if(--R.GAS > 0) {
$z3891538916 = $f3892138922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3892138922,
"from":L[2246]});
}
} catch($e3891338914) {
if(R.isCont($e3891338914)) {
var $ss3891738918 = {"from":L[2246],
"go":function(anf_arg247338923) {
return $Hanf_arg925438924(anf_arg247338923,anf_arg247015002,self31115003,_plus55,torepr65);
}};
$e3891338914.stack[R.EXN_STACKHEIGHT++] = $ss3891738918;
}
if(R.isPyretException($e3891338914)) {
$e3891338914.pyretStack.push(L[2246]);
}
throw $e3891338914;
}
var $ret3891938920 = $Hanf_arg925438924($z3891538916,anf_arg247015002,self31115003,_plus55,torepr65);
++R.GAS;
return $ret3891938920;
};
var $Hanf_arg925438924 = function(anf_arg247338923,anf_arg247015002,self31115003,_plus55,torepr65) {
var $z3892738928 = D;
var $f3893338934 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg247015002,anf_arg247338923):R.ffi.throwNonFunApp(L[2246],_plus55,[anf_arg247015002,anf_arg247338923]);
};
try {
if(--R.GAS > 0) {
$z3892738928 = $f3893338934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3893338934,
"from":L[2246]});
}
} catch($e3892538926) {
if(R.isCont($e3892538926)) {
var $ss3892938930 = {"from":L[2246],
"go":function(anf_arg247438935) {
return $Hanf_arg925338936(anf_arg247438935,self31115003,_plus55,torepr65);
}};
$e3892538926.stack[R.EXN_STACKHEIGHT++] = $ss3892938930;
}
if(R.isPyretException($e3892538926)) {
$e3892538926.pyretStack.push(L[2246]);
}
throw $e3892538926;
}
var $ret3893138932 = $Hanf_arg925338936($z3892738928,self31115003,_plus55,torepr65);
++R.GAS;
return $ret3893138932;
};
var $Hanf_arg925338936 = function(anf_arg247438935,self31115003,_plus55,torepr65) {
var anf_arg247538947 = G(self31115003,"left",L[2246]);
var $z3893938940 = D;
var $f3894538946 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg247538947):R.ffi.throwNonFunApp(L[2246],torepr65,[anf_arg247538947]);
};
try {
if(--R.GAS > 0) {
$z3893938940 = $f3894538946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3894538946,
"from":L[2246]});
}
} catch($e3893738938) {
if(R.isCont($e3893738938)) {
var $ss3894138942 = {"from":L[2246],
"go":function(anf_arg247638948) {
return $Hanf_arg925238949(anf_arg247638948,anf_arg247438935,self31115003,_plus55,torepr65);
}};
$e3893738938.stack[R.EXN_STACKHEIGHT++] = $ss3894138942;
}
if(R.isPyretException($e3893738938)) {
$e3893738938.pyretStack.push(L[2246]);
}
throw $e3893738938;
}
var $ret3894338944 = $Hanf_arg925238949($z3893938940,anf_arg247438935,self31115003,_plus55,torepr65);
++R.GAS;
return $ret3894338944;
};
var $Hanf_arg925238949 = function(anf_arg247638948,anf_arg247438935,self31115003,_plus55,torepr65) {
var $z3895238953 = D;
var $f3895838959 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg247638948):R.ffi.throwNonFunApp(L[2246],_plus55,[(", "),anf_arg247638948]);
};
try {
if(--R.GAS > 0) {
$z3895238953 = $f3895838959();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3895838959,
"from":L[2246]});
}
} catch($e3895038951) {
if(R.isCont($e3895038951)) {
var $ss3895438955 = {"from":L[2246],
"go":function(anf_arg247738960) {
return $Hanf_arg925138961(anf_arg247738960,anf_arg247438935,self31115003,_plus55,torepr65);
}};
$e3895038951.stack[R.EXN_STACKHEIGHT++] = $ss3895438955;
}
if(R.isPyretException($e3895038951)) {
$e3895038951.pyretStack.push(L[2246]);
}
throw $e3895038951;
}
var $ret3895638957 = $Hanf_arg925138961($z3895238953,anf_arg247438935,self31115003,_plus55,torepr65);
++R.GAS;
return $ret3895638957;
};
var $Hanf_arg925138961 = function(anf_arg247738960,anf_arg247438935,self31115003,_plus55,torepr65) {
var $z3896438965 = D;
var $f3897038971 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg247438935,anf_arg247738960):R.ffi.throwNonFunApp(L[2246],_plus55,[anf_arg247438935,anf_arg247738960]);
};
try {
if(--R.GAS > 0) {
$z3896438965 = $f3897038971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3897038971,
"from":L[2246]});
}
} catch($e3896238963) {
if(R.isCont($e3896238963)) {
var $ss3896638967 = {"from":L[2246],
"go":function(anf_arg247838972) {
return $Hanf_arg925038973(anf_arg247838972,self31115003,_plus55,torepr65);
}};
$e3896238963.stack[R.EXN_STACKHEIGHT++] = $ss3896638967;
}
if(R.isPyretException($e3896238963)) {
$e3896238963.pyretStack.push(L[2246]);
}
throw $e3896238963;
}
var $ret3896838969 = $Hanf_arg925038973($z3896438965,self31115003,_plus55,torepr65);
++R.GAS;
return $ret3896838969;
};
var $Hanf_arg925038973 = function(anf_arg247838972,self31115003,_plus55,torepr65) {
var anf_arg247938984 = G(self31115003,"right",L[2246]);
var $z3897638977 = D;
var $f3898238983 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg247938984):R.ffi.throwNonFunApp(L[2246],torepr65,[anf_arg247938984]);
};
try {
if(--R.GAS > 0) {
$z3897638977 = $f3898238983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3898238983,
"from":L[2246]});
}
} catch($e3897438975) {
if(R.isCont($e3897438975)) {
var $ss3897838979 = {"from":L[2246],
"go":function(anf_arg248038985) {
return $Hanf_arg924938986(anf_arg248038985,anf_arg247838972,_plus55);
}};
$e3897438975.stack[R.EXN_STACKHEIGHT++] = $ss3897838979;
}
if(R.isPyretException($e3897438975)) {
$e3897438975.pyretStack.push(L[2246]);
}
throw $e3897438975;
}
var $ret3898038981 = $Hanf_arg924938986($z3897638977,anf_arg247838972,_plus55);
++R.GAS;
return $ret3898038981;
};
var $Hanf_arg924938986 = function(anf_arg248038985,anf_arg247838972,_plus55) {
var $z3898938990 = D;
var $f3899538996 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg248038985):R.ffi.throwNonFunApp(L[2246],_plus55,[(", "),anf_arg248038985]);
};
try {
if(--R.GAS > 0) {
$z3898938990 = $f3899538996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3899538996,
"from":L[2246]});
}
} catch($e3898738988) {
if(R.isCont($e3898738988)) {
var $ss3899138992 = {"from":L[2246],
"go":function(anf_arg248138997) {
return $Hanf_arg924838998(anf_arg248138997,anf_arg247838972,_plus55);
}};
$e3898738988.stack[R.EXN_STACKHEIGHT++] = $ss3899138992;
}
if(R.isPyretException($e3898738988)) {
$e3898738988.pyretStack.push(L[2246]);
}
throw $e3898738988;
}
var $ret3899338994 = $Hanf_arg924838998($z3898938990,anf_arg247838972,_plus55);
++R.GAS;
return $ret3899338994;
};
var $Hanf_arg924838998 = function(anf_arg248138997,anf_arg247838972,_plus55) {
var $z3900139002 = D;
var $f3900739008 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg247838972,anf_arg248138997):R.ffi.throwNonFunApp(L[2246],_plus55,[anf_arg247838972,anf_arg248138997]);
};
try {
if(--R.GAS > 0) {
$z3900139002 = $f3900739008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3900739008,
"from":L[2246]});
}
} catch($e3899939000) {
if(R.isCont($e3899939000)) {
var $ss3900339004 = {"from":L[2246],
"go":function(anf_arg248239009) {
return $Hanf_arg924739010(anf_arg248239009,_plus55);
}};
$e3899939000.stack[R.EXN_STACKHEIGHT++] = $ss3900339004;
}
if(R.isPyretException($e3899939000)) {
$e3899939000.pyretStack.push(L[2246]);
}
throw $e3899939000;
}
var $ret3900539006 = $Hanf_arg924739010($z3900139002,_plus55);
++R.GAS;
return $ret3900539006;
};
var $Hanf_arg924739010 = function(anf_arg248239009,_plus55) {
var $z3901339014 = D;
var $f3901939020 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg248239009,(")")):R.ffi.throwNonFunApp(L[2246],_plus55,[anf_arg248239009,(")")]);
};
try {
if(--R.GAS > 0) {
$z3901339014 = $f3901939020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3901939020,
"from":L[2246]});
}
} catch($e3901139012) {
if(R.isCont($e3901139012)) {
var $ss3901539016 = {"from":L[2246],
"go":function(anf_arg248339021) {
return $Hanf_arg924639022(anf_arg248339021,_plus55);
}};
$e3901139012.stack[R.EXN_STACKHEIGHT++] = $ss3901539016;
}
if(R.isPyretException($e3901139012)) {
$e3901139012.pyretStack.push(L[2246]);
}
throw $e3901139012;
}
var $ret3901739018 = $Hanf_arg924639022($z3901339014,_plus55);
++R.GAS;
return $ret3901739018;
};
var $Hanf_arg924639022 = function(anf_arg248339021,_plus55) {
var $z3902539026 = D;
var $f3903139032 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg248339021):R.ffi.throwNonFunApp(L[2246],_plus55,[("("),anf_arg248339021]);
};
try {
if(--R.GAS > 0) {
$z3902539026 = $f3903139032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3903139032,
"from":L[2246]});
}
} catch($e3902339024) {
if(R.isCont($e3902339024)) {
var $ss3902739028 = {"from":L[2246],
"go":function(anf_arg248439033) {
return $Hanf_arg924539034(anf_arg248439033,_plus55);
}};
$e3902339024.stack[R.EXN_STACKHEIGHT++] = $ss3902739028;
}
if(R.isPyretException($e3902339024)) {
$e3902339024.pyretStack.push(L[2246]);
}
throw $e3902339024;
}
var $ret3902939030 = $Hanf_arg924539034($z3902539026,_plus55);
++R.GAS;
return $ret3902939030;
};
var $Hanf_arg924539034 = function(anf_arg248439033,_plus55) {
var $z3903739038 = D;
var $f3904339044 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-op"),anf_arg248439033):R.ffi.throwNonFunApp(L[2246],_plus55,[("s-op"),anf_arg248439033]);
};
try {
if(--R.GAS > 0) {
$z3903739038 = $f3904339044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3904339044,
"from":L[2246]});
}
} catch($e3903539036) {
if(R.isCont($e3903539036)) {
var $ss3903939040 = {"from":L[2246],
"go":function(ann_DASH_check_DASH_temp246839045) {
return $Hann_DASH_check_DASH_temp924439046(ann_DASH_check_DASH_temp246839045);
}};
$e3903539036.stack[R.EXN_STACKHEIGHT++] = $ss3903939040;
}
if(R.isPyretException($e3903539036)) {
$e3903539036.pyretStack.push(L[2246]);
}
throw $e3903539036;
}
var $ret3904139042 = $Hann_DASH_check_DASH_temp924439046($z3903739038);
++R.GAS;
return $ret3904139042;
};
var $Hann_DASH_check_DASH_temp924439046 = function(ann_DASH_check_DASH_temp246839045) {
return ann_DASH_check_DASH_temp246839045;
};
var $Hcont_tail_arg924215022 = function(cont_tail_arg246515020,if_helper245415021) {
if(--R.GAS > 0) {
$z3904739048 = R.isFunction(if_helper245415021)?if_helper245415021.app(cont_tail_arg246515020):R.ffi.throwNonFunApp(L[2246],if_helper245415021,[cont_tail_arg246515020]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper245415021)?if_helper245415021.app(cont_tail_arg246515020):R.ffi.throwNonFunApp(L[2246],if_helper245415021,[cont_tail_arg246515020]);
},
"from":L[2246]});
}
++R.GAS;
return $z3904739048;
};
var $Hcont_tail_arg924315037 = function(cont_tail_arg245915036,if_helper245415021) {
if(--R.GAS > 0) {
$z3904939050 = R.isFunction(if_helper245415021)?if_helper245415021.app(cont_tail_arg245915036):R.ffi.throwNonFunApp(L[2246],if_helper245415021,[cont_tail_arg245915036]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper245415021)?if_helper245415021.app(cont_tail_arg245915036):R.ffi.throwNonFunApp(L[2246],if_helper245415021,[cont_tail_arg245915036]);
},
"from":L[2246]});
}
++R.GAS;
return $z3904939050;
};
var $Hanf_arg924115057 = function(anf_arg242815055,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55) {
var anf_fun242939063 = G(PP170,"nest",L[4500]);
var anf_bracket243039065 = G(self79215056,"body",L[4499]);
var anf_fun243139061 = G(anf_bracket243039065,"tosource",L[4498]);
var $z3905339054 = D;
var $f3905939060 = function(_) {
return R.isFunction(anf_fun243139061)?anf_fun243139061.app():R.ffi.throwNonFunApp(L[4497],anf_fun243139061,[]);
};
try {
if(--R.GAS > 0) {
$z3905339054 = $f3905939060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3905939060,
"from":L[4497]});
}
} catch($e3905139052) {
if(R.isCont($e3905139052)) {
var $ss3905539056 = {"from":L[4497],
"go":function(anf_arg243239062) {
return $Hanf_arg924039064(anf_arg243239062,INDENT118169,PP170,anf_arg242815055,anf_fun242939063,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
}};
$e3905139052.stack[R.EXN_STACKHEIGHT++] = $ss3905539056;
}
if(R.isPyretException($e3905139052)) {
$e3905139052.pyretStack.push(L[4497]);
}
throw $e3905139052;
}
var $ret3905739058 = $Hanf_arg924039064($z3905339054,INDENT118169,PP170,anf_arg242815055,anf_fun242939063,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
++R.GAS;
return $ret3905739058;
};
var $Hanf_arg924039064 = function(anf_arg243239062,INDENT118169,PP170,anf_arg242815055,anf_fun242939063,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55) {
var $z3906839069 = D;
var $f3907439075 = function(_) {
return R.isFunction(anf_fun242939063)?anf_fun242939063.app(INDENT118169,anf_arg243239062):R.ffi.throwNonFunApp(L[4501],anf_fun242939063,[INDENT118169,anf_arg243239062]);
};
try {
if(--R.GAS > 0) {
$z3906839069 = $f3907439075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3907439075,
"from":L[4501]});
}
} catch($e3906639067) {
if(R.isCont($e3906639067)) {
var $ss3907039071 = {"from":L[4501],
"go":function(anf_arg243339076) {
return $Hanf_arg923939077(anf_arg243339076,INDENT118169,PP170,anf_arg242815055,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
}};
$e3906639067.stack[R.EXN_STACKHEIGHT++] = $ss3907039071;
}
if(R.isPyretException($e3906639067)) {
$e3906639067.pyretStack.push(L[4501]);
}
throw $e3906639067;
}
var $ret3907239073 = $Hanf_arg923939077($z3906839069,INDENT118169,PP170,anf_arg242815055,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
++R.GAS;
return $ret3907239073;
};
var $Hanf_arg923939077 = function(anf_arg243339076,INDENT118169,PP170,anf_arg242815055,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55) {
var $z3908039081 = D;
var $f3908639087 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg242815055,anf_arg243339076):R.ffi.throwNonFunApp(L[2799],_plus55,[anf_arg242815055,anf_arg243339076]);
};
try {
if(--R.GAS > 0) {
$z3908039081 = $f3908639087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3908639087,
"from":L[2799]});
}
} catch($e3907839079) {
if(R.isCont($e3907839079)) {
var $ss3908239083 = {"from":L[2799],
"go":function(anf_arg243439088) {
return $Hanf_arg923839089(anf_arg243439088,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
}};
$e3907839079.stack[R.EXN_STACKHEIGHT++] = $ss3908239083;
}
if(R.isPyretException($e3907839079)) {
$e3907839079.pyretStack.push(L[2799]);
}
throw $e3907839079;
}
var $ret3908439085 = $Hanf_arg923839089($z3908039081,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
++R.GAS;
return $ret3908439085;
};
var $Hanf_arg923839089 = function(anf_arg243439088,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55) {
var $z3909239093 = D;
var $f3909839099 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg243439088,break_DASH_one119168):R.ffi.throwNonFunApp(L[4502],_plus55,[anf_arg243439088,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3909239093 = $f3909839099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3909839099,
"from":L[4502]});
}
} catch($e3909039091) {
if(R.isCont($e3909039091)) {
var $ss3909439095 = {"from":L[4502],
"go":function(_try79339100) {
return $H_try923739101(_try79339100,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
}};
$e3909039091.stack[R.EXN_STACKHEIGHT++] = $ss3909439095;
}
if(R.isPyretException($e3909039091)) {
$e3909039091.pyretStack.push(L[4502]);
}
throw $e3909039091;
}
var $ret3909639097 = $H_try923739101($z3909239093,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
++R.GAS;
return $ret3909639097;
};
var $H_try923739101 = function(_try79339100,INDENT118169,PP170,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55) {
var anf_fun243539114 = G(PP170,"parens",L[4506]);
var anf_bracket243639116 = G(self79215056,"id",L[4505]);
var anf_fun243739112 = G(anf_bracket243639116,"tosource",L[4504]);
var $z3910439105 = D;
var $f3911039111 = function(_) {
return R.isFunction(anf_fun243739112)?anf_fun243739112.app():R.ffi.throwNonFunApp(L[4503],anf_fun243739112,[]);
};
try {
if(--R.GAS > 0) {
$z3910439105 = $f3911039111();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3911039111,
"from":L[4503]});
}
} catch($e3910239103) {
if(R.isCont($e3910239103)) {
var $ss3910639107 = {"from":L[4503],
"go":function(anf_arg243839113) {
return $Hanf_arg923639115(anf_arg243839113,INDENT118169,PP170,_try79339100,anf_fun243539114,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
}};
$e3910239103.stack[R.EXN_STACKHEIGHT++] = $ss3910639107;
}
if(R.isPyretException($e3910239103)) {
$e3910239103.pyretStack.push(L[4503]);
}
throw $e3910239103;
}
var $ret3910839109 = $Hanf_arg923639115($z3910439105,INDENT118169,PP170,_try79339100,anf_fun243539114,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
++R.GAS;
return $ret3910839109;
};
var $Hanf_arg923639115 = function(anf_arg243839113,INDENT118169,PP170,_try79339100,anf_fun243539114,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55) {
var $z3911939120 = D;
var $f3912539126 = function(_) {
return R.isFunction(anf_fun243539114)?anf_fun243539114.app(anf_arg243839113):R.ffi.throwNonFunApp(L[4507],anf_fun243539114,[anf_arg243839113]);
};
try {
if(--R.GAS > 0) {
$z3911939120 = $f3912539126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3912539126,
"from":L[4507]});
}
} catch($e3911739118) {
if(R.isCont($e3911739118)) {
var $ss3912139122 = {"from":L[4507],
"go":function(anf_arg243939127) {
return $Hanf_arg923539128(anf_arg243939127,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
}};
$e3911739118.stack[R.EXN_STACKHEIGHT++] = $ss3912139122;
}
if(R.isPyretException($e3911739118)) {
$e3911739118.pyretStack.push(L[4507]);
}
throw $e3911739118;
}
var $ret3912339124 = $Hanf_arg923539128($z3911939120,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55);
++R.GAS;
return $ret3912339124;
};
var $Hanf_arg923539128 = function(anf_arg243939127,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,str_DASH_except149559,_plus55) {
var $z3913139132 = D;
var $f3913739138 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_except149559,anf_arg243939127):R.ffi.throwNonFunApp(L[4508],_plus55,[str_DASH_except149559,anf_arg243939127]);
};
try {
if(--R.GAS > 0) {
$z3913139132 = $f3913739138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3913739138,
"from":L[4508]});
}
} catch($e3912939130) {
if(R.isCont($e3912939130)) {
var $ss3913339134 = {"from":L[4508],
"go":function(anf_arg244039139) {
return $Hanf_arg923439140(anf_arg244039139,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e3912939130.stack[R.EXN_STACKHEIGHT++] = $ss3913339134;
}
if(R.isPyretException($e3912939130)) {
$e3912939130.pyretStack.push(L[4508]);
}
throw $e3912939130;
}
var $ret3913539136 = $Hanf_arg923439140($z3913139132,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3913539136;
};
var $Hanf_arg923439140 = function(anf_arg244039139,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z3914339144 = D;
var $f3914939150 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg244039139,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4508],_plus55,[anf_arg244039139,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z3914339144 = $f3914939150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3914939150,
"from":L[4508]});
}
} catch($e3914139142) {
if(R.isCont($e3914139142)) {
var $ss3914539146 = {"from":L[4508],
"go":function(anf_arg244139151) {
return $Hanf_arg923339152(anf_arg244139151,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_end148546,_plus55);
}};
$e3914139142.stack[R.EXN_STACKHEIGHT++] = $ss3914539146;
}
if(R.isPyretException($e3914139142)) {
$e3914139142.pyretStack.push(L[4508]);
}
throw $e3914139142;
}
var $ret3914739148 = $Hanf_arg923339152($z3914339144,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3914739148;
};
var $Hanf_arg923339152 = function(anf_arg244139151,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_end148546,_plus55) {
var $z3915539156 = D;
var $f3916139162 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg244139151,break_DASH_one119168):R.ffi.throwNonFunApp(L[4508],_plus55,[anf_arg244139151,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3915539156 = $f3916139162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3916139162,
"from":L[4508]});
}
} catch($e3915339154) {
if(R.isCont($e3915339154)) {
var $ss3915739158 = {"from":L[4508],
"go":function(anf_arg244239163) {
return $Hanf_arg923239164(anf_arg244239163,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_end148546,_plus55);
}};
$e3915339154.stack[R.EXN_STACKHEIGHT++] = $ss3915739158;
}
if(R.isPyretException($e3915339154)) {
$e3915339154.pyretStack.push(L[4508]);
}
throw $e3915339154;
}
var $ret3915939160 = $Hanf_arg923239164($z3915539156,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3915939160;
};
var $Hanf_arg923239164 = function(anf_arg244239163,INDENT118169,PP170,_try79339100,break_DASH_one119168,self79215056,str_DASH_end148546,_plus55) {
var anf_fun244339177 = G(PP170,"nest",L[4512]);
var anf_bracket244439179 = G(self79215056,"_except",L[4511]);
var anf_fun244539175 = G(anf_bracket244439179,"tosource",L[4510]);
var $z3916739168 = D;
var $f3917339174 = function(_) {
return R.isFunction(anf_fun244539175)?anf_fun244539175.app():R.ffi.throwNonFunApp(L[4509],anf_fun244539175,[]);
};
try {
if(--R.GAS > 0) {
$z3916739168 = $f3917339174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3917339174,
"from":L[4509]});
}
} catch($e3916539166) {
if(R.isCont($e3916539166)) {
var $ss3916939170 = {"from":L[4509],
"go":function(anf_arg244639176) {
return $Hanf_arg923139178(anf_arg244639176,INDENT118169,PP170,_try79339100,anf_arg244239163,anf_fun244339177,break_DASH_one119168,str_DASH_end148546,_plus55);
}};
$e3916539166.stack[R.EXN_STACKHEIGHT++] = $ss3916939170;
}
if(R.isPyretException($e3916539166)) {
$e3916539166.pyretStack.push(L[4509]);
}
throw $e3916539166;
}
var $ret3917139172 = $Hanf_arg923139178($z3916739168,INDENT118169,PP170,_try79339100,anf_arg244239163,anf_fun244339177,break_DASH_one119168,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3917139172;
};
var $Hanf_arg923139178 = function(anf_arg244639176,INDENT118169,PP170,_try79339100,anf_arg244239163,anf_fun244339177,break_DASH_one119168,str_DASH_end148546,_plus55) {
var $z3918239183 = D;
var $f3918839189 = function(_) {
return R.isFunction(anf_fun244339177)?anf_fun244339177.app(INDENT118169,anf_arg244639176):R.ffi.throwNonFunApp(L[4513],anf_fun244339177,[INDENT118169,anf_arg244639176]);
};
try {
if(--R.GAS > 0) {
$z3918239183 = $f3918839189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3918839189,
"from":L[4513]});
}
} catch($e3918039181) {
if(R.isCont($e3918039181)) {
var $ss3918439185 = {"from":L[4513],
"go":function(anf_arg244739190) {
return $Hanf_arg923039191(anf_arg244739190,PP170,_try79339100,anf_arg244239163,break_DASH_one119168,str_DASH_end148546,_plus55);
}};
$e3918039181.stack[R.EXN_STACKHEIGHT++] = $ss3918439185;
}
if(R.isPyretException($e3918039181)) {
$e3918039181.pyretStack.push(L[4513]);
}
throw $e3918039181;
}
var $ret3918639187 = $Hanf_arg923039191($z3918239183,PP170,_try79339100,anf_arg244239163,break_DASH_one119168,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3918639187;
};
var $Hanf_arg923039191 = function(anf_arg244739190,PP170,_try79339100,anf_arg244239163,break_DASH_one119168,str_DASH_end148546,_plus55) {
var $z3919439195 = D;
var $f3920039201 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg244239163,anf_arg244739190):R.ffi.throwNonFunApp(L[4508],_plus55,[anf_arg244239163,anf_arg244739190]);
};
try {
if(--R.GAS > 0) {
$z3919439195 = $f3920039201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3920039201,
"from":L[4508]});
}
} catch($e3919239193) {
if(R.isCont($e3919239193)) {
var $ss3919639197 = {"from":L[4508],
"go":function(anf_arg244839202) {
return $Hanf_arg922939203(anf_arg244839202,PP170,_try79339100,break_DASH_one119168,str_DASH_end148546,_plus55);
}};
$e3919239193.stack[R.EXN_STACKHEIGHT++] = $ss3919639197;
}
if(R.isPyretException($e3919239193)) {
$e3919239193.pyretStack.push(L[4508]);
}
throw $e3919239193;
}
var $ret3919839199 = $Hanf_arg922939203($z3919439195,PP170,_try79339100,break_DASH_one119168,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3919839199;
};
var $Hanf_arg922939203 = function(anf_arg244839202,PP170,_try79339100,break_DASH_one119168,str_DASH_end148546,_plus55) {
var $z3920639207 = D;
var $f3921239213 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg244839202,break_DASH_one119168):R.ffi.throwNonFunApp(L[4514],_plus55,[anf_arg244839202,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3920639207 = $f3921239213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3921239213,
"from":L[4514]});
}
} catch($e3920439205) {
if(R.isCont($e3920439205)) {
var $ss3920839209 = {"from":L[4514],
"go":function(_except79439214) {
return $H_except922839215(_except79439214,PP170,_try79339100,str_DASH_end148546,_plus55);
}};
$e3920439205.stack[R.EXN_STACKHEIGHT++] = $ss3920839209;
}
if(R.isPyretException($e3920439205)) {
$e3920439205.pyretStack.push(L[4514]);
}
throw $e3920439205;
}
var $ret3921039211 = $H_except922839215($z3920639207,PP170,_try79339100,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3921039211;
};
var $H_except922839215 = function(_except79439214,PP170,_try79339100,str_DASH_end148546,_plus55) {
var anf_fun244939227 = G(PP170,"group",L[4516]);
var $z3921839219 = D;
var $f3922439225 = function(_) {
return R.isFunction(_plus55)?_plus55.app(_try79339100,_except79439214):R.ffi.throwNonFunApp(L[4515],_plus55,[_try79339100,_except79439214]);
};
try {
if(--R.GAS > 0) {
$z3921839219 = $f3922439225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3922439225,
"from":L[4515]});
}
} catch($e3921639217) {
if(R.isCont($e3921639217)) {
var $ss3922039221 = {"from":L[4515],
"go":function(anf_arg245039226) {
return $Hanf_arg922739228(anf_arg245039226,anf_fun244939227,str_DASH_end148546,_plus55);
}};
$e3921639217.stack[R.EXN_STACKHEIGHT++] = $ss3922039221;
}
if(R.isPyretException($e3921639217)) {
$e3921639217.pyretStack.push(L[4515]);
}
throw $e3921639217;
}
var $ret3922239223 = $Hanf_arg922739228($z3921839219,anf_fun244939227,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3922239223;
};
var $Hanf_arg922739228 = function(anf_arg245039226,anf_fun244939227,str_DASH_end148546,_plus55) {
var $z3923139232 = D;
var $f3923739238 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg245039226,str_DASH_end148546):R.ffi.throwNonFunApp(L[4515],_plus55,[anf_arg245039226,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z3923139232 = $f3923739238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3923739238,
"from":L[4515]});
}
} catch($e3922939230) {
if(R.isCont($e3922939230)) {
var $ss3923339234 = {"from":L[4515],
"go":function(anf_arg245139239) {
return $Hanf_arg922639240(anf_arg245139239,anf_fun244939227);
}};
$e3922939230.stack[R.EXN_STACKHEIGHT++] = $ss3923339234;
}
if(R.isPyretException($e3922939230)) {
$e3922939230.pyretStack.push(L[4515]);
}
throw $e3922939230;
}
var $ret3923539236 = $Hanf_arg922639240($z3923139232,anf_fun244939227);
++R.GAS;
return $ret3923539236;
};
var $Hanf_arg922639240 = function(anf_arg245139239,anf_fun244939227) {
var $z3924339244 = D;
var $f3924939250 = function(_) {
return R.isFunction(anf_fun244939227)?anf_fun244939227.app(anf_arg245139239):R.ffi.throwNonFunApp(L[2800],anf_fun244939227,[anf_arg245139239]);
};
try {
if(--R.GAS > 0) {
$z3924339244 = $f3924939250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3924939250,
"from":L[2800]});
}
} catch($e3924139242) {
if(R.isCont($e3924139242)) {
var $ss3924539246 = {"from":L[2800],
"go":function(ann_DASH_check_DASH_temp242739251) {
return $Hann_DASH_check_DASH_temp922539252(ann_DASH_check_DASH_temp242739251);
}};
$e3924139242.stack[R.EXN_STACKHEIGHT++] = $ss3924539246;
}
if(R.isPyretException($e3924139242)) {
$e3924139242.pyretStack.push(L[2800]);
}
throw $e3924139242;
}
var $ret3924739248 = $Hann_DASH_check_DASH_temp922539252($z3924339244);
++R.GAS;
return $ret3924739248;
};
var $Hann_DASH_check_DASH_temp922539252 = function(ann_DASH_check_DASH_temp242739251) {
return ann_DASH_check_DASH_temp242739251;
};
var $Hanf_arg922415073 = function(anf_arg240915071,self30515072,_plus55,torepr65) {
var anf_arg241039263 = G(self30515072,"body",L[2247]);
var $z3925539256 = D;
var $f3926139262 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg241039263):R.ffi.throwNonFunApp(L[2247],torepr65,[anf_arg241039263]);
};
try {
if(--R.GAS > 0) {
$z3925539256 = $f3926139262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3926139262,
"from":L[2247]});
}
} catch($e3925339254) {
if(R.isCont($e3925339254)) {
var $ss3925739258 = {"from":L[2247],
"go":function(anf_arg241139264) {
return $Hanf_arg922339265(anf_arg241139264,anf_arg240915071,self30515072,_plus55,torepr65);
}};
$e3925339254.stack[R.EXN_STACKHEIGHT++] = $ss3925739258;
}
if(R.isPyretException($e3925339254)) {
$e3925339254.pyretStack.push(L[2247]);
}
throw $e3925339254;
}
var $ret3925939260 = $Hanf_arg922339265($z3925539256,anf_arg240915071,self30515072,_plus55,torepr65);
++R.GAS;
return $ret3925939260;
};
var $Hanf_arg922339265 = function(anf_arg241139264,anf_arg240915071,self30515072,_plus55,torepr65) {
var $z3926839269 = D;
var $f3927439275 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg241139264):R.ffi.throwNonFunApp(L[2247],_plus55,[(", "),anf_arg241139264]);
};
try {
if(--R.GAS > 0) {
$z3926839269 = $f3927439275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3927439275,
"from":L[2247]});
}
} catch($e3926639267) {
if(R.isCont($e3926639267)) {
var $ss3927039271 = {"from":L[2247],
"go":function(anf_arg241239276) {
return $Hanf_arg922239277(anf_arg241239276,anf_arg240915071,self30515072,_plus55,torepr65);
}};
$e3926639267.stack[R.EXN_STACKHEIGHT++] = $ss3927039271;
}
if(R.isPyretException($e3926639267)) {
$e3926639267.pyretStack.push(L[2247]);
}
throw $e3926639267;
}
var $ret3927239273 = $Hanf_arg922239277($z3926839269,anf_arg240915071,self30515072,_plus55,torepr65);
++R.GAS;
return $ret3927239273;
};
var $Hanf_arg922239277 = function(anf_arg241239276,anf_arg240915071,self30515072,_plus55,torepr65) {
var $z3928039281 = D;
var $f3928639287 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg240915071,anf_arg241239276):R.ffi.throwNonFunApp(L[2247],_plus55,[anf_arg240915071,anf_arg241239276]);
};
try {
if(--R.GAS > 0) {
$z3928039281 = $f3928639287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3928639287,
"from":L[2247]});
}
} catch($e3927839279) {
if(R.isCont($e3927839279)) {
var $ss3928239283 = {"from":L[2247],
"go":function(anf_arg241339288) {
return $Hanf_arg922139289(anf_arg241339288,self30515072,_plus55,torepr65);
}};
$e3927839279.stack[R.EXN_STACKHEIGHT++] = $ss3928239283;
}
if(R.isPyretException($e3927839279)) {
$e3927839279.pyretStack.push(L[2247]);
}
throw $e3927839279;
}
var $ret3928439285 = $Hanf_arg922139289($z3928039281,self30515072,_plus55,torepr65);
++R.GAS;
return $ret3928439285;
};
var $Hanf_arg922139289 = function(anf_arg241339288,self30515072,_plus55,torepr65) {
var anf_arg241439300 = G(self30515072,"id",L[2247]);
var $z3929239293 = D;
var $f3929839299 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg241439300):R.ffi.throwNonFunApp(L[2247],torepr65,[anf_arg241439300]);
};
try {
if(--R.GAS > 0) {
$z3929239293 = $f3929839299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3929839299,
"from":L[2247]});
}
} catch($e3929039291) {
if(R.isCont($e3929039291)) {
var $ss3929439295 = {"from":L[2247],
"go":function(anf_arg241539301) {
return $Hanf_arg922039302(anf_arg241539301,anf_arg241339288,self30515072,_plus55,torepr65);
}};
$e3929039291.stack[R.EXN_STACKHEIGHT++] = $ss3929439295;
}
if(R.isPyretException($e3929039291)) {
$e3929039291.pyretStack.push(L[2247]);
}
throw $e3929039291;
}
var $ret3929639297 = $Hanf_arg922039302($z3929239293,anf_arg241339288,self30515072,_plus55,torepr65);
++R.GAS;
return $ret3929639297;
};
var $Hanf_arg922039302 = function(anf_arg241539301,anf_arg241339288,self30515072,_plus55,torepr65) {
var $z3930539306 = D;
var $f3931139312 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg241539301):R.ffi.throwNonFunApp(L[2247],_plus55,[(", "),anf_arg241539301]);
};
try {
if(--R.GAS > 0) {
$z3930539306 = $f3931139312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3931139312,
"from":L[2247]});
}
} catch($e3930339304) {
if(R.isCont($e3930339304)) {
var $ss3930739308 = {"from":L[2247],
"go":function(anf_arg241639313) {
return $Hanf_arg921939314(anf_arg241639313,anf_arg241339288,self30515072,_plus55,torepr65);
}};
$e3930339304.stack[R.EXN_STACKHEIGHT++] = $ss3930739308;
}
if(R.isPyretException($e3930339304)) {
$e3930339304.pyretStack.push(L[2247]);
}
throw $e3930339304;
}
var $ret3930939310 = $Hanf_arg921939314($z3930539306,anf_arg241339288,self30515072,_plus55,torepr65);
++R.GAS;
return $ret3930939310;
};
var $Hanf_arg921939314 = function(anf_arg241639313,anf_arg241339288,self30515072,_plus55,torepr65) {
var $z3931739318 = D;
var $f3932339324 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg241339288,anf_arg241639313):R.ffi.throwNonFunApp(L[2247],_plus55,[anf_arg241339288,anf_arg241639313]);
};
try {
if(--R.GAS > 0) {
$z3931739318 = $f3932339324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3932339324,
"from":L[2247]});
}
} catch($e3931539316) {
if(R.isCont($e3931539316)) {
var $ss3931939320 = {"from":L[2247],
"go":function(anf_arg241739325) {
return $Hanf_arg921839326(anf_arg241739325,self30515072,_plus55,torepr65);
}};
$e3931539316.stack[R.EXN_STACKHEIGHT++] = $ss3931939320;
}
if(R.isPyretException($e3931539316)) {
$e3931539316.pyretStack.push(L[2247]);
}
throw $e3931539316;
}
var $ret3932139322 = $Hanf_arg921839326($z3931739318,self30515072,_plus55,torepr65);
++R.GAS;
return $ret3932139322;
};
var $Hanf_arg921839326 = function(anf_arg241739325,self30515072,_plus55,torepr65) {
var anf_arg241839337 = G(self30515072,"_except",L[2247]);
var $z3932939330 = D;
var $f3933539336 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg241839337):R.ffi.throwNonFunApp(L[2247],torepr65,[anf_arg241839337]);
};
try {
if(--R.GAS > 0) {
$z3932939330 = $f3933539336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3933539336,
"from":L[2247]});
}
} catch($e3932739328) {
if(R.isCont($e3932739328)) {
var $ss3933139332 = {"from":L[2247],
"go":function(anf_arg241939338) {
return $Hanf_arg921739339(anf_arg241939338,anf_arg241739325,_plus55);
}};
$e3932739328.stack[R.EXN_STACKHEIGHT++] = $ss3933139332;
}
if(R.isPyretException($e3932739328)) {
$e3932739328.pyretStack.push(L[2247]);
}
throw $e3932739328;
}
var $ret3933339334 = $Hanf_arg921739339($z3932939330,anf_arg241739325,_plus55);
++R.GAS;
return $ret3933339334;
};
var $Hanf_arg921739339 = function(anf_arg241939338,anf_arg241739325,_plus55) {
var $z3934239343 = D;
var $f3934839349 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg241939338):R.ffi.throwNonFunApp(L[2247],_plus55,[(", "),anf_arg241939338]);
};
try {
if(--R.GAS > 0) {
$z3934239343 = $f3934839349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3934839349,
"from":L[2247]});
}
} catch($e3934039341) {
if(R.isCont($e3934039341)) {
var $ss3934439345 = {"from":L[2247],
"go":function(anf_arg242039350) {
return $Hanf_arg921639351(anf_arg242039350,anf_arg241739325,_plus55);
}};
$e3934039341.stack[R.EXN_STACKHEIGHT++] = $ss3934439345;
}
if(R.isPyretException($e3934039341)) {
$e3934039341.pyretStack.push(L[2247]);
}
throw $e3934039341;
}
var $ret3934639347 = $Hanf_arg921639351($z3934239343,anf_arg241739325,_plus55);
++R.GAS;
return $ret3934639347;
};
var $Hanf_arg921639351 = function(anf_arg242039350,anf_arg241739325,_plus55) {
var $z3935439355 = D;
var $f3936039361 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg241739325,anf_arg242039350):R.ffi.throwNonFunApp(L[2247],_plus55,[anf_arg241739325,anf_arg242039350]);
};
try {
if(--R.GAS > 0) {
$z3935439355 = $f3936039361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3936039361,
"from":L[2247]});
}
} catch($e3935239353) {
if(R.isCont($e3935239353)) {
var $ss3935639357 = {"from":L[2247],
"go":function(anf_arg242139362) {
return $Hanf_arg921539363(anf_arg242139362,_plus55);
}};
$e3935239353.stack[R.EXN_STACKHEIGHT++] = $ss3935639357;
}
if(R.isPyretException($e3935239353)) {
$e3935239353.pyretStack.push(L[2247]);
}
throw $e3935239353;
}
var $ret3935839359 = $Hanf_arg921539363($z3935439355,_plus55);
++R.GAS;
return $ret3935839359;
};
var $Hanf_arg921539363 = function(anf_arg242139362,_plus55) {
var $z3936639367 = D;
var $f3937239373 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg242139362,(")")):R.ffi.throwNonFunApp(L[2247],_plus55,[anf_arg242139362,(")")]);
};
try {
if(--R.GAS > 0) {
$z3936639367 = $f3937239373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3937239373,
"from":L[2247]});
}
} catch($e3936439365) {
if(R.isCont($e3936439365)) {
var $ss3936839369 = {"from":L[2247],
"go":function(anf_arg242239374) {
return $Hanf_arg921439375(anf_arg242239374,_plus55);
}};
$e3936439365.stack[R.EXN_STACKHEIGHT++] = $ss3936839369;
}
if(R.isPyretException($e3936439365)) {
$e3936439365.pyretStack.push(L[2247]);
}
throw $e3936439365;
}
var $ret3937039371 = $Hanf_arg921439375($z3936639367,_plus55);
++R.GAS;
return $ret3937039371;
};
var $Hanf_arg921439375 = function(anf_arg242239374,_plus55) {
var $z3937839379 = D;
var $f3938439385 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg242239374):R.ffi.throwNonFunApp(L[2247],_plus55,[("("),anf_arg242239374]);
};
try {
if(--R.GAS > 0) {
$z3937839379 = $f3938439385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3938439385,
"from":L[2247]});
}
} catch($e3937639377) {
if(R.isCont($e3937639377)) {
var $ss3938039381 = {"from":L[2247],
"go":function(anf_arg242339386) {
return $Hanf_arg921339387(anf_arg242339386,_plus55);
}};
$e3937639377.stack[R.EXN_STACKHEIGHT++] = $ss3938039381;
}
if(R.isPyretException($e3937639377)) {
$e3937639377.pyretStack.push(L[2247]);
}
throw $e3937639377;
}
var $ret3938239383 = $Hanf_arg921339387($z3937839379,_plus55);
++R.GAS;
return $ret3938239383;
};
var $Hanf_arg921339387 = function(anf_arg242339386,_plus55) {
var $z3939039391 = D;
var $f3939639397 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-try"),anf_arg242339386):R.ffi.throwNonFunApp(L[2247],_plus55,[("s-try"),anf_arg242339386]);
};
try {
if(--R.GAS > 0) {
$z3939039391 = $f3939639397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3939639397,
"from":L[2247]});
}
} catch($e3938839389) {
if(R.isCont($e3938839389)) {
var $ss3939239393 = {"from":L[2247],
"go":function(ann_DASH_check_DASH_temp240739398) {
return $Hann_DASH_check_DASH_temp921239399(ann_DASH_check_DASH_temp240739398);
}};
$e3938839389.stack[R.EXN_STACKHEIGHT++] = $ss3939239393;
}
if(R.isPyretException($e3938839389)) {
$e3938839389.pyretStack.push(L[2247]);
}
throw $e3938839389;
}
var $ret3939439395 = $Hann_DASH_check_DASH_temp921239399($z3939039391);
++R.GAS;
return $ret3939439395;
};
var $Hann_DASH_check_DASH_temp921239399 = function(ann_DASH_check_DASH_temp240739398) {
return ann_DASH_check_DASH_temp240739398;
};
var $Hcont_tail_arg921015091 = function(cont_tail_arg240415089,if_helper239315090) {
if(--R.GAS > 0) {
$z3940039401 = R.isFunction(if_helper239315090)?if_helper239315090.app(cont_tail_arg240415089):R.ffi.throwNonFunApp(L[2247],if_helper239315090,[cont_tail_arg240415089]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper239315090)?if_helper239315090.app(cont_tail_arg240415089):R.ffi.throwNonFunApp(L[2247],if_helper239315090,[cont_tail_arg240415089]);
},
"from":L[2247]});
}
++R.GAS;
return $z3940039401;
};
var $Hcont_tail_arg921115106 = function(cont_tail_arg239815105,if_helper239315090) {
if(--R.GAS > 0) {
$z3940239403 = R.isFunction(if_helper239315090)?if_helper239315090.app(cont_tail_arg239815105):R.ffi.throwNonFunApp(L[2247],if_helper239315090,[cont_tail_arg239815105]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper239315090)?if_helper239315090.app(cont_tail_arg239815105):R.ffi.throwNonFunApp(L[2247],if_helper239315090,[cont_tail_arg239815105]);
},
"from":L[2247]});
}
++R.GAS;
return $z3940239403;
};
var $Hanf_arg920915128 = function(anf_arg236215125,INDENT118169,PP170,anf_fun235915126,break_DASH_one119168,self78315127,str_DASH_cases130312,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var $z3940639407 = D;
var $f3941239413 = function(_) {
return R.isFunction(anf_fun235915126)?anf_fun235915126.app(anf_arg236215125):R.ffi.throwNonFunApp(L[4517],anf_fun235915126,[anf_arg236215125]);
};
try {
if(--R.GAS > 0) {
$z3940639407 = $f3941239413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3941239413,
"from":L[4517]});
}
} catch($e3940439405) {
if(R.isCont($e3940439405)) {
var $ss3940839409 = {"from":L[4517],
"go":function(anf_arg236339414) {
return $Hanf_arg920839415(anf_arg236339414,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_cases130312,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3940439405.stack[R.EXN_STACKHEIGHT++] = $ss3940839409;
}
if(R.isPyretException($e3940439405)) {
$e3940439405.pyretStack.push(L[4517]);
}
throw $e3940439405;
}
var $ret3941039411 = $Hanf_arg920839415($z3940639407,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_cases130312,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3941039411;
};
var $Hanf_arg920839415 = function(anf_arg236339414,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_cases130312,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var $z3941839419 = D;
var $f3942439425 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_cases130312,anf_arg236339414):R.ffi.throwNonFunApp(L[4518],_plus55,[str_DASH_cases130312,anf_arg236339414]);
};
try {
if(--R.GAS > 0) {
$z3941839419 = $f3942439425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3942439425,
"from":L[4518]});
}
} catch($e3941639417) {
if(R.isCont($e3941639417)) {
var $ss3942039421 = {"from":L[4518],
"go":function(anf_arg236439426) {
return $Hanf_arg920739427(anf_arg236439426,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3941639417.stack[R.EXN_STACKHEIGHT++] = $ss3942039421;
}
if(R.isPyretException($e3941639417)) {
$e3941639417.pyretStack.push(L[4518]);
}
throw $e3941639417;
}
var $ret3942239423 = $Hanf_arg920739427($z3941839419,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3942239423;
};
var $Hanf_arg920739427 = function(anf_arg236439426,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var $z3943039431 = D;
var $f3943639437 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg236439426,break_DASH_one119168):R.ffi.throwNonFunApp(L[4518],_plus55,[anf_arg236439426,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3943039431 = $f3943639437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3943639437,
"from":L[4518]});
}
} catch($e3942839429) {
if(R.isCont($e3942839429)) {
var $ss3943239433 = {"from":L[4518],
"go":function(anf_arg236539438) {
return $Hanf_arg920639439(anf_arg236539438,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3942839429.stack[R.EXN_STACKHEIGHT++] = $ss3943239433;
}
if(R.isPyretException($e3942839429)) {
$e3942839429.pyretStack.push(L[4518]);
}
throw $e3942839429;
}
var $ret3943439435 = $Hanf_arg920639439($z3943039431,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3943439435;
};
var $Hanf_arg920639439 = function(anf_arg236539438,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var anf_bracket236639453 = G(self78315127,"val",L[4521]);
var anf_fun236739450 = G(anf_bracket236639453,"tosource",L[4520]);
var $z3944239443 = D;
var $f3944839449 = function(_) {
return R.isFunction(anf_fun236739450)?anf_fun236739450.app():R.ffi.throwNonFunApp(L[4519],anf_fun236739450,[]);
};
try {
if(--R.GAS > 0) {
$z3944239443 = $f3944839449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3944839449,
"from":L[4519]});
}
} catch($e3944039441) {
if(R.isCont($e3944039441)) {
var $ss3944439445 = {"from":L[4519],
"go":function(anf_arg236839451) {
return $Hanf_arg920539452(anf_arg236839451,INDENT118169,PP170,anf_arg236539438,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3944039441.stack[R.EXN_STACKHEIGHT++] = $ss3944439445;
}
if(R.isPyretException($e3944039441)) {
$e3944039441.pyretStack.push(L[4519]);
}
throw $e3944039441;
}
var $ret3944639447 = $Hanf_arg920539452($z3944239443,INDENT118169,PP170,anf_arg236539438,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3944639447;
};
var $Hanf_arg920539452 = function(anf_arg236839451,INDENT118169,PP170,anf_arg236539438,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var $z3945639457 = D;
var $f3946239463 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg236539438,anf_arg236839451):R.ffi.throwNonFunApp(L[4518],_plus55,[anf_arg236539438,anf_arg236839451]);
};
try {
if(--R.GAS > 0) {
$z3945639457 = $f3946239463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3946239463,
"from":L[4518]});
}
} catch($e3945439455) {
if(R.isCont($e3945439455)) {
var $ss3945839459 = {"from":L[4518],
"go":function(anf_arg236939464) {
return $Hanf_arg920439465(anf_arg236939464,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3945439455.stack[R.EXN_STACKHEIGHT++] = $ss3945839459;
}
if(R.isPyretException($e3945439455)) {
$e3945439455.pyretStack.push(L[4518]);
}
throw $e3945439455;
}
var $ret3946039461 = $Hanf_arg920439465($z3945639457,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3946039461;
};
var $Hanf_arg920439465 = function(anf_arg236939464,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_colon134364,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var $z3946839469 = D;
var $f3947439475 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg236939464,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4522],_plus55,[anf_arg236939464,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z3946839469 = $f3947439475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3947439475,
"from":L[4522]});
}
} catch($e3946639467) {
if(R.isCont($e3946639467)) {
var $ss3947039471 = {"from":L[4522],
"go":function(header78439476) {
return $Hheader920339477(header78439476,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3946639467.stack[R.EXN_STACKHEIGHT++] = $ss3947039471;
}
if(R.isPyretException($e3946639467)) {
$e3946639467.pyretStack.push(L[4522]);
}
throw $e3946639467;
}
var $ret3947239473 = $Hheader920339477($z3946839469,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3947239473;
};
var $Hheader920339477 = function(header78439476,INDENT118169,PP170,break_DASH_one119168,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var anf_fun237039491 = G(PP170,"separate",L[4530]);
var anf_bracket237139508 = G(self78315127,"branches",L[4529]);
var anf_fun237239488 = G(anf_bracket237139508,"map",L[4528]);
var anf_arg237739489 = R.makeFunction(function(b78639493) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4524],1,arguments);
}
var anf_fun237439506 = G(PP170,"group",L[4527]);
var anf_fun237539504 = G(b78639493,"tosource",L[4526]);
var $z3949639497 = D;
var $f3950239503 = function(_) {
return R.isFunction(anf_fun237539504)?anf_fun237539504.app():R.ffi.throwNonFunApp(L[4525],anf_fun237539504,[]);
};
try {
if(--R.GAS > 0) {
$z3949639497 = $f3950239503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3950239503,
"from":L[4525]});
}
} catch($e3949439495) {
if(R.isCont($e3949439495)) {
var $ss3949839499 = {"from":L[4525],
"go":function(anf_arg237639505) {
return $Hanf_arg919239507(anf_arg237639505,anf_fun237439506);
}};
$e3949439495.stack[R.EXN_STACKHEIGHT++] = $ss3949839499;
}
if(R.isPyretException($e3949439495)) {
$e3949439495.pyretStack.push(L[4525]);
}
throw $e3949439495;
}
var $ret3950039501 = $Hanf_arg919239507($z3949639497,anf_fun237439506);
++R.GAS;
return $ret3950039501;
});
var $z3948039481 = D;
var $f3948639487 = function(_) {
return R.isFunction(anf_fun237239488)?anf_fun237239488.app(anf_arg237739489):R.ffi.throwNonFunApp(L[4523],anf_fun237239488,[anf_arg237739489]);
};
try {
if(--R.GAS > 0) {
$z3948039481 = $f3948639487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3948639487,
"from":L[4523]});
}
} catch($e3947839479) {
if(R.isCont($e3947839479)) {
var $ss3948239483 = {"from":L[4523],
"go":function(anf_arg237839490) {
return $Hanf_arg920239492(anf_arg237839490,INDENT118169,PP170,anf_fun237039491,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3947839479.stack[R.EXN_STACKHEIGHT++] = $ss3948239483;
}
if(R.isPyretException($e3947839479)) {
$e3947839479.pyretStack.push(L[4523]);
}
throw $e3947839479;
}
var $ret3948439485 = $Hanf_arg920239492($z3948039481,INDENT118169,PP170,anf_fun237039491,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3948439485;
};
var $Hanf_arg920239492 = function(anf_arg237839490,INDENT118169,PP170,anf_fun237039491,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var $z3951139512 = D;
var $f3951739518 = function(_) {
return R.isFunction(anf_fun237039491)?anf_fun237039491.app(break_DASH_one119168,anf_arg237839490):R.ffi.throwNonFunApp(L[4531],anf_fun237039491,[break_DASH_one119168,anf_arg237839490]);
};
try {
if(--R.GAS > 0) {
$z3951139512 = $f3951739518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3951739518,
"from":L[4531]});
}
} catch($e3950939510) {
if(R.isCont($e3950939510)) {
var $ss3951339514 = {"from":L[4531],
"go":function(anf_arg237939519) {
return $Hanf_arg920139520(anf_arg237939519,INDENT118169,PP170,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3950939510.stack[R.EXN_STACKHEIGHT++] = $ss3951339514;
}
if(R.isPyretException($e3950939510)) {
$e3950939510.pyretStack.push(L[4531]);
}
throw $e3950939510;
}
var $ret3951539516 = $Hanf_arg920139520($z3951139512,INDENT118169,PP170,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3951539516;
};
var $Hanf_arg920139520 = function(anf_arg237939519,INDENT118169,PP170,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var $z3952339524 = D;
var $f3952939530 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg237939519,break_DASH_one119168):R.ffi.throwNonFunApp(L[4532],_plus55,[anf_arg237939519,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3952339524 = $f3952939530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3952939530,
"from":L[4532]});
}
} catch($e3952139522) {
if(R.isCont($e3952139522)) {
var $ss3952539526 = {"from":L[4532],
"go":function(anf_arg238039531) {
return $Hanf_arg920039532(anf_arg238039531,INDENT118169,PP170,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
}};
$e3952139522.stack[R.EXN_STACKHEIGHT++] = $ss3952539526;
}
if(R.isPyretException($e3952139522)) {
$e3952139522.pyretStack.push(L[4532]);
}
throw $e3952139522;
}
var $ret3952739528 = $Hanf_arg920039532($z3952339524,INDENT118169,PP170,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3952739528;
};
var $Hanf_arg920039532 = function(anf_arg238039531,INDENT118169,PP170,break_DASH_one119168,header78439476,self78315127,str_DASH_elsebranch144494,str_DASH_end148546,_plus55) {
var anf_fun238139544 = G(PP170,"group",L[4534]);
var $z3953539536 = D;
var $f3954139542 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_elsebranch144494,break_DASH_one119168):R.ffi.throwNonFunApp(L[4533],_plus55,[str_DASH_elsebranch144494,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3953539536 = $f3954139542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3954139542,
"from":L[4533]});
}
} catch($e3953339534) {
if(R.isCont($e3953339534)) {
var $ss3953739538 = {"from":L[4533],
"go":function(anf_arg238239543) {
return $Hanf_arg919939545(anf_arg238239543,INDENT118169,PP170,anf_arg238039531,anf_fun238139544,header78439476,self78315127,str_DASH_end148546,_plus55);
}};
$e3953339534.stack[R.EXN_STACKHEIGHT++] = $ss3953739538;
}
if(R.isPyretException($e3953339534)) {
$e3953339534.pyretStack.push(L[4533]);
}
throw $e3953339534;
}
var $ret3953939540 = $Hanf_arg919939545($z3953539536,INDENT118169,PP170,anf_arg238039531,anf_fun238139544,header78439476,self78315127,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3953939540;
};
var $Hanf_arg919939545 = function(anf_arg238239543,INDENT118169,PP170,anf_arg238039531,anf_fun238139544,header78439476,self78315127,str_DASH_end148546,_plus55) {
var anf_bracket238339559 = G(self78315127,"_else",L[4537]);
var anf_fun238439556 = G(anf_bracket238339559,"tosource",L[4536]);
var $z3954839549 = D;
var $f3955439555 = function(_) {
return R.isFunction(anf_fun238439556)?anf_fun238439556.app():R.ffi.throwNonFunApp(L[4535],anf_fun238439556,[]);
};
try {
if(--R.GAS > 0) {
$z3954839549 = $f3955439555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3955439555,
"from":L[4535]});
}
} catch($e3954639547) {
if(R.isCont($e3954639547)) {
var $ss3955039551 = {"from":L[4535],
"go":function(anf_arg238539557) {
return $Hanf_arg919839558(anf_arg238539557,INDENT118169,PP170,anf_arg238039531,anf_arg238239543,anf_fun238139544,header78439476,str_DASH_end148546,_plus55);
}};
$e3954639547.stack[R.EXN_STACKHEIGHT++] = $ss3955039551;
}
if(R.isPyretException($e3954639547)) {
$e3954639547.pyretStack.push(L[4535]);
}
throw $e3954639547;
}
var $ret3955239553 = $Hanf_arg919839558($z3954839549,INDENT118169,PP170,anf_arg238039531,anf_arg238239543,anf_fun238139544,header78439476,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3955239553;
};
var $Hanf_arg919839558 = function(anf_arg238539557,INDENT118169,PP170,anf_arg238039531,anf_arg238239543,anf_fun238139544,header78439476,str_DASH_end148546,_plus55) {
var $z3956239563 = D;
var $f3956839569 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg238239543,anf_arg238539557):R.ffi.throwNonFunApp(L[4533],_plus55,[anf_arg238239543,anf_arg238539557]);
};
try {
if(--R.GAS > 0) {
$z3956239563 = $f3956839569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3956839569,
"from":L[4533]});
}
} catch($e3956039561) {
if(R.isCont($e3956039561)) {
var $ss3956439565 = {"from":L[4533],
"go":function(anf_arg238639570) {
return $Hanf_arg919739571(anf_arg238639570,INDENT118169,PP170,anf_arg238039531,anf_fun238139544,header78439476,str_DASH_end148546,_plus55);
}};
$e3956039561.stack[R.EXN_STACKHEIGHT++] = $ss3956439565;
}
if(R.isPyretException($e3956039561)) {
$e3956039561.pyretStack.push(L[4533]);
}
throw $e3956039561;
}
var $ret3956639567 = $Hanf_arg919739571($z3956239563,INDENT118169,PP170,anf_arg238039531,anf_fun238139544,header78439476,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3956639567;
};
var $Hanf_arg919739571 = function(anf_arg238639570,INDENT118169,PP170,anf_arg238039531,anf_fun238139544,header78439476,str_DASH_end148546,_plus55) {
var $z3957439575 = D;
var $f3958039581 = function(_) {
return R.isFunction(anf_fun238139544)?anf_fun238139544.app(anf_arg238639570):R.ffi.throwNonFunApp(L[4538],anf_fun238139544,[anf_arg238639570]);
};
try {
if(--R.GAS > 0) {
$z3957439575 = $f3958039581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3958039581,
"from":L[4538]});
}
} catch($e3957239573) {
if(R.isCont($e3957239573)) {
var $ss3957639577 = {"from":L[4538],
"go":function(anf_arg238739582) {
return $Hanf_arg919639583(anf_arg238739582,INDENT118169,PP170,anf_arg238039531,header78439476,str_DASH_end148546,_plus55);
}};
$e3957239573.stack[R.EXN_STACKHEIGHT++] = $ss3957639577;
}
if(R.isPyretException($e3957239573)) {
$e3957239573.pyretStack.push(L[4538]);
}
throw $e3957239573;
}
var $ret3957839579 = $Hanf_arg919639583($z3957439575,INDENT118169,PP170,anf_arg238039531,header78439476,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3957839579;
};
var $Hanf_arg919639583 = function(anf_arg238739582,INDENT118169,PP170,anf_arg238039531,header78439476,str_DASH_end148546,_plus55) {
var $z3958639587 = D;
var $f3959239593 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg238039531,anf_arg238739582):R.ffi.throwNonFunApp(L[4539],_plus55,[anf_arg238039531,anf_arg238739582]);
};
try {
if(--R.GAS > 0) {
$z3958639587 = $f3959239593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3959239593,
"from":L[4539]});
}
} catch($e3958439585) {
if(R.isCont($e3958439585)) {
var $ss3958839589 = {"from":L[4539],
"go":function(body78539594) {
return $Hbody919539595(body78539594,INDENT118169,PP170,header78439476,str_DASH_end148546);
}};
$e3958439585.stack[R.EXN_STACKHEIGHT++] = $ss3958839589;
}
if(R.isPyretException($e3958439585)) {
$e3958439585.pyretStack.push(L[4539]);
}
throw $e3958439585;
}
var $ret3959039591 = $Hbody919539595($z3958639587,INDENT118169,PP170,header78439476,str_DASH_end148546);
++R.GAS;
return $ret3959039591;
};
var $Hbody919539595 = function(body78539594,INDENT118169,PP170,header78439476,str_DASH_end148546) {
var anf_fun238839608 = G(PP170,"surround",L[4542]);
var anf_fun238939606 = G(PP170,"group",L[4541]);
var $z3959839599 = D;
var $f3960439605 = function(_) {
return R.isFunction(anf_fun238939606)?anf_fun238939606.app(header78439476):R.ffi.throwNonFunApp(L[4540],anf_fun238939606,[header78439476]);
};
try {
if(--R.GAS > 0) {
$z3959839599 = $f3960439605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3960439605,
"from":L[4540]});
}
} catch($e3959639597) {
if(R.isCont($e3959639597)) {
var $ss3960039601 = {"from":L[4540],
"go":function(anf_arg239039607) {
return $Hanf_arg919439609(anf_arg239039607,INDENT118169,anf_fun238839608,body78539594,str_DASH_end148546);
}};
$e3959639597.stack[R.EXN_STACKHEIGHT++] = $ss3960039601;
}
if(R.isPyretException($e3959639597)) {
$e3959639597.pyretStack.push(L[4540]);
}
throw $e3959639597;
}
var $ret3960239603 = $Hanf_arg919439609($z3959839599,INDENT118169,anf_fun238839608,body78539594,str_DASH_end148546);
++R.GAS;
return $ret3960239603;
};
var $Hanf_arg919439609 = function(anf_arg239039607,INDENT118169,anf_fun238839608,body78539594,str_DASH_end148546) {
var $z3961239613 = D;
var $f3961839619 = function(_) {
return R.isFunction(anf_fun238839608)?anf_fun238839608.app(INDENT118169,(1),anf_arg239039607,body78539594,str_DASH_end148546):R.ffi.throwNonFunApp(L[2810],anf_fun238839608,[INDENT118169,(1),anf_arg239039607,body78539594,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z3961239613 = $f3961839619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3961839619,
"from":L[2810]});
}
} catch($e3961039611) {
if(R.isCont($e3961039611)) {
var $ss3961439615 = {"from":L[2810],
"go":function(ann_DASH_check_DASH_temp235839620) {
return $Hann_DASH_check_DASH_temp919339621(ann_DASH_check_DASH_temp235839620);
}};
$e3961039611.stack[R.EXN_STACKHEIGHT++] = $ss3961439615;
}
if(R.isPyretException($e3961039611)) {
$e3961039611.pyretStack.push(L[2810]);
}
throw $e3961039611;
}
var $ret3961639617 = $Hann_DASH_check_DASH_temp919339621($z3961239613);
++R.GAS;
return $ret3961639617;
};
var $Hann_DASH_check_DASH_temp919339621 = function(ann_DASH_check_DASH_temp235839620) {
return ann_DASH_check_DASH_temp235839620;
};
var $Hanf_arg919239507 = function(anf_arg237639505,anf_fun237439506) {
var $z3962439625 = D;
var $f3963039631 = function(_) {
return R.isFunction(anf_fun237439506)?anf_fun237439506.app(anf_arg237639505):R.ffi.throwNonFunApp(L[4524],anf_fun237439506,[anf_arg237639505]);
};
try {
if(--R.GAS > 0) {
$z3962439625 = $f3963039631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3963039631,
"from":L[4524]});
}
} catch($e3962239623) {
if(R.isCont($e3962239623)) {
var $ss3962639627 = {"from":L[4524],
"go":function(ann_DASH_check_DASH_temp237339632) {
return $Hann_DASH_check_DASH_temp919139633(ann_DASH_check_DASH_temp237339632);
}};
$e3962239623.stack[R.EXN_STACKHEIGHT++] = $ss3962639627;
}
if(R.isPyretException($e3962239623)) {
$e3962239623.pyretStack.push(L[4524]);
}
throw $e3962239623;
}
var $ret3962839629 = $Hann_DASH_check_DASH_temp919139633($z3962439625);
++R.GAS;
return $ret3962839629;
};
var $Hann_DASH_check_DASH_temp919139633 = function(ann_DASH_check_DASH_temp237339632) {
return ann_DASH_check_DASH_temp237339632;
};
var $Hanf_arg919015145 = function(anf_arg233615143,self29915144,_plus55,torepr65) {
var anf_arg233739644 = G(self29915144,"typ",L[2248]);
var $z3963639637 = D;
var $f3964239643 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg233739644):R.ffi.throwNonFunApp(L[2248],torepr65,[anf_arg233739644]);
};
try {
if(--R.GAS > 0) {
$z3963639637 = $f3964239643();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3964239643,
"from":L[2248]});
}
} catch($e3963439635) {
if(R.isCont($e3963439635)) {
var $ss3963839639 = {"from":L[2248],
"go":function(anf_arg233839645) {
return $Hanf_arg918939646(anf_arg233839645,anf_arg233615143,self29915144,_plus55,torepr65);
}};
$e3963439635.stack[R.EXN_STACKHEIGHT++] = $ss3963839639;
}
if(R.isPyretException($e3963439635)) {
$e3963439635.pyretStack.push(L[2248]);
}
throw $e3963439635;
}
var $ret3964039641 = $Hanf_arg918939646($z3963639637,anf_arg233615143,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3964039641;
};
var $Hanf_arg918939646 = function(anf_arg233839645,anf_arg233615143,self29915144,_plus55,torepr65) {
var $z3964939650 = D;
var $f3965539656 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg233839645):R.ffi.throwNonFunApp(L[2248],_plus55,[(", "),anf_arg233839645]);
};
try {
if(--R.GAS > 0) {
$z3964939650 = $f3965539656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3965539656,
"from":L[2248]});
}
} catch($e3964739648) {
if(R.isCont($e3964739648)) {
var $ss3965139652 = {"from":L[2248],
"go":function(anf_arg233939657) {
return $Hanf_arg918839658(anf_arg233939657,anf_arg233615143,self29915144,_plus55,torepr65);
}};
$e3964739648.stack[R.EXN_STACKHEIGHT++] = $ss3965139652;
}
if(R.isPyretException($e3964739648)) {
$e3964739648.pyretStack.push(L[2248]);
}
throw $e3964739648;
}
var $ret3965339654 = $Hanf_arg918839658($z3964939650,anf_arg233615143,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3965339654;
};
var $Hanf_arg918839658 = function(anf_arg233939657,anf_arg233615143,self29915144,_plus55,torepr65) {
var $z3966139662 = D;
var $f3966739668 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg233615143,anf_arg233939657):R.ffi.throwNonFunApp(L[2248],_plus55,[anf_arg233615143,anf_arg233939657]);
};
try {
if(--R.GAS > 0) {
$z3966139662 = $f3966739668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3966739668,
"from":L[2248]});
}
} catch($e3965939660) {
if(R.isCont($e3965939660)) {
var $ss3966339664 = {"from":L[2248],
"go":function(anf_arg234039669) {
return $Hanf_arg918739670(anf_arg234039669,self29915144,_plus55,torepr65);
}};
$e3965939660.stack[R.EXN_STACKHEIGHT++] = $ss3966339664;
}
if(R.isPyretException($e3965939660)) {
$e3965939660.pyretStack.push(L[2248]);
}
throw $e3965939660;
}
var $ret3966539666 = $Hanf_arg918739670($z3966139662,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3966539666;
};
var $Hanf_arg918739670 = function(anf_arg234039669,self29915144,_plus55,torepr65) {
var anf_arg234139681 = G(self29915144,"val",L[2248]);
var $z3967339674 = D;
var $f3967939680 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg234139681):R.ffi.throwNonFunApp(L[2248],torepr65,[anf_arg234139681]);
};
try {
if(--R.GAS > 0) {
$z3967339674 = $f3967939680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3967939680,
"from":L[2248]});
}
} catch($e3967139672) {
if(R.isCont($e3967139672)) {
var $ss3967539676 = {"from":L[2248],
"go":function(anf_arg234239682) {
return $Hanf_arg918639683(anf_arg234239682,anf_arg234039669,self29915144,_plus55,torepr65);
}};
$e3967139672.stack[R.EXN_STACKHEIGHT++] = $ss3967539676;
}
if(R.isPyretException($e3967139672)) {
$e3967139672.pyretStack.push(L[2248]);
}
throw $e3967139672;
}
var $ret3967739678 = $Hanf_arg918639683($z3967339674,anf_arg234039669,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3967739678;
};
var $Hanf_arg918639683 = function(anf_arg234239682,anf_arg234039669,self29915144,_plus55,torepr65) {
var $z3968639687 = D;
var $f3969239693 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg234239682):R.ffi.throwNonFunApp(L[2248],_plus55,[(", "),anf_arg234239682]);
};
try {
if(--R.GAS > 0) {
$z3968639687 = $f3969239693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3969239693,
"from":L[2248]});
}
} catch($e3968439685) {
if(R.isCont($e3968439685)) {
var $ss3968839689 = {"from":L[2248],
"go":function(anf_arg234339694) {
return $Hanf_arg918539695(anf_arg234339694,anf_arg234039669,self29915144,_plus55,torepr65);
}};
$e3968439685.stack[R.EXN_STACKHEIGHT++] = $ss3968839689;
}
if(R.isPyretException($e3968439685)) {
$e3968439685.pyretStack.push(L[2248]);
}
throw $e3968439685;
}
var $ret3969039691 = $Hanf_arg918539695($z3968639687,anf_arg234039669,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3969039691;
};
var $Hanf_arg918539695 = function(anf_arg234339694,anf_arg234039669,self29915144,_plus55,torepr65) {
var $z3969839699 = D;
var $f3970439705 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg234039669,anf_arg234339694):R.ffi.throwNonFunApp(L[2248],_plus55,[anf_arg234039669,anf_arg234339694]);
};
try {
if(--R.GAS > 0) {
$z3969839699 = $f3970439705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3970439705,
"from":L[2248]});
}
} catch($e3969639697) {
if(R.isCont($e3969639697)) {
var $ss3970039701 = {"from":L[2248],
"go":function(anf_arg234439706) {
return $Hanf_arg918439707(anf_arg234439706,self29915144,_plus55,torepr65);
}};
$e3969639697.stack[R.EXN_STACKHEIGHT++] = $ss3970039701;
}
if(R.isPyretException($e3969639697)) {
$e3969639697.pyretStack.push(L[2248]);
}
throw $e3969639697;
}
var $ret3970239703 = $Hanf_arg918439707($z3969839699,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3970239703;
};
var $Hanf_arg918439707 = function(anf_arg234439706,self29915144,_plus55,torepr65) {
var anf_arg234539718 = G(self29915144,"branches",L[2248]);
var $z3971039711 = D;
var $f3971639717 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg234539718):R.ffi.throwNonFunApp(L[2248],torepr65,[anf_arg234539718]);
};
try {
if(--R.GAS > 0) {
$z3971039711 = $f3971639717();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3971639717,
"from":L[2248]});
}
} catch($e3970839709) {
if(R.isCont($e3970839709)) {
var $ss3971239713 = {"from":L[2248],
"go":function(anf_arg234639719) {
return $Hanf_arg918339720(anf_arg234639719,anf_arg234439706,self29915144,_plus55,torepr65);
}};
$e3970839709.stack[R.EXN_STACKHEIGHT++] = $ss3971239713;
}
if(R.isPyretException($e3970839709)) {
$e3970839709.pyretStack.push(L[2248]);
}
throw $e3970839709;
}
var $ret3971439715 = $Hanf_arg918339720($z3971039711,anf_arg234439706,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3971439715;
};
var $Hanf_arg918339720 = function(anf_arg234639719,anf_arg234439706,self29915144,_plus55,torepr65) {
var $z3972339724 = D;
var $f3972939730 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg234639719):R.ffi.throwNonFunApp(L[2248],_plus55,[(", "),anf_arg234639719]);
};
try {
if(--R.GAS > 0) {
$z3972339724 = $f3972939730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3972939730,
"from":L[2248]});
}
} catch($e3972139722) {
if(R.isCont($e3972139722)) {
var $ss3972539726 = {"from":L[2248],
"go":function(anf_arg234739731) {
return $Hanf_arg918239732(anf_arg234739731,anf_arg234439706,self29915144,_plus55,torepr65);
}};
$e3972139722.stack[R.EXN_STACKHEIGHT++] = $ss3972539726;
}
if(R.isPyretException($e3972139722)) {
$e3972139722.pyretStack.push(L[2248]);
}
throw $e3972139722;
}
var $ret3972739728 = $Hanf_arg918239732($z3972339724,anf_arg234439706,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3972739728;
};
var $Hanf_arg918239732 = function(anf_arg234739731,anf_arg234439706,self29915144,_plus55,torepr65) {
var $z3973539736 = D;
var $f3974139742 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg234439706,anf_arg234739731):R.ffi.throwNonFunApp(L[2248],_plus55,[anf_arg234439706,anf_arg234739731]);
};
try {
if(--R.GAS > 0) {
$z3973539736 = $f3974139742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3974139742,
"from":L[2248]});
}
} catch($e3973339734) {
if(R.isCont($e3973339734)) {
var $ss3973739738 = {"from":L[2248],
"go":function(anf_arg234839743) {
return $Hanf_arg918139744(anf_arg234839743,self29915144,_plus55,torepr65);
}};
$e3973339734.stack[R.EXN_STACKHEIGHT++] = $ss3973739738;
}
if(R.isPyretException($e3973339734)) {
$e3973339734.pyretStack.push(L[2248]);
}
throw $e3973339734;
}
var $ret3973939740 = $Hanf_arg918139744($z3973539736,self29915144,_plus55,torepr65);
++R.GAS;
return $ret3973939740;
};
var $Hanf_arg918139744 = function(anf_arg234839743,self29915144,_plus55,torepr65) {
var anf_arg234939755 = G(self29915144,"_else",L[2248]);
var $z3974739748 = D;
var $f3975339754 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg234939755):R.ffi.throwNonFunApp(L[2248],torepr65,[anf_arg234939755]);
};
try {
if(--R.GAS > 0) {
$z3974739748 = $f3975339754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3975339754,
"from":L[2248]});
}
} catch($e3974539746) {
if(R.isCont($e3974539746)) {
var $ss3974939750 = {"from":L[2248],
"go":function(anf_arg235039756) {
return $Hanf_arg918039757(anf_arg235039756,anf_arg234839743,_plus55);
}};
$e3974539746.stack[R.EXN_STACKHEIGHT++] = $ss3974939750;
}
if(R.isPyretException($e3974539746)) {
$e3974539746.pyretStack.push(L[2248]);
}
throw $e3974539746;
}
var $ret3975139752 = $Hanf_arg918039757($z3974739748,anf_arg234839743,_plus55);
++R.GAS;
return $ret3975139752;
};
var $Hanf_arg918039757 = function(anf_arg235039756,anf_arg234839743,_plus55) {
var $z3976039761 = D;
var $f3976639767 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg235039756):R.ffi.throwNonFunApp(L[2248],_plus55,[(", "),anf_arg235039756]);
};
try {
if(--R.GAS > 0) {
$z3976039761 = $f3976639767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3976639767,
"from":L[2248]});
}
} catch($e3975839759) {
if(R.isCont($e3975839759)) {
var $ss3976239763 = {"from":L[2248],
"go":function(anf_arg235139768) {
return $Hanf_arg917939769(anf_arg235139768,anf_arg234839743,_plus55);
}};
$e3975839759.stack[R.EXN_STACKHEIGHT++] = $ss3976239763;
}
if(R.isPyretException($e3975839759)) {
$e3975839759.pyretStack.push(L[2248]);
}
throw $e3975839759;
}
var $ret3976439765 = $Hanf_arg917939769($z3976039761,anf_arg234839743,_plus55);
++R.GAS;
return $ret3976439765;
};
var $Hanf_arg917939769 = function(anf_arg235139768,anf_arg234839743,_plus55) {
var $z3977239773 = D;
var $f3977839779 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg234839743,anf_arg235139768):R.ffi.throwNonFunApp(L[2248],_plus55,[anf_arg234839743,anf_arg235139768]);
};
try {
if(--R.GAS > 0) {
$z3977239773 = $f3977839779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3977839779,
"from":L[2248]});
}
} catch($e3977039771) {
if(R.isCont($e3977039771)) {
var $ss3977439775 = {"from":L[2248],
"go":function(anf_arg235239780) {
return $Hanf_arg917839781(anf_arg235239780,_plus55);
}};
$e3977039771.stack[R.EXN_STACKHEIGHT++] = $ss3977439775;
}
if(R.isPyretException($e3977039771)) {
$e3977039771.pyretStack.push(L[2248]);
}
throw $e3977039771;
}
var $ret3977639777 = $Hanf_arg917839781($z3977239773,_plus55);
++R.GAS;
return $ret3977639777;
};
var $Hanf_arg917839781 = function(anf_arg235239780,_plus55) {
var $z3978439785 = D;
var $f3979039791 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg235239780,(")")):R.ffi.throwNonFunApp(L[2248],_plus55,[anf_arg235239780,(")")]);
};
try {
if(--R.GAS > 0) {
$z3978439785 = $f3979039791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3979039791,
"from":L[2248]});
}
} catch($e3978239783) {
if(R.isCont($e3978239783)) {
var $ss3978639787 = {"from":L[2248],
"go":function(anf_arg235339792) {
return $Hanf_arg917739793(anf_arg235339792,_plus55);
}};
$e3978239783.stack[R.EXN_STACKHEIGHT++] = $ss3978639787;
}
if(R.isPyretException($e3978239783)) {
$e3978239783.pyretStack.push(L[2248]);
}
throw $e3978239783;
}
var $ret3978839789 = $Hanf_arg917739793($z3978439785,_plus55);
++R.GAS;
return $ret3978839789;
};
var $Hanf_arg917739793 = function(anf_arg235339792,_plus55) {
var $z3979639797 = D;
var $f3980239803 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg235339792):R.ffi.throwNonFunApp(L[2248],_plus55,[("("),anf_arg235339792]);
};
try {
if(--R.GAS > 0) {
$z3979639797 = $f3980239803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3980239803,
"from":L[2248]});
}
} catch($e3979439795) {
if(R.isCont($e3979439795)) {
var $ss3979839799 = {"from":L[2248],
"go":function(anf_arg235439804) {
return $Hanf_arg917639805(anf_arg235439804,_plus55);
}};
$e3979439795.stack[R.EXN_STACKHEIGHT++] = $ss3979839799;
}
if(R.isPyretException($e3979439795)) {
$e3979439795.pyretStack.push(L[2248]);
}
throw $e3979439795;
}
var $ret3980039801 = $Hanf_arg917639805($z3979639797,_plus55);
++R.GAS;
return $ret3980039801;
};
var $Hanf_arg917639805 = function(anf_arg235439804,_plus55) {
var $z3980839809 = D;
var $f3981439815 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-cases-else"),anf_arg235439804):R.ffi.throwNonFunApp(L[2248],_plus55,[("s-cases-else"),anf_arg235439804]);
};
try {
if(--R.GAS > 0) {
$z3980839809 = $f3981439815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3981439815,
"from":L[2248]});
}
} catch($e3980639807) {
if(R.isCont($e3980639807)) {
var $ss3981039811 = {"from":L[2248],
"go":function(ann_DASH_check_DASH_temp233439816) {
return $Hann_DASH_check_DASH_temp917539817(ann_DASH_check_DASH_temp233439816);
}};
$e3980639807.stack[R.EXN_STACKHEIGHT++] = $ss3981039811;
}
if(R.isPyretException($e3980639807)) {
$e3980639807.pyretStack.push(L[2248]);
}
throw $e3980639807;
}
var $ret3981239813 = $Hann_DASH_check_DASH_temp917539817($z3980839809);
++R.GAS;
return $ret3981239813;
};
var $Hann_DASH_check_DASH_temp917539817 = function(ann_DASH_check_DASH_temp233439816) {
return ann_DASH_check_DASH_temp233439816;
};
var $Hcont_tail_arg917315164 = function(cont_tail_arg233115162,if_helper231915163) {
if(--R.GAS > 0) {
$z3981839819 = R.isFunction(if_helper231915163)?if_helper231915163.app(cont_tail_arg233115162):R.ffi.throwNonFunApp(L[2248],if_helper231915163,[cont_tail_arg233115162]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper231915163)?if_helper231915163.app(cont_tail_arg233115162):R.ffi.throwNonFunApp(L[2248],if_helper231915163,[cont_tail_arg233115162]);
},
"from":L[2248]});
}
++R.GAS;
return $z3981839819;
};
var $Hcont_tail_arg917415179 = function(cont_tail_arg232415178,if_helper231915163) {
if(--R.GAS > 0) {
$z3982039821 = R.isFunction(if_helper231915163)?if_helper231915163.app(cont_tail_arg232415178):R.ffi.throwNonFunApp(L[2248],if_helper231915163,[cont_tail_arg232415178]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper231915163)?if_helper231915163.app(cont_tail_arg232415178):R.ffi.throwNonFunApp(L[2248],if_helper231915163,[cont_tail_arg232415178]);
},
"from":L[2248]});
}
++R.GAS;
return $z3982039821;
};
var $Hanf_arg917215201 = function(anf_arg229615198,INDENT118169,PP170,anf_fun229315199,break_DASH_one119168,self77415200,str_DASH_cases130312,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55) {
var $z3982439825 = D;
var $f3983039831 = function(_) {
return R.isFunction(anf_fun229315199)?anf_fun229315199.app(anf_arg229615198):R.ffi.throwNonFunApp(L[4543],anf_fun229315199,[anf_arg229615198]);
};
try {
if(--R.GAS > 0) {
$z3982439825 = $f3983039831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3983039831,
"from":L[4543]});
}
} catch($e3982239823) {
if(R.isCont($e3982239823)) {
var $ss3982639827 = {"from":L[4543],
"go":function(anf_arg229739832) {
return $Hanf_arg917139833(anf_arg229739832,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_cases130312,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
}};
$e3982239823.stack[R.EXN_STACKHEIGHT++] = $ss3982639827;
}
if(R.isPyretException($e3982239823)) {
$e3982239823.pyretStack.push(L[4543]);
}
throw $e3982239823;
}
var $ret3982839829 = $Hanf_arg917139833($z3982439825,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_cases130312,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
++R.GAS;
return $ret3982839829;
};
var $Hanf_arg917139833 = function(anf_arg229739832,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_cases130312,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55) {
var $z3983639837 = D;
var $f3984239843 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_cases130312,anf_arg229739832):R.ffi.throwNonFunApp(L[4544],_plus55,[str_DASH_cases130312,anf_arg229739832]);
};
try {
if(--R.GAS > 0) {
$z3983639837 = $f3984239843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3984239843,
"from":L[4544]});
}
} catch($e3983439835) {
if(R.isCont($e3983439835)) {
var $ss3983839839 = {"from":L[4544],
"go":function(anf_arg229839844) {
return $Hanf_arg917039845(anf_arg229839844,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
}};
$e3983439835.stack[R.EXN_STACKHEIGHT++] = $ss3983839839;
}
if(R.isPyretException($e3983439835)) {
$e3983439835.pyretStack.push(L[4544]);
}
throw $e3983439835;
}
var $ret3984039841 = $Hanf_arg917039845($z3983639837,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
++R.GAS;
return $ret3984039841;
};
var $Hanf_arg917039845 = function(anf_arg229839844,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55) {
var $z3984839849 = D;
var $f3985439855 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg229839844,break_DASH_one119168):R.ffi.throwNonFunApp(L[4544],_plus55,[anf_arg229839844,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z3984839849 = $f3985439855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3985439855,
"from":L[4544]});
}
} catch($e3984639847) {
if(R.isCont($e3984639847)) {
var $ss3985039851 = {"from":L[4544],
"go":function(anf_arg229939856) {
return $Hanf_arg916939857(anf_arg229939856,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
}};
$e3984639847.stack[R.EXN_STACKHEIGHT++] = $ss3985039851;
}
if(R.isPyretException($e3984639847)) {
$e3984639847.pyretStack.push(L[4544]);
}
throw $e3984639847;
}
var $ret3985239853 = $Hanf_arg916939857($z3984839849,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
++R.GAS;
return $ret3985239853;
};
var $Hanf_arg916939857 = function(anf_arg229939856,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55) {
var anf_bracket230039871 = G(self77415200,"val",L[4547]);
var anf_fun230139868 = G(anf_bracket230039871,"tosource",L[4546]);
var $z3986039861 = D;
var $f3986639867 = function(_) {
return R.isFunction(anf_fun230139868)?anf_fun230139868.app():R.ffi.throwNonFunApp(L[4545],anf_fun230139868,[]);
};
try {
if(--R.GAS > 0) {
$z3986039861 = $f3986639867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3986639867,
"from":L[4545]});
}
} catch($e3985839859) {
if(R.isCont($e3985839859)) {
var $ss3986239863 = {"from":L[4545],
"go":function(anf_arg230239869) {
return $Hanf_arg916839870(anf_arg230239869,INDENT118169,PP170,anf_arg229939856,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
}};
$e3985839859.stack[R.EXN_STACKHEIGHT++] = $ss3986239863;
}
if(R.isPyretException($e3985839859)) {
$e3985839859.pyretStack.push(L[4545]);
}
throw $e3985839859;
}
var $ret3986439865 = $Hanf_arg916839870($z3986039861,INDENT118169,PP170,anf_arg229939856,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
++R.GAS;
return $ret3986439865;
};
var $Hanf_arg916839870 = function(anf_arg230239869,INDENT118169,PP170,anf_arg229939856,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55) {
var $z3987439875 = D;
var $f3988039881 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg229939856,anf_arg230239869):R.ffi.throwNonFunApp(L[4544],_plus55,[anf_arg229939856,anf_arg230239869]);
};
try {
if(--R.GAS > 0) {
$z3987439875 = $f3988039881();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3988039881,
"from":L[4544]});
}
} catch($e3987239873) {
if(R.isCont($e3987239873)) {
var $ss3987639877 = {"from":L[4544],
"go":function(anf_arg230339882) {
return $Hanf_arg916739883(anf_arg230339882,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
}};
$e3987239873.stack[R.EXN_STACKHEIGHT++] = $ss3987639877;
}
if(R.isPyretException($e3987239873)) {
$e3987239873.pyretStack.push(L[4544]);
}
throw $e3987239873;
}
var $ret3987839879 = $Hanf_arg916739883($z3987439875,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55);
++R.GAS;
return $ret3987839879;
};
var $Hanf_arg916739883 = function(anf_arg230339882,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_colon134364,str_DASH_end148546,str_DASH_space168806,_plus55) {
var $z3988639887 = D;
var $f3989239893 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg230339882,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4548],_plus55,[anf_arg230339882,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z3988639887 = $f3989239893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3989239893,
"from":L[4548]});
}
} catch($e3988439885) {
if(R.isCont($e3988439885)) {
var $ss3988839889 = {"from":L[4548],
"go":function(header77539894) {
return $Hheader916639895(header77539894,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_end148546,str_DASH_space168806,_plus55);
}};
$e3988439885.stack[R.EXN_STACKHEIGHT++] = $ss3988839889;
}
if(R.isPyretException($e3988439885)) {
$e3988439885.pyretStack.push(L[4548]);
}
throw $e3988439885;
}
var $ret3989039891 = $Hheader916639895($z3988639887,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_end148546,str_DASH_space168806,_plus55);
++R.GAS;
return $ret3989039891;
};
var $Hheader916639895 = function(header77539894,INDENT118169,PP170,break_DASH_one119168,self77415200,str_DASH_end148546,str_DASH_space168806,_plus55) {
var anf_fun230439907 = G(PP170,"surround-separate",L[4550]);
var $z3989839899 = D;
var $f3990439905 = function(_) {
return R.isFunction(_plus55)?_plus55.app(header77539894,str_DASH_space168806):R.ffi.throwNonFunApp(L[4549],_plus55,[header77539894,str_DASH_space168806]);
};
try {
if(--R.GAS > 0) {
$z3989839899 = $f3990439905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3990439905,
"from":L[4549]});
}
} catch($e3989639897) {
if(R.isCont($e3989639897)) {
var $ss3990039901 = {"from":L[4549],
"go":function(anf_arg230539906) {
return $Hanf_arg916539908(anf_arg230539906,INDENT118169,PP170,anf_fun230439907,break_DASH_one119168,header77539894,self77415200,str_DASH_end148546,_plus55);
}};
$e3989639897.stack[R.EXN_STACKHEIGHT++] = $ss3990039901;
}
if(R.isPyretException($e3989639897)) {
$e3989639897.pyretStack.push(L[4549]);
}
throw $e3989639897;
}
var $ret3990239903 = $Hanf_arg916539908($z3989839899,INDENT118169,PP170,anf_fun230439907,break_DASH_one119168,header77539894,self77415200,str_DASH_end148546,_plus55);
++R.GAS;
return $ret3990239903;
};
var $Hanf_arg916539908 = function(anf_arg230539906,INDENT118169,PP170,anf_fun230439907,break_DASH_one119168,header77539894,self77415200,str_DASH_end148546,_plus55) {
var $z3991139912 = D;
var $f3991739918 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg230539906,str_DASH_end148546):R.ffi.throwNonFunApp(L[4549],_plus55,[anf_arg230539906,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z3991139912 = $f3991739918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3991739918,
"from":L[4549]});
}
} catch($e3990939910) {
if(R.isCont($e3990939910)) {
var $ss3991339914 = {"from":L[4549],
"go":function(anf_arg230639919) {
return $Hanf_arg916439920(anf_arg230639919,INDENT118169,PP170,anf_fun230439907,break_DASH_one119168,header77539894,self77415200,str_DASH_end148546);
}};
$e3990939910.stack[R.EXN_STACKHEIGHT++] = $ss3991339914;
}
if(R.isPyretException($e3990939910)) {
$e3990939910.pyretStack.push(L[4549]);
}
throw $e3990939910;
}
var $ret3991539916 = $Hanf_arg916439920($z3991139912,INDENT118169,PP170,anf_fun230439907,break_DASH_one119168,header77539894,self77415200,str_DASH_end148546);
++R.GAS;
return $ret3991539916;
};
var $Hanf_arg916439920 = function(anf_arg230639919,INDENT118169,PP170,anf_fun230439907,break_DASH_one119168,header77539894,self77415200,str_DASH_end148546) {
var anf_fun230739931 = G(PP170,"group",L[4552]);
var $z3992339924 = D;
var $f3992939930 = function(_) {
return R.isFunction(anf_fun230739931)?anf_fun230739931.app(header77539894):R.ffi.throwNonFunApp(L[4551],anf_fun230739931,[header77539894]);
};
try {
if(--R.GAS > 0) {
$z3992339924 = $f3992939930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3992939930,
"from":L[4551]});
}
} catch($e3992139922) {
if(R.isCont($e3992139922)) {
var $ss3992539926 = {"from":L[4551],
"go":function(anf_arg230839932) {
return $Hanf_arg916339933(anf_arg230839932,INDENT118169,PP170,anf_arg230639919,anf_fun230439907,break_DASH_one119168,self77415200,str_DASH_end148546);
}};
$e3992139922.stack[R.EXN_STACKHEIGHT++] = $ss3992539926;
}
if(R.isPyretException($e3992139922)) {
$e3992139922.pyretStack.push(L[4551]);
}
throw $e3992139922;
}
var $ret3992739928 = $Hanf_arg916339933($z3992339924,INDENT118169,PP170,anf_arg230639919,anf_fun230439907,break_DASH_one119168,self77415200,str_DASH_end148546);
++R.GAS;
return $ret3992739928;
};
var $Hanf_arg916339933 = function(anf_arg230839932,INDENT118169,PP170,anf_arg230639919,anf_fun230439907,break_DASH_one119168,self77415200,str_DASH_end148546) {
var anf_bracket230939963 = G(self77415200,"branches",L[4559]);
var anf_fun231039944 = G(anf_bracket230939963,"map",L[4558]);
var anf_arg231539945 = R.makeFunction(function(b77639948) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4554],1,arguments);
}
var anf_fun231239961 = G(PP170,"group",L[4557]);
var anf_fun231339959 = G(b77639948,"tosource",L[4556]);
var $z3995139952 = D;
var $f3995739958 = function(_) {
return R.isFunction(anf_fun231339959)?anf_fun231339959.app():R.ffi.throwNonFunApp(L[4555],anf_fun231339959,[]);
};
try {
if(--R.GAS > 0) {
$z3995139952 = $f3995739958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3995739958,
"from":L[4555]});
}
} catch($e3994939950) {
if(R.isCont($e3994939950)) {
var $ss3995339954 = {"from":L[4555],
"go":function(anf_arg231439960) {
return $Hanf_arg916039962(anf_arg231439960,anf_fun231239961);
}};
$e3994939950.stack[R.EXN_STACKHEIGHT++] = $ss3995339954;
}
if(R.isPyretException($e3994939950)) {
$e3994939950.pyretStack.push(L[4555]);
}
throw $e3994939950;
}
var $ret3995539956 = $Hanf_arg916039962($z3995139952,anf_fun231239961);
++R.GAS;
return $ret3995539956;
});
var $z3993639937 = D;
var $f3994239943 = function(_) {
return R.isFunction(anf_fun231039944)?anf_fun231039944.app(anf_arg231539945):R.ffi.throwNonFunApp(L[4553],anf_fun231039944,[anf_arg231539945]);
};
try {
if(--R.GAS > 0) {
$z3993639937 = $f3994239943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3994239943,
"from":L[4553]});
}
} catch($e3993439935) {
if(R.isCont($e3993439935)) {
var $ss3993839939 = {"from":L[4553],
"go":function(anf_arg231639946) {
return $Hanf_arg916239947(anf_arg231639946,INDENT118169,anf_arg230639919,anf_arg230839932,anf_fun230439907,break_DASH_one119168,str_DASH_end148546);
}};
$e3993439935.stack[R.EXN_STACKHEIGHT++] = $ss3993839939;
}
if(R.isPyretException($e3993439935)) {
$e3993439935.pyretStack.push(L[4553]);
}
throw $e3993439935;
}
var $ret3994039941 = $Hanf_arg916239947($z3993639937,INDENT118169,anf_arg230639919,anf_arg230839932,anf_fun230439907,break_DASH_one119168,str_DASH_end148546);
++R.GAS;
return $ret3994039941;
};
var $Hanf_arg916239947 = function(anf_arg231639946,INDENT118169,anf_arg230639919,anf_arg230839932,anf_fun230439907,break_DASH_one119168,str_DASH_end148546) {
var $z3996639967 = D;
var $f3997239973 = function(_) {
return R.isFunction(anf_fun230439907)?anf_fun230439907.app(INDENT118169,(1),anf_arg230639919,anf_arg230839932,break_DASH_one119168,str_DASH_end148546,anf_arg231639946):R.ffi.throwNonFunApp(L[2821],anf_fun230439907,[INDENT118169,(1),anf_arg230639919,anf_arg230839932,break_DASH_one119168,str_DASH_end148546,anf_arg231639946]);
};
try {
if(--R.GAS > 0) {
$z3996639967 = $f3997239973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3997239973,
"from":L[2821]});
}
} catch($e3996439965) {
if(R.isCont($e3996439965)) {
var $ss3996839969 = {"from":L[2821],
"go":function(ann_DASH_check_DASH_temp229239974) {
return $Hann_DASH_check_DASH_temp916139975(ann_DASH_check_DASH_temp229239974);
}};
$e3996439965.stack[R.EXN_STACKHEIGHT++] = $ss3996839969;
}
if(R.isPyretException($e3996439965)) {
$e3996439965.pyretStack.push(L[2821]);
}
throw $e3996439965;
}
var $ret3997039971 = $Hann_DASH_check_DASH_temp916139975($z3996639967);
++R.GAS;
return $ret3997039971;
};
var $Hann_DASH_check_DASH_temp916139975 = function(ann_DASH_check_DASH_temp229239974) {
return ann_DASH_check_DASH_temp229239974;
};
var $Hanf_arg916039962 = function(anf_arg231439960,anf_fun231239961) {
var $z3997839979 = D;
var $f3998439985 = function(_) {
return R.isFunction(anf_fun231239961)?anf_fun231239961.app(anf_arg231439960):R.ffi.throwNonFunApp(L[4554],anf_fun231239961,[anf_arg231439960]);
};
try {
if(--R.GAS > 0) {
$z3997839979 = $f3998439985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3998439985,
"from":L[4554]});
}
} catch($e3997639977) {
if(R.isCont($e3997639977)) {
var $ss3998039981 = {"from":L[4554],
"go":function(ann_DASH_check_DASH_temp231139986) {
return $Hann_DASH_check_DASH_temp915939987(ann_DASH_check_DASH_temp231139986);
}};
$e3997639977.stack[R.EXN_STACKHEIGHT++] = $ss3998039981;
}
if(R.isPyretException($e3997639977)) {
$e3997639977.pyretStack.push(L[4554]);
}
throw $e3997639977;
}
var $ret3998239983 = $Hann_DASH_check_DASH_temp915939987($z3997839979);
++R.GAS;
return $ret3998239983;
};
var $Hann_DASH_check_DASH_temp915939987 = function(ann_DASH_check_DASH_temp231139986) {
return ann_DASH_check_DASH_temp231139986;
};
var $Hanf_arg915815218 = function(anf_arg227415216,self29315217,_plus55,torepr65) {
var anf_arg227539998 = G(self29315217,"typ",L[2249]);
var $z3999039991 = D;
var $f3999639997 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg227539998):R.ffi.throwNonFunApp(L[2249],torepr65,[anf_arg227539998]);
};
try {
if(--R.GAS > 0) {
$z3999039991 = $f3999639997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3999639997,
"from":L[2249]});
}
} catch($e3998839989) {
if(R.isCont($e3998839989)) {
var $ss3999239993 = {"from":L[2249],
"go":function(anf_arg227639999) {
return $Hanf_arg915740000(anf_arg227639999,anf_arg227415216,self29315217,_plus55,torepr65);
}};
$e3998839989.stack[R.EXN_STACKHEIGHT++] = $ss3999239993;
}
if(R.isPyretException($e3998839989)) {
$e3998839989.pyretStack.push(L[2249]);
}
throw $e3998839989;
}
var $ret3999439995 = $Hanf_arg915740000($z3999039991,anf_arg227415216,self29315217,_plus55,torepr65);
++R.GAS;
return $ret3999439995;
};
var $Hanf_arg915740000 = function(anf_arg227639999,anf_arg227415216,self29315217,_plus55,torepr65) {
var $z4000340004 = D;
var $f4000940010 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg227639999):R.ffi.throwNonFunApp(L[2249],_plus55,[(", "),anf_arg227639999]);
};
try {
if(--R.GAS > 0) {
$z4000340004 = $f4000940010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4000940010,
"from":L[2249]});
}
} catch($e4000140002) {
if(R.isCont($e4000140002)) {
var $ss4000540006 = {"from":L[2249],
"go":function(anf_arg227740011) {
return $Hanf_arg915640012(anf_arg227740011,anf_arg227415216,self29315217,_plus55,torepr65);
}};
$e4000140002.stack[R.EXN_STACKHEIGHT++] = $ss4000540006;
}
if(R.isPyretException($e4000140002)) {
$e4000140002.pyretStack.push(L[2249]);
}
throw $e4000140002;
}
var $ret4000740008 = $Hanf_arg915640012($z4000340004,anf_arg227415216,self29315217,_plus55,torepr65);
++R.GAS;
return $ret4000740008;
};
var $Hanf_arg915640012 = function(anf_arg227740011,anf_arg227415216,self29315217,_plus55,torepr65) {
var $z4001540016 = D;
var $f4002140022 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg227415216,anf_arg227740011):R.ffi.throwNonFunApp(L[2249],_plus55,[anf_arg227415216,anf_arg227740011]);
};
try {
if(--R.GAS > 0) {
$z4001540016 = $f4002140022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4002140022,
"from":L[2249]});
}
} catch($e4001340014) {
if(R.isCont($e4001340014)) {
var $ss4001740018 = {"from":L[2249],
"go":function(anf_arg227840023) {
return $Hanf_arg915540024(anf_arg227840023,self29315217,_plus55,torepr65);
}};
$e4001340014.stack[R.EXN_STACKHEIGHT++] = $ss4001740018;
}
if(R.isPyretException($e4001340014)) {
$e4001340014.pyretStack.push(L[2249]);
}
throw $e4001340014;
}
var $ret4001940020 = $Hanf_arg915540024($z4001540016,self29315217,_plus55,torepr65);
++R.GAS;
return $ret4001940020;
};
var $Hanf_arg915540024 = function(anf_arg227840023,self29315217,_plus55,torepr65) {
var anf_arg227940035 = G(self29315217,"val",L[2249]);
var $z4002740028 = D;
var $f4003340034 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg227940035):R.ffi.throwNonFunApp(L[2249],torepr65,[anf_arg227940035]);
};
try {
if(--R.GAS > 0) {
$z4002740028 = $f4003340034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4003340034,
"from":L[2249]});
}
} catch($e4002540026) {
if(R.isCont($e4002540026)) {
var $ss4002940030 = {"from":L[2249],
"go":function(anf_arg228040036) {
return $Hanf_arg915440037(anf_arg228040036,anf_arg227840023,self29315217,_plus55,torepr65);
}};
$e4002540026.stack[R.EXN_STACKHEIGHT++] = $ss4002940030;
}
if(R.isPyretException($e4002540026)) {
$e4002540026.pyretStack.push(L[2249]);
}
throw $e4002540026;
}
var $ret4003140032 = $Hanf_arg915440037($z4002740028,anf_arg227840023,self29315217,_plus55,torepr65);
++R.GAS;
return $ret4003140032;
};
var $Hanf_arg915440037 = function(anf_arg228040036,anf_arg227840023,self29315217,_plus55,torepr65) {
var $z4004040041 = D;
var $f4004640047 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg228040036):R.ffi.throwNonFunApp(L[2249],_plus55,[(", "),anf_arg228040036]);
};
try {
if(--R.GAS > 0) {
$z4004040041 = $f4004640047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4004640047,
"from":L[2249]});
}
} catch($e4003840039) {
if(R.isCont($e4003840039)) {
var $ss4004240043 = {"from":L[2249],
"go":function(anf_arg228140048) {
return $Hanf_arg915340049(anf_arg228140048,anf_arg227840023,self29315217,_plus55,torepr65);
}};
$e4003840039.stack[R.EXN_STACKHEIGHT++] = $ss4004240043;
}
if(R.isPyretException($e4003840039)) {
$e4003840039.pyretStack.push(L[2249]);
}
throw $e4003840039;
}
var $ret4004440045 = $Hanf_arg915340049($z4004040041,anf_arg227840023,self29315217,_plus55,torepr65);
++R.GAS;
return $ret4004440045;
};
var $Hanf_arg915340049 = function(anf_arg228140048,anf_arg227840023,self29315217,_plus55,torepr65) {
var $z4005240053 = D;
var $f4005840059 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg227840023,anf_arg228140048):R.ffi.throwNonFunApp(L[2249],_plus55,[anf_arg227840023,anf_arg228140048]);
};
try {
if(--R.GAS > 0) {
$z4005240053 = $f4005840059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4005840059,
"from":L[2249]});
}
} catch($e4005040051) {
if(R.isCont($e4005040051)) {
var $ss4005440055 = {"from":L[2249],
"go":function(anf_arg228240060) {
return $Hanf_arg915240061(anf_arg228240060,self29315217,_plus55,torepr65);
}};
$e4005040051.stack[R.EXN_STACKHEIGHT++] = $ss4005440055;
}
if(R.isPyretException($e4005040051)) {
$e4005040051.pyretStack.push(L[2249]);
}
throw $e4005040051;
}
var $ret4005640057 = $Hanf_arg915240061($z4005240053,self29315217,_plus55,torepr65);
++R.GAS;
return $ret4005640057;
};
var $Hanf_arg915240061 = function(anf_arg228240060,self29315217,_plus55,torepr65) {
var anf_arg228340072 = G(self29315217,"branches",L[2249]);
var $z4006440065 = D;
var $f4007040071 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg228340072):R.ffi.throwNonFunApp(L[2249],torepr65,[anf_arg228340072]);
};
try {
if(--R.GAS > 0) {
$z4006440065 = $f4007040071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4007040071,
"from":L[2249]});
}
} catch($e4006240063) {
if(R.isCont($e4006240063)) {
var $ss4006640067 = {"from":L[2249],
"go":function(anf_arg228440073) {
return $Hanf_arg915140074(anf_arg228440073,anf_arg228240060,_plus55);
}};
$e4006240063.stack[R.EXN_STACKHEIGHT++] = $ss4006640067;
}
if(R.isPyretException($e4006240063)) {
$e4006240063.pyretStack.push(L[2249]);
}
throw $e4006240063;
}
var $ret4006840069 = $Hanf_arg915140074($z4006440065,anf_arg228240060,_plus55);
++R.GAS;
return $ret4006840069;
};
var $Hanf_arg915140074 = function(anf_arg228440073,anf_arg228240060,_plus55) {
var $z4007740078 = D;
var $f4008340084 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg228440073):R.ffi.throwNonFunApp(L[2249],_plus55,[(", "),anf_arg228440073]);
};
try {
if(--R.GAS > 0) {
$z4007740078 = $f4008340084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4008340084,
"from":L[2249]});
}
} catch($e4007540076) {
if(R.isCont($e4007540076)) {
var $ss4007940080 = {"from":L[2249],
"go":function(anf_arg228540085) {
return $Hanf_arg915040086(anf_arg228540085,anf_arg228240060,_plus55);
}};
$e4007540076.stack[R.EXN_STACKHEIGHT++] = $ss4007940080;
}
if(R.isPyretException($e4007540076)) {
$e4007540076.pyretStack.push(L[2249]);
}
throw $e4007540076;
}
var $ret4008140082 = $Hanf_arg915040086($z4007740078,anf_arg228240060,_plus55);
++R.GAS;
return $ret4008140082;
};
var $Hanf_arg915040086 = function(anf_arg228540085,anf_arg228240060,_plus55) {
var $z4008940090 = D;
var $f4009540096 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg228240060,anf_arg228540085):R.ffi.throwNonFunApp(L[2249],_plus55,[anf_arg228240060,anf_arg228540085]);
};
try {
if(--R.GAS > 0) {
$z4008940090 = $f4009540096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4009540096,
"from":L[2249]});
}
} catch($e4008740088) {
if(R.isCont($e4008740088)) {
var $ss4009140092 = {"from":L[2249],
"go":function(anf_arg228640097) {
return $Hanf_arg914940098(anf_arg228640097,_plus55);
}};
$e4008740088.stack[R.EXN_STACKHEIGHT++] = $ss4009140092;
}
if(R.isPyretException($e4008740088)) {
$e4008740088.pyretStack.push(L[2249]);
}
throw $e4008740088;
}
var $ret4009340094 = $Hanf_arg914940098($z4008940090,_plus55);
++R.GAS;
return $ret4009340094;
};
var $Hanf_arg914940098 = function(anf_arg228640097,_plus55) {
var $z4010140102 = D;
var $f4010740108 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg228640097,(")")):R.ffi.throwNonFunApp(L[2249],_plus55,[anf_arg228640097,(")")]);
};
try {
if(--R.GAS > 0) {
$z4010140102 = $f4010740108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4010740108,
"from":L[2249]});
}
} catch($e4009940100) {
if(R.isCont($e4009940100)) {
var $ss4010340104 = {"from":L[2249],
"go":function(anf_arg228740109) {
return $Hanf_arg914840110(anf_arg228740109,_plus55);
}};
$e4009940100.stack[R.EXN_STACKHEIGHT++] = $ss4010340104;
}
if(R.isPyretException($e4009940100)) {
$e4009940100.pyretStack.push(L[2249]);
}
throw $e4009940100;
}
var $ret4010540106 = $Hanf_arg914840110($z4010140102,_plus55);
++R.GAS;
return $ret4010540106;
};
var $Hanf_arg914840110 = function(anf_arg228740109,_plus55) {
var $z4011340114 = D;
var $f4011940120 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg228740109):R.ffi.throwNonFunApp(L[2249],_plus55,[("("),anf_arg228740109]);
};
try {
if(--R.GAS > 0) {
$z4011340114 = $f4011940120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4011940120,
"from":L[2249]});
}
} catch($e4011140112) {
if(R.isCont($e4011140112)) {
var $ss4011540116 = {"from":L[2249],
"go":function(anf_arg228840121) {
return $Hanf_arg914740122(anf_arg228840121,_plus55);
}};
$e4011140112.stack[R.EXN_STACKHEIGHT++] = $ss4011540116;
}
if(R.isPyretException($e4011140112)) {
$e4011140112.pyretStack.push(L[2249]);
}
throw $e4011140112;
}
var $ret4011740118 = $Hanf_arg914740122($z4011340114,_plus55);
++R.GAS;
return $ret4011740118;
};
var $Hanf_arg914740122 = function(anf_arg228840121,_plus55) {
var $z4012540126 = D;
var $f4013140132 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-cases"),anf_arg228840121):R.ffi.throwNonFunApp(L[2249],_plus55,[("s-cases"),anf_arg228840121]);
};
try {
if(--R.GAS > 0) {
$z4012540126 = $f4013140132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4013140132,
"from":L[2249]});
}
} catch($e4012340124) {
if(R.isCont($e4012340124)) {
var $ss4012740128 = {"from":L[2249],
"go":function(ann_DASH_check_DASH_temp227240133) {
return $Hann_DASH_check_DASH_temp914640134(ann_DASH_check_DASH_temp227240133);
}};
$e4012340124.stack[R.EXN_STACKHEIGHT++] = $ss4012740128;
}
if(R.isPyretException($e4012340124)) {
$e4012340124.pyretStack.push(L[2249]);
}
throw $e4012340124;
}
var $ret4012940130 = $Hann_DASH_check_DASH_temp914640134($z4012540126);
++R.GAS;
return $ret4012940130;
};
var $Hann_DASH_check_DASH_temp914640134 = function(ann_DASH_check_DASH_temp227240133) {
return ann_DASH_check_DASH_temp227240133;
};
var $Hcont_tail_arg914415236 = function(cont_tail_arg226915234,if_helper225815235) {
if(--R.GAS > 0) {
$z4013540136 = R.isFunction(if_helper225815235)?if_helper225815235.app(cont_tail_arg226915234):R.ffi.throwNonFunApp(L[2249],if_helper225815235,[cont_tail_arg226915234]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper225815235)?if_helper225815235.app(cont_tail_arg226915234):R.ffi.throwNonFunApp(L[2249],if_helper225815235,[cont_tail_arg226915234]);
},
"from":L[2249]});
}
++R.GAS;
return $z4013540136;
};
var $Hcont_tail_arg914515251 = function(cont_tail_arg226315250,if_helper225815235) {
if(--R.GAS > 0) {
$z4013740138 = R.isFunction(if_helper225815235)?if_helper225815235.app(cont_tail_arg226315250):R.ffi.throwNonFunApp(L[2249],if_helper225815235,[cont_tail_arg226315250]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper225815235)?if_helper225815235.app(cont_tail_arg226315250):R.ffi.throwNonFunApp(L[2249],if_helper225815235,[cont_tail_arg226315250]);
},
"from":L[2249]});
}
++R.GAS;
return $z4013740138;
};
var $Hanf_arg914315272 = function(anf_arg223815269,INDENT118169,PP170,anf_fun223715270,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55) {
var anf_bracket223940167 = G(self76515271,"branches",L[4564]);
var anf_fun224040149 = G(anf_bracket223940167,"map",L[4563]);
var anf_arg224340150 = R.makeFunction(function(b76740153) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4561],1,arguments);
}
var anf_fun224240164 = G(b76740153,"tosource",L[4562]);
var $z4015640157 = D;
var $f4016240163 = function(_) {
return R.isFunction(anf_fun224240164)?anf_fun224240164.app():R.ffi.throwNonFunApp(L[4561],anf_fun224240164,[]);
};
try {
if(--R.GAS > 0) {
$z4015640157 = $f4016240163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4016240163,
"from":L[4561]});
}
} catch($e4015440155) {
if(R.isCont($e4015440155)) {
var $ss4015840159 = {"from":L[4561],
"go":function(ann_DASH_check_DASH_temp224140165) {
return $Hann_DASH_check_DASH_temp913140166(ann_DASH_check_DASH_temp224140165);
}};
$e4015440155.stack[R.EXN_STACKHEIGHT++] = $ss4015840159;
}
if(R.isPyretException($e4015440155)) {
$e4015440155.pyretStack.push(L[4561]);
}
throw $e4015440155;
}
var $ret4016040161 = $Hann_DASH_check_DASH_temp913140166($z4015640157);
++R.GAS;
return $ret4016040161;
});
var $z4014140142 = D;
var $f4014740148 = function(_) {
return R.isFunction(anf_fun224040149)?anf_fun224040149.app(anf_arg224340150):R.ffi.throwNonFunApp(L[4560],anf_fun224040149,[anf_arg224340150]);
};
try {
if(--R.GAS > 0) {
$z4014140142 = $f4014740148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4014740148,
"from":L[4560]});
}
} catch($e4013940140) {
if(R.isCont($e4013940140)) {
var $ss4014340144 = {"from":L[4560],
"go":function(anf_arg224440151) {
return $Hanf_arg914240152(anf_arg224440151,INDENT118169,PP170,anf_arg223815269,anf_fun223715270,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
}};
$e4013940140.stack[R.EXN_STACKHEIGHT++] = $ss4014340144;
}
if(R.isPyretException($e4013940140)) {
$e4013940140.pyretStack.push(L[4560]);
}
throw $e4013940140;
}
var $ret4014540146 = $Hanf_arg914240152($z4014140142,INDENT118169,PP170,anf_arg223815269,anf_fun223715270,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4014540146;
};
var $Hanf_arg914240152 = function(anf_arg224440151,INDENT118169,PP170,anf_arg223815269,anf_fun223715270,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55) {
var $z4017040171 = D;
var $f4017640177 = function(_) {
return R.isFunction(anf_fun223715270)?anf_fun223715270.app(anf_arg223815269,anf_arg224440151):R.ffi.throwNonFunApp(L[4565],anf_fun223715270,[anf_arg223815269,anf_arg224440151]);
};
try {
if(--R.GAS > 0) {
$z4017040171 = $f4017640177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4017640177,
"from":L[4565]});
}
} catch($e4016840169) {
if(R.isCont($e4016840169)) {
var $ss4017240173 = {"from":L[4565],
"go":function(branches76640178) {
return $Hbranches914140179(branches76640178,INDENT118169,PP170,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
}};
$e4016840169.stack[R.EXN_STACKHEIGHT++] = $ss4017240173;
}
if(R.isPyretException($e4016840169)) {
$e4016840169.pyretStack.push(L[4565]);
}
throw $e4016840169;
}
var $ret4017440175 = $Hbranches914140179($z4017040171,INDENT118169,PP170,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4017440175;
};
var $Hbranches914140179 = function(branches76640178,INDENT118169,PP170,break_DASH_one119168,self76515271,str_DASH_elsecolon145507,str_DASH_end148546,_plus55) {
var anf_fun224540192 = G(PP170,"nest",L[4569]);
var anf_bracket224640194 = G(self76515271,"_else",L[4568]);
var anf_fun224740190 = G(anf_bracket224640194,"tosource",L[4567]);
var $z4018240183 = D;
var $f4018840189 = function(_) {
return R.isFunction(anf_fun224740190)?anf_fun224740190.app():R.ffi.throwNonFunApp(L[4566],anf_fun224740190,[]);
};
try {
if(--R.GAS > 0) {
$z4018240183 = $f4018840189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4018840189,
"from":L[4566]});
}
} catch($e4018040181) {
if(R.isCont($e4018040181)) {
var $ss4018440185 = {"from":L[4566],
"go":function(anf_arg224840191) {
return $Hanf_arg914040193(anf_arg224840191,INDENT118169,PP170,anf_fun224540192,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
}};
$e4018040181.stack[R.EXN_STACKHEIGHT++] = $ss4018440185;
}
if(R.isPyretException($e4018040181)) {
$e4018040181.pyretStack.push(L[4566]);
}
throw $e4018040181;
}
var $ret4018640187 = $Hanf_arg914040193($z4018240183,INDENT118169,PP170,anf_fun224540192,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4018640187;
};
var $Hanf_arg914040193 = function(anf_arg224840191,INDENT118169,PP170,anf_fun224540192,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55) {
var $z4019740198 = D;
var $f4020340204 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,anf_arg224840191):R.ffi.throwNonFunApp(L[4570],_plus55,[break_DASH_one119168,anf_arg224840191]);
};
try {
if(--R.GAS > 0) {
$z4019740198 = $f4020340204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4020340204,
"from":L[4570]});
}
} catch($e4019540196) {
if(R.isCont($e4019540196)) {
var $ss4019940200 = {"from":L[4570],
"go":function(anf_arg224940205) {
return $Hanf_arg913940206(anf_arg224940205,INDENT118169,PP170,anf_fun224540192,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
}};
$e4019540196.stack[R.EXN_STACKHEIGHT++] = $ss4019940200;
}
if(R.isPyretException($e4019540196)) {
$e4019540196.pyretStack.push(L[4570]);
}
throw $e4019540196;
}
var $ret4020140202 = $Hanf_arg913940206($z4019740198,INDENT118169,PP170,anf_fun224540192,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4020140202;
};
var $Hanf_arg913940206 = function(anf_arg224940205,INDENT118169,PP170,anf_fun224540192,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55) {
var $z4020940210 = D;
var $f4021540216 = function(_) {
return R.isFunction(anf_fun224540192)?anf_fun224540192.app(INDENT118169,anf_arg224940205):R.ffi.throwNonFunApp(L[4571],anf_fun224540192,[INDENT118169,anf_arg224940205]);
};
try {
if(--R.GAS > 0) {
$z4020940210 = $f4021540216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4021540216,
"from":L[4571]});
}
} catch($e4020740208) {
if(R.isCont($e4020740208)) {
var $ss4021140212 = {"from":L[4571],
"go":function(anf_arg225040217) {
return $Hanf_arg913840218(anf_arg225040217,PP170,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
}};
$e4020740208.stack[R.EXN_STACKHEIGHT++] = $ss4021140212;
}
if(R.isPyretException($e4020740208)) {
$e4020740208.pyretStack.push(L[4571]);
}
throw $e4020740208;
}
var $ret4021340214 = $Hanf_arg913840218($z4020940210,PP170,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4021340214;
};
var $Hanf_arg913840218 = function(anf_arg225040217,PP170,branches76640178,break_DASH_one119168,str_DASH_elsecolon145507,str_DASH_end148546,_plus55) {
var $z4022140222 = D;
var $f4022740228 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_elsecolon145507,anf_arg225040217):R.ffi.throwNonFunApp(L[4572],_plus55,[str_DASH_elsecolon145507,anf_arg225040217]);
};
try {
if(--R.GAS > 0) {
$z4022140222 = $f4022740228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4022740228,
"from":L[4572]});
}
} catch($e4021940220) {
if(R.isCont($e4021940220)) {
var $ss4022340224 = {"from":L[4572],
"go":function(_else76840229) {
return $H_else913740230(_else76840229,PP170,branches76640178,break_DASH_one119168,str_DASH_end148546,_plus55);
}};
$e4021940220.stack[R.EXN_STACKHEIGHT++] = $ss4022340224;
}
if(R.isPyretException($e4021940220)) {
$e4021940220.pyretStack.push(L[4572]);
}
throw $e4021940220;
}
var $ret4022540226 = $H_else913740230($z4022140222,PP170,branches76640178,break_DASH_one119168,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4022540226;
};
var $H_else913740230 = function(_else76840229,PP170,branches76640178,break_DASH_one119168,str_DASH_end148546,_plus55) {
var anf_fun225140242 = G(PP170,"group",L[4574]);
var $z4023340234 = D;
var $f4023940240 = function(_) {
return R.isFunction(_plus55)?_plus55.app(branches76640178,break_DASH_one119168):R.ffi.throwNonFunApp(L[4573],_plus55,[branches76640178,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4023340234 = $f4023940240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4023940240,
"from":L[4573]});
}
} catch($e4023140232) {
if(R.isCont($e4023140232)) {
var $ss4023540236 = {"from":L[4573],
"go":function(anf_arg225240241) {
return $Hanf_arg913640243(anf_arg225240241,_else76840229,anf_fun225140242,break_DASH_one119168,str_DASH_end148546,_plus55);
}};
$e4023140232.stack[R.EXN_STACKHEIGHT++] = $ss4023540236;
}
if(R.isPyretException($e4023140232)) {
$e4023140232.pyretStack.push(L[4573]);
}
throw $e4023140232;
}
var $ret4023740238 = $Hanf_arg913640243($z4023340234,_else76840229,anf_fun225140242,break_DASH_one119168,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4023740238;
};
var $Hanf_arg913640243 = function(anf_arg225240241,_else76840229,anf_fun225140242,break_DASH_one119168,str_DASH_end148546,_plus55) {
var $z4024640247 = D;
var $f4025240253 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg225240241,_else76840229):R.ffi.throwNonFunApp(L[4573],_plus55,[anf_arg225240241,_else76840229]);
};
try {
if(--R.GAS > 0) {
$z4024640247 = $f4025240253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4025240253,
"from":L[4573]});
}
} catch($e4024440245) {
if(R.isCont($e4024440245)) {
var $ss4024840249 = {"from":L[4573],
"go":function(anf_arg225340254) {
return $Hanf_arg913540255(anf_arg225340254,anf_fun225140242,break_DASH_one119168,str_DASH_end148546,_plus55);
}};
$e4024440245.stack[R.EXN_STACKHEIGHT++] = $ss4024840249;
}
if(R.isPyretException($e4024440245)) {
$e4024440245.pyretStack.push(L[4573]);
}
throw $e4024440245;
}
var $ret4025040251 = $Hanf_arg913540255($z4024640247,anf_fun225140242,break_DASH_one119168,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4025040251;
};
var $Hanf_arg913540255 = function(anf_arg225340254,anf_fun225140242,break_DASH_one119168,str_DASH_end148546,_plus55) {
var $z4025840259 = D;
var $f4026440265 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg225340254,break_DASH_one119168):R.ffi.throwNonFunApp(L[4573],_plus55,[anf_arg225340254,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4025840259 = $f4026440265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4026440265,
"from":L[4573]});
}
} catch($e4025640257) {
if(R.isCont($e4025640257)) {
var $ss4026040261 = {"from":L[4573],
"go":function(anf_arg225440266) {
return $Hanf_arg913440267(anf_arg225440266,anf_fun225140242,str_DASH_end148546,_plus55);
}};
$e4025640257.stack[R.EXN_STACKHEIGHT++] = $ss4026040261;
}
if(R.isPyretException($e4025640257)) {
$e4025640257.pyretStack.push(L[4573]);
}
throw $e4025640257;
}
var $ret4026240263 = $Hanf_arg913440267($z4025840259,anf_fun225140242,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4026240263;
};
var $Hanf_arg913440267 = function(anf_arg225440266,anf_fun225140242,str_DASH_end148546,_plus55) {
var $z4027040271 = D;
var $f4027640277 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg225440266,str_DASH_end148546):R.ffi.throwNonFunApp(L[4573],_plus55,[anf_arg225440266,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4027040271 = $f4027640277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4027640277,
"from":L[4573]});
}
} catch($e4026840269) {
if(R.isCont($e4026840269)) {
var $ss4027240273 = {"from":L[4573],
"go":function(anf_arg225540278) {
return $Hanf_arg913340279(anf_arg225540278,anf_fun225140242);
}};
$e4026840269.stack[R.EXN_STACKHEIGHT++] = $ss4027240273;
}
if(R.isPyretException($e4026840269)) {
$e4026840269.pyretStack.push(L[4573]);
}
throw $e4026840269;
}
var $ret4027440275 = $Hanf_arg913340279($z4027040271,anf_fun225140242);
++R.GAS;
return $ret4027440275;
};
var $Hanf_arg913340279 = function(anf_arg225540278,anf_fun225140242) {
var $z4028240283 = D;
var $f4028840289 = function(_) {
return R.isFunction(anf_fun225140242)?anf_fun225140242.app(anf_arg225540278):R.ffi.throwNonFunApp(L[2829],anf_fun225140242,[anf_arg225540278]);
};
try {
if(--R.GAS > 0) {
$z4028240283 = $f4028840289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4028840289,
"from":L[2829]});
}
} catch($e4028040281) {
if(R.isCont($e4028040281)) {
var $ss4028440285 = {"from":L[2829],
"go":function(ann_DASH_check_DASH_temp223640290) {
return $Hann_DASH_check_DASH_temp913240291(ann_DASH_check_DASH_temp223640290);
}};
$e4028040281.stack[R.EXN_STACKHEIGHT++] = $ss4028440285;
}
if(R.isPyretException($e4028040281)) {
$e4028040281.pyretStack.push(L[2829]);
}
throw $e4028040281;
}
var $ret4028640287 = $Hann_DASH_check_DASH_temp913240291($z4028240283);
++R.GAS;
return $ret4028640287;
};
var $Hann_DASH_check_DASH_temp913240291 = function(ann_DASH_check_DASH_temp223640290) {
return ann_DASH_check_DASH_temp223640290;
};
var $Hann_DASH_check_DASH_temp913140166 = function(ann_DASH_check_DASH_temp224140165) {
return ann_DASH_check_DASH_temp224140165;
};
var $Hanf_arg913015288 = function(anf_arg222215286,self28715287,_plus55,torepr65) {
var anf_arg222340302 = G(self28715287,"branches",L[2250]);
var $z4029440295 = D;
var $f4030040301 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg222340302):R.ffi.throwNonFunApp(L[2250],torepr65,[anf_arg222340302]);
};
try {
if(--R.GAS > 0) {
$z4029440295 = $f4030040301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4030040301,
"from":L[2250]});
}
} catch($e4029240293) {
if(R.isCont($e4029240293)) {
var $ss4029640297 = {"from":L[2250],
"go":function(anf_arg222440303) {
return $Hanf_arg912940304(anf_arg222440303,anf_arg222215286,self28715287,_plus55,torepr65);
}};
$e4029240293.stack[R.EXN_STACKHEIGHT++] = $ss4029640297;
}
if(R.isPyretException($e4029240293)) {
$e4029240293.pyretStack.push(L[2250]);
}
throw $e4029240293;
}
var $ret4029840299 = $Hanf_arg912940304($z4029440295,anf_arg222215286,self28715287,_plus55,torepr65);
++R.GAS;
return $ret4029840299;
};
var $Hanf_arg912940304 = function(anf_arg222440303,anf_arg222215286,self28715287,_plus55,torepr65) {
var $z4030740308 = D;
var $f4031340314 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg222440303):R.ffi.throwNonFunApp(L[2250],_plus55,[(", "),anf_arg222440303]);
};
try {
if(--R.GAS > 0) {
$z4030740308 = $f4031340314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4031340314,
"from":L[2250]});
}
} catch($e4030540306) {
if(R.isCont($e4030540306)) {
var $ss4030940310 = {"from":L[2250],
"go":function(anf_arg222540315) {
return $Hanf_arg912840316(anf_arg222540315,anf_arg222215286,self28715287,_plus55,torepr65);
}};
$e4030540306.stack[R.EXN_STACKHEIGHT++] = $ss4030940310;
}
if(R.isPyretException($e4030540306)) {
$e4030540306.pyretStack.push(L[2250]);
}
throw $e4030540306;
}
var $ret4031140312 = $Hanf_arg912840316($z4030740308,anf_arg222215286,self28715287,_plus55,torepr65);
++R.GAS;
return $ret4031140312;
};
var $Hanf_arg912840316 = function(anf_arg222540315,anf_arg222215286,self28715287,_plus55,torepr65) {
var $z4031940320 = D;
var $f4032540326 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg222215286,anf_arg222540315):R.ffi.throwNonFunApp(L[2250],_plus55,[anf_arg222215286,anf_arg222540315]);
};
try {
if(--R.GAS > 0) {
$z4031940320 = $f4032540326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4032540326,
"from":L[2250]});
}
} catch($e4031740318) {
if(R.isCont($e4031740318)) {
var $ss4032140322 = {"from":L[2250],
"go":function(anf_arg222640327) {
return $Hanf_arg912740328(anf_arg222640327,self28715287,_plus55,torepr65);
}};
$e4031740318.stack[R.EXN_STACKHEIGHT++] = $ss4032140322;
}
if(R.isPyretException($e4031740318)) {
$e4031740318.pyretStack.push(L[2250]);
}
throw $e4031740318;
}
var $ret4032340324 = $Hanf_arg912740328($z4031940320,self28715287,_plus55,torepr65);
++R.GAS;
return $ret4032340324;
};
var $Hanf_arg912740328 = function(anf_arg222640327,self28715287,_plus55,torepr65) {
var anf_arg222740339 = G(self28715287,"_else",L[2250]);
var $z4033140332 = D;
var $f4033740338 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg222740339):R.ffi.throwNonFunApp(L[2250],torepr65,[anf_arg222740339]);
};
try {
if(--R.GAS > 0) {
$z4033140332 = $f4033740338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4033740338,
"from":L[2250]});
}
} catch($e4032940330) {
if(R.isCont($e4032940330)) {
var $ss4033340334 = {"from":L[2250],
"go":function(anf_arg222840340) {
return $Hanf_arg912640341(anf_arg222840340,anf_arg222640327,_plus55);
}};
$e4032940330.stack[R.EXN_STACKHEIGHT++] = $ss4033340334;
}
if(R.isPyretException($e4032940330)) {
$e4032940330.pyretStack.push(L[2250]);
}
throw $e4032940330;
}
var $ret4033540336 = $Hanf_arg912640341($z4033140332,anf_arg222640327,_plus55);
++R.GAS;
return $ret4033540336;
};
var $Hanf_arg912640341 = function(anf_arg222840340,anf_arg222640327,_plus55) {
var $z4034440345 = D;
var $f4035040351 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg222840340):R.ffi.throwNonFunApp(L[2250],_plus55,[(", "),anf_arg222840340]);
};
try {
if(--R.GAS > 0) {
$z4034440345 = $f4035040351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4035040351,
"from":L[2250]});
}
} catch($e4034240343) {
if(R.isCont($e4034240343)) {
var $ss4034640347 = {"from":L[2250],
"go":function(anf_arg222940352) {
return $Hanf_arg912540353(anf_arg222940352,anf_arg222640327,_plus55);
}};
$e4034240343.stack[R.EXN_STACKHEIGHT++] = $ss4034640347;
}
if(R.isPyretException($e4034240343)) {
$e4034240343.pyretStack.push(L[2250]);
}
throw $e4034240343;
}
var $ret4034840349 = $Hanf_arg912540353($z4034440345,anf_arg222640327,_plus55);
++R.GAS;
return $ret4034840349;
};
var $Hanf_arg912540353 = function(anf_arg222940352,anf_arg222640327,_plus55) {
var $z4035640357 = D;
var $f4036240363 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg222640327,anf_arg222940352):R.ffi.throwNonFunApp(L[2250],_plus55,[anf_arg222640327,anf_arg222940352]);
};
try {
if(--R.GAS > 0) {
$z4035640357 = $f4036240363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4036240363,
"from":L[2250]});
}
} catch($e4035440355) {
if(R.isCont($e4035440355)) {
var $ss4035840359 = {"from":L[2250],
"go":function(anf_arg223040364) {
return $Hanf_arg912440365(anf_arg223040364,_plus55);
}};
$e4035440355.stack[R.EXN_STACKHEIGHT++] = $ss4035840359;
}
if(R.isPyretException($e4035440355)) {
$e4035440355.pyretStack.push(L[2250]);
}
throw $e4035440355;
}
var $ret4036040361 = $Hanf_arg912440365($z4035640357,_plus55);
++R.GAS;
return $ret4036040361;
};
var $Hanf_arg912440365 = function(anf_arg223040364,_plus55) {
var $z4036840369 = D;
var $f4037440375 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg223040364,(")")):R.ffi.throwNonFunApp(L[2250],_plus55,[anf_arg223040364,(")")]);
};
try {
if(--R.GAS > 0) {
$z4036840369 = $f4037440375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4037440375,
"from":L[2250]});
}
} catch($e4036640367) {
if(R.isCont($e4036640367)) {
var $ss4037040371 = {"from":L[2250],
"go":function(anf_arg223140376) {
return $Hanf_arg912340377(anf_arg223140376,_plus55);
}};
$e4036640367.stack[R.EXN_STACKHEIGHT++] = $ss4037040371;
}
if(R.isPyretException($e4036640367)) {
$e4036640367.pyretStack.push(L[2250]);
}
throw $e4036640367;
}
var $ret4037240373 = $Hanf_arg912340377($z4036840369,_plus55);
++R.GAS;
return $ret4037240373;
};
var $Hanf_arg912340377 = function(anf_arg223140376,_plus55) {
var $z4038040381 = D;
var $f4038640387 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg223140376):R.ffi.throwNonFunApp(L[2250],_plus55,[("("),anf_arg223140376]);
};
try {
if(--R.GAS > 0) {
$z4038040381 = $f4038640387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4038640387,
"from":L[2250]});
}
} catch($e4037840379) {
if(R.isCont($e4037840379)) {
var $ss4038240383 = {"from":L[2250],
"go":function(anf_arg223240388) {
return $Hanf_arg912240389(anf_arg223240388,_plus55);
}};
$e4037840379.stack[R.EXN_STACKHEIGHT++] = $ss4038240383;
}
if(R.isPyretException($e4037840379)) {
$e4037840379.pyretStack.push(L[2250]);
}
throw $e4037840379;
}
var $ret4038440385 = $Hanf_arg912240389($z4038040381,_plus55);
++R.GAS;
return $ret4038440385;
};
var $Hanf_arg912240389 = function(anf_arg223240388,_plus55) {
var $z4039240393 = D;
var $f4039840399 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-if-else"),anf_arg223240388):R.ffi.throwNonFunApp(L[2250],_plus55,[("s-if-else"),anf_arg223240388]);
};
try {
if(--R.GAS > 0) {
$z4039240393 = $f4039840399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4039840399,
"from":L[2250]});
}
} catch($e4039040391) {
if(R.isCont($e4039040391)) {
var $ss4039440395 = {"from":L[2250],
"go":function(ann_DASH_check_DASH_temp222040400) {
return $Hann_DASH_check_DASH_temp912140401(ann_DASH_check_DASH_temp222040400);
}};
$e4039040391.stack[R.EXN_STACKHEIGHT++] = $ss4039440395;
}
if(R.isPyretException($e4039040391)) {
$e4039040391.pyretStack.push(L[2250]);
}
throw $e4039040391;
}
var $ret4039640397 = $Hann_DASH_check_DASH_temp912140401($z4039240393);
++R.GAS;
return $ret4039640397;
};
var $Hann_DASH_check_DASH_temp912140401 = function(ann_DASH_check_DASH_temp222040400) {
return ann_DASH_check_DASH_temp222040400;
};
var $Hcont_tail_arg911915305 = function(cont_tail_arg221715303,if_helper220715304) {
if(--R.GAS > 0) {
$z4040240403 = R.isFunction(if_helper220715304)?if_helper220715304.app(cont_tail_arg221715303):R.ffi.throwNonFunApp(L[2250],if_helper220715304,[cont_tail_arg221715303]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper220715304)?if_helper220715304.app(cont_tail_arg221715303):R.ffi.throwNonFunApp(L[2250],if_helper220715304,[cont_tail_arg221715303]);
},
"from":L[2250]});
}
++R.GAS;
return $z4040240403;
};
var $Hcont_tail_arg912015320 = function(cont_tail_arg221215319,if_helper220715304) {
if(--R.GAS > 0) {
$z4040440405 = R.isFunction(if_helper220715304)?if_helper220715304.app(cont_tail_arg221215319):R.ffi.throwNonFunApp(L[2250],if_helper220715304,[cont_tail_arg221215319]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper220715304)?if_helper220715304.app(cont_tail_arg221215319):R.ffi.throwNonFunApp(L[2250],if_helper220715304,[cont_tail_arg221215319]);
},
"from":L[2250]});
}
++R.GAS;
return $z4040440405;
};
var $Hanf_arg911815341 = function(anf_arg219515338,PP170,anf_fun219415339,break_DASH_one119168,self75815340,str_DASH_end148546,_plus55) {
var anf_bracket219640434 = G(self75815340,"branches",L[4579]);
var anf_fun219740416 = G(anf_bracket219640434,"map",L[4578]);
var anf_arg220040417 = R.makeFunction(function(b76040420) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4576],1,arguments);
}
var anf_fun219940431 = G(b76040420,"tosource",L[4577]);
var $z4042340424 = D;
var $f4042940430 = function(_) {
return R.isFunction(anf_fun219940431)?anf_fun219940431.app():R.ffi.throwNonFunApp(L[4576],anf_fun219940431,[]);
};
try {
if(--R.GAS > 0) {
$z4042340424 = $f4042940430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4042940430,
"from":L[4576]});
}
} catch($e4042140422) {
if(R.isCont($e4042140422)) {
var $ss4042540426 = {"from":L[4576],
"go":function(ann_DASH_check_DASH_temp219840432) {
return $Hann_DASH_check_DASH_temp911240433(ann_DASH_check_DASH_temp219840432);
}};
$e4042140422.stack[R.EXN_STACKHEIGHT++] = $ss4042540426;
}
if(R.isPyretException($e4042140422)) {
$e4042140422.pyretStack.push(L[4576]);
}
throw $e4042140422;
}
var $ret4042740428 = $Hann_DASH_check_DASH_temp911240433($z4042340424);
++R.GAS;
return $ret4042740428;
});
var $z4040840409 = D;
var $f4041440415 = function(_) {
return R.isFunction(anf_fun219740416)?anf_fun219740416.app(anf_arg220040417):R.ffi.throwNonFunApp(L[4575],anf_fun219740416,[anf_arg220040417]);
};
try {
if(--R.GAS > 0) {
$z4040840409 = $f4041440415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4041440415,
"from":L[4575]});
}
} catch($e4040640407) {
if(R.isCont($e4040640407)) {
var $ss4041040411 = {"from":L[4575],
"go":function(anf_arg220140418) {
return $Hanf_arg911740419(anf_arg220140418,PP170,anf_arg219515338,anf_fun219415339,break_DASH_one119168,str_DASH_end148546,_plus55);
}};
$e4040640407.stack[R.EXN_STACKHEIGHT++] = $ss4041040411;
}
if(R.isPyretException($e4040640407)) {
$e4040640407.pyretStack.push(L[4575]);
}
throw $e4040640407;
}
var $ret4041240413 = $Hanf_arg911740419($z4040840409,PP170,anf_arg219515338,anf_fun219415339,break_DASH_one119168,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4041240413;
};
var $Hanf_arg911740419 = function(anf_arg220140418,PP170,anf_arg219515338,anf_fun219415339,break_DASH_one119168,str_DASH_end148546,_plus55) {
var $z4043740438 = D;
var $f4044340444 = function(_) {
return R.isFunction(anf_fun219415339)?anf_fun219415339.app(anf_arg219515338,anf_arg220140418):R.ffi.throwNonFunApp(L[4580],anf_fun219415339,[anf_arg219515338,anf_arg220140418]);
};
try {
if(--R.GAS > 0) {
$z4043740438 = $f4044340444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4044340444,
"from":L[4580]});
}
} catch($e4043540436) {
if(R.isCont($e4043540436)) {
var $ss4043940440 = {"from":L[4580],
"go":function(branches75940445) {
return $Hbranches911640446(branches75940445,PP170,break_DASH_one119168,str_DASH_end148546,_plus55);
}};
$e4043540436.stack[R.EXN_STACKHEIGHT++] = $ss4043940440;
}
if(R.isPyretException($e4043540436)) {
$e4043540436.pyretStack.push(L[4580]);
}
throw $e4043540436;
}
var $ret4044140442 = $Hbranches911640446($z4043740438,PP170,break_DASH_one119168,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4044140442;
};
var $Hbranches911640446 = function(branches75940445,PP170,break_DASH_one119168,str_DASH_end148546,_plus55) {
var anf_fun220240458 = G(PP170,"group",L[4582]);
var $z4044940450 = D;
var $f4045540456 = function(_) {
return R.isFunction(_plus55)?_plus55.app(branches75940445,break_DASH_one119168):R.ffi.throwNonFunApp(L[4581],_plus55,[branches75940445,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4044940450 = $f4045540456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4045540456,
"from":L[4581]});
}
} catch($e4044740448) {
if(R.isCont($e4044740448)) {
var $ss4045140452 = {"from":L[4581],
"go":function(anf_arg220340457) {
return $Hanf_arg911540459(anf_arg220340457,anf_fun220240458,str_DASH_end148546,_plus55);
}};
$e4044740448.stack[R.EXN_STACKHEIGHT++] = $ss4045140452;
}
if(R.isPyretException($e4044740448)) {
$e4044740448.pyretStack.push(L[4581]);
}
throw $e4044740448;
}
var $ret4045340454 = $Hanf_arg911540459($z4044940450,anf_fun220240458,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4045340454;
};
var $Hanf_arg911540459 = function(anf_arg220340457,anf_fun220240458,str_DASH_end148546,_plus55) {
var $z4046240463 = D;
var $f4046840469 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg220340457,str_DASH_end148546):R.ffi.throwNonFunApp(L[4581],_plus55,[anf_arg220340457,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4046240463 = $f4046840469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4046840469,
"from":L[4581]});
}
} catch($e4046040461) {
if(R.isCont($e4046040461)) {
var $ss4046440465 = {"from":L[4581],
"go":function(anf_arg220440470) {
return $Hanf_arg911440471(anf_arg220440470,anf_fun220240458);
}};
$e4046040461.stack[R.EXN_STACKHEIGHT++] = $ss4046440465;
}
if(R.isPyretException($e4046040461)) {
$e4046040461.pyretStack.push(L[4581]);
}
throw $e4046040461;
}
var $ret4046640467 = $Hanf_arg911440471($z4046240463,anf_fun220240458);
++R.GAS;
return $ret4046640467;
};
var $Hanf_arg911440471 = function(anf_arg220440470,anf_fun220240458) {
var $z4047440475 = D;
var $f4048040481 = function(_) {
return R.isFunction(anf_fun220240458)?anf_fun220240458.app(anf_arg220440470):R.ffi.throwNonFunApp(L[2836],anf_fun220240458,[anf_arg220440470]);
};
try {
if(--R.GAS > 0) {
$z4047440475 = $f4048040481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4048040481,
"from":L[2836]});
}
} catch($e4047240473) {
if(R.isCont($e4047240473)) {
var $ss4047640477 = {"from":L[2836],
"go":function(ann_DASH_check_DASH_temp219340482) {
return $Hann_DASH_check_DASH_temp911340483(ann_DASH_check_DASH_temp219340482);
}};
$e4047240473.stack[R.EXN_STACKHEIGHT++] = $ss4047640477;
}
if(R.isPyretException($e4047240473)) {
$e4047240473.pyretStack.push(L[2836]);
}
throw $e4047240473;
}
var $ret4047840479 = $Hann_DASH_check_DASH_temp911340483($z4047440475);
++R.GAS;
return $ret4047840479;
};
var $Hann_DASH_check_DASH_temp911340483 = function(ann_DASH_check_DASH_temp219340482) {
return ann_DASH_check_DASH_temp219340482;
};
var $Hann_DASH_check_DASH_temp911240433 = function(ann_DASH_check_DASH_temp219840432) {
return ann_DASH_check_DASH_temp219840432;
};
var $Hanf_arg911115357 = function(anf_arg218315355,self28115356,_plus55,torepr65) {
var anf_arg218440494 = G(self28115356,"branches",L[2251]);
var $z4048640487 = D;
var $f4049240493 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg218440494):R.ffi.throwNonFunApp(L[2251],torepr65,[anf_arg218440494]);
};
try {
if(--R.GAS > 0) {
$z4048640487 = $f4049240493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4049240493,
"from":L[2251]});
}
} catch($e4048440485) {
if(R.isCont($e4048440485)) {
var $ss4048840489 = {"from":L[2251],
"go":function(anf_arg218540495) {
return $Hanf_arg911040496(anf_arg218540495,anf_arg218315355,_plus55);
}};
$e4048440485.stack[R.EXN_STACKHEIGHT++] = $ss4048840489;
}
if(R.isPyretException($e4048440485)) {
$e4048440485.pyretStack.push(L[2251]);
}
throw $e4048440485;
}
var $ret4049040491 = $Hanf_arg911040496($z4048640487,anf_arg218315355,_plus55);
++R.GAS;
return $ret4049040491;
};
var $Hanf_arg911040496 = function(anf_arg218540495,anf_arg218315355,_plus55) {
var $z4049940500 = D;
var $f4050540506 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg218540495):R.ffi.throwNonFunApp(L[2251],_plus55,[(", "),anf_arg218540495]);
};
try {
if(--R.GAS > 0) {
$z4049940500 = $f4050540506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4050540506,
"from":L[2251]});
}
} catch($e4049740498) {
if(R.isCont($e4049740498)) {
var $ss4050140502 = {"from":L[2251],
"go":function(anf_arg218640507) {
return $Hanf_arg910940508(anf_arg218640507,anf_arg218315355,_plus55);
}};
$e4049740498.stack[R.EXN_STACKHEIGHT++] = $ss4050140502;
}
if(R.isPyretException($e4049740498)) {
$e4049740498.pyretStack.push(L[2251]);
}
throw $e4049740498;
}
var $ret4050340504 = $Hanf_arg910940508($z4049940500,anf_arg218315355,_plus55);
++R.GAS;
return $ret4050340504;
};
var $Hanf_arg910940508 = function(anf_arg218640507,anf_arg218315355,_plus55) {
var $z4051140512 = D;
var $f4051740518 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg218315355,anf_arg218640507):R.ffi.throwNonFunApp(L[2251],_plus55,[anf_arg218315355,anf_arg218640507]);
};
try {
if(--R.GAS > 0) {
$z4051140512 = $f4051740518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4051740518,
"from":L[2251]});
}
} catch($e4050940510) {
if(R.isCont($e4050940510)) {
var $ss4051340514 = {"from":L[2251],
"go":function(anf_arg218740519) {
return $Hanf_arg910840520(anf_arg218740519,_plus55);
}};
$e4050940510.stack[R.EXN_STACKHEIGHT++] = $ss4051340514;
}
if(R.isPyretException($e4050940510)) {
$e4050940510.pyretStack.push(L[2251]);
}
throw $e4050940510;
}
var $ret4051540516 = $Hanf_arg910840520($z4051140512,_plus55);
++R.GAS;
return $ret4051540516;
};
var $Hanf_arg910840520 = function(anf_arg218740519,_plus55) {
var $z4052340524 = D;
var $f4052940530 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg218740519,(")")):R.ffi.throwNonFunApp(L[2251],_plus55,[anf_arg218740519,(")")]);
};
try {
if(--R.GAS > 0) {
$z4052340524 = $f4052940530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4052940530,
"from":L[2251]});
}
} catch($e4052140522) {
if(R.isCont($e4052140522)) {
var $ss4052540526 = {"from":L[2251],
"go":function(anf_arg218840531) {
return $Hanf_arg910740532(anf_arg218840531,_plus55);
}};
$e4052140522.stack[R.EXN_STACKHEIGHT++] = $ss4052540526;
}
if(R.isPyretException($e4052140522)) {
$e4052140522.pyretStack.push(L[2251]);
}
throw $e4052140522;
}
var $ret4052740528 = $Hanf_arg910740532($z4052340524,_plus55);
++R.GAS;
return $ret4052740528;
};
var $Hanf_arg910740532 = function(anf_arg218840531,_plus55) {
var $z4053540536 = D;
var $f4054140542 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg218840531):R.ffi.throwNonFunApp(L[2251],_plus55,[("("),anf_arg218840531]);
};
try {
if(--R.GAS > 0) {
$z4053540536 = $f4054140542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4054140542,
"from":L[2251]});
}
} catch($e4053340534) {
if(R.isCont($e4053340534)) {
var $ss4053740538 = {"from":L[2251],
"go":function(anf_arg218940543) {
return $Hanf_arg910640544(anf_arg218940543,_plus55);
}};
$e4053340534.stack[R.EXN_STACKHEIGHT++] = $ss4053740538;
}
if(R.isPyretException($e4053340534)) {
$e4053340534.pyretStack.push(L[2251]);
}
throw $e4053340534;
}
var $ret4053940540 = $Hanf_arg910640544($z4053540536,_plus55);
++R.GAS;
return $ret4053940540;
};
var $Hanf_arg910640544 = function(anf_arg218940543,_plus55) {
var $z4054740548 = D;
var $f4055340554 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-if"),anf_arg218940543):R.ffi.throwNonFunApp(L[2251],_plus55,[("s-if"),anf_arg218940543]);
};
try {
if(--R.GAS > 0) {
$z4054740548 = $f4055340554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4055340554,
"from":L[2251]});
}
} catch($e4054540546) {
if(R.isCont($e4054540546)) {
var $ss4054940550 = {"from":L[2251],
"go":function(ann_DASH_check_DASH_temp218140555) {
return $Hann_DASH_check_DASH_temp910540556(ann_DASH_check_DASH_temp218140555);
}};
$e4054540546.stack[R.EXN_STACKHEIGHT++] = $ss4054940550;
}
if(R.isPyretException($e4054540546)) {
$e4054540546.pyretStack.push(L[2251]);
}
throw $e4054540546;
}
var $ret4055140552 = $Hann_DASH_check_DASH_temp910540556($z4054740548);
++R.GAS;
return $ret4055140552;
};
var $Hann_DASH_check_DASH_temp910540556 = function(ann_DASH_check_DASH_temp218140555) {
return ann_DASH_check_DASH_temp218140555;
};
var $Hcont_tail_arg910315373 = function(cont_tail_arg217815371,if_helper216915372) {
if(--R.GAS > 0) {
$z4055740558 = R.isFunction(if_helper216915372)?if_helper216915372.app(cont_tail_arg217815371):R.ffi.throwNonFunApp(L[2251],if_helper216915372,[cont_tail_arg217815371]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper216915372)?if_helper216915372.app(cont_tail_arg217815371):R.ffi.throwNonFunApp(L[2251],if_helper216915372,[cont_tail_arg217815371]);
},
"from":L[2251]});
}
++R.GAS;
return $z4055740558;
};
var $Hcont_tail_arg910415388 = function(cont_tail_arg217415387,if_helper216915372) {
if(--R.GAS > 0) {
$z4055940560 = R.isFunction(if_helper216915372)?if_helper216915372.app(cont_tail_arg217415387):R.ffi.throwNonFunApp(L[2251],if_helper216915372,[cont_tail_arg217415387]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper216915372)?if_helper216915372.app(cont_tail_arg217415387):R.ffi.throwNonFunApp(L[2251],if_helper216915372,[cont_tail_arg217415387]);
},
"from":L[2251]});
}
++R.GAS;
return $z4055940560;
};
var $Hanf_arg910215411 = function(anf_arg215315408,INDENT118169,PP170,anf_fun214515409,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55) {
var $z4056340564 = D;
var $f4056940570 = function(_) {
return R.isFunction(anf_fun214515409)?anf_fun214515409.app(break_DASH_one119168,anf_arg215315408):R.ffi.throwNonFunApp(L[4583],anf_fun214515409,[break_DASH_one119168,anf_arg215315408]);
};
try {
if(--R.GAS > 0) {
$z4056340564 = $f4056940570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4056940570,
"from":L[4583]});
}
} catch($e4056140562) {
if(R.isCont($e4056140562)) {
var $ss4056540566 = {"from":L[4583],
"go":function(anf_arg215440571) {
return $Hanf_arg910140572(anf_arg215440571,INDENT118169,PP170,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55);
}};
$e4056140562.stack[R.EXN_STACKHEIGHT++] = $ss4056540566;
}
if(R.isPyretException($e4056140562)) {
$e4056140562.pyretStack.push(L[4583]);
}
throw $e4056140562;
}
var $ret4056740568 = $Hanf_arg910140572($z4056340564,INDENT118169,PP170,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55);
++R.GAS;
return $ret4056740568;
};
var $Hanf_arg910140572 = function(anf_arg215440571,INDENT118169,PP170,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55) {
var $z4057540576 = D;
var $f4058140582 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg215440571,break_DASH_one119168):R.ffi.throwNonFunApp(L[4584],_plus55,[anf_arg215440571,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4057540576 = $f4058140582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4058140582,
"from":L[4584]});
}
} catch($e4057340574) {
if(R.isCont($e4057340574)) {
var $ss4057740578 = {"from":L[4584],
"go":function(anf_arg215540583) {
return $Hanf_arg910040584(anf_arg215540583,INDENT118169,PP170,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55);
}};
$e4057340574.stack[R.EXN_STACKHEIGHT++] = $ss4057740578;
}
if(R.isPyretException($e4057340574)) {
$e4057340574.pyretStack.push(L[4584]);
}
throw $e4057340574;
}
var $ret4057940580 = $Hanf_arg910040584($z4057540576,INDENT118169,PP170,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55);
++R.GAS;
return $ret4057940580;
};
var $Hanf_arg910040584 = function(anf_arg215540583,INDENT118169,PP170,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,str_DASH_otherwisecolon146520,str_DASH_pipespace162728,_plus55) {
var anf_fun215640596 = G(PP170,"group",L[4586]);
var $z4058740588 = D;
var $f4059340594 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_pipespace162728,str_DASH_otherwisecolon146520):R.ffi.throwNonFunApp(L[4585],_plus55,[str_DASH_pipespace162728,str_DASH_otherwisecolon146520]);
};
try {
if(--R.GAS > 0) {
$z4058740588 = $f4059340594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4059340594,
"from":L[4585]});
}
} catch($e4058540586) {
if(R.isCont($e4058540586)) {
var $ss4058940590 = {"from":L[4585],
"go":function(anf_arg215740595) {
return $Hanf_arg909940597(anf_arg215740595,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
}};
$e4058540586.stack[R.EXN_STACKHEIGHT++] = $ss4058940590;
}
if(R.isPyretException($e4058540586)) {
$e4058540586.pyretStack.push(L[4585]);
}
throw $e4058540586;
}
var $ret4059140592 = $Hanf_arg909940597($z4058740588,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4059140592;
};
var $Hanf_arg909940597 = function(anf_arg215740595,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,break_DASH_one119168,self75215410,str_DASH_askcolon156650,str_DASH_end148546,_plus55) {
var $z4060040601 = D;
var $f4060640607 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg215740595,break_DASH_one119168):R.ffi.throwNonFunApp(L[4585],_plus55,[anf_arg215740595,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4060040601 = $f4060640607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4060640607,
"from":L[4585]});
}
} catch($e4059840599) {
if(R.isCont($e4059840599)) {
var $ss4060240603 = {"from":L[4585],
"go":function(anf_arg215840608) {
return $Hanf_arg909840609(anf_arg215840608,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,self75215410,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
}};
$e4059840599.stack[R.EXN_STACKHEIGHT++] = $ss4060240603;
}
if(R.isPyretException($e4059840599)) {
$e4059840599.pyretStack.push(L[4585]);
}
throw $e4059840599;
}
var $ret4060440605 = $Hanf_arg909840609($z4060040601,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,self75215410,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4060440605;
};
var $Hanf_arg909840609 = function(anf_arg215840608,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,self75215410,str_DASH_askcolon156650,str_DASH_end148546,_plus55) {
var anf_bracket215940623 = G(self75215410,"_else",L[4589]);
var anf_fun216040620 = G(anf_bracket215940623,"tosource",L[4588]);
var $z4061240613 = D;
var $f4061840619 = function(_) {
return R.isFunction(anf_fun216040620)?anf_fun216040620.app():R.ffi.throwNonFunApp(L[4587],anf_fun216040620,[]);
};
try {
if(--R.GAS > 0) {
$z4061240613 = $f4061840619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4061840619,
"from":L[4587]});
}
} catch($e4061040611) {
if(R.isCont($e4061040611)) {
var $ss4061440615 = {"from":L[4587],
"go":function(anf_arg216140621) {
return $Hanf_arg909740622(anf_arg216140621,INDENT118169,PP170,anf_arg215540583,anf_arg215840608,anf_fun215640596,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
}};
$e4061040611.stack[R.EXN_STACKHEIGHT++] = $ss4061440615;
}
if(R.isPyretException($e4061040611)) {
$e4061040611.pyretStack.push(L[4587]);
}
throw $e4061040611;
}
var $ret4061640617 = $Hanf_arg909740622($z4061240613,INDENT118169,PP170,anf_arg215540583,anf_arg215840608,anf_fun215640596,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4061640617;
};
var $Hanf_arg909740622 = function(anf_arg216140621,INDENT118169,PP170,anf_arg215540583,anf_arg215840608,anf_fun215640596,str_DASH_askcolon156650,str_DASH_end148546,_plus55) {
var $z4062640627 = D;
var $f4063240633 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg215840608,anf_arg216140621):R.ffi.throwNonFunApp(L[4585],_plus55,[anf_arg215840608,anf_arg216140621]);
};
try {
if(--R.GAS > 0) {
$z4062640627 = $f4063240633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4063240633,
"from":L[4585]});
}
} catch($e4062440625) {
if(R.isCont($e4062440625)) {
var $ss4062840629 = {"from":L[4585],
"go":function(anf_arg216240634) {
return $Hanf_arg909640635(anf_arg216240634,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
}};
$e4062440625.stack[R.EXN_STACKHEIGHT++] = $ss4062840629;
}
if(R.isPyretException($e4062440625)) {
$e4062440625.pyretStack.push(L[4585]);
}
throw $e4062440625;
}
var $ret4063040631 = $Hanf_arg909640635($z4062640627,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4063040631;
};
var $Hanf_arg909640635 = function(anf_arg216240634,INDENT118169,PP170,anf_arg215540583,anf_fun215640596,str_DASH_askcolon156650,str_DASH_end148546,_plus55) {
var $z4063840639 = D;
var $f4064440645 = function(_) {
return R.isFunction(anf_fun215640596)?anf_fun215640596.app(anf_arg216240634):R.ffi.throwNonFunApp(L[4590],anf_fun215640596,[anf_arg216240634]);
};
try {
if(--R.GAS > 0) {
$z4063840639 = $f4064440645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4064440645,
"from":L[4590]});
}
} catch($e4063640637) {
if(R.isCont($e4063640637)) {
var $ss4064040641 = {"from":L[4590],
"go":function(anf_arg216340646) {
return $Hanf_arg909540647(anf_arg216340646,INDENT118169,PP170,anf_arg215540583,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
}};
$e4063640637.stack[R.EXN_STACKHEIGHT++] = $ss4064040641;
}
if(R.isPyretException($e4063640637)) {
$e4063640637.pyretStack.push(L[4590]);
}
throw $e4063640637;
}
var $ret4064240643 = $Hanf_arg909540647($z4063840639,INDENT118169,PP170,anf_arg215540583,str_DASH_askcolon156650,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4064240643;
};
var $Hanf_arg909540647 = function(anf_arg216340646,INDENT118169,PP170,anf_arg215540583,str_DASH_askcolon156650,str_DASH_end148546,_plus55) {
var $z4065040651 = D;
var $f4065640657 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg215540583,anf_arg216340646):R.ffi.throwNonFunApp(L[4591],_plus55,[anf_arg215540583,anf_arg216340646]);
};
try {
if(--R.GAS > 0) {
$z4065040651 = $f4065640657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4065640657,
"from":L[4591]});
}
} catch($e4064840649) {
if(R.isCont($e4064840649)) {
var $ss4065240653 = {"from":L[4591],
"go":function(body75340658) {
return $Hbody909440659(body75340658,INDENT118169,PP170,str_DASH_askcolon156650,str_DASH_end148546);
}};
$e4064840649.stack[R.EXN_STACKHEIGHT++] = $ss4065240653;
}
if(R.isPyretException($e4064840649)) {
$e4064840649.pyretStack.push(L[4591]);
}
throw $e4064840649;
}
var $ret4065440655 = $Hbody909440659($z4065040651,INDENT118169,PP170,str_DASH_askcolon156650,str_DASH_end148546);
++R.GAS;
return $ret4065440655;
};
var $Hbody909440659 = function(body75340658,INDENT118169,PP170,str_DASH_askcolon156650,str_DASH_end148546) {
var anf_fun216440672 = G(PP170,"surround",L[4594]);
var anf_fun216540670 = G(PP170,"group",L[4593]);
var $z4066240663 = D;
var $f4066840669 = function(_) {
return R.isFunction(anf_fun216540670)?anf_fun216540670.app(str_DASH_askcolon156650):R.ffi.throwNonFunApp(L[4592],anf_fun216540670,[str_DASH_askcolon156650]);
};
try {
if(--R.GAS > 0) {
$z4066240663 = $f4066840669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4066840669,
"from":L[4592]});
}
} catch($e4066040661) {
if(R.isCont($e4066040661)) {
var $ss4066440665 = {"from":L[4592],
"go":function(anf_arg216640671) {
return $Hanf_arg909340673(anf_arg216640671,INDENT118169,anf_fun216440672,body75340658,str_DASH_end148546);
}};
$e4066040661.stack[R.EXN_STACKHEIGHT++] = $ss4066440665;
}
if(R.isPyretException($e4066040661)) {
$e4066040661.pyretStack.push(L[4592]);
}
throw $e4066040661;
}
var $ret4066640667 = $Hanf_arg909340673($z4066240663,INDENT118169,anf_fun216440672,body75340658,str_DASH_end148546);
++R.GAS;
return $ret4066640667;
};
var $Hanf_arg909340673 = function(anf_arg216640671,INDENT118169,anf_fun216440672,body75340658,str_DASH_end148546) {
var $z4067640677 = D;
var $f4068240683 = function(_) {
return R.isFunction(anf_fun216440672)?anf_fun216440672.app(INDENT118169,(1),anf_arg216640671,body75340658,str_DASH_end148546):R.ffi.throwNonFunApp(L[2848],anf_fun216440672,[INDENT118169,(1),anf_arg216640671,body75340658,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4067640677 = $f4068240683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4068240683,
"from":L[2848]});
}
} catch($e4067440675) {
if(R.isCont($e4067440675)) {
var $ss4067840679 = {"from":L[2848],
"go":function(ann_DASH_check_DASH_temp214440684) {
return $Hann_DASH_check_DASH_temp909240685(ann_DASH_check_DASH_temp214440684);
}};
$e4067440675.stack[R.EXN_STACKHEIGHT++] = $ss4067840679;
}
if(R.isPyretException($e4067440675)) {
$e4067440675.pyretStack.push(L[2848]);
}
throw $e4067440675;
}
var $ret4068040681 = $Hann_DASH_check_DASH_temp909240685($z4067640677);
++R.GAS;
return $ret4068040681;
};
var $Hann_DASH_check_DASH_temp909240685 = function(ann_DASH_check_DASH_temp214440684) {
return ann_DASH_check_DASH_temp214440684;
};
var $Hanf_arg909115426 = function(anf_arg215115424,anf_fun214915425) {
var $z4068840689 = D;
var $f4069440695 = function(_) {
return R.isFunction(anf_fun214915425)?anf_fun214915425.app(anf_arg215115424):R.ffi.throwNonFunApp(L[2841],anf_fun214915425,[anf_arg215115424]);
};
try {
if(--R.GAS > 0) {
$z4068840689 = $f4069440695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4069440695,
"from":L[2841]});
}
} catch($e4068640687) {
if(R.isCont($e4068640687)) {
var $ss4069040691 = {"from":L[2841],
"go":function(ann_DASH_check_DASH_temp214840696) {
return $Hann_DASH_check_DASH_temp909040697(ann_DASH_check_DASH_temp214840696);
}};
$e4068640687.stack[R.EXN_STACKHEIGHT++] = $ss4069040691;
}
if(R.isPyretException($e4068640687)) {
$e4068640687.pyretStack.push(L[2841]);
}
throw $e4068640687;
}
var $ret4069240693 = $Hann_DASH_check_DASH_temp909040697($z4068840689);
++R.GAS;
return $ret4069240693;
};
var $Hann_DASH_check_DASH_temp909040697 = function(ann_DASH_check_DASH_temp214840696) {
return ann_DASH_check_DASH_temp214840696;
};
var $Hanf_arg908915443 = function(anf_arg213015441,self27515442,_plus55,torepr65) {
var anf_arg213140708 = G(self27515442,"branches",L[2252]);
var $z4070040701 = D;
var $f4070640707 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg213140708):R.ffi.throwNonFunApp(L[2252],torepr65,[anf_arg213140708]);
};
try {
if(--R.GAS > 0) {
$z4070040701 = $f4070640707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4070640707,
"from":L[2252]});
}
} catch($e4069840699) {
if(R.isCont($e4069840699)) {
var $ss4070240703 = {"from":L[2252],
"go":function(anf_arg213240709) {
return $Hanf_arg908840710(anf_arg213240709,anf_arg213015441,self27515442,_plus55,torepr65);
}};
$e4069840699.stack[R.EXN_STACKHEIGHT++] = $ss4070240703;
}
if(R.isPyretException($e4069840699)) {
$e4069840699.pyretStack.push(L[2252]);
}
throw $e4069840699;
}
var $ret4070440705 = $Hanf_arg908840710($z4070040701,anf_arg213015441,self27515442,_plus55,torepr65);
++R.GAS;
return $ret4070440705;
};
var $Hanf_arg908840710 = function(anf_arg213240709,anf_arg213015441,self27515442,_plus55,torepr65) {
var $z4071340714 = D;
var $f4071940720 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg213240709):R.ffi.throwNonFunApp(L[2252],_plus55,[(", "),anf_arg213240709]);
};
try {
if(--R.GAS > 0) {
$z4071340714 = $f4071940720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4071940720,
"from":L[2252]});
}
} catch($e4071140712) {
if(R.isCont($e4071140712)) {
var $ss4071540716 = {"from":L[2252],
"go":function(anf_arg213340721) {
return $Hanf_arg908740722(anf_arg213340721,anf_arg213015441,self27515442,_plus55,torepr65);
}};
$e4071140712.stack[R.EXN_STACKHEIGHT++] = $ss4071540716;
}
if(R.isPyretException($e4071140712)) {
$e4071140712.pyretStack.push(L[2252]);
}
throw $e4071140712;
}
var $ret4071740718 = $Hanf_arg908740722($z4071340714,anf_arg213015441,self27515442,_plus55,torepr65);
++R.GAS;
return $ret4071740718;
};
var $Hanf_arg908740722 = function(anf_arg213340721,anf_arg213015441,self27515442,_plus55,torepr65) {
var $z4072540726 = D;
var $f4073140732 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg213015441,anf_arg213340721):R.ffi.throwNonFunApp(L[2252],_plus55,[anf_arg213015441,anf_arg213340721]);
};
try {
if(--R.GAS > 0) {
$z4072540726 = $f4073140732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4073140732,
"from":L[2252]});
}
} catch($e4072340724) {
if(R.isCont($e4072340724)) {
var $ss4072740728 = {"from":L[2252],
"go":function(anf_arg213440733) {
return $Hanf_arg908640734(anf_arg213440733,self27515442,_plus55,torepr65);
}};
$e4072340724.stack[R.EXN_STACKHEIGHT++] = $ss4072740728;
}
if(R.isPyretException($e4072340724)) {
$e4072340724.pyretStack.push(L[2252]);
}
throw $e4072340724;
}
var $ret4072940730 = $Hanf_arg908640734($z4072540726,self27515442,_plus55,torepr65);
++R.GAS;
return $ret4072940730;
};
var $Hanf_arg908640734 = function(anf_arg213440733,self27515442,_plus55,torepr65) {
var anf_arg213540745 = G(self27515442,"_else",L[2252]);
var $z4073740738 = D;
var $f4074340744 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg213540745):R.ffi.throwNonFunApp(L[2252],torepr65,[anf_arg213540745]);
};
try {
if(--R.GAS > 0) {
$z4073740738 = $f4074340744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4074340744,
"from":L[2252]});
}
} catch($e4073540736) {
if(R.isCont($e4073540736)) {
var $ss4073940740 = {"from":L[2252],
"go":function(anf_arg213640746) {
return $Hanf_arg908540747(anf_arg213640746,anf_arg213440733,_plus55);
}};
$e4073540736.stack[R.EXN_STACKHEIGHT++] = $ss4073940740;
}
if(R.isPyretException($e4073540736)) {
$e4073540736.pyretStack.push(L[2252]);
}
throw $e4073540736;
}
var $ret4074140742 = $Hanf_arg908540747($z4073740738,anf_arg213440733,_plus55);
++R.GAS;
return $ret4074140742;
};
var $Hanf_arg908540747 = function(anf_arg213640746,anf_arg213440733,_plus55) {
var $z4075040751 = D;
var $f4075640757 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg213640746):R.ffi.throwNonFunApp(L[2252],_plus55,[(", "),anf_arg213640746]);
};
try {
if(--R.GAS > 0) {
$z4075040751 = $f4075640757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4075640757,
"from":L[2252]});
}
} catch($e4074840749) {
if(R.isCont($e4074840749)) {
var $ss4075240753 = {"from":L[2252],
"go":function(anf_arg213740758) {
return $Hanf_arg908440759(anf_arg213740758,anf_arg213440733,_plus55);
}};
$e4074840749.stack[R.EXN_STACKHEIGHT++] = $ss4075240753;
}
if(R.isPyretException($e4074840749)) {
$e4074840749.pyretStack.push(L[2252]);
}
throw $e4074840749;
}
var $ret4075440755 = $Hanf_arg908440759($z4075040751,anf_arg213440733,_plus55);
++R.GAS;
return $ret4075440755;
};
var $Hanf_arg908440759 = function(anf_arg213740758,anf_arg213440733,_plus55) {
var $z4076240763 = D;
var $f4076840769 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg213440733,anf_arg213740758):R.ffi.throwNonFunApp(L[2252],_plus55,[anf_arg213440733,anf_arg213740758]);
};
try {
if(--R.GAS > 0) {
$z4076240763 = $f4076840769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4076840769,
"from":L[2252]});
}
} catch($e4076040761) {
if(R.isCont($e4076040761)) {
var $ss4076440765 = {"from":L[2252],
"go":function(anf_arg213840770) {
return $Hanf_arg908340771(anf_arg213840770,_plus55);
}};
$e4076040761.stack[R.EXN_STACKHEIGHT++] = $ss4076440765;
}
if(R.isPyretException($e4076040761)) {
$e4076040761.pyretStack.push(L[2252]);
}
throw $e4076040761;
}
var $ret4076640767 = $Hanf_arg908340771($z4076240763,_plus55);
++R.GAS;
return $ret4076640767;
};
var $Hanf_arg908340771 = function(anf_arg213840770,_plus55) {
var $z4077440775 = D;
var $f4078040781 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg213840770,(")")):R.ffi.throwNonFunApp(L[2252],_plus55,[anf_arg213840770,(")")]);
};
try {
if(--R.GAS > 0) {
$z4077440775 = $f4078040781();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4078040781,
"from":L[2252]});
}
} catch($e4077240773) {
if(R.isCont($e4077240773)) {
var $ss4077640777 = {"from":L[2252],
"go":function(anf_arg213940782) {
return $Hanf_arg908240783(anf_arg213940782,_plus55);
}};
$e4077240773.stack[R.EXN_STACKHEIGHT++] = $ss4077640777;
}
if(R.isPyretException($e4077240773)) {
$e4077240773.pyretStack.push(L[2252]);
}
throw $e4077240773;
}
var $ret4077840779 = $Hanf_arg908240783($z4077440775,_plus55);
++R.GAS;
return $ret4077840779;
};
var $Hanf_arg908240783 = function(anf_arg213940782,_plus55) {
var $z4078640787 = D;
var $f4079240793 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg213940782):R.ffi.throwNonFunApp(L[2252],_plus55,[("("),anf_arg213940782]);
};
try {
if(--R.GAS > 0) {
$z4078640787 = $f4079240793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4079240793,
"from":L[2252]});
}
} catch($e4078440785) {
if(R.isCont($e4078440785)) {
var $ss4078840789 = {"from":L[2252],
"go":function(anf_arg214040794) {
return $Hanf_arg908140795(anf_arg214040794,_plus55);
}};
$e4078440785.stack[R.EXN_STACKHEIGHT++] = $ss4078840789;
}
if(R.isPyretException($e4078440785)) {
$e4078440785.pyretStack.push(L[2252]);
}
throw $e4078440785;
}
var $ret4079040791 = $Hanf_arg908140795($z4078640787,_plus55);
++R.GAS;
return $ret4079040791;
};
var $Hanf_arg908140795 = function(anf_arg214040794,_plus55) {
var $z4079840799 = D;
var $f4080440805 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-if-pipe-else"),anf_arg214040794):R.ffi.throwNonFunApp(L[2252],_plus55,[("s-if-pipe-else"),anf_arg214040794]);
};
try {
if(--R.GAS > 0) {
$z4079840799 = $f4080440805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4080440805,
"from":L[2252]});
}
} catch($e4079640797) {
if(R.isCont($e4079640797)) {
var $ss4080040801 = {"from":L[2252],
"go":function(ann_DASH_check_DASH_temp212840806) {
return $Hann_DASH_check_DASH_temp908040807(ann_DASH_check_DASH_temp212840806);
}};
$e4079640797.stack[R.EXN_STACKHEIGHT++] = $ss4080040801;
}
if(R.isPyretException($e4079640797)) {
$e4079640797.pyretStack.push(L[2252]);
}
throw $e4079640797;
}
var $ret4080240803 = $Hann_DASH_check_DASH_temp908040807($z4079840799);
++R.GAS;
return $ret4080240803;
};
var $Hann_DASH_check_DASH_temp908040807 = function(ann_DASH_check_DASH_temp212840806) {
return ann_DASH_check_DASH_temp212840806;
};
var $Hcont_tail_arg907815460 = function(cont_tail_arg212515458,if_helper211515459) {
if(--R.GAS > 0) {
$z4080840809 = R.isFunction(if_helper211515459)?if_helper211515459.app(cont_tail_arg212515458):R.ffi.throwNonFunApp(L[2252],if_helper211515459,[cont_tail_arg212515458]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper211515459)?if_helper211515459.app(cont_tail_arg212515458):R.ffi.throwNonFunApp(L[2252],if_helper211515459,[cont_tail_arg212515458]);
},
"from":L[2252]});
}
++R.GAS;
return $z4080840809;
};
var $Hcont_tail_arg907915475 = function(cont_tail_arg212015474,if_helper211515459) {
if(--R.GAS > 0) {
$z4081040811 = R.isFunction(if_helper211515459)?if_helper211515459.app(cont_tail_arg212015474):R.ffi.throwNonFunApp(L[2252],if_helper211515459,[cont_tail_arg212015474]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper211515459)?if_helper211515459.app(cont_tail_arg212015474):R.ffi.throwNonFunApp(L[2252],if_helper211515459,[cont_tail_arg212015474]);
},
"from":L[2252]});
}
++R.GAS;
return $z4081040811;
};
var $Hanf_arg907715496 = function(anf_arg210115493,INDENT118169,PP170,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_askcolon156650,str_DASH_end148546,_plus55) {
var $z4081440815 = D;
var $f4082040821 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg210115493,str_DASH_end148546):R.ffi.throwNonFunApp(L[2853],_plus55,[anf_arg210115493,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4081440815 = $f4082040821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4082040821,
"from":L[2853]});
}
} catch($e4081240813) {
if(R.isCont($e4081240813)) {
var $ss4081640817 = {"from":L[2853],
"go":function(anf_arg210240822) {
return $Hanf_arg907640823(anf_arg210240822,INDENT118169,PP170,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_askcolon156650,str_DASH_end148546);
}};
$e4081240813.stack[R.EXN_STACKHEIGHT++] = $ss4081640817;
}
if(R.isPyretException($e4081240813)) {
$e4081240813.pyretStack.push(L[2853]);
}
throw $e4081240813;
}
var $ret4081840819 = $Hanf_arg907640823($z4081440815,INDENT118169,PP170,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_askcolon156650,str_DASH_end148546);
++R.GAS;
return $ret4081840819;
};
var $Hanf_arg907640823 = function(anf_arg210240822,INDENT118169,PP170,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_askcolon156650,str_DASH_end148546) {
var anf_fun210340834 = G(PP170,"group",L[4596]);
var $z4082640827 = D;
var $f4083240833 = function(_) {
return R.isFunction(anf_fun210340834)?anf_fun210340834.app(str_DASH_askcolon156650):R.ffi.throwNonFunApp(L[4595],anf_fun210340834,[str_DASH_askcolon156650]);
};
try {
if(--R.GAS > 0) {
$z4082640827 = $f4083240833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4083240833,
"from":L[4595]});
}
} catch($e4082440825) {
if(R.isCont($e4082440825)) {
var $ss4082840829 = {"from":L[4595],
"go":function(anf_arg210440835) {
return $Hanf_arg907540836(anf_arg210440835,INDENT118169,PP170,anf_arg210240822,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_end148546);
}};
$e4082440825.stack[R.EXN_STACKHEIGHT++] = $ss4082840829;
}
if(R.isPyretException($e4082440825)) {
$e4082440825.pyretStack.push(L[4595]);
}
throw $e4082440825;
}
var $ret4083040831 = $Hanf_arg907540836($z4082640827,INDENT118169,PP170,anf_arg210240822,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_end148546);
++R.GAS;
return $ret4083040831;
};
var $Hanf_arg907540836 = function(anf_arg210440835,INDENT118169,PP170,anf_arg210240822,anf_fun210015494,break_DASH_one119168,self74615495,str_DASH_end148546) {
var anf_bracket210540866 = G(self74615495,"branches",L[4603]);
var anf_fun210640847 = G(anf_bracket210540866,"map",L[4602]);
var anf_arg211140848 = R.makeFunction(function(b74740851) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4598],1,arguments);
}
var anf_fun210840864 = G(PP170,"group",L[4601]);
var anf_fun210940862 = G(b74740851,"tosource",L[4600]);
var $z4085440855 = D;
var $f4086040861 = function(_) {
return R.isFunction(anf_fun210940862)?anf_fun210940862.app():R.ffi.throwNonFunApp(L[4599],anf_fun210940862,[]);
};
try {
if(--R.GAS > 0) {
$z4085440855 = $f4086040861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4086040861,
"from":L[4599]});
}
} catch($e4085240853) {
if(R.isCont($e4085240853)) {
var $ss4085640857 = {"from":L[4599],
"go":function(anf_arg211040863) {
return $Hanf_arg907240865(anf_arg211040863,anf_fun210840864);
}};
$e4085240853.stack[R.EXN_STACKHEIGHT++] = $ss4085640857;
}
if(R.isPyretException($e4085240853)) {
$e4085240853.pyretStack.push(L[4599]);
}
throw $e4085240853;
}
var $ret4085840859 = $Hanf_arg907240865($z4085440855,anf_fun210840864);
++R.GAS;
return $ret4085840859;
});
var $z4083940840 = D;
var $f4084540846 = function(_) {
return R.isFunction(anf_fun210640847)?anf_fun210640847.app(anf_arg211140848):R.ffi.throwNonFunApp(L[4597],anf_fun210640847,[anf_arg211140848]);
};
try {
if(--R.GAS > 0) {
$z4083940840 = $f4084540846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4084540846,
"from":L[4597]});
}
} catch($e4083740838) {
if(R.isCont($e4083740838)) {
var $ss4084140842 = {"from":L[4597],
"go":function(anf_arg211240849) {
return $Hanf_arg907440850(anf_arg211240849,INDENT118169,anf_arg210240822,anf_arg210440835,anf_fun210015494,break_DASH_one119168,str_DASH_end148546);
}};
$e4083740838.stack[R.EXN_STACKHEIGHT++] = $ss4084140842;
}
if(R.isPyretException($e4083740838)) {
$e4083740838.pyretStack.push(L[4597]);
}
throw $e4083740838;
}
var $ret4084340844 = $Hanf_arg907440850($z4083940840,INDENT118169,anf_arg210240822,anf_arg210440835,anf_fun210015494,break_DASH_one119168,str_DASH_end148546);
++R.GAS;
return $ret4084340844;
};
var $Hanf_arg907440850 = function(anf_arg211240849,INDENT118169,anf_arg210240822,anf_arg210440835,anf_fun210015494,break_DASH_one119168,str_DASH_end148546) {
var $z4086940870 = D;
var $f4087540876 = function(_) {
return R.isFunction(anf_fun210015494)?anf_fun210015494.app(INDENT118169,(1),anf_arg210240822,anf_arg210440835,break_DASH_one119168,str_DASH_end148546,anf_arg211240849):R.ffi.throwNonFunApp(L[2855],anf_fun210015494,[INDENT118169,(1),anf_arg210240822,anf_arg210440835,break_DASH_one119168,str_DASH_end148546,anf_arg211240849]);
};
try {
if(--R.GAS > 0) {
$z4086940870 = $f4087540876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4087540876,
"from":L[2855]});
}
} catch($e4086740868) {
if(R.isCont($e4086740868)) {
var $ss4087140872 = {"from":L[2855],
"go":function(ann_DASH_check_DASH_temp209940877) {
return $Hann_DASH_check_DASH_temp907340878(ann_DASH_check_DASH_temp209940877);
}};
$e4086740868.stack[R.EXN_STACKHEIGHT++] = $ss4087140872;
}
if(R.isPyretException($e4086740868)) {
$e4086740868.pyretStack.push(L[2855]);
}
throw $e4086740868;
}
var $ret4087340874 = $Hann_DASH_check_DASH_temp907340878($z4086940870);
++R.GAS;
return $ret4087340874;
};
var $Hann_DASH_check_DASH_temp907340878 = function(ann_DASH_check_DASH_temp209940877) {
return ann_DASH_check_DASH_temp209940877;
};
var $Hanf_arg907240865 = function(anf_arg211040863,anf_fun210840864) {
var $z4088140882 = D;
var $f4088740888 = function(_) {
return R.isFunction(anf_fun210840864)?anf_fun210840864.app(anf_arg211040863):R.ffi.throwNonFunApp(L[4598],anf_fun210840864,[anf_arg211040863]);
};
try {
if(--R.GAS > 0) {
$z4088140882 = $f4088740888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4088740888,
"from":L[4598]});
}
} catch($e4087940880) {
if(R.isCont($e4087940880)) {
var $ss4088340884 = {"from":L[4598],
"go":function(ann_DASH_check_DASH_temp210740889) {
return $Hann_DASH_check_DASH_temp907140890(ann_DASH_check_DASH_temp210740889);
}};
$e4087940880.stack[R.EXN_STACKHEIGHT++] = $ss4088340884;
}
if(R.isPyretException($e4087940880)) {
$e4087940880.pyretStack.push(L[4598]);
}
throw $e4087940880;
}
var $ret4088540886 = $Hann_DASH_check_DASH_temp907140890($z4088140882);
++R.GAS;
return $ret4088540886;
};
var $Hann_DASH_check_DASH_temp907140890 = function(ann_DASH_check_DASH_temp210740889) {
return ann_DASH_check_DASH_temp210740889;
};
var $Hanf_arg907015512 = function(anf_arg208915510,self26915511,_plus55,torepr65) {
var anf_arg209040901 = G(self26915511,"branches",L[2253]);
var $z4089340894 = D;
var $f4089940900 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg209040901):R.ffi.throwNonFunApp(L[2253],torepr65,[anf_arg209040901]);
};
try {
if(--R.GAS > 0) {
$z4089340894 = $f4089940900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4089940900,
"from":L[2253]});
}
} catch($e4089140892) {
if(R.isCont($e4089140892)) {
var $ss4089540896 = {"from":L[2253],
"go":function(anf_arg209140902) {
return $Hanf_arg906940903(anf_arg209140902,anf_arg208915510,_plus55);
}};
$e4089140892.stack[R.EXN_STACKHEIGHT++] = $ss4089540896;
}
if(R.isPyretException($e4089140892)) {
$e4089140892.pyretStack.push(L[2253]);
}
throw $e4089140892;
}
var $ret4089740898 = $Hanf_arg906940903($z4089340894,anf_arg208915510,_plus55);
++R.GAS;
return $ret4089740898;
};
var $Hanf_arg906940903 = function(anf_arg209140902,anf_arg208915510,_plus55) {
var $z4090640907 = D;
var $f4091240913 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg209140902):R.ffi.throwNonFunApp(L[2253],_plus55,[(", "),anf_arg209140902]);
};
try {
if(--R.GAS > 0) {
$z4090640907 = $f4091240913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4091240913,
"from":L[2253]});
}
} catch($e4090440905) {
if(R.isCont($e4090440905)) {
var $ss4090840909 = {"from":L[2253],
"go":function(anf_arg209240914) {
return $Hanf_arg906840915(anf_arg209240914,anf_arg208915510,_plus55);
}};
$e4090440905.stack[R.EXN_STACKHEIGHT++] = $ss4090840909;
}
if(R.isPyretException($e4090440905)) {
$e4090440905.pyretStack.push(L[2253]);
}
throw $e4090440905;
}
var $ret4091040911 = $Hanf_arg906840915($z4090640907,anf_arg208915510,_plus55);
++R.GAS;
return $ret4091040911;
};
var $Hanf_arg906840915 = function(anf_arg209240914,anf_arg208915510,_plus55) {
var $z4091840919 = D;
var $f4092440925 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg208915510,anf_arg209240914):R.ffi.throwNonFunApp(L[2253],_plus55,[anf_arg208915510,anf_arg209240914]);
};
try {
if(--R.GAS > 0) {
$z4091840919 = $f4092440925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4092440925,
"from":L[2253]});
}
} catch($e4091640917) {
if(R.isCont($e4091640917)) {
var $ss4092040921 = {"from":L[2253],
"go":function(anf_arg209340926) {
return $Hanf_arg906740927(anf_arg209340926,_plus55);
}};
$e4091640917.stack[R.EXN_STACKHEIGHT++] = $ss4092040921;
}
if(R.isPyretException($e4091640917)) {
$e4091640917.pyretStack.push(L[2253]);
}
throw $e4091640917;
}
var $ret4092240923 = $Hanf_arg906740927($z4091840919,_plus55);
++R.GAS;
return $ret4092240923;
};
var $Hanf_arg906740927 = function(anf_arg209340926,_plus55) {
var $z4093040931 = D;
var $f4093640937 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg209340926,(")")):R.ffi.throwNonFunApp(L[2253],_plus55,[anf_arg209340926,(")")]);
};
try {
if(--R.GAS > 0) {
$z4093040931 = $f4093640937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4093640937,
"from":L[2253]});
}
} catch($e4092840929) {
if(R.isCont($e4092840929)) {
var $ss4093240933 = {"from":L[2253],
"go":function(anf_arg209440938) {
return $Hanf_arg906640939(anf_arg209440938,_plus55);
}};
$e4092840929.stack[R.EXN_STACKHEIGHT++] = $ss4093240933;
}
if(R.isPyretException($e4092840929)) {
$e4092840929.pyretStack.push(L[2253]);
}
throw $e4092840929;
}
var $ret4093440935 = $Hanf_arg906640939($z4093040931,_plus55);
++R.GAS;
return $ret4093440935;
};
var $Hanf_arg906640939 = function(anf_arg209440938,_plus55) {
var $z4094240943 = D;
var $f4094840949 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg209440938):R.ffi.throwNonFunApp(L[2253],_plus55,[("("),anf_arg209440938]);
};
try {
if(--R.GAS > 0) {
$z4094240943 = $f4094840949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4094840949,
"from":L[2253]});
}
} catch($e4094040941) {
if(R.isCont($e4094040941)) {
var $ss4094440945 = {"from":L[2253],
"go":function(anf_arg209540950) {
return $Hanf_arg906540951(anf_arg209540950,_plus55);
}};
$e4094040941.stack[R.EXN_STACKHEIGHT++] = $ss4094440945;
}
if(R.isPyretException($e4094040941)) {
$e4094040941.pyretStack.push(L[2253]);
}
throw $e4094040941;
}
var $ret4094640947 = $Hanf_arg906540951($z4094240943,_plus55);
++R.GAS;
return $ret4094640947;
};
var $Hanf_arg906540951 = function(anf_arg209540950,_plus55) {
var $z4095440955 = D;
var $f4096040961 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-if-pipe"),anf_arg209540950):R.ffi.throwNonFunApp(L[2253],_plus55,[("s-if-pipe"),anf_arg209540950]);
};
try {
if(--R.GAS > 0) {
$z4095440955 = $f4096040961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4096040961,
"from":L[2253]});
}
} catch($e4095240953) {
if(R.isCont($e4095240953)) {
var $ss4095640957 = {"from":L[2253],
"go":function(ann_DASH_check_DASH_temp208740962) {
return $Hann_DASH_check_DASH_temp906440963(ann_DASH_check_DASH_temp208740962);
}};
$e4095240953.stack[R.EXN_STACKHEIGHT++] = $ss4095640957;
}
if(R.isPyretException($e4095240953)) {
$e4095240953.pyretStack.push(L[2253]);
}
throw $e4095240953;
}
var $ret4095840959 = $Hann_DASH_check_DASH_temp906440963($z4095440955);
++R.GAS;
return $ret4095840959;
};
var $Hann_DASH_check_DASH_temp906440963 = function(ann_DASH_check_DASH_temp208740962) {
return ann_DASH_check_DASH_temp208740962;
};
var $Hcont_tail_arg906215528 = function(cont_tail_arg208415526,if_helper207515527) {
if(--R.GAS > 0) {
$z4096440965 = R.isFunction(if_helper207515527)?if_helper207515527.app(cont_tail_arg208415526):R.ffi.throwNonFunApp(L[2253],if_helper207515527,[cont_tail_arg208415526]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper207515527)?if_helper207515527.app(cont_tail_arg208415526):R.ffi.throwNonFunApp(L[2253],if_helper207515527,[cont_tail_arg208415526]);
},
"from":L[2253]});
}
++R.GAS;
return $z4096440965;
};
var $Hcont_tail_arg906315543 = function(cont_tail_arg208015542,if_helper207515527) {
if(--R.GAS > 0) {
$z4096640967 = R.isFunction(if_helper207515527)?if_helper207515527.app(cont_tail_arg208015542):R.ffi.throwNonFunApp(L[2253],if_helper207515527,[cont_tail_arg208015542]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper207515527)?if_helper207515527.app(cont_tail_arg208015542):R.ffi.throwNonFunApp(L[2253],if_helper207515527,[cont_tail_arg208015542]);
},
"from":L[2253]});
}
++R.GAS;
return $z4096640967;
};
var $Hanf_arg906115566 = function(anf_arg206515562,INDENT118169,anf_fun206115563,anf_fun206215564,break_DASH_one119168,self74215565,str_DASH_spacecolonequal169819,_plus55) {
var $z4097040971 = D;
var $f4097640977 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg206515562,str_DASH_spacecolonequal169819):R.ffi.throwNonFunApp(L[4604],_plus55,[anf_arg206515562,str_DASH_spacecolonequal169819]);
};
try {
if(--R.GAS > 0) {
$z4097040971 = $f4097640977();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4097640977,
"from":L[4604]});
}
} catch($e4096840969) {
if(R.isCont($e4096840969)) {
var $ss4097240973 = {"from":L[4604],
"go":function(anf_arg206640978) {
return $Hanf_arg906040979(anf_arg206640978,INDENT118169,anf_fun206115563,anf_fun206215564,break_DASH_one119168,self74215565,_plus55);
}};
$e4096840969.stack[R.EXN_STACKHEIGHT++] = $ss4097240973;
}
if(R.isPyretException($e4096840969)) {
$e4096840969.pyretStack.push(L[4604]);
}
throw $e4096840969;
}
var $ret4097440975 = $Hanf_arg906040979($z4097040971,INDENT118169,anf_fun206115563,anf_fun206215564,break_DASH_one119168,self74215565,_plus55);
++R.GAS;
return $ret4097440975;
};
var $Hanf_arg906040979 = function(anf_arg206640978,INDENT118169,anf_fun206115563,anf_fun206215564,break_DASH_one119168,self74215565,_plus55) {
var $z4098240983 = D;
var $f4098840989 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg206640978,break_DASH_one119168):R.ffi.throwNonFunApp(L[4604],_plus55,[anf_arg206640978,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4098240983 = $f4098840989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4098840989,
"from":L[4604]});
}
} catch($e4098040981) {
if(R.isCont($e4098040981)) {
var $ss4098440985 = {"from":L[4604],
"go":function(anf_arg206740990) {
return $Hanf_arg905940991(anf_arg206740990,INDENT118169,anf_fun206115563,anf_fun206215564,self74215565,_plus55);
}};
$e4098040981.stack[R.EXN_STACKHEIGHT++] = $ss4098440985;
}
if(R.isPyretException($e4098040981)) {
$e4098040981.pyretStack.push(L[4604]);
}
throw $e4098040981;
}
var $ret4098640987 = $Hanf_arg905940991($z4098240983,INDENT118169,anf_fun206115563,anf_fun206215564,self74215565,_plus55);
++R.GAS;
return $ret4098640987;
};
var $Hanf_arg905940991 = function(anf_arg206740990,INDENT118169,anf_fun206115563,anf_fun206215564,self74215565,_plus55) {
var anf_bracket206841005 = G(self74215565,"value",L[4607]);
var anf_fun206941002 = G(anf_bracket206841005,"tosource",L[4606]);
var $z4099440995 = D;
var $f4100041001 = function(_) {
return R.isFunction(anf_fun206941002)?anf_fun206941002.app():R.ffi.throwNonFunApp(L[4605],anf_fun206941002,[]);
};
try {
if(--R.GAS > 0) {
$z4099440995 = $f4100041001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4100041001,
"from":L[4605]});
}
} catch($e4099240993) {
if(R.isCont($e4099240993)) {
var $ss4099640997 = {"from":L[4605],
"go":function(anf_arg207041003) {
return $Hanf_arg905841004(anf_arg207041003,INDENT118169,anf_arg206740990,anf_fun206115563,anf_fun206215564,_plus55);
}};
$e4099240993.stack[R.EXN_STACKHEIGHT++] = $ss4099640997;
}
if(R.isPyretException($e4099240993)) {
$e4099240993.pyretStack.push(L[4605]);
}
throw $e4099240993;
}
var $ret4099840999 = $Hanf_arg905841004($z4099440995,INDENT118169,anf_arg206740990,anf_fun206115563,anf_fun206215564,_plus55);
++R.GAS;
return $ret4099840999;
};
var $Hanf_arg905841004 = function(anf_arg207041003,INDENT118169,anf_arg206740990,anf_fun206115563,anf_fun206215564,_plus55) {
var $z4100841009 = D;
var $f4101441015 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg206740990,anf_arg207041003):R.ffi.throwNonFunApp(L[4604],_plus55,[anf_arg206740990,anf_arg207041003]);
};
try {
if(--R.GAS > 0) {
$z4100841009 = $f4101441015();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4101441015,
"from":L[4604]});
}
} catch($e4100641007) {
if(R.isCont($e4100641007)) {
var $ss4101041011 = {"from":L[4604],
"go":function(anf_arg207141016) {
return $Hanf_arg905741017(anf_arg207141016,INDENT118169,anf_fun206115563,anf_fun206215564);
}};
$e4100641007.stack[R.EXN_STACKHEIGHT++] = $ss4101041011;
}
if(R.isPyretException($e4100641007)) {
$e4100641007.pyretStack.push(L[4604]);
}
throw $e4100641007;
}
var $ret4101241013 = $Hanf_arg905741017($z4100841009,INDENT118169,anf_fun206115563,anf_fun206215564);
++R.GAS;
return $ret4101241013;
};
var $Hanf_arg905741017 = function(anf_arg207141016,INDENT118169,anf_fun206115563,anf_fun206215564) {
var $z4102041021 = D;
var $f4102641027 = function(_) {
return R.isFunction(anf_fun206215564)?anf_fun206215564.app(INDENT118169,anf_arg207141016):R.ffi.throwNonFunApp(L[4608],anf_fun206215564,[INDENT118169,anf_arg207141016]);
};
try {
if(--R.GAS > 0) {
$z4102041021 = $f4102641027();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4102641027,
"from":L[4608]});
}
} catch($e4101841019) {
if(R.isCont($e4101841019)) {
var $ss4102241023 = {"from":L[4608],
"go":function(anf_arg207241028) {
return $Hanf_arg905641029(anf_arg207241028,anf_fun206115563);
}};
$e4101841019.stack[R.EXN_STACKHEIGHT++] = $ss4102241023;
}
if(R.isPyretException($e4101841019)) {
$e4101841019.pyretStack.push(L[4608]);
}
throw $e4101841019;
}
var $ret4102441025 = $Hanf_arg905641029($z4102041021,anf_fun206115563);
++R.GAS;
return $ret4102441025;
};
var $Hanf_arg905641029 = function(anf_arg207241028,anf_fun206115563) {
var $z4103241033 = D;
var $f4103841039 = function(_) {
return R.isFunction(anf_fun206115563)?anf_fun206115563.app(anf_arg207241028):R.ffi.throwNonFunApp(L[2864],anf_fun206115563,[anf_arg207241028]);
};
try {
if(--R.GAS > 0) {
$z4103241033 = $f4103841039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4103841039,
"from":L[2864]});
}
} catch($e4103041031) {
if(R.isCont($e4103041031)) {
var $ss4103441035 = {"from":L[2864],
"go":function(ann_DASH_check_DASH_temp206041040) {
return $Hann_DASH_check_DASH_temp905541041(ann_DASH_check_DASH_temp206041040);
}};
$e4103041031.stack[R.EXN_STACKHEIGHT++] = $ss4103441035;
}
if(R.isPyretException($e4103041031)) {
$e4103041031.pyretStack.push(L[2864]);
}
throw $e4103041031;
}
var $ret4103641037 = $Hann_DASH_check_DASH_temp905541041($z4103241033);
++R.GAS;
return $ret4103641037;
};
var $Hann_DASH_check_DASH_temp905541041 = function(ann_DASH_check_DASH_temp206041040) {
return ann_DASH_check_DASH_temp206041040;
};
var $Hanf_arg905415583 = function(anf_arg204615581,self26315582,_plus55,torepr65) {
var anf_arg204741052 = G(self26315582,"id",L[2254]);
var $z4104441045 = D;
var $f4105041051 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg204741052):R.ffi.throwNonFunApp(L[2254],torepr65,[anf_arg204741052]);
};
try {
if(--R.GAS > 0) {
$z4104441045 = $f4105041051();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4105041051,
"from":L[2254]});
}
} catch($e4104241043) {
if(R.isCont($e4104241043)) {
var $ss4104641047 = {"from":L[2254],
"go":function(anf_arg204841053) {
return $Hanf_arg905341054(anf_arg204841053,anf_arg204615581,self26315582,_plus55,torepr65);
}};
$e4104241043.stack[R.EXN_STACKHEIGHT++] = $ss4104641047;
}
if(R.isPyretException($e4104241043)) {
$e4104241043.pyretStack.push(L[2254]);
}
throw $e4104241043;
}
var $ret4104841049 = $Hanf_arg905341054($z4104441045,anf_arg204615581,self26315582,_plus55,torepr65);
++R.GAS;
return $ret4104841049;
};
var $Hanf_arg905341054 = function(anf_arg204841053,anf_arg204615581,self26315582,_plus55,torepr65) {
var $z4105741058 = D;
var $f4106341064 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg204841053):R.ffi.throwNonFunApp(L[2254],_plus55,[(", "),anf_arg204841053]);
};
try {
if(--R.GAS > 0) {
$z4105741058 = $f4106341064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4106341064,
"from":L[2254]});
}
} catch($e4105541056) {
if(R.isCont($e4105541056)) {
var $ss4105941060 = {"from":L[2254],
"go":function(anf_arg204941065) {
return $Hanf_arg905241066(anf_arg204941065,anf_arg204615581,self26315582,_plus55,torepr65);
}};
$e4105541056.stack[R.EXN_STACKHEIGHT++] = $ss4105941060;
}
if(R.isPyretException($e4105541056)) {
$e4105541056.pyretStack.push(L[2254]);
}
throw $e4105541056;
}
var $ret4106141062 = $Hanf_arg905241066($z4105741058,anf_arg204615581,self26315582,_plus55,torepr65);
++R.GAS;
return $ret4106141062;
};
var $Hanf_arg905241066 = function(anf_arg204941065,anf_arg204615581,self26315582,_plus55,torepr65) {
var $z4106941070 = D;
var $f4107541076 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg204615581,anf_arg204941065):R.ffi.throwNonFunApp(L[2254],_plus55,[anf_arg204615581,anf_arg204941065]);
};
try {
if(--R.GAS > 0) {
$z4106941070 = $f4107541076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4107541076,
"from":L[2254]});
}
} catch($e4106741068) {
if(R.isCont($e4106741068)) {
var $ss4107141072 = {"from":L[2254],
"go":function(anf_arg205041077) {
return $Hanf_arg905141078(anf_arg205041077,self26315582,_plus55,torepr65);
}};
$e4106741068.stack[R.EXN_STACKHEIGHT++] = $ss4107141072;
}
if(R.isPyretException($e4106741068)) {
$e4106741068.pyretStack.push(L[2254]);
}
throw $e4106741068;
}
var $ret4107341074 = $Hanf_arg905141078($z4106941070,self26315582,_plus55,torepr65);
++R.GAS;
return $ret4107341074;
};
var $Hanf_arg905141078 = function(anf_arg205041077,self26315582,_plus55,torepr65) {
var anf_arg205141089 = G(self26315582,"value",L[2254]);
var $z4108141082 = D;
var $f4108741088 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg205141089):R.ffi.throwNonFunApp(L[2254],torepr65,[anf_arg205141089]);
};
try {
if(--R.GAS > 0) {
$z4108141082 = $f4108741088();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4108741088,
"from":L[2254]});
}
} catch($e4107941080) {
if(R.isCont($e4107941080)) {
var $ss4108341084 = {"from":L[2254],
"go":function(anf_arg205241090) {
return $Hanf_arg905041091(anf_arg205241090,anf_arg205041077,_plus55);
}};
$e4107941080.stack[R.EXN_STACKHEIGHT++] = $ss4108341084;
}
if(R.isPyretException($e4107941080)) {
$e4107941080.pyretStack.push(L[2254]);
}
throw $e4107941080;
}
var $ret4108541086 = $Hanf_arg905041091($z4108141082,anf_arg205041077,_plus55);
++R.GAS;
return $ret4108541086;
};
var $Hanf_arg905041091 = function(anf_arg205241090,anf_arg205041077,_plus55) {
var $z4109441095 = D;
var $f4110041101 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg205241090):R.ffi.throwNonFunApp(L[2254],_plus55,[(", "),anf_arg205241090]);
};
try {
if(--R.GAS > 0) {
$z4109441095 = $f4110041101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4110041101,
"from":L[2254]});
}
} catch($e4109241093) {
if(R.isCont($e4109241093)) {
var $ss4109641097 = {"from":L[2254],
"go":function(anf_arg205341102) {
return $Hanf_arg904941103(anf_arg205341102,anf_arg205041077,_plus55);
}};
$e4109241093.stack[R.EXN_STACKHEIGHT++] = $ss4109641097;
}
if(R.isPyretException($e4109241093)) {
$e4109241093.pyretStack.push(L[2254]);
}
throw $e4109241093;
}
var $ret4109841099 = $Hanf_arg904941103($z4109441095,anf_arg205041077,_plus55);
++R.GAS;
return $ret4109841099;
};
var $Hanf_arg904941103 = function(anf_arg205341102,anf_arg205041077,_plus55) {
var $z4110641107 = D;
var $f4111241113 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg205041077,anf_arg205341102):R.ffi.throwNonFunApp(L[2254],_plus55,[anf_arg205041077,anf_arg205341102]);
};
try {
if(--R.GAS > 0) {
$z4110641107 = $f4111241113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4111241113,
"from":L[2254]});
}
} catch($e4110441105) {
if(R.isCont($e4110441105)) {
var $ss4110841109 = {"from":L[2254],
"go":function(anf_arg205441114) {
return $Hanf_arg904841115(anf_arg205441114,_plus55);
}};
$e4110441105.stack[R.EXN_STACKHEIGHT++] = $ss4110841109;
}
if(R.isPyretException($e4110441105)) {
$e4110441105.pyretStack.push(L[2254]);
}
throw $e4110441105;
}
var $ret4111041111 = $Hanf_arg904841115($z4110641107,_plus55);
++R.GAS;
return $ret4111041111;
};
var $Hanf_arg904841115 = function(anf_arg205441114,_plus55) {
var $z4111841119 = D;
var $f4112441125 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg205441114,(")")):R.ffi.throwNonFunApp(L[2254],_plus55,[anf_arg205441114,(")")]);
};
try {
if(--R.GAS > 0) {
$z4111841119 = $f4112441125();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4112441125,
"from":L[2254]});
}
} catch($e4111641117) {
if(R.isCont($e4111641117)) {
var $ss4112041121 = {"from":L[2254],
"go":function(anf_arg205541126) {
return $Hanf_arg904741127(anf_arg205541126,_plus55);
}};
$e4111641117.stack[R.EXN_STACKHEIGHT++] = $ss4112041121;
}
if(R.isPyretException($e4111641117)) {
$e4111641117.pyretStack.push(L[2254]);
}
throw $e4111641117;
}
var $ret4112241123 = $Hanf_arg904741127($z4111841119,_plus55);
++R.GAS;
return $ret4112241123;
};
var $Hanf_arg904741127 = function(anf_arg205541126,_plus55) {
var $z4113041131 = D;
var $f4113641137 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg205541126):R.ffi.throwNonFunApp(L[2254],_plus55,[("("),anf_arg205541126]);
};
try {
if(--R.GAS > 0) {
$z4113041131 = $f4113641137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4113641137,
"from":L[2254]});
}
} catch($e4112841129) {
if(R.isCont($e4112841129)) {
var $ss4113241133 = {"from":L[2254],
"go":function(anf_arg205641138) {
return $Hanf_arg904641139(anf_arg205641138,_plus55);
}};
$e4112841129.stack[R.EXN_STACKHEIGHT++] = $ss4113241133;
}
if(R.isPyretException($e4112841129)) {
$e4112841129.pyretStack.push(L[2254]);
}
throw $e4112841129;
}
var $ret4113441135 = $Hanf_arg904641139($z4113041131,_plus55);
++R.GAS;
return $ret4113441135;
};
var $Hanf_arg904641139 = function(anf_arg205641138,_plus55) {
var $z4114241143 = D;
var $f4114841149 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-assign"),anf_arg205641138):R.ffi.throwNonFunApp(L[2254],_plus55,[("s-assign"),anf_arg205641138]);
};
try {
if(--R.GAS > 0) {
$z4114241143 = $f4114841149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4114841149,
"from":L[2254]});
}
} catch($e4114041141) {
if(R.isCont($e4114041141)) {
var $ss4114441145 = {"from":L[2254],
"go":function(ann_DASH_check_DASH_temp204441150) {
return $Hann_DASH_check_DASH_temp904541151(ann_DASH_check_DASH_temp204441150);
}};
$e4114041141.stack[R.EXN_STACKHEIGHT++] = $ss4114441145;
}
if(R.isPyretException($e4114041141)) {
$e4114041141.pyretStack.push(L[2254]);
}
throw $e4114041141;
}
var $ret4114641147 = $Hann_DASH_check_DASH_temp904541151($z4114241143);
++R.GAS;
return $ret4114641147;
};
var $Hann_DASH_check_DASH_temp904541151 = function(ann_DASH_check_DASH_temp204441150) {
return ann_DASH_check_DASH_temp204441150;
};
var $Hcont_tail_arg904315600 = function(cont_tail_arg204115598,if_helper203115599) {
if(--R.GAS > 0) {
$z4115241153 = R.isFunction(if_helper203115599)?if_helper203115599.app(cont_tail_arg204115598):R.ffi.throwNonFunApp(L[2254],if_helper203115599,[cont_tail_arg204115598]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper203115599)?if_helper203115599.app(cont_tail_arg204115598):R.ffi.throwNonFunApp(L[2254],if_helper203115599,[cont_tail_arg204115598]);
},
"from":L[2254]});
}
++R.GAS;
return $z4115241153;
};
var $Hcont_tail_arg904415615 = function(cont_tail_arg203615614,if_helper203115599) {
if(--R.GAS > 0) {
$z4115441155 = R.isFunction(if_helper203115599)?if_helper203115599.app(cont_tail_arg203615614):R.ffi.throwNonFunApp(L[2254],if_helper203115599,[cont_tail_arg203615614]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper203115599)?if_helper203115599.app(cont_tail_arg203615614):R.ffi.throwNonFunApp(L[2254],if_helper203115599,[cont_tail_arg203615614]);
},
"from":L[2254]});
}
++R.GAS;
return $z4115441155;
};
var $Hanf_arg904215638 = function(anf_arg202215634,INDENT118169,anf_fun201815635,anf_fun201915636,self73715637,str_DASH_colon134364,str_DASH_end148546,str_DASH_when181975,_plus55) {
var $z4115841159 = D;
var $f4116441165 = function(_) {
return R.isFunction(anf_fun201915636)?anf_fun201915636.app(anf_arg202215634):R.ffi.throwNonFunApp(L[4609],anf_fun201915636,[anf_arg202215634]);
};
try {
if(--R.GAS > 0) {
$z4115841159 = $f4116441165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4116441165,
"from":L[4609]});
}
} catch($e4115641157) {
if(R.isCont($e4115641157)) {
var $ss4116041161 = {"from":L[4609],
"go":function(anf_arg202341166) {
return $Hanf_arg904141167(anf_arg202341166,INDENT118169,anf_fun201815635,self73715637,str_DASH_colon134364,str_DASH_end148546,str_DASH_when181975,_plus55);
}};
$e4115641157.stack[R.EXN_STACKHEIGHT++] = $ss4116041161;
}
if(R.isPyretException($e4115641157)) {
$e4115641157.pyretStack.push(L[4609]);
}
throw $e4115641157;
}
var $ret4116241163 = $Hanf_arg904141167($z4115841159,INDENT118169,anf_fun201815635,self73715637,str_DASH_colon134364,str_DASH_end148546,str_DASH_when181975,_plus55);
++R.GAS;
return $ret4116241163;
};
var $Hanf_arg904141167 = function(anf_arg202341166,INDENT118169,anf_fun201815635,self73715637,str_DASH_colon134364,str_DASH_end148546,str_DASH_when181975,_plus55) {
var $z4117041171 = D;
var $f4117641177 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_when181975,anf_arg202341166):R.ffi.throwNonFunApp(L[4610],_plus55,[str_DASH_when181975,anf_arg202341166]);
};
try {
if(--R.GAS > 0) {
$z4117041171 = $f4117641177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4117641177,
"from":L[4610]});
}
} catch($e4116841169) {
if(R.isCont($e4116841169)) {
var $ss4117241173 = {"from":L[4610],
"go":function(anf_arg202441178) {
return $Hanf_arg904041179(anf_arg202441178,INDENT118169,anf_fun201815635,self73715637,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e4116841169.stack[R.EXN_STACKHEIGHT++] = $ss4117241173;
}
if(R.isPyretException($e4116841169)) {
$e4116841169.pyretStack.push(L[4610]);
}
throw $e4116841169;
}
var $ret4117441175 = $Hanf_arg904041179($z4117041171,INDENT118169,anf_fun201815635,self73715637,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4117441175;
};
var $Hanf_arg904041179 = function(anf_arg202441178,INDENT118169,anf_fun201815635,self73715637,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z4118241183 = D;
var $f4118841189 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg202441178,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4610],_plus55,[anf_arg202441178,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z4118241183 = $f4118841189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4118841189,
"from":L[4610]});
}
} catch($e4118041181) {
if(R.isCont($e4118041181)) {
var $ss4118441185 = {"from":L[4610],
"go":function(anf_arg202541190) {
return $Hanf_arg903941191(anf_arg202541190,INDENT118169,anf_fun201815635,self73715637,str_DASH_end148546);
}};
$e4118041181.stack[R.EXN_STACKHEIGHT++] = $ss4118441185;
}
if(R.isPyretException($e4118041181)) {
$e4118041181.pyretStack.push(L[4610]);
}
throw $e4118041181;
}
var $ret4118641187 = $Hanf_arg903941191($z4118241183,INDENT118169,anf_fun201815635,self73715637,str_DASH_end148546);
++R.GAS;
return $ret4118641187;
};
var $Hanf_arg903941191 = function(anf_arg202541190,INDENT118169,anf_fun201815635,self73715637,str_DASH_end148546) {
var anf_bracket202641205 = G(self73715637,"block",L[4613]);
var anf_fun202741202 = G(anf_bracket202641205,"tosource",L[4612]);
var $z4119441195 = D;
var $f4120041201 = function(_) {
return R.isFunction(anf_fun202741202)?anf_fun202741202.app():R.ffi.throwNonFunApp(L[4611],anf_fun202741202,[]);
};
try {
if(--R.GAS > 0) {
$z4119441195 = $f4120041201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4120041201,
"from":L[4611]});
}
} catch($e4119241193) {
if(R.isCont($e4119241193)) {
var $ss4119641197 = {"from":L[4611],
"go":function(anf_arg202841203) {
return $Hanf_arg903841204(anf_arg202841203,INDENT118169,anf_arg202541190,anf_fun201815635,str_DASH_end148546);
}};
$e4119241193.stack[R.EXN_STACKHEIGHT++] = $ss4119641197;
}
if(R.isPyretException($e4119241193)) {
$e4119241193.pyretStack.push(L[4611]);
}
throw $e4119241193;
}
var $ret4119841199 = $Hanf_arg903841204($z4119441195,INDENT118169,anf_arg202541190,anf_fun201815635,str_DASH_end148546);
++R.GAS;
return $ret4119841199;
};
var $Hanf_arg903841204 = function(anf_arg202841203,INDENT118169,anf_arg202541190,anf_fun201815635,str_DASH_end148546) {
var $z4120841209 = D;
var $f4121441215 = function(_) {
return R.isFunction(anf_fun201815635)?anf_fun201815635.app(INDENT118169,(1),anf_arg202541190,anf_arg202841203,str_DASH_end148546):R.ffi.throwNonFunApp(L[2874],anf_fun201815635,[INDENT118169,(1),anf_arg202541190,anf_arg202841203,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4120841209 = $f4121441215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4121441215,
"from":L[2874]});
}
} catch($e4120641207) {
if(R.isCont($e4120641207)) {
var $ss4121041211 = {"from":L[2874],
"go":function(ann_DASH_check_DASH_temp201741216) {
return $Hann_DASH_check_DASH_temp903741217(ann_DASH_check_DASH_temp201741216);
}};
$e4120641207.stack[R.EXN_STACKHEIGHT++] = $ss4121041211;
}
if(R.isPyretException($e4120641207)) {
$e4120641207.pyretStack.push(L[2874]);
}
throw $e4120641207;
}
var $ret4121241213 = $Hann_DASH_check_DASH_temp903741217($z4120841209);
++R.GAS;
return $ret4121241213;
};
var $Hann_DASH_check_DASH_temp903741217 = function(ann_DASH_check_DASH_temp201741216) {
return ann_DASH_check_DASH_temp201741216;
};
var $Hanf_arg903615655 = function(anf_arg200315653,self25715654,_plus55,torepr65) {
var anf_arg200441228 = G(self25715654,"test",L[2255]);
var $z4122041221 = D;
var $f4122641227 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg200441228):R.ffi.throwNonFunApp(L[2255],torepr65,[anf_arg200441228]);
};
try {
if(--R.GAS > 0) {
$z4122041221 = $f4122641227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4122641227,
"from":L[2255]});
}
} catch($e4121841219) {
if(R.isCont($e4121841219)) {
var $ss4122241223 = {"from":L[2255],
"go":function(anf_arg200541229) {
return $Hanf_arg903541230(anf_arg200541229,anf_arg200315653,self25715654,_plus55,torepr65);
}};
$e4121841219.stack[R.EXN_STACKHEIGHT++] = $ss4122241223;
}
if(R.isPyretException($e4121841219)) {
$e4121841219.pyretStack.push(L[2255]);
}
throw $e4121841219;
}
var $ret4122441225 = $Hanf_arg903541230($z4122041221,anf_arg200315653,self25715654,_plus55,torepr65);
++R.GAS;
return $ret4122441225;
};
var $Hanf_arg903541230 = function(anf_arg200541229,anf_arg200315653,self25715654,_plus55,torepr65) {
var $z4123341234 = D;
var $f4123941240 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg200541229):R.ffi.throwNonFunApp(L[2255],_plus55,[(", "),anf_arg200541229]);
};
try {
if(--R.GAS > 0) {
$z4123341234 = $f4123941240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4123941240,
"from":L[2255]});
}
} catch($e4123141232) {
if(R.isCont($e4123141232)) {
var $ss4123541236 = {"from":L[2255],
"go":function(anf_arg200641241) {
return $Hanf_arg903441242(anf_arg200641241,anf_arg200315653,self25715654,_plus55,torepr65);
}};
$e4123141232.stack[R.EXN_STACKHEIGHT++] = $ss4123541236;
}
if(R.isPyretException($e4123141232)) {
$e4123141232.pyretStack.push(L[2255]);
}
throw $e4123141232;
}
var $ret4123741238 = $Hanf_arg903441242($z4123341234,anf_arg200315653,self25715654,_plus55,torepr65);
++R.GAS;
return $ret4123741238;
};
var $Hanf_arg903441242 = function(anf_arg200641241,anf_arg200315653,self25715654,_plus55,torepr65) {
var $z4124541246 = D;
var $f4125141252 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg200315653,anf_arg200641241):R.ffi.throwNonFunApp(L[2255],_plus55,[anf_arg200315653,anf_arg200641241]);
};
try {
if(--R.GAS > 0) {
$z4124541246 = $f4125141252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4125141252,
"from":L[2255]});
}
} catch($e4124341244) {
if(R.isCont($e4124341244)) {
var $ss4124741248 = {"from":L[2255],
"go":function(anf_arg200741253) {
return $Hanf_arg903341254(anf_arg200741253,self25715654,_plus55,torepr65);
}};
$e4124341244.stack[R.EXN_STACKHEIGHT++] = $ss4124741248;
}
if(R.isPyretException($e4124341244)) {
$e4124341244.pyretStack.push(L[2255]);
}
throw $e4124341244;
}
var $ret4124941250 = $Hanf_arg903341254($z4124541246,self25715654,_plus55,torepr65);
++R.GAS;
return $ret4124941250;
};
var $Hanf_arg903341254 = function(anf_arg200741253,self25715654,_plus55,torepr65) {
var anf_arg200841265 = G(self25715654,"block",L[2255]);
var $z4125741258 = D;
var $f4126341264 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg200841265):R.ffi.throwNonFunApp(L[2255],torepr65,[anf_arg200841265]);
};
try {
if(--R.GAS > 0) {
$z4125741258 = $f4126341264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4126341264,
"from":L[2255]});
}
} catch($e4125541256) {
if(R.isCont($e4125541256)) {
var $ss4125941260 = {"from":L[2255],
"go":function(anf_arg200941266) {
return $Hanf_arg903241267(anf_arg200941266,anf_arg200741253,_plus55);
}};
$e4125541256.stack[R.EXN_STACKHEIGHT++] = $ss4125941260;
}
if(R.isPyretException($e4125541256)) {
$e4125541256.pyretStack.push(L[2255]);
}
throw $e4125541256;
}
var $ret4126141262 = $Hanf_arg903241267($z4125741258,anf_arg200741253,_plus55);
++R.GAS;
return $ret4126141262;
};
var $Hanf_arg903241267 = function(anf_arg200941266,anf_arg200741253,_plus55) {
var $z4127041271 = D;
var $f4127641277 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg200941266):R.ffi.throwNonFunApp(L[2255],_plus55,[(", "),anf_arg200941266]);
};
try {
if(--R.GAS > 0) {
$z4127041271 = $f4127641277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4127641277,
"from":L[2255]});
}
} catch($e4126841269) {
if(R.isCont($e4126841269)) {
var $ss4127241273 = {"from":L[2255],
"go":function(anf_arg201041278) {
return $Hanf_arg903141279(anf_arg201041278,anf_arg200741253,_plus55);
}};
$e4126841269.stack[R.EXN_STACKHEIGHT++] = $ss4127241273;
}
if(R.isPyretException($e4126841269)) {
$e4126841269.pyretStack.push(L[2255]);
}
throw $e4126841269;
}
var $ret4127441275 = $Hanf_arg903141279($z4127041271,anf_arg200741253,_plus55);
++R.GAS;
return $ret4127441275;
};
var $Hanf_arg903141279 = function(anf_arg201041278,anf_arg200741253,_plus55) {
var $z4128241283 = D;
var $f4128841289 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg200741253,anf_arg201041278):R.ffi.throwNonFunApp(L[2255],_plus55,[anf_arg200741253,anf_arg201041278]);
};
try {
if(--R.GAS > 0) {
$z4128241283 = $f4128841289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4128841289,
"from":L[2255]});
}
} catch($e4128041281) {
if(R.isCont($e4128041281)) {
var $ss4128441285 = {"from":L[2255],
"go":function(anf_arg201141290) {
return $Hanf_arg903041291(anf_arg201141290,_plus55);
}};
$e4128041281.stack[R.EXN_STACKHEIGHT++] = $ss4128441285;
}
if(R.isPyretException($e4128041281)) {
$e4128041281.pyretStack.push(L[2255]);
}
throw $e4128041281;
}
var $ret4128641287 = $Hanf_arg903041291($z4128241283,_plus55);
++R.GAS;
return $ret4128641287;
};
var $Hanf_arg903041291 = function(anf_arg201141290,_plus55) {
var $z4129441295 = D;
var $f4130041301 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg201141290,(")")):R.ffi.throwNonFunApp(L[2255],_plus55,[anf_arg201141290,(")")]);
};
try {
if(--R.GAS > 0) {
$z4129441295 = $f4130041301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4130041301,
"from":L[2255]});
}
} catch($e4129241293) {
if(R.isCont($e4129241293)) {
var $ss4129641297 = {"from":L[2255],
"go":function(anf_arg201241302) {
return $Hanf_arg902941303(anf_arg201241302,_plus55);
}};
$e4129241293.stack[R.EXN_STACKHEIGHT++] = $ss4129641297;
}
if(R.isPyretException($e4129241293)) {
$e4129241293.pyretStack.push(L[2255]);
}
throw $e4129241293;
}
var $ret4129841299 = $Hanf_arg902941303($z4129441295,_plus55);
++R.GAS;
return $ret4129841299;
};
var $Hanf_arg902941303 = function(anf_arg201241302,_plus55) {
var $z4130641307 = D;
var $f4131241313 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg201241302):R.ffi.throwNonFunApp(L[2255],_plus55,[("("),anf_arg201241302]);
};
try {
if(--R.GAS > 0) {
$z4130641307 = $f4131241313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4131241313,
"from":L[2255]});
}
} catch($e4130441305) {
if(R.isCont($e4130441305)) {
var $ss4130841309 = {"from":L[2255],
"go":function(anf_arg201341314) {
return $Hanf_arg902841315(anf_arg201341314,_plus55);
}};
$e4130441305.stack[R.EXN_STACKHEIGHT++] = $ss4130841309;
}
if(R.isPyretException($e4130441305)) {
$e4130441305.pyretStack.push(L[2255]);
}
throw $e4130441305;
}
var $ret4131041311 = $Hanf_arg902841315($z4130641307,_plus55);
++R.GAS;
return $ret4131041311;
};
var $Hanf_arg902841315 = function(anf_arg201341314,_plus55) {
var $z4131841319 = D;
var $f4132441325 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-when"),anf_arg201341314):R.ffi.throwNonFunApp(L[2255],_plus55,[("s-when"),anf_arg201341314]);
};
try {
if(--R.GAS > 0) {
$z4131841319 = $f4132441325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4132441325,
"from":L[2255]});
}
} catch($e4131641317) {
if(R.isCont($e4131641317)) {
var $ss4132041321 = {"from":L[2255],
"go":function(ann_DASH_check_DASH_temp200141326) {
return $Hann_DASH_check_DASH_temp902741327(ann_DASH_check_DASH_temp200141326);
}};
$e4131641317.stack[R.EXN_STACKHEIGHT++] = $ss4132041321;
}
if(R.isPyretException($e4131641317)) {
$e4131641317.pyretStack.push(L[2255]);
}
throw $e4131641317;
}
var $ret4132241323 = $Hann_DASH_check_DASH_temp902741327($z4131841319);
++R.GAS;
return $ret4132241323;
};
var $Hann_DASH_check_DASH_temp902741327 = function(ann_DASH_check_DASH_temp200141326) {
return ann_DASH_check_DASH_temp200141326;
};
var $Hcont_tail_arg902515672 = function(cont_tail_arg199815670,if_helper198815671) {
if(--R.GAS > 0) {
$z4132841329 = R.isFunction(if_helper198815671)?if_helper198815671.app(cont_tail_arg199815670):R.ffi.throwNonFunApp(L[2255],if_helper198815671,[cont_tail_arg199815670]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper198815671)?if_helper198815671.app(cont_tail_arg199815670):R.ffi.throwNonFunApp(L[2255],if_helper198815671,[cont_tail_arg199815670]);
},
"from":L[2255]});
}
++R.GAS;
return $z4132841329;
};
var $Hcont_tail_arg902615687 = function(cont_tail_arg199315686,if_helper198815671) {
if(--R.GAS > 0) {
$z4133041331 = R.isFunction(if_helper198815671)?if_helper198815671.app(cont_tail_arg199315686):R.ffi.throwNonFunApp(L[2255],if_helper198815671,[cont_tail_arg199315686]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper198815671)?if_helper198815671.app(cont_tail_arg199315686):R.ffi.throwNonFunApp(L[2255],if_helper198815671,[cont_tail_arg199315686]);
},
"from":L[2255]});
}
++R.GAS;
return $z4133041331;
};
var $Hanf_arg902415709 = function(anf_arg198215706,INDENT118169,anf_fun197915707,self73215708,str_DASH_coloncolon135377) {
var anf_bracket198341345 = G(self73215708,"ann",L[4616]);
var anf_fun198441342 = G(anf_bracket198341345,"tosource",L[4615]);
var $z4133441335 = D;
var $f4134041341 = function(_) {
return R.isFunction(anf_fun198441342)?anf_fun198441342.app():R.ffi.throwNonFunApp(L[4614],anf_fun198441342,[]);
};
try {
if(--R.GAS > 0) {
$z4133441335 = $f4134041341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4134041341,
"from":L[4614]});
}
} catch($e4133241333) {
if(R.isCont($e4133241333)) {
var $ss4133641337 = {"from":L[4614],
"go":function(anf_arg198541343) {
return $Hanf_arg902341344(anf_arg198541343,INDENT118169,anf_arg198215706,anf_fun197915707,str_DASH_coloncolon135377);
}};
$e4133241333.stack[R.EXN_STACKHEIGHT++] = $ss4133641337;
}
if(R.isPyretException($e4133241333)) {
$e4133241333.pyretStack.push(L[4614]);
}
throw $e4133241333;
}
var $ret4133841339 = $Hanf_arg902341344($z4133441335,INDENT118169,anf_arg198215706,anf_fun197915707,str_DASH_coloncolon135377);
++R.GAS;
return $ret4133841339;
};
var $Hanf_arg902341344 = function(anf_arg198541343,INDENT118169,anf_arg198215706,anf_fun197915707,str_DASH_coloncolon135377) {
var $z4134841349 = D;
var $f4135441355 = function(_) {
return R.isFunction(anf_fun197915707)?anf_fun197915707.app(INDENT118169,(1),str_DASH_coloncolon135377,anf_arg198215706,anf_arg198541343):R.ffi.throwNonFunApp(L[2883],anf_fun197915707,[INDENT118169,(1),str_DASH_coloncolon135377,anf_arg198215706,anf_arg198541343]);
};
try {
if(--R.GAS > 0) {
$z4134841349 = $f4135441355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4135441355,
"from":L[2883]});
}
} catch($e4134641347) {
if(R.isCont($e4134641347)) {
var $ss4135041351 = {"from":L[2883],
"go":function(ann_DASH_check_DASH_temp197841356) {
return $Hann_DASH_check_DASH_temp902241357(ann_DASH_check_DASH_temp197841356);
}};
$e4134641347.stack[R.EXN_STACKHEIGHT++] = $ss4135041351;
}
if(R.isPyretException($e4134641347)) {
$e4134641347.pyretStack.push(L[2883]);
}
throw $e4134641347;
}
var $ret4135241353 = $Hann_DASH_check_DASH_temp902241357($z4134841349);
++R.GAS;
return $ret4135241353;
};
var $Hann_DASH_check_DASH_temp902241357 = function(ann_DASH_check_DASH_temp197841356) {
return ann_DASH_check_DASH_temp197841356;
};
var $Hanf_arg902115726 = function(anf_arg196415724,self25115725,_plus55,torepr65) {
var anf_arg196541368 = G(self25115725,"name",L[2256]);
var $z4136041361 = D;
var $f4136641367 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg196541368):R.ffi.throwNonFunApp(L[2256],torepr65,[anf_arg196541368]);
};
try {
if(--R.GAS > 0) {
$z4136041361 = $f4136641367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4136641367,
"from":L[2256]});
}
} catch($e4135841359) {
if(R.isCont($e4135841359)) {
var $ss4136241363 = {"from":L[2256],
"go":function(anf_arg196641369) {
return $Hanf_arg902041370(anf_arg196641369,anf_arg196415724,self25115725,_plus55,torepr65);
}};
$e4135841359.stack[R.EXN_STACKHEIGHT++] = $ss4136241363;
}
if(R.isPyretException($e4135841359)) {
$e4135841359.pyretStack.push(L[2256]);
}
throw $e4135841359;
}
var $ret4136441365 = $Hanf_arg902041370($z4136041361,anf_arg196415724,self25115725,_plus55,torepr65);
++R.GAS;
return $ret4136441365;
};
var $Hanf_arg902041370 = function(anf_arg196641369,anf_arg196415724,self25115725,_plus55,torepr65) {
var $z4137341374 = D;
var $f4137941380 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg196641369):R.ffi.throwNonFunApp(L[2256],_plus55,[(", "),anf_arg196641369]);
};
try {
if(--R.GAS > 0) {
$z4137341374 = $f4137941380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4137941380,
"from":L[2256]});
}
} catch($e4137141372) {
if(R.isCont($e4137141372)) {
var $ss4137541376 = {"from":L[2256],
"go":function(anf_arg196741381) {
return $Hanf_arg901941382(anf_arg196741381,anf_arg196415724,self25115725,_plus55,torepr65);
}};
$e4137141372.stack[R.EXN_STACKHEIGHT++] = $ss4137541376;
}
if(R.isPyretException($e4137141372)) {
$e4137141372.pyretStack.push(L[2256]);
}
throw $e4137141372;
}
var $ret4137741378 = $Hanf_arg901941382($z4137341374,anf_arg196415724,self25115725,_plus55,torepr65);
++R.GAS;
return $ret4137741378;
};
var $Hanf_arg901941382 = function(anf_arg196741381,anf_arg196415724,self25115725,_plus55,torepr65) {
var $z4138541386 = D;
var $f4139141392 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg196415724,anf_arg196741381):R.ffi.throwNonFunApp(L[2256],_plus55,[anf_arg196415724,anf_arg196741381]);
};
try {
if(--R.GAS > 0) {
$z4138541386 = $f4139141392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4139141392,
"from":L[2256]});
}
} catch($e4138341384) {
if(R.isCont($e4138341384)) {
var $ss4138741388 = {"from":L[2256],
"go":function(anf_arg196841393) {
return $Hanf_arg901841394(anf_arg196841393,self25115725,_plus55,torepr65);
}};
$e4138341384.stack[R.EXN_STACKHEIGHT++] = $ss4138741388;
}
if(R.isPyretException($e4138341384)) {
$e4138341384.pyretStack.push(L[2256]);
}
throw $e4138341384;
}
var $ret4138941390 = $Hanf_arg901841394($z4138541386,self25115725,_plus55,torepr65);
++R.GAS;
return $ret4138941390;
};
var $Hanf_arg901841394 = function(anf_arg196841393,self25115725,_plus55,torepr65) {
var anf_arg196941405 = G(self25115725,"ann",L[2256]);
var $z4139741398 = D;
var $f4140341404 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg196941405):R.ffi.throwNonFunApp(L[2256],torepr65,[anf_arg196941405]);
};
try {
if(--R.GAS > 0) {
$z4139741398 = $f4140341404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4140341404,
"from":L[2256]});
}
} catch($e4139541396) {
if(R.isCont($e4139541396)) {
var $ss4139941400 = {"from":L[2256],
"go":function(anf_arg197041406) {
return $Hanf_arg901741407(anf_arg197041406,anf_arg196841393,_plus55);
}};
$e4139541396.stack[R.EXN_STACKHEIGHT++] = $ss4139941400;
}
if(R.isPyretException($e4139541396)) {
$e4139541396.pyretStack.push(L[2256]);
}
throw $e4139541396;
}
var $ret4140141402 = $Hanf_arg901741407($z4139741398,anf_arg196841393,_plus55);
++R.GAS;
return $ret4140141402;
};
var $Hanf_arg901741407 = function(anf_arg197041406,anf_arg196841393,_plus55) {
var $z4141041411 = D;
var $f4141641417 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg197041406):R.ffi.throwNonFunApp(L[2256],_plus55,[(", "),anf_arg197041406]);
};
try {
if(--R.GAS > 0) {
$z4141041411 = $f4141641417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4141641417,
"from":L[2256]});
}
} catch($e4140841409) {
if(R.isCont($e4140841409)) {
var $ss4141241413 = {"from":L[2256],
"go":function(anf_arg197141418) {
return $Hanf_arg901641419(anf_arg197141418,anf_arg196841393,_plus55);
}};
$e4140841409.stack[R.EXN_STACKHEIGHT++] = $ss4141241413;
}
if(R.isPyretException($e4140841409)) {
$e4140841409.pyretStack.push(L[2256]);
}
throw $e4140841409;
}
var $ret4141441415 = $Hanf_arg901641419($z4141041411,anf_arg196841393,_plus55);
++R.GAS;
return $ret4141441415;
};
var $Hanf_arg901641419 = function(anf_arg197141418,anf_arg196841393,_plus55) {
var $z4142241423 = D;
var $f4142841429 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg196841393,anf_arg197141418):R.ffi.throwNonFunApp(L[2256],_plus55,[anf_arg196841393,anf_arg197141418]);
};
try {
if(--R.GAS > 0) {
$z4142241423 = $f4142841429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4142841429,
"from":L[2256]});
}
} catch($e4142041421) {
if(R.isCont($e4142041421)) {
var $ss4142441425 = {"from":L[2256],
"go":function(anf_arg197241430) {
return $Hanf_arg901541431(anf_arg197241430,_plus55);
}};
$e4142041421.stack[R.EXN_STACKHEIGHT++] = $ss4142441425;
}
if(R.isPyretException($e4142041421)) {
$e4142041421.pyretStack.push(L[2256]);
}
throw $e4142041421;
}
var $ret4142641427 = $Hanf_arg901541431($z4142241423,_plus55);
++R.GAS;
return $ret4142641427;
};
var $Hanf_arg901541431 = function(anf_arg197241430,_plus55) {
var $z4143441435 = D;
var $f4144041441 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg197241430,(")")):R.ffi.throwNonFunApp(L[2256],_plus55,[anf_arg197241430,(")")]);
};
try {
if(--R.GAS > 0) {
$z4143441435 = $f4144041441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4144041441,
"from":L[2256]});
}
} catch($e4143241433) {
if(R.isCont($e4143241433)) {
var $ss4143641437 = {"from":L[2256],
"go":function(anf_arg197341442) {
return $Hanf_arg901441443(anf_arg197341442,_plus55);
}};
$e4143241433.stack[R.EXN_STACKHEIGHT++] = $ss4143641437;
}
if(R.isPyretException($e4143241433)) {
$e4143241433.pyretStack.push(L[2256]);
}
throw $e4143241433;
}
var $ret4143841439 = $Hanf_arg901441443($z4143441435,_plus55);
++R.GAS;
return $ret4143841439;
};
var $Hanf_arg901441443 = function(anf_arg197341442,_plus55) {
var $z4144641447 = D;
var $f4145241453 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg197341442):R.ffi.throwNonFunApp(L[2256],_plus55,[("("),anf_arg197341442]);
};
try {
if(--R.GAS > 0) {
$z4144641447 = $f4145241453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4145241453,
"from":L[2256]});
}
} catch($e4144441445) {
if(R.isCont($e4144441445)) {
var $ss4144841449 = {"from":L[2256],
"go":function(anf_arg197441454) {
return $Hanf_arg901341455(anf_arg197441454,_plus55);
}};
$e4144441445.stack[R.EXN_STACKHEIGHT++] = $ss4144841449;
}
if(R.isPyretException($e4144441445)) {
$e4144441445.pyretStack.push(L[2256]);
}
throw $e4144441445;
}
var $ret4145041451 = $Hanf_arg901341455($z4144641447,_plus55);
++R.GAS;
return $ret4145041451;
};
var $Hanf_arg901341455 = function(anf_arg197441454,_plus55) {
var $z4145841459 = D;
var $f4146441465 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-contract"),anf_arg197441454):R.ffi.throwNonFunApp(L[2256],_plus55,[("s-contract"),anf_arg197441454]);
};
try {
if(--R.GAS > 0) {
$z4145841459 = $f4146441465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4146441465,
"from":L[2256]});
}
} catch($e4145641457) {
if(R.isCont($e4145641457)) {
var $ss4146041461 = {"from":L[2256],
"go":function(ann_DASH_check_DASH_temp196241466) {
return $Hann_DASH_check_DASH_temp901241467(ann_DASH_check_DASH_temp196241466);
}};
$e4145641457.stack[R.EXN_STACKHEIGHT++] = $ss4146041461;
}
if(R.isPyretException($e4145641457)) {
$e4145641457.pyretStack.push(L[2256]);
}
throw $e4145641457;
}
var $ret4146241463 = $Hann_DASH_check_DASH_temp901241467($z4145841459);
++R.GAS;
return $ret4146241463;
};
var $Hann_DASH_check_DASH_temp901241467 = function(ann_DASH_check_DASH_temp196241466) {
return ann_DASH_check_DASH_temp196241466;
};
var $Hcont_tail_arg901015743 = function(cont_tail_arg195915741,if_helper194915742) {
if(--R.GAS > 0) {
$z4146841469 = R.isFunction(if_helper194915742)?if_helper194915742.app(cont_tail_arg195915741):R.ffi.throwNonFunApp(L[2256],if_helper194915742,[cont_tail_arg195915741]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper194915742)?if_helper194915742.app(cont_tail_arg195915741):R.ffi.throwNonFunApp(L[2256],if_helper194915742,[cont_tail_arg195915741]);
},
"from":L[2256]});
}
++R.GAS;
return $z4146841469;
};
var $Hcont_tail_arg901115758 = function(cont_tail_arg195415757,if_helper194915742) {
if(--R.GAS > 0) {
$z4147041471 = R.isFunction(if_helper194915742)?if_helper194915742.app(cont_tail_arg195415757):R.ffi.throwNonFunApp(L[2256],if_helper194915742,[cont_tail_arg195415757]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper194915742)?if_helper194915742.app(cont_tail_arg195415757):R.ffi.throwNonFunApp(L[2256],if_helper194915742,[cont_tail_arg195415757]);
},
"from":L[2256]});
}
++R.GAS;
return $z4147041471;
};
var $Hanf_arg900915782 = function(anf_arg194615780,anf_fun193915781,str_DASH_end148546,str_DASH_graph154624) {
var $z4147441475 = D;
var $f4148041481 = function(_) {
return R.isFunction(anf_fun193915781)?anf_fun193915781.app((0),(1),str_DASH_graph154624,anf_arg194615780,str_DASH_end148546):R.ffi.throwNonFunApp(L[2894],anf_fun193915781,[(0),(1),str_DASH_graph154624,anf_arg194615780,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4147441475 = $f4148041481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4148041481,
"from":L[2894]});
}
} catch($e4147241473) {
if(R.isCont($e4147241473)) {
var $ss4147641477 = {"from":L[2894],
"go":function(ann_DASH_check_DASH_temp193841482) {
return $Hann_DASH_check_DASH_temp900841483(ann_DASH_check_DASH_temp193841482);
}};
$e4147241473.stack[R.EXN_STACKHEIGHT++] = $ss4147641477;
}
if(R.isPyretException($e4147241473)) {
$e4147241473.pyretStack.push(L[2894]);
}
throw $e4147241473;
}
var $ret4147841479 = $Hann_DASH_check_DASH_temp900841483($z4147441475);
++R.GAS;
return $ret4147841479;
};
var $Hann_DASH_check_DASH_temp900841483 = function(ann_DASH_check_DASH_temp193841482) {
return ann_DASH_check_DASH_temp193841482;
};
var $Hann_DASH_check_DASH_temp900715797 = function(ann_DASH_check_DASH_temp194215796) {
return ann_DASH_check_DASH_temp194215796;
};
var $Hanf_arg900615813 = function(anf_arg192815811,self24415812,_plus55,torepr65) {
var anf_arg192941494 = G(self24415812,"bindings",L[2257]);
var $z4148641487 = D;
var $f4149241493 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg192941494):R.ffi.throwNonFunApp(L[2257],torepr65,[anf_arg192941494]);
};
try {
if(--R.GAS > 0) {
$z4148641487 = $f4149241493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4149241493,
"from":L[2257]});
}
} catch($e4148441485) {
if(R.isCont($e4148441485)) {
var $ss4148841489 = {"from":L[2257],
"go":function(anf_arg193041495) {
return $Hanf_arg900541496(anf_arg193041495,anf_arg192815811,_plus55);
}};
$e4148441485.stack[R.EXN_STACKHEIGHT++] = $ss4148841489;
}
if(R.isPyretException($e4148441485)) {
$e4148441485.pyretStack.push(L[2257]);
}
throw $e4148441485;
}
var $ret4149041491 = $Hanf_arg900541496($z4148641487,anf_arg192815811,_plus55);
++R.GAS;
return $ret4149041491;
};
var $Hanf_arg900541496 = function(anf_arg193041495,anf_arg192815811,_plus55) {
var $z4149941500 = D;
var $f4150541506 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg193041495):R.ffi.throwNonFunApp(L[2257],_plus55,[(", "),anf_arg193041495]);
};
try {
if(--R.GAS > 0) {
$z4149941500 = $f4150541506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4150541506,
"from":L[2257]});
}
} catch($e4149741498) {
if(R.isCont($e4149741498)) {
var $ss4150141502 = {"from":L[2257],
"go":function(anf_arg193141507) {
return $Hanf_arg900441508(anf_arg193141507,anf_arg192815811,_plus55);
}};
$e4149741498.stack[R.EXN_STACKHEIGHT++] = $ss4150141502;
}
if(R.isPyretException($e4149741498)) {
$e4149741498.pyretStack.push(L[2257]);
}
throw $e4149741498;
}
var $ret4150341504 = $Hanf_arg900441508($z4149941500,anf_arg192815811,_plus55);
++R.GAS;
return $ret4150341504;
};
var $Hanf_arg900441508 = function(anf_arg193141507,anf_arg192815811,_plus55) {
var $z4151141512 = D;
var $f4151741518 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg192815811,anf_arg193141507):R.ffi.throwNonFunApp(L[2257],_plus55,[anf_arg192815811,anf_arg193141507]);
};
try {
if(--R.GAS > 0) {
$z4151141512 = $f4151741518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4151741518,
"from":L[2257]});
}
} catch($e4150941510) {
if(R.isCont($e4150941510)) {
var $ss4151341514 = {"from":L[2257],
"go":function(anf_arg193241519) {
return $Hanf_arg900341520(anf_arg193241519,_plus55);
}};
$e4150941510.stack[R.EXN_STACKHEIGHT++] = $ss4151341514;
}
if(R.isPyretException($e4150941510)) {
$e4150941510.pyretStack.push(L[2257]);
}
throw $e4150941510;
}
var $ret4151541516 = $Hanf_arg900341520($z4151141512,_plus55);
++R.GAS;
return $ret4151541516;
};
var $Hanf_arg900341520 = function(anf_arg193241519,_plus55) {
var $z4152341524 = D;
var $f4152941530 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg193241519,(")")):R.ffi.throwNonFunApp(L[2257],_plus55,[anf_arg193241519,(")")]);
};
try {
if(--R.GAS > 0) {
$z4152341524 = $f4152941530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4152941530,
"from":L[2257]});
}
} catch($e4152141522) {
if(R.isCont($e4152141522)) {
var $ss4152541526 = {"from":L[2257],
"go":function(anf_arg193341531) {
return $Hanf_arg900241532(anf_arg193341531,_plus55);
}};
$e4152141522.stack[R.EXN_STACKHEIGHT++] = $ss4152541526;
}
if(R.isPyretException($e4152141522)) {
$e4152141522.pyretStack.push(L[2257]);
}
throw $e4152141522;
}
var $ret4152741528 = $Hanf_arg900241532($z4152341524,_plus55);
++R.GAS;
return $ret4152741528;
};
var $Hanf_arg900241532 = function(anf_arg193341531,_plus55) {
var $z4153541536 = D;
var $f4154141542 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg193341531):R.ffi.throwNonFunApp(L[2257],_plus55,[("("),anf_arg193341531]);
};
try {
if(--R.GAS > 0) {
$z4153541536 = $f4154141542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4154141542,
"from":L[2257]});
}
} catch($e4153341534) {
if(R.isCont($e4153341534)) {
var $ss4153741538 = {"from":L[2257],
"go":function(anf_arg193441543) {
return $Hanf_arg900141544(anf_arg193441543,_plus55);
}};
$e4153341534.stack[R.EXN_STACKHEIGHT++] = $ss4153741538;
}
if(R.isPyretException($e4153341534)) {
$e4153341534.pyretStack.push(L[2257]);
}
throw $e4153341534;
}
var $ret4153941540 = $Hanf_arg900141544($z4153541536,_plus55);
++R.GAS;
return $ret4153941540;
};
var $Hanf_arg900141544 = function(anf_arg193441543,_plus55) {
var $z4154741548 = D;
var $f4155341554 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-graph"),anf_arg193441543):R.ffi.throwNonFunApp(L[2257],_plus55,[("s-graph"),anf_arg193441543]);
};
try {
if(--R.GAS > 0) {
$z4154741548 = $f4155341554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4155341554,
"from":L[2257]});
}
} catch($e4154541546) {
if(R.isCont($e4154541546)) {
var $ss4154941550 = {"from":L[2257],
"go":function(ann_DASH_check_DASH_temp192641555) {
return $Hann_DASH_check_DASH_temp900041556(ann_DASH_check_DASH_temp192641555);
}};
$e4154541546.stack[R.EXN_STACKHEIGHT++] = $ss4154941550;
}
if(R.isPyretException($e4154541546)) {
$e4154541546.pyretStack.push(L[2257]);
}
throw $e4154541546;
}
var $ret4155141552 = $Hann_DASH_check_DASH_temp900041556($z4154741548);
++R.GAS;
return $ret4155141552;
};
var $Hann_DASH_check_DASH_temp900041556 = function(ann_DASH_check_DASH_temp192641555) {
return ann_DASH_check_DASH_temp192641555;
};
var $Hcont_tail_arg899815829 = function(cont_tail_arg192315827,if_helper191415828) {
if(--R.GAS > 0) {
$z4155741558 = R.isFunction(if_helper191415828)?if_helper191415828.app(cont_tail_arg192315827):R.ffi.throwNonFunApp(L[2257],if_helper191415828,[cont_tail_arg192315827]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper191415828)?if_helper191415828.app(cont_tail_arg192315827):R.ffi.throwNonFunApp(L[2257],if_helper191415828,[cont_tail_arg192315827]);
},
"from":L[2257]});
}
++R.GAS;
return $z4155741558;
};
var $Hcont_tail_arg899915843 = function(cont_tail_arg191915842,if_helper191415828) {
if(--R.GAS > 0) {
$z4155941560 = R.isFunction(if_helper191415828)?if_helper191415828.app(cont_tail_arg191915842):R.ffi.throwNonFunApp(L[2257],if_helper191415828,[cont_tail_arg191915842]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper191415828)?if_helper191415828.app(cont_tail_arg191915842):R.ffi.throwNonFunApp(L[2257],if_helper191415828,[cont_tail_arg191915842]);
},
"from":L[2257]});
}
++R.GAS;
return $z4155941560;
};
var $Hcont_tail_app899715863 = function(cont_tail_app191115862) {
return cont_tail_app191115862;
};
var $Hanf_arg899615888 = function(anf_arg189715884,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,if_helper_arg189415872,self72315887,str_DASH_spaceequal170832,_plus55) {
var $z4156341564 = D;
var $f4156941570 = function(_) {
return R.isFunction(_plus55)?_plus55.app(if_helper_arg189415872,anf_arg189715884):R.ffi.throwNonFunApp(L[4617],_plus55,[if_helper_arg189415872,anf_arg189715884]);
};
try {
if(--R.GAS > 0) {
$z4156341564 = $f4156941570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4156941570,
"from":L[4617]});
}
} catch($e4156141562) {
if(R.isCont($e4156141562)) {
var $ss4156541566 = {"from":L[4617],
"go":function(anf_arg189841571) {
return $Hanf_arg899541572(anf_arg189841571,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,self72315887,str_DASH_spaceequal170832,_plus55);
}};
$e4156141562.stack[R.EXN_STACKHEIGHT++] = $ss4156541566;
}
if(R.isPyretException($e4156141562)) {
$e4156141562.pyretStack.push(L[4617]);
}
throw $e4156141562;
}
var $ret4156741568 = $Hanf_arg899541572($z4156341564,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,self72315887,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret4156741568;
};
var $Hanf_arg899541572 = function(anf_arg189841571,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,self72315887,str_DASH_spaceequal170832,_plus55) {
var $z4157541576 = D;
var $f4158141582 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg189841571,str_DASH_spaceequal170832):R.ffi.throwNonFunApp(L[4617],_plus55,[anf_arg189841571,str_DASH_spaceequal170832]);
};
try {
if(--R.GAS > 0) {
$z4157541576 = $f4158141582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4158141582,
"from":L[4617]});
}
} catch($e4157341574) {
if(R.isCont($e4157341574)) {
var $ss4157741578 = {"from":L[4617],
"go":function(anf_arg189941583) {
return $Hanf_arg899441584(anf_arg189941583,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,self72315887,_plus55);
}};
$e4157341574.stack[R.EXN_STACKHEIGHT++] = $ss4157741578;
}
if(R.isPyretException($e4157341574)) {
$e4157341574.pyretStack.push(L[4617]);
}
throw $e4157341574;
}
var $ret4157941580 = $Hanf_arg899441584($z4157541576,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,self72315887,_plus55);
++R.GAS;
return $ret4157941580;
};
var $Hanf_arg899441584 = function(anf_arg189941583,INDENT118169,anf_fun189115885,anf_fun189215886,break_DASH_one119168,self72315887,_plus55) {
var $z4158741588 = D;
var $f4159341594 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg189941583,break_DASH_one119168):R.ffi.throwNonFunApp(L[4617],_plus55,[anf_arg189941583,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4158741588 = $f4159341594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4159341594,
"from":L[4617]});
}
} catch($e4158541586) {
if(R.isCont($e4158541586)) {
var $ss4158941590 = {"from":L[4617],
"go":function(anf_arg190041595) {
return $Hanf_arg899341596(anf_arg190041595,INDENT118169,anf_fun189115885,anf_fun189215886,self72315887,_plus55);
}};
$e4158541586.stack[R.EXN_STACKHEIGHT++] = $ss4158941590;
}
if(R.isPyretException($e4158541586)) {
$e4158541586.pyretStack.push(L[4617]);
}
throw $e4158541586;
}
var $ret4159141592 = $Hanf_arg899341596($z4158741588,INDENT118169,anf_fun189115885,anf_fun189215886,self72315887,_plus55);
++R.GAS;
return $ret4159141592;
};
var $Hanf_arg899341596 = function(anf_arg190041595,INDENT118169,anf_fun189115885,anf_fun189215886,self72315887,_plus55) {
var anf_bracket190141610 = G(self72315887,"value",L[4620]);
var anf_fun190241607 = G(anf_bracket190141610,"tosource",L[4619]);
var $z4159941600 = D;
var $f4160541606 = function(_) {
return R.isFunction(anf_fun190241607)?anf_fun190241607.app():R.ffi.throwNonFunApp(L[4618],anf_fun190241607,[]);
};
try {
if(--R.GAS > 0) {
$z4159941600 = $f4160541606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4160541606,
"from":L[4618]});
}
} catch($e4159741598) {
if(R.isCont($e4159741598)) {
var $ss4160141602 = {"from":L[4618],
"go":function(anf_arg190341608) {
return $Hanf_arg899241609(anf_arg190341608,INDENT118169,anf_arg190041595,anf_fun189115885,anf_fun189215886,_plus55);
}};
$e4159741598.stack[R.EXN_STACKHEIGHT++] = $ss4160141602;
}
if(R.isPyretException($e4159741598)) {
$e4159741598.pyretStack.push(L[4618]);
}
throw $e4159741598;
}
var $ret4160341604 = $Hanf_arg899241609($z4159941600,INDENT118169,anf_arg190041595,anf_fun189115885,anf_fun189215886,_plus55);
++R.GAS;
return $ret4160341604;
};
var $Hanf_arg899241609 = function(anf_arg190341608,INDENT118169,anf_arg190041595,anf_fun189115885,anf_fun189215886,_plus55) {
var $z4161341614 = D;
var $f4161941620 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg190041595,anf_arg190341608):R.ffi.throwNonFunApp(L[4617],_plus55,[anf_arg190041595,anf_arg190341608]);
};
try {
if(--R.GAS > 0) {
$z4161341614 = $f4161941620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4161941620,
"from":L[4617]});
}
} catch($e4161141612) {
if(R.isCont($e4161141612)) {
var $ss4161541616 = {"from":L[4617],
"go":function(anf_arg190441621) {
return $Hanf_arg899141622(anf_arg190441621,INDENT118169,anf_fun189115885,anf_fun189215886);
}};
$e4161141612.stack[R.EXN_STACKHEIGHT++] = $ss4161541616;
}
if(R.isPyretException($e4161141612)) {
$e4161141612.pyretStack.push(L[4617]);
}
throw $e4161141612;
}
var $ret4161741618 = $Hanf_arg899141622($z4161341614,INDENT118169,anf_fun189115885,anf_fun189215886);
++R.GAS;
return $ret4161741618;
};
var $Hanf_arg899141622 = function(anf_arg190441621,INDENT118169,anf_fun189115885,anf_fun189215886) {
var $z4162541626 = D;
var $f4163141632 = function(_) {
return R.isFunction(anf_fun189215886)?anf_fun189215886.app(INDENT118169,anf_arg190441621):R.ffi.throwNonFunApp(L[4621],anf_fun189215886,[INDENT118169,anf_arg190441621]);
};
try {
if(--R.GAS > 0) {
$z4162541626 = $f4163141632();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4163141632,
"from":L[4621]});
}
} catch($e4162341624) {
if(R.isCont($e4162341624)) {
var $ss4162741628 = {"from":L[4621],
"go":function(anf_arg190541633) {
return $Hanf_arg899041634(anf_arg190541633,anf_fun189115885);
}};
$e4162341624.stack[R.EXN_STACKHEIGHT++] = $ss4162741628;
}
if(R.isPyretException($e4162341624)) {
$e4162341624.pyretStack.push(L[4621]);
}
throw $e4162341624;
}
var $ret4162941630 = $Hanf_arg899041634($z4162541626,anf_fun189115885);
++R.GAS;
return $ret4162941630;
};
var $Hanf_arg899041634 = function(anf_arg190541633,anf_fun189115885) {
var $z4163741638 = D;
var $f4164341644 = function(_) {
return R.isFunction(anf_fun189115885)?anf_fun189115885.app(anf_arg190541633):R.ffi.throwNonFunApp(L[2906],anf_fun189115885,[anf_arg190541633]);
};
try {
if(--R.GAS > 0) {
$z4163741638 = $f4164341644();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4164341644,
"from":L[2906]});
}
} catch($e4163541636) {
if(R.isCont($e4163541636)) {
var $ss4163941640 = {"from":L[2906],
"go":function(ann_DASH_check_DASH_temp189041645) {
return $Hann_DASH_check_DASH_temp898941646(ann_DASH_check_DASH_temp189041645);
}};
$e4163541636.stack[R.EXN_STACKHEIGHT++] = $ss4163941640;
}
if(R.isPyretException($e4163541636)) {
$e4163541636.pyretStack.push(L[2906]);
}
throw $e4163541636;
}
var $ret4164141642 = $Hann_DASH_check_DASH_temp898941646($z4163741638);
++R.GAS;
return $ret4164141642;
};
var $Hann_DASH_check_DASH_temp898941646 = function(ann_DASH_check_DASH_temp189041645) {
return ann_DASH_check_DASH_temp189041645;
};
var $Hanf_arg898815904 = function(anf_arg187215903,self2371785,_plus55,torepr65) {
var anf_arg187341657 = G(self2371785,"name",L[2258]);
var $z4164941650 = D;
var $f4165541656 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg187341657):R.ffi.throwNonFunApp(L[2258],torepr65,[anf_arg187341657]);
};
try {
if(--R.GAS > 0) {
$z4164941650 = $f4165541656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4165541656,
"from":L[2258]});
}
} catch($e4164741648) {
if(R.isCont($e4164741648)) {
var $ss4165141652 = {"from":L[2258],
"go":function(anf_arg187441658) {
return $Hanf_arg898741659(anf_arg187441658,anf_arg187215903,self2371785,_plus55,torepr65);
}};
$e4164741648.stack[R.EXN_STACKHEIGHT++] = $ss4165141652;
}
if(R.isPyretException($e4164741648)) {
$e4164741648.pyretStack.push(L[2258]);
}
throw $e4164741648;
}
var $ret4165341654 = $Hanf_arg898741659($z4164941650,anf_arg187215903,self2371785,_plus55,torepr65);
++R.GAS;
return $ret4165341654;
};
var $Hanf_arg898741659 = function(anf_arg187441658,anf_arg187215903,self2371785,_plus55,torepr65) {
var $z4166241663 = D;
var $f4166841669 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg187441658):R.ffi.throwNonFunApp(L[2258],_plus55,[(", "),anf_arg187441658]);
};
try {
if(--R.GAS > 0) {
$z4166241663 = $f4166841669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4166841669,
"from":L[2258]});
}
} catch($e4166041661) {
if(R.isCont($e4166041661)) {
var $ss4166441665 = {"from":L[2258],
"go":function(anf_arg187541670) {
return $Hanf_arg898641671(anf_arg187541670,anf_arg187215903,self2371785,_plus55,torepr65);
}};
$e4166041661.stack[R.EXN_STACKHEIGHT++] = $ss4166441665;
}
if(R.isPyretException($e4166041661)) {
$e4166041661.pyretStack.push(L[2258]);
}
throw $e4166041661;
}
var $ret4166641667 = $Hanf_arg898641671($z4166241663,anf_arg187215903,self2371785,_plus55,torepr65);
++R.GAS;
return $ret4166641667;
};
var $Hanf_arg898641671 = function(anf_arg187541670,anf_arg187215903,self2371785,_plus55,torepr65) {
var $z4167441675 = D;
var $f4168041681 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg187215903,anf_arg187541670):R.ffi.throwNonFunApp(L[2258],_plus55,[anf_arg187215903,anf_arg187541670]);
};
try {
if(--R.GAS > 0) {
$z4167441675 = $f4168041681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4168041681,
"from":L[2258]});
}
} catch($e4167241673) {
if(R.isCont($e4167241673)) {
var $ss4167641677 = {"from":L[2258],
"go":function(anf_arg187641682) {
return $Hanf_arg898541683(anf_arg187641682,self2371785,_plus55,torepr65);
}};
$e4167241673.stack[R.EXN_STACKHEIGHT++] = $ss4167641677;
}
if(R.isPyretException($e4167241673)) {
$e4167241673.pyretStack.push(L[2258]);
}
throw $e4167241673;
}
var $ret4167841679 = $Hanf_arg898541683($z4167441675,self2371785,_plus55,torepr65);
++R.GAS;
return $ret4167841679;
};
var $Hanf_arg898541683 = function(anf_arg187641682,self2371785,_plus55,torepr65) {
var anf_arg187741694 = G(self2371785,"value",L[2258]);
var $z4168641687 = D;
var $f4169241693 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg187741694):R.ffi.throwNonFunApp(L[2258],torepr65,[anf_arg187741694]);
};
try {
if(--R.GAS > 0) {
$z4168641687 = $f4169241693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4169241693,
"from":L[2258]});
}
} catch($e4168441685) {
if(R.isCont($e4168441685)) {
var $ss4168841689 = {"from":L[2258],
"go":function(anf_arg187841695) {
return $Hanf_arg898441696(anf_arg187841695,anf_arg187641682,self2371785,_plus55,torepr65);
}};
$e4168441685.stack[R.EXN_STACKHEIGHT++] = $ss4168841689;
}
if(R.isPyretException($e4168441685)) {
$e4168441685.pyretStack.push(L[2258]);
}
throw $e4168441685;
}
var $ret4169041691 = $Hanf_arg898441696($z4168641687,anf_arg187641682,self2371785,_plus55,torepr65);
++R.GAS;
return $ret4169041691;
};
var $Hanf_arg898441696 = function(anf_arg187841695,anf_arg187641682,self2371785,_plus55,torepr65) {
var $z4169941700 = D;
var $f4170541706 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg187841695):R.ffi.throwNonFunApp(L[2258],_plus55,[(", "),anf_arg187841695]);
};
try {
if(--R.GAS > 0) {
$z4169941700 = $f4170541706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4170541706,
"from":L[2258]});
}
} catch($e4169741698) {
if(R.isCont($e4169741698)) {
var $ss4170141702 = {"from":L[2258],
"go":function(anf_arg187941707) {
return $Hanf_arg898341708(anf_arg187941707,anf_arg187641682,self2371785,_plus55,torepr65);
}};
$e4169741698.stack[R.EXN_STACKHEIGHT++] = $ss4170141702;
}
if(R.isPyretException($e4169741698)) {
$e4169741698.pyretStack.push(L[2258]);
}
throw $e4169741698;
}
var $ret4170341704 = $Hanf_arg898341708($z4169941700,anf_arg187641682,self2371785,_plus55,torepr65);
++R.GAS;
return $ret4170341704;
};
var $Hanf_arg898341708 = function(anf_arg187941707,anf_arg187641682,self2371785,_plus55,torepr65) {
var $z4171141712 = D;
var $f4171741718 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg187641682,anf_arg187941707):R.ffi.throwNonFunApp(L[2258],_plus55,[anf_arg187641682,anf_arg187941707]);
};
try {
if(--R.GAS > 0) {
$z4171141712 = $f4171741718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4171741718,
"from":L[2258]});
}
} catch($e4170941710) {
if(R.isCont($e4170941710)) {
var $ss4171341714 = {"from":L[2258],
"go":function(anf_arg188041719) {
return $Hanf_arg898241720(anf_arg188041719,self2371785,_plus55,torepr65);
}};
$e4170941710.stack[R.EXN_STACKHEIGHT++] = $ss4171341714;
}
if(R.isPyretException($e4170941710)) {
$e4170941710.pyretStack.push(L[2258]);
}
throw $e4170941710;
}
var $ret4171541716 = $Hanf_arg898241720($z4171141712,self2371785,_plus55,torepr65);
++R.GAS;
return $ret4171541716;
};
var $Hanf_arg898241720 = function(anf_arg188041719,self2371785,_plus55,torepr65) {
var anf_arg188141731 = G(self2371785,"keyword-val",L[2258]);
var $z4172341724 = D;
var $f4172941730 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg188141731):R.ffi.throwNonFunApp(L[2258],torepr65,[anf_arg188141731]);
};
try {
if(--R.GAS > 0) {
$z4172341724 = $f4172941730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4172941730,
"from":L[2258]});
}
} catch($e4172141722) {
if(R.isCont($e4172141722)) {
var $ss4172541726 = {"from":L[2258],
"go":function(anf_arg188241732) {
return $Hanf_arg898141733(anf_arg188241732,anf_arg188041719,_plus55);
}};
$e4172141722.stack[R.EXN_STACKHEIGHT++] = $ss4172541726;
}
if(R.isPyretException($e4172141722)) {
$e4172141722.pyretStack.push(L[2258]);
}
throw $e4172141722;
}
var $ret4172741728 = $Hanf_arg898141733($z4172341724,anf_arg188041719,_plus55);
++R.GAS;
return $ret4172741728;
};
var $Hanf_arg898141733 = function(anf_arg188241732,anf_arg188041719,_plus55) {
var $z4173641737 = D;
var $f4174241743 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg188241732):R.ffi.throwNonFunApp(L[2258],_plus55,[(", "),anf_arg188241732]);
};
try {
if(--R.GAS > 0) {
$z4173641737 = $f4174241743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4174241743,
"from":L[2258]});
}
} catch($e4173441735) {
if(R.isCont($e4173441735)) {
var $ss4173841739 = {"from":L[2258],
"go":function(anf_arg188341744) {
return $Hanf_arg898041745(anf_arg188341744,anf_arg188041719,_plus55);
}};
$e4173441735.stack[R.EXN_STACKHEIGHT++] = $ss4173841739;
}
if(R.isPyretException($e4173441735)) {
$e4173441735.pyretStack.push(L[2258]);
}
throw $e4173441735;
}
var $ret4174041741 = $Hanf_arg898041745($z4173641737,anf_arg188041719,_plus55);
++R.GAS;
return $ret4174041741;
};
var $Hanf_arg898041745 = function(anf_arg188341744,anf_arg188041719,_plus55) {
var $z4174841749 = D;
var $f4175441755 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg188041719,anf_arg188341744):R.ffi.throwNonFunApp(L[2258],_plus55,[anf_arg188041719,anf_arg188341744]);
};
try {
if(--R.GAS > 0) {
$z4174841749 = $f4175441755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4175441755,
"from":L[2258]});
}
} catch($e4174641747) {
if(R.isCont($e4174641747)) {
var $ss4175041751 = {"from":L[2258],
"go":function(anf_arg188441756) {
return $Hanf_arg897941757(anf_arg188441756,_plus55);
}};
$e4174641747.stack[R.EXN_STACKHEIGHT++] = $ss4175041751;
}
if(R.isPyretException($e4174641747)) {
$e4174641747.pyretStack.push(L[2258]);
}
throw $e4174641747;
}
var $ret4175241753 = $Hanf_arg897941757($z4174841749,_plus55);
++R.GAS;
return $ret4175241753;
};
var $Hanf_arg897941757 = function(anf_arg188441756,_plus55) {
var $z4176041761 = D;
var $f4176641767 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg188441756,(")")):R.ffi.throwNonFunApp(L[2258],_plus55,[anf_arg188441756,(")")]);
};
try {
if(--R.GAS > 0) {
$z4176041761 = $f4176641767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4176641767,
"from":L[2258]});
}
} catch($e4175841759) {
if(R.isCont($e4175841759)) {
var $ss4176241763 = {"from":L[2258],
"go":function(anf_arg188541768) {
return $Hanf_arg897841769(anf_arg188541768,_plus55);
}};
$e4175841759.stack[R.EXN_STACKHEIGHT++] = $ss4176241763;
}
if(R.isPyretException($e4175841759)) {
$e4175841759.pyretStack.push(L[2258]);
}
throw $e4175841759;
}
var $ret4176441765 = $Hanf_arg897841769($z4176041761,_plus55);
++R.GAS;
return $ret4176441765;
};
var $Hanf_arg897841769 = function(anf_arg188541768,_plus55) {
var $z4177241773 = D;
var $f4177841779 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg188541768):R.ffi.throwNonFunApp(L[2258],_plus55,[("("),anf_arg188541768]);
};
try {
if(--R.GAS > 0) {
$z4177241773 = $f4177841779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4177841779,
"from":L[2258]});
}
} catch($e4177041771) {
if(R.isCont($e4177041771)) {
var $ss4177441775 = {"from":L[2258],
"go":function(anf_arg188641780) {
return $Hanf_arg897741781(anf_arg188641780,_plus55);
}};
$e4177041771.stack[R.EXN_STACKHEIGHT++] = $ss4177441775;
}
if(R.isPyretException($e4177041771)) {
$e4177041771.pyretStack.push(L[2258]);
}
throw $e4177041771;
}
var $ret4177641777 = $Hanf_arg897741781($z4177241773,_plus55);
++R.GAS;
return $ret4177641777;
};
var $Hanf_arg897741781 = function(anf_arg188641780,_plus55) {
var $z4178441785 = D;
var $f4179041791 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-let"),anf_arg188641780):R.ffi.throwNonFunApp(L[2258],_plus55,[("s-let"),anf_arg188641780]);
};
try {
if(--R.GAS > 0) {
$z4178441785 = $f4179041791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4179041791,
"from":L[2258]});
}
} catch($e4178241783) {
if(R.isCont($e4178241783)) {
var $ss4178641787 = {"from":L[2258],
"go":function(ann_DASH_check_DASH_temp187041792) {
return $Hann_DASH_check_DASH_temp897641793(ann_DASH_check_DASH_temp187041792);
}};
$e4178241783.stack[R.EXN_STACKHEIGHT++] = $ss4178641787;
}
if(R.isPyretException($e4178241783)) {
$e4178241783.pyretStack.push(L[2258]);
}
throw $e4178241783;
}
var $ret4178841789 = $Hann_DASH_check_DASH_temp897641793($z4178441785);
++R.GAS;
return $ret4178841789;
};
var $Hann_DASH_check_DASH_temp897641793 = function(ann_DASH_check_DASH_temp187041792) {
return ann_DASH_check_DASH_temp187041792;
};
var $Hcont_tail_arg897415922 = function(cont_tail_arg186715920,if_helper185615921) {
if(--R.GAS > 0) {
$z4179441795 = R.isFunction(if_helper185615921)?if_helper185615921.app(cont_tail_arg186715920):R.ffi.throwNonFunApp(L[2258],if_helper185615921,[cont_tail_arg186715920]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper185615921)?if_helper185615921.app(cont_tail_arg186715920):R.ffi.throwNonFunApp(L[2258],if_helper185615921,[cont_tail_arg186715920]);
},
"from":L[2258]});
}
++R.GAS;
return $z4179441795;
};
var $Hcont_tail_arg897515936 = function(cont_tail_arg186115935,if_helper185615921) {
if(--R.GAS > 0) {
$z4179641797 = R.isFunction(if_helper185615921)?if_helper185615921.app(cont_tail_arg186115935):R.ffi.throwNonFunApp(L[2258],if_helper185615921,[cont_tail_arg186115935]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper185615921)?if_helper185615921.app(cont_tail_arg186115935):R.ffi.throwNonFunApp(L[2258],if_helper185615921,[cont_tail_arg186115935]);
},
"from":L[2258]});
}
++R.GAS;
return $z4179641797;
};
var $Hanf_arg897315959 = function(anf_arg184515955,INDENT118169,anf_fun184115956,anf_fun184215957,break_DASH_one119168,self71715958,str_DASH_spaceequal170832,str_DASH_var175897,_plus55) {
var $z4180041801 = D;
var $f4180641807 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg184515955,str_DASH_spaceequal170832):R.ffi.throwNonFunApp(L[4622],_plus55,[anf_arg184515955,str_DASH_spaceequal170832]);
};
try {
if(--R.GAS > 0) {
$z4180041801 = $f4180641807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4180641807,
"from":L[4622]});
}
} catch($e4179841799) {
if(R.isCont($e4179841799)) {
var $ss4180241803 = {"from":L[4622],
"go":function(anf_arg184641808) {
return $Hanf_arg897241809(anf_arg184641808,INDENT118169,anf_fun184115956,anf_fun184215957,break_DASH_one119168,self71715958,str_DASH_var175897,_plus55);
}};
$e4179841799.stack[R.EXN_STACKHEIGHT++] = $ss4180241803;
}
if(R.isPyretException($e4179841799)) {
$e4179841799.pyretStack.push(L[4622]);
}
throw $e4179841799;
}
var $ret4180441805 = $Hanf_arg897241809($z4180041801,INDENT118169,anf_fun184115956,anf_fun184215957,break_DASH_one119168,self71715958,str_DASH_var175897,_plus55);
++R.GAS;
return $ret4180441805;
};
var $Hanf_arg897241809 = function(anf_arg184641808,INDENT118169,anf_fun184115956,anf_fun184215957,break_DASH_one119168,self71715958,str_DASH_var175897,_plus55) {
var $z4181241813 = D;
var $f4181841819 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg184641808,break_DASH_one119168):R.ffi.throwNonFunApp(L[4622],_plus55,[anf_arg184641808,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4181241813 = $f4181841819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4181841819,
"from":L[4622]});
}
} catch($e4181041811) {
if(R.isCont($e4181041811)) {
var $ss4181441815 = {"from":L[4622],
"go":function(anf_arg184741820) {
return $Hanf_arg897141821(anf_arg184741820,INDENT118169,anf_fun184115956,anf_fun184215957,self71715958,str_DASH_var175897,_plus55);
}};
$e4181041811.stack[R.EXN_STACKHEIGHT++] = $ss4181441815;
}
if(R.isPyretException($e4181041811)) {
$e4181041811.pyretStack.push(L[4622]);
}
throw $e4181041811;
}
var $ret4181641817 = $Hanf_arg897141821($z4181241813,INDENT118169,anf_fun184115956,anf_fun184215957,self71715958,str_DASH_var175897,_plus55);
++R.GAS;
return $ret4181641817;
};
var $Hanf_arg897141821 = function(anf_arg184741820,INDENT118169,anf_fun184115956,anf_fun184215957,self71715958,str_DASH_var175897,_plus55) {
var anf_bracket184841835 = G(self71715958,"value",L[4625]);
var anf_fun184941832 = G(anf_bracket184841835,"tosource",L[4624]);
var $z4182441825 = D;
var $f4183041831 = function(_) {
return R.isFunction(anf_fun184941832)?anf_fun184941832.app():R.ffi.throwNonFunApp(L[4623],anf_fun184941832,[]);
};
try {
if(--R.GAS > 0) {
$z4182441825 = $f4183041831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4183041831,
"from":L[4623]});
}
} catch($e4182241823) {
if(R.isCont($e4182241823)) {
var $ss4182641827 = {"from":L[4623],
"go":function(anf_arg185041833) {
return $Hanf_arg897041834(anf_arg185041833,INDENT118169,anf_arg184741820,anf_fun184115956,anf_fun184215957,str_DASH_var175897,_plus55);
}};
$e4182241823.stack[R.EXN_STACKHEIGHT++] = $ss4182641827;
}
if(R.isPyretException($e4182241823)) {
$e4182241823.pyretStack.push(L[4623]);
}
throw $e4182241823;
}
var $ret4182841829 = $Hanf_arg897041834($z4182441825,INDENT118169,anf_arg184741820,anf_fun184115956,anf_fun184215957,str_DASH_var175897,_plus55);
++R.GAS;
return $ret4182841829;
};
var $Hanf_arg897041834 = function(anf_arg185041833,INDENT118169,anf_arg184741820,anf_fun184115956,anf_fun184215957,str_DASH_var175897,_plus55) {
var $z4183841839 = D;
var $f4184441845 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg184741820,anf_arg185041833):R.ffi.throwNonFunApp(L[4622],_plus55,[anf_arg184741820,anf_arg185041833]);
};
try {
if(--R.GAS > 0) {
$z4183841839 = $f4184441845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4184441845,
"from":L[4622]});
}
} catch($e4183641837) {
if(R.isCont($e4183641837)) {
var $ss4184041841 = {"from":L[4622],
"go":function(anf_arg185141846) {
return $Hanf_arg896941847(anf_arg185141846,INDENT118169,anf_fun184115956,anf_fun184215957,str_DASH_var175897,_plus55);
}};
$e4183641837.stack[R.EXN_STACKHEIGHT++] = $ss4184041841;
}
if(R.isPyretException($e4183641837)) {
$e4183641837.pyretStack.push(L[4622]);
}
throw $e4183641837;
}
var $ret4184241843 = $Hanf_arg896941847($z4183841839,INDENT118169,anf_fun184115956,anf_fun184215957,str_DASH_var175897,_plus55);
++R.GAS;
return $ret4184241843;
};
var $Hanf_arg896941847 = function(anf_arg185141846,INDENT118169,anf_fun184115956,anf_fun184215957,str_DASH_var175897,_plus55) {
var $z4185041851 = D;
var $f4185641857 = function(_) {
return R.isFunction(anf_fun184215957)?anf_fun184215957.app(INDENT118169,anf_arg185141846):R.ffi.throwNonFunApp(L[4626],anf_fun184215957,[INDENT118169,anf_arg185141846]);
};
try {
if(--R.GAS > 0) {
$z4185041851 = $f4185641857();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4185641857,
"from":L[4626]});
}
} catch($e4184841849) {
if(R.isCont($e4184841849)) {
var $ss4185241853 = {"from":L[4626],
"go":function(anf_arg185241858) {
return $Hanf_arg896841859(anf_arg185241858,anf_fun184115956,str_DASH_var175897,_plus55);
}};
$e4184841849.stack[R.EXN_STACKHEIGHT++] = $ss4185241853;
}
if(R.isPyretException($e4184841849)) {
$e4184841849.pyretStack.push(L[4626]);
}
throw $e4184841849;
}
var $ret4185441855 = $Hanf_arg896841859($z4185041851,anf_fun184115956,str_DASH_var175897,_plus55);
++R.GAS;
return $ret4185441855;
};
var $Hanf_arg896841859 = function(anf_arg185241858,anf_fun184115956,str_DASH_var175897,_plus55) {
var $z4186241863 = D;
var $f4186841869 = function(_) {
return R.isFunction(anf_fun184115956)?anf_fun184115956.app(anf_arg185241858):R.ffi.throwNonFunApp(L[4627],anf_fun184115956,[anf_arg185241858]);
};
try {
if(--R.GAS > 0) {
$z4186241863 = $f4186841869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4186841869,
"from":L[4627]});
}
} catch($e4186041861) {
if(R.isCont($e4186041861)) {
var $ss4186441865 = {"from":L[4627],
"go":function(anf_arg185341870) {
return $Hanf_arg896741871(anf_arg185341870,str_DASH_var175897,_plus55);
}};
$e4186041861.stack[R.EXN_STACKHEIGHT++] = $ss4186441865;
}
if(R.isPyretException($e4186041861)) {
$e4186041861.pyretStack.push(L[4627]);
}
throw $e4186041861;
}
var $ret4186641867 = $Hanf_arg896741871($z4186241863,str_DASH_var175897,_plus55);
++R.GAS;
return $ret4186641867;
};
var $Hanf_arg896741871 = function(anf_arg185341870,str_DASH_var175897,_plus55) {
var $z4187441875 = D;
var $f4188041881 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_var175897,anf_arg185341870):R.ffi.throwNonFunApp(L[2917],_plus55,[str_DASH_var175897,anf_arg185341870]);
};
try {
if(--R.GAS > 0) {
$z4187441875 = $f4188041881();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4188041881,
"from":L[2917]});
}
} catch($e4187241873) {
if(R.isCont($e4187241873)) {
var $ss4187641877 = {"from":L[2917],
"go":function(ann_DASH_check_DASH_temp184041882) {
return $Hann_DASH_check_DASH_temp896641883(ann_DASH_check_DASH_temp184041882);
}};
$e4187241873.stack[R.EXN_STACKHEIGHT++] = $ss4187641877;
}
if(R.isPyretException($e4187241873)) {
$e4187241873.pyretStack.push(L[2917]);
}
throw $e4187241873;
}
var $ret4187841879 = $Hann_DASH_check_DASH_temp896641883($z4187441875);
++R.GAS;
return $ret4187841879;
};
var $Hann_DASH_check_DASH_temp896641883 = function(ann_DASH_check_DASH_temp184041882) {
return ann_DASH_check_DASH_temp184041882;
};
var $Hanf_arg896515975 = function(anf_arg182615974,self2311182,_plus55,torepr65) {
var anf_arg182741894 = G(self2311182,"name",L[2259]);
var $z4188641887 = D;
var $f4189241893 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg182741894):R.ffi.throwNonFunApp(L[2259],torepr65,[anf_arg182741894]);
};
try {
if(--R.GAS > 0) {
$z4188641887 = $f4189241893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4189241893,
"from":L[2259]});
}
} catch($e4188441885) {
if(R.isCont($e4188441885)) {
var $ss4188841889 = {"from":L[2259],
"go":function(anf_arg182841895) {
return $Hanf_arg896441896(anf_arg182841895,anf_arg182615974,self2311182,_plus55,torepr65);
}};
$e4188441885.stack[R.EXN_STACKHEIGHT++] = $ss4188841889;
}
if(R.isPyretException($e4188441885)) {
$e4188441885.pyretStack.push(L[2259]);
}
throw $e4188441885;
}
var $ret4189041891 = $Hanf_arg896441896($z4188641887,anf_arg182615974,self2311182,_plus55,torepr65);
++R.GAS;
return $ret4189041891;
};
var $Hanf_arg896441896 = function(anf_arg182841895,anf_arg182615974,self2311182,_plus55,torepr65) {
var $z4189941900 = D;
var $f4190541906 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg182841895):R.ffi.throwNonFunApp(L[2259],_plus55,[(", "),anf_arg182841895]);
};
try {
if(--R.GAS > 0) {
$z4189941900 = $f4190541906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4190541906,
"from":L[2259]});
}
} catch($e4189741898) {
if(R.isCont($e4189741898)) {
var $ss4190141902 = {"from":L[2259],
"go":function(anf_arg182941907) {
return $Hanf_arg896341908(anf_arg182941907,anf_arg182615974,self2311182,_plus55,torepr65);
}};
$e4189741898.stack[R.EXN_STACKHEIGHT++] = $ss4190141902;
}
if(R.isPyretException($e4189741898)) {
$e4189741898.pyretStack.push(L[2259]);
}
throw $e4189741898;
}
var $ret4190341904 = $Hanf_arg896341908($z4189941900,anf_arg182615974,self2311182,_plus55,torepr65);
++R.GAS;
return $ret4190341904;
};
var $Hanf_arg896341908 = function(anf_arg182941907,anf_arg182615974,self2311182,_plus55,torepr65) {
var $z4191141912 = D;
var $f4191741918 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg182615974,anf_arg182941907):R.ffi.throwNonFunApp(L[2259],_plus55,[anf_arg182615974,anf_arg182941907]);
};
try {
if(--R.GAS > 0) {
$z4191141912 = $f4191741918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4191741918,
"from":L[2259]});
}
} catch($e4190941910) {
if(R.isCont($e4190941910)) {
var $ss4191341914 = {"from":L[2259],
"go":function(anf_arg183041919) {
return $Hanf_arg896241920(anf_arg183041919,self2311182,_plus55,torepr65);
}};
$e4190941910.stack[R.EXN_STACKHEIGHT++] = $ss4191341914;
}
if(R.isPyretException($e4190941910)) {
$e4190941910.pyretStack.push(L[2259]);
}
throw $e4190941910;
}
var $ret4191541916 = $Hanf_arg896241920($z4191141912,self2311182,_plus55,torepr65);
++R.GAS;
return $ret4191541916;
};
var $Hanf_arg896241920 = function(anf_arg183041919,self2311182,_plus55,torepr65) {
var anf_arg183141931 = G(self2311182,"value",L[2259]);
var $z4192341924 = D;
var $f4192941930 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg183141931):R.ffi.throwNonFunApp(L[2259],torepr65,[anf_arg183141931]);
};
try {
if(--R.GAS > 0) {
$z4192341924 = $f4192941930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4192941930,
"from":L[2259]});
}
} catch($e4192141922) {
if(R.isCont($e4192141922)) {
var $ss4192541926 = {"from":L[2259],
"go":function(anf_arg183241932) {
return $Hanf_arg896141933(anf_arg183241932,anf_arg183041919,_plus55);
}};
$e4192141922.stack[R.EXN_STACKHEIGHT++] = $ss4192541926;
}
if(R.isPyretException($e4192141922)) {
$e4192141922.pyretStack.push(L[2259]);
}
throw $e4192141922;
}
var $ret4192741928 = $Hanf_arg896141933($z4192341924,anf_arg183041919,_plus55);
++R.GAS;
return $ret4192741928;
};
var $Hanf_arg896141933 = function(anf_arg183241932,anf_arg183041919,_plus55) {
var $z4193641937 = D;
var $f4194241943 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg183241932):R.ffi.throwNonFunApp(L[2259],_plus55,[(", "),anf_arg183241932]);
};
try {
if(--R.GAS > 0) {
$z4193641937 = $f4194241943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4194241943,
"from":L[2259]});
}
} catch($e4193441935) {
if(R.isCont($e4193441935)) {
var $ss4193841939 = {"from":L[2259],
"go":function(anf_arg183341944) {
return $Hanf_arg896041945(anf_arg183341944,anf_arg183041919,_plus55);
}};
$e4193441935.stack[R.EXN_STACKHEIGHT++] = $ss4193841939;
}
if(R.isPyretException($e4193441935)) {
$e4193441935.pyretStack.push(L[2259]);
}
throw $e4193441935;
}
var $ret4194041941 = $Hanf_arg896041945($z4193641937,anf_arg183041919,_plus55);
++R.GAS;
return $ret4194041941;
};
var $Hanf_arg896041945 = function(anf_arg183341944,anf_arg183041919,_plus55) {
var $z4194841949 = D;
var $f4195441955 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg183041919,anf_arg183341944):R.ffi.throwNonFunApp(L[2259],_plus55,[anf_arg183041919,anf_arg183341944]);
};
try {
if(--R.GAS > 0) {
$z4194841949 = $f4195441955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4195441955,
"from":L[2259]});
}
} catch($e4194641947) {
if(R.isCont($e4194641947)) {
var $ss4195041951 = {"from":L[2259],
"go":function(anf_arg183441956) {
return $Hanf_arg895941957(anf_arg183441956,_plus55);
}};
$e4194641947.stack[R.EXN_STACKHEIGHT++] = $ss4195041951;
}
if(R.isPyretException($e4194641947)) {
$e4194641947.pyretStack.push(L[2259]);
}
throw $e4194641947;
}
var $ret4195241953 = $Hanf_arg895941957($z4194841949,_plus55);
++R.GAS;
return $ret4195241953;
};
var $Hanf_arg895941957 = function(anf_arg183441956,_plus55) {
var $z4196041961 = D;
var $f4196641967 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg183441956,(")")):R.ffi.throwNonFunApp(L[2259],_plus55,[anf_arg183441956,(")")]);
};
try {
if(--R.GAS > 0) {
$z4196041961 = $f4196641967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4196641967,
"from":L[2259]});
}
} catch($e4195841959) {
if(R.isCont($e4195841959)) {
var $ss4196241963 = {"from":L[2259],
"go":function(anf_arg183541968) {
return $Hanf_arg895841969(anf_arg183541968,_plus55);
}};
$e4195841959.stack[R.EXN_STACKHEIGHT++] = $ss4196241963;
}
if(R.isPyretException($e4195841959)) {
$e4195841959.pyretStack.push(L[2259]);
}
throw $e4195841959;
}
var $ret4196441965 = $Hanf_arg895841969($z4196041961,_plus55);
++R.GAS;
return $ret4196441965;
};
var $Hanf_arg895841969 = function(anf_arg183541968,_plus55) {
var $z4197241973 = D;
var $f4197841979 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg183541968):R.ffi.throwNonFunApp(L[2259],_plus55,[("("),anf_arg183541968]);
};
try {
if(--R.GAS > 0) {
$z4197241973 = $f4197841979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4197841979,
"from":L[2259]});
}
} catch($e4197041971) {
if(R.isCont($e4197041971)) {
var $ss4197441975 = {"from":L[2259],
"go":function(anf_arg183641980) {
return $Hanf_arg895741981(anf_arg183641980,_plus55);
}};
$e4197041971.stack[R.EXN_STACKHEIGHT++] = $ss4197441975;
}
if(R.isPyretException($e4197041971)) {
$e4197041971.pyretStack.push(L[2259]);
}
throw $e4197041971;
}
var $ret4197641977 = $Hanf_arg895741981($z4197241973,_plus55);
++R.GAS;
return $ret4197641977;
};
var $Hanf_arg895741981 = function(anf_arg183641980,_plus55) {
var $z4198441985 = D;
var $f4199041991 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-var"),anf_arg183641980):R.ffi.throwNonFunApp(L[2259],_plus55,[("s-var"),anf_arg183641980]);
};
try {
if(--R.GAS > 0) {
$z4198441985 = $f4199041991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4199041991,
"from":L[2259]});
}
} catch($e4198241983) {
if(R.isCont($e4198241983)) {
var $ss4198641987 = {"from":L[2259],
"go":function(ann_DASH_check_DASH_temp182441992) {
return $Hann_DASH_check_DASH_temp895641993(ann_DASH_check_DASH_temp182441992);
}};
$e4198241983.stack[R.EXN_STACKHEIGHT++] = $ss4198641987;
}
if(R.isPyretException($e4198241983)) {
$e4198241983.pyretStack.push(L[2259]);
}
throw $e4198241983;
}
var $ret4198841989 = $Hann_DASH_check_DASH_temp895641993($z4198441985);
++R.GAS;
return $ret4198841989;
};
var $Hann_DASH_check_DASH_temp895641993 = function(ann_DASH_check_DASH_temp182441992) {
return ann_DASH_check_DASH_temp182441992;
};
var $Hcont_tail_arg895415992 = function(cont_tail_arg182115990,if_helper181115991) {
if(--R.GAS > 0) {
$z4199441995 = R.isFunction(if_helper181115991)?if_helper181115991.app(cont_tail_arg182115990):R.ffi.throwNonFunApp(L[2259],if_helper181115991,[cont_tail_arg182115990]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper181115991)?if_helper181115991.app(cont_tail_arg182115990):R.ffi.throwNonFunApp(L[2259],if_helper181115991,[cont_tail_arg182115990]);
},
"from":L[2259]});
}
++R.GAS;
return $z4199441995;
};
var $Hcont_tail_arg895516007 = function(cont_tail_arg181616006,if_helper181115991) {
if(--R.GAS > 0) {
$z4199641997 = R.isFunction(if_helper181115991)?if_helper181115991.app(cont_tail_arg181616006):R.ffi.throwNonFunApp(L[2259],if_helper181115991,[cont_tail_arg181616006]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper181115991)?if_helper181115991.app(cont_tail_arg181616006):R.ffi.throwNonFunApp(L[2259],if_helper181115991,[cont_tail_arg181616006]);
},
"from":L[2259]});
}
++R.GAS;
return $z4199641997;
};
var $Hanf_arg895316030 = function(anf_arg179916026,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,str_DASH_newtype176910,_plus55) {
var $z4200042001 = D;
var $f4200642007 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_newtype176910,anf_arg179916026):R.ffi.throwNonFunApp(L[4628],_plus55,[str_DASH_newtype176910,anf_arg179916026]);
};
try {
if(--R.GAS > 0) {
$z4200042001 = $f4200642007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4200642007,
"from":L[4628]});
}
} catch($e4199841999) {
if(R.isCont($e4199841999)) {
var $ss4200242003 = {"from":L[4628],
"go":function(anf_arg180042008) {
return $Hanf_arg895242009(anf_arg180042008,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,_plus55);
}};
$e4199841999.stack[R.EXN_STACKHEIGHT++] = $ss4200242003;
}
if(R.isPyretException($e4199841999)) {
$e4199841999.pyretStack.push(L[4628]);
}
throw $e4199841999;
}
var $ret4200442005 = $Hanf_arg895242009($z4200042001,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,_plus55);
++R.GAS;
return $ret4200442005;
};
var $Hanf_arg895242009 = function(anf_arg180042008,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,_plus55) {
var $z4201242013 = D;
var $f4201842019 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg180042008,break_DASH_one119168):R.ffi.throwNonFunApp(L[4628],_plus55,[anf_arg180042008,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4201242013 = $f4201842019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4201842019,
"from":L[4628]});
}
} catch($e4201042011) {
if(R.isCont($e4201042011)) {
var $ss4201442015 = {"from":L[4628],
"go":function(anf_arg180142020) {
return $Hanf_arg895142021(anf_arg180142020,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,_plus55);
}};
$e4201042011.stack[R.EXN_STACKHEIGHT++] = $ss4201442015;
}
if(R.isPyretException($e4201042011)) {
$e4201042011.pyretStack.push(L[4628]);
}
throw $e4201042011;
}
var $ret4201642017 = $Hanf_arg895142021($z4201242013,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,_plus55);
++R.GAS;
return $ret4201642017;
};
var $Hanf_arg895142021 = function(anf_arg180142020,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,str_DASH_as123221,_plus55) {
var $z4202442025 = D;
var $f4203042031 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg180142020,str_DASH_as123221):R.ffi.throwNonFunApp(L[4628],_plus55,[anf_arg180142020,str_DASH_as123221]);
};
try {
if(--R.GAS > 0) {
$z4202442025 = $f4203042031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4203042031,
"from":L[4628]});
}
} catch($e4202242023) {
if(R.isCont($e4202242023)) {
var $ss4202642027 = {"from":L[4628],
"go":function(anf_arg180242032) {
return $Hanf_arg895042033(anf_arg180242032,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,_plus55);
}};
$e4202242023.stack[R.EXN_STACKHEIGHT++] = $ss4202642027;
}
if(R.isPyretException($e4202242023)) {
$e4202242023.pyretStack.push(L[4628]);
}
throw $e4202242023;
}
var $ret4202842029 = $Hanf_arg895042033($z4202442025,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,_plus55);
++R.GAS;
return $ret4202842029;
};
var $Hanf_arg895042033 = function(anf_arg180242032,INDENT118169,anf_fun179516027,anf_fun179616028,break_DASH_one119168,self71216029,_plus55) {
var $z4203642037 = D;
var $f4204242043 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg180242032,break_DASH_one119168):R.ffi.throwNonFunApp(L[4628],_plus55,[anf_arg180242032,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4203642037 = $f4204242043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4204242043,
"from":L[4628]});
}
} catch($e4203442035) {
if(R.isCont($e4203442035)) {
var $ss4203842039 = {"from":L[4628],
"go":function(anf_arg180342044) {
return $Hanf_arg894942045(anf_arg180342044,INDENT118169,anf_fun179516027,anf_fun179616028,self71216029,_plus55);
}};
$e4203442035.stack[R.EXN_STACKHEIGHT++] = $ss4203842039;
}
if(R.isPyretException($e4203442035)) {
$e4203442035.pyretStack.push(L[4628]);
}
throw $e4203442035;
}
var $ret4204042041 = $Hanf_arg894942045($z4203642037,INDENT118169,anf_fun179516027,anf_fun179616028,self71216029,_plus55);
++R.GAS;
return $ret4204042041;
};
var $Hanf_arg894942045 = function(anf_arg180342044,INDENT118169,anf_fun179516027,anf_fun179616028,self71216029,_plus55) {
var anf_bracket180442059 = G(self71216029,"namet",L[4631]);
var anf_fun180542056 = G(anf_bracket180442059,"tosource",L[4630]);
var $z4204842049 = D;
var $f4205442055 = function(_) {
return R.isFunction(anf_fun180542056)?anf_fun180542056.app():R.ffi.throwNonFunApp(L[4629],anf_fun180542056,[]);
};
try {
if(--R.GAS > 0) {
$z4204842049 = $f4205442055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4205442055,
"from":L[4629]});
}
} catch($e4204642047) {
if(R.isCont($e4204642047)) {
var $ss4205042051 = {"from":L[4629],
"go":function(anf_arg180642057) {
return $Hanf_arg894842058(anf_arg180642057,INDENT118169,anf_arg180342044,anf_fun179516027,anf_fun179616028,_plus55);
}};
$e4204642047.stack[R.EXN_STACKHEIGHT++] = $ss4205042051;
}
if(R.isPyretException($e4204642047)) {
$e4204642047.pyretStack.push(L[4629]);
}
throw $e4204642047;
}
var $ret4205242053 = $Hanf_arg894842058($z4204842049,INDENT118169,anf_arg180342044,anf_fun179516027,anf_fun179616028,_plus55);
++R.GAS;
return $ret4205242053;
};
var $Hanf_arg894842058 = function(anf_arg180642057,INDENT118169,anf_arg180342044,anf_fun179516027,anf_fun179616028,_plus55) {
var $z4206242063 = D;
var $f4206842069 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg180342044,anf_arg180642057):R.ffi.throwNonFunApp(L[4628],_plus55,[anf_arg180342044,anf_arg180642057]);
};
try {
if(--R.GAS > 0) {
$z4206242063 = $f4206842069();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4206842069,
"from":L[4628]});
}
} catch($e4206042061) {
if(R.isCont($e4206042061)) {
var $ss4206442065 = {"from":L[4628],
"go":function(anf_arg180742070) {
return $Hanf_arg894742071(anf_arg180742070,INDENT118169,anf_fun179516027,anf_fun179616028);
}};
$e4206042061.stack[R.EXN_STACKHEIGHT++] = $ss4206442065;
}
if(R.isPyretException($e4206042061)) {
$e4206042061.pyretStack.push(L[4628]);
}
throw $e4206042061;
}
var $ret4206642067 = $Hanf_arg894742071($z4206242063,INDENT118169,anf_fun179516027,anf_fun179616028);
++R.GAS;
return $ret4206642067;
};
var $Hanf_arg894742071 = function(anf_arg180742070,INDENT118169,anf_fun179516027,anf_fun179616028) {
var $z4207442075 = D;
var $f4208042081 = function(_) {
return R.isFunction(anf_fun179616028)?anf_fun179616028.app(INDENT118169,anf_arg180742070):R.ffi.throwNonFunApp(L[4632],anf_fun179616028,[INDENT118169,anf_arg180742070]);
};
try {
if(--R.GAS > 0) {
$z4207442075 = $f4208042081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4208042081,
"from":L[4632]});
}
} catch($e4207242073) {
if(R.isCont($e4207242073)) {
var $ss4207642077 = {"from":L[4632],
"go":function(anf_arg180842082) {
return $Hanf_arg894642083(anf_arg180842082,anf_fun179516027);
}};
$e4207242073.stack[R.EXN_STACKHEIGHT++] = $ss4207642077;
}
if(R.isPyretException($e4207242073)) {
$e4207242073.pyretStack.push(L[4632]);
}
throw $e4207242073;
}
var $ret4207842079 = $Hanf_arg894642083($z4207442075,anf_fun179516027);
++R.GAS;
return $ret4207842079;
};
var $Hanf_arg894642083 = function(anf_arg180842082,anf_fun179516027) {
var $z4208642087 = D;
var $f4209242093 = function(_) {
return R.isFunction(anf_fun179516027)?anf_fun179516027.app(anf_arg180842082):R.ffi.throwNonFunApp(L[2927],anf_fun179516027,[anf_arg180842082]);
};
try {
if(--R.GAS > 0) {
$z4208642087 = $f4209242093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4209242093,
"from":L[2927]});
}
} catch($e4208442085) {
if(R.isCont($e4208442085)) {
var $ss4208842089 = {"from":L[2927],
"go":function(ann_DASH_check_DASH_temp179442094) {
return $Hann_DASH_check_DASH_temp894542095(ann_DASH_check_DASH_temp179442094);
}};
$e4208442085.stack[R.EXN_STACKHEIGHT++] = $ss4208842089;
}
if(R.isPyretException($e4208442085)) {
$e4208442085.pyretStack.push(L[2927]);
}
throw $e4208442085;
}
var $ret4209042091 = $Hann_DASH_check_DASH_temp894542095($z4208642087);
++R.GAS;
return $ret4209042091;
};
var $Hann_DASH_check_DASH_temp894542095 = function(ann_DASH_check_DASH_temp179442094) {
return ann_DASH_check_DASH_temp179442094;
};
var $Hanf_arg894416046 = function(anf_arg178016045,self2251281,_plus55,torepr65) {
var anf_arg178142106 = G(self2251281,"name",L[2260]);
var $z4209842099 = D;
var $f4210442105 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg178142106):R.ffi.throwNonFunApp(L[2260],torepr65,[anf_arg178142106]);
};
try {
if(--R.GAS > 0) {
$z4209842099 = $f4210442105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4210442105,
"from":L[2260]});
}
} catch($e4209642097) {
if(R.isCont($e4209642097)) {
var $ss4210042101 = {"from":L[2260],
"go":function(anf_arg178242107) {
return $Hanf_arg894342108(anf_arg178242107,anf_arg178016045,self2251281,_plus55,torepr65);
}};
$e4209642097.stack[R.EXN_STACKHEIGHT++] = $ss4210042101;
}
if(R.isPyretException($e4209642097)) {
$e4209642097.pyretStack.push(L[2260]);
}
throw $e4209642097;
}
var $ret4210242103 = $Hanf_arg894342108($z4209842099,anf_arg178016045,self2251281,_plus55,torepr65);
++R.GAS;
return $ret4210242103;
};
var $Hanf_arg894342108 = function(anf_arg178242107,anf_arg178016045,self2251281,_plus55,torepr65) {
var $z4211142112 = D;
var $f4211742118 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg178242107):R.ffi.throwNonFunApp(L[2260],_plus55,[(", "),anf_arg178242107]);
};
try {
if(--R.GAS > 0) {
$z4211142112 = $f4211742118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4211742118,
"from":L[2260]});
}
} catch($e4210942110) {
if(R.isCont($e4210942110)) {
var $ss4211342114 = {"from":L[2260],
"go":function(anf_arg178342119) {
return $Hanf_arg894242120(anf_arg178342119,anf_arg178016045,self2251281,_plus55,torepr65);
}};
$e4210942110.stack[R.EXN_STACKHEIGHT++] = $ss4211342114;
}
if(R.isPyretException($e4210942110)) {
$e4210942110.pyretStack.push(L[2260]);
}
throw $e4210942110;
}
var $ret4211542116 = $Hanf_arg894242120($z4211142112,anf_arg178016045,self2251281,_plus55,torepr65);
++R.GAS;
return $ret4211542116;
};
var $Hanf_arg894242120 = function(anf_arg178342119,anf_arg178016045,self2251281,_plus55,torepr65) {
var $z4212342124 = D;
var $f4212942130 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg178016045,anf_arg178342119):R.ffi.throwNonFunApp(L[2260],_plus55,[anf_arg178016045,anf_arg178342119]);
};
try {
if(--R.GAS > 0) {
$z4212342124 = $f4212942130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4212942130,
"from":L[2260]});
}
} catch($e4212142122) {
if(R.isCont($e4212142122)) {
var $ss4212542126 = {"from":L[2260],
"go":function(anf_arg178442131) {
return $Hanf_arg894142132(anf_arg178442131,self2251281,_plus55,torepr65);
}};
$e4212142122.stack[R.EXN_STACKHEIGHT++] = $ss4212542126;
}
if(R.isPyretException($e4212142122)) {
$e4212142122.pyretStack.push(L[2260]);
}
throw $e4212142122;
}
var $ret4212742128 = $Hanf_arg894142132($z4212342124,self2251281,_plus55,torepr65);
++R.GAS;
return $ret4212742128;
};
var $Hanf_arg894142132 = function(anf_arg178442131,self2251281,_plus55,torepr65) {
var anf_arg178542143 = G(self2251281,"namet",L[2260]);
var $z4213542136 = D;
var $f4214142142 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg178542143):R.ffi.throwNonFunApp(L[2260],torepr65,[anf_arg178542143]);
};
try {
if(--R.GAS > 0) {
$z4213542136 = $f4214142142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4214142142,
"from":L[2260]});
}
} catch($e4213342134) {
if(R.isCont($e4213342134)) {
var $ss4213742138 = {"from":L[2260],
"go":function(anf_arg178642144) {
return $Hanf_arg894042145(anf_arg178642144,anf_arg178442131,_plus55);
}};
$e4213342134.stack[R.EXN_STACKHEIGHT++] = $ss4213742138;
}
if(R.isPyretException($e4213342134)) {
$e4213342134.pyretStack.push(L[2260]);
}
throw $e4213342134;
}
var $ret4213942140 = $Hanf_arg894042145($z4213542136,anf_arg178442131,_plus55);
++R.GAS;
return $ret4213942140;
};
var $Hanf_arg894042145 = function(anf_arg178642144,anf_arg178442131,_plus55) {
var $z4214842149 = D;
var $f4215442155 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg178642144):R.ffi.throwNonFunApp(L[2260],_plus55,[(", "),anf_arg178642144]);
};
try {
if(--R.GAS > 0) {
$z4214842149 = $f4215442155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4215442155,
"from":L[2260]});
}
} catch($e4214642147) {
if(R.isCont($e4214642147)) {
var $ss4215042151 = {"from":L[2260],
"go":function(anf_arg178742156) {
return $Hanf_arg893942157(anf_arg178742156,anf_arg178442131,_plus55);
}};
$e4214642147.stack[R.EXN_STACKHEIGHT++] = $ss4215042151;
}
if(R.isPyretException($e4214642147)) {
$e4214642147.pyretStack.push(L[2260]);
}
throw $e4214642147;
}
var $ret4215242153 = $Hanf_arg893942157($z4214842149,anf_arg178442131,_plus55);
++R.GAS;
return $ret4215242153;
};
var $Hanf_arg893942157 = function(anf_arg178742156,anf_arg178442131,_plus55) {
var $z4216042161 = D;
var $f4216642167 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg178442131,anf_arg178742156):R.ffi.throwNonFunApp(L[2260],_plus55,[anf_arg178442131,anf_arg178742156]);
};
try {
if(--R.GAS > 0) {
$z4216042161 = $f4216642167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4216642167,
"from":L[2260]});
}
} catch($e4215842159) {
if(R.isCont($e4215842159)) {
var $ss4216242163 = {"from":L[2260],
"go":function(anf_arg178842168) {
return $Hanf_arg893842169(anf_arg178842168,_plus55);
}};
$e4215842159.stack[R.EXN_STACKHEIGHT++] = $ss4216242163;
}
if(R.isPyretException($e4215842159)) {
$e4215842159.pyretStack.push(L[2260]);
}
throw $e4215842159;
}
var $ret4216442165 = $Hanf_arg893842169($z4216042161,_plus55);
++R.GAS;
return $ret4216442165;
};
var $Hanf_arg893842169 = function(anf_arg178842168,_plus55) {
var $z4217242173 = D;
var $f4217842179 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg178842168,(")")):R.ffi.throwNonFunApp(L[2260],_plus55,[anf_arg178842168,(")")]);
};
try {
if(--R.GAS > 0) {
$z4217242173 = $f4217842179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4217842179,
"from":L[2260]});
}
} catch($e4217042171) {
if(R.isCont($e4217042171)) {
var $ss4217442175 = {"from":L[2260],
"go":function(anf_arg178942180) {
return $Hanf_arg893742181(anf_arg178942180,_plus55);
}};
$e4217042171.stack[R.EXN_STACKHEIGHT++] = $ss4217442175;
}
if(R.isPyretException($e4217042171)) {
$e4217042171.pyretStack.push(L[2260]);
}
throw $e4217042171;
}
var $ret4217642177 = $Hanf_arg893742181($z4217242173,_plus55);
++R.GAS;
return $ret4217642177;
};
var $Hanf_arg893742181 = function(anf_arg178942180,_plus55) {
var $z4218442185 = D;
var $f4219042191 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg178942180):R.ffi.throwNonFunApp(L[2260],_plus55,[("("),anf_arg178942180]);
};
try {
if(--R.GAS > 0) {
$z4218442185 = $f4219042191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4219042191,
"from":L[2260]});
}
} catch($e4218242183) {
if(R.isCont($e4218242183)) {
var $ss4218642187 = {"from":L[2260],
"go":function(anf_arg179042192) {
return $Hanf_arg893642193(anf_arg179042192,_plus55);
}};
$e4218242183.stack[R.EXN_STACKHEIGHT++] = $ss4218642187;
}
if(R.isPyretException($e4218242183)) {
$e4218242183.pyretStack.push(L[2260]);
}
throw $e4218242183;
}
var $ret4218842189 = $Hanf_arg893642193($z4218442185,_plus55);
++R.GAS;
return $ret4218842189;
};
var $Hanf_arg893642193 = function(anf_arg179042192,_plus55) {
var $z4219642197 = D;
var $f4220242203 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-newtype"),anf_arg179042192):R.ffi.throwNonFunApp(L[2260],_plus55,[("s-newtype"),anf_arg179042192]);
};
try {
if(--R.GAS > 0) {
$z4219642197 = $f4220242203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4220242203,
"from":L[2260]});
}
} catch($e4219442195) {
if(R.isCont($e4219442195)) {
var $ss4219842199 = {"from":L[2260],
"go":function(ann_DASH_check_DASH_temp177842204) {
return $Hann_DASH_check_DASH_temp893542205(ann_DASH_check_DASH_temp177842204);
}};
$e4219442195.stack[R.EXN_STACKHEIGHT++] = $ss4219842199;
}
if(R.isPyretException($e4219442195)) {
$e4219442195.pyretStack.push(L[2260]);
}
throw $e4219442195;
}
var $ret4220042201 = $Hann_DASH_check_DASH_temp893542205($z4219642197);
++R.GAS;
return $ret4220042201;
};
var $Hann_DASH_check_DASH_temp893542205 = function(ann_DASH_check_DASH_temp177842204) {
return ann_DASH_check_DASH_temp177842204;
};
var $Hcont_tail_arg893316063 = function(cont_tail_arg177516061,if_helper176516062) {
if(--R.GAS > 0) {
$z4220642207 = R.isFunction(if_helper176516062)?if_helper176516062.app(cont_tail_arg177516061):R.ffi.throwNonFunApp(L[2260],if_helper176516062,[cont_tail_arg177516061]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper176516062)?if_helper176516062.app(cont_tail_arg177516061):R.ffi.throwNonFunApp(L[2260],if_helper176516062,[cont_tail_arg177516061]);
},
"from":L[2260]});
}
++R.GAS;
return $z4220642207;
};
var $Hcont_tail_arg893416077 = function(cont_tail_arg177016076,if_helper176516062) {
if(--R.GAS > 0) {
$z4220842209 = R.isFunction(if_helper176516062)?if_helper176516062.app(cont_tail_arg177016076):R.ffi.throwNonFunApp(L[2260],if_helper176516062,[cont_tail_arg177016076]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper176516062)?if_helper176516062.app(cont_tail_arg177016076):R.ffi.throwNonFunApp(L[2260],if_helper176516062,[cont_tail_arg177016076]);
},
"from":L[2260]});
}
++R.GAS;
return $z4220842209;
};
var $Hanf_arg893216100 = function(anf_arg175416096,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,str_DASH_spaceequal170832,str_DASH_type177923,_plus55) {
var $z4221242213 = D;
var $f4221842219 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_type177923,anf_arg175416096):R.ffi.throwNonFunApp(L[4633],_plus55,[str_DASH_type177923,anf_arg175416096]);
};
try {
if(--R.GAS > 0) {
$z4221242213 = $f4221842219();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4221842219,
"from":L[4633]});
}
} catch($e4221042211) {
if(R.isCont($e4221042211)) {
var $ss4221442215 = {"from":L[4633],
"go":function(anf_arg175542220) {
return $Hanf_arg893142221(anf_arg175542220,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,str_DASH_spaceequal170832,_plus55);
}};
$e4221042211.stack[R.EXN_STACKHEIGHT++] = $ss4221442215;
}
if(R.isPyretException($e4221042211)) {
$e4221042211.pyretStack.push(L[4633]);
}
throw $e4221042211;
}
var $ret4221642217 = $Hanf_arg893142221($z4221242213,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret4221642217;
};
var $Hanf_arg893142221 = function(anf_arg175542220,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,str_DASH_spaceequal170832,_plus55) {
var $z4222442225 = D;
var $f4223042231 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg175542220,str_DASH_spaceequal170832):R.ffi.throwNonFunApp(L[4633],_plus55,[anf_arg175542220,str_DASH_spaceequal170832]);
};
try {
if(--R.GAS > 0) {
$z4222442225 = $f4223042231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4223042231,
"from":L[4633]});
}
} catch($e4222242223) {
if(R.isCont($e4222242223)) {
var $ss4222642227 = {"from":L[4633],
"go":function(anf_arg175642232) {
return $Hanf_arg893042233(anf_arg175642232,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,_plus55);
}};
$e4222242223.stack[R.EXN_STACKHEIGHT++] = $ss4222642227;
}
if(R.isPyretException($e4222242223)) {
$e4222242223.pyretStack.push(L[4633]);
}
throw $e4222242223;
}
var $ret4222842229 = $Hanf_arg893042233($z4222442225,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,_plus55);
++R.GAS;
return $ret4222842229;
};
var $Hanf_arg893042233 = function(anf_arg175642232,INDENT118169,anf_fun175016097,anf_fun175116098,break_DASH_one119168,self70716099,_plus55) {
var $z4223642237 = D;
var $f4224242243 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg175642232,break_DASH_one119168):R.ffi.throwNonFunApp(L[4633],_plus55,[anf_arg175642232,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4223642237 = $f4224242243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4224242243,
"from":L[4633]});
}
} catch($e4223442235) {
if(R.isCont($e4223442235)) {
var $ss4223842239 = {"from":L[4633],
"go":function(anf_arg175742244) {
return $Hanf_arg892942245(anf_arg175742244,INDENT118169,anf_fun175016097,anf_fun175116098,self70716099,_plus55);
}};
$e4223442235.stack[R.EXN_STACKHEIGHT++] = $ss4223842239;
}
if(R.isPyretException($e4223442235)) {
$e4223442235.pyretStack.push(L[4633]);
}
throw $e4223442235;
}
var $ret4224042241 = $Hanf_arg892942245($z4223642237,INDENT118169,anf_fun175016097,anf_fun175116098,self70716099,_plus55);
++R.GAS;
return $ret4224042241;
};
var $Hanf_arg892942245 = function(anf_arg175742244,INDENT118169,anf_fun175016097,anf_fun175116098,self70716099,_plus55) {
var anf_bracket175842259 = G(self70716099,"ann",L[4636]);
var anf_fun175942256 = G(anf_bracket175842259,"tosource",L[4635]);
var $z4224842249 = D;
var $f4225442255 = function(_) {
return R.isFunction(anf_fun175942256)?anf_fun175942256.app():R.ffi.throwNonFunApp(L[4634],anf_fun175942256,[]);
};
try {
if(--R.GAS > 0) {
$z4224842249 = $f4225442255();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4225442255,
"from":L[4634]});
}
} catch($e4224642247) {
if(R.isCont($e4224642247)) {
var $ss4225042251 = {"from":L[4634],
"go":function(anf_arg176042257) {
return $Hanf_arg892842258(anf_arg176042257,INDENT118169,anf_arg175742244,anf_fun175016097,anf_fun175116098,_plus55);
}};
$e4224642247.stack[R.EXN_STACKHEIGHT++] = $ss4225042251;
}
if(R.isPyretException($e4224642247)) {
$e4224642247.pyretStack.push(L[4634]);
}
throw $e4224642247;
}
var $ret4225242253 = $Hanf_arg892842258($z4224842249,INDENT118169,anf_arg175742244,anf_fun175016097,anf_fun175116098,_plus55);
++R.GAS;
return $ret4225242253;
};
var $Hanf_arg892842258 = function(anf_arg176042257,INDENT118169,anf_arg175742244,anf_fun175016097,anf_fun175116098,_plus55) {
var $z4226242263 = D;
var $f4226842269 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg175742244,anf_arg176042257):R.ffi.throwNonFunApp(L[4633],_plus55,[anf_arg175742244,anf_arg176042257]);
};
try {
if(--R.GAS > 0) {
$z4226242263 = $f4226842269();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4226842269,
"from":L[4633]});
}
} catch($e4226042261) {
if(R.isCont($e4226042261)) {
var $ss4226442265 = {"from":L[4633],
"go":function(anf_arg176142270) {
return $Hanf_arg892742271(anf_arg176142270,INDENT118169,anf_fun175016097,anf_fun175116098);
}};
$e4226042261.stack[R.EXN_STACKHEIGHT++] = $ss4226442265;
}
if(R.isPyretException($e4226042261)) {
$e4226042261.pyretStack.push(L[4633]);
}
throw $e4226042261;
}
var $ret4226642267 = $Hanf_arg892742271($z4226242263,INDENT118169,anf_fun175016097,anf_fun175116098);
++R.GAS;
return $ret4226642267;
};
var $Hanf_arg892742271 = function(anf_arg176142270,INDENT118169,anf_fun175016097,anf_fun175116098) {
var $z4227442275 = D;
var $f4228042281 = function(_) {
return R.isFunction(anf_fun175116098)?anf_fun175116098.app(INDENT118169,anf_arg176142270):R.ffi.throwNonFunApp(L[4637],anf_fun175116098,[INDENT118169,anf_arg176142270]);
};
try {
if(--R.GAS > 0) {
$z4227442275 = $f4228042281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4228042281,
"from":L[4637]});
}
} catch($e4227242273) {
if(R.isCont($e4227242273)) {
var $ss4227642277 = {"from":L[4637],
"go":function(anf_arg176242282) {
return $Hanf_arg892642283(anf_arg176242282,anf_fun175016097);
}};
$e4227242273.stack[R.EXN_STACKHEIGHT++] = $ss4227642277;
}
if(R.isPyretException($e4227242273)) {
$e4227242273.pyretStack.push(L[4637]);
}
throw $e4227242273;
}
var $ret4227842279 = $Hanf_arg892642283($z4227442275,anf_fun175016097);
++R.GAS;
return $ret4227842279;
};
var $Hanf_arg892642283 = function(anf_arg176242282,anf_fun175016097) {
var $z4228642287 = D;
var $f4229242293 = function(_) {
return R.isFunction(anf_fun175016097)?anf_fun175016097.app(anf_arg176242282):R.ffi.throwNonFunApp(L[2937],anf_fun175016097,[anf_arg176242282]);
};
try {
if(--R.GAS > 0) {
$z4228642287 = $f4229242293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4229242293,
"from":L[2937]});
}
} catch($e4228442285) {
if(R.isCont($e4228442285)) {
var $ss4228842289 = {"from":L[2937],
"go":function(ann_DASH_check_DASH_temp174942294) {
return $Hann_DASH_check_DASH_temp892542295(ann_DASH_check_DASH_temp174942294);
}};
$e4228442285.stack[R.EXN_STACKHEIGHT++] = $ss4228842289;
}
if(R.isPyretException($e4228442285)) {
$e4228442285.pyretStack.push(L[2937]);
}
throw $e4228442285;
}
var $ret4229042291 = $Hann_DASH_check_DASH_temp892542295($z4228642287);
++R.GAS;
return $ret4229042291;
};
var $Hann_DASH_check_DASH_temp892542295 = function(ann_DASH_check_DASH_temp174942294) {
return ann_DASH_check_DASH_temp174942294;
};
var $Hanf_arg892416116 = function(anf_arg173516115,self2191404,_plus55,torepr65) {
var anf_arg173642306 = G(self2191404,"name",L[2261]);
var $z4229842299 = D;
var $f4230442305 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg173642306):R.ffi.throwNonFunApp(L[2261],torepr65,[anf_arg173642306]);
};
try {
if(--R.GAS > 0) {
$z4229842299 = $f4230442305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4230442305,
"from":L[2261]});
}
} catch($e4229642297) {
if(R.isCont($e4229642297)) {
var $ss4230042301 = {"from":L[2261],
"go":function(anf_arg173742307) {
return $Hanf_arg892342308(anf_arg173742307,anf_arg173516115,self2191404,_plus55,torepr65);
}};
$e4229642297.stack[R.EXN_STACKHEIGHT++] = $ss4230042301;
}
if(R.isPyretException($e4229642297)) {
$e4229642297.pyretStack.push(L[2261]);
}
throw $e4229642297;
}
var $ret4230242303 = $Hanf_arg892342308($z4229842299,anf_arg173516115,self2191404,_plus55,torepr65);
++R.GAS;
return $ret4230242303;
};
var $Hanf_arg892342308 = function(anf_arg173742307,anf_arg173516115,self2191404,_plus55,torepr65) {
var $z4231142312 = D;
var $f4231742318 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg173742307):R.ffi.throwNonFunApp(L[2261],_plus55,[(", "),anf_arg173742307]);
};
try {
if(--R.GAS > 0) {
$z4231142312 = $f4231742318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4231742318,
"from":L[2261]});
}
} catch($e4230942310) {
if(R.isCont($e4230942310)) {
var $ss4231342314 = {"from":L[2261],
"go":function(anf_arg173842319) {
return $Hanf_arg892242320(anf_arg173842319,anf_arg173516115,self2191404,_plus55,torepr65);
}};
$e4230942310.stack[R.EXN_STACKHEIGHT++] = $ss4231342314;
}
if(R.isPyretException($e4230942310)) {
$e4230942310.pyretStack.push(L[2261]);
}
throw $e4230942310;
}
var $ret4231542316 = $Hanf_arg892242320($z4231142312,anf_arg173516115,self2191404,_plus55,torepr65);
++R.GAS;
return $ret4231542316;
};
var $Hanf_arg892242320 = function(anf_arg173842319,anf_arg173516115,self2191404,_plus55,torepr65) {
var $z4232342324 = D;
var $f4232942330 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg173516115,anf_arg173842319):R.ffi.throwNonFunApp(L[2261],_plus55,[anf_arg173516115,anf_arg173842319]);
};
try {
if(--R.GAS > 0) {
$z4232342324 = $f4232942330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4232942330,
"from":L[2261]});
}
} catch($e4232142322) {
if(R.isCont($e4232142322)) {
var $ss4232542326 = {"from":L[2261],
"go":function(anf_arg173942331) {
return $Hanf_arg892142332(anf_arg173942331,self2191404,_plus55,torepr65);
}};
$e4232142322.stack[R.EXN_STACKHEIGHT++] = $ss4232542326;
}
if(R.isPyretException($e4232142322)) {
$e4232142322.pyretStack.push(L[2261]);
}
throw $e4232142322;
}
var $ret4232742328 = $Hanf_arg892142332($z4232342324,self2191404,_plus55,torepr65);
++R.GAS;
return $ret4232742328;
};
var $Hanf_arg892142332 = function(anf_arg173942331,self2191404,_plus55,torepr65) {
var anf_arg174042343 = G(self2191404,"ann",L[2261]);
var $z4233542336 = D;
var $f4234142342 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg174042343):R.ffi.throwNonFunApp(L[2261],torepr65,[anf_arg174042343]);
};
try {
if(--R.GAS > 0) {
$z4233542336 = $f4234142342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4234142342,
"from":L[2261]});
}
} catch($e4233342334) {
if(R.isCont($e4233342334)) {
var $ss4233742338 = {"from":L[2261],
"go":function(anf_arg174142344) {
return $Hanf_arg892042345(anf_arg174142344,anf_arg173942331,_plus55);
}};
$e4233342334.stack[R.EXN_STACKHEIGHT++] = $ss4233742338;
}
if(R.isPyretException($e4233342334)) {
$e4233342334.pyretStack.push(L[2261]);
}
throw $e4233342334;
}
var $ret4233942340 = $Hanf_arg892042345($z4233542336,anf_arg173942331,_plus55);
++R.GAS;
return $ret4233942340;
};
var $Hanf_arg892042345 = function(anf_arg174142344,anf_arg173942331,_plus55) {
var $z4234842349 = D;
var $f4235442355 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg174142344):R.ffi.throwNonFunApp(L[2261],_plus55,[(", "),anf_arg174142344]);
};
try {
if(--R.GAS > 0) {
$z4234842349 = $f4235442355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4235442355,
"from":L[2261]});
}
} catch($e4234642347) {
if(R.isCont($e4234642347)) {
var $ss4235042351 = {"from":L[2261],
"go":function(anf_arg174242356) {
return $Hanf_arg891942357(anf_arg174242356,anf_arg173942331,_plus55);
}};
$e4234642347.stack[R.EXN_STACKHEIGHT++] = $ss4235042351;
}
if(R.isPyretException($e4234642347)) {
$e4234642347.pyretStack.push(L[2261]);
}
throw $e4234642347;
}
var $ret4235242353 = $Hanf_arg891942357($z4234842349,anf_arg173942331,_plus55);
++R.GAS;
return $ret4235242353;
};
var $Hanf_arg891942357 = function(anf_arg174242356,anf_arg173942331,_plus55) {
var $z4236042361 = D;
var $f4236642367 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg173942331,anf_arg174242356):R.ffi.throwNonFunApp(L[2261],_plus55,[anf_arg173942331,anf_arg174242356]);
};
try {
if(--R.GAS > 0) {
$z4236042361 = $f4236642367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4236642367,
"from":L[2261]});
}
} catch($e4235842359) {
if(R.isCont($e4235842359)) {
var $ss4236242363 = {"from":L[2261],
"go":function(anf_arg174342368) {
return $Hanf_arg891842369(anf_arg174342368,_plus55);
}};
$e4235842359.stack[R.EXN_STACKHEIGHT++] = $ss4236242363;
}
if(R.isPyretException($e4235842359)) {
$e4235842359.pyretStack.push(L[2261]);
}
throw $e4235842359;
}
var $ret4236442365 = $Hanf_arg891842369($z4236042361,_plus55);
++R.GAS;
return $ret4236442365;
};
var $Hanf_arg891842369 = function(anf_arg174342368,_plus55) {
var $z4237242373 = D;
var $f4237842379 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg174342368,(")")):R.ffi.throwNonFunApp(L[2261],_plus55,[anf_arg174342368,(")")]);
};
try {
if(--R.GAS > 0) {
$z4237242373 = $f4237842379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4237842379,
"from":L[2261]});
}
} catch($e4237042371) {
if(R.isCont($e4237042371)) {
var $ss4237442375 = {"from":L[2261],
"go":function(anf_arg174442380) {
return $Hanf_arg891742381(anf_arg174442380,_plus55);
}};
$e4237042371.stack[R.EXN_STACKHEIGHT++] = $ss4237442375;
}
if(R.isPyretException($e4237042371)) {
$e4237042371.pyretStack.push(L[2261]);
}
throw $e4237042371;
}
var $ret4237642377 = $Hanf_arg891742381($z4237242373,_plus55);
++R.GAS;
return $ret4237642377;
};
var $Hanf_arg891742381 = function(anf_arg174442380,_plus55) {
var $z4238442385 = D;
var $f4239042391 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg174442380):R.ffi.throwNonFunApp(L[2261],_plus55,[("("),anf_arg174442380]);
};
try {
if(--R.GAS > 0) {
$z4238442385 = $f4239042391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4239042391,
"from":L[2261]});
}
} catch($e4238242383) {
if(R.isCont($e4238242383)) {
var $ss4238642387 = {"from":L[2261],
"go":function(anf_arg174542392) {
return $Hanf_arg891642393(anf_arg174542392,_plus55);
}};
$e4238242383.stack[R.EXN_STACKHEIGHT++] = $ss4238642387;
}
if(R.isPyretException($e4238242383)) {
$e4238242383.pyretStack.push(L[2261]);
}
throw $e4238242383;
}
var $ret4238842389 = $Hanf_arg891642393($z4238442385,_plus55);
++R.GAS;
return $ret4238842389;
};
var $Hanf_arg891642393 = function(anf_arg174542392,_plus55) {
var $z4239642397 = D;
var $f4240242403 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-type"),anf_arg174542392):R.ffi.throwNonFunApp(L[2261],_plus55,[("s-type"),anf_arg174542392]);
};
try {
if(--R.GAS > 0) {
$z4239642397 = $f4240242403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4240242403,
"from":L[2261]});
}
} catch($e4239442395) {
if(R.isCont($e4239442395)) {
var $ss4239842399 = {"from":L[2261],
"go":function(ann_DASH_check_DASH_temp173342404) {
return $Hann_DASH_check_DASH_temp891542405(ann_DASH_check_DASH_temp173342404);
}};
$e4239442395.stack[R.EXN_STACKHEIGHT++] = $ss4239842399;
}
if(R.isPyretException($e4239442395)) {
$e4239442395.pyretStack.push(L[2261]);
}
throw $e4239442395;
}
var $ret4240042401 = $Hann_DASH_check_DASH_temp891542405($z4239642397);
++R.GAS;
return $ret4240042401;
};
var $Hann_DASH_check_DASH_temp891542405 = function(ann_DASH_check_DASH_temp173342404) {
return ann_DASH_check_DASH_temp173342404;
};
var $Hcont_tail_arg891316133 = function(cont_tail_arg173016131,if_helper172016132) {
if(--R.GAS > 0) {
$z4240642407 = R.isFunction(if_helper172016132)?if_helper172016132.app(cont_tail_arg173016131):R.ffi.throwNonFunApp(L[2261],if_helper172016132,[cont_tail_arg173016131]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper172016132)?if_helper172016132.app(cont_tail_arg173016131):R.ffi.throwNonFunApp(L[2261],if_helper172016132,[cont_tail_arg173016131]);
},
"from":L[2261]});
}
++R.GAS;
return $z4240642407;
};
var $Hcont_tail_arg891416147 = function(cont_tail_arg172516146,if_helper172016132) {
if(--R.GAS > 0) {
$z4240842409 = R.isFunction(if_helper172016132)?if_helper172016132.app(cont_tail_arg172516146):R.ffi.throwNonFunApp(L[2261],if_helper172016132,[cont_tail_arg172516146]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper172016132)?if_helper172016132.app(cont_tail_arg172516146):R.ffi.throwNonFunApp(L[2261],if_helper172016132,[cont_tail_arg172516146]);
},
"from":L[2261]});
}
++R.GAS;
return $z4240842409;
};
var $Hann_DASH_check_DASH_temp891216173 = function(ann_DASH_check_DASH_temp171016172) {
return ann_DASH_check_DASH_temp171016172;
};
var $Hanf_arg891116189 = function(anf_arg167616187,self21316188,_plus55,torepr65) {
var anf_arg167742420 = G(self21316188,"name",L[2262]);
var $z4241242413 = D;
var $f4241842419 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg167742420):R.ffi.throwNonFunApp(L[2262],torepr65,[anf_arg167742420]);
};
try {
if(--R.GAS > 0) {
$z4241242413 = $f4241842419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4241842419,
"from":L[2262]});
}
} catch($e4241042411) {
if(R.isCont($e4241042411)) {
var $ss4241442415 = {"from":L[2262],
"go":function(anf_arg167842421) {
return $Hanf_arg891042422(anf_arg167842421,anf_arg167616187,self21316188,_plus55,torepr65);
}};
$e4241042411.stack[R.EXN_STACKHEIGHT++] = $ss4241442415;
}
if(R.isPyretException($e4241042411)) {
$e4241042411.pyretStack.push(L[2262]);
}
throw $e4241042411;
}
var $ret4241642417 = $Hanf_arg891042422($z4241242413,anf_arg167616187,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4241642417;
};
var $Hanf_arg891042422 = function(anf_arg167842421,anf_arg167616187,self21316188,_plus55,torepr65) {
var $z4242542426 = D;
var $f4243142432 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg167842421):R.ffi.throwNonFunApp(L[2262],_plus55,[(", "),anf_arg167842421]);
};
try {
if(--R.GAS > 0) {
$z4242542426 = $f4243142432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4243142432,
"from":L[2262]});
}
} catch($e4242342424) {
if(R.isCont($e4242342424)) {
var $ss4242742428 = {"from":L[2262],
"go":function(anf_arg167942433) {
return $Hanf_arg890942434(anf_arg167942433,anf_arg167616187,self21316188,_plus55,torepr65);
}};
$e4242342424.stack[R.EXN_STACKHEIGHT++] = $ss4242742428;
}
if(R.isPyretException($e4242342424)) {
$e4242342424.pyretStack.push(L[2262]);
}
throw $e4242342424;
}
var $ret4242942430 = $Hanf_arg890942434($z4242542426,anf_arg167616187,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4242942430;
};
var $Hanf_arg890942434 = function(anf_arg167942433,anf_arg167616187,self21316188,_plus55,torepr65) {
var $z4243742438 = D;
var $f4244342444 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg167616187,anf_arg167942433):R.ffi.throwNonFunApp(L[2262],_plus55,[anf_arg167616187,anf_arg167942433]);
};
try {
if(--R.GAS > 0) {
$z4243742438 = $f4244342444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4244342444,
"from":L[2262]});
}
} catch($e4243542436) {
if(R.isCont($e4243542436)) {
var $ss4243942440 = {"from":L[2262],
"go":function(anf_arg168042445) {
return $Hanf_arg890842446(anf_arg168042445,self21316188,_plus55,torepr65);
}};
$e4243542436.stack[R.EXN_STACKHEIGHT++] = $ss4243942440;
}
if(R.isPyretException($e4243542436)) {
$e4243542436.pyretStack.push(L[2262]);
}
throw $e4243542436;
}
var $ret4244142442 = $Hanf_arg890842446($z4243742438,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4244142442;
};
var $Hanf_arg890842446 = function(anf_arg168042445,self21316188,_plus55,torepr65) {
var anf_arg168142457 = G(self21316188,"params",L[2262]);
var $z4244942450 = D;
var $f4245542456 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg168142457):R.ffi.throwNonFunApp(L[2262],torepr65,[anf_arg168142457]);
};
try {
if(--R.GAS > 0) {
$z4244942450 = $f4245542456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4245542456,
"from":L[2262]});
}
} catch($e4244742448) {
if(R.isCont($e4244742448)) {
var $ss4245142452 = {"from":L[2262],
"go":function(anf_arg168242458) {
return $Hanf_arg890742459(anf_arg168242458,anf_arg168042445,self21316188,_plus55,torepr65);
}};
$e4244742448.stack[R.EXN_STACKHEIGHT++] = $ss4245142452;
}
if(R.isPyretException($e4244742448)) {
$e4244742448.pyretStack.push(L[2262]);
}
throw $e4244742448;
}
var $ret4245342454 = $Hanf_arg890742459($z4244942450,anf_arg168042445,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4245342454;
};
var $Hanf_arg890742459 = function(anf_arg168242458,anf_arg168042445,self21316188,_plus55,torepr65) {
var $z4246242463 = D;
var $f4246842469 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg168242458):R.ffi.throwNonFunApp(L[2262],_plus55,[(", "),anf_arg168242458]);
};
try {
if(--R.GAS > 0) {
$z4246242463 = $f4246842469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4246842469,
"from":L[2262]});
}
} catch($e4246042461) {
if(R.isCont($e4246042461)) {
var $ss4246442465 = {"from":L[2262],
"go":function(anf_arg168342470) {
return $Hanf_arg890642471(anf_arg168342470,anf_arg168042445,self21316188,_plus55,torepr65);
}};
$e4246042461.stack[R.EXN_STACKHEIGHT++] = $ss4246442465;
}
if(R.isPyretException($e4246042461)) {
$e4246042461.pyretStack.push(L[2262]);
}
throw $e4246042461;
}
var $ret4246642467 = $Hanf_arg890642471($z4246242463,anf_arg168042445,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4246642467;
};
var $Hanf_arg890642471 = function(anf_arg168342470,anf_arg168042445,self21316188,_plus55,torepr65) {
var $z4247442475 = D;
var $f4248042481 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg168042445,anf_arg168342470):R.ffi.throwNonFunApp(L[2262],_plus55,[anf_arg168042445,anf_arg168342470]);
};
try {
if(--R.GAS > 0) {
$z4247442475 = $f4248042481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4248042481,
"from":L[2262]});
}
} catch($e4247242473) {
if(R.isCont($e4247242473)) {
var $ss4247642477 = {"from":L[2262],
"go":function(anf_arg168442482) {
return $Hanf_arg890542483(anf_arg168442482,self21316188,_plus55,torepr65);
}};
$e4247242473.stack[R.EXN_STACKHEIGHT++] = $ss4247642477;
}
if(R.isPyretException($e4247242473)) {
$e4247242473.pyretStack.push(L[2262]);
}
throw $e4247242473;
}
var $ret4247842479 = $Hanf_arg890542483($z4247442475,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4247842479;
};
var $Hanf_arg890542483 = function(anf_arg168442482,self21316188,_plus55,torepr65) {
var anf_arg168542494 = G(self21316188,"args",L[2262]);
var $z4248642487 = D;
var $f4249242493 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg168542494):R.ffi.throwNonFunApp(L[2262],torepr65,[anf_arg168542494]);
};
try {
if(--R.GAS > 0) {
$z4248642487 = $f4249242493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4249242493,
"from":L[2262]});
}
} catch($e4248442485) {
if(R.isCont($e4248442485)) {
var $ss4248842489 = {"from":L[2262],
"go":function(anf_arg168642495) {
return $Hanf_arg890442496(anf_arg168642495,anf_arg168442482,self21316188,_plus55,torepr65);
}};
$e4248442485.stack[R.EXN_STACKHEIGHT++] = $ss4248842489;
}
if(R.isPyretException($e4248442485)) {
$e4248442485.pyretStack.push(L[2262]);
}
throw $e4248442485;
}
var $ret4249042491 = $Hanf_arg890442496($z4248642487,anf_arg168442482,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4249042491;
};
var $Hanf_arg890442496 = function(anf_arg168642495,anf_arg168442482,self21316188,_plus55,torepr65) {
var $z4249942500 = D;
var $f4250542506 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg168642495):R.ffi.throwNonFunApp(L[2262],_plus55,[(", "),anf_arg168642495]);
};
try {
if(--R.GAS > 0) {
$z4249942500 = $f4250542506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4250542506,
"from":L[2262]});
}
} catch($e4249742498) {
if(R.isCont($e4249742498)) {
var $ss4250142502 = {"from":L[2262],
"go":function(anf_arg168742507) {
return $Hanf_arg890342508(anf_arg168742507,anf_arg168442482,self21316188,_plus55,torepr65);
}};
$e4249742498.stack[R.EXN_STACKHEIGHT++] = $ss4250142502;
}
if(R.isPyretException($e4249742498)) {
$e4249742498.pyretStack.push(L[2262]);
}
throw $e4249742498;
}
var $ret4250342504 = $Hanf_arg890342508($z4249942500,anf_arg168442482,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4250342504;
};
var $Hanf_arg890342508 = function(anf_arg168742507,anf_arg168442482,self21316188,_plus55,torepr65) {
var $z4251142512 = D;
var $f4251742518 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg168442482,anf_arg168742507):R.ffi.throwNonFunApp(L[2262],_plus55,[anf_arg168442482,anf_arg168742507]);
};
try {
if(--R.GAS > 0) {
$z4251142512 = $f4251742518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4251742518,
"from":L[2262]});
}
} catch($e4250942510) {
if(R.isCont($e4250942510)) {
var $ss4251342514 = {"from":L[2262],
"go":function(anf_arg168842519) {
return $Hanf_arg890242520(anf_arg168842519,self21316188,_plus55,torepr65);
}};
$e4250942510.stack[R.EXN_STACKHEIGHT++] = $ss4251342514;
}
if(R.isPyretException($e4250942510)) {
$e4250942510.pyretStack.push(L[2262]);
}
throw $e4250942510;
}
var $ret4251542516 = $Hanf_arg890242520($z4251142512,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4251542516;
};
var $Hanf_arg890242520 = function(anf_arg168842519,self21316188,_plus55,torepr65) {
var anf_arg168942531 = G(self21316188,"ann",L[2262]);
var $z4252342524 = D;
var $f4252942530 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg168942531):R.ffi.throwNonFunApp(L[2262],torepr65,[anf_arg168942531]);
};
try {
if(--R.GAS > 0) {
$z4252342524 = $f4252942530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4252942530,
"from":L[2262]});
}
} catch($e4252142522) {
if(R.isCont($e4252142522)) {
var $ss4252542526 = {"from":L[2262],
"go":function(anf_arg169042532) {
return $Hanf_arg890142533(anf_arg169042532,anf_arg168842519,self21316188,_plus55,torepr65);
}};
$e4252142522.stack[R.EXN_STACKHEIGHT++] = $ss4252542526;
}
if(R.isPyretException($e4252142522)) {
$e4252142522.pyretStack.push(L[2262]);
}
throw $e4252142522;
}
var $ret4252742528 = $Hanf_arg890142533($z4252342524,anf_arg168842519,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4252742528;
};
var $Hanf_arg890142533 = function(anf_arg169042532,anf_arg168842519,self21316188,_plus55,torepr65) {
var $z4253642537 = D;
var $f4254242543 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg169042532):R.ffi.throwNonFunApp(L[2262],_plus55,[(", "),anf_arg169042532]);
};
try {
if(--R.GAS > 0) {
$z4253642537 = $f4254242543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4254242543,
"from":L[2262]});
}
} catch($e4253442535) {
if(R.isCont($e4253442535)) {
var $ss4253842539 = {"from":L[2262],
"go":function(anf_arg169142544) {
return $Hanf_arg890042545(anf_arg169142544,anf_arg168842519,self21316188,_plus55,torepr65);
}};
$e4253442535.stack[R.EXN_STACKHEIGHT++] = $ss4253842539;
}
if(R.isPyretException($e4253442535)) {
$e4253442535.pyretStack.push(L[2262]);
}
throw $e4253442535;
}
var $ret4254042541 = $Hanf_arg890042545($z4253642537,anf_arg168842519,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4254042541;
};
var $Hanf_arg890042545 = function(anf_arg169142544,anf_arg168842519,self21316188,_plus55,torepr65) {
var $z4254842549 = D;
var $f4255442555 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg168842519,anf_arg169142544):R.ffi.throwNonFunApp(L[2262],_plus55,[anf_arg168842519,anf_arg169142544]);
};
try {
if(--R.GAS > 0) {
$z4254842549 = $f4255442555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4255442555,
"from":L[2262]});
}
} catch($e4254642547) {
if(R.isCont($e4254642547)) {
var $ss4255042551 = {"from":L[2262],
"go":function(anf_arg169242556) {
return $Hanf_arg889942557(anf_arg169242556,self21316188,_plus55,torepr65);
}};
$e4254642547.stack[R.EXN_STACKHEIGHT++] = $ss4255042551;
}
if(R.isPyretException($e4254642547)) {
$e4254642547.pyretStack.push(L[2262]);
}
throw $e4254642547;
}
var $ret4255242553 = $Hanf_arg889942557($z4254842549,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4255242553;
};
var $Hanf_arg889942557 = function(anf_arg169242556,self21316188,_plus55,torepr65) {
var anf_arg169342568 = G(self21316188,"doc",L[2262]);
var $z4256042561 = D;
var $f4256642567 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg169342568):R.ffi.throwNonFunApp(L[2262],torepr65,[anf_arg169342568]);
};
try {
if(--R.GAS > 0) {
$z4256042561 = $f4256642567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4256642567,
"from":L[2262]});
}
} catch($e4255842559) {
if(R.isCont($e4255842559)) {
var $ss4256242563 = {"from":L[2262],
"go":function(anf_arg169442569) {
return $Hanf_arg889842570(anf_arg169442569,anf_arg169242556,self21316188,_plus55,torepr65);
}};
$e4255842559.stack[R.EXN_STACKHEIGHT++] = $ss4256242563;
}
if(R.isPyretException($e4255842559)) {
$e4255842559.pyretStack.push(L[2262]);
}
throw $e4255842559;
}
var $ret4256442565 = $Hanf_arg889842570($z4256042561,anf_arg169242556,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4256442565;
};
var $Hanf_arg889842570 = function(anf_arg169442569,anf_arg169242556,self21316188,_plus55,torepr65) {
var $z4257342574 = D;
var $f4257942580 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg169442569):R.ffi.throwNonFunApp(L[2262],_plus55,[(", "),anf_arg169442569]);
};
try {
if(--R.GAS > 0) {
$z4257342574 = $f4257942580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4257942580,
"from":L[2262]});
}
} catch($e4257142572) {
if(R.isCont($e4257142572)) {
var $ss4257542576 = {"from":L[2262],
"go":function(anf_arg169542581) {
return $Hanf_arg889742582(anf_arg169542581,anf_arg169242556,self21316188,_plus55,torepr65);
}};
$e4257142572.stack[R.EXN_STACKHEIGHT++] = $ss4257542576;
}
if(R.isPyretException($e4257142572)) {
$e4257142572.pyretStack.push(L[2262]);
}
throw $e4257142572;
}
var $ret4257742578 = $Hanf_arg889742582($z4257342574,anf_arg169242556,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4257742578;
};
var $Hanf_arg889742582 = function(anf_arg169542581,anf_arg169242556,self21316188,_plus55,torepr65) {
var $z4258542586 = D;
var $f4259142592 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg169242556,anf_arg169542581):R.ffi.throwNonFunApp(L[2262],_plus55,[anf_arg169242556,anf_arg169542581]);
};
try {
if(--R.GAS > 0) {
$z4258542586 = $f4259142592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4259142592,
"from":L[2262]});
}
} catch($e4258342584) {
if(R.isCont($e4258342584)) {
var $ss4258742588 = {"from":L[2262],
"go":function(anf_arg169642593) {
return $Hanf_arg889642594(anf_arg169642593,self21316188,_plus55,torepr65);
}};
$e4258342584.stack[R.EXN_STACKHEIGHT++] = $ss4258742588;
}
if(R.isPyretException($e4258342584)) {
$e4258342584.pyretStack.push(L[2262]);
}
throw $e4258342584;
}
var $ret4258942590 = $Hanf_arg889642594($z4258542586,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4258942590;
};
var $Hanf_arg889642594 = function(anf_arg169642593,self21316188,_plus55,torepr65) {
var anf_arg169742605 = G(self21316188,"body",L[2262]);
var $z4259742598 = D;
var $f4260342604 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg169742605):R.ffi.throwNonFunApp(L[2262],torepr65,[anf_arg169742605]);
};
try {
if(--R.GAS > 0) {
$z4259742598 = $f4260342604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4260342604,
"from":L[2262]});
}
} catch($e4259542596) {
if(R.isCont($e4259542596)) {
var $ss4259942600 = {"from":L[2262],
"go":function(anf_arg169842606) {
return $Hanf_arg889542607(anf_arg169842606,anf_arg169642593,self21316188,_plus55,torepr65);
}};
$e4259542596.stack[R.EXN_STACKHEIGHT++] = $ss4259942600;
}
if(R.isPyretException($e4259542596)) {
$e4259542596.pyretStack.push(L[2262]);
}
throw $e4259542596;
}
var $ret4260142602 = $Hanf_arg889542607($z4259742598,anf_arg169642593,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4260142602;
};
var $Hanf_arg889542607 = function(anf_arg169842606,anf_arg169642593,self21316188,_plus55,torepr65) {
var $z4261042611 = D;
var $f4261642617 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg169842606):R.ffi.throwNonFunApp(L[2262],_plus55,[(", "),anf_arg169842606]);
};
try {
if(--R.GAS > 0) {
$z4261042611 = $f4261642617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4261642617,
"from":L[2262]});
}
} catch($e4260842609) {
if(R.isCont($e4260842609)) {
var $ss4261242613 = {"from":L[2262],
"go":function(anf_arg169942618) {
return $Hanf_arg889442619(anf_arg169942618,anf_arg169642593,self21316188,_plus55,torepr65);
}};
$e4260842609.stack[R.EXN_STACKHEIGHT++] = $ss4261242613;
}
if(R.isPyretException($e4260842609)) {
$e4260842609.pyretStack.push(L[2262]);
}
throw $e4260842609;
}
var $ret4261442615 = $Hanf_arg889442619($z4261042611,anf_arg169642593,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4261442615;
};
var $Hanf_arg889442619 = function(anf_arg169942618,anf_arg169642593,self21316188,_plus55,torepr65) {
var $z4262242623 = D;
var $f4262842629 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg169642593,anf_arg169942618):R.ffi.throwNonFunApp(L[2262],_plus55,[anf_arg169642593,anf_arg169942618]);
};
try {
if(--R.GAS > 0) {
$z4262242623 = $f4262842629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4262842629,
"from":L[2262]});
}
} catch($e4262042621) {
if(R.isCont($e4262042621)) {
var $ss4262442625 = {"from":L[2262],
"go":function(anf_arg170042630) {
return $Hanf_arg889342631(anf_arg170042630,self21316188,_plus55,torepr65);
}};
$e4262042621.stack[R.EXN_STACKHEIGHT++] = $ss4262442625;
}
if(R.isPyretException($e4262042621)) {
$e4262042621.pyretStack.push(L[2262]);
}
throw $e4262042621;
}
var $ret4262642627 = $Hanf_arg889342631($z4262242623,self21316188,_plus55,torepr65);
++R.GAS;
return $ret4262642627;
};
var $Hanf_arg889342631 = function(anf_arg170042630,self21316188,_plus55,torepr65) {
var anf_arg170142642 = G(self21316188,"_check",L[2262]);
var $z4263442635 = D;
var $f4264042641 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg170142642):R.ffi.throwNonFunApp(L[2262],torepr65,[anf_arg170142642]);
};
try {
if(--R.GAS > 0) {
$z4263442635 = $f4264042641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4264042641,
"from":L[2262]});
}
} catch($e4263242633) {
if(R.isCont($e4263242633)) {
var $ss4263642637 = {"from":L[2262],
"go":function(anf_arg170242643) {
return $Hanf_arg889242644(anf_arg170242643,anf_arg170042630,_plus55);
}};
$e4263242633.stack[R.EXN_STACKHEIGHT++] = $ss4263642637;
}
if(R.isPyretException($e4263242633)) {
$e4263242633.pyretStack.push(L[2262]);
}
throw $e4263242633;
}
var $ret4263842639 = $Hanf_arg889242644($z4263442635,anf_arg170042630,_plus55);
++R.GAS;
return $ret4263842639;
};
var $Hanf_arg889242644 = function(anf_arg170242643,anf_arg170042630,_plus55) {
var $z4264742648 = D;
var $f4265342654 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg170242643):R.ffi.throwNonFunApp(L[2262],_plus55,[(", "),anf_arg170242643]);
};
try {
if(--R.GAS > 0) {
$z4264742648 = $f4265342654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4265342654,
"from":L[2262]});
}
} catch($e4264542646) {
if(R.isCont($e4264542646)) {
var $ss4264942650 = {"from":L[2262],
"go":function(anf_arg170342655) {
return $Hanf_arg889142656(anf_arg170342655,anf_arg170042630,_plus55);
}};
$e4264542646.stack[R.EXN_STACKHEIGHT++] = $ss4264942650;
}
if(R.isPyretException($e4264542646)) {
$e4264542646.pyretStack.push(L[2262]);
}
throw $e4264542646;
}
var $ret4265142652 = $Hanf_arg889142656($z4264742648,anf_arg170042630,_plus55);
++R.GAS;
return $ret4265142652;
};
var $Hanf_arg889142656 = function(anf_arg170342655,anf_arg170042630,_plus55) {
var $z4265942660 = D;
var $f4266542666 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg170042630,anf_arg170342655):R.ffi.throwNonFunApp(L[2262],_plus55,[anf_arg170042630,anf_arg170342655]);
};
try {
if(--R.GAS > 0) {
$z4265942660 = $f4266542666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4266542666,
"from":L[2262]});
}
} catch($e4265742658) {
if(R.isCont($e4265742658)) {
var $ss4266142662 = {"from":L[2262],
"go":function(anf_arg170442667) {
return $Hanf_arg889042668(anf_arg170442667,_plus55);
}};
$e4265742658.stack[R.EXN_STACKHEIGHT++] = $ss4266142662;
}
if(R.isPyretException($e4265742658)) {
$e4265742658.pyretStack.push(L[2262]);
}
throw $e4265742658;
}
var $ret4266342664 = $Hanf_arg889042668($z4265942660,_plus55);
++R.GAS;
return $ret4266342664;
};
var $Hanf_arg889042668 = function(anf_arg170442667,_plus55) {
var $z4267142672 = D;
var $f4267742678 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg170442667,(")")):R.ffi.throwNonFunApp(L[2262],_plus55,[anf_arg170442667,(")")]);
};
try {
if(--R.GAS > 0) {
$z4267142672 = $f4267742678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4267742678,
"from":L[2262]});
}
} catch($e4266942670) {
if(R.isCont($e4266942670)) {
var $ss4267342674 = {"from":L[2262],
"go":function(anf_arg170542679) {
return $Hanf_arg888942680(anf_arg170542679,_plus55);
}};
$e4266942670.stack[R.EXN_STACKHEIGHT++] = $ss4267342674;
}
if(R.isPyretException($e4266942670)) {
$e4266942670.pyretStack.push(L[2262]);
}
throw $e4266942670;
}
var $ret4267542676 = $Hanf_arg888942680($z4267142672,_plus55);
++R.GAS;
return $ret4267542676;
};
var $Hanf_arg888942680 = function(anf_arg170542679,_plus55) {
var $z4268342684 = D;
var $f4268942690 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg170542679):R.ffi.throwNonFunApp(L[2262],_plus55,[("("),anf_arg170542679]);
};
try {
if(--R.GAS > 0) {
$z4268342684 = $f4268942690();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4268942690,
"from":L[2262]});
}
} catch($e4268142682) {
if(R.isCont($e4268142682)) {
var $ss4268542686 = {"from":L[2262],
"go":function(anf_arg170642691) {
return $Hanf_arg888842692(anf_arg170642691,_plus55);
}};
$e4268142682.stack[R.EXN_STACKHEIGHT++] = $ss4268542686;
}
if(R.isPyretException($e4268142682)) {
$e4268142682.pyretStack.push(L[2262]);
}
throw $e4268142682;
}
var $ret4268742688 = $Hanf_arg888842692($z4268342684,_plus55);
++R.GAS;
return $ret4268742688;
};
var $Hanf_arg888842692 = function(anf_arg170642691,_plus55) {
var $z4269542696 = D;
var $f4270142702 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-fun"),anf_arg170642691):R.ffi.throwNonFunApp(L[2262],_plus55,[("s-fun"),anf_arg170642691]);
};
try {
if(--R.GAS > 0) {
$z4269542696 = $f4270142702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4270142702,
"from":L[2262]});
}
} catch($e4269342694) {
if(R.isCont($e4269342694)) {
var $ss4269742698 = {"from":L[2262],
"go":function(ann_DASH_check_DASH_temp167442703) {
return $Hann_DASH_check_DASH_temp888742704(ann_DASH_check_DASH_temp167442703);
}};
$e4269342694.stack[R.EXN_STACKHEIGHT++] = $ss4269742698;
}
if(R.isPyretException($e4269342694)) {
$e4269342694.pyretStack.push(L[2262]);
}
throw $e4269342694;
}
var $ret4269942700 = $Hann_DASH_check_DASH_temp888742704($z4269542696);
++R.GAS;
return $ret4269942700;
};
var $Hann_DASH_check_DASH_temp888742704 = function(ann_DASH_check_DASH_temp167442703) {
return ann_DASH_check_DASH_temp167442703;
};
var $Hcont_tail_arg888516211 = function(cont_tail_arg167116209,if_helper165616210) {
if(--R.GAS > 0) {
$z4270542706 = R.isFunction(if_helper165616210)?if_helper165616210.app(cont_tail_arg167116209):R.ffi.throwNonFunApp(L[2262],if_helper165616210,[cont_tail_arg167116209]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper165616210)?if_helper165616210.app(cont_tail_arg167116209):R.ffi.throwNonFunApp(L[2262],if_helper165616210,[cont_tail_arg167116209]);
},
"from":L[2262]});
}
++R.GAS;
return $z4270542706;
};
var $Hcont_tail_arg888616225 = function(cont_tail_arg166116224,if_helper165616210) {
if(--R.GAS > 0) {
$z4270742708 = R.isFunction(if_helper165616210)?if_helper165616210.app(cont_tail_arg166116224):R.ffi.throwNonFunApp(L[2262],if_helper165616210,[cont_tail_arg166116224]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper165616210)?if_helper165616210.app(cont_tail_arg166116224):R.ffi.throwNonFunApp(L[2262],if_helper165616210,[cont_tail_arg166116224]);
},
"from":L[2262]});
}
++R.GAS;
return $z4270742708;
};
var $Hanf_arg888416246 = function(anf_arg165316244,INDENT118169,anf_fun165016245,str_DASH_block128286,str_DASH_end148546) {
var $z4271142712 = D;
var $f4271742718 = function(_) {
return R.isFunction(anf_fun165016245)?anf_fun165016245.app(INDENT118169,(1),str_DASH_block128286,anf_arg165316244,str_DASH_end148546):R.ffi.throwNonFunApp(L[2963],anf_fun165016245,[INDENT118169,(1),str_DASH_block128286,anf_arg165316244,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4271142712 = $f4271742718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4271742718,
"from":L[2963]});
}
} catch($e4270942710) {
if(R.isCont($e4270942710)) {
var $ss4271342714 = {"from":L[2963],
"go":function(ann_DASH_check_DASH_temp164942719) {
return $Hann_DASH_check_DASH_temp888342720(ann_DASH_check_DASH_temp164942719);
}};
$e4270942710.stack[R.EXN_STACKHEIGHT++] = $ss4271342714;
}
if(R.isPyretException($e4270942710)) {
$e4270942710.pyretStack.push(L[2963]);
}
throw $e4270942710;
}
var $ret4271542716 = $Hann_DASH_check_DASH_temp888342720($z4271142712);
++R.GAS;
return $ret4271542716;
};
var $Hann_DASH_check_DASH_temp888342720 = function(ann_DASH_check_DASH_temp164942719) {
return ann_DASH_check_DASH_temp164942719;
};
var $Hanf_arg888216262 = function(anf_arg163916261,self2071552,_plus55,torepr65) {
var anf_arg164042731 = G(self2071552,"body",L[2263]);
var $z4272342724 = D;
var $f4272942730 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg164042731):R.ffi.throwNonFunApp(L[2263],torepr65,[anf_arg164042731]);
};
try {
if(--R.GAS > 0) {
$z4272342724 = $f4272942730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4272942730,
"from":L[2263]});
}
} catch($e4272142722) {
if(R.isCont($e4272142722)) {
var $ss4272542726 = {"from":L[2263],
"go":function(anf_arg164142732) {
return $Hanf_arg888142733(anf_arg164142732,anf_arg163916261,_plus55);
}};
$e4272142722.stack[R.EXN_STACKHEIGHT++] = $ss4272542726;
}
if(R.isPyretException($e4272142722)) {
$e4272142722.pyretStack.push(L[2263]);
}
throw $e4272142722;
}
var $ret4272742728 = $Hanf_arg888142733($z4272342724,anf_arg163916261,_plus55);
++R.GAS;
return $ret4272742728;
};
var $Hanf_arg888142733 = function(anf_arg164142732,anf_arg163916261,_plus55) {
var $z4273642737 = D;
var $f4274242743 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg164142732):R.ffi.throwNonFunApp(L[2263],_plus55,[(", "),anf_arg164142732]);
};
try {
if(--R.GAS > 0) {
$z4273642737 = $f4274242743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4274242743,
"from":L[2263]});
}
} catch($e4273442735) {
if(R.isCont($e4273442735)) {
var $ss4273842739 = {"from":L[2263],
"go":function(anf_arg164242744) {
return $Hanf_arg888042745(anf_arg164242744,anf_arg163916261,_plus55);
}};
$e4273442735.stack[R.EXN_STACKHEIGHT++] = $ss4273842739;
}
if(R.isPyretException($e4273442735)) {
$e4273442735.pyretStack.push(L[2263]);
}
throw $e4273442735;
}
var $ret4274042741 = $Hanf_arg888042745($z4273642737,anf_arg163916261,_plus55);
++R.GAS;
return $ret4274042741;
};
var $Hanf_arg888042745 = function(anf_arg164242744,anf_arg163916261,_plus55) {
var $z4274842749 = D;
var $f4275442755 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg163916261,anf_arg164242744):R.ffi.throwNonFunApp(L[2263],_plus55,[anf_arg163916261,anf_arg164242744]);
};
try {
if(--R.GAS > 0) {
$z4274842749 = $f4275442755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4275442755,
"from":L[2263]});
}
} catch($e4274642747) {
if(R.isCont($e4274642747)) {
var $ss4275042751 = {"from":L[2263],
"go":function(anf_arg164342756) {
return $Hanf_arg887942757(anf_arg164342756,_plus55);
}};
$e4274642747.stack[R.EXN_STACKHEIGHT++] = $ss4275042751;
}
if(R.isPyretException($e4274642747)) {
$e4274642747.pyretStack.push(L[2263]);
}
throw $e4274642747;
}
var $ret4275242753 = $Hanf_arg887942757($z4274842749,_plus55);
++R.GAS;
return $ret4275242753;
};
var $Hanf_arg887942757 = function(anf_arg164342756,_plus55) {
var $z4276042761 = D;
var $f4276642767 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg164342756,(")")):R.ffi.throwNonFunApp(L[2263],_plus55,[anf_arg164342756,(")")]);
};
try {
if(--R.GAS > 0) {
$z4276042761 = $f4276642767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4276642767,
"from":L[2263]});
}
} catch($e4275842759) {
if(R.isCont($e4275842759)) {
var $ss4276242763 = {"from":L[2263],
"go":function(anf_arg164442768) {
return $Hanf_arg887842769(anf_arg164442768,_plus55);
}};
$e4275842759.stack[R.EXN_STACKHEIGHT++] = $ss4276242763;
}
if(R.isPyretException($e4275842759)) {
$e4275842759.pyretStack.push(L[2263]);
}
throw $e4275842759;
}
var $ret4276442765 = $Hanf_arg887842769($z4276042761,_plus55);
++R.GAS;
return $ret4276442765;
};
var $Hanf_arg887842769 = function(anf_arg164442768,_plus55) {
var $z4277242773 = D;
var $f4277842779 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg164442768):R.ffi.throwNonFunApp(L[2263],_plus55,[("("),anf_arg164442768]);
};
try {
if(--R.GAS > 0) {
$z4277242773 = $f4277842779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4277842779,
"from":L[2263]});
}
} catch($e4277042771) {
if(R.isCont($e4277042771)) {
var $ss4277442775 = {"from":L[2263],
"go":function(anf_arg164542780) {
return $Hanf_arg887742781(anf_arg164542780,_plus55);
}};
$e4277042771.stack[R.EXN_STACKHEIGHT++] = $ss4277442775;
}
if(R.isPyretException($e4277042771)) {
$e4277042771.pyretStack.push(L[2263]);
}
throw $e4277042771;
}
var $ret4277642777 = $Hanf_arg887742781($z4277242773,_plus55);
++R.GAS;
return $ret4277642777;
};
var $Hanf_arg887742781 = function(anf_arg164542780,_plus55) {
var $z4278442785 = D;
var $f4279042791 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-user-block"),anf_arg164542780):R.ffi.throwNonFunApp(L[2263],_plus55,[("s-user-block"),anf_arg164542780]);
};
try {
if(--R.GAS > 0) {
$z4278442785 = $f4279042791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4279042791,
"from":L[2263]});
}
} catch($e4278242783) {
if(R.isCont($e4278242783)) {
var $ss4278642787 = {"from":L[2263],
"go":function(ann_DASH_check_DASH_temp163742792) {
return $Hann_DASH_check_DASH_temp887642793(ann_DASH_check_DASH_temp163742792);
}};
$e4278242783.stack[R.EXN_STACKHEIGHT++] = $ss4278642787;
}
if(R.isPyretException($e4278242783)) {
$e4278242783.pyretStack.push(L[2263]);
}
throw $e4278242783;
}
var $ret4278842789 = $Hann_DASH_check_DASH_temp887642793($z4278442785);
++R.GAS;
return $ret4278842789;
};
var $Hann_DASH_check_DASH_temp887642793 = function(ann_DASH_check_DASH_temp163742792) {
return ann_DASH_check_DASH_temp163742792;
};
var $Hcont_tail_arg887416278 = function(cont_tail_arg163416276,if_helper162516277) {
if(--R.GAS > 0) {
$z4279442795 = R.isFunction(if_helper162516277)?if_helper162516277.app(cont_tail_arg163416276):R.ffi.throwNonFunApp(L[2263],if_helper162516277,[cont_tail_arg163416276]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper162516277)?if_helper162516277.app(cont_tail_arg163416276):R.ffi.throwNonFunApp(L[2263],if_helper162516277,[cont_tail_arg163416276]);
},
"from":L[2263]});
}
++R.GAS;
return $z4279442795;
};
var $Hcont_tail_arg887516292 = function(cont_tail_arg163016291,if_helper162516277) {
if(--R.GAS > 0) {
$z4279642797 = R.isFunction(if_helper162516277)?if_helper162516277.app(cont_tail_arg163016291):R.ffi.throwNonFunApp(L[2263],if_helper162516277,[cont_tail_arg163016291]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper162516277)?if_helper162516277.app(cont_tail_arg163016291):R.ffi.throwNonFunApp(L[2263],if_helper162516277,[cont_tail_arg163016291]);
},
"from":L[2263]});
}
++R.GAS;
return $z4279642797;
};
var $Hann_DASH_check_DASH_temp887316315 = function(ann_DASH_check_DASH_temp161616314) {
return ann_DASH_check_DASH_temp161616314;
};
var $Hann_DASH_check_DASH_temp887216330 = function(ann_DASH_check_DASH_temp161916329) {
return ann_DASH_check_DASH_temp161916329;
};
var $Hanf_arg887116345 = function(anf_arg160616344,self2001648,_plus55,torepr65) {
var anf_arg160742808 = G(self2001648,"stmts",L[2264]);
var $z4280042801 = D;
var $f4280642807 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg160742808):R.ffi.throwNonFunApp(L[2264],torepr65,[anf_arg160742808]);
};
try {
if(--R.GAS > 0) {
$z4280042801 = $f4280642807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4280642807,
"from":L[2264]});
}
} catch($e4279842799) {
if(R.isCont($e4279842799)) {
var $ss4280242803 = {"from":L[2264],
"go":function(anf_arg160842809) {
return $Hanf_arg887042810(anf_arg160842809,anf_arg160616344,_plus55);
}};
$e4279842799.stack[R.EXN_STACKHEIGHT++] = $ss4280242803;
}
if(R.isPyretException($e4279842799)) {
$e4279842799.pyretStack.push(L[2264]);
}
throw $e4279842799;
}
var $ret4280442805 = $Hanf_arg887042810($z4280042801,anf_arg160616344,_plus55);
++R.GAS;
return $ret4280442805;
};
var $Hanf_arg887042810 = function(anf_arg160842809,anf_arg160616344,_plus55) {
var $z4281342814 = D;
var $f4281942820 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg160842809):R.ffi.throwNonFunApp(L[2264],_plus55,[(", "),anf_arg160842809]);
};
try {
if(--R.GAS > 0) {
$z4281342814 = $f4281942820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4281942820,
"from":L[2264]});
}
} catch($e4281142812) {
if(R.isCont($e4281142812)) {
var $ss4281542816 = {"from":L[2264],
"go":function(anf_arg160942821) {
return $Hanf_arg886942822(anf_arg160942821,anf_arg160616344,_plus55);
}};
$e4281142812.stack[R.EXN_STACKHEIGHT++] = $ss4281542816;
}
if(R.isPyretException($e4281142812)) {
$e4281142812.pyretStack.push(L[2264]);
}
throw $e4281142812;
}
var $ret4281742818 = $Hanf_arg886942822($z4281342814,anf_arg160616344,_plus55);
++R.GAS;
return $ret4281742818;
};
var $Hanf_arg886942822 = function(anf_arg160942821,anf_arg160616344,_plus55) {
var $z4282542826 = D;
var $f4283142832 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg160616344,anf_arg160942821):R.ffi.throwNonFunApp(L[2264],_plus55,[anf_arg160616344,anf_arg160942821]);
};
try {
if(--R.GAS > 0) {
$z4282542826 = $f4283142832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4283142832,
"from":L[2264]});
}
} catch($e4282342824) {
if(R.isCont($e4282342824)) {
var $ss4282742828 = {"from":L[2264],
"go":function(anf_arg161042833) {
return $Hanf_arg886842834(anf_arg161042833,_plus55);
}};
$e4282342824.stack[R.EXN_STACKHEIGHT++] = $ss4282742828;
}
if(R.isPyretException($e4282342824)) {
$e4282342824.pyretStack.push(L[2264]);
}
throw $e4282342824;
}
var $ret4282942830 = $Hanf_arg886842834($z4282542826,_plus55);
++R.GAS;
return $ret4282942830;
};
var $Hanf_arg886842834 = function(anf_arg161042833,_plus55) {
var $z4283742838 = D;
var $f4284342844 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg161042833,(")")):R.ffi.throwNonFunApp(L[2264],_plus55,[anf_arg161042833,(")")]);
};
try {
if(--R.GAS > 0) {
$z4283742838 = $f4284342844();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4284342844,
"from":L[2264]});
}
} catch($e4283542836) {
if(R.isCont($e4283542836)) {
var $ss4283942840 = {"from":L[2264],
"go":function(anf_arg161142845) {
return $Hanf_arg886742846(anf_arg161142845,_plus55);
}};
$e4283542836.stack[R.EXN_STACKHEIGHT++] = $ss4283942840;
}
if(R.isPyretException($e4283542836)) {
$e4283542836.pyretStack.push(L[2264]);
}
throw $e4283542836;
}
var $ret4284142842 = $Hanf_arg886742846($z4283742838,_plus55);
++R.GAS;
return $ret4284142842;
};
var $Hanf_arg886742846 = function(anf_arg161142845,_plus55) {
var $z4284942850 = D;
var $f4285542856 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg161142845):R.ffi.throwNonFunApp(L[2264],_plus55,[("("),anf_arg161142845]);
};
try {
if(--R.GAS > 0) {
$z4284942850 = $f4285542856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4285542856,
"from":L[2264]});
}
} catch($e4284742848) {
if(R.isCont($e4284742848)) {
var $ss4285142852 = {"from":L[2264],
"go":function(anf_arg161242857) {
return $Hanf_arg886642858(anf_arg161242857,_plus55);
}};
$e4284742848.stack[R.EXN_STACKHEIGHT++] = $ss4285142852;
}
if(R.isPyretException($e4284742848)) {
$e4284742848.pyretStack.push(L[2264]);
}
throw $e4284742848;
}
var $ret4285342854 = $Hanf_arg886642858($z4284942850,_plus55);
++R.GAS;
return $ret4285342854;
};
var $Hanf_arg886642858 = function(anf_arg161242857,_plus55) {
var $z4286142862 = D;
var $f4286742868 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-block"),anf_arg161242857):R.ffi.throwNonFunApp(L[2264],_plus55,[("s-block"),anf_arg161242857]);
};
try {
if(--R.GAS > 0) {
$z4286142862 = $f4286742868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4286742868,
"from":L[2264]});
}
} catch($e4285942860) {
if(R.isCont($e4285942860)) {
var $ss4286342864 = {"from":L[2264],
"go":function(ann_DASH_check_DASH_temp160442869) {
return $Hann_DASH_check_DASH_temp886542870(ann_DASH_check_DASH_temp160442869);
}};
$e4285942860.stack[R.EXN_STACKHEIGHT++] = $ss4286342864;
}
if(R.isPyretException($e4285942860)) {
$e4285942860.pyretStack.push(L[2264]);
}
throw $e4285942860;
}
var $ret4286542866 = $Hann_DASH_check_DASH_temp886542870($z4286142862);
++R.GAS;
return $ret4286542866;
};
var $Hann_DASH_check_DASH_temp886542870 = function(ann_DASH_check_DASH_temp160442869) {
return ann_DASH_check_DASH_temp160442869;
};
var $Hcont_tail_arg886316361 = function(cont_tail_arg160116359,if_helper159216360) {
if(--R.GAS > 0) {
$z4287142872 = R.isFunction(if_helper159216360)?if_helper159216360.app(cont_tail_arg160116359):R.ffi.throwNonFunApp(L[2264],if_helper159216360,[cont_tail_arg160116359]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper159216360)?if_helper159216360.app(cont_tail_arg160116359):R.ffi.throwNonFunApp(L[2264],if_helper159216360,[cont_tail_arg160116359]);
},
"from":L[2264]});
}
++R.GAS;
return $z4287142872;
};
var $Hcont_tail_arg886416376 = function(cont_tail_arg159716375,if_helper159216360) {
if(--R.GAS > 0) {
$z4287342874 = R.isFunction(if_helper159216360)?if_helper159216360.app(cont_tail_arg159716375):R.ffi.throwNonFunApp(L[2264],if_helper159216360,[cont_tail_arg159716375]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper159216360)?if_helper159216360.app(cont_tail_arg159716375):R.ffi.throwNonFunApp(L[2264],if_helper159216360,[cont_tail_arg159716375]);
},
"from":L[2264]});
}
++R.GAS;
return $z4287342874;
};
var $Hanf_arg886216398 = function(anf_arg157716395,INDENT118169,PP170,anf_fun157416396,self68416397,_plus55) {
var anf_fun157842892 = G(PP170,"surround-separate",L[4646]);
var anf_arg157942888 = G(PP170,"mt-doc",L[4645]);
var anf_arg158042889 = G(PP170,"langle",L[4644]);
var anf_arg158142890 = G(PP170,"commabreak",L[4643]);
var anf_arg158242891 = G(PP170,"rangle",L[4642]);
var anf_bracket158342896 = G(self68416397,"params",L[4641]);
var anf_fun158442885 = G(anf_bracket158342896,"map",L[4640]);
var anf_arg158642886 = R.makeFunction(function(recv_DASH_19542894) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4639],1,arguments);
}
var ann_DASH_check_DASH_temp158542895 = G(recv_DASH_19542894,"tosource",L[4639]);
return ann_DASH_check_DASH_temp158542895;
});
var $z4287742878 = D;
var $f4288342884 = function(_) {
return R.isFunction(anf_fun158442885)?anf_fun158442885.app(anf_arg158642886):R.ffi.throwNonFunApp(L[4638],anf_fun158442885,[anf_arg158642886]);
};
try {
if(--R.GAS > 0) {
$z4287742878 = $f4288342884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4288342884,
"from":L[4638]});
}
} catch($e4287542876) {
if(R.isCont($e4287542876)) {
var $ss4287942880 = {"from":L[4638],
"go":function(anf_arg158742887) {
return $Hanf_arg886142893(anf_arg158742887,INDENT118169,anf_arg157716395,anf_arg157942888,anf_arg158042889,anf_arg158142890,anf_arg158242891,anf_fun157416396,anf_fun157842892,_plus55);
}};
$e4287542876.stack[R.EXN_STACKHEIGHT++] = $ss4287942880;
}
if(R.isPyretException($e4287542876)) {
$e4287542876.pyretStack.push(L[4638]);
}
throw $e4287542876;
}
var $ret4288142882 = $Hanf_arg886142893($z4287742878,INDENT118169,anf_arg157716395,anf_arg157942888,anf_arg158042889,anf_arg158142890,anf_arg158242891,anf_fun157416396,anf_fun157842892,_plus55);
++R.GAS;
return $ret4288142882;
};
var $Hanf_arg886142893 = function(anf_arg158742887,INDENT118169,anf_arg157716395,anf_arg157942888,anf_arg158042889,anf_arg158142890,anf_arg158242891,anf_fun157416396,anf_fun157842892,_plus55) {
var $z4289942900 = D;
var $f4290542906 = function(_) {
return R.isFunction(anf_fun157842892)?anf_fun157842892.app(INDENT118169,(0),anf_arg157942888,anf_arg158042889,anf_arg158142890,anf_arg158242891,anf_arg158742887):R.ffi.throwNonFunApp(L[4647],anf_fun157842892,[INDENT118169,(0),anf_arg157942888,anf_arg158042889,anf_arg158142890,anf_arg158242891,anf_arg158742887]);
};
try {
if(--R.GAS > 0) {
$z4289942900 = $f4290542906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4290542906,
"from":L[4647]});
}
} catch($e4289742898) {
if(R.isCont($e4289742898)) {
var $ss4290142902 = {"from":L[4647],
"go":function(anf_arg158842907) {
return $Hanf_arg886042908(anf_arg158842907,anf_arg157716395,anf_fun157416396,_plus55);
}};
$e4289742898.stack[R.EXN_STACKHEIGHT++] = $ss4290142902;
}
if(R.isPyretException($e4289742898)) {
$e4289742898.pyretStack.push(L[4647]);
}
throw $e4289742898;
}
var $ret4290342904 = $Hanf_arg886042908($z4289942900,anf_arg157716395,anf_fun157416396,_plus55);
++R.GAS;
return $ret4290342904;
};
var $Hanf_arg886042908 = function(anf_arg158842907,anf_arg157716395,anf_fun157416396,_plus55) {
var $z4291142912 = D;
var $f4291742918 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg157716395,anf_arg158842907):R.ffi.throwNonFunApp(L[4648],_plus55,[anf_arg157716395,anf_arg158842907]);
};
try {
if(--R.GAS > 0) {
$z4291142912 = $f4291742918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4291742918,
"from":L[4648]});
}
} catch($e4290942910) {
if(R.isCont($e4290942910)) {
var $ss4291342914 = {"from":L[4648],
"go":function(anf_arg158942919) {
return $Hanf_arg885942920(anf_arg158942919,anf_fun157416396);
}};
$e4290942910.stack[R.EXN_STACKHEIGHT++] = $ss4291342914;
}
if(R.isPyretException($e4290942910)) {
$e4290942910.pyretStack.push(L[4648]);
}
throw $e4290942910;
}
var $ret4291542916 = $Hanf_arg885942920($z4291142912,anf_fun157416396);
++R.GAS;
return $ret4291542916;
};
var $Hanf_arg885942920 = function(anf_arg158942919,anf_fun157416396) {
var $z4292342924 = D;
var $f4292942930 = function(_) {
return R.isFunction(anf_fun157416396)?anf_fun157416396.app(anf_arg158942919):R.ffi.throwNonFunApp(L[2979],anf_fun157416396,[anf_arg158942919]);
};
try {
if(--R.GAS > 0) {
$z4292342924 = $f4292942930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4292942930,
"from":L[2979]});
}
} catch($e4292142922) {
if(R.isCont($e4292142922)) {
var $ss4292542926 = {"from":L[2979],
"go":function(ann_DASH_check_DASH_temp157342931) {
return $Hann_DASH_check_DASH_temp885842932(ann_DASH_check_DASH_temp157342931);
}};
$e4292142922.stack[R.EXN_STACKHEIGHT++] = $ss4292542926;
}
if(R.isPyretException($e4292142922)) {
$e4292142922.pyretStack.push(L[2979]);
}
throw $e4292142922;
}
var $ret4292742928 = $Hann_DASH_check_DASH_temp885842932($z4292342924);
++R.GAS;
return $ret4292742928;
};
var $Hann_DASH_check_DASH_temp885842932 = function(ann_DASH_check_DASH_temp157342931) {
return ann_DASH_check_DASH_temp157342931;
};
var $Hanf_arg885716415 = function(anf_arg155916413,self19316414,_plus55,torepr65) {
var anf_arg156042943 = G(self19316414,"expr",L[2265]);
var $z4293542936 = D;
var $f4294142942 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg156042943):R.ffi.throwNonFunApp(L[2265],torepr65,[anf_arg156042943]);
};
try {
if(--R.GAS > 0) {
$z4293542936 = $f4294142942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4294142942,
"from":L[2265]});
}
} catch($e4293342934) {
if(R.isCont($e4293342934)) {
var $ss4293742938 = {"from":L[2265],
"go":function(anf_arg156142944) {
return $Hanf_arg885642945(anf_arg156142944,anf_arg155916413,self19316414,_plus55,torepr65);
}};
$e4293342934.stack[R.EXN_STACKHEIGHT++] = $ss4293742938;
}
if(R.isPyretException($e4293342934)) {
$e4293342934.pyretStack.push(L[2265]);
}
throw $e4293342934;
}
var $ret4293942940 = $Hanf_arg885642945($z4293542936,anf_arg155916413,self19316414,_plus55,torepr65);
++R.GAS;
return $ret4293942940;
};
var $Hanf_arg885642945 = function(anf_arg156142944,anf_arg155916413,self19316414,_plus55,torepr65) {
var $z4294842949 = D;
var $f4295442955 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg156142944):R.ffi.throwNonFunApp(L[2265],_plus55,[(", "),anf_arg156142944]);
};
try {
if(--R.GAS > 0) {
$z4294842949 = $f4295442955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4295442955,
"from":L[2265]});
}
} catch($e4294642947) {
if(R.isCont($e4294642947)) {
var $ss4295042951 = {"from":L[2265],
"go":function(anf_arg156242956) {
return $Hanf_arg885542957(anf_arg156242956,anf_arg155916413,self19316414,_plus55,torepr65);
}};
$e4294642947.stack[R.EXN_STACKHEIGHT++] = $ss4295042951;
}
if(R.isPyretException($e4294642947)) {
$e4294642947.pyretStack.push(L[2265]);
}
throw $e4294642947;
}
var $ret4295242953 = $Hanf_arg885542957($z4294842949,anf_arg155916413,self19316414,_plus55,torepr65);
++R.GAS;
return $ret4295242953;
};
var $Hanf_arg885542957 = function(anf_arg156242956,anf_arg155916413,self19316414,_plus55,torepr65) {
var $z4296042961 = D;
var $f4296642967 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg155916413,anf_arg156242956):R.ffi.throwNonFunApp(L[2265],_plus55,[anf_arg155916413,anf_arg156242956]);
};
try {
if(--R.GAS > 0) {
$z4296042961 = $f4296642967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4296642967,
"from":L[2265]});
}
} catch($e4295842959) {
if(R.isCont($e4295842959)) {
var $ss4296242963 = {"from":L[2265],
"go":function(anf_arg156342968) {
return $Hanf_arg885442969(anf_arg156342968,self19316414,_plus55,torepr65);
}};
$e4295842959.stack[R.EXN_STACKHEIGHT++] = $ss4296242963;
}
if(R.isPyretException($e4295842959)) {
$e4295842959.pyretStack.push(L[2265]);
}
throw $e4295842959;
}
var $ret4296442965 = $Hanf_arg885442969($z4296042961,self19316414,_plus55,torepr65);
++R.GAS;
return $ret4296442965;
};
var $Hanf_arg885442969 = function(anf_arg156342968,self19316414,_plus55,torepr65) {
var anf_arg156442980 = G(self19316414,"params",L[2265]);
var $z4297242973 = D;
var $f4297842979 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg156442980):R.ffi.throwNonFunApp(L[2265],torepr65,[anf_arg156442980]);
};
try {
if(--R.GAS > 0) {
$z4297242973 = $f4297842979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4297842979,
"from":L[2265]});
}
} catch($e4297042971) {
if(R.isCont($e4297042971)) {
var $ss4297442975 = {"from":L[2265],
"go":function(anf_arg156542981) {
return $Hanf_arg885342982(anf_arg156542981,anf_arg156342968,_plus55);
}};
$e4297042971.stack[R.EXN_STACKHEIGHT++] = $ss4297442975;
}
if(R.isPyretException($e4297042971)) {
$e4297042971.pyretStack.push(L[2265]);
}
throw $e4297042971;
}
var $ret4297642977 = $Hanf_arg885342982($z4297242973,anf_arg156342968,_plus55);
++R.GAS;
return $ret4297642977;
};
var $Hanf_arg885342982 = function(anf_arg156542981,anf_arg156342968,_plus55) {
var $z4298542986 = D;
var $f4299142992 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg156542981):R.ffi.throwNonFunApp(L[2265],_plus55,[(", "),anf_arg156542981]);
};
try {
if(--R.GAS > 0) {
$z4298542986 = $f4299142992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4299142992,
"from":L[2265]});
}
} catch($e4298342984) {
if(R.isCont($e4298342984)) {
var $ss4298742988 = {"from":L[2265],
"go":function(anf_arg156642993) {
return $Hanf_arg885242994(anf_arg156642993,anf_arg156342968,_plus55);
}};
$e4298342984.stack[R.EXN_STACKHEIGHT++] = $ss4298742988;
}
if(R.isPyretException($e4298342984)) {
$e4298342984.pyretStack.push(L[2265]);
}
throw $e4298342984;
}
var $ret4298942990 = $Hanf_arg885242994($z4298542986,anf_arg156342968,_plus55);
++R.GAS;
return $ret4298942990;
};
var $Hanf_arg885242994 = function(anf_arg156642993,anf_arg156342968,_plus55) {
var $z4299742998 = D;
var $f4300343004 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg156342968,anf_arg156642993):R.ffi.throwNonFunApp(L[2265],_plus55,[anf_arg156342968,anf_arg156642993]);
};
try {
if(--R.GAS > 0) {
$z4299742998 = $f4300343004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4300343004,
"from":L[2265]});
}
} catch($e4299542996) {
if(R.isCont($e4299542996)) {
var $ss4299943000 = {"from":L[2265],
"go":function(anf_arg156743005) {
return $Hanf_arg885143006(anf_arg156743005,_plus55);
}};
$e4299542996.stack[R.EXN_STACKHEIGHT++] = $ss4299943000;
}
if(R.isPyretException($e4299542996)) {
$e4299542996.pyretStack.push(L[2265]);
}
throw $e4299542996;
}
var $ret4300143002 = $Hanf_arg885143006($z4299742998,_plus55);
++R.GAS;
return $ret4300143002;
};
var $Hanf_arg885143006 = function(anf_arg156743005,_plus55) {
var $z4300943010 = D;
var $f4301543016 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg156743005,(")")):R.ffi.throwNonFunApp(L[2265],_plus55,[anf_arg156743005,(")")]);
};
try {
if(--R.GAS > 0) {
$z4300943010 = $f4301543016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4301543016,
"from":L[2265]});
}
} catch($e4300743008) {
if(R.isCont($e4300743008)) {
var $ss4301143012 = {"from":L[2265],
"go":function(anf_arg156843017) {
return $Hanf_arg885043018(anf_arg156843017,_plus55);
}};
$e4300743008.stack[R.EXN_STACKHEIGHT++] = $ss4301143012;
}
if(R.isPyretException($e4300743008)) {
$e4300743008.pyretStack.push(L[2265]);
}
throw $e4300743008;
}
var $ret4301343014 = $Hanf_arg885043018($z4300943010,_plus55);
++R.GAS;
return $ret4301343014;
};
var $Hanf_arg885043018 = function(anf_arg156843017,_plus55) {
var $z4302143022 = D;
var $f4302743028 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg156843017):R.ffi.throwNonFunApp(L[2265],_plus55,[("("),anf_arg156843017]);
};
try {
if(--R.GAS > 0) {
$z4302143022 = $f4302743028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4302743028,
"from":L[2265]});
}
} catch($e4301943020) {
if(R.isCont($e4301943020)) {
var $ss4302343024 = {"from":L[2265],
"go":function(anf_arg156943029) {
return $Hanf_arg884943030(anf_arg156943029,_plus55);
}};
$e4301943020.stack[R.EXN_STACKHEIGHT++] = $ss4302343024;
}
if(R.isPyretException($e4301943020)) {
$e4301943020.pyretStack.push(L[2265]);
}
throw $e4301943020;
}
var $ret4302543026 = $Hanf_arg884943030($z4302143022,_plus55);
++R.GAS;
return $ret4302543026;
};
var $Hanf_arg884943030 = function(anf_arg156943029,_plus55) {
var $z4303343034 = D;
var $f4303943040 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-instantiate"),anf_arg156943029):R.ffi.throwNonFunApp(L[2265],_plus55,[("s-instantiate"),anf_arg156943029]);
};
try {
if(--R.GAS > 0) {
$z4303343034 = $f4303943040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4303943040,
"from":L[2265]});
}
} catch($e4303143032) {
if(R.isCont($e4303143032)) {
var $ss4303543036 = {"from":L[2265],
"go":function(ann_DASH_check_DASH_temp155743041) {
return $Hann_DASH_check_DASH_temp884843042(ann_DASH_check_DASH_temp155743041);
}};
$e4303143032.stack[R.EXN_STACKHEIGHT++] = $ss4303543036;
}
if(R.isPyretException($e4303143032)) {
$e4303143032.pyretStack.push(L[2265]);
}
throw $e4303143032;
}
var $ret4303743038 = $Hann_DASH_check_DASH_temp884843042($z4303343034);
++R.GAS;
return $ret4303743038;
};
var $Hann_DASH_check_DASH_temp884843042 = function(ann_DASH_check_DASH_temp155743041) {
return ann_DASH_check_DASH_temp155743041;
};
var $Hcont_tail_arg884616432 = function(cont_tail_arg155416430,if_helper154416431) {
if(--R.GAS > 0) {
$z4304343044 = R.isFunction(if_helper154416431)?if_helper154416431.app(cont_tail_arg155416430):R.ffi.throwNonFunApp(L[2265],if_helper154416431,[cont_tail_arg155416430]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper154416431)?if_helper154416431.app(cont_tail_arg155416430):R.ffi.throwNonFunApp(L[2265],if_helper154416431,[cont_tail_arg155416430]);
},
"from":L[2265]});
}
++R.GAS;
return $z4304343044;
};
var $Hcont_tail_arg884716447 = function(cont_tail_arg154916446,if_helper154416431) {
if(--R.GAS > 0) {
$z4304543046 = R.isFunction(if_helper154416431)?if_helper154416431.app(cont_tail_arg154916446):R.ffi.throwNonFunApp(L[2265],if_helper154416431,[cont_tail_arg154916446]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper154416431)?if_helper154416431.app(cont_tail_arg154916446):R.ffi.throwNonFunApp(L[2265],if_helper154416431,[cont_tail_arg154916446]);
},
"from":L[2265]});
}
++R.GAS;
return $z4304543046;
};
var $Hanf_arg884516470 = function(anf_arg153616469,PP170,self6789741,_plus55) {
var anf_arg153743057 = G(PP170,"hardline",L[4650]);
var $z4304943050 = D;
var $f4305543056 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg153616469,anf_arg153743057):R.ffi.throwNonFunApp(L[4649],_plus55,[anf_arg153616469,anf_arg153743057]);
};
try {
if(--R.GAS > 0) {
$z4304943050 = $f4305543056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4305543056,
"from":L[4649]});
}
} catch($e4304743048) {
if(R.isCont($e4304743048)) {
var $ss4305143052 = {"from":L[4649],
"go":function(anf_arg153843058) {
return $Hanf_arg884443059(anf_arg153843058,self6789741,_plus55);
}};
$e4304743048.stack[R.EXN_STACKHEIGHT++] = $ss4305143052;
}
if(R.isPyretException($e4304743048)) {
$e4304743048.pyretStack.push(L[4649]);
}
throw $e4304743048;
}
var $ret4305343054 = $Hanf_arg884443059($z4304943050,self6789741,_plus55);
++R.GAS;
return $ret4305343054;
};
var $Hanf_arg884443059 = function(anf_arg153843058,self6789741,_plus55) {
var anf_bracket153943073 = G(self6789741,"e",L[4653]);
var anf_fun154043070 = G(anf_bracket153943073,"tosource",L[4652]);
var $z4306243063 = D;
var $f4306843069 = function(_) {
return R.isFunction(anf_fun154043070)?anf_fun154043070.app():R.ffi.throwNonFunApp(L[4651],anf_fun154043070,[]);
};
try {
if(--R.GAS > 0) {
$z4306243063 = $f4306843069();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4306843069,
"from":L[4651]});
}
} catch($e4306043061) {
if(R.isCont($e4306043061)) {
var $ss4306443065 = {"from":L[4651],
"go":function(anf_arg154143071) {
return $Hanf_arg884343072(anf_arg154143071,anf_arg153843058,_plus55);
}};
$e4306043061.stack[R.EXN_STACKHEIGHT++] = $ss4306443065;
}
if(R.isPyretException($e4306043061)) {
$e4306043061.pyretStack.push(L[4651]);
}
throw $e4306043061;
}
var $ret4306643067 = $Hanf_arg884343072($z4306243063,anf_arg153843058,_plus55);
++R.GAS;
return $ret4306643067;
};
var $Hanf_arg884343072 = function(anf_arg154143071,anf_arg153843058,_plus55) {
var $z4307643077 = D;
var $f4308243083 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg153843058,anf_arg154143071):R.ffi.throwNonFunApp(L[2991],_plus55,[anf_arg153843058,anf_arg154143071]);
};
try {
if(--R.GAS > 0) {
$z4307643077 = $f4308243083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4308243083,
"from":L[2991]});
}
} catch($e4307443075) {
if(R.isCont($e4307443075)) {
var $ss4307843079 = {"from":L[2991],
"go":function(ann_DASH_check_DASH_temp152843084) {
return $Hann_DASH_check_DASH_temp884243085(ann_DASH_check_DASH_temp152843084);
}};
$e4307443075.stack[R.EXN_STACKHEIGHT++] = $ss4307843079;
}
if(R.isPyretException($e4307443075)) {
$e4307443075.pyretStack.push(L[2991]);
}
throw $e4307443075;
}
var $ret4308043081 = $Hann_DASH_check_DASH_temp884243085($z4307643077);
++R.GAS;
return $ret4308043081;
};
var $Hann_DASH_check_DASH_temp884243085 = function(ann_DASH_check_DASH_temp152843084) {
return ann_DASH_check_DASH_temp152843084;
};
var $Hanf_arg884116484 = function(anf_arg153316483,str_DASH_comment137403,_plus55) {
var $z4308843089 = D;
var $f4309443095 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_comment137403,anf_arg153316483):R.ffi.throwNonFunApp(L[2986],_plus55,[str_DASH_comment137403,anf_arg153316483]);
};
try {
if(--R.GAS > 0) {
$z4308843089 = $f4309443095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4309443095,
"from":L[2986]});
}
} catch($e4308643087) {
if(R.isCont($e4308643087)) {
var $ss4309043091 = {"from":L[2986],
"go":function(ann_DASH_check_DASH_temp153143096) {
return $Hann_DASH_check_DASH_temp884043097(ann_DASH_check_DASH_temp153143096);
}};
$e4308643087.stack[R.EXN_STACKHEIGHT++] = $ss4309043091;
}
if(R.isPyretException($e4308643087)) {
$e4308643087.pyretStack.push(L[2986]);
}
throw $e4308643087;
}
var $ret4309243093 = $Hann_DASH_check_DASH_temp884043097($z4308843089);
++R.GAS;
return $ret4309243093;
};
var $Hann_DASH_check_DASH_temp884043097 = function(ann_DASH_check_DASH_temp153143096) {
return ann_DASH_check_DASH_temp153143096;
};
var $Hanf_arg883916500 = function(anf_arg151416498,self18716499,_plus55,torepr65) {
var anf_arg151543108 = G(self18716499,"hints",L[2266]);
var $z4310043101 = D;
var $f4310643107 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg151543108):R.ffi.throwNonFunApp(L[2266],torepr65,[anf_arg151543108]);
};
try {
if(--R.GAS > 0) {
$z4310043101 = $f4310643107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4310643107,
"from":L[2266]});
}
} catch($e4309843099) {
if(R.isCont($e4309843099)) {
var $ss4310243103 = {"from":L[2266],
"go":function(anf_arg151643109) {
return $Hanf_arg883843110(anf_arg151643109,anf_arg151416498,self18716499,_plus55,torepr65);
}};
$e4309843099.stack[R.EXN_STACKHEIGHT++] = $ss4310243103;
}
if(R.isPyretException($e4309843099)) {
$e4309843099.pyretStack.push(L[2266]);
}
throw $e4309843099;
}
var $ret4310443105 = $Hanf_arg883843110($z4310043101,anf_arg151416498,self18716499,_plus55,torepr65);
++R.GAS;
return $ret4310443105;
};
var $Hanf_arg883843110 = function(anf_arg151643109,anf_arg151416498,self18716499,_plus55,torepr65) {
var $z4311343114 = D;
var $f4311943120 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg151643109):R.ffi.throwNonFunApp(L[2266],_plus55,[(", "),anf_arg151643109]);
};
try {
if(--R.GAS > 0) {
$z4311343114 = $f4311943120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4311943120,
"from":L[2266]});
}
} catch($e4311143112) {
if(R.isCont($e4311143112)) {
var $ss4311543116 = {"from":L[2266],
"go":function(anf_arg151743121) {
return $Hanf_arg883743122(anf_arg151743121,anf_arg151416498,self18716499,_plus55,torepr65);
}};
$e4311143112.stack[R.EXN_STACKHEIGHT++] = $ss4311543116;
}
if(R.isPyretException($e4311143112)) {
$e4311143112.pyretStack.push(L[2266]);
}
throw $e4311143112;
}
var $ret4311743118 = $Hanf_arg883743122($z4311343114,anf_arg151416498,self18716499,_plus55,torepr65);
++R.GAS;
return $ret4311743118;
};
var $Hanf_arg883743122 = function(anf_arg151743121,anf_arg151416498,self18716499,_plus55,torepr65) {
var $z4312543126 = D;
var $f4313143132 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg151416498,anf_arg151743121):R.ffi.throwNonFunApp(L[2266],_plus55,[anf_arg151416498,anf_arg151743121]);
};
try {
if(--R.GAS > 0) {
$z4312543126 = $f4313143132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4313143132,
"from":L[2266]});
}
} catch($e4312343124) {
if(R.isCont($e4312343124)) {
var $ss4312743128 = {"from":L[2266],
"go":function(anf_arg151843133) {
return $Hanf_arg883643134(anf_arg151843133,self18716499,_plus55,torepr65);
}};
$e4312343124.stack[R.EXN_STACKHEIGHT++] = $ss4312743128;
}
if(R.isPyretException($e4312343124)) {
$e4312343124.pyretStack.push(L[2266]);
}
throw $e4312343124;
}
var $ret4312943130 = $Hanf_arg883643134($z4312543126,self18716499,_plus55,torepr65);
++R.GAS;
return $ret4312943130;
};
var $Hanf_arg883643134 = function(anf_arg151843133,self18716499,_plus55,torepr65) {
var anf_arg151943145 = G(self18716499,"exp",L[2266]);
var $z4313743138 = D;
var $f4314343144 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg151943145):R.ffi.throwNonFunApp(L[2266],torepr65,[anf_arg151943145]);
};
try {
if(--R.GAS > 0) {
$z4313743138 = $f4314343144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4314343144,
"from":L[2266]});
}
} catch($e4313543136) {
if(R.isCont($e4313543136)) {
var $ss4313943140 = {"from":L[2266],
"go":function(anf_arg152043146) {
return $Hanf_arg883543147(anf_arg152043146,anf_arg151843133,_plus55);
}};
$e4313543136.stack[R.EXN_STACKHEIGHT++] = $ss4313943140;
}
if(R.isPyretException($e4313543136)) {
$e4313543136.pyretStack.push(L[2266]);
}
throw $e4313543136;
}
var $ret4314143142 = $Hanf_arg883543147($z4313743138,anf_arg151843133,_plus55);
++R.GAS;
return $ret4314143142;
};
var $Hanf_arg883543147 = function(anf_arg152043146,anf_arg151843133,_plus55) {
var $z4315043151 = D;
var $f4315643157 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg152043146):R.ffi.throwNonFunApp(L[2266],_plus55,[(", "),anf_arg152043146]);
};
try {
if(--R.GAS > 0) {
$z4315043151 = $f4315643157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4315643157,
"from":L[2266]});
}
} catch($e4314843149) {
if(R.isCont($e4314843149)) {
var $ss4315243153 = {"from":L[2266],
"go":function(anf_arg152143158) {
return $Hanf_arg883443159(anf_arg152143158,anf_arg151843133,_plus55);
}};
$e4314843149.stack[R.EXN_STACKHEIGHT++] = $ss4315243153;
}
if(R.isPyretException($e4314843149)) {
$e4314843149.pyretStack.push(L[2266]);
}
throw $e4314843149;
}
var $ret4315443155 = $Hanf_arg883443159($z4315043151,anf_arg151843133,_plus55);
++R.GAS;
return $ret4315443155;
};
var $Hanf_arg883443159 = function(anf_arg152143158,anf_arg151843133,_plus55) {
var $z4316243163 = D;
var $f4316843169 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg151843133,anf_arg152143158):R.ffi.throwNonFunApp(L[2266],_plus55,[anf_arg151843133,anf_arg152143158]);
};
try {
if(--R.GAS > 0) {
$z4316243163 = $f4316843169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4316843169,
"from":L[2266]});
}
} catch($e4316043161) {
if(R.isCont($e4316043161)) {
var $ss4316443165 = {"from":L[2266],
"go":function(anf_arg152243170) {
return $Hanf_arg883343171(anf_arg152243170,_plus55);
}};
$e4316043161.stack[R.EXN_STACKHEIGHT++] = $ss4316443165;
}
if(R.isPyretException($e4316043161)) {
$e4316043161.pyretStack.push(L[2266]);
}
throw $e4316043161;
}
var $ret4316643167 = $Hanf_arg883343171($z4316243163,_plus55);
++R.GAS;
return $ret4316643167;
};
var $Hanf_arg883343171 = function(anf_arg152243170,_plus55) {
var $z4317443175 = D;
var $f4318043181 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg152243170,(")")):R.ffi.throwNonFunApp(L[2266],_plus55,[anf_arg152243170,(")")]);
};
try {
if(--R.GAS > 0) {
$z4317443175 = $f4318043181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4318043181,
"from":L[2266]});
}
} catch($e4317243173) {
if(R.isCont($e4317243173)) {
var $ss4317643177 = {"from":L[2266],
"go":function(anf_arg152343182) {
return $Hanf_arg883243183(anf_arg152343182,_plus55);
}};
$e4317243173.stack[R.EXN_STACKHEIGHT++] = $ss4317643177;
}
if(R.isPyretException($e4317243173)) {
$e4317243173.pyretStack.push(L[2266]);
}
throw $e4317243173;
}
var $ret4317843179 = $Hanf_arg883243183($z4317443175,_plus55);
++R.GAS;
return $ret4317843179;
};
var $Hanf_arg883243183 = function(anf_arg152343182,_plus55) {
var $z4318643187 = D;
var $f4319243193 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg152343182):R.ffi.throwNonFunApp(L[2266],_plus55,[("("),anf_arg152343182]);
};
try {
if(--R.GAS > 0) {
$z4318643187 = $f4319243193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4319243193,
"from":L[2266]});
}
} catch($e4318443185) {
if(R.isCont($e4318443185)) {
var $ss4318843189 = {"from":L[2266],
"go":function(anf_arg152443194) {
return $Hanf_arg883143195(anf_arg152443194,_plus55);
}};
$e4318443185.stack[R.EXN_STACKHEIGHT++] = $ss4318843189;
}
if(R.isPyretException($e4318443185)) {
$e4318443185.pyretStack.push(L[2266]);
}
throw $e4318443185;
}
var $ret4319043191 = $Hanf_arg883143195($z4318643187,_plus55);
++R.GAS;
return $ret4319043191;
};
var $Hanf_arg883143195 = function(anf_arg152443194,_plus55) {
var $z4319843199 = D;
var $f4320443205 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-hint-exp"),anf_arg152443194):R.ffi.throwNonFunApp(L[2266],_plus55,[("s-hint-exp"),anf_arg152443194]);
};
try {
if(--R.GAS > 0) {
$z4319843199 = $f4320443205();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4320443205,
"from":L[2266]});
}
} catch($e4319643197) {
if(R.isCont($e4319643197)) {
var $ss4320043201 = {"from":L[2266],
"go":function(ann_DASH_check_DASH_temp151243206) {
return $Hann_DASH_check_DASH_temp883043207(ann_DASH_check_DASH_temp151243206);
}};
$e4319643197.stack[R.EXN_STACKHEIGHT++] = $ss4320043201;
}
if(R.isPyretException($e4319643197)) {
$e4319643197.pyretStack.push(L[2266]);
}
throw $e4319643197;
}
var $ret4320243203 = $Hann_DASH_check_DASH_temp883043207($z4319843199);
++R.GAS;
return $ret4320243203;
};
var $Hann_DASH_check_DASH_temp883043207 = function(ann_DASH_check_DASH_temp151243206) {
return ann_DASH_check_DASH_temp151243206;
};
var $Hcont_tail_arg882816517 = function(cont_tail_arg150916515,if_helper149916516) {
if(--R.GAS > 0) {
$z4320843209 = R.isFunction(if_helper149916516)?if_helper149916516.app(cont_tail_arg150916515):R.ffi.throwNonFunApp(L[2266],if_helper149916516,[cont_tail_arg150916515]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper149916516)?if_helper149916516.app(cont_tail_arg150916515):R.ffi.throwNonFunApp(L[2266],if_helper149916516,[cont_tail_arg150916515]);
},
"from":L[2266]});
}
++R.GAS;
return $z4320843209;
};
var $Hcont_tail_arg882916532 = function(cont_tail_arg150416531,if_helper149916516) {
if(--R.GAS > 0) {
$z4321043211 = R.isFunction(if_helper149916516)?if_helper149916516.app(cont_tail_arg150416531):R.ffi.throwNonFunApp(L[2266],if_helper149916516,[cont_tail_arg150416531]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper149916516)?if_helper149916516.app(cont_tail_arg150416531):R.ffi.throwNonFunApp(L[2266],if_helper149916516,[cont_tail_arg150416531]);
},
"from":L[2266]});
}
++R.GAS;
return $z4321043211;
};
var $Hanf_arg882716552 = function(anf_arg148016550,INDENT118169,PP170,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55) {
var anf_fun148143222 = G(PP170,"str",L[4655]);
var $z4321443215 = D;
var $f4322043221 = function(_) {
return R.isFunction(anf_fun148143222)?anf_fun148143222.app((" ")):R.ffi.throwNonFunApp(L[4654],anf_fun148143222,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z4321443215 = $f4322043221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4322043221,
"from":L[4654]});
}
} catch($e4321243213) {
if(R.isCont($e4321243213)) {
var $ss4321643217 = {"from":L[4654],
"go":function(anf_arg148243223) {
return $Hanf_arg882643224(anf_arg148243223,INDENT118169,PP170,anf_arg148016550,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55);
}};
$e4321243213.stack[R.EXN_STACKHEIGHT++] = $ss4321643217;
}
if(R.isPyretException($e4321243213)) {
$e4321243213.pyretStack.push(L[4654]);
}
throw $e4321243213;
}
var $ret4321843219 = $Hanf_arg882643224($z4321443215,INDENT118169,PP170,anf_arg148016550,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55);
++R.GAS;
return $ret4321843219;
};
var $Hanf_arg882643224 = function(anf_arg148243223,INDENT118169,PP170,anf_arg148016550,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55) {
var $z4322743228 = D;
var $f4323343234 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_letrec127273,anf_arg148243223):R.ffi.throwNonFunApp(L[4656],_plus55,[str_DASH_letrec127273,anf_arg148243223]);
};
try {
if(--R.GAS > 0) {
$z4322743228 = $f4323343234();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4323343234,
"from":L[4656]});
}
} catch($e4322543226) {
if(R.isCont($e4322543226)) {
var $ss4322943230 = {"from":L[4656],
"go":function(anf_arg148343235) {
return $Hanf_arg882543236(anf_arg148343235,INDENT118169,PP170,anf_arg148016550,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55);
}};
$e4322543226.stack[R.EXN_STACKHEIGHT++] = $ss4322943230;
}
if(R.isPyretException($e4322543226)) {
$e4322543226.pyretStack.push(L[4656]);
}
throw $e4322543226;
}
var $ret4323143232 = $Hanf_arg882543236($z4322743228,INDENT118169,PP170,anf_arg148016550,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55);
++R.GAS;
return $ret4323143232;
};
var $Hanf_arg882543236 = function(anf_arg148343235,INDENT118169,PP170,anf_arg148016550,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55) {
var anf_arg148443250 = G(PP170,"commabreak",L[4662]);
var anf_arg148543251 = G(PP170,"mt-doc",L[4661]);
var anf_bracket148643267 = G(self6729809,"binds",L[4660]);
var anf_fun148743247 = G(anf_bracket148643267,"map",L[4659]);
var anf_arg149043248 = R.makeFunction(function(recv_DASH_18243253) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4658],1,arguments);
}
var anf_fun148943264 = G(recv_DASH_18243253,"tosource",L[4658]);
var $z4325643257 = D;
var $f4326243263 = function(_) {
return R.isFunction(anf_fun148943264)?anf_fun148943264.app():R.ffi.throwNonFunApp(L[4658],anf_fun148943264,[]);
};
try {
if(--R.GAS > 0) {
$z4325643257 = $f4326243263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4326243263,
"from":L[4658]});
}
} catch($e4325443255) {
if(R.isCont($e4325443255)) {
var $ss4325843259 = {"from":L[4658],
"go":function(ann_DASH_check_DASH_temp148843265) {
return $Hann_DASH_check_DASH_temp881943266(ann_DASH_check_DASH_temp148843265);
}};
$e4325443255.stack[R.EXN_STACKHEIGHT++] = $ss4325843259;
}
if(R.isPyretException($e4325443255)) {
$e4325443255.pyretStack.push(L[4658]);
}
throw $e4325443255;
}
var $ret4326043261 = $Hann_DASH_check_DASH_temp881943266($z4325643257);
++R.GAS;
return $ret4326043261;
});
var $z4323943240 = D;
var $f4324543246 = function(_) {
return R.isFunction(anf_fun148743247)?anf_fun148743247.app(anf_arg149043248):R.ffi.throwNonFunApp(L[4657],anf_fun148743247,[anf_arg149043248]);
};
try {
if(--R.GAS > 0) {
$z4323943240 = $f4324543246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4324543246,
"from":L[4657]});
}
} catch($e4323743238) {
if(R.isCont($e4323743238)) {
var $ss4324143242 = {"from":L[4657],
"go":function(anf_arg149143249) {
return $Hanf_arg882443252(anf_arg149143249,INDENT118169,PP170,anf_arg148016550,anf_arg148343235,anf_arg148443250,anf_arg148543251,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55);
}};
$e4323743238.stack[R.EXN_STACKHEIGHT++] = $ss4324143242;
}
if(R.isPyretException($e4323743238)) {
$e4323743238.pyretStack.push(L[4657]);
}
throw $e4323743238;
}
var $ret4324343244 = $Hanf_arg882443252($z4323943240,INDENT118169,PP170,anf_arg148016550,anf_arg148343235,anf_arg148443250,anf_arg148543251,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55);
++R.GAS;
return $ret4324343244;
};
var $Hanf_arg882443252 = function(anf_arg149143249,INDENT118169,PP170,anf_arg148016550,anf_arg148343235,anf_arg148443250,anf_arg148543251,anf_fun147916551,self6729809,str_DASH_colon134364,str_DASH_end148546,str_DASH_letrec127273,_plus55) {
var $z4327043271 = D;
var $f4327643277 = function(_) {
return R.isFunction(anf_fun147916551)?anf_fun147916551.app(anf_arg148016550,(1),str_DASH_letrec127273,anf_arg148343235,anf_arg148443250,anf_arg148543251,anf_arg149143249):R.ffi.throwNonFunApp(L[4663],anf_fun147916551,[anf_arg148016550,(1),str_DASH_letrec127273,anf_arg148343235,anf_arg148443250,anf_arg148543251,anf_arg149143249]);
};
try {
if(--R.GAS > 0) {
$z4327043271 = $f4327643277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4327643277,
"from":L[4663]});
}
} catch($e4326843269) {
if(R.isCont($e4326843269)) {
var $ss4327243273 = {"from":L[4663],
"go":function(anf_arg149243278) {
return $Hanf_arg882343279(anf_arg149243278,INDENT118169,PP170,self6729809,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e4326843269.stack[R.EXN_STACKHEIGHT++] = $ss4327243273;
}
if(R.isPyretException($e4326843269)) {
$e4326843269.pyretStack.push(L[4663]);
}
throw $e4326843269;
}
var $ret4327443275 = $Hanf_arg882343279($z4327043271,INDENT118169,PP170,self6729809,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4327443275;
};
var $Hanf_arg882343279 = function(anf_arg149243278,INDENT118169,PP170,self6729809,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z4328243283 = D;
var $f4328843289 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg149243278,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4664],_plus55,[anf_arg149243278,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z4328243283 = $f4328843289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4328843289,
"from":L[4664]});
}
} catch($e4328043281) {
if(R.isCont($e4328043281)) {
var $ss4328443285 = {"from":L[4664],
"go":function(header67343290) {
return $Hheader882243291(header67343290,INDENT118169,PP170,self6729809,str_DASH_end148546);
}};
$e4328043281.stack[R.EXN_STACKHEIGHT++] = $ss4328443285;
}
if(R.isPyretException($e4328043281)) {
$e4328043281.pyretStack.push(L[4664]);
}
throw $e4328043281;
}
var $ret4328643287 = $Hheader882243291($z4328243283,INDENT118169,PP170,self6729809,str_DASH_end148546);
++R.GAS;
return $ret4328643287;
};
var $Hheader882243291 = function(header67343290,INDENT118169,PP170,self6729809,str_DASH_end148546) {
var anf_fun149343304 = G(PP170,"surround",L[4668]);
var anf_bracket149443306 = G(self6729809,"body",L[4667]);
var anf_fun149543302 = G(anf_bracket149443306,"tosource",L[4666]);
var $z4329443295 = D;
var $f4330043301 = function(_) {
return R.isFunction(anf_fun149543302)?anf_fun149543302.app():R.ffi.throwNonFunApp(L[4665],anf_fun149543302,[]);
};
try {
if(--R.GAS > 0) {
$z4329443295 = $f4330043301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4330043301,
"from":L[4665]});
}
} catch($e4329243293) {
if(R.isCont($e4329243293)) {
var $ss4329643297 = {"from":L[4665],
"go":function(anf_arg149643303) {
return $Hanf_arg882143305(anf_arg149643303,INDENT118169,anf_fun149343304,header67343290,str_DASH_end148546);
}};
$e4329243293.stack[R.EXN_STACKHEIGHT++] = $ss4329643297;
}
if(R.isPyretException($e4329243293)) {
$e4329243293.pyretStack.push(L[4665]);
}
throw $e4329243293;
}
var $ret4329843299 = $Hanf_arg882143305($z4329443295,INDENT118169,anf_fun149343304,header67343290,str_DASH_end148546);
++R.GAS;
return $ret4329843299;
};
var $Hanf_arg882143305 = function(anf_arg149643303,INDENT118169,anf_fun149343304,header67343290,str_DASH_end148546) {
var $z4330943310 = D;
var $f4331543316 = function(_) {
return R.isFunction(anf_fun149343304)?anf_fun149343304.app(INDENT118169,(1),header67343290,anf_arg149643303,str_DASH_end148546):R.ffi.throwNonFunApp(L[2998],anf_fun149343304,[INDENT118169,(1),header67343290,anf_arg149643303,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4330943310 = $f4331543316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4331543316,
"from":L[2998]});
}
} catch($e4330743308) {
if(R.isCont($e4330743308)) {
var $ss4331143312 = {"from":L[2998],
"go":function(ann_DASH_check_DASH_temp147843317) {
return $Hann_DASH_check_DASH_temp882043318(ann_DASH_check_DASH_temp147843317);
}};
$e4330743308.stack[R.EXN_STACKHEIGHT++] = $ss4331143312;
}
if(R.isPyretException($e4330743308)) {
$e4330743308.pyretStack.push(L[2998]);
}
throw $e4330743308;
}
var $ret4331343314 = $Hann_DASH_check_DASH_temp882043318($z4330943310);
++R.GAS;
return $ret4331343314;
};
var $Hann_DASH_check_DASH_temp882043318 = function(ann_DASH_check_DASH_temp147843317) {
return ann_DASH_check_DASH_temp147843317;
};
var $Hann_DASH_check_DASH_temp881943266 = function(ann_DASH_check_DASH_temp148843265) {
return ann_DASH_check_DASH_temp148843265;
};
var $Hanf_arg881816568 = function(anf_arg146416566,self18016567,_plus55,torepr65) {
var anf_arg146543329 = G(self18016567,"binds",L[2267]);
var $z4332143322 = D;
var $f4332743328 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg146543329):R.ffi.throwNonFunApp(L[2267],torepr65,[anf_arg146543329]);
};
try {
if(--R.GAS > 0) {
$z4332143322 = $f4332743328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4332743328,
"from":L[2267]});
}
} catch($e4331943320) {
if(R.isCont($e4331943320)) {
var $ss4332343324 = {"from":L[2267],
"go":function(anf_arg146643330) {
return $Hanf_arg881743331(anf_arg146643330,anf_arg146416566,self18016567,_plus55,torepr65);
}};
$e4331943320.stack[R.EXN_STACKHEIGHT++] = $ss4332343324;
}
if(R.isPyretException($e4331943320)) {
$e4331943320.pyretStack.push(L[2267]);
}
throw $e4331943320;
}
var $ret4332543326 = $Hanf_arg881743331($z4332143322,anf_arg146416566,self18016567,_plus55,torepr65);
++R.GAS;
return $ret4332543326;
};
var $Hanf_arg881743331 = function(anf_arg146643330,anf_arg146416566,self18016567,_plus55,torepr65) {
var $z4333443335 = D;
var $f4334043341 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg146643330):R.ffi.throwNonFunApp(L[2267],_plus55,[(", "),anf_arg146643330]);
};
try {
if(--R.GAS > 0) {
$z4333443335 = $f4334043341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4334043341,
"from":L[2267]});
}
} catch($e4333243333) {
if(R.isCont($e4333243333)) {
var $ss4333643337 = {"from":L[2267],
"go":function(anf_arg146743342) {
return $Hanf_arg881643343(anf_arg146743342,anf_arg146416566,self18016567,_plus55,torepr65);
}};
$e4333243333.stack[R.EXN_STACKHEIGHT++] = $ss4333643337;
}
if(R.isPyretException($e4333243333)) {
$e4333243333.pyretStack.push(L[2267]);
}
throw $e4333243333;
}
var $ret4333843339 = $Hanf_arg881643343($z4333443335,anf_arg146416566,self18016567,_plus55,torepr65);
++R.GAS;
return $ret4333843339;
};
var $Hanf_arg881643343 = function(anf_arg146743342,anf_arg146416566,self18016567,_plus55,torepr65) {
var $z4334643347 = D;
var $f4335243353 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg146416566,anf_arg146743342):R.ffi.throwNonFunApp(L[2267],_plus55,[anf_arg146416566,anf_arg146743342]);
};
try {
if(--R.GAS > 0) {
$z4334643347 = $f4335243353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4335243353,
"from":L[2267]});
}
} catch($e4334443345) {
if(R.isCont($e4334443345)) {
var $ss4334843349 = {"from":L[2267],
"go":function(anf_arg146843354) {
return $Hanf_arg881543355(anf_arg146843354,self18016567,_plus55,torepr65);
}};
$e4334443345.stack[R.EXN_STACKHEIGHT++] = $ss4334843349;
}
if(R.isPyretException($e4334443345)) {
$e4334443345.pyretStack.push(L[2267]);
}
throw $e4334443345;
}
var $ret4335043351 = $Hanf_arg881543355($z4334643347,self18016567,_plus55,torepr65);
++R.GAS;
return $ret4335043351;
};
var $Hanf_arg881543355 = function(anf_arg146843354,self18016567,_plus55,torepr65) {
var anf_arg146943366 = G(self18016567,"body",L[2267]);
var $z4335843359 = D;
var $f4336443365 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg146943366):R.ffi.throwNonFunApp(L[2267],torepr65,[anf_arg146943366]);
};
try {
if(--R.GAS > 0) {
$z4335843359 = $f4336443365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4336443365,
"from":L[2267]});
}
} catch($e4335643357) {
if(R.isCont($e4335643357)) {
var $ss4336043361 = {"from":L[2267],
"go":function(anf_arg147043367) {
return $Hanf_arg881443368(anf_arg147043367,anf_arg146843354,_plus55);
}};
$e4335643357.stack[R.EXN_STACKHEIGHT++] = $ss4336043361;
}
if(R.isPyretException($e4335643357)) {
$e4335643357.pyretStack.push(L[2267]);
}
throw $e4335643357;
}
var $ret4336243363 = $Hanf_arg881443368($z4335843359,anf_arg146843354,_plus55);
++R.GAS;
return $ret4336243363;
};
var $Hanf_arg881443368 = function(anf_arg147043367,anf_arg146843354,_plus55) {
var $z4337143372 = D;
var $f4337743378 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg147043367):R.ffi.throwNonFunApp(L[2267],_plus55,[(", "),anf_arg147043367]);
};
try {
if(--R.GAS > 0) {
$z4337143372 = $f4337743378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4337743378,
"from":L[2267]});
}
} catch($e4336943370) {
if(R.isCont($e4336943370)) {
var $ss4337343374 = {"from":L[2267],
"go":function(anf_arg147143379) {
return $Hanf_arg881343380(anf_arg147143379,anf_arg146843354,_plus55);
}};
$e4336943370.stack[R.EXN_STACKHEIGHT++] = $ss4337343374;
}
if(R.isPyretException($e4336943370)) {
$e4336943370.pyretStack.push(L[2267]);
}
throw $e4336943370;
}
var $ret4337543376 = $Hanf_arg881343380($z4337143372,anf_arg146843354,_plus55);
++R.GAS;
return $ret4337543376;
};
var $Hanf_arg881343380 = function(anf_arg147143379,anf_arg146843354,_plus55) {
var $z4338343384 = D;
var $f4338943390 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg146843354,anf_arg147143379):R.ffi.throwNonFunApp(L[2267],_plus55,[anf_arg146843354,anf_arg147143379]);
};
try {
if(--R.GAS > 0) {
$z4338343384 = $f4338943390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4338943390,
"from":L[2267]});
}
} catch($e4338143382) {
if(R.isCont($e4338143382)) {
var $ss4338543386 = {"from":L[2267],
"go":function(anf_arg147243391) {
return $Hanf_arg881243392(anf_arg147243391,_plus55);
}};
$e4338143382.stack[R.EXN_STACKHEIGHT++] = $ss4338543386;
}
if(R.isPyretException($e4338143382)) {
$e4338143382.pyretStack.push(L[2267]);
}
throw $e4338143382;
}
var $ret4338743388 = $Hanf_arg881243392($z4338343384,_plus55);
++R.GAS;
return $ret4338743388;
};
var $Hanf_arg881243392 = function(anf_arg147243391,_plus55) {
var $z4339543396 = D;
var $f4340143402 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg147243391,(")")):R.ffi.throwNonFunApp(L[2267],_plus55,[anf_arg147243391,(")")]);
};
try {
if(--R.GAS > 0) {
$z4339543396 = $f4340143402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4340143402,
"from":L[2267]});
}
} catch($e4339343394) {
if(R.isCont($e4339343394)) {
var $ss4339743398 = {"from":L[2267],
"go":function(anf_arg147343403) {
return $Hanf_arg881143404(anf_arg147343403,_plus55);
}};
$e4339343394.stack[R.EXN_STACKHEIGHT++] = $ss4339743398;
}
if(R.isPyretException($e4339343394)) {
$e4339343394.pyretStack.push(L[2267]);
}
throw $e4339343394;
}
var $ret4339943400 = $Hanf_arg881143404($z4339543396,_plus55);
++R.GAS;
return $ret4339943400;
};
var $Hanf_arg881143404 = function(anf_arg147343403,_plus55) {
var $z4340743408 = D;
var $f4341343414 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg147343403):R.ffi.throwNonFunApp(L[2267],_plus55,[("("),anf_arg147343403]);
};
try {
if(--R.GAS > 0) {
$z4340743408 = $f4341343414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4341343414,
"from":L[2267]});
}
} catch($e4340543406) {
if(R.isCont($e4340543406)) {
var $ss4340943410 = {"from":L[2267],
"go":function(anf_arg147443415) {
return $Hanf_arg881043416(anf_arg147443415,_plus55);
}};
$e4340543406.stack[R.EXN_STACKHEIGHT++] = $ss4340943410;
}
if(R.isPyretException($e4340543406)) {
$e4340543406.pyretStack.push(L[2267]);
}
throw $e4340543406;
}
var $ret4341143412 = $Hanf_arg881043416($z4340743408,_plus55);
++R.GAS;
return $ret4341143412;
};
var $Hanf_arg881043416 = function(anf_arg147443415,_plus55) {
var $z4341943420 = D;
var $f4342543426 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-letrec"),anf_arg147443415):R.ffi.throwNonFunApp(L[2267],_plus55,[("s-letrec"),anf_arg147443415]);
};
try {
if(--R.GAS > 0) {
$z4341943420 = $f4342543426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4342543426,
"from":L[2267]});
}
} catch($e4341743418) {
if(R.isCont($e4341743418)) {
var $ss4342143422 = {"from":L[2267],
"go":function(ann_DASH_check_DASH_temp146243427) {
return $Hann_DASH_check_DASH_temp880943428(ann_DASH_check_DASH_temp146243427);
}};
$e4341743418.stack[R.EXN_STACKHEIGHT++] = $ss4342143422;
}
if(R.isPyretException($e4341743418)) {
$e4341743418.pyretStack.push(L[2267]);
}
throw $e4341743418;
}
var $ret4342343424 = $Hann_DASH_check_DASH_temp880943428($z4341943420);
++R.GAS;
return $ret4342343424;
};
var $Hann_DASH_check_DASH_temp880943428 = function(ann_DASH_check_DASH_temp146243427) {
return ann_DASH_check_DASH_temp146243427;
};
var $Hcont_tail_arg880716585 = function(cont_tail_arg145916583,if_helper144916584) {
if(--R.GAS > 0) {
$z4342943430 = R.isFunction(if_helper144916584)?if_helper144916584.app(cont_tail_arg145916583):R.ffi.throwNonFunApp(L[2267],if_helper144916584,[cont_tail_arg145916583]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper144916584)?if_helper144916584.app(cont_tail_arg145916583):R.ffi.throwNonFunApp(L[2267],if_helper144916584,[cont_tail_arg145916583]);
},
"from":L[2267]});
}
++R.GAS;
return $z4342943430;
};
var $Hcont_tail_arg880816600 = function(cont_tail_arg145416599,if_helper144916584) {
if(--R.GAS > 0) {
$z4343143432 = R.isFunction(if_helper144916584)?if_helper144916584.app(cont_tail_arg145416599):R.ffi.throwNonFunApp(L[2267],if_helper144916584,[cont_tail_arg145416599]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper144916584)?if_helper144916584.app(cont_tail_arg145416599):R.ffi.throwNonFunApp(L[2267],if_helper144916584,[cont_tail_arg145416599]);
},
"from":L[2267]});
}
++R.GAS;
return $z4343143432;
};
var $Hanf_arg880616621 = function(anf_arg143016618,INDENT118169,PP170,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55) {
var anf_fun143143443 = G(PP170,"str",L[4670]);
var $z4343543436 = D;
var $f4344143442 = function(_) {
return R.isFunction(anf_fun143143443)?anf_fun143143443.app((" ")):R.ffi.throwNonFunApp(L[4669],anf_fun143143443,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z4343543436 = $f4344143442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4344143442,
"from":L[4669]});
}
} catch($e4343343434) {
if(R.isCont($e4343343434)) {
var $ss4343743438 = {"from":L[4669],
"go":function(anf_arg143243444) {
return $Hanf_arg880543445(anf_arg143243444,INDENT118169,PP170,anf_arg143016618,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55);
}};
$e4343343434.stack[R.EXN_STACKHEIGHT++] = $ss4343743438;
}
if(R.isPyretException($e4343343434)) {
$e4343343434.pyretStack.push(L[4669]);
}
throw $e4343343434;
}
var $ret4343943440 = $Hanf_arg880543445($z4343543436,INDENT118169,PP170,anf_arg143016618,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55);
++R.GAS;
return $ret4343943440;
};
var $Hanf_arg880543445 = function(anf_arg143243444,INDENT118169,PP170,anf_arg143016618,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55) {
var $z4344843449 = D;
var $f4345443455 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_let125247,anf_arg143243444):R.ffi.throwNonFunApp(L[4671],_plus55,[str_DASH_let125247,anf_arg143243444]);
};
try {
if(--R.GAS > 0) {
$z4344843449 = $f4345443455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4345443455,
"from":L[4671]});
}
} catch($e4344643447) {
if(R.isCont($e4344643447)) {
var $ss4345043451 = {"from":L[4671],
"go":function(anf_arg143343456) {
return $Hanf_arg880443457(anf_arg143343456,INDENT118169,PP170,anf_arg143016618,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55);
}};
$e4344643447.stack[R.EXN_STACKHEIGHT++] = $ss4345043451;
}
if(R.isPyretException($e4344643447)) {
$e4344643447.pyretStack.push(L[4671]);
}
throw $e4344643447;
}
var $ret4345243453 = $Hanf_arg880443457($z4344843449,INDENT118169,PP170,anf_arg143016618,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55);
++R.GAS;
return $ret4345243453;
};
var $Hanf_arg880443457 = function(anf_arg143343456,INDENT118169,PP170,anf_arg143016618,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55) {
var anf_arg143443471 = G(PP170,"commabreak",L[4677]);
var anf_arg143543472 = G(PP170,"mt-doc",L[4676]);
var anf_bracket143643488 = G(self66616620,"binds",L[4675]);
var anf_fun143743468 = G(anf_bracket143643488,"map",L[4674]);
var anf_arg144043469 = R.makeFunction(function(recv_DASH_17543474) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4673],1,arguments);
}
var anf_fun143943485 = G(recv_DASH_17543474,"tosource",L[4673]);
var $z4347743478 = D;
var $f4348343484 = function(_) {
return R.isFunction(anf_fun143943485)?anf_fun143943485.app():R.ffi.throwNonFunApp(L[4673],anf_fun143943485,[]);
};
try {
if(--R.GAS > 0) {
$z4347743478 = $f4348343484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4348343484,
"from":L[4673]});
}
} catch($e4347543476) {
if(R.isCont($e4347543476)) {
var $ss4347943480 = {"from":L[4673],
"go":function(ann_DASH_check_DASH_temp143843486) {
return $Hann_DASH_check_DASH_temp879843487(ann_DASH_check_DASH_temp143843486);
}};
$e4347543476.stack[R.EXN_STACKHEIGHT++] = $ss4347943480;
}
if(R.isPyretException($e4347543476)) {
$e4347543476.pyretStack.push(L[4673]);
}
throw $e4347543476;
}
var $ret4348143482 = $Hann_DASH_check_DASH_temp879843487($z4347743478);
++R.GAS;
return $ret4348143482;
});
var $z4346043461 = D;
var $f4346643467 = function(_) {
return R.isFunction(anf_fun143743468)?anf_fun143743468.app(anf_arg144043469):R.ffi.throwNonFunApp(L[4672],anf_fun143743468,[anf_arg144043469]);
};
try {
if(--R.GAS > 0) {
$z4346043461 = $f4346643467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4346643467,
"from":L[4672]});
}
} catch($e4345843459) {
if(R.isCont($e4345843459)) {
var $ss4346243463 = {"from":L[4672],
"go":function(anf_arg144143470) {
return $Hanf_arg880343473(anf_arg144143470,INDENT118169,PP170,anf_arg143016618,anf_arg143343456,anf_arg143443471,anf_arg143543472,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55);
}};
$e4345843459.stack[R.EXN_STACKHEIGHT++] = $ss4346243463;
}
if(R.isPyretException($e4345843459)) {
$e4345843459.pyretStack.push(L[4672]);
}
throw $e4345843459;
}
var $ret4346443465 = $Hanf_arg880343473($z4346043461,INDENT118169,PP170,anf_arg143016618,anf_arg143343456,anf_arg143443471,anf_arg143543472,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55);
++R.GAS;
return $ret4346443465;
};
var $Hanf_arg880343473 = function(anf_arg144143470,INDENT118169,PP170,anf_arg143016618,anf_arg143343456,anf_arg143443471,anf_arg143543472,anf_fun142916619,self66616620,str_DASH_colon134364,str_DASH_end148546,str_DASH_let125247,_plus55) {
var $z4349143492 = D;
var $f4349743498 = function(_) {
return R.isFunction(anf_fun142916619)?anf_fun142916619.app(anf_arg143016618,(1),str_DASH_let125247,anf_arg143343456,anf_arg143443471,anf_arg143543472,anf_arg144143470):R.ffi.throwNonFunApp(L[4678],anf_fun142916619,[anf_arg143016618,(1),str_DASH_let125247,anf_arg143343456,anf_arg143443471,anf_arg143543472,anf_arg144143470]);
};
try {
if(--R.GAS > 0) {
$z4349143492 = $f4349743498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4349743498,
"from":L[4678]});
}
} catch($e4348943490) {
if(R.isCont($e4348943490)) {
var $ss4349343494 = {"from":L[4678],
"go":function(anf_arg144243499) {
return $Hanf_arg880243500(anf_arg144243499,INDENT118169,PP170,self66616620,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e4348943490.stack[R.EXN_STACKHEIGHT++] = $ss4349343494;
}
if(R.isPyretException($e4348943490)) {
$e4348943490.pyretStack.push(L[4678]);
}
throw $e4348943490;
}
var $ret4349543496 = $Hanf_arg880243500($z4349143492,INDENT118169,PP170,self66616620,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4349543496;
};
var $Hanf_arg880243500 = function(anf_arg144243499,INDENT118169,PP170,self66616620,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z4350343504 = D;
var $f4350943510 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg144243499,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4679],_plus55,[anf_arg144243499,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z4350343504 = $f4350943510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4350943510,
"from":L[4679]});
}
} catch($e4350143502) {
if(R.isCont($e4350143502)) {
var $ss4350543506 = {"from":L[4679],
"go":function(header66743511) {
return $Hheader880143512(header66743511,INDENT118169,PP170,self66616620,str_DASH_end148546);
}};
$e4350143502.stack[R.EXN_STACKHEIGHT++] = $ss4350543506;
}
if(R.isPyretException($e4350143502)) {
$e4350143502.pyretStack.push(L[4679]);
}
throw $e4350143502;
}
var $ret4350743508 = $Hheader880143512($z4350343504,INDENT118169,PP170,self66616620,str_DASH_end148546);
++R.GAS;
return $ret4350743508;
};
var $Hheader880143512 = function(header66743511,INDENT118169,PP170,self66616620,str_DASH_end148546) {
var anf_fun144343525 = G(PP170,"surround",L[4683]);
var anf_bracket144443527 = G(self66616620,"body",L[4682]);
var anf_fun144543523 = G(anf_bracket144443527,"tosource",L[4681]);
var $z4351543516 = D;
var $f4352143522 = function(_) {
return R.isFunction(anf_fun144543523)?anf_fun144543523.app():R.ffi.throwNonFunApp(L[4680],anf_fun144543523,[]);
};
try {
if(--R.GAS > 0) {
$z4351543516 = $f4352143522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4352143522,
"from":L[4680]});
}
} catch($e4351343514) {
if(R.isCont($e4351343514)) {
var $ss4351743518 = {"from":L[4680],
"go":function(anf_arg144643524) {
return $Hanf_arg880043526(anf_arg144643524,INDENT118169,anf_fun144343525,header66743511,str_DASH_end148546);
}};
$e4351343514.stack[R.EXN_STACKHEIGHT++] = $ss4351743518;
}
if(R.isPyretException($e4351343514)) {
$e4351343514.pyretStack.push(L[4680]);
}
throw $e4351343514;
}
var $ret4351943520 = $Hanf_arg880043526($z4351543516,INDENT118169,anf_fun144343525,header66743511,str_DASH_end148546);
++R.GAS;
return $ret4351943520;
};
var $Hanf_arg880043526 = function(anf_arg144643524,INDENT118169,anf_fun144343525,header66743511,str_DASH_end148546) {
var $z4353043531 = D;
var $f4353643537 = function(_) {
return R.isFunction(anf_fun144343525)?anf_fun144343525.app(INDENT118169,(1),header66743511,anf_arg144643524,str_DASH_end148546):R.ffi.throwNonFunApp(L[3005],anf_fun144343525,[INDENT118169,(1),header66743511,anf_arg144643524,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4353043531 = $f4353643537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4353643537,
"from":L[3005]});
}
} catch($e4352843529) {
if(R.isCont($e4352843529)) {
var $ss4353243533 = {"from":L[3005],
"go":function(ann_DASH_check_DASH_temp142843538) {
return $Hann_DASH_check_DASH_temp879943539(ann_DASH_check_DASH_temp142843538);
}};
$e4352843529.stack[R.EXN_STACKHEIGHT++] = $ss4353243533;
}
if(R.isPyretException($e4352843529)) {
$e4352843529.pyretStack.push(L[3005]);
}
throw $e4352843529;
}
var $ret4353443535 = $Hann_DASH_check_DASH_temp879943539($z4353043531);
++R.GAS;
return $ret4353443535;
};
var $Hann_DASH_check_DASH_temp879943539 = function(ann_DASH_check_DASH_temp142843538) {
return ann_DASH_check_DASH_temp142843538;
};
var $Hann_DASH_check_DASH_temp879843487 = function(ann_DASH_check_DASH_temp143843486) {
return ann_DASH_check_DASH_temp143843486;
};
var $Hanf_arg879716637 = function(anf_arg141416635,self17316636,_plus55,torepr65) {
var anf_arg141543550 = G(self17316636,"binds",L[2268]);
var $z4354243543 = D;
var $f4354843549 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg141543550):R.ffi.throwNonFunApp(L[2268],torepr65,[anf_arg141543550]);
};
try {
if(--R.GAS > 0) {
$z4354243543 = $f4354843549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4354843549,
"from":L[2268]});
}
} catch($e4354043541) {
if(R.isCont($e4354043541)) {
var $ss4354443545 = {"from":L[2268],
"go":function(anf_arg141643551) {
return $Hanf_arg879643552(anf_arg141643551,anf_arg141416635,self17316636,_plus55,torepr65);
}};
$e4354043541.stack[R.EXN_STACKHEIGHT++] = $ss4354443545;
}
if(R.isPyretException($e4354043541)) {
$e4354043541.pyretStack.push(L[2268]);
}
throw $e4354043541;
}
var $ret4354643547 = $Hanf_arg879643552($z4354243543,anf_arg141416635,self17316636,_plus55,torepr65);
++R.GAS;
return $ret4354643547;
};
var $Hanf_arg879643552 = function(anf_arg141643551,anf_arg141416635,self17316636,_plus55,torepr65) {
var $z4355543556 = D;
var $f4356143562 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg141643551):R.ffi.throwNonFunApp(L[2268],_plus55,[(", "),anf_arg141643551]);
};
try {
if(--R.GAS > 0) {
$z4355543556 = $f4356143562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4356143562,
"from":L[2268]});
}
} catch($e4355343554) {
if(R.isCont($e4355343554)) {
var $ss4355743558 = {"from":L[2268],
"go":function(anf_arg141743563) {
return $Hanf_arg879543564(anf_arg141743563,anf_arg141416635,self17316636,_plus55,torepr65);
}};
$e4355343554.stack[R.EXN_STACKHEIGHT++] = $ss4355743558;
}
if(R.isPyretException($e4355343554)) {
$e4355343554.pyretStack.push(L[2268]);
}
throw $e4355343554;
}
var $ret4355943560 = $Hanf_arg879543564($z4355543556,anf_arg141416635,self17316636,_plus55,torepr65);
++R.GAS;
return $ret4355943560;
};
var $Hanf_arg879543564 = function(anf_arg141743563,anf_arg141416635,self17316636,_plus55,torepr65) {
var $z4356743568 = D;
var $f4357343574 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg141416635,anf_arg141743563):R.ffi.throwNonFunApp(L[2268],_plus55,[anf_arg141416635,anf_arg141743563]);
};
try {
if(--R.GAS > 0) {
$z4356743568 = $f4357343574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4357343574,
"from":L[2268]});
}
} catch($e4356543566) {
if(R.isCont($e4356543566)) {
var $ss4356943570 = {"from":L[2268],
"go":function(anf_arg141843575) {
return $Hanf_arg879443576(anf_arg141843575,self17316636,_plus55,torepr65);
}};
$e4356543566.stack[R.EXN_STACKHEIGHT++] = $ss4356943570;
}
if(R.isPyretException($e4356543566)) {
$e4356543566.pyretStack.push(L[2268]);
}
throw $e4356543566;
}
var $ret4357143572 = $Hanf_arg879443576($z4356743568,self17316636,_plus55,torepr65);
++R.GAS;
return $ret4357143572;
};
var $Hanf_arg879443576 = function(anf_arg141843575,self17316636,_plus55,torepr65) {
var anf_arg141943587 = G(self17316636,"body",L[2268]);
var $z4357943580 = D;
var $f4358543586 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg141943587):R.ffi.throwNonFunApp(L[2268],torepr65,[anf_arg141943587]);
};
try {
if(--R.GAS > 0) {
$z4357943580 = $f4358543586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4358543586,
"from":L[2268]});
}
} catch($e4357743578) {
if(R.isCont($e4357743578)) {
var $ss4358143582 = {"from":L[2268],
"go":function(anf_arg142043588) {
return $Hanf_arg879343589(anf_arg142043588,anf_arg141843575,_plus55);
}};
$e4357743578.stack[R.EXN_STACKHEIGHT++] = $ss4358143582;
}
if(R.isPyretException($e4357743578)) {
$e4357743578.pyretStack.push(L[2268]);
}
throw $e4357743578;
}
var $ret4358343584 = $Hanf_arg879343589($z4357943580,anf_arg141843575,_plus55);
++R.GAS;
return $ret4358343584;
};
var $Hanf_arg879343589 = function(anf_arg142043588,anf_arg141843575,_plus55) {
var $z4359243593 = D;
var $f4359843599 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg142043588):R.ffi.throwNonFunApp(L[2268],_plus55,[(", "),anf_arg142043588]);
};
try {
if(--R.GAS > 0) {
$z4359243593 = $f4359843599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4359843599,
"from":L[2268]});
}
} catch($e4359043591) {
if(R.isCont($e4359043591)) {
var $ss4359443595 = {"from":L[2268],
"go":function(anf_arg142143600) {
return $Hanf_arg879243601(anf_arg142143600,anf_arg141843575,_plus55);
}};
$e4359043591.stack[R.EXN_STACKHEIGHT++] = $ss4359443595;
}
if(R.isPyretException($e4359043591)) {
$e4359043591.pyretStack.push(L[2268]);
}
throw $e4359043591;
}
var $ret4359643597 = $Hanf_arg879243601($z4359243593,anf_arg141843575,_plus55);
++R.GAS;
return $ret4359643597;
};
var $Hanf_arg879243601 = function(anf_arg142143600,anf_arg141843575,_plus55) {
var $z4360443605 = D;
var $f4361043611 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg141843575,anf_arg142143600):R.ffi.throwNonFunApp(L[2268],_plus55,[anf_arg141843575,anf_arg142143600]);
};
try {
if(--R.GAS > 0) {
$z4360443605 = $f4361043611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4361043611,
"from":L[2268]});
}
} catch($e4360243603) {
if(R.isCont($e4360243603)) {
var $ss4360643607 = {"from":L[2268],
"go":function(anf_arg142243612) {
return $Hanf_arg879143613(anf_arg142243612,_plus55);
}};
$e4360243603.stack[R.EXN_STACKHEIGHT++] = $ss4360643607;
}
if(R.isPyretException($e4360243603)) {
$e4360243603.pyretStack.push(L[2268]);
}
throw $e4360243603;
}
var $ret4360843609 = $Hanf_arg879143613($z4360443605,_plus55);
++R.GAS;
return $ret4360843609;
};
var $Hanf_arg879143613 = function(anf_arg142243612,_plus55) {
var $z4361643617 = D;
var $f4362243623 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg142243612,(")")):R.ffi.throwNonFunApp(L[2268],_plus55,[anf_arg142243612,(")")]);
};
try {
if(--R.GAS > 0) {
$z4361643617 = $f4362243623();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4362243623,
"from":L[2268]});
}
} catch($e4361443615) {
if(R.isCont($e4361443615)) {
var $ss4361843619 = {"from":L[2268],
"go":function(anf_arg142343624) {
return $Hanf_arg879043625(anf_arg142343624,_plus55);
}};
$e4361443615.stack[R.EXN_STACKHEIGHT++] = $ss4361843619;
}
if(R.isPyretException($e4361443615)) {
$e4361443615.pyretStack.push(L[2268]);
}
throw $e4361443615;
}
var $ret4362043621 = $Hanf_arg879043625($z4361643617,_plus55);
++R.GAS;
return $ret4362043621;
};
var $Hanf_arg879043625 = function(anf_arg142343624,_plus55) {
var $z4362843629 = D;
var $f4363443635 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg142343624):R.ffi.throwNonFunApp(L[2268],_plus55,[("("),anf_arg142343624]);
};
try {
if(--R.GAS > 0) {
$z4362843629 = $f4363443635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4363443635,
"from":L[2268]});
}
} catch($e4362643627) {
if(R.isCont($e4362643627)) {
var $ss4363043631 = {"from":L[2268],
"go":function(anf_arg142443636) {
return $Hanf_arg878943637(anf_arg142443636,_plus55);
}};
$e4362643627.stack[R.EXN_STACKHEIGHT++] = $ss4363043631;
}
if(R.isPyretException($e4362643627)) {
$e4362643627.pyretStack.push(L[2268]);
}
throw $e4362643627;
}
var $ret4363243633 = $Hanf_arg878943637($z4362843629,_plus55);
++R.GAS;
return $ret4363243633;
};
var $Hanf_arg878943637 = function(anf_arg142443636,_plus55) {
var $z4364043641 = D;
var $f4364643647 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-let-expr"),anf_arg142443636):R.ffi.throwNonFunApp(L[2268],_plus55,[("s-let-expr"),anf_arg142443636]);
};
try {
if(--R.GAS > 0) {
$z4364043641 = $f4364643647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4364643647,
"from":L[2268]});
}
} catch($e4363843639) {
if(R.isCont($e4363843639)) {
var $ss4364243643 = {"from":L[2268],
"go":function(ann_DASH_check_DASH_temp141243648) {
return $Hann_DASH_check_DASH_temp878843649(ann_DASH_check_DASH_temp141243648);
}};
$e4363843639.stack[R.EXN_STACKHEIGHT++] = $ss4364243643;
}
if(R.isPyretException($e4363843639)) {
$e4363843639.pyretStack.push(L[2268]);
}
throw $e4363843639;
}
var $ret4364443645 = $Hann_DASH_check_DASH_temp878843649($z4364043641);
++R.GAS;
return $ret4364443645;
};
var $Hann_DASH_check_DASH_temp878843649 = function(ann_DASH_check_DASH_temp141243648) {
return ann_DASH_check_DASH_temp141243648;
};
var $Hcont_tail_arg878616654 = function(cont_tail_arg140916652,if_helper139916653) {
if(--R.GAS > 0) {
$z4365043651 = R.isFunction(if_helper139916653)?if_helper139916653.app(cont_tail_arg140916652):R.ffi.throwNonFunApp(L[2268],if_helper139916653,[cont_tail_arg140916652]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper139916653)?if_helper139916653.app(cont_tail_arg140916652):R.ffi.throwNonFunApp(L[2268],if_helper139916653,[cont_tail_arg140916652]);
},
"from":L[2268]});
}
++R.GAS;
return $z4365043651;
};
var $Hcont_tail_arg878716669 = function(cont_tail_arg140416668,if_helper139916653) {
if(--R.GAS > 0) {
$z4365243653 = R.isFunction(if_helper139916653)?if_helper139916653.app(cont_tail_arg140416668):R.ffi.throwNonFunApp(L[2268],if_helper139916653,[cont_tail_arg140416668]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper139916653)?if_helper139916653.app(cont_tail_arg140416668):R.ffi.throwNonFunApp(L[2268],if_helper139916653,[cont_tail_arg140416668]);
},
"from":L[2268]});
}
++R.GAS;
return $z4365243653;
};
var $Hanf_arg878516690 = function(anf_arg138016687,INDENT118169,PP170,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55) {
var anf_fun138143664 = G(PP170,"str",L[4685]);
var $z4365643657 = D;
var $f4366243663 = function(_) {
return R.isFunction(anf_fun138143664)?anf_fun138143664.app((" ")):R.ffi.throwNonFunApp(L[4684],anf_fun138143664,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z4365643657 = $f4366243663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4366243663,
"from":L[4684]});
}
} catch($e4365443655) {
if(R.isCont($e4365443655)) {
var $ss4365843659 = {"from":L[4684],
"go":function(anf_arg138243665) {
return $Hanf_arg878443666(anf_arg138243665,INDENT118169,PP170,anf_arg138016687,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55);
}};
$e4365443655.stack[R.EXN_STACKHEIGHT++] = $ss4365843659;
}
if(R.isPyretException($e4365443655)) {
$e4365443655.pyretStack.push(L[4684]);
}
throw $e4365443655;
}
var $ret4366043661 = $Hanf_arg878443666($z4365643657,INDENT118169,PP170,anf_arg138016687,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55);
++R.GAS;
return $ret4366043661;
};
var $Hanf_arg878443666 = function(anf_arg138243665,INDENT118169,PP170,anf_arg138016687,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55) {
var $z4366943670 = D;
var $f4367543676 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_type_DASH_let126260,anf_arg138243665):R.ffi.throwNonFunApp(L[4686],_plus55,[str_DASH_type_DASH_let126260,anf_arg138243665]);
};
try {
if(--R.GAS > 0) {
$z4366943670 = $f4367543676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4367543676,
"from":L[4686]});
}
} catch($e4366743668) {
if(R.isCont($e4366743668)) {
var $ss4367143672 = {"from":L[4686],
"go":function(anf_arg138343677) {
return $Hanf_arg878343678(anf_arg138343677,INDENT118169,PP170,anf_arg138016687,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55);
}};
$e4366743668.stack[R.EXN_STACKHEIGHT++] = $ss4367143672;
}
if(R.isPyretException($e4366743668)) {
$e4366743668.pyretStack.push(L[4686]);
}
throw $e4366743668;
}
var $ret4367343674 = $Hanf_arg878343678($z4366943670,INDENT118169,PP170,anf_arg138016687,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55);
++R.GAS;
return $ret4367343674;
};
var $Hanf_arg878343678 = function(anf_arg138343677,INDENT118169,PP170,anf_arg138016687,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55) {
var anf_arg138443692 = G(PP170,"commabreak",L[4692]);
var anf_arg138543693 = G(PP170,"mt-doc",L[4691]);
var anf_bracket138643709 = G(self66016689,"binds",L[4690]);
var anf_fun138743689 = G(anf_bracket138643709,"map",L[4689]);
var anf_arg139043690 = R.makeFunction(function(recv_DASH_16843695) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4688],1,arguments);
}
var anf_fun138943706 = G(recv_DASH_16843695,"tosource",L[4688]);
var $z4369843699 = D;
var $f4370443705 = function(_) {
return R.isFunction(anf_fun138943706)?anf_fun138943706.app():R.ffi.throwNonFunApp(L[4688],anf_fun138943706,[]);
};
try {
if(--R.GAS > 0) {
$z4369843699 = $f4370443705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4370443705,
"from":L[4688]});
}
} catch($e4369643697) {
if(R.isCont($e4369643697)) {
var $ss4370043701 = {"from":L[4688],
"go":function(ann_DASH_check_DASH_temp138843707) {
return $Hann_DASH_check_DASH_temp877743708(ann_DASH_check_DASH_temp138843707);
}};
$e4369643697.stack[R.EXN_STACKHEIGHT++] = $ss4370043701;
}
if(R.isPyretException($e4369643697)) {
$e4369643697.pyretStack.push(L[4688]);
}
throw $e4369643697;
}
var $ret4370243703 = $Hann_DASH_check_DASH_temp877743708($z4369843699);
++R.GAS;
return $ret4370243703;
});
var $z4368143682 = D;
var $f4368743688 = function(_) {
return R.isFunction(anf_fun138743689)?anf_fun138743689.app(anf_arg139043690):R.ffi.throwNonFunApp(L[4687],anf_fun138743689,[anf_arg139043690]);
};
try {
if(--R.GAS > 0) {
$z4368143682 = $f4368743688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4368743688,
"from":L[4687]});
}
} catch($e4367943680) {
if(R.isCont($e4367943680)) {
var $ss4368343684 = {"from":L[4687],
"go":function(anf_arg139143691) {
return $Hanf_arg878243694(anf_arg139143691,INDENT118169,PP170,anf_arg138016687,anf_arg138343677,anf_arg138443692,anf_arg138543693,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55);
}};
$e4367943680.stack[R.EXN_STACKHEIGHT++] = $ss4368343684;
}
if(R.isPyretException($e4367943680)) {
$e4367943680.pyretStack.push(L[4687]);
}
throw $e4367943680;
}
var $ret4368543686 = $Hanf_arg878243694($z4368143682,INDENT118169,PP170,anf_arg138016687,anf_arg138343677,anf_arg138443692,anf_arg138543693,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55);
++R.GAS;
return $ret4368543686;
};
var $Hanf_arg878243694 = function(anf_arg139143691,INDENT118169,PP170,anf_arg138016687,anf_arg138343677,anf_arg138443692,anf_arg138543693,anf_fun137916688,self66016689,str_DASH_colon134364,str_DASH_end148546,str_DASH_type_DASH_let126260,_plus55) {
var $z4371243713 = D;
var $f4371843719 = function(_) {
return R.isFunction(anf_fun137916688)?anf_fun137916688.app(anf_arg138016687,(1),str_DASH_type_DASH_let126260,anf_arg138343677,anf_arg138443692,anf_arg138543693,anf_arg139143691):R.ffi.throwNonFunApp(L[4693],anf_fun137916688,[anf_arg138016687,(1),str_DASH_type_DASH_let126260,anf_arg138343677,anf_arg138443692,anf_arg138543693,anf_arg139143691]);
};
try {
if(--R.GAS > 0) {
$z4371243713 = $f4371843719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4371843719,
"from":L[4693]});
}
} catch($e4371043711) {
if(R.isCont($e4371043711)) {
var $ss4371443715 = {"from":L[4693],
"go":function(anf_arg139243720) {
return $Hanf_arg878143721(anf_arg139243720,INDENT118169,PP170,self66016689,str_DASH_colon134364,str_DASH_end148546,_plus55);
}};
$e4371043711.stack[R.EXN_STACKHEIGHT++] = $ss4371443715;
}
if(R.isPyretException($e4371043711)) {
$e4371043711.pyretStack.push(L[4693]);
}
throw $e4371043711;
}
var $ret4371643717 = $Hanf_arg878143721($z4371243713,INDENT118169,PP170,self66016689,str_DASH_colon134364,str_DASH_end148546,_plus55);
++R.GAS;
return $ret4371643717;
};
var $Hanf_arg878143721 = function(anf_arg139243720,INDENT118169,PP170,self66016689,str_DASH_colon134364,str_DASH_end148546,_plus55) {
var $z4372443725 = D;
var $f4373043731 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg139243720,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4694],_plus55,[anf_arg139243720,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z4372443725 = $f4373043731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4373043731,
"from":L[4694]});
}
} catch($e4372243723) {
if(R.isCont($e4372243723)) {
var $ss4372643727 = {"from":L[4694],
"go":function(header66143732) {
return $Hheader878043733(header66143732,INDENT118169,PP170,self66016689,str_DASH_end148546);
}};
$e4372243723.stack[R.EXN_STACKHEIGHT++] = $ss4372643727;
}
if(R.isPyretException($e4372243723)) {
$e4372243723.pyretStack.push(L[4694]);
}
throw $e4372243723;
}
var $ret4372843729 = $Hheader878043733($z4372443725,INDENT118169,PP170,self66016689,str_DASH_end148546);
++R.GAS;
return $ret4372843729;
};
var $Hheader878043733 = function(header66143732,INDENT118169,PP170,self66016689,str_DASH_end148546) {
var anf_fun139343746 = G(PP170,"surround",L[4698]);
var anf_bracket139443748 = G(self66016689,"body",L[4697]);
var anf_fun139543744 = G(anf_bracket139443748,"tosource",L[4696]);
var $z4373643737 = D;
var $f4374243743 = function(_) {
return R.isFunction(anf_fun139543744)?anf_fun139543744.app():R.ffi.throwNonFunApp(L[4695],anf_fun139543744,[]);
};
try {
if(--R.GAS > 0) {
$z4373643737 = $f4374243743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4374243743,
"from":L[4695]});
}
} catch($e4373443735) {
if(R.isCont($e4373443735)) {
var $ss4373843739 = {"from":L[4695],
"go":function(anf_arg139643745) {
return $Hanf_arg877943747(anf_arg139643745,INDENT118169,anf_fun139343746,header66143732,str_DASH_end148546);
}};
$e4373443735.stack[R.EXN_STACKHEIGHT++] = $ss4373843739;
}
if(R.isPyretException($e4373443735)) {
$e4373443735.pyretStack.push(L[4695]);
}
throw $e4373443735;
}
var $ret4374043741 = $Hanf_arg877943747($z4373643737,INDENT118169,anf_fun139343746,header66143732,str_DASH_end148546);
++R.GAS;
return $ret4374043741;
};
var $Hanf_arg877943747 = function(anf_arg139643745,INDENT118169,anf_fun139343746,header66143732,str_DASH_end148546) {
var $z4375143752 = D;
var $f4375743758 = function(_) {
return R.isFunction(anf_fun139343746)?anf_fun139343746.app(INDENT118169,(1),header66143732,anf_arg139643745,str_DASH_end148546):R.ffi.throwNonFunApp(L[3012],anf_fun139343746,[INDENT118169,(1),header66143732,anf_arg139643745,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4375143752 = $f4375743758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4375743758,
"from":L[3012]});
}
} catch($e4374943750) {
if(R.isCont($e4374943750)) {
var $ss4375343754 = {"from":L[3012],
"go":function(ann_DASH_check_DASH_temp137843759) {
return $Hann_DASH_check_DASH_temp877843760(ann_DASH_check_DASH_temp137843759);
}};
$e4374943750.stack[R.EXN_STACKHEIGHT++] = $ss4375343754;
}
if(R.isPyretException($e4374943750)) {
$e4374943750.pyretStack.push(L[3012]);
}
throw $e4374943750;
}
var $ret4375543756 = $Hann_DASH_check_DASH_temp877843760($z4375143752);
++R.GAS;
return $ret4375543756;
};
var $Hann_DASH_check_DASH_temp877843760 = function(ann_DASH_check_DASH_temp137843759) {
return ann_DASH_check_DASH_temp137843759;
};
var $Hann_DASH_check_DASH_temp877743708 = function(ann_DASH_check_DASH_temp138843707) {
return ann_DASH_check_DASH_temp138843707;
};
var $Hanf_arg877616706 = function(anf_arg136416704,self16616705,_plus55,torepr65) {
var anf_arg136543771 = G(self16616705,"binds",L[2269]);
var $z4376343764 = D;
var $f4376943770 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg136543771):R.ffi.throwNonFunApp(L[2269],torepr65,[anf_arg136543771]);
};
try {
if(--R.GAS > 0) {
$z4376343764 = $f4376943770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4376943770,
"from":L[2269]});
}
} catch($e4376143762) {
if(R.isCont($e4376143762)) {
var $ss4376543766 = {"from":L[2269],
"go":function(anf_arg136643772) {
return $Hanf_arg877543773(anf_arg136643772,anf_arg136416704,self16616705,_plus55,torepr65);
}};
$e4376143762.stack[R.EXN_STACKHEIGHT++] = $ss4376543766;
}
if(R.isPyretException($e4376143762)) {
$e4376143762.pyretStack.push(L[2269]);
}
throw $e4376143762;
}
var $ret4376743768 = $Hanf_arg877543773($z4376343764,anf_arg136416704,self16616705,_plus55,torepr65);
++R.GAS;
return $ret4376743768;
};
var $Hanf_arg877543773 = function(anf_arg136643772,anf_arg136416704,self16616705,_plus55,torepr65) {
var $z4377643777 = D;
var $f4378243783 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg136643772):R.ffi.throwNonFunApp(L[2269],_plus55,[(", "),anf_arg136643772]);
};
try {
if(--R.GAS > 0) {
$z4377643777 = $f4378243783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4378243783,
"from":L[2269]});
}
} catch($e4377443775) {
if(R.isCont($e4377443775)) {
var $ss4377843779 = {"from":L[2269],
"go":function(anf_arg136743784) {
return $Hanf_arg877443785(anf_arg136743784,anf_arg136416704,self16616705,_plus55,torepr65);
}};
$e4377443775.stack[R.EXN_STACKHEIGHT++] = $ss4377843779;
}
if(R.isPyretException($e4377443775)) {
$e4377443775.pyretStack.push(L[2269]);
}
throw $e4377443775;
}
var $ret4378043781 = $Hanf_arg877443785($z4377643777,anf_arg136416704,self16616705,_plus55,torepr65);
++R.GAS;
return $ret4378043781;
};
var $Hanf_arg877443785 = function(anf_arg136743784,anf_arg136416704,self16616705,_plus55,torepr65) {
var $z4378843789 = D;
var $f4379443795 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg136416704,anf_arg136743784):R.ffi.throwNonFunApp(L[2269],_plus55,[anf_arg136416704,anf_arg136743784]);
};
try {
if(--R.GAS > 0) {
$z4378843789 = $f4379443795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4379443795,
"from":L[2269]});
}
} catch($e4378643787) {
if(R.isCont($e4378643787)) {
var $ss4379043791 = {"from":L[2269],
"go":function(anf_arg136843796) {
return $Hanf_arg877343797(anf_arg136843796,self16616705,_plus55,torepr65);
}};
$e4378643787.stack[R.EXN_STACKHEIGHT++] = $ss4379043791;
}
if(R.isPyretException($e4378643787)) {
$e4378643787.pyretStack.push(L[2269]);
}
throw $e4378643787;
}
var $ret4379243793 = $Hanf_arg877343797($z4378843789,self16616705,_plus55,torepr65);
++R.GAS;
return $ret4379243793;
};
var $Hanf_arg877343797 = function(anf_arg136843796,self16616705,_plus55,torepr65) {
var anf_arg136943808 = G(self16616705,"body",L[2269]);
var $z4380043801 = D;
var $f4380643807 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg136943808):R.ffi.throwNonFunApp(L[2269],torepr65,[anf_arg136943808]);
};
try {
if(--R.GAS > 0) {
$z4380043801 = $f4380643807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4380643807,
"from":L[2269]});
}
} catch($e4379843799) {
if(R.isCont($e4379843799)) {
var $ss4380243803 = {"from":L[2269],
"go":function(anf_arg137043809) {
return $Hanf_arg877243810(anf_arg137043809,anf_arg136843796,_plus55);
}};
$e4379843799.stack[R.EXN_STACKHEIGHT++] = $ss4380243803;
}
if(R.isPyretException($e4379843799)) {
$e4379843799.pyretStack.push(L[2269]);
}
throw $e4379843799;
}
var $ret4380443805 = $Hanf_arg877243810($z4380043801,anf_arg136843796,_plus55);
++R.GAS;
return $ret4380443805;
};
var $Hanf_arg877243810 = function(anf_arg137043809,anf_arg136843796,_plus55) {
var $z4381343814 = D;
var $f4381943820 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg137043809):R.ffi.throwNonFunApp(L[2269],_plus55,[(", "),anf_arg137043809]);
};
try {
if(--R.GAS > 0) {
$z4381343814 = $f4381943820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4381943820,
"from":L[2269]});
}
} catch($e4381143812) {
if(R.isCont($e4381143812)) {
var $ss4381543816 = {"from":L[2269],
"go":function(anf_arg137143821) {
return $Hanf_arg877143822(anf_arg137143821,anf_arg136843796,_plus55);
}};
$e4381143812.stack[R.EXN_STACKHEIGHT++] = $ss4381543816;
}
if(R.isPyretException($e4381143812)) {
$e4381143812.pyretStack.push(L[2269]);
}
throw $e4381143812;
}
var $ret4381743818 = $Hanf_arg877143822($z4381343814,anf_arg136843796,_plus55);
++R.GAS;
return $ret4381743818;
};
var $Hanf_arg877143822 = function(anf_arg137143821,anf_arg136843796,_plus55) {
var $z4382543826 = D;
var $f4383143832 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg136843796,anf_arg137143821):R.ffi.throwNonFunApp(L[2269],_plus55,[anf_arg136843796,anf_arg137143821]);
};
try {
if(--R.GAS > 0) {
$z4382543826 = $f4383143832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4383143832,
"from":L[2269]});
}
} catch($e4382343824) {
if(R.isCont($e4382343824)) {
var $ss4382743828 = {"from":L[2269],
"go":function(anf_arg137243833) {
return $Hanf_arg877043834(anf_arg137243833,_plus55);
}};
$e4382343824.stack[R.EXN_STACKHEIGHT++] = $ss4382743828;
}
if(R.isPyretException($e4382343824)) {
$e4382343824.pyretStack.push(L[2269]);
}
throw $e4382343824;
}
var $ret4382943830 = $Hanf_arg877043834($z4382543826,_plus55);
++R.GAS;
return $ret4382943830;
};
var $Hanf_arg877043834 = function(anf_arg137243833,_plus55) {
var $z4383743838 = D;
var $f4384343844 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg137243833,(")")):R.ffi.throwNonFunApp(L[2269],_plus55,[anf_arg137243833,(")")]);
};
try {
if(--R.GAS > 0) {
$z4383743838 = $f4384343844();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4384343844,
"from":L[2269]});
}
} catch($e4383543836) {
if(R.isCont($e4383543836)) {
var $ss4383943840 = {"from":L[2269],
"go":function(anf_arg137343845) {
return $Hanf_arg876943846(anf_arg137343845,_plus55);
}};
$e4383543836.stack[R.EXN_STACKHEIGHT++] = $ss4383943840;
}
if(R.isPyretException($e4383543836)) {
$e4383543836.pyretStack.push(L[2269]);
}
throw $e4383543836;
}
var $ret4384143842 = $Hanf_arg876943846($z4383743838,_plus55);
++R.GAS;
return $ret4384143842;
};
var $Hanf_arg876943846 = function(anf_arg137343845,_plus55) {
var $z4384943850 = D;
var $f4385543856 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg137343845):R.ffi.throwNonFunApp(L[2269],_plus55,[("("),anf_arg137343845]);
};
try {
if(--R.GAS > 0) {
$z4384943850 = $f4385543856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4385543856,
"from":L[2269]});
}
} catch($e4384743848) {
if(R.isCont($e4384743848)) {
var $ss4385143852 = {"from":L[2269],
"go":function(anf_arg137443857) {
return $Hanf_arg876843858(anf_arg137443857,_plus55);
}};
$e4384743848.stack[R.EXN_STACKHEIGHT++] = $ss4385143852;
}
if(R.isPyretException($e4384743848)) {
$e4384743848.pyretStack.push(L[2269]);
}
throw $e4384743848;
}
var $ret4385343854 = $Hanf_arg876843858($z4384943850,_plus55);
++R.GAS;
return $ret4385343854;
};
var $Hanf_arg876843858 = function(anf_arg137443857,_plus55) {
var $z4386143862 = D;
var $f4386743868 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-type-let-expr"),anf_arg137443857):R.ffi.throwNonFunApp(L[2269],_plus55,[("s-type-let-expr"),anf_arg137443857]);
};
try {
if(--R.GAS > 0) {
$z4386143862 = $f4386743868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4386743868,
"from":L[2269]});
}
} catch($e4385943860) {
if(R.isCont($e4385943860)) {
var $ss4386343864 = {"from":L[2269],
"go":function(ann_DASH_check_DASH_temp136243869) {
return $Hann_DASH_check_DASH_temp876743870(ann_DASH_check_DASH_temp136243869);
}};
$e4385943860.stack[R.EXN_STACKHEIGHT++] = $ss4386343864;
}
if(R.isPyretException($e4385943860)) {
$e4385943860.pyretStack.push(L[2269]);
}
throw $e4385943860;
}
var $ret4386543866 = $Hann_DASH_check_DASH_temp876743870($z4386143862);
++R.GAS;
return $ret4386543866;
};
var $Hann_DASH_check_DASH_temp876743870 = function(ann_DASH_check_DASH_temp136243869) {
return ann_DASH_check_DASH_temp136243869;
};
var $Hcont_tail_arg876516723 = function(cont_tail_arg135916721,if_helper134916722) {
if(--R.GAS > 0) {
$z4387143872 = R.isFunction(if_helper134916722)?if_helper134916722.app(cont_tail_arg135916721):R.ffi.throwNonFunApp(L[2269],if_helper134916722,[cont_tail_arg135916721]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper134916722)?if_helper134916722.app(cont_tail_arg135916721):R.ffi.throwNonFunApp(L[2269],if_helper134916722,[cont_tail_arg135916721]);
},
"from":L[2269]});
}
++R.GAS;
return $z4387143872;
};
var $Hcont_tail_arg876616738 = function(cont_tail_arg135416737,if_helper134916722) {
if(--R.GAS > 0) {
$z4387343874 = R.isFunction(if_helper134916722)?if_helper134916722.app(cont_tail_arg135416737):R.ffi.throwNonFunApp(L[2269],if_helper134916722,[cont_tail_arg135416737]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper134916722)?if_helper134916722.app(cont_tail_arg135416737):R.ffi.throwNonFunApp(L[2269],if_helper134916722,[cont_tail_arg135416737]);
},
"from":L[2269]});
}
++R.GAS;
return $z4387343874;
};
var $Hanf_arg876416759 = function(anf_arg130316757,INDENT118169,PP170,list25154,self65416758,str_DASH_colon134364,_plus55) {
var anf_fun130443889 = G(PP170,"parens",L[4706]);
var anf_fun130543890 = G(PP170,"flow-map",L[4705]);
var anf_arg130643887 = G(PP170,"commabreak",L[4704]);
var anf_arg130843888 = R.makeFunction(function(x65543894) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4703],1,arguments);
}
var ann_DASH_check_DASH_temp130743895 = x65543894;
return ann_DASH_check_DASH_temp130743895;
});
var anf_fun130943891 = G(list25154,"make",L[4702]);
var anf_fun131043892 = G(PP170,"infix",L[4701]);
var anf_fun131143885 = G(PP170,"str",L[4700]);
var $z4387743878 = D;
var $f4388343884 = function(_) {
return R.isFunction(anf_fun131143885)?anf_fun131143885.app(("Answer")):R.ffi.throwNonFunApp(L[4699],anf_fun131143885,[("Answer")]);
};
try {
if(--R.GAS > 0) {
$z4387743878 = $f4388343884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4388343884,
"from":L[4699]});
}
} catch($e4387543876) {
if(R.isCont($e4387543876)) {
var $ss4387943880 = {"from":L[4699],
"go":function(anf_arg131243886) {
return $Hanf_arg876343893(anf_arg131243886,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131043892,self65416758,str_DASH_colon134364,_plus55);
}};
$e4387543876.stack[R.EXN_STACKHEIGHT++] = $ss4387943880;
}
if(R.isPyretException($e4387543876)) {
$e4387543876.pyretStack.push(L[4699]);
}
throw $e4387543876;
}
var $ret4388143882 = $Hanf_arg876343893($z4387743878,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131043892,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4388143882;
};
var $Hanf_arg876343893 = function(anf_arg131243886,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131043892,self65416758,str_DASH_colon134364,_plus55) {
var anf_bracket131343909 = G(self65416758,"answer",L[4709]);
var anf_fun131443906 = G(anf_bracket131343909,"tosource",L[4708]);
var $z4389843899 = D;
var $f4390443905 = function(_) {
return R.isFunction(anf_fun131443906)?anf_fun131443906.app():R.ffi.throwNonFunApp(L[4707],anf_fun131443906,[]);
};
try {
if(--R.GAS > 0) {
$z4389843899 = $f4390443905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4390443905,
"from":L[4707]});
}
} catch($e4389643897) {
if(R.isCont($e4389643897)) {
var $ss4390043901 = {"from":L[4707],
"go":function(anf_arg131543907) {
return $Hanf_arg876243908(anf_arg131543907,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg131243886,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131043892,self65416758,str_DASH_colon134364,_plus55);
}};
$e4389643897.stack[R.EXN_STACKHEIGHT++] = $ss4390043901;
}
if(R.isPyretException($e4389643897)) {
$e4389643897.pyretStack.push(L[4707]);
}
throw $e4389643897;
}
var $ret4390243903 = $Hanf_arg876243908($z4389843899,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg131243886,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131043892,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4390243903;
};
var $Hanf_arg876243908 = function(anf_arg131543907,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg131243886,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131043892,self65416758,str_DASH_colon134364,_plus55) {
var $z4391243913 = D;
var $f4391843919 = function(_) {
return R.isFunction(anf_fun131043892)?anf_fun131043892.app(INDENT118169,(1),str_DASH_colon134364,anf_arg131243886,anf_arg131543907):R.ffi.throwNonFunApp(L[4710],anf_fun131043892,[INDENT118169,(1),str_DASH_colon134364,anf_arg131243886,anf_arg131543907]);
};
try {
if(--R.GAS > 0) {
$z4391243913 = $f4391843919();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4391843919,
"from":L[4710]});
}
} catch($e4391043911) {
if(R.isCont($e4391043911)) {
var $ss4391443915 = {"from":L[4710],
"go":function(anf_array_val131643920) {
return $Hanf_array_val876143921(anf_array_val131643920,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55);
}};
$e4391043911.stack[R.EXN_STACKHEIGHT++] = $ss4391443915;
}
if(R.isPyretException($e4391043911)) {
$e4391043911.pyretStack.push(L[4710]);
}
throw $e4391043911;
}
var $ret4391643917 = $Hanf_array_val876143921($z4391243913,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4391643917;
};
var $Hanf_array_val876143921 = function(anf_array_val131643920,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55) {
var anf_fun131743934 = G(PP170,"infix",L[4713]);
var anf_fun131843932 = G(PP170,"str",L[4712]);
var $z4392443925 = D;
var $f4393043931 = function(_) {
return R.isFunction(anf_fun131843932)?anf_fun131843932.app(("Provides")):R.ffi.throwNonFunApp(L[4711],anf_fun131843932,[("Provides")]);
};
try {
if(--R.GAS > 0) {
$z4392443925 = $f4393043931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4393043931,
"from":L[4711]});
}
} catch($e4392243923) {
if(R.isCont($e4392243923)) {
var $ss4392643927 = {"from":L[4711],
"go":function(anf_arg131943933) {
return $Hanf_arg876043935(anf_arg131943933,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131743934,self65416758,str_DASH_colon134364,_plus55);
}};
$e4392243923.stack[R.EXN_STACKHEIGHT++] = $ss4392643927;
}
if(R.isPyretException($e4392243923)) {
$e4392243923.pyretStack.push(L[4711]);
}
throw $e4392243923;
}
var $ret4392843929 = $Hanf_arg876043935($z4392443925,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131743934,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4392843929;
};
var $Hanf_arg876043935 = function(anf_arg131943933,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131743934,self65416758,str_DASH_colon134364,_plus55) {
var anf_bracket132043949 = G(self65416758,"provides",L[4716]);
var anf_fun132143946 = G(anf_bracket132043949,"tosource",L[4715]);
var $z4393843939 = D;
var $f4394443945 = function(_) {
return R.isFunction(anf_fun132143946)?anf_fun132143946.app():R.ffi.throwNonFunApp(L[4714],anf_fun132143946,[]);
};
try {
if(--R.GAS > 0) {
$z4393843939 = $f4394443945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4394443945,
"from":L[4714]});
}
} catch($e4393643937) {
if(R.isCont($e4393643937)) {
var $ss4394043941 = {"from":L[4714],
"go":function(anf_arg132243947) {
return $Hanf_arg875943948(anf_arg132243947,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg131943933,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131743934,self65416758,str_DASH_colon134364,_plus55);
}};
$e4393643937.stack[R.EXN_STACKHEIGHT++] = $ss4394043941;
}
if(R.isPyretException($e4393643937)) {
$e4393643937.pyretStack.push(L[4714]);
}
throw $e4393643937;
}
var $ret4394243943 = $Hanf_arg875943948($z4393843939,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg131943933,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131743934,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4394243943;
};
var $Hanf_arg875943948 = function(anf_arg132243947,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg131943933,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun131743934,self65416758,str_DASH_colon134364,_plus55) {
var $z4395243953 = D;
var $f4395843959 = function(_) {
return R.isFunction(anf_fun131743934)?anf_fun131743934.app(INDENT118169,(1),str_DASH_colon134364,anf_arg131943933,anf_arg132243947):R.ffi.throwNonFunApp(L[4717],anf_fun131743934,[INDENT118169,(1),str_DASH_colon134364,anf_arg131943933,anf_arg132243947]);
};
try {
if(--R.GAS > 0) {
$z4395243953 = $f4395843959();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4395843959,
"from":L[4717]});
}
} catch($e4395043951) {
if(R.isCont($e4395043951)) {
var $ss4395443955 = {"from":L[4717],
"go":function(anf_array_val132343960) {
return $Hanf_array_val875843961(anf_array_val132343960,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55);
}};
$e4395043951.stack[R.EXN_STACKHEIGHT++] = $ss4395443955;
}
if(R.isPyretException($e4395043951)) {
$e4395043951.pyretStack.push(L[4717]);
}
throw $e4395043951;
}
var $ret4395643957 = $Hanf_array_val875843961($z4395243953,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4395643957;
};
var $Hanf_array_val875843961 = function(anf_array_val132343960,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55) {
var anf_fun132443974 = G(PP170,"infix",L[4720]);
var anf_fun132543972 = G(PP170,"str",L[4719]);
var $z4396443965 = D;
var $f4397043971 = function(_) {
return R.isFunction(anf_fun132543972)?anf_fun132543972.app(("Types")):R.ffi.throwNonFunApp(L[4718],anf_fun132543972,[("Types")]);
};
try {
if(--R.GAS > 0) {
$z4396443965 = $f4397043971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4397043971,
"from":L[4718]});
}
} catch($e4396243963) {
if(R.isCont($e4396243963)) {
var $ss4396643967 = {"from":L[4718],
"go":function(anf_arg132643973) {
return $Hanf_arg875743975(anf_arg132643973,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,self65416758,str_DASH_colon134364,_plus55);
}};
$e4396243963.stack[R.EXN_STACKHEIGHT++] = $ss4396643967;
}
if(R.isPyretException($e4396243963)) {
$e4396243963.pyretStack.push(L[4718]);
}
throw $e4396243963;
}
var $ret4396843969 = $Hanf_arg875743975($z4396443965,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4396843969;
};
var $Hanf_arg875743975 = function(anf_arg132643973,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,self65416758,str_DASH_colon134364,_plus55) {
var anf_fun132743991 = G(PP170,"brackets",L[4726]);
var anf_fun132843986 = G(PP170,"flow-map",L[4725]);
var anf_arg132943987 = G(PP170,"commabreak",L[4724]);
var anf_arg133243988 = R.makeFunction(function(recv_DASH_16143993) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4723],1,arguments);
}
var anf_fun133144004 = G(recv_DASH_16143993,"tosource",L[4723]);
var $z4399643997 = D;
var $f4400244003 = function(_) {
return R.isFunction(anf_fun133144004)?anf_fun133144004.app():R.ffi.throwNonFunApp(L[4723],anf_fun133144004,[]);
};
try {
if(--R.GAS > 0) {
$z4399643997 = $f4400244003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4400244003,
"from":L[4723]});
}
} catch($e4399443995) {
if(R.isCont($e4399443995)) {
var $ss4399843999 = {"from":L[4723],
"go":function(ann_DASH_check_DASH_temp133044005) {
return $Hann_DASH_check_DASH_temp874644006(ann_DASH_check_DASH_temp133044005);
}};
$e4399443995.stack[R.EXN_STACKHEIGHT++] = $ss4399843999;
}
if(R.isPyretException($e4399443995)) {
$e4399443995.pyretStack.push(L[4723]);
}
throw $e4399443995;
}
var $ret4400044001 = $Hann_DASH_check_DASH_temp874644006($z4399643997);
++R.GAS;
return $ret4400044001;
});
var anf_arg133343989 = G(self65416758,"types",L[4722]);
var $z4397843979 = D;
var $f4398443985 = function(_) {
return R.isFunction(anf_fun132843986)?anf_fun132843986.app(anf_arg132943987,anf_arg133243988,anf_arg133343989):R.ffi.throwNonFunApp(L[4721],anf_fun132843986,[anf_arg132943987,anf_arg133243988,anf_arg133343989]);
};
try {
if(--R.GAS > 0) {
$z4397843979 = $f4398443985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4398443985,
"from":L[4721]});
}
} catch($e4397643977) {
if(R.isCont($e4397643977)) {
var $ss4398043981 = {"from":L[4721],
"go":function(anf_arg133443990) {
return $Hanf_arg875643992(anf_arg133443990,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg132643973,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,anf_fun132743991,self65416758,str_DASH_colon134364,_plus55);
}};
$e4397643977.stack[R.EXN_STACKHEIGHT++] = $ss4398043981;
}
if(R.isPyretException($e4397643977)) {
$e4397643977.pyretStack.push(L[4721]);
}
throw $e4397643977;
}
var $ret4398243983 = $Hanf_arg875643992($z4397843979,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg132643973,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,anf_fun132743991,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4398243983;
};
var $Hanf_arg875643992 = function(anf_arg133443990,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg132643973,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,anf_fun132743991,self65416758,str_DASH_colon134364,_plus55) {
var $z4400944010 = D;
var $f4401544016 = function(_) {
return R.isFunction(anf_fun132743991)?anf_fun132743991.app(anf_arg133443990):R.ffi.throwNonFunApp(L[4727],anf_fun132743991,[anf_arg133443990]);
};
try {
if(--R.GAS > 0) {
$z4400944010 = $f4401544016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4401544016,
"from":L[4727]});
}
} catch($e4400744008) {
if(R.isCont($e4400744008)) {
var $ss4401144012 = {"from":L[4727],
"go":function(anf_arg133544017) {
return $Hanf_arg875544018(anf_arg133544017,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg132643973,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,self65416758,str_DASH_colon134364,_plus55);
}};
$e4400744008.stack[R.EXN_STACKHEIGHT++] = $ss4401144012;
}
if(R.isPyretException($e4400744008)) {
$e4400744008.pyretStack.push(L[4727]);
}
throw $e4400744008;
}
var $ret4401344014 = $Hanf_arg875544018($z4400944010,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg132643973,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4401344014;
};
var $Hanf_arg875544018 = function(anf_arg133544017,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg132643973,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun132443974,self65416758,str_DASH_colon134364,_plus55) {
var $z4402144022 = D;
var $f4402744028 = function(_) {
return R.isFunction(anf_fun132443974)?anf_fun132443974.app(INDENT118169,(1),str_DASH_colon134364,anf_arg132643973,anf_arg133544017):R.ffi.throwNonFunApp(L[4728],anf_fun132443974,[INDENT118169,(1),str_DASH_colon134364,anf_arg132643973,anf_arg133544017]);
};
try {
if(--R.GAS > 0) {
$z4402144022 = $f4402744028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4402744028,
"from":L[4728]});
}
} catch($e4401944020) {
if(R.isCont($e4401944020)) {
var $ss4402344024 = {"from":L[4728],
"go":function(anf_array_val133644029) {
return $Hanf_array_val875444030(anf_array_val133644029,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55);
}};
$e4401944020.stack[R.EXN_STACKHEIGHT++] = $ss4402344024;
}
if(R.isPyretException($e4401944020)) {
$e4401944020.pyretStack.push(L[4728]);
}
throw $e4401944020;
}
var $ret4402544026 = $Hanf_array_val875444030($z4402144022,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4402544026;
};
var $Hanf_array_val875444030 = function(anf_array_val133644029,INDENT118169,PP170,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_fun130443889,anf_fun130543890,anf_fun130943891,self65416758,str_DASH_colon134364,_plus55) {
var anf_fun133744043 = G(PP170,"infix",L[4731]);
var anf_fun133844041 = G(PP170,"str",L[4730]);
var $z4403344034 = D;
var $f4403944040 = function(_) {
return R.isFunction(anf_fun133844041)?anf_fun133844041.app(("checks")):R.ffi.throwNonFunApp(L[4729],anf_fun133844041,[("checks")]);
};
try {
if(--R.GAS > 0) {
$z4403344034 = $f4403944040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4403944040,
"from":L[4729]});
}
} catch($e4403144032) {
if(R.isCont($e4403144032)) {
var $ss4403544036 = {"from":L[4729],
"go":function(anf_arg133944042) {
return $Hanf_arg875344044(anf_arg133944042,INDENT118169,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun133744043,self65416758,str_DASH_colon134364,_plus55);
}};
$e4403144032.stack[R.EXN_STACKHEIGHT++] = $ss4403544036;
}
if(R.isPyretException($e4403144032)) {
$e4403144032.pyretStack.push(L[4729]);
}
throw $e4403144032;
}
var $ret4403744038 = $Hanf_arg875344044($z4403344034,INDENT118169,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun133744043,self65416758,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4403744038;
};
var $Hanf_arg875344044 = function(anf_arg133944042,INDENT118169,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun133744043,self65416758,str_DASH_colon134364,_plus55) {
var anf_bracket134044058 = G(self65416758,"checks",L[4734]);
var anf_fun134144055 = G(anf_bracket134044058,"tosource",L[4733]);
var $z4404744048 = D;
var $f4405344054 = function(_) {
return R.isFunction(anf_fun134144055)?anf_fun134144055.app():R.ffi.throwNonFunApp(L[4732],anf_fun134144055,[]);
};
try {
if(--R.GAS > 0) {
$z4404744048 = $f4405344054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4405344054,
"from":L[4732]});
}
} catch($e4404544046) {
if(R.isCont($e4404544046)) {
var $ss4404944050 = {"from":L[4732],
"go":function(anf_arg134244056) {
return $Hanf_arg875244057(anf_arg134244056,INDENT118169,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg133944042,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun133744043,str_DASH_colon134364,_plus55);
}};
$e4404544046.stack[R.EXN_STACKHEIGHT++] = $ss4404944050;
}
if(R.isPyretException($e4404544046)) {
$e4404544046.pyretStack.push(L[4732]);
}
throw $e4404544046;
}
var $ret4405144052 = $Hanf_arg875244057($z4404744048,INDENT118169,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg133944042,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun133744043,str_DASH_colon134364,_plus55);
++R.GAS;
return $ret4405144052;
};
var $Hanf_arg875244057 = function(anf_arg134244056,INDENT118169,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_arg133944042,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,anf_fun133744043,str_DASH_colon134364,_plus55) {
var $z4406144062 = D;
var $f4406744068 = function(_) {
return R.isFunction(anf_fun133744043)?anf_fun133744043.app(INDENT118169,(1),str_DASH_colon134364,anf_arg133944042,anf_arg134244056):R.ffi.throwNonFunApp(L[4735],anf_fun133744043,[INDENT118169,(1),str_DASH_colon134364,anf_arg133944042,anf_arg134244056]);
};
try {
if(--R.GAS > 0) {
$z4406144062 = $f4406744068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4406744068,
"from":L[4735]});
}
} catch($e4405944060) {
if(R.isCont($e4405944060)) {
var $ss4406344064 = {"from":L[4735],
"go":function(anf_array_val134344069) {
return $Hanf_array_val875144070(anf_array_val134344069,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,_plus55);
}};
$e4405944060.stack[R.EXN_STACKHEIGHT++] = $ss4406344064;
}
if(R.isPyretException($e4405944060)) {
$e4405944060.pyretStack.push(L[4735]);
}
throw $e4405944060;
}
var $ret4406544066 = $Hanf_array_val875144070($z4406144062,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,_plus55);
++R.GAS;
return $ret4406544066;
};
var $Hanf_array_val875144070 = function(anf_array_val134344069,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_fun130443889,anf_fun130543890,anf_fun130943891,_plus55) {
var $z4407344074 = D;
var $f4407944080 = function(_) {
return R.isFunction(anf_fun130943891)?anf_fun130943891.app([anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_array_val134344069]):R.ffi.throwNonFunApp(L[4702],anf_fun130943891,[[anf_array_val131643920,anf_array_val132343960,anf_array_val133644029,anf_array_val134344069]]);
};
try {
if(--R.GAS > 0) {
$z4407344074 = $f4407944080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4407944080,
"from":L[4702]});
}
} catch($e4407144072) {
if(R.isCont($e4407144072)) {
var $ss4407544076 = {"from":L[4702],
"go":function(anf_arg134444081) {
return $Hanf_arg875044082(anf_arg134444081,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,_plus55);
}};
$e4407144072.stack[R.EXN_STACKHEIGHT++] = $ss4407544076;
}
if(R.isPyretException($e4407144072)) {
$e4407144072.pyretStack.push(L[4702]);
}
throw $e4407144072;
}
var $ret4407744078 = $Hanf_arg875044082($z4407344074,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,_plus55);
++R.GAS;
return $ret4407744078;
};
var $Hanf_arg875044082 = function(anf_arg134444081,anf_arg130316757,anf_arg130643887,anf_arg130843888,anf_fun130443889,anf_fun130543890,_plus55) {
var $z4408544086 = D;
var $f4409144092 = function(_) {
return R.isFunction(anf_fun130543890)?anf_fun130543890.app(anf_arg130643887,anf_arg130843888,anf_arg134444081):R.ffi.throwNonFunApp(L[4736],anf_fun130543890,[anf_arg130643887,anf_arg130843888,anf_arg134444081]);
};
try {
if(--R.GAS > 0) {
$z4408544086 = $f4409144092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4409144092,
"from":L[4736]});
}
} catch($e4408344084) {
if(R.isCont($e4408344084)) {
var $ss4408744088 = {"from":L[4736],
"go":function(anf_arg134544093) {
return $Hanf_arg874944094(anf_arg134544093,anf_arg130316757,anf_fun130443889,_plus55);
}};
$e4408344084.stack[R.EXN_STACKHEIGHT++] = $ss4408744088;
}
if(R.isPyretException($e4408344084)) {
$e4408344084.pyretStack.push(L[4736]);
}
throw $e4408344084;
}
var $ret4408944090 = $Hanf_arg874944094($z4408544086,anf_arg130316757,anf_fun130443889,_plus55);
++R.GAS;
return $ret4408944090;
};
var $Hanf_arg874944094 = function(anf_arg134544093,anf_arg130316757,anf_fun130443889,_plus55) {
var $z4409744098 = D;
var $f4410344104 = function(_) {
return R.isFunction(anf_fun130443889)?anf_fun130443889.app(anf_arg134544093):R.ffi.throwNonFunApp(L[4737],anf_fun130443889,[anf_arg134544093]);
};
try {
if(--R.GAS > 0) {
$z4409744098 = $f4410344104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4410344104,
"from":L[4737]});
}
} catch($e4409544096) {
if(R.isCont($e4409544096)) {
var $ss4409944100 = {"from":L[4737],
"go":function(anf_arg134644105) {
return $Hanf_arg874844106(anf_arg134644105,anf_arg130316757,_plus55);
}};
$e4409544096.stack[R.EXN_STACKHEIGHT++] = $ss4409944100;
}
if(R.isPyretException($e4409544096)) {
$e4409544096.pyretStack.push(L[4737]);
}
throw $e4409544096;
}
var $ret4410144102 = $Hanf_arg874844106($z4409744098,anf_arg130316757,_plus55);
++R.GAS;
return $ret4410144102;
};
var $Hanf_arg874844106 = function(anf_arg134644105,anf_arg130316757,_plus55) {
var $z4410944110 = D;
var $f4411544116 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg130316757,anf_arg134644105):R.ffi.throwNonFunApp(L[3019],_plus55,[anf_arg130316757,anf_arg134644105]);
};
try {
if(--R.GAS > 0) {
$z4410944110 = $f4411544116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4411544116,
"from":L[3019]});
}
} catch($e4410744108) {
if(R.isCont($e4410744108)) {
var $ss4411144112 = {"from":L[3019],
"go":function(ann_DASH_check_DASH_temp130144117) {
return $Hann_DASH_check_DASH_temp874744118(ann_DASH_check_DASH_temp130144117);
}};
$e4410744108.stack[R.EXN_STACKHEIGHT++] = $ss4411144112;
}
if(R.isPyretException($e4410744108)) {
$e4410744108.pyretStack.push(L[3019]);
}
throw $e4410744108;
}
var $ret4411344114 = $Hann_DASH_check_DASH_temp874744118($z4410944110);
++R.GAS;
return $ret4411344114;
};
var $Hann_DASH_check_DASH_temp874744118 = function(ann_DASH_check_DASH_temp130144117) {
return ann_DASH_check_DASH_temp130144117;
};
var $Hann_DASH_check_DASH_temp874644006 = function(ann_DASH_check_DASH_temp133044005) {
return ann_DASH_check_DASH_temp133044005;
};
var $Hanf_arg874516775 = function(anf_arg127916773,self15916774,_plus55,torepr65) {
var anf_arg128044129 = G(self15916774,"answer",L[2270]);
var $z4412144122 = D;
var $f4412744128 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg128044129):R.ffi.throwNonFunApp(L[2270],torepr65,[anf_arg128044129]);
};
try {
if(--R.GAS > 0) {
$z4412144122 = $f4412744128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4412744128,
"from":L[2270]});
}
} catch($e4411944120) {
if(R.isCont($e4411944120)) {
var $ss4412344124 = {"from":L[2270],
"go":function(anf_arg128144130) {
return $Hanf_arg874444131(anf_arg128144130,anf_arg127916773,self15916774,_plus55,torepr65);
}};
$e4411944120.stack[R.EXN_STACKHEIGHT++] = $ss4412344124;
}
if(R.isPyretException($e4411944120)) {
$e4411944120.pyretStack.push(L[2270]);
}
throw $e4411944120;
}
var $ret4412544126 = $Hanf_arg874444131($z4412144122,anf_arg127916773,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4412544126;
};
var $Hanf_arg874444131 = function(anf_arg128144130,anf_arg127916773,self15916774,_plus55,torepr65) {
var $z4413444135 = D;
var $f4414044141 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg128144130):R.ffi.throwNonFunApp(L[2270],_plus55,[(", "),anf_arg128144130]);
};
try {
if(--R.GAS > 0) {
$z4413444135 = $f4414044141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4414044141,
"from":L[2270]});
}
} catch($e4413244133) {
if(R.isCont($e4413244133)) {
var $ss4413644137 = {"from":L[2270],
"go":function(anf_arg128244142) {
return $Hanf_arg874344143(anf_arg128244142,anf_arg127916773,self15916774,_plus55,torepr65);
}};
$e4413244133.stack[R.EXN_STACKHEIGHT++] = $ss4413644137;
}
if(R.isPyretException($e4413244133)) {
$e4413244133.pyretStack.push(L[2270]);
}
throw $e4413244133;
}
var $ret4413844139 = $Hanf_arg874344143($z4413444135,anf_arg127916773,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4413844139;
};
var $Hanf_arg874344143 = function(anf_arg128244142,anf_arg127916773,self15916774,_plus55,torepr65) {
var $z4414644147 = D;
var $f4415244153 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg127916773,anf_arg128244142):R.ffi.throwNonFunApp(L[2270],_plus55,[anf_arg127916773,anf_arg128244142]);
};
try {
if(--R.GAS > 0) {
$z4414644147 = $f4415244153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4415244153,
"from":L[2270]});
}
} catch($e4414444145) {
if(R.isCont($e4414444145)) {
var $ss4414844149 = {"from":L[2270],
"go":function(anf_arg128344154) {
return $Hanf_arg874244155(anf_arg128344154,self15916774,_plus55,torepr65);
}};
$e4414444145.stack[R.EXN_STACKHEIGHT++] = $ss4414844149;
}
if(R.isPyretException($e4414444145)) {
$e4414444145.pyretStack.push(L[2270]);
}
throw $e4414444145;
}
var $ret4415044151 = $Hanf_arg874244155($z4414644147,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4415044151;
};
var $Hanf_arg874244155 = function(anf_arg128344154,self15916774,_plus55,torepr65) {
var anf_arg128444166 = G(self15916774,"provides",L[2270]);
var $z4415844159 = D;
var $f4416444165 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg128444166):R.ffi.throwNonFunApp(L[2270],torepr65,[anf_arg128444166]);
};
try {
if(--R.GAS > 0) {
$z4415844159 = $f4416444165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4416444165,
"from":L[2270]});
}
} catch($e4415644157) {
if(R.isCont($e4415644157)) {
var $ss4416044161 = {"from":L[2270],
"go":function(anf_arg128544167) {
return $Hanf_arg874144168(anf_arg128544167,anf_arg128344154,self15916774,_plus55,torepr65);
}};
$e4415644157.stack[R.EXN_STACKHEIGHT++] = $ss4416044161;
}
if(R.isPyretException($e4415644157)) {
$e4415644157.pyretStack.push(L[2270]);
}
throw $e4415644157;
}
var $ret4416244163 = $Hanf_arg874144168($z4415844159,anf_arg128344154,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4416244163;
};
var $Hanf_arg874144168 = function(anf_arg128544167,anf_arg128344154,self15916774,_plus55,torepr65) {
var $z4417144172 = D;
var $f4417744178 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg128544167):R.ffi.throwNonFunApp(L[2270],_plus55,[(", "),anf_arg128544167]);
};
try {
if(--R.GAS > 0) {
$z4417144172 = $f4417744178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4417744178,
"from":L[2270]});
}
} catch($e4416944170) {
if(R.isCont($e4416944170)) {
var $ss4417344174 = {"from":L[2270],
"go":function(anf_arg128644179) {
return $Hanf_arg874044180(anf_arg128644179,anf_arg128344154,self15916774,_plus55,torepr65);
}};
$e4416944170.stack[R.EXN_STACKHEIGHT++] = $ss4417344174;
}
if(R.isPyretException($e4416944170)) {
$e4416944170.pyretStack.push(L[2270]);
}
throw $e4416944170;
}
var $ret4417544176 = $Hanf_arg874044180($z4417144172,anf_arg128344154,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4417544176;
};
var $Hanf_arg874044180 = function(anf_arg128644179,anf_arg128344154,self15916774,_plus55,torepr65) {
var $z4418344184 = D;
var $f4418944190 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg128344154,anf_arg128644179):R.ffi.throwNonFunApp(L[2270],_plus55,[anf_arg128344154,anf_arg128644179]);
};
try {
if(--R.GAS > 0) {
$z4418344184 = $f4418944190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4418944190,
"from":L[2270]});
}
} catch($e4418144182) {
if(R.isCont($e4418144182)) {
var $ss4418544186 = {"from":L[2270],
"go":function(anf_arg128744191) {
return $Hanf_arg873944192(anf_arg128744191,self15916774,_plus55,torepr65);
}};
$e4418144182.stack[R.EXN_STACKHEIGHT++] = $ss4418544186;
}
if(R.isPyretException($e4418144182)) {
$e4418144182.pyretStack.push(L[2270]);
}
throw $e4418144182;
}
var $ret4418744188 = $Hanf_arg873944192($z4418344184,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4418744188;
};
var $Hanf_arg873944192 = function(anf_arg128744191,self15916774,_plus55,torepr65) {
var anf_arg128844203 = G(self15916774,"types",L[2270]);
var $z4419544196 = D;
var $f4420144202 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg128844203):R.ffi.throwNonFunApp(L[2270],torepr65,[anf_arg128844203]);
};
try {
if(--R.GAS > 0) {
$z4419544196 = $f4420144202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4420144202,
"from":L[2270]});
}
} catch($e4419344194) {
if(R.isCont($e4419344194)) {
var $ss4419744198 = {"from":L[2270],
"go":function(anf_arg128944204) {
return $Hanf_arg873844205(anf_arg128944204,anf_arg128744191,self15916774,_plus55,torepr65);
}};
$e4419344194.stack[R.EXN_STACKHEIGHT++] = $ss4419744198;
}
if(R.isPyretException($e4419344194)) {
$e4419344194.pyretStack.push(L[2270]);
}
throw $e4419344194;
}
var $ret4419944200 = $Hanf_arg873844205($z4419544196,anf_arg128744191,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4419944200;
};
var $Hanf_arg873844205 = function(anf_arg128944204,anf_arg128744191,self15916774,_plus55,torepr65) {
var $z4420844209 = D;
var $f4421444215 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg128944204):R.ffi.throwNonFunApp(L[2270],_plus55,[(", "),anf_arg128944204]);
};
try {
if(--R.GAS > 0) {
$z4420844209 = $f4421444215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4421444215,
"from":L[2270]});
}
} catch($e4420644207) {
if(R.isCont($e4420644207)) {
var $ss4421044211 = {"from":L[2270],
"go":function(anf_arg129044216) {
return $Hanf_arg873744217(anf_arg129044216,anf_arg128744191,self15916774,_plus55,torepr65);
}};
$e4420644207.stack[R.EXN_STACKHEIGHT++] = $ss4421044211;
}
if(R.isPyretException($e4420644207)) {
$e4420644207.pyretStack.push(L[2270]);
}
throw $e4420644207;
}
var $ret4421244213 = $Hanf_arg873744217($z4420844209,anf_arg128744191,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4421244213;
};
var $Hanf_arg873744217 = function(anf_arg129044216,anf_arg128744191,self15916774,_plus55,torepr65) {
var $z4422044221 = D;
var $f4422644227 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg128744191,anf_arg129044216):R.ffi.throwNonFunApp(L[2270],_plus55,[anf_arg128744191,anf_arg129044216]);
};
try {
if(--R.GAS > 0) {
$z4422044221 = $f4422644227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4422644227,
"from":L[2270]});
}
} catch($e4421844219) {
if(R.isCont($e4421844219)) {
var $ss4422244223 = {"from":L[2270],
"go":function(anf_arg129144228) {
return $Hanf_arg873644229(anf_arg129144228,self15916774,_plus55,torepr65);
}};
$e4421844219.stack[R.EXN_STACKHEIGHT++] = $ss4422244223;
}
if(R.isPyretException($e4421844219)) {
$e4421844219.pyretStack.push(L[2270]);
}
throw $e4421844219;
}
var $ret4422444225 = $Hanf_arg873644229($z4422044221,self15916774,_plus55,torepr65);
++R.GAS;
return $ret4422444225;
};
var $Hanf_arg873644229 = function(anf_arg129144228,self15916774,_plus55,torepr65) {
var anf_arg129244240 = G(self15916774,"checks",L[2270]);
var $z4423244233 = D;
var $f4423844239 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg129244240):R.ffi.throwNonFunApp(L[2270],torepr65,[anf_arg129244240]);
};
try {
if(--R.GAS > 0) {
$z4423244233 = $f4423844239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4423844239,
"from":L[2270]});
}
} catch($e4423044231) {
if(R.isCont($e4423044231)) {
var $ss4423444235 = {"from":L[2270],
"go":function(anf_arg129344241) {
return $Hanf_arg873544242(anf_arg129344241,anf_arg129144228,_plus55);
}};
$e4423044231.stack[R.EXN_STACKHEIGHT++] = $ss4423444235;
}
if(R.isPyretException($e4423044231)) {
$e4423044231.pyretStack.push(L[2270]);
}
throw $e4423044231;
}
var $ret4423644237 = $Hanf_arg873544242($z4423244233,anf_arg129144228,_plus55);
++R.GAS;
return $ret4423644237;
};
var $Hanf_arg873544242 = function(anf_arg129344241,anf_arg129144228,_plus55) {
var $z4424544246 = D;
var $f4425144252 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg129344241):R.ffi.throwNonFunApp(L[2270],_plus55,[(", "),anf_arg129344241]);
};
try {
if(--R.GAS > 0) {
$z4424544246 = $f4425144252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4425144252,
"from":L[2270]});
}
} catch($e4424344244) {
if(R.isCont($e4424344244)) {
var $ss4424744248 = {"from":L[2270],
"go":function(anf_arg129444253) {
return $Hanf_arg873444254(anf_arg129444253,anf_arg129144228,_plus55);
}};
$e4424344244.stack[R.EXN_STACKHEIGHT++] = $ss4424744248;
}
if(R.isPyretException($e4424344244)) {
$e4424344244.pyretStack.push(L[2270]);
}
throw $e4424344244;
}
var $ret4424944250 = $Hanf_arg873444254($z4424544246,anf_arg129144228,_plus55);
++R.GAS;
return $ret4424944250;
};
var $Hanf_arg873444254 = function(anf_arg129444253,anf_arg129144228,_plus55) {
var $z4425744258 = D;
var $f4426344264 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg129144228,anf_arg129444253):R.ffi.throwNonFunApp(L[2270],_plus55,[anf_arg129144228,anf_arg129444253]);
};
try {
if(--R.GAS > 0) {
$z4425744258 = $f4426344264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4426344264,
"from":L[2270]});
}
} catch($e4425544256) {
if(R.isCont($e4425544256)) {
var $ss4425944260 = {"from":L[2270],
"go":function(anf_arg129544265) {
return $Hanf_arg873344266(anf_arg129544265,_plus55);
}};
$e4425544256.stack[R.EXN_STACKHEIGHT++] = $ss4425944260;
}
if(R.isPyretException($e4425544256)) {
$e4425544256.pyretStack.push(L[2270]);
}
throw $e4425544256;
}
var $ret4426144262 = $Hanf_arg873344266($z4425744258,_plus55);
++R.GAS;
return $ret4426144262;
};
var $Hanf_arg873344266 = function(anf_arg129544265,_plus55) {
var $z4426944270 = D;
var $f4427544276 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg129544265,(")")):R.ffi.throwNonFunApp(L[2270],_plus55,[anf_arg129544265,(")")]);
};
try {
if(--R.GAS > 0) {
$z4426944270 = $f4427544276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4427544276,
"from":L[2270]});
}
} catch($e4426744268) {
if(R.isCont($e4426744268)) {
var $ss4427144272 = {"from":L[2270],
"go":function(anf_arg129644277) {
return $Hanf_arg873244278(anf_arg129644277,_plus55);
}};
$e4426744268.stack[R.EXN_STACKHEIGHT++] = $ss4427144272;
}
if(R.isPyretException($e4426744268)) {
$e4426744268.pyretStack.push(L[2270]);
}
throw $e4426744268;
}
var $ret4427344274 = $Hanf_arg873244278($z4426944270,_plus55);
++R.GAS;
return $ret4427344274;
};
var $Hanf_arg873244278 = function(anf_arg129644277,_plus55) {
var $z4428144282 = D;
var $f4428744288 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg129644277):R.ffi.throwNonFunApp(L[2270],_plus55,[("("),anf_arg129644277]);
};
try {
if(--R.GAS > 0) {
$z4428144282 = $f4428744288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4428744288,
"from":L[2270]});
}
} catch($e4427944280) {
if(R.isCont($e4427944280)) {
var $ss4428344284 = {"from":L[2270],
"go":function(anf_arg129744289) {
return $Hanf_arg873144290(anf_arg129744289,_plus55);
}};
$e4427944280.stack[R.EXN_STACKHEIGHT++] = $ss4428344284;
}
if(R.isPyretException($e4427944280)) {
$e4427944280.pyretStack.push(L[2270]);
}
throw $e4427944280;
}
var $ret4428544286 = $Hanf_arg873144290($z4428144282,_plus55);
++R.GAS;
return $ret4428544286;
};
var $Hanf_arg873144290 = function(anf_arg129744289,_plus55) {
var $z4429344294 = D;
var $f4429944300 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-module"),anf_arg129744289):R.ffi.throwNonFunApp(L[2270],_plus55,[("s-module"),anf_arg129744289]);
};
try {
if(--R.GAS > 0) {
$z4429344294 = $f4429944300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4429944300,
"from":L[2270]});
}
} catch($e4429144292) {
if(R.isCont($e4429144292)) {
var $ss4429544296 = {"from":L[2270],
"go":function(ann_DASH_check_DASH_temp127744301) {
return $Hann_DASH_check_DASH_temp873044302(ann_DASH_check_DASH_temp127744301);
}};
$e4429144292.stack[R.EXN_STACKHEIGHT++] = $ss4429544296;
}
if(R.isPyretException($e4429144292)) {
$e4429144292.pyretStack.push(L[2270]);
}
throw $e4429144292;
}
var $ret4429744298 = $Hann_DASH_check_DASH_temp873044302($z4429344294);
++R.GAS;
return $ret4429744298;
};
var $Hann_DASH_check_DASH_temp873044302 = function(ann_DASH_check_DASH_temp127744301) {
return ann_DASH_check_DASH_temp127744301;
};
var $Hcont_tail_arg872816794 = function(cont_tail_arg127416792,if_helper126216793) {
if(--R.GAS > 0) {
$z4430344304 = R.isFunction(if_helper126216793)?if_helper126216793.app(cont_tail_arg127416792):R.ffi.throwNonFunApp(L[2270],if_helper126216793,[cont_tail_arg127416792]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper126216793)?if_helper126216793.app(cont_tail_arg127416792):R.ffi.throwNonFunApp(L[2270],if_helper126216793,[cont_tail_arg127416792]);
},
"from":L[2270]});
}
++R.GAS;
return $z4430344304;
};
var $Hcont_tail_arg872916809 = function(cont_tail_arg126716808,if_helper126216793) {
if(--R.GAS > 0) {
$z4430544306 = R.isFunction(if_helper126216793)?if_helper126216793.app(cont_tail_arg126716808):R.ffi.throwNonFunApp(L[2270],if_helper126216793,[cont_tail_arg126716808]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper126216793)?if_helper126216793.app(cont_tail_arg126716808):R.ffi.throwNonFunApp(L[2270],if_helper126216793,[cont_tail_arg126716808]);
},
"from":L[2270]});
}
++R.GAS;
return $z4430544306;
};
var $Hann_DASH_check_DASH_temp872716831 = function(ann_DASH_check_DASH_temp125316830) {
return ann_DASH_check_DASH_temp125316830;
};
var $Hanf_arg872616844 = function(anf_arg125716843,_plus55,raise62) {
var $z4430944310 = D;
var $f4431544316 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg125716843):R.ffi.throwNonFunApp(L[4738],_plus55,[("No visitor field for "),anf_arg125716843]);
};
try {
if(--R.GAS > 0) {
$z4430944310 = $f4431544316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4431544316,
"from":L[4738]});
}
} catch($e4430744308) {
if(R.isCont($e4430744308)) {
var $ss4431144312 = {"from":L[4738],
"go":function(anf_arg125844317) {
return $Hanf_arg872544318(anf_arg125844317,raise62);
}};
$e4430744308.stack[R.EXN_STACKHEIGHT++] = $ss4431144312;
}
if(R.isPyretException($e4430744308)) {
$e4430744308.pyretStack.push(L[4738]);
}
throw $e4430744308;
}
var $ret4431344314 = $Hanf_arg872544318($z4430944310,raise62);
++R.GAS;
return $ret4431344314;
};
var $Hanf_arg872544318 = function(anf_arg125844317,raise62) {
var $z4432144322 = D;
var $f4432744328 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg125844317):R.ffi.throwNonFunApp(L[3027],raise62,[anf_arg125844317]);
};
try {
if(--R.GAS > 0) {
$z4432144322 = $f4432744328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4432744328,
"from":L[3027]});
}
} catch($e4431944320) {
if(R.isCont($e4431944320)) {
var $ss4432344324 = {"from":L[3027],
"go":function(ann_DASH_check_DASH_temp125544329) {
return $Hann_DASH_check_DASH_temp872444330(ann_DASH_check_DASH_temp125544329);
}};
$e4431944320.stack[R.EXN_STACKHEIGHT++] = $ss4432344324;
}
if(R.isPyretException($e4431944320)) {
$e4431944320.pyretStack.push(L[3027]);
}
throw $e4431944320;
}
var $ret4432544326 = $Hann_DASH_check_DASH_temp872444330($z4432144322);
++R.GAS;
return $ret4432544326;
};
var $Hann_DASH_check_DASH_temp872444330 = function(ann_DASH_check_DASH_temp125544329) {
return ann_DASH_check_DASH_temp125544329;
};
var $Hanf_arg872316886 = function(anf_arg123516882,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,str_DASH_newtype176910,_plus55) {
var $z4433344334 = D;
var $f4433944340 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_newtype176910,anf_arg123516882):R.ffi.throwNonFunApp(L[4739],_plus55,[str_DASH_newtype176910,anf_arg123516882]);
};
try {
if(--R.GAS > 0) {
$z4433344334 = $f4433944340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4433944340,
"from":L[4739]});
}
} catch($e4433144332) {
if(R.isCont($e4433144332)) {
var $ss4433544336 = {"from":L[4739],
"go":function(anf_arg123644341) {
return $Hanf_arg872244342(anf_arg123644341,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,_plus55);
}};
$e4433144332.stack[R.EXN_STACKHEIGHT++] = $ss4433544336;
}
if(R.isPyretException($e4433144332)) {
$e4433144332.pyretStack.push(L[4739]);
}
throw $e4433144332;
}
var $ret4433744338 = $Hanf_arg872244342($z4433344334,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,_plus55);
++R.GAS;
return $ret4433744338;
};
var $Hanf_arg872244342 = function(anf_arg123644341,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,_plus55) {
var $z4434544346 = D;
var $f4435144352 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg123644341,break_DASH_one119168):R.ffi.throwNonFunApp(L[4739],_plus55,[anf_arg123644341,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4434544346 = $f4435144352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4435144352,
"from":L[4739]});
}
} catch($e4434344344) {
if(R.isCont($e4434344344)) {
var $ss4434744348 = {"from":L[4739],
"go":function(anf_arg123744353) {
return $Hanf_arg872144354(anf_arg123744353,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,_plus55);
}};
$e4434344344.stack[R.EXN_STACKHEIGHT++] = $ss4434744348;
}
if(R.isPyretException($e4434344344)) {
$e4434344344.pyretStack.push(L[4739]);
}
throw $e4434344344;
}
var $ret4434944350 = $Hanf_arg872144354($z4434544346,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,_plus55);
++R.GAS;
return $ret4434944350;
};
var $Hanf_arg872144354 = function(anf_arg123744353,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,str_DASH_as123221,_plus55) {
var $z4435744358 = D;
var $f4436344364 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg123744353,str_DASH_as123221):R.ffi.throwNonFunApp(L[4739],_plus55,[anf_arg123744353,str_DASH_as123221]);
};
try {
if(--R.GAS > 0) {
$z4435744358 = $f4436344364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4436344364,
"from":L[4739]});
}
} catch($e4435544356) {
if(R.isCont($e4435544356)) {
var $ss4435944360 = {"from":L[4739],
"go":function(anf_arg123844365) {
return $Hanf_arg872044366(anf_arg123844365,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,_plus55);
}};
$e4435544356.stack[R.EXN_STACKHEIGHT++] = $ss4435944360;
}
if(R.isPyretException($e4435544356)) {
$e4435544356.pyretStack.push(L[4739]);
}
throw $e4435544356;
}
var $ret4436144362 = $Hanf_arg872044366($z4435744358,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,_plus55);
++R.GAS;
return $ret4436144362;
};
var $Hanf_arg872044366 = function(anf_arg123844365,INDENT118169,anf_fun123116883,anf_fun123216884,break_DASH_one119168,self64516885,_plus55) {
var $z4436944370 = D;
var $f4437544376 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg123844365,break_DASH_one119168):R.ffi.throwNonFunApp(L[4739],_plus55,[anf_arg123844365,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4436944370 = $f4437544376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4437544376,
"from":L[4739]});
}
} catch($e4436744368) {
if(R.isCont($e4436744368)) {
var $ss4437144372 = {"from":L[4739],
"go":function(anf_arg123944377) {
return $Hanf_arg871944378(anf_arg123944377,INDENT118169,anf_fun123116883,anf_fun123216884,self64516885,_plus55);
}};
$e4436744368.stack[R.EXN_STACKHEIGHT++] = $ss4437144372;
}
if(R.isPyretException($e4436744368)) {
$e4436744368.pyretStack.push(L[4739]);
}
throw $e4436744368;
}
var $ret4437344374 = $Hanf_arg871944378($z4436944370,INDENT118169,anf_fun123116883,anf_fun123216884,self64516885,_plus55);
++R.GAS;
return $ret4437344374;
};
var $Hanf_arg871944378 = function(anf_arg123944377,INDENT118169,anf_fun123116883,anf_fun123216884,self64516885,_plus55) {
var anf_bracket124044392 = G(self64516885,"namet",L[4742]);
var anf_fun124144389 = G(anf_bracket124044392,"tosource",L[4741]);
var $z4438144382 = D;
var $f4438744388 = function(_) {
return R.isFunction(anf_fun124144389)?anf_fun124144389.app():R.ffi.throwNonFunApp(L[4740],anf_fun124144389,[]);
};
try {
if(--R.GAS > 0) {
$z4438144382 = $f4438744388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4438744388,
"from":L[4740]});
}
} catch($e4437944380) {
if(R.isCont($e4437944380)) {
var $ss4438344384 = {"from":L[4740],
"go":function(anf_arg124244390) {
return $Hanf_arg871844391(anf_arg124244390,INDENT118169,anf_arg123944377,anf_fun123116883,anf_fun123216884,_plus55);
}};
$e4437944380.stack[R.EXN_STACKHEIGHT++] = $ss4438344384;
}
if(R.isPyretException($e4437944380)) {
$e4437944380.pyretStack.push(L[4740]);
}
throw $e4437944380;
}
var $ret4438544386 = $Hanf_arg871844391($z4438144382,INDENT118169,anf_arg123944377,anf_fun123116883,anf_fun123216884,_plus55);
++R.GAS;
return $ret4438544386;
};
var $Hanf_arg871844391 = function(anf_arg124244390,INDENT118169,anf_arg123944377,anf_fun123116883,anf_fun123216884,_plus55) {
var $z4439544396 = D;
var $f4440144402 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg123944377,anf_arg124244390):R.ffi.throwNonFunApp(L[4739],_plus55,[anf_arg123944377,anf_arg124244390]);
};
try {
if(--R.GAS > 0) {
$z4439544396 = $f4440144402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4440144402,
"from":L[4739]});
}
} catch($e4439344394) {
if(R.isCont($e4439344394)) {
var $ss4439744398 = {"from":L[4739],
"go":function(anf_arg124344403) {
return $Hanf_arg871744404(anf_arg124344403,INDENT118169,anf_fun123116883,anf_fun123216884);
}};
$e4439344394.stack[R.EXN_STACKHEIGHT++] = $ss4439744398;
}
if(R.isPyretException($e4439344394)) {
$e4439344394.pyretStack.push(L[4739]);
}
throw $e4439344394;
}
var $ret4439944400 = $Hanf_arg871744404($z4439544396,INDENT118169,anf_fun123116883,anf_fun123216884);
++R.GAS;
return $ret4439944400;
};
var $Hanf_arg871744404 = function(anf_arg124344403,INDENT118169,anf_fun123116883,anf_fun123216884) {
var $z4440744408 = D;
var $f4441344414 = function(_) {
return R.isFunction(anf_fun123216884)?anf_fun123216884.app(INDENT118169,anf_arg124344403):R.ffi.throwNonFunApp(L[4743],anf_fun123216884,[INDENT118169,anf_arg124344403]);
};
try {
if(--R.GAS > 0) {
$z4440744408 = $f4441344414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4441344414,
"from":L[4743]});
}
} catch($e4440544406) {
if(R.isCont($e4440544406)) {
var $ss4440944410 = {"from":L[4743],
"go":function(anf_arg124444415) {
return $Hanf_arg871644416(anf_arg124444415,anf_fun123116883);
}};
$e4440544406.stack[R.EXN_STACKHEIGHT++] = $ss4440944410;
}
if(R.isPyretException($e4440544406)) {
$e4440544406.pyretStack.push(L[4743]);
}
throw $e4440544406;
}
var $ret4441144412 = $Hanf_arg871644416($z4440744408,anf_fun123116883);
++R.GAS;
return $ret4441144412;
};
var $Hanf_arg871644416 = function(anf_arg124444415,anf_fun123116883) {
var $z4441944420 = D;
var $f4442544426 = function(_) {
return R.isFunction(anf_fun123116883)?anf_fun123116883.app(anf_arg124444415):R.ffi.throwNonFunApp(L[3047],anf_fun123116883,[anf_arg124444415]);
};
try {
if(--R.GAS > 0) {
$z4441944420 = $f4442544426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4442544426,
"from":L[3047]});
}
} catch($e4441744418) {
if(R.isCont($e4441744418)) {
var $ss4442144422 = {"from":L[3047],
"go":function(ann_DASH_check_DASH_temp123044427) {
return $Hann_DASH_check_DASH_temp871544428(ann_DASH_check_DASH_temp123044427);
}};
$e4441744418.stack[R.EXN_STACKHEIGHT++] = $ss4442144422;
}
if(R.isPyretException($e4441744418)) {
$e4441744418.pyretStack.push(L[3047]);
}
throw $e4441744418;
}
var $ret4442344424 = $Hann_DASH_check_DASH_temp871544428($z4441944420);
++R.GAS;
return $ret4442344424;
};
var $Hann_DASH_check_DASH_temp871544428 = function(ann_DASH_check_DASH_temp123044427) {
return ann_DASH_check_DASH_temp123044427;
};
var $Hanf_arg871416903 = function(anf_arg121616901,self15316902,_plus55,torepr65) {
var anf_arg121744439 = G(self15316902,"name",L[3031]);
var $z4443144432 = D;
var $f4443744438 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg121744439):R.ffi.throwNonFunApp(L[3031],torepr65,[anf_arg121744439]);
};
try {
if(--R.GAS > 0) {
$z4443144432 = $f4443744438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4443744438,
"from":L[3031]});
}
} catch($e4442944430) {
if(R.isCont($e4442944430)) {
var $ss4443344434 = {"from":L[3031],
"go":function(anf_arg121844440) {
return $Hanf_arg871344441(anf_arg121844440,anf_arg121616901,self15316902,_plus55,torepr65);
}};
$e4442944430.stack[R.EXN_STACKHEIGHT++] = $ss4443344434;
}
if(R.isPyretException($e4442944430)) {
$e4442944430.pyretStack.push(L[3031]);
}
throw $e4442944430;
}
var $ret4443544436 = $Hanf_arg871344441($z4443144432,anf_arg121616901,self15316902,_plus55,torepr65);
++R.GAS;
return $ret4443544436;
};
var $Hanf_arg871344441 = function(anf_arg121844440,anf_arg121616901,self15316902,_plus55,torepr65) {
var $z4444444445 = D;
var $f4445044451 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg121844440):R.ffi.throwNonFunApp(L[3031],_plus55,[(", "),anf_arg121844440]);
};
try {
if(--R.GAS > 0) {
$z4444444445 = $f4445044451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4445044451,
"from":L[3031]});
}
} catch($e4444244443) {
if(R.isCont($e4444244443)) {
var $ss4444644447 = {"from":L[3031],
"go":function(anf_arg121944452) {
return $Hanf_arg871244453(anf_arg121944452,anf_arg121616901,self15316902,_plus55,torepr65);
}};
$e4444244443.stack[R.EXN_STACKHEIGHT++] = $ss4444644447;
}
if(R.isPyretException($e4444244443)) {
$e4444244443.pyretStack.push(L[3031]);
}
throw $e4444244443;
}
var $ret4444844449 = $Hanf_arg871244453($z4444444445,anf_arg121616901,self15316902,_plus55,torepr65);
++R.GAS;
return $ret4444844449;
};
var $Hanf_arg871244453 = function(anf_arg121944452,anf_arg121616901,self15316902,_plus55,torepr65) {
var $z4445644457 = D;
var $f4446244463 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg121616901,anf_arg121944452):R.ffi.throwNonFunApp(L[3031],_plus55,[anf_arg121616901,anf_arg121944452]);
};
try {
if(--R.GAS > 0) {
$z4445644457 = $f4446244463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4446244463,
"from":L[3031]});
}
} catch($e4445444455) {
if(R.isCont($e4445444455)) {
var $ss4445844459 = {"from":L[3031],
"go":function(anf_arg122044464) {
return $Hanf_arg871144465(anf_arg122044464,self15316902,_plus55,torepr65);
}};
$e4445444455.stack[R.EXN_STACKHEIGHT++] = $ss4445844459;
}
if(R.isPyretException($e4445444455)) {
$e4445444455.pyretStack.push(L[3031]);
}
throw $e4445444455;
}
var $ret4446044461 = $Hanf_arg871144465($z4445644457,self15316902,_plus55,torepr65);
++R.GAS;
return $ret4446044461;
};
var $Hanf_arg871144465 = function(anf_arg122044464,self15316902,_plus55,torepr65) {
var anf_arg122144476 = G(self15316902,"namet",L[3031]);
var $z4446844469 = D;
var $f4447444475 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg122144476):R.ffi.throwNonFunApp(L[3031],torepr65,[anf_arg122144476]);
};
try {
if(--R.GAS > 0) {
$z4446844469 = $f4447444475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4447444475,
"from":L[3031]});
}
} catch($e4446644467) {
if(R.isCont($e4446644467)) {
var $ss4447044471 = {"from":L[3031],
"go":function(anf_arg122244477) {
return $Hanf_arg871044478(anf_arg122244477,anf_arg122044464,_plus55);
}};
$e4446644467.stack[R.EXN_STACKHEIGHT++] = $ss4447044471;
}
if(R.isPyretException($e4446644467)) {
$e4446644467.pyretStack.push(L[3031]);
}
throw $e4446644467;
}
var $ret4447244473 = $Hanf_arg871044478($z4446844469,anf_arg122044464,_plus55);
++R.GAS;
return $ret4447244473;
};
var $Hanf_arg871044478 = function(anf_arg122244477,anf_arg122044464,_plus55) {
var $z4448144482 = D;
var $f4448744488 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg122244477):R.ffi.throwNonFunApp(L[3031],_plus55,[(", "),anf_arg122244477]);
};
try {
if(--R.GAS > 0) {
$z4448144482 = $f4448744488();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4448744488,
"from":L[3031]});
}
} catch($e4447944480) {
if(R.isCont($e4447944480)) {
var $ss4448344484 = {"from":L[3031],
"go":function(anf_arg122344489) {
return $Hanf_arg870944490(anf_arg122344489,anf_arg122044464,_plus55);
}};
$e4447944480.stack[R.EXN_STACKHEIGHT++] = $ss4448344484;
}
if(R.isPyretException($e4447944480)) {
$e4447944480.pyretStack.push(L[3031]);
}
throw $e4447944480;
}
var $ret4448544486 = $Hanf_arg870944490($z4448144482,anf_arg122044464,_plus55);
++R.GAS;
return $ret4448544486;
};
var $Hanf_arg870944490 = function(anf_arg122344489,anf_arg122044464,_plus55) {
var $z4449344494 = D;
var $f4449944500 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg122044464,anf_arg122344489):R.ffi.throwNonFunApp(L[3031],_plus55,[anf_arg122044464,anf_arg122344489]);
};
try {
if(--R.GAS > 0) {
$z4449344494 = $f4449944500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4449944500,
"from":L[3031]});
}
} catch($e4449144492) {
if(R.isCont($e4449144492)) {
var $ss4449544496 = {"from":L[3031],
"go":function(anf_arg122444501) {
return $Hanf_arg870844502(anf_arg122444501,_plus55);
}};
$e4449144492.stack[R.EXN_STACKHEIGHT++] = $ss4449544496;
}
if(R.isPyretException($e4449144492)) {
$e4449144492.pyretStack.push(L[3031]);
}
throw $e4449144492;
}
var $ret4449744498 = $Hanf_arg870844502($z4449344494,_plus55);
++R.GAS;
return $ret4449744498;
};
var $Hanf_arg870844502 = function(anf_arg122444501,_plus55) {
var $z4450544506 = D;
var $f4451144512 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg122444501,(")")):R.ffi.throwNonFunApp(L[3031],_plus55,[anf_arg122444501,(")")]);
};
try {
if(--R.GAS > 0) {
$z4450544506 = $f4451144512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4451144512,
"from":L[3031]});
}
} catch($e4450344504) {
if(R.isCont($e4450344504)) {
var $ss4450744508 = {"from":L[3031],
"go":function(anf_arg122544513) {
return $Hanf_arg870744514(anf_arg122544513,_plus55);
}};
$e4450344504.stack[R.EXN_STACKHEIGHT++] = $ss4450744508;
}
if(R.isPyretException($e4450344504)) {
$e4450344504.pyretStack.push(L[3031]);
}
throw $e4450344504;
}
var $ret4450944510 = $Hanf_arg870744514($z4450544506,_plus55);
++R.GAS;
return $ret4450944510;
};
var $Hanf_arg870744514 = function(anf_arg122544513,_plus55) {
var $z4451744518 = D;
var $f4452344524 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg122544513):R.ffi.throwNonFunApp(L[3031],_plus55,[("("),anf_arg122544513]);
};
try {
if(--R.GAS > 0) {
$z4451744518 = $f4452344524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4452344524,
"from":L[3031]});
}
} catch($e4451544516) {
if(R.isCont($e4451544516)) {
var $ss4451944520 = {"from":L[3031],
"go":function(anf_arg122644525) {
return $Hanf_arg870644526(anf_arg122644525,_plus55);
}};
$e4451544516.stack[R.EXN_STACKHEIGHT++] = $ss4451944520;
}
if(R.isPyretException($e4451544516)) {
$e4451544516.pyretStack.push(L[3031]);
}
throw $e4451544516;
}
var $ret4452144522 = $Hanf_arg870644526($z4451744518,_plus55);
++R.GAS;
return $ret4452144522;
};
var $Hanf_arg870644526 = function(anf_arg122644525,_plus55) {
var $z4452944530 = D;
var $f4453544536 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-newtype-bind"),anf_arg122644525):R.ffi.throwNonFunApp(L[3031],_plus55,[("s-newtype-bind"),anf_arg122644525]);
};
try {
if(--R.GAS > 0) {
$z4452944530 = $f4453544536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4453544536,
"from":L[3031]});
}
} catch($e4452744528) {
if(R.isCont($e4452744528)) {
var $ss4453144532 = {"from":L[3031],
"go":function(ann_DASH_check_DASH_temp121444537) {
return $Hann_DASH_check_DASH_temp870544538(ann_DASH_check_DASH_temp121444537);
}};
$e4452744528.stack[R.EXN_STACKHEIGHT++] = $ss4453144532;
}
if(R.isPyretException($e4452744528)) {
$e4452744528.pyretStack.push(L[3031]);
}
throw $e4452744528;
}
var $ret4453344534 = $Hann_DASH_check_DASH_temp870544538($z4452944530);
++R.GAS;
return $ret4453344534;
};
var $Hann_DASH_check_DASH_temp870544538 = function(ann_DASH_check_DASH_temp121444537) {
return ann_DASH_check_DASH_temp121444537;
};
var $Hcont_tail_arg870316920 = function(cont_tail_arg121116918,if_helper120116919) {
if(--R.GAS > 0) {
$z4453944540 = R.isFunction(if_helper120116919)?if_helper120116919.app(cont_tail_arg121116918):R.ffi.throwNonFunApp(L[3031],if_helper120116919,[cont_tail_arg121116918]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper120116919)?if_helper120116919.app(cont_tail_arg121116918):R.ffi.throwNonFunApp(L[3031],if_helper120116919,[cont_tail_arg121116918]);
},
"from":L[3031]});
}
++R.GAS;
return $z4453944540;
};
var $Hcont_tail_arg870416935 = function(cont_tail_arg120616934,if_helper120116919) {
if(--R.GAS > 0) {
$z4454144542 = R.isFunction(if_helper120116919)?if_helper120116919.app(cont_tail_arg120616934):R.ffi.throwNonFunApp(L[3031],if_helper120116919,[cont_tail_arg120616934]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper120116919)?if_helper120116919.app(cont_tail_arg120616934):R.ffi.throwNonFunApp(L[3031],if_helper120116919,[cont_tail_arg120616934]);
},
"from":L[3031]});
}
++R.GAS;
return $z4454144542;
};
var $Hanf_arg870216957 = function(anf_arg119116954,INDENT118169,anf_fun118716955,anf_fun118816956,break_DASH_one119168,self64010167,str_DASH_spaceequal170832,_plus55) {
var $z4454544546 = D;
var $f4455144552 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg119116954,str_DASH_spaceequal170832):R.ffi.throwNonFunApp(L[4744],_plus55,[anf_arg119116954,str_DASH_spaceequal170832]);
};
try {
if(--R.GAS > 0) {
$z4454544546 = $f4455144552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4455144552,
"from":L[4744]});
}
} catch($e4454344544) {
if(R.isCont($e4454344544)) {
var $ss4454744548 = {"from":L[4744],
"go":function(anf_arg119244553) {
return $Hanf_arg870144554(anf_arg119244553,INDENT118169,anf_fun118716955,anf_fun118816956,break_DASH_one119168,self64010167,_plus55);
}};
$e4454344544.stack[R.EXN_STACKHEIGHT++] = $ss4454744548;
}
if(R.isPyretException($e4454344544)) {
$e4454344544.pyretStack.push(L[4744]);
}
throw $e4454344544;
}
var $ret4454944550 = $Hanf_arg870144554($z4454544546,INDENT118169,anf_fun118716955,anf_fun118816956,break_DASH_one119168,self64010167,_plus55);
++R.GAS;
return $ret4454944550;
};
var $Hanf_arg870144554 = function(anf_arg119244553,INDENT118169,anf_fun118716955,anf_fun118816956,break_DASH_one119168,self64010167,_plus55) {
var $z4455744558 = D;
var $f4456344564 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg119244553,break_DASH_one119168):R.ffi.throwNonFunApp(L[4744],_plus55,[anf_arg119244553,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4455744558 = $f4456344564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4456344564,
"from":L[4744]});
}
} catch($e4455544556) {
if(R.isCont($e4455544556)) {
var $ss4455944560 = {"from":L[4744],
"go":function(anf_arg119344565) {
return $Hanf_arg870044566(anf_arg119344565,INDENT118169,anf_fun118716955,anf_fun118816956,self64010167,_plus55);
}};
$e4455544556.stack[R.EXN_STACKHEIGHT++] = $ss4455944560;
}
if(R.isPyretException($e4455544556)) {
$e4455544556.pyretStack.push(L[4744]);
}
throw $e4455544556;
}
var $ret4456144562 = $Hanf_arg870044566($z4455744558,INDENT118169,anf_fun118716955,anf_fun118816956,self64010167,_plus55);
++R.GAS;
return $ret4456144562;
};
var $Hanf_arg870044566 = function(anf_arg119344565,INDENT118169,anf_fun118716955,anf_fun118816956,self64010167,_plus55) {
var anf_bracket119444580 = G(self64010167,"ann",L[4747]);
var anf_fun119544577 = G(anf_bracket119444580,"tosource",L[4746]);
var $z4456944570 = D;
var $f4457544576 = function(_) {
return R.isFunction(anf_fun119544577)?anf_fun119544577.app():R.ffi.throwNonFunApp(L[4745],anf_fun119544577,[]);
};
try {
if(--R.GAS > 0) {
$z4456944570 = $f4457544576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4457544576,
"from":L[4745]});
}
} catch($e4456744568) {
if(R.isCont($e4456744568)) {
var $ss4457144572 = {"from":L[4745],
"go":function(anf_arg119644578) {
return $Hanf_arg869944579(anf_arg119644578,INDENT118169,anf_arg119344565,anf_fun118716955,anf_fun118816956,_plus55);
}};
$e4456744568.stack[R.EXN_STACKHEIGHT++] = $ss4457144572;
}
if(R.isPyretException($e4456744568)) {
$e4456744568.pyretStack.push(L[4745]);
}
throw $e4456744568;
}
var $ret4457344574 = $Hanf_arg869944579($z4456944570,INDENT118169,anf_arg119344565,anf_fun118716955,anf_fun118816956,_plus55);
++R.GAS;
return $ret4457344574;
};
var $Hanf_arg869944579 = function(anf_arg119644578,INDENT118169,anf_arg119344565,anf_fun118716955,anf_fun118816956,_plus55) {
var $z4458344584 = D;
var $f4458944590 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg119344565,anf_arg119644578):R.ffi.throwNonFunApp(L[4744],_plus55,[anf_arg119344565,anf_arg119644578]);
};
try {
if(--R.GAS > 0) {
$z4458344584 = $f4458944590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4458944590,
"from":L[4744]});
}
} catch($e4458144582) {
if(R.isCont($e4458144582)) {
var $ss4458544586 = {"from":L[4744],
"go":function(anf_arg119744591) {
return $Hanf_arg869844592(anf_arg119744591,INDENT118169,anf_fun118716955,anf_fun118816956);
}};
$e4458144582.stack[R.EXN_STACKHEIGHT++] = $ss4458544586;
}
if(R.isPyretException($e4458144582)) {
$e4458144582.pyretStack.push(L[4744]);
}
throw $e4458144582;
}
var $ret4458744588 = $Hanf_arg869844592($z4458344584,INDENT118169,anf_fun118716955,anf_fun118816956);
++R.GAS;
return $ret4458744588;
};
var $Hanf_arg869844592 = function(anf_arg119744591,INDENT118169,anf_fun118716955,anf_fun118816956) {
var $z4459544596 = D;
var $f4460144602 = function(_) {
return R.isFunction(anf_fun118816956)?anf_fun118816956.app(INDENT118169,anf_arg119744591):R.ffi.throwNonFunApp(L[4748],anf_fun118816956,[INDENT118169,anf_arg119744591]);
};
try {
if(--R.GAS > 0) {
$z4459544596 = $f4460144602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4460144602,
"from":L[4748]});
}
} catch($e4459344594) {
if(R.isCont($e4459344594)) {
var $ss4459744598 = {"from":L[4748],
"go":function(anf_arg119844603) {
return $Hanf_arg869744604(anf_arg119844603,anf_fun118716955);
}};
$e4459344594.stack[R.EXN_STACKHEIGHT++] = $ss4459744598;
}
if(R.isPyretException($e4459344594)) {
$e4459344594.pyretStack.push(L[4748]);
}
throw $e4459344594;
}
var $ret4459944600 = $Hanf_arg869744604($z4459544596,anf_fun118716955);
++R.GAS;
return $ret4459944600;
};
var $Hanf_arg869744604 = function(anf_arg119844603,anf_fun118716955) {
var $z4460744608 = D;
var $f4461344614 = function(_) {
return R.isFunction(anf_fun118716955)?anf_fun118716955.app(anf_arg119844603):R.ffi.throwNonFunApp(L[3057],anf_fun118716955,[anf_arg119844603]);
};
try {
if(--R.GAS > 0) {
$z4460744608 = $f4461344614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4461344614,
"from":L[3057]});
}
} catch($e4460544606) {
if(R.isCont($e4460544606)) {
var $ss4460944610 = {"from":L[3057],
"go":function(ann_DASH_check_DASH_temp118644615) {
return $Hann_DASH_check_DASH_temp869644616(ann_DASH_check_DASH_temp118644615);
}};
$e4460544606.stack[R.EXN_STACKHEIGHT++] = $ss4460944610;
}
if(R.isPyretException($e4460544606)) {
$e4460544606.pyretStack.push(L[3057]);
}
throw $e4460544606;
}
var $ret4461144612 = $Hann_DASH_check_DASH_temp869644616($z4460744608);
++R.GAS;
return $ret4461144612;
};
var $Hann_DASH_check_DASH_temp869644616 = function(ann_DASH_check_DASH_temp118644615) {
return ann_DASH_check_DASH_temp118644615;
};
var $Hanf_arg869516974 = function(anf_arg117216972,self14716973,_plus55,torepr65) {
var anf_arg117344627 = G(self14716973,"name",L[3032]);
var $z4461944620 = D;
var $f4462544626 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg117344627):R.ffi.throwNonFunApp(L[3032],torepr65,[anf_arg117344627]);
};
try {
if(--R.GAS > 0) {
$z4461944620 = $f4462544626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4462544626,
"from":L[3032]});
}
} catch($e4461744618) {
if(R.isCont($e4461744618)) {
var $ss4462144622 = {"from":L[3032],
"go":function(anf_arg117444628) {
return $Hanf_arg869444629(anf_arg117444628,anf_arg117216972,self14716973,_plus55,torepr65);
}};
$e4461744618.stack[R.EXN_STACKHEIGHT++] = $ss4462144622;
}
if(R.isPyretException($e4461744618)) {
$e4461744618.pyretStack.push(L[3032]);
}
throw $e4461744618;
}
var $ret4462344624 = $Hanf_arg869444629($z4461944620,anf_arg117216972,self14716973,_plus55,torepr65);
++R.GAS;
return $ret4462344624;
};
var $Hanf_arg869444629 = function(anf_arg117444628,anf_arg117216972,self14716973,_plus55,torepr65) {
var $z4463244633 = D;
var $f4463844639 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg117444628):R.ffi.throwNonFunApp(L[3032],_plus55,[(", "),anf_arg117444628]);
};
try {
if(--R.GAS > 0) {
$z4463244633 = $f4463844639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4463844639,
"from":L[3032]});
}
} catch($e4463044631) {
if(R.isCont($e4463044631)) {
var $ss4463444635 = {"from":L[3032],
"go":function(anf_arg117544640) {
return $Hanf_arg869344641(anf_arg117544640,anf_arg117216972,self14716973,_plus55,torepr65);
}};
$e4463044631.stack[R.EXN_STACKHEIGHT++] = $ss4463444635;
}
if(R.isPyretException($e4463044631)) {
$e4463044631.pyretStack.push(L[3032]);
}
throw $e4463044631;
}
var $ret4463644637 = $Hanf_arg869344641($z4463244633,anf_arg117216972,self14716973,_plus55,torepr65);
++R.GAS;
return $ret4463644637;
};
var $Hanf_arg869344641 = function(anf_arg117544640,anf_arg117216972,self14716973,_plus55,torepr65) {
var $z4464444645 = D;
var $f4465044651 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg117216972,anf_arg117544640):R.ffi.throwNonFunApp(L[3032],_plus55,[anf_arg117216972,anf_arg117544640]);
};
try {
if(--R.GAS > 0) {
$z4464444645 = $f4465044651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4465044651,
"from":L[3032]});
}
} catch($e4464244643) {
if(R.isCont($e4464244643)) {
var $ss4464644647 = {"from":L[3032],
"go":function(anf_arg117644652) {
return $Hanf_arg869244653(anf_arg117644652,self14716973,_plus55,torepr65);
}};
$e4464244643.stack[R.EXN_STACKHEIGHT++] = $ss4464644647;
}
if(R.isPyretException($e4464244643)) {
$e4464244643.pyretStack.push(L[3032]);
}
throw $e4464244643;
}
var $ret4464844649 = $Hanf_arg869244653($z4464444645,self14716973,_plus55,torepr65);
++R.GAS;
return $ret4464844649;
};
var $Hanf_arg869244653 = function(anf_arg117644652,self14716973,_plus55,torepr65) {
var anf_arg117744664 = G(self14716973,"ann",L[3032]);
var $z4465644657 = D;
var $f4466244663 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg117744664):R.ffi.throwNonFunApp(L[3032],torepr65,[anf_arg117744664]);
};
try {
if(--R.GAS > 0) {
$z4465644657 = $f4466244663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4466244663,
"from":L[3032]});
}
} catch($e4465444655) {
if(R.isCont($e4465444655)) {
var $ss4465844659 = {"from":L[3032],
"go":function(anf_arg117844665) {
return $Hanf_arg869144666(anf_arg117844665,anf_arg117644652,_plus55);
}};
$e4465444655.stack[R.EXN_STACKHEIGHT++] = $ss4465844659;
}
if(R.isPyretException($e4465444655)) {
$e4465444655.pyretStack.push(L[3032]);
}
throw $e4465444655;
}
var $ret4466044661 = $Hanf_arg869144666($z4465644657,anf_arg117644652,_plus55);
++R.GAS;
return $ret4466044661;
};
var $Hanf_arg869144666 = function(anf_arg117844665,anf_arg117644652,_plus55) {
var $z4466944670 = D;
var $f4467544676 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg117844665):R.ffi.throwNonFunApp(L[3032],_plus55,[(", "),anf_arg117844665]);
};
try {
if(--R.GAS > 0) {
$z4466944670 = $f4467544676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4467544676,
"from":L[3032]});
}
} catch($e4466744668) {
if(R.isCont($e4466744668)) {
var $ss4467144672 = {"from":L[3032],
"go":function(anf_arg117944677) {
return $Hanf_arg869044678(anf_arg117944677,anf_arg117644652,_plus55);
}};
$e4466744668.stack[R.EXN_STACKHEIGHT++] = $ss4467144672;
}
if(R.isPyretException($e4466744668)) {
$e4466744668.pyretStack.push(L[3032]);
}
throw $e4466744668;
}
var $ret4467344674 = $Hanf_arg869044678($z4466944670,anf_arg117644652,_plus55);
++R.GAS;
return $ret4467344674;
};
var $Hanf_arg869044678 = function(anf_arg117944677,anf_arg117644652,_plus55) {
var $z4468144682 = D;
var $f4468744688 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg117644652,anf_arg117944677):R.ffi.throwNonFunApp(L[3032],_plus55,[anf_arg117644652,anf_arg117944677]);
};
try {
if(--R.GAS > 0) {
$z4468144682 = $f4468744688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4468744688,
"from":L[3032]});
}
} catch($e4467944680) {
if(R.isCont($e4467944680)) {
var $ss4468344684 = {"from":L[3032],
"go":function(anf_arg118044689) {
return $Hanf_arg868944690(anf_arg118044689,_plus55);
}};
$e4467944680.stack[R.EXN_STACKHEIGHT++] = $ss4468344684;
}
if(R.isPyretException($e4467944680)) {
$e4467944680.pyretStack.push(L[3032]);
}
throw $e4467944680;
}
var $ret4468544686 = $Hanf_arg868944690($z4468144682,_plus55);
++R.GAS;
return $ret4468544686;
};
var $Hanf_arg868944690 = function(anf_arg118044689,_plus55) {
var $z4469344694 = D;
var $f4469944700 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg118044689,(")")):R.ffi.throwNonFunApp(L[3032],_plus55,[anf_arg118044689,(")")]);
};
try {
if(--R.GAS > 0) {
$z4469344694 = $f4469944700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4469944700,
"from":L[3032]});
}
} catch($e4469144692) {
if(R.isCont($e4469144692)) {
var $ss4469544696 = {"from":L[3032],
"go":function(anf_arg118144701) {
return $Hanf_arg868844702(anf_arg118144701,_plus55);
}};
$e4469144692.stack[R.EXN_STACKHEIGHT++] = $ss4469544696;
}
if(R.isPyretException($e4469144692)) {
$e4469144692.pyretStack.push(L[3032]);
}
throw $e4469144692;
}
var $ret4469744698 = $Hanf_arg868844702($z4469344694,_plus55);
++R.GAS;
return $ret4469744698;
};
var $Hanf_arg868844702 = function(anf_arg118144701,_plus55) {
var $z4470544706 = D;
var $f4471144712 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg118144701):R.ffi.throwNonFunApp(L[3032],_plus55,[("("),anf_arg118144701]);
};
try {
if(--R.GAS > 0) {
$z4470544706 = $f4471144712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4471144712,
"from":L[3032]});
}
} catch($e4470344704) {
if(R.isCont($e4470344704)) {
var $ss4470744708 = {"from":L[3032],
"go":function(anf_arg118244713) {
return $Hanf_arg868744714(anf_arg118244713,_plus55);
}};
$e4470344704.stack[R.EXN_STACKHEIGHT++] = $ss4470744708;
}
if(R.isPyretException($e4470344704)) {
$e4470344704.pyretStack.push(L[3032]);
}
throw $e4470344704;
}
var $ret4470944710 = $Hanf_arg868744714($z4470544706,_plus55);
++R.GAS;
return $ret4470944710;
};
var $Hanf_arg868744714 = function(anf_arg118244713,_plus55) {
var $z4471744718 = D;
var $f4472344724 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-type-bind"),anf_arg118244713):R.ffi.throwNonFunApp(L[3032],_plus55,[("s-type-bind"),anf_arg118244713]);
};
try {
if(--R.GAS > 0) {
$z4471744718 = $f4472344724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4472344724,
"from":L[3032]});
}
} catch($e4471544716) {
if(R.isCont($e4471544716)) {
var $ss4471944720 = {"from":L[3032],
"go":function(ann_DASH_check_DASH_temp117044725) {
return $Hann_DASH_check_DASH_temp868644726(ann_DASH_check_DASH_temp117044725);
}};
$e4471544716.stack[R.EXN_STACKHEIGHT++] = $ss4471944720;
}
if(R.isPyretException($e4471544716)) {
$e4471544716.pyretStack.push(L[3032]);
}
throw $e4471544716;
}
var $ret4472144722 = $Hann_DASH_check_DASH_temp868644726($z4471744718);
++R.GAS;
return $ret4472144722;
};
var $Hann_DASH_check_DASH_temp868644726 = function(ann_DASH_check_DASH_temp117044725) {
return ann_DASH_check_DASH_temp117044725;
};
var $Hcont_tail_arg868416991 = function(cont_tail_arg116716989,if_helper115716990) {
if(--R.GAS > 0) {
$z4472744728 = R.isFunction(if_helper115716990)?if_helper115716990.app(cont_tail_arg116716989):R.ffi.throwNonFunApp(L[3032],if_helper115716990,[cont_tail_arg116716989]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper115716990)?if_helper115716990.app(cont_tail_arg116716989):R.ffi.throwNonFunApp(L[3032],if_helper115716990,[cont_tail_arg116716989]);
},
"from":L[3032]});
}
++R.GAS;
return $z4472744728;
};
var $Hcont_tail_arg868517006 = function(cont_tail_arg116217005,if_helper115716990) {
if(--R.GAS > 0) {
$z4472944730 = R.isFunction(if_helper115716990)?if_helper115716990.app(cont_tail_arg116217005):R.ffi.throwNonFunApp(L[3032],if_helper115716990,[cont_tail_arg116217005]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper115716990)?if_helper115716990.app(cont_tail_arg116217005):R.ffi.throwNonFunApp(L[3032],if_helper115716990,[cont_tail_arg116217005]);
},
"from":L[3032]});
}
++R.GAS;
return $z4472944730;
};
var $Hann_DASH_check_DASH_temp868317028 = function(ann_DASH_check_DASH_temp114817027) {
return ann_DASH_check_DASH_temp114817027;
};
var $Hanf_arg868217041 = function(anf_arg115217040,_plus55,raise62) {
var $z4473344734 = D;
var $f4473944740 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg115217040):R.ffi.throwNonFunApp(L[4749],_plus55,[("No visitor field for "),anf_arg115217040]);
};
try {
if(--R.GAS > 0) {
$z4473344734 = $f4473944740();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4473944740,
"from":L[4749]});
}
} catch($e4473144732) {
if(R.isCont($e4473144732)) {
var $ss4473544736 = {"from":L[4749],
"go":function(anf_arg115344741) {
return $Hanf_arg868144742(anf_arg115344741,raise62);
}};
$e4473144732.stack[R.EXN_STACKHEIGHT++] = $ss4473544736;
}
if(R.isPyretException($e4473144732)) {
$e4473144732.pyretStack.push(L[4749]);
}
throw $e4473144732;
}
var $ret4473744738 = $Hanf_arg868144742($z4473344734,raise62);
++R.GAS;
return $ret4473744738;
};
var $Hanf_arg868144742 = function(anf_arg115344741,raise62) {
var $z4474544746 = D;
var $f4475144752 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg115344741):R.ffi.throwNonFunApp(L[3063],raise62,[anf_arg115344741]);
};
try {
if(--R.GAS > 0) {
$z4474544746 = $f4475144752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4475144752,
"from":L[3063]});
}
} catch($e4474344744) {
if(R.isCont($e4474344744)) {
var $ss4474744748 = {"from":L[3063],
"go":function(ann_DASH_check_DASH_temp115044753) {
return $Hann_DASH_check_DASH_temp868044754(ann_DASH_check_DASH_temp115044753);
}};
$e4474344744.stack[R.EXN_STACKHEIGHT++] = $ss4474744748;
}
if(R.isPyretException($e4474344744)) {
$e4474344744.pyretStack.push(L[3063]);
}
throw $e4474344744;
}
var $ret4474944750 = $Hann_DASH_check_DASH_temp868044754($z4474544746);
++R.GAS;
return $ret4474944750;
};
var $Hann_DASH_check_DASH_temp868044754 = function(ann_DASH_check_DASH_temp115044753) {
return ann_DASH_check_DASH_temp115044753;
};
var $Hanf_arg867917069 = function(anf_arg113417065,INDENT118169,anf_fun113017066,anf_fun113117067,break_DASH_one119168,self63317068,str_DASH_spaceequal170832,_plus55) {
var $z4475744758 = D;
var $f4476344764 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg113417065,str_DASH_spaceequal170832):R.ffi.throwNonFunApp(L[4750],_plus55,[anf_arg113417065,str_DASH_spaceequal170832]);
};
try {
if(--R.GAS > 0) {
$z4475744758 = $f4476344764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4476344764,
"from":L[4750]});
}
} catch($e4475544756) {
if(R.isCont($e4475544756)) {
var $ss4475944760 = {"from":L[4750],
"go":function(anf_arg113544765) {
return $Hanf_arg867844766(anf_arg113544765,INDENT118169,anf_fun113017066,anf_fun113117067,break_DASH_one119168,self63317068,_plus55);
}};
$e4475544756.stack[R.EXN_STACKHEIGHT++] = $ss4475944760;
}
if(R.isPyretException($e4475544756)) {
$e4475544756.pyretStack.push(L[4750]);
}
throw $e4475544756;
}
var $ret4476144762 = $Hanf_arg867844766($z4475744758,INDENT118169,anf_fun113017066,anf_fun113117067,break_DASH_one119168,self63317068,_plus55);
++R.GAS;
return $ret4476144762;
};
var $Hanf_arg867844766 = function(anf_arg113544765,INDENT118169,anf_fun113017066,anf_fun113117067,break_DASH_one119168,self63317068,_plus55) {
var $z4476944770 = D;
var $f4477544776 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg113544765,break_DASH_one119168):R.ffi.throwNonFunApp(L[4750],_plus55,[anf_arg113544765,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4476944770 = $f4477544776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4477544776,
"from":L[4750]});
}
} catch($e4476744768) {
if(R.isCont($e4476744768)) {
var $ss4477144772 = {"from":L[4750],
"go":function(anf_arg113644777) {
return $Hanf_arg867744778(anf_arg113644777,INDENT118169,anf_fun113017066,anf_fun113117067,self63317068,_plus55);
}};
$e4476744768.stack[R.EXN_STACKHEIGHT++] = $ss4477144772;
}
if(R.isPyretException($e4476744768)) {
$e4476744768.pyretStack.push(L[4750]);
}
throw $e4476744768;
}
var $ret4477344774 = $Hanf_arg867744778($z4476944770,INDENT118169,anf_fun113017066,anf_fun113117067,self63317068,_plus55);
++R.GAS;
return $ret4477344774;
};
var $Hanf_arg867744778 = function(anf_arg113644777,INDENT118169,anf_fun113017066,anf_fun113117067,self63317068,_plus55) {
var anf_bracket113744792 = G(self63317068,"value",L[4753]);
var anf_fun113844789 = G(anf_bracket113744792,"tosource",L[4752]);
var $z4478144782 = D;
var $f4478744788 = function(_) {
return R.isFunction(anf_fun113844789)?anf_fun113844789.app():R.ffi.throwNonFunApp(L[4751],anf_fun113844789,[]);
};
try {
if(--R.GAS > 0) {
$z4478144782 = $f4478744788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4478744788,
"from":L[4751]});
}
} catch($e4477944780) {
if(R.isCont($e4477944780)) {
var $ss4478344784 = {"from":L[4751],
"go":function(anf_arg113944790) {
return $Hanf_arg867644791(anf_arg113944790,INDENT118169,anf_arg113644777,anf_fun113017066,anf_fun113117067,_plus55);
}};
$e4477944780.stack[R.EXN_STACKHEIGHT++] = $ss4478344784;
}
if(R.isPyretException($e4477944780)) {
$e4477944780.pyretStack.push(L[4751]);
}
throw $e4477944780;
}
var $ret4478544786 = $Hanf_arg867644791($z4478144782,INDENT118169,anf_arg113644777,anf_fun113017066,anf_fun113117067,_plus55);
++R.GAS;
return $ret4478544786;
};
var $Hanf_arg867644791 = function(anf_arg113944790,INDENT118169,anf_arg113644777,anf_fun113017066,anf_fun113117067,_plus55) {
var $z4479544796 = D;
var $f4480144802 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg113644777,anf_arg113944790):R.ffi.throwNonFunApp(L[4750],_plus55,[anf_arg113644777,anf_arg113944790]);
};
try {
if(--R.GAS > 0) {
$z4479544796 = $f4480144802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4480144802,
"from":L[4750]});
}
} catch($e4479344794) {
if(R.isCont($e4479344794)) {
var $ss4479744798 = {"from":L[4750],
"go":function(anf_arg114044803) {
return $Hanf_arg867544804(anf_arg114044803,INDENT118169,anf_fun113017066,anf_fun113117067);
}};
$e4479344794.stack[R.EXN_STACKHEIGHT++] = $ss4479744798;
}
if(R.isPyretException($e4479344794)) {
$e4479344794.pyretStack.push(L[4750]);
}
throw $e4479344794;
}
var $ret4479944800 = $Hanf_arg867544804($z4479544796,INDENT118169,anf_fun113017066,anf_fun113117067);
++R.GAS;
return $ret4479944800;
};
var $Hanf_arg867544804 = function(anf_arg114044803,INDENT118169,anf_fun113017066,anf_fun113117067) {
var $z4480744808 = D;
var $f4481344814 = function(_) {
return R.isFunction(anf_fun113117067)?anf_fun113117067.app(INDENT118169,anf_arg114044803):R.ffi.throwNonFunApp(L[4754],anf_fun113117067,[INDENT118169,anf_arg114044803]);
};
try {
if(--R.GAS > 0) {
$z4480744808 = $f4481344814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4481344814,
"from":L[4754]});
}
} catch($e4480544806) {
if(R.isCont($e4480544806)) {
var $ss4480944810 = {"from":L[4754],
"go":function(anf_arg114144815) {
return $Hanf_arg867444816(anf_arg114144815,anf_fun113017066);
}};
$e4480544806.stack[R.EXN_STACKHEIGHT++] = $ss4480944810;
}
if(R.isPyretException($e4480544806)) {
$e4480544806.pyretStack.push(L[4754]);
}
throw $e4480544806;
}
var $ret4481144812 = $Hanf_arg867444816($z4480744808,anf_fun113017066);
++R.GAS;
return $ret4481144812;
};
var $Hanf_arg867444816 = function(anf_arg114144815,anf_fun113017066) {
var $z4481944820 = D;
var $f4482544826 = function(_) {
return R.isFunction(anf_fun113017066)?anf_fun113017066.app(anf_arg114144815):R.ffi.throwNonFunApp(L[3078],anf_fun113017066,[anf_arg114144815]);
};
try {
if(--R.GAS > 0) {
$z4481944820 = $f4482544826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4482544826,
"from":L[3078]});
}
} catch($e4481744818) {
if(R.isCont($e4481744818)) {
var $ss4482144822 = {"from":L[3078],
"go":function(ann_DASH_check_DASH_temp112944827) {
return $Hann_DASH_check_DASH_temp867344828(ann_DASH_check_DASH_temp112944827);
}};
$e4481744818.stack[R.EXN_STACKHEIGHT++] = $ss4482144822;
}
if(R.isPyretException($e4481744818)) {
$e4481744818.pyretStack.push(L[3078]);
}
throw $e4481744818;
}
var $ret4482344824 = $Hann_DASH_check_DASH_temp867344828($z4481944820);
++R.GAS;
return $ret4482344824;
};
var $Hann_DASH_check_DASH_temp867344828 = function(ann_DASH_check_DASH_temp112944827) {
return ann_DASH_check_DASH_temp112944827;
};
var $Hanf_arg867217084 = function(anf_arg111717082,self14117083,_plus55,torepr65) {
var anf_arg111844839 = G(self14117083,"b",L[3067]);
var $z4483144832 = D;
var $f4483744838 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg111844839):R.ffi.throwNonFunApp(L[3067],torepr65,[anf_arg111844839]);
};
try {
if(--R.GAS > 0) {
$z4483144832 = $f4483744838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4483744838,
"from":L[3067]});
}
} catch($e4482944830) {
if(R.isCont($e4482944830)) {
var $ss4483344834 = {"from":L[3067],
"go":function(anf_arg111944840) {
return $Hanf_arg867144841(anf_arg111944840,anf_arg111717082,self14117083,_plus55,torepr65);
}};
$e4482944830.stack[R.EXN_STACKHEIGHT++] = $ss4483344834;
}
if(R.isPyretException($e4482944830)) {
$e4482944830.pyretStack.push(L[3067]);
}
throw $e4482944830;
}
var $ret4483544836 = $Hanf_arg867144841($z4483144832,anf_arg111717082,self14117083,_plus55,torepr65);
++R.GAS;
return $ret4483544836;
};
var $Hanf_arg867144841 = function(anf_arg111944840,anf_arg111717082,self14117083,_plus55,torepr65) {
var $z4484444845 = D;
var $f4485044851 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg111944840):R.ffi.throwNonFunApp(L[3067],_plus55,[(", "),anf_arg111944840]);
};
try {
if(--R.GAS > 0) {
$z4484444845 = $f4485044851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4485044851,
"from":L[3067]});
}
} catch($e4484244843) {
if(R.isCont($e4484244843)) {
var $ss4484644847 = {"from":L[3067],
"go":function(anf_arg112044852) {
return $Hanf_arg867044853(anf_arg112044852,anf_arg111717082,self14117083,_plus55,torepr65);
}};
$e4484244843.stack[R.EXN_STACKHEIGHT++] = $ss4484644847;
}
if(R.isPyretException($e4484244843)) {
$e4484244843.pyretStack.push(L[3067]);
}
throw $e4484244843;
}
var $ret4484844849 = $Hanf_arg867044853($z4484444845,anf_arg111717082,self14117083,_plus55,torepr65);
++R.GAS;
return $ret4484844849;
};
var $Hanf_arg867044853 = function(anf_arg112044852,anf_arg111717082,self14117083,_plus55,torepr65) {
var $z4485644857 = D;
var $f4486244863 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg111717082,anf_arg112044852):R.ffi.throwNonFunApp(L[3067],_plus55,[anf_arg111717082,anf_arg112044852]);
};
try {
if(--R.GAS > 0) {
$z4485644857 = $f4486244863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4486244863,
"from":L[3067]});
}
} catch($e4485444855) {
if(R.isCont($e4485444855)) {
var $ss4485844859 = {"from":L[3067],
"go":function(anf_arg112144864) {
return $Hanf_arg866944865(anf_arg112144864,self14117083,_plus55,torepr65);
}};
$e4485444855.stack[R.EXN_STACKHEIGHT++] = $ss4485844859;
}
if(R.isPyretException($e4485444855)) {
$e4485444855.pyretStack.push(L[3067]);
}
throw $e4485444855;
}
var $ret4486044861 = $Hanf_arg866944865($z4485644857,self14117083,_plus55,torepr65);
++R.GAS;
return $ret4486044861;
};
var $Hanf_arg866944865 = function(anf_arg112144864,self14117083,_plus55,torepr65) {
var anf_arg112244876 = G(self14117083,"value",L[3067]);
var $z4486844869 = D;
var $f4487444875 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg112244876):R.ffi.throwNonFunApp(L[3067],torepr65,[anf_arg112244876]);
};
try {
if(--R.GAS > 0) {
$z4486844869 = $f4487444875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4487444875,
"from":L[3067]});
}
} catch($e4486644867) {
if(R.isCont($e4486644867)) {
var $ss4487044871 = {"from":L[3067],
"go":function(anf_arg112344877) {
return $Hanf_arg866844878(anf_arg112344877,anf_arg112144864,_plus55);
}};
$e4486644867.stack[R.EXN_STACKHEIGHT++] = $ss4487044871;
}
if(R.isPyretException($e4486644867)) {
$e4486644867.pyretStack.push(L[3067]);
}
throw $e4486644867;
}
var $ret4487244873 = $Hanf_arg866844878($z4486844869,anf_arg112144864,_plus55);
++R.GAS;
return $ret4487244873;
};
var $Hanf_arg866844878 = function(anf_arg112344877,anf_arg112144864,_plus55) {
var $z4488144882 = D;
var $f4488744888 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg112344877):R.ffi.throwNonFunApp(L[3067],_plus55,[(", "),anf_arg112344877]);
};
try {
if(--R.GAS > 0) {
$z4488144882 = $f4488744888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4488744888,
"from":L[3067]});
}
} catch($e4487944880) {
if(R.isCont($e4487944880)) {
var $ss4488344884 = {"from":L[3067],
"go":function(anf_arg112444889) {
return $Hanf_arg866744890(anf_arg112444889,anf_arg112144864,_plus55);
}};
$e4487944880.stack[R.EXN_STACKHEIGHT++] = $ss4488344884;
}
if(R.isPyretException($e4487944880)) {
$e4487944880.pyretStack.push(L[3067]);
}
throw $e4487944880;
}
var $ret4488544886 = $Hanf_arg866744890($z4488144882,anf_arg112144864,_plus55);
++R.GAS;
return $ret4488544886;
};
var $Hanf_arg866744890 = function(anf_arg112444889,anf_arg112144864,_plus55) {
var $z4489344894 = D;
var $f4489944900 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg112144864,anf_arg112444889):R.ffi.throwNonFunApp(L[3067],_plus55,[anf_arg112144864,anf_arg112444889]);
};
try {
if(--R.GAS > 0) {
$z4489344894 = $f4489944900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4489944900,
"from":L[3067]});
}
} catch($e4489144892) {
if(R.isCont($e4489144892)) {
var $ss4489544896 = {"from":L[3067],
"go":function(anf_arg112544901) {
return $Hanf_arg866644902(anf_arg112544901,_plus55);
}};
$e4489144892.stack[R.EXN_STACKHEIGHT++] = $ss4489544896;
}
if(R.isPyretException($e4489144892)) {
$e4489144892.pyretStack.push(L[3067]);
}
throw $e4489144892;
}
var $ret4489744898 = $Hanf_arg866644902($z4489344894,_plus55);
++R.GAS;
return $ret4489744898;
};
var $Hanf_arg866644902 = function(anf_arg112544901,_plus55) {
var $z4490544906 = D;
var $f4491144912 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg112544901,(")")):R.ffi.throwNonFunApp(L[3067],_plus55,[anf_arg112544901,(")")]);
};
try {
if(--R.GAS > 0) {
$z4490544906 = $f4491144912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4491144912,
"from":L[3067]});
}
} catch($e4490344904) {
if(R.isCont($e4490344904)) {
var $ss4490744908 = {"from":L[3067],
"go":function(anf_arg112644913) {
return $Hanf_arg866544914(anf_arg112644913,_plus55);
}};
$e4490344904.stack[R.EXN_STACKHEIGHT++] = $ss4490744908;
}
if(R.isPyretException($e4490344904)) {
$e4490344904.pyretStack.push(L[3067]);
}
throw $e4490344904;
}
var $ret4490944910 = $Hanf_arg866544914($z4490544906,_plus55);
++R.GAS;
return $ret4490944910;
};
var $Hanf_arg866544914 = function(anf_arg112644913,_plus55) {
var $z4491744918 = D;
var $f4492344924 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg112644913):R.ffi.throwNonFunApp(L[3067],_plus55,[("("),anf_arg112644913]);
};
try {
if(--R.GAS > 0) {
$z4491744918 = $f4492344924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4492344924,
"from":L[3067]});
}
} catch($e4491544916) {
if(R.isCont($e4491544916)) {
var $ss4491944920 = {"from":L[3067],
"go":function(anf_arg112744925) {
return $Hanf_arg866444926(anf_arg112744925,_plus55);
}};
$e4491544916.stack[R.EXN_STACKHEIGHT++] = $ss4491944920;
}
if(R.isPyretException($e4491544916)) {
$e4491544916.pyretStack.push(L[3067]);
}
throw $e4491544916;
}
var $ret4492144922 = $Hanf_arg866444926($z4491744918,_plus55);
++R.GAS;
return $ret4492144922;
};
var $Hanf_arg866444926 = function(anf_arg112744925,_plus55) {
var $z4492944930 = D;
var $f4493544936 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-letrec-bind"),anf_arg112744925):R.ffi.throwNonFunApp(L[3067],_plus55,[("s-letrec-bind"),anf_arg112744925]);
};
try {
if(--R.GAS > 0) {
$z4492944930 = $f4493544936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4493544936,
"from":L[3067]});
}
} catch($e4492744928) {
if(R.isCont($e4492744928)) {
var $ss4493144932 = {"from":L[3067],
"go":function(ann_DASH_check_DASH_temp111544937) {
return $Hann_DASH_check_DASH_temp866344938(ann_DASH_check_DASH_temp111544937);
}};
$e4492744928.stack[R.EXN_STACKHEIGHT++] = $ss4493144932;
}
if(R.isPyretException($e4492744928)) {
$e4492744928.pyretStack.push(L[3067]);
}
throw $e4492744928;
}
var $ret4493344934 = $Hann_DASH_check_DASH_temp866344938($z4492944930);
++R.GAS;
return $ret4493344934;
};
var $Hann_DASH_check_DASH_temp866344938 = function(ann_DASH_check_DASH_temp111544937) {
return ann_DASH_check_DASH_temp111544937;
};
var $Hcont_tail_arg866117101 = function(cont_tail_arg111217099,if_helper110217100) {
if(--R.GAS > 0) {
$z4493944940 = R.isFunction(if_helper110217100)?if_helper110217100.app(cont_tail_arg111217099):R.ffi.throwNonFunApp(L[3067],if_helper110217100,[cont_tail_arg111217099]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper110217100)?if_helper110217100.app(cont_tail_arg111217099):R.ffi.throwNonFunApp(L[3067],if_helper110217100,[cont_tail_arg111217099]);
},
"from":L[3067]});
}
++R.GAS;
return $z4493944940;
};
var $Hcont_tail_arg866217116 = function(cont_tail_arg110717115,if_helper110217100) {
if(--R.GAS > 0) {
$z4494144942 = R.isFunction(if_helper110217100)?if_helper110217100.app(cont_tail_arg110717115):R.ffi.throwNonFunApp(L[3067],if_helper110217100,[cont_tail_arg110717115]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper110217100)?if_helper110217100.app(cont_tail_arg110717115):R.ffi.throwNonFunApp(L[3067],if_helper110217100,[cont_tail_arg110717115]);
},
"from":L[3067]});
}
++R.GAS;
return $z4494144942;
};
var $Hann_DASH_check_DASH_temp866017138 = function(ann_DASH_check_DASH_temp109317137) {
return ann_DASH_check_DASH_temp109317137;
};
var $Hanf_arg865917151 = function(anf_arg109717150,_plus55,raise62) {
var $z4494544946 = D;
var $f4495144952 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg109717150):R.ffi.throwNonFunApp(L[4755],_plus55,[("No visitor field for "),anf_arg109717150]);
};
try {
if(--R.GAS > 0) {
$z4494544946 = $f4495144952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4495144952,
"from":L[4755]});
}
} catch($e4494344944) {
if(R.isCont($e4494344944)) {
var $ss4494744948 = {"from":L[4755],
"go":function(anf_arg109844953) {
return $Hanf_arg865844954(anf_arg109844953,raise62);
}};
$e4494344944.stack[R.EXN_STACKHEIGHT++] = $ss4494744948;
}
if(R.isPyretException($e4494344944)) {
$e4494344944.pyretStack.push(L[4755]);
}
throw $e4494344944;
}
var $ret4494944950 = $Hanf_arg865844954($z4494544946,raise62);
++R.GAS;
return $ret4494944950;
};
var $Hanf_arg865844954 = function(anf_arg109844953,raise62) {
var $z4495744958 = D;
var $f4496344964 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg109844953):R.ffi.throwNonFunApp(L[3083],raise62,[anf_arg109844953]);
};
try {
if(--R.GAS > 0) {
$z4495744958 = $f4496344964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4496344964,
"from":L[3083]});
}
} catch($e4495544956) {
if(R.isCont($e4495544956)) {
var $ss4495944960 = {"from":L[3083],
"go":function(ann_DASH_check_DASH_temp109544965) {
return $Hann_DASH_check_DASH_temp865744966(ann_DASH_check_DASH_temp109544965);
}};
$e4495544956.stack[R.EXN_STACKHEIGHT++] = $ss4495944960;
}
if(R.isPyretException($e4495544956)) {
$e4495544956.pyretStack.push(L[3083]);
}
throw $e4495544956;
}
var $ret4496144962 = $Hann_DASH_check_DASH_temp865744966($z4495744958);
++R.GAS;
return $ret4496144962;
};
var $Hann_DASH_check_DASH_temp865744966 = function(ann_DASH_check_DASH_temp109544965) {
return ann_DASH_check_DASH_temp109544965;
};
var $Hanf_arg865617190 = function(anf_arg107317186,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55) {
var anf_bracket107444980 = G(self62717189,"b",L[4758]);
var anf_fun107544977 = G(anf_bracket107444980,"tosource",L[4757]);
var $z4496944970 = D;
var $f4497544976 = function(_) {
return R.isFunction(anf_fun107544977)?anf_fun107544977.app():R.ffi.throwNonFunApp(L[4756],anf_fun107544977,[]);
};
try {
if(--R.GAS > 0) {
$z4496944970 = $f4497544976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4497544976,
"from":L[4756]});
}
} catch($e4496744968) {
if(R.isCont($e4496744968)) {
var $ss4497144972 = {"from":L[4756],
"go":function(anf_arg107644978) {
return $Hanf_arg865544979(anf_arg107644978,INDENT118169,anf_arg107317186,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55);
}};
$e4496744968.stack[R.EXN_STACKHEIGHT++] = $ss4497144972;
}
if(R.isPyretException($e4496744968)) {
$e4496744968.pyretStack.push(L[4756]);
}
throw $e4496744968;
}
var $ret4497344974 = $Hanf_arg865544979($z4496944970,INDENT118169,anf_arg107317186,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret4497344974;
};
var $Hanf_arg865544979 = function(anf_arg107644978,INDENT118169,anf_arg107317186,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55) {
var $z4498344984 = D;
var $f4498944990 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg107317186,anf_arg107644978):R.ffi.throwNonFunApp(L[4759],_plus55,[anf_arg107317186,anf_arg107644978]);
};
try {
if(--R.GAS > 0) {
$z4498344984 = $f4498944990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4498944990,
"from":L[4759]});
}
} catch($e4498144982) {
if(R.isCont($e4498144982)) {
var $ss4498544986 = {"from":L[4759],
"go":function(anf_arg107744991) {
return $Hanf_arg865444992(anf_arg107744991,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55);
}};
$e4498144982.stack[R.EXN_STACKHEIGHT++] = $ss4498544986;
}
if(R.isPyretException($e4498144982)) {
$e4498144982.pyretStack.push(L[4759]);
}
throw $e4498144982;
}
var $ret4498744988 = $Hanf_arg865444992($z4498344984,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55);
++R.GAS;
return $ret4498744988;
};
var $Hanf_arg865444992 = function(anf_arg107744991,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,str_DASH_spaceequal170832,_plus55) {
var $z4499544996 = D;
var $f4500145002 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg107744991,str_DASH_spaceequal170832):R.ffi.throwNonFunApp(L[4759],_plus55,[anf_arg107744991,str_DASH_spaceequal170832]);
};
try {
if(--R.GAS > 0) {
$z4499544996 = $f4500145002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4500145002,
"from":L[4759]});
}
} catch($e4499344994) {
if(R.isCont($e4499344994)) {
var $ss4499744998 = {"from":L[4759],
"go":function(anf_arg107845003) {
return $Hanf_arg865345004(anf_arg107845003,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,_plus55);
}};
$e4499344994.stack[R.EXN_STACKHEIGHT++] = $ss4499744998;
}
if(R.isPyretException($e4499344994)) {
$e4499344994.pyretStack.push(L[4759]);
}
throw $e4499344994;
}
var $ret4499945000 = $Hanf_arg865345004($z4499544996,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,_plus55);
++R.GAS;
return $ret4499945000;
};
var $Hanf_arg865345004 = function(anf_arg107845003,INDENT118169,anf_fun107017187,anf_fun107117188,break_DASH_one119168,self62717189,_plus55) {
var $z4500745008 = D;
var $f4501345014 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg107845003,break_DASH_one119168):R.ffi.throwNonFunApp(L[4759],_plus55,[anf_arg107845003,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4500745008 = $f4501345014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4501345014,
"from":L[4759]});
}
} catch($e4500545006) {
if(R.isCont($e4500545006)) {
var $ss4500945010 = {"from":L[4759],
"go":function(anf_arg107945015) {
return $Hanf_arg865245016(anf_arg107945015,INDENT118169,anf_fun107017187,anf_fun107117188,self62717189,_plus55);
}};
$e4500545006.stack[R.EXN_STACKHEIGHT++] = $ss4500945010;
}
if(R.isPyretException($e4500545006)) {
$e4500545006.pyretStack.push(L[4759]);
}
throw $e4500545006;
}
var $ret4501145012 = $Hanf_arg865245016($z4500745008,INDENT118169,anf_fun107017187,anf_fun107117188,self62717189,_plus55);
++R.GAS;
return $ret4501145012;
};
var $Hanf_arg865245016 = function(anf_arg107945015,INDENT118169,anf_fun107017187,anf_fun107117188,self62717189,_plus55) {
var anf_bracket108045030 = G(self62717189,"value",L[4762]);
var anf_fun108145027 = G(anf_bracket108045030,"tosource",L[4761]);
var $z4501945020 = D;
var $f4502545026 = function(_) {
return R.isFunction(anf_fun108145027)?anf_fun108145027.app():R.ffi.throwNonFunApp(L[4760],anf_fun108145027,[]);
};
try {
if(--R.GAS > 0) {
$z4501945020 = $f4502545026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4502545026,
"from":L[4760]});
}
} catch($e4501745018) {
if(R.isCont($e4501745018)) {
var $ss4502145022 = {"from":L[4760],
"go":function(anf_arg108245028) {
return $Hanf_arg865145029(anf_arg108245028,INDENT118169,anf_arg107945015,anf_fun107017187,anf_fun107117188,_plus55);
}};
$e4501745018.stack[R.EXN_STACKHEIGHT++] = $ss4502145022;
}
if(R.isPyretException($e4501745018)) {
$e4501745018.pyretStack.push(L[4760]);
}
throw $e4501745018;
}
var $ret4502345024 = $Hanf_arg865145029($z4501945020,INDENT118169,anf_arg107945015,anf_fun107017187,anf_fun107117188,_plus55);
++R.GAS;
return $ret4502345024;
};
var $Hanf_arg865145029 = function(anf_arg108245028,INDENT118169,anf_arg107945015,anf_fun107017187,anf_fun107117188,_plus55) {
var $z4503345034 = D;
var $f4503945040 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg107945015,anf_arg108245028):R.ffi.throwNonFunApp(L[4759],_plus55,[anf_arg107945015,anf_arg108245028]);
};
try {
if(--R.GAS > 0) {
$z4503345034 = $f4503945040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4503945040,
"from":L[4759]});
}
} catch($e4503145032) {
if(R.isCont($e4503145032)) {
var $ss4503545036 = {"from":L[4759],
"go":function(anf_arg108345041) {
return $Hanf_arg865045042(anf_arg108345041,INDENT118169,anf_fun107017187,anf_fun107117188);
}};
$e4503145032.stack[R.EXN_STACKHEIGHT++] = $ss4503545036;
}
if(R.isPyretException($e4503145032)) {
$e4503145032.pyretStack.push(L[4759]);
}
throw $e4503145032;
}
var $ret4503745038 = $Hanf_arg865045042($z4503345034,INDENT118169,anf_fun107017187,anf_fun107117188);
++R.GAS;
return $ret4503745038;
};
var $Hanf_arg865045042 = function(anf_arg108345041,INDENT118169,anf_fun107017187,anf_fun107117188) {
var $z4504545046 = D;
var $f4505145052 = function(_) {
return R.isFunction(anf_fun107117188)?anf_fun107117188.app(INDENT118169,anf_arg108345041):R.ffi.throwNonFunApp(L[4763],anf_fun107117188,[INDENT118169,anf_arg108345041]);
};
try {
if(--R.GAS > 0) {
$z4504545046 = $f4505145052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4505145052,
"from":L[4763]});
}
} catch($e4504345044) {
if(R.isCont($e4504345044)) {
var $ss4504745048 = {"from":L[4763],
"go":function(anf_arg108445053) {
return $Hanf_arg864945054(anf_arg108445053,anf_fun107017187);
}};
$e4504345044.stack[R.EXN_STACKHEIGHT++] = $ss4504745048;
}
if(R.isPyretException($e4504345044)) {
$e4504345044.pyretStack.push(L[4763]);
}
throw $e4504345044;
}
var $ret4504945050 = $Hanf_arg864945054($z4504545046,anf_fun107017187);
++R.GAS;
return $ret4504945050;
};
var $Hanf_arg864945054 = function(anf_arg108445053,anf_fun107017187) {
var $z4505745058 = D;
var $f4506345064 = function(_) {
return R.isFunction(anf_fun107017187)?anf_fun107017187.app(anf_arg108445053):R.ffi.throwNonFunApp(L[3102],anf_fun107017187,[anf_arg108445053]);
};
try {
if(--R.GAS > 0) {
$z4505745058 = $f4506345064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4506345064,
"from":L[3102]});
}
} catch($e4505545056) {
if(R.isCont($e4505545056)) {
var $ss4505945060 = {"from":L[3102],
"go":function(ann_DASH_check_DASH_temp106945065) {
return $Hann_DASH_check_DASH_temp864845066(ann_DASH_check_DASH_temp106945065);
}};
$e4505545056.stack[R.EXN_STACKHEIGHT++] = $ss4505945060;
}
if(R.isPyretException($e4505545056)) {
$e4505545056.pyretStack.push(L[3102]);
}
throw $e4505545056;
}
var $ret4506145062 = $Hann_DASH_check_DASH_temp864845066($z4505745058);
++R.GAS;
return $ret4506145062;
};
var $Hann_DASH_check_DASH_temp864845066 = function(ann_DASH_check_DASH_temp106945065) {
return ann_DASH_check_DASH_temp106945065;
};
var $Hanf_arg864717204 = function(anf_arg105717202,self13517203,_plus55,torepr65) {
var anf_arg105845077 = G(self13517203,"b",L[3087]);
var $z4506945070 = D;
var $f4507545076 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg105845077):R.ffi.throwNonFunApp(L[3087],torepr65,[anf_arg105845077]);
};
try {
if(--R.GAS > 0) {
$z4506945070 = $f4507545076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4507545076,
"from":L[3087]});
}
} catch($e4506745068) {
if(R.isCont($e4506745068)) {
var $ss4507145072 = {"from":L[3087],
"go":function(anf_arg105945078) {
return $Hanf_arg864645079(anf_arg105945078,anf_arg105717202,self13517203,_plus55,torepr65);
}};
$e4506745068.stack[R.EXN_STACKHEIGHT++] = $ss4507145072;
}
if(R.isPyretException($e4506745068)) {
$e4506745068.pyretStack.push(L[3087]);
}
throw $e4506745068;
}
var $ret4507345074 = $Hanf_arg864645079($z4506945070,anf_arg105717202,self13517203,_plus55,torepr65);
++R.GAS;
return $ret4507345074;
};
var $Hanf_arg864645079 = function(anf_arg105945078,anf_arg105717202,self13517203,_plus55,torepr65) {
var $z4508245083 = D;
var $f4508845089 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg105945078):R.ffi.throwNonFunApp(L[3087],_plus55,[(", "),anf_arg105945078]);
};
try {
if(--R.GAS > 0) {
$z4508245083 = $f4508845089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4508845089,
"from":L[3087]});
}
} catch($e4508045081) {
if(R.isCont($e4508045081)) {
var $ss4508445085 = {"from":L[3087],
"go":function(anf_arg106045090) {
return $Hanf_arg864545091(anf_arg106045090,anf_arg105717202,self13517203,_plus55,torepr65);
}};
$e4508045081.stack[R.EXN_STACKHEIGHT++] = $ss4508445085;
}
if(R.isPyretException($e4508045081)) {
$e4508045081.pyretStack.push(L[3087]);
}
throw $e4508045081;
}
var $ret4508645087 = $Hanf_arg864545091($z4508245083,anf_arg105717202,self13517203,_plus55,torepr65);
++R.GAS;
return $ret4508645087;
};
var $Hanf_arg864545091 = function(anf_arg106045090,anf_arg105717202,self13517203,_plus55,torepr65) {
var $z4509445095 = D;
var $f4510045101 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg105717202,anf_arg106045090):R.ffi.throwNonFunApp(L[3087],_plus55,[anf_arg105717202,anf_arg106045090]);
};
try {
if(--R.GAS > 0) {
$z4509445095 = $f4510045101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4510045101,
"from":L[3087]});
}
} catch($e4509245093) {
if(R.isCont($e4509245093)) {
var $ss4509645097 = {"from":L[3087],
"go":function(anf_arg106145102) {
return $Hanf_arg864445103(anf_arg106145102,self13517203,_plus55,torepr65);
}};
$e4509245093.stack[R.EXN_STACKHEIGHT++] = $ss4509645097;
}
if(R.isPyretException($e4509245093)) {
$e4509245093.pyretStack.push(L[3087]);
}
throw $e4509245093;
}
var $ret4509845099 = $Hanf_arg864445103($z4509445095,self13517203,_plus55,torepr65);
++R.GAS;
return $ret4509845099;
};
var $Hanf_arg864445103 = function(anf_arg106145102,self13517203,_plus55,torepr65) {
var anf_arg106245114 = G(self13517203,"value",L[3087]);
var $z4510645107 = D;
var $f4511245113 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg106245114):R.ffi.throwNonFunApp(L[3087],torepr65,[anf_arg106245114]);
};
try {
if(--R.GAS > 0) {
$z4510645107 = $f4511245113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4511245113,
"from":L[3087]});
}
} catch($e4510445105) {
if(R.isCont($e4510445105)) {
var $ss4510845109 = {"from":L[3087],
"go":function(anf_arg106345115) {
return $Hanf_arg864345116(anf_arg106345115,anf_arg106145102,_plus55);
}};
$e4510445105.stack[R.EXN_STACKHEIGHT++] = $ss4510845109;
}
if(R.isPyretException($e4510445105)) {
$e4510445105.pyretStack.push(L[3087]);
}
throw $e4510445105;
}
var $ret4511045111 = $Hanf_arg864345116($z4510645107,anf_arg106145102,_plus55);
++R.GAS;
return $ret4511045111;
};
var $Hanf_arg864345116 = function(anf_arg106345115,anf_arg106145102,_plus55) {
var $z4511945120 = D;
var $f4512545126 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg106345115):R.ffi.throwNonFunApp(L[3087],_plus55,[(", "),anf_arg106345115]);
};
try {
if(--R.GAS > 0) {
$z4511945120 = $f4512545126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4512545126,
"from":L[3087]});
}
} catch($e4511745118) {
if(R.isCont($e4511745118)) {
var $ss4512145122 = {"from":L[3087],
"go":function(anf_arg106445127) {
return $Hanf_arg864245128(anf_arg106445127,anf_arg106145102,_plus55);
}};
$e4511745118.stack[R.EXN_STACKHEIGHT++] = $ss4512145122;
}
if(R.isPyretException($e4511745118)) {
$e4511745118.pyretStack.push(L[3087]);
}
throw $e4511745118;
}
var $ret4512345124 = $Hanf_arg864245128($z4511945120,anf_arg106145102,_plus55);
++R.GAS;
return $ret4512345124;
};
var $Hanf_arg864245128 = function(anf_arg106445127,anf_arg106145102,_plus55) {
var $z4513145132 = D;
var $f4513745138 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg106145102,anf_arg106445127):R.ffi.throwNonFunApp(L[3087],_plus55,[anf_arg106145102,anf_arg106445127]);
};
try {
if(--R.GAS > 0) {
$z4513145132 = $f4513745138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4513745138,
"from":L[3087]});
}
} catch($e4512945130) {
if(R.isCont($e4512945130)) {
var $ss4513345134 = {"from":L[3087],
"go":function(anf_arg106545139) {
return $Hanf_arg864145140(anf_arg106545139,_plus55);
}};
$e4512945130.stack[R.EXN_STACKHEIGHT++] = $ss4513345134;
}
if(R.isPyretException($e4512945130)) {
$e4512945130.pyretStack.push(L[3087]);
}
throw $e4512945130;
}
var $ret4513545136 = $Hanf_arg864145140($z4513145132,_plus55);
++R.GAS;
return $ret4513545136;
};
var $Hanf_arg864145140 = function(anf_arg106545139,_plus55) {
var $z4514345144 = D;
var $f4514945150 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg106545139,(")")):R.ffi.throwNonFunApp(L[3087],_plus55,[anf_arg106545139,(")")]);
};
try {
if(--R.GAS > 0) {
$z4514345144 = $f4514945150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4514945150,
"from":L[3087]});
}
} catch($e4514145142) {
if(R.isCont($e4514145142)) {
var $ss4514545146 = {"from":L[3087],
"go":function(anf_arg106645151) {
return $Hanf_arg864045152(anf_arg106645151,_plus55);
}};
$e4514145142.stack[R.EXN_STACKHEIGHT++] = $ss4514545146;
}
if(R.isPyretException($e4514145142)) {
$e4514145142.pyretStack.push(L[3087]);
}
throw $e4514145142;
}
var $ret4514745148 = $Hanf_arg864045152($z4514345144,_plus55);
++R.GAS;
return $ret4514745148;
};
var $Hanf_arg864045152 = function(anf_arg106645151,_plus55) {
var $z4515545156 = D;
var $f4516145162 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg106645151):R.ffi.throwNonFunApp(L[3087],_plus55,[("("),anf_arg106645151]);
};
try {
if(--R.GAS > 0) {
$z4515545156 = $f4516145162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4516145162,
"from":L[3087]});
}
} catch($e4515345154) {
if(R.isCont($e4515345154)) {
var $ss4515745158 = {"from":L[3087],
"go":function(anf_arg106745163) {
return $Hanf_arg863945164(anf_arg106745163,_plus55);
}};
$e4515345154.stack[R.EXN_STACKHEIGHT++] = $ss4515745158;
}
if(R.isPyretException($e4515345154)) {
$e4515345154.pyretStack.push(L[3087]);
}
throw $e4515345154;
}
var $ret4515945160 = $Hanf_arg863945164($z4515545156,_plus55);
++R.GAS;
return $ret4515945160;
};
var $Hanf_arg863945164 = function(anf_arg106745163,_plus55) {
var $z4516745168 = D;
var $f4517345174 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-var-bind"),anf_arg106745163):R.ffi.throwNonFunApp(L[3087],_plus55,[("s-var-bind"),anf_arg106745163]);
};
try {
if(--R.GAS > 0) {
$z4516745168 = $f4517345174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4517345174,
"from":L[3087]});
}
} catch($e4516545166) {
if(R.isCont($e4516545166)) {
var $ss4516945170 = {"from":L[3087],
"go":function(ann_DASH_check_DASH_temp105545175) {
return $Hann_DASH_check_DASH_temp863845176(ann_DASH_check_DASH_temp105545175);
}};
$e4516545166.stack[R.EXN_STACKHEIGHT++] = $ss4516945170;
}
if(R.isPyretException($e4516545166)) {
$e4516545166.pyretStack.push(L[3087]);
}
throw $e4516545166;
}
var $ret4517145172 = $Hann_DASH_check_DASH_temp863845176($z4516745168);
++R.GAS;
return $ret4517145172;
};
var $Hann_DASH_check_DASH_temp863845176 = function(ann_DASH_check_DASH_temp105545175) {
return ann_DASH_check_DASH_temp105545175;
};
var $Hcont_tail_arg863617221 = function(cont_tail_arg105217219,if_helper104217220) {
if(--R.GAS > 0) {
$z4517745178 = R.isFunction(if_helper104217220)?if_helper104217220.app(cont_tail_arg105217219):R.ffi.throwNonFunApp(L[3087],if_helper104217220,[cont_tail_arg105217219]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper104217220)?if_helper104217220.app(cont_tail_arg105217219):R.ffi.throwNonFunApp(L[3087],if_helper104217220,[cont_tail_arg105217219]);
},
"from":L[3087]});
}
++R.GAS;
return $z4517745178;
};
var $Hcont_tail_arg863717236 = function(cont_tail_arg104717235,if_helper104217220) {
if(--R.GAS > 0) {
$z4517945180 = R.isFunction(if_helper104217220)?if_helper104217220.app(cont_tail_arg104717235):R.ffi.throwNonFunApp(L[3087],if_helper104217220,[cont_tail_arg104717235]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper104217220)?if_helper104217220.app(cont_tail_arg104717235):R.ffi.throwNonFunApp(L[3087],if_helper104217220,[cont_tail_arg104717235]);
},
"from":L[3087]});
}
++R.GAS;
return $z4517945180;
};
var $Hanf_arg863517259 = function(anf_arg103217255,INDENT118169,anf_fun102817256,anf_fun102917257,break_DASH_one119168,self62317258,str_DASH_spaceequal170832,_plus55) {
var $z4518345184 = D;
var $f4518945190 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg103217255,str_DASH_spaceequal170832):R.ffi.throwNonFunApp(L[4764],_plus55,[anf_arg103217255,str_DASH_spaceequal170832]);
};
try {
if(--R.GAS > 0) {
$z4518345184 = $f4518945190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4518945190,
"from":L[4764]});
}
} catch($e4518145182) {
if(R.isCont($e4518145182)) {
var $ss4518545186 = {"from":L[4764],
"go":function(anf_arg103345191) {
return $Hanf_arg863445192(anf_arg103345191,INDENT118169,anf_fun102817256,anf_fun102917257,break_DASH_one119168,self62317258,_plus55);
}};
$e4518145182.stack[R.EXN_STACKHEIGHT++] = $ss4518545186;
}
if(R.isPyretException($e4518145182)) {
$e4518145182.pyretStack.push(L[4764]);
}
throw $e4518145182;
}
var $ret4518745188 = $Hanf_arg863445192($z4518345184,INDENT118169,anf_fun102817256,anf_fun102917257,break_DASH_one119168,self62317258,_plus55);
++R.GAS;
return $ret4518745188;
};
var $Hanf_arg863445192 = function(anf_arg103345191,INDENT118169,anf_fun102817256,anf_fun102917257,break_DASH_one119168,self62317258,_plus55) {
var $z4519545196 = D;
var $f4520145202 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg103345191,break_DASH_one119168):R.ffi.throwNonFunApp(L[4764],_plus55,[anf_arg103345191,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4519545196 = $f4520145202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4520145202,
"from":L[4764]});
}
} catch($e4519345194) {
if(R.isCont($e4519345194)) {
var $ss4519745198 = {"from":L[4764],
"go":function(anf_arg103445203) {
return $Hanf_arg863345204(anf_arg103445203,INDENT118169,anf_fun102817256,anf_fun102917257,self62317258,_plus55);
}};
$e4519345194.stack[R.EXN_STACKHEIGHT++] = $ss4519745198;
}
if(R.isPyretException($e4519345194)) {
$e4519345194.pyretStack.push(L[4764]);
}
throw $e4519345194;
}
var $ret4519945200 = $Hanf_arg863345204($z4519545196,INDENT118169,anf_fun102817256,anf_fun102917257,self62317258,_plus55);
++R.GAS;
return $ret4519945200;
};
var $Hanf_arg863345204 = function(anf_arg103445203,INDENT118169,anf_fun102817256,anf_fun102917257,self62317258,_plus55) {
var anf_bracket103545218 = G(self62317258,"value",L[4767]);
var anf_fun103645215 = G(anf_bracket103545218,"tosource",L[4766]);
var $z4520745208 = D;
var $f4521345214 = function(_) {
return R.isFunction(anf_fun103645215)?anf_fun103645215.app():R.ffi.throwNonFunApp(L[4765],anf_fun103645215,[]);
};
try {
if(--R.GAS > 0) {
$z4520745208 = $f4521345214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4521345214,
"from":L[4765]});
}
} catch($e4520545206) {
if(R.isCont($e4520545206)) {
var $ss4520945210 = {"from":L[4765],
"go":function(anf_arg103745216) {
return $Hanf_arg863245217(anf_arg103745216,INDENT118169,anf_arg103445203,anf_fun102817256,anf_fun102917257,_plus55);
}};
$e4520545206.stack[R.EXN_STACKHEIGHT++] = $ss4520945210;
}
if(R.isPyretException($e4520545206)) {
$e4520545206.pyretStack.push(L[4765]);
}
throw $e4520545206;
}
var $ret4521145212 = $Hanf_arg863245217($z4520745208,INDENT118169,anf_arg103445203,anf_fun102817256,anf_fun102917257,_plus55);
++R.GAS;
return $ret4521145212;
};
var $Hanf_arg863245217 = function(anf_arg103745216,INDENT118169,anf_arg103445203,anf_fun102817256,anf_fun102917257,_plus55) {
var $z4522145222 = D;
var $f4522745228 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg103445203,anf_arg103745216):R.ffi.throwNonFunApp(L[4764],_plus55,[anf_arg103445203,anf_arg103745216]);
};
try {
if(--R.GAS > 0) {
$z4522145222 = $f4522745228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4522745228,
"from":L[4764]});
}
} catch($e4521945220) {
if(R.isCont($e4521945220)) {
var $ss4522345224 = {"from":L[4764],
"go":function(anf_arg103845229) {
return $Hanf_arg863145230(anf_arg103845229,INDENT118169,anf_fun102817256,anf_fun102917257);
}};
$e4521945220.stack[R.EXN_STACKHEIGHT++] = $ss4522345224;
}
if(R.isPyretException($e4521945220)) {
$e4521945220.pyretStack.push(L[4764]);
}
throw $e4521945220;
}
var $ret4522545226 = $Hanf_arg863145230($z4522145222,INDENT118169,anf_fun102817256,anf_fun102917257);
++R.GAS;
return $ret4522545226;
};
var $Hanf_arg863145230 = function(anf_arg103845229,INDENT118169,anf_fun102817256,anf_fun102917257) {
var $z4523345234 = D;
var $f4523945240 = function(_) {
return R.isFunction(anf_fun102917257)?anf_fun102917257.app(INDENT118169,anf_arg103845229):R.ffi.throwNonFunApp(L[4768],anf_fun102917257,[INDENT118169,anf_arg103845229]);
};
try {
if(--R.GAS > 0) {
$z4523345234 = $f4523945240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4523945240,
"from":L[4768]});
}
} catch($e4523145232) {
if(R.isCont($e4523145232)) {
var $ss4523545236 = {"from":L[4768],
"go":function(anf_arg103945241) {
return $Hanf_arg863045242(anf_arg103945241,anf_fun102817256);
}};
$e4523145232.stack[R.EXN_STACKHEIGHT++] = $ss4523545236;
}
if(R.isPyretException($e4523145232)) {
$e4523145232.pyretStack.push(L[4768]);
}
throw $e4523145232;
}
var $ret4523745238 = $Hanf_arg863045242($z4523345234,anf_fun102817256);
++R.GAS;
return $ret4523745238;
};
var $Hanf_arg863045242 = function(anf_arg103945241,anf_fun102817256) {
var $z4524545246 = D;
var $f4525145252 = function(_) {
return R.isFunction(anf_fun102817256)?anf_fun102817256.app(anf_arg103945241):R.ffi.throwNonFunApp(L[3111],anf_fun102817256,[anf_arg103945241]);
};
try {
if(--R.GAS > 0) {
$z4524545246 = $f4525145252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4525145252,
"from":L[3111]});
}
} catch($e4524345244) {
if(R.isCont($e4524345244)) {
var $ss4524745248 = {"from":L[3111],
"go":function(ann_DASH_check_DASH_temp102745253) {
return $Hann_DASH_check_DASH_temp862945254(ann_DASH_check_DASH_temp102745253);
}};
$e4524345244.stack[R.EXN_STACKHEIGHT++] = $ss4524745248;
}
if(R.isPyretException($e4524345244)) {
$e4524345244.pyretStack.push(L[3111]);
}
throw $e4524345244;
}
var $ret4524945250 = $Hann_DASH_check_DASH_temp862945254($z4524545246);
++R.GAS;
return $ret4524945250;
};
var $Hann_DASH_check_DASH_temp862945254 = function(ann_DASH_check_DASH_temp102745253) {
return ann_DASH_check_DASH_temp102745253;
};
var $Hanf_arg862817274 = function(anf_arg101517272,self12917273,_plus55,torepr65) {
var anf_arg101645265 = G(self12917273,"b",L[3088]);
var $z4525745258 = D;
var $f4526345264 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg101645265):R.ffi.throwNonFunApp(L[3088],torepr65,[anf_arg101645265]);
};
try {
if(--R.GAS > 0) {
$z4525745258 = $f4526345264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4526345264,
"from":L[3088]});
}
} catch($e4525545256) {
if(R.isCont($e4525545256)) {
var $ss4525945260 = {"from":L[3088],
"go":function(anf_arg101745266) {
return $Hanf_arg862745267(anf_arg101745266,anf_arg101517272,self12917273,_plus55,torepr65);
}};
$e4525545256.stack[R.EXN_STACKHEIGHT++] = $ss4525945260;
}
if(R.isPyretException($e4525545256)) {
$e4525545256.pyretStack.push(L[3088]);
}
throw $e4525545256;
}
var $ret4526145262 = $Hanf_arg862745267($z4525745258,anf_arg101517272,self12917273,_plus55,torepr65);
++R.GAS;
return $ret4526145262;
};
var $Hanf_arg862745267 = function(anf_arg101745266,anf_arg101517272,self12917273,_plus55,torepr65) {
var $z4527045271 = D;
var $f4527645277 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg101745266):R.ffi.throwNonFunApp(L[3088],_plus55,[(", "),anf_arg101745266]);
};
try {
if(--R.GAS > 0) {
$z4527045271 = $f4527645277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4527645277,
"from":L[3088]});
}
} catch($e4526845269) {
if(R.isCont($e4526845269)) {
var $ss4527245273 = {"from":L[3088],
"go":function(anf_arg101845278) {
return $Hanf_arg862645279(anf_arg101845278,anf_arg101517272,self12917273,_plus55,torepr65);
}};
$e4526845269.stack[R.EXN_STACKHEIGHT++] = $ss4527245273;
}
if(R.isPyretException($e4526845269)) {
$e4526845269.pyretStack.push(L[3088]);
}
throw $e4526845269;
}
var $ret4527445275 = $Hanf_arg862645279($z4527045271,anf_arg101517272,self12917273,_plus55,torepr65);
++R.GAS;
return $ret4527445275;
};
var $Hanf_arg862645279 = function(anf_arg101845278,anf_arg101517272,self12917273,_plus55,torepr65) {
var $z4528245283 = D;
var $f4528845289 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg101517272,anf_arg101845278):R.ffi.throwNonFunApp(L[3088],_plus55,[anf_arg101517272,anf_arg101845278]);
};
try {
if(--R.GAS > 0) {
$z4528245283 = $f4528845289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4528845289,
"from":L[3088]});
}
} catch($e4528045281) {
if(R.isCont($e4528045281)) {
var $ss4528445285 = {"from":L[3088],
"go":function(anf_arg101945290) {
return $Hanf_arg862545291(anf_arg101945290,self12917273,_plus55,torepr65);
}};
$e4528045281.stack[R.EXN_STACKHEIGHT++] = $ss4528445285;
}
if(R.isPyretException($e4528045281)) {
$e4528045281.pyretStack.push(L[3088]);
}
throw $e4528045281;
}
var $ret4528645287 = $Hanf_arg862545291($z4528245283,self12917273,_plus55,torepr65);
++R.GAS;
return $ret4528645287;
};
var $Hanf_arg862545291 = function(anf_arg101945290,self12917273,_plus55,torepr65) {
var anf_arg102045302 = G(self12917273,"value",L[3088]);
var $z4529445295 = D;
var $f4530045301 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg102045302):R.ffi.throwNonFunApp(L[3088],torepr65,[anf_arg102045302]);
};
try {
if(--R.GAS > 0) {
$z4529445295 = $f4530045301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4530045301,
"from":L[3088]});
}
} catch($e4529245293) {
if(R.isCont($e4529245293)) {
var $ss4529645297 = {"from":L[3088],
"go":function(anf_arg102145303) {
return $Hanf_arg862445304(anf_arg102145303,anf_arg101945290,_plus55);
}};
$e4529245293.stack[R.EXN_STACKHEIGHT++] = $ss4529645297;
}
if(R.isPyretException($e4529245293)) {
$e4529245293.pyretStack.push(L[3088]);
}
throw $e4529245293;
}
var $ret4529845299 = $Hanf_arg862445304($z4529445295,anf_arg101945290,_plus55);
++R.GAS;
return $ret4529845299;
};
var $Hanf_arg862445304 = function(anf_arg102145303,anf_arg101945290,_plus55) {
var $z4530745308 = D;
var $f4531345314 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg102145303):R.ffi.throwNonFunApp(L[3088],_plus55,[(", "),anf_arg102145303]);
};
try {
if(--R.GAS > 0) {
$z4530745308 = $f4531345314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4531345314,
"from":L[3088]});
}
} catch($e4530545306) {
if(R.isCont($e4530545306)) {
var $ss4530945310 = {"from":L[3088],
"go":function(anf_arg102245315) {
return $Hanf_arg862345316(anf_arg102245315,anf_arg101945290,_plus55);
}};
$e4530545306.stack[R.EXN_STACKHEIGHT++] = $ss4530945310;
}
if(R.isPyretException($e4530545306)) {
$e4530545306.pyretStack.push(L[3088]);
}
throw $e4530545306;
}
var $ret4531145312 = $Hanf_arg862345316($z4530745308,anf_arg101945290,_plus55);
++R.GAS;
return $ret4531145312;
};
var $Hanf_arg862345316 = function(anf_arg102245315,anf_arg101945290,_plus55) {
var $z4531945320 = D;
var $f4532545326 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg101945290,anf_arg102245315):R.ffi.throwNonFunApp(L[3088],_plus55,[anf_arg101945290,anf_arg102245315]);
};
try {
if(--R.GAS > 0) {
$z4531945320 = $f4532545326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4532545326,
"from":L[3088]});
}
} catch($e4531745318) {
if(R.isCont($e4531745318)) {
var $ss4532145322 = {"from":L[3088],
"go":function(anf_arg102345327) {
return $Hanf_arg862245328(anf_arg102345327,_plus55);
}};
$e4531745318.stack[R.EXN_STACKHEIGHT++] = $ss4532145322;
}
if(R.isPyretException($e4531745318)) {
$e4531745318.pyretStack.push(L[3088]);
}
throw $e4531745318;
}
var $ret4532345324 = $Hanf_arg862245328($z4531945320,_plus55);
++R.GAS;
return $ret4532345324;
};
var $Hanf_arg862245328 = function(anf_arg102345327,_plus55) {
var $z4533145332 = D;
var $f4533745338 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg102345327,(")")):R.ffi.throwNonFunApp(L[3088],_plus55,[anf_arg102345327,(")")]);
};
try {
if(--R.GAS > 0) {
$z4533145332 = $f4533745338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4533745338,
"from":L[3088]});
}
} catch($e4532945330) {
if(R.isCont($e4532945330)) {
var $ss4533345334 = {"from":L[3088],
"go":function(anf_arg102445339) {
return $Hanf_arg862145340(anf_arg102445339,_plus55);
}};
$e4532945330.stack[R.EXN_STACKHEIGHT++] = $ss4533345334;
}
if(R.isPyretException($e4532945330)) {
$e4532945330.pyretStack.push(L[3088]);
}
throw $e4532945330;
}
var $ret4533545336 = $Hanf_arg862145340($z4533145332,_plus55);
++R.GAS;
return $ret4533545336;
};
var $Hanf_arg862145340 = function(anf_arg102445339,_plus55) {
var $z4534345344 = D;
var $f4534945350 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg102445339):R.ffi.throwNonFunApp(L[3088],_plus55,[("("),anf_arg102445339]);
};
try {
if(--R.GAS > 0) {
$z4534345344 = $f4534945350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4534945350,
"from":L[3088]});
}
} catch($e4534145342) {
if(R.isCont($e4534145342)) {
var $ss4534545346 = {"from":L[3088],
"go":function(anf_arg102545351) {
return $Hanf_arg862045352(anf_arg102545351,_plus55);
}};
$e4534145342.stack[R.EXN_STACKHEIGHT++] = $ss4534545346;
}
if(R.isPyretException($e4534145342)) {
$e4534145342.pyretStack.push(L[3088]);
}
throw $e4534145342;
}
var $ret4534745348 = $Hanf_arg862045352($z4534345344,_plus55);
++R.GAS;
return $ret4534745348;
};
var $Hanf_arg862045352 = function(anf_arg102545351,_plus55) {
var $z4535545356 = D;
var $f4536145362 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-let-bind"),anf_arg102545351):R.ffi.throwNonFunApp(L[3088],_plus55,[("s-let-bind"),anf_arg102545351]);
};
try {
if(--R.GAS > 0) {
$z4535545356 = $f4536145362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4536145362,
"from":L[3088]});
}
} catch($e4535345354) {
if(R.isCont($e4535345354)) {
var $ss4535745358 = {"from":L[3088],
"go":function(ann_DASH_check_DASH_temp101345363) {
return $Hann_DASH_check_DASH_temp861945364(ann_DASH_check_DASH_temp101345363);
}};
$e4535345354.stack[R.EXN_STACKHEIGHT++] = $ss4535745358;
}
if(R.isPyretException($e4535345354)) {
$e4535345354.pyretStack.push(L[3088]);
}
throw $e4535345354;
}
var $ret4535945360 = $Hann_DASH_check_DASH_temp861945364($z4535545356);
++R.GAS;
return $ret4535945360;
};
var $Hann_DASH_check_DASH_temp861945364 = function(ann_DASH_check_DASH_temp101345363) {
return ann_DASH_check_DASH_temp101345363;
};
var $Hcont_tail_arg861717291 = function(cont_tail_arg101017289,if_helper100017290) {
if(--R.GAS > 0) {
$z4536545366 = R.isFunction(if_helper100017290)?if_helper100017290.app(cont_tail_arg101017289):R.ffi.throwNonFunApp(L[3088],if_helper100017290,[cont_tail_arg101017289]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper100017290)?if_helper100017290.app(cont_tail_arg101017289):R.ffi.throwNonFunApp(L[3088],if_helper100017290,[cont_tail_arg101017289]);
},
"from":L[3088]});
}
++R.GAS;
return $z4536545366;
};
var $Hcont_tail_arg861817306 = function(cont_tail_arg100517305,if_helper100017290) {
if(--R.GAS > 0) {
$z4536745368 = R.isFunction(if_helper100017290)?if_helper100017290.app(cont_tail_arg100517305):R.ffi.throwNonFunApp(L[3088],if_helper100017290,[cont_tail_arg100517305]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper100017290)?if_helper100017290.app(cont_tail_arg100517305):R.ffi.throwNonFunApp(L[3088],if_helper100017290,[cont_tail_arg100517305]);
},
"from":L[3088]});
}
++R.GAS;
return $z4536745368;
};
var $Hann_DASH_check_DASH_temp861617328 = function(ann_DASH_check_DASH_temp99117327) {
return ann_DASH_check_DASH_temp99117327;
};
var $Hanf_arg861517341 = function(anf_arg99517340,_plus55,raise62) {
var $z4537145372 = D;
var $f4537745378 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg99517340):R.ffi.throwNonFunApp(L[4769],_plus55,[("No visitor field for "),anf_arg99517340]);
};
try {
if(--R.GAS > 0) {
$z4537145372 = $f4537745378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4537745378,
"from":L[4769]});
}
} catch($e4536945370) {
if(R.isCont($e4536945370)) {
var $ss4537345374 = {"from":L[4769],
"go":function(anf_arg99645379) {
return $Hanf_arg861445380(anf_arg99645379,raise62);
}};
$e4536945370.stack[R.EXN_STACKHEIGHT++] = $ss4537345374;
}
if(R.isPyretException($e4536945370)) {
$e4536945370.pyretStack.push(L[4769]);
}
throw $e4536945370;
}
var $ret4537545376 = $Hanf_arg861445380($z4537145372,raise62);
++R.GAS;
return $ret4537545376;
};
var $Hanf_arg861445380 = function(anf_arg99645379,raise62) {
var $z4538345384 = D;
var $f4538945390 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg99645379):R.ffi.throwNonFunApp(L[3116],raise62,[anf_arg99645379]);
};
try {
if(--R.GAS > 0) {
$z4538345384 = $f4538945390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4538945390,
"from":L[3116]});
}
} catch($e4538145382) {
if(R.isCont($e4538145382)) {
var $ss4538545386 = {"from":L[3116],
"go":function(ann_DASH_check_DASH_temp99345391) {
return $Hann_DASH_check_DASH_temp861345392(ann_DASH_check_DASH_temp99345391);
}};
$e4538145382.stack[R.EXN_STACKHEIGHT++] = $ss4538545386;
}
if(R.isPyretException($e4538145382)) {
$e4538145382.pyretStack.push(L[3116]);
}
throw $e4538145382;
}
var $ret4538745388 = $Hann_DASH_check_DASH_temp861345392($z4538345384);
++R.GAS;
return $ret4538745388;
};
var $Hann_DASH_check_DASH_temp861345392 = function(ann_DASH_check_DASH_temp99345391) {
return ann_DASH_check_DASH_temp99345391;
};
var $Hanf_arg861217366 = function(anf_arg98217363,anf_fun97917364,anf_fun98017365,str_DASH_use_DASH_loc174884,_plus55) {
var $z4539545396 = D;
var $f4540145402 = function(_) {
return R.isFunction(anf_fun98017365)?anf_fun98017365.app(anf_arg98217363):R.ffi.throwNonFunApp(L[4770],anf_fun98017365,[anf_arg98217363]);
};
try {
if(--R.GAS > 0) {
$z4539545396 = $f4540145402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4540145402,
"from":L[4770]});
}
} catch($e4539345394) {
if(R.isCont($e4539345394)) {
var $ss4539745398 = {"from":L[4770],
"go":function(anf_arg98345403) {
return $Hanf_arg861145404(anf_arg98345403,anf_fun97917364,str_DASH_use_DASH_loc174884,_plus55);
}};
$e4539345394.stack[R.EXN_STACKHEIGHT++] = $ss4539745398;
}
if(R.isPyretException($e4539345394)) {
$e4539345394.pyretStack.push(L[4770]);
}
throw $e4539345394;
}
var $ret4539945400 = $Hanf_arg861145404($z4539545396,anf_fun97917364,str_DASH_use_DASH_loc174884,_plus55);
++R.GAS;
return $ret4539945400;
};
var $Hanf_arg861145404 = function(anf_arg98345403,anf_fun97917364,str_DASH_use_DASH_loc174884,_plus55) {
var $z4540745408 = D;
var $f4541345414 = function(_) {
return R.isFunction(anf_fun97917364)?anf_fun97917364.app(anf_arg98345403):R.ffi.throwNonFunApp(L[4771],anf_fun97917364,[anf_arg98345403]);
};
try {
if(--R.GAS > 0) {
$z4540745408 = $f4541345414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4541345414,
"from":L[4771]});
}
} catch($e4540545406) {
if(R.isCont($e4540545406)) {
var $ss4540945410 = {"from":L[4771],
"go":function(anf_arg98445415) {
return $Hanf_arg861045416(anf_arg98445415,str_DASH_use_DASH_loc174884,_plus55);
}};
$e4540545406.stack[R.EXN_STACKHEIGHT++] = $ss4540945410;
}
if(R.isPyretException($e4540545406)) {
$e4540545406.pyretStack.push(L[4771]);
}
throw $e4540545406;
}
var $ret4541145412 = $Hanf_arg861045416($z4540745408,str_DASH_use_DASH_loc174884,_plus55);
++R.GAS;
return $ret4541145412;
};
var $Hanf_arg861045416 = function(anf_arg98445415,str_DASH_use_DASH_loc174884,_plus55) {
var $z4541945420 = D;
var $f4542545426 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_use_DASH_loc174884,anf_arg98445415):R.ffi.throwNonFunApp(L[3128],_plus55,[str_DASH_use_DASH_loc174884,anf_arg98445415]);
};
try {
if(--R.GAS > 0) {
$z4541945420 = $f4542545426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4542545426,
"from":L[3128]});
}
} catch($e4541745418) {
if(R.isCont($e4541745418)) {
var $ss4542145422 = {"from":L[3128],
"go":function(ann_DASH_check_DASH_temp97845427) {
return $Hann_DASH_check_DASH_temp860945428(ann_DASH_check_DASH_temp97845427);
}};
$e4541745418.stack[R.EXN_STACKHEIGHT++] = $ss4542145422;
}
if(R.isPyretException($e4541745418)) {
$e4541745418.pyretStack.push(L[3128]);
}
throw $e4541745418;
}
var $ret4542345424 = $Hann_DASH_check_DASH_temp860945428($z4541945420);
++R.GAS;
return $ret4542345424;
};
var $Hann_DASH_check_DASH_temp860945428 = function(ann_DASH_check_DASH_temp97845427) {
return ann_DASH_check_DASH_temp97845427;
};
var $Hanf_arg860817380 = function(anf_arg97417379,_plus55) {
var $z4543145432 = D;
var $f4543745438 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg97417379,(")")):R.ffi.throwNonFunApp(L[3120],_plus55,[anf_arg97417379,(")")]);
};
try {
if(--R.GAS > 0) {
$z4543145432 = $f4543745438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4543745438,
"from":L[3120]});
}
} catch($e4542945430) {
if(R.isCont($e4542945430)) {
var $ss4543345434 = {"from":L[3120],
"go":function(anf_arg97545439) {
return $Hanf_arg860745440(anf_arg97545439,_plus55);
}};
$e4542945430.stack[R.EXN_STACKHEIGHT++] = $ss4543345434;
}
if(R.isPyretException($e4542945430)) {
$e4542945430.pyretStack.push(L[3120]);
}
throw $e4542945430;
}
var $ret4543545436 = $Hanf_arg860745440($z4543145432,_plus55);
++R.GAS;
return $ret4543545436;
};
var $Hanf_arg860745440 = function(anf_arg97545439,_plus55) {
var $z4544345444 = D;
var $f4544945450 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg97545439):R.ffi.throwNonFunApp(L[3120],_plus55,[("("),anf_arg97545439]);
};
try {
if(--R.GAS > 0) {
$z4544345444 = $f4544945450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4544945450,
"from":L[3120]});
}
} catch($e4544145442) {
if(R.isCont($e4544145442)) {
var $ss4544545446 = {"from":L[3120],
"go":function(anf_arg97645451) {
return $Hanf_arg860645452(anf_arg97645451,_plus55);
}};
$e4544145442.stack[R.EXN_STACKHEIGHT++] = $ss4544545446;
}
if(R.isPyretException($e4544145442)) {
$e4544145442.pyretStack.push(L[3120]);
}
throw $e4544145442;
}
var $ret4544745448 = $Hanf_arg860645452($z4544345444,_plus55);
++R.GAS;
return $ret4544745448;
};
var $Hanf_arg860645452 = function(anf_arg97645451,_plus55) {
var $z4545545456 = D;
var $f4546145462 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("h-use-loc"),anf_arg97645451):R.ffi.throwNonFunApp(L[3120],_plus55,[("h-use-loc"),anf_arg97645451]);
};
try {
if(--R.GAS > 0) {
$z4545545456 = $f4546145462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4546145462,
"from":L[3120]});
}
} catch($e4545345454) {
if(R.isCont($e4545345454)) {
var $ss4545745458 = {"from":L[3120],
"go":function(ann_DASH_check_DASH_temp97245463) {
return $Hann_DASH_check_DASH_temp860545464(ann_DASH_check_DASH_temp97245463);
}};
$e4545345454.stack[R.EXN_STACKHEIGHT++] = $ss4545745458;
}
if(R.isPyretException($e4545345454)) {
$e4545345454.pyretStack.push(L[3120]);
}
throw $e4545345454;
}
var $ret4545945460 = $Hann_DASH_check_DASH_temp860545464($z4545545456);
++R.GAS;
return $ret4545945460;
};
var $Hann_DASH_check_DASH_temp860545464 = function(ann_DASH_check_DASH_temp97245463) {
return ann_DASH_check_DASH_temp97245463;
};
var $Hcont_tail_arg860317396 = function(cont_tail_arg96917394,if_helper96117395) {
if(--R.GAS > 0) {
$z4546545466 = R.isFunction(if_helper96117395)?if_helper96117395.app(cont_tail_arg96917394):R.ffi.throwNonFunApp(L[3120],if_helper96117395,[cont_tail_arg96917394]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper96117395)?if_helper96117395.app(cont_tail_arg96917394):R.ffi.throwNonFunApp(L[3120],if_helper96117395,[cont_tail_arg96917394]);
},
"from":L[3120]});
}
++R.GAS;
return $z4546545466;
};
var $Hcont_tail_arg860417411 = function(cont_tail_arg96617410,if_helper96117395) {
if(--R.GAS > 0) {
$z4546745468 = R.isFunction(if_helper96117395)?if_helper96117395.app(cont_tail_arg96617410):R.ffi.throwNonFunApp(L[3120],if_helper96117395,[cont_tail_arg96617410]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper96117395)?if_helper96117395.app(cont_tail_arg96617410):R.ffi.throwNonFunApp(L[3120],if_helper96117395,[cont_tail_arg96617410]);
},
"from":L[3120]});
}
++R.GAS;
return $z4546745468;
};
var $Hann_DASH_check_DASH_temp860217433 = function(ann_DASH_check_DASH_temp95217432) {
return ann_DASH_check_DASH_temp95217432;
};
var $Hanf_arg860117446 = function(anf_arg95617445,_plus55,raise62) {
var $z4547145472 = D;
var $f4547745478 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg95617445):R.ffi.throwNonFunApp(L[4772],_plus55,[("No visitor field for "),anf_arg95617445]);
};
try {
if(--R.GAS > 0) {
$z4547145472 = $f4547745478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4547745478,
"from":L[4772]});
}
} catch($e4546945470) {
if(R.isCont($e4546945470)) {
var $ss4547345474 = {"from":L[4772],
"go":function(anf_arg95745479) {
return $Hanf_arg860045480(anf_arg95745479,raise62);
}};
$e4546945470.stack[R.EXN_STACKHEIGHT++] = $ss4547345474;
}
if(R.isPyretException($e4546945470)) {
$e4546945470.pyretStack.push(L[4772]);
}
throw $e4546945470;
}
var $ret4547545476 = $Hanf_arg860045480($z4547145472,raise62);
++R.GAS;
return $ret4547545476;
};
var $Hanf_arg860045480 = function(anf_arg95745479,raise62) {
var $z4548345484 = D;
var $f4548945490 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg95745479):R.ffi.throwNonFunApp(L[3131],raise62,[anf_arg95745479]);
};
try {
if(--R.GAS > 0) {
$z4548345484 = $f4548945490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4548945490,
"from":L[3131]});
}
} catch($e4548145482) {
if(R.isCont($e4548145482)) {
var $ss4548545486 = {"from":L[3131],
"go":function(ann_DASH_check_DASH_temp95445491) {
return $Hann_DASH_check_DASH_temp859945492(ann_DASH_check_DASH_temp95445491);
}};
$e4548145482.stack[R.EXN_STACKHEIGHT++] = $ss4548545486;
}
if(R.isPyretException($e4548145482)) {
$e4548145482.pyretStack.push(L[3131]);
}
throw $e4548145482;
}
var $ret4548745488 = $Hann_DASH_check_DASH_temp859945492($z4548345484);
++R.GAS;
return $ret4548745488;
};
var $Hann_DASH_check_DASH_temp859945492 = function(ann_DASH_check_DASH_temp95445491) {
return ann_DASH_check_DASH_temp95445491;
};
var $Hann_DASH_check_DASH_temp859817484 = function(ann_DASH_check_DASH_temp94117483) {
return ann_DASH_check_DASH_temp94117483;
};
var $Hanf_arg859717500 = function(anf_arg93117498,self11717499,_plus55,torepr65) {
var anf_arg93245503 = G(self11717499,"mod",L[3135]);
var $z4549545496 = D;
var $f4550145502 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg93245503):R.ffi.throwNonFunApp(L[3135],torepr65,[anf_arg93245503]);
};
try {
if(--R.GAS > 0) {
$z4549545496 = $f4550145502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4550145502,
"from":L[3135]});
}
} catch($e4549345494) {
if(R.isCont($e4549345494)) {
var $ss4549745498 = {"from":L[3135],
"go":function(anf_arg93345504) {
return $Hanf_arg859645505(anf_arg93345504,anf_arg93117498,_plus55);
}};
$e4549345494.stack[R.EXN_STACKHEIGHT++] = $ss4549745498;
}
if(R.isPyretException($e4549345494)) {
$e4549345494.pyretStack.push(L[3135]);
}
throw $e4549345494;
}
var $ret4549945500 = $Hanf_arg859645505($z4549545496,anf_arg93117498,_plus55);
++R.GAS;
return $ret4549945500;
};
var $Hanf_arg859645505 = function(anf_arg93345504,anf_arg93117498,_plus55) {
var $z4550845509 = D;
var $f4551445515 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg93345504):R.ffi.throwNonFunApp(L[3135],_plus55,[(", "),anf_arg93345504]);
};
try {
if(--R.GAS > 0) {
$z4550845509 = $f4551445515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4551445515,
"from":L[3135]});
}
} catch($e4550645507) {
if(R.isCont($e4550645507)) {
var $ss4551045511 = {"from":L[3135],
"go":function(anf_arg93445516) {
return $Hanf_arg859545517(anf_arg93445516,anf_arg93117498,_plus55);
}};
$e4550645507.stack[R.EXN_STACKHEIGHT++] = $ss4551045511;
}
if(R.isPyretException($e4550645507)) {
$e4550645507.pyretStack.push(L[3135]);
}
throw $e4550645507;
}
var $ret4551245513 = $Hanf_arg859545517($z4550845509,anf_arg93117498,_plus55);
++R.GAS;
return $ret4551245513;
};
var $Hanf_arg859545517 = function(anf_arg93445516,anf_arg93117498,_plus55) {
var $z4552045521 = D;
var $f4552645527 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg93117498,anf_arg93445516):R.ffi.throwNonFunApp(L[3135],_plus55,[anf_arg93117498,anf_arg93445516]);
};
try {
if(--R.GAS > 0) {
$z4552045521 = $f4552645527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4552645527,
"from":L[3135]});
}
} catch($e4551845519) {
if(R.isCont($e4551845519)) {
var $ss4552245523 = {"from":L[3135],
"go":function(anf_arg93545528) {
return $Hanf_arg859445529(anf_arg93545528,_plus55);
}};
$e4551845519.stack[R.EXN_STACKHEIGHT++] = $ss4552245523;
}
if(R.isPyretException($e4551845519)) {
$e4551845519.pyretStack.push(L[3135]);
}
throw $e4551845519;
}
var $ret4552445525 = $Hanf_arg859445529($z4552045521,_plus55);
++R.GAS;
return $ret4552445525;
};
var $Hanf_arg859445529 = function(anf_arg93545528,_plus55) {
var $z4553245533 = D;
var $f4553845539 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg93545528,(")")):R.ffi.throwNonFunApp(L[3135],_plus55,[anf_arg93545528,(")")]);
};
try {
if(--R.GAS > 0) {
$z4553245533 = $f4553845539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4553845539,
"from":L[3135]});
}
} catch($e4553045531) {
if(R.isCont($e4553045531)) {
var $ss4553445535 = {"from":L[3135],
"go":function(anf_arg93645540) {
return $Hanf_arg859345541(anf_arg93645540,_plus55);
}};
$e4553045531.stack[R.EXN_STACKHEIGHT++] = $ss4553445535;
}
if(R.isPyretException($e4553045531)) {
$e4553045531.pyretStack.push(L[3135]);
}
throw $e4553045531;
}
var $ret4553645537 = $Hanf_arg859345541($z4553245533,_plus55);
++R.GAS;
return $ret4553645537;
};
var $Hanf_arg859345541 = function(anf_arg93645540,_plus55) {
var $z4554445545 = D;
var $f4555045551 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg93645540):R.ffi.throwNonFunApp(L[3135],_plus55,[("("),anf_arg93645540]);
};
try {
if(--R.GAS > 0) {
$z4554445545 = $f4555045551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4555045551,
"from":L[3135]});
}
} catch($e4554245543) {
if(R.isCont($e4554245543)) {
var $ss4554645547 = {"from":L[3135],
"go":function(anf_arg93745552) {
return $Hanf_arg859245553(anf_arg93745552,_plus55);
}};
$e4554245543.stack[R.EXN_STACKHEIGHT++] = $ss4554645547;
}
if(R.isPyretException($e4554245543)) {
$e4554245543.pyretStack.push(L[3135]);
}
throw $e4554245543;
}
var $ret4554845549 = $Hanf_arg859245553($z4554445545,_plus55);
++R.GAS;
return $ret4554845549;
};
var $Hanf_arg859245553 = function(anf_arg93745552,_plus55) {
var $z4555645557 = D;
var $f4556245563 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-const-import"),anf_arg93745552):R.ffi.throwNonFunApp(L[3135],_plus55,[("s-const-import"),anf_arg93745552]);
};
try {
if(--R.GAS > 0) {
$z4555645557 = $f4556245563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4556245563,
"from":L[3135]});
}
} catch($e4555445555) {
if(R.isCont($e4555445555)) {
var $ss4555845559 = {"from":L[3135],
"go":function(ann_DASH_check_DASH_temp92945564) {
return $Hann_DASH_check_DASH_temp859145565(ann_DASH_check_DASH_temp92945564);
}};
$e4555445555.stack[R.EXN_STACKHEIGHT++] = $ss4555845559;
}
if(R.isPyretException($e4555445555)) {
$e4555445555.pyretStack.push(L[3135]);
}
throw $e4555445555;
}
var $ret4556045561 = $Hann_DASH_check_DASH_temp859145565($z4555645557);
++R.GAS;
return $ret4556045561;
};
var $Hann_DASH_check_DASH_temp859145565 = function(ann_DASH_check_DASH_temp92945564) {
return ann_DASH_check_DASH_temp92945564;
};
var $Hcont_tail_arg858917516 = function(cont_tail_arg92617514,if_helper91717515) {
if(--R.GAS > 0) {
$z4556645567 = R.isFunction(if_helper91717515)?if_helper91717515.app(cont_tail_arg92617514):R.ffi.throwNonFunApp(L[3135],if_helper91717515,[cont_tail_arg92617514]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper91717515)?if_helper91717515.app(cont_tail_arg92617514):R.ffi.throwNonFunApp(L[3135],if_helper91717515,[cont_tail_arg92617514]);
},
"from":L[3135]});
}
++R.GAS;
return $z4556645567;
};
var $Hcont_tail_arg859017531 = function(cont_tail_arg92217530,if_helper91717515) {
if(--R.GAS > 0) {
$z4556845569 = R.isFunction(if_helper91717515)?if_helper91717515.app(cont_tail_arg92217530):R.ffi.throwNonFunApp(L[3135],if_helper91717515,[cont_tail_arg92217530]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper91717515)?if_helper91717515.app(cont_tail_arg92217530):R.ffi.throwNonFunApp(L[3135],if_helper91717515,[cont_tail_arg92217530]);
},
"from":L[3135]});
}
++R.GAS;
return $z4556845569;
};
var $Hanf_arg858817552 = function(anf_arg91417550,anf_fun91217551) {
var $z4557245573 = D;
var $f4557845579 = function(_) {
return R.isFunction(anf_fun91217551)?anf_fun91217551.app(anf_arg91417550):R.ffi.throwNonFunApp(L[3153],anf_fun91217551,[anf_arg91417550]);
};
try {
if(--R.GAS > 0) {
$z4557245573 = $f4557845579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4557845579,
"from":L[3153]});
}
} catch($e4557045571) {
if(R.isCont($e4557045571)) {
var $ss4557445575 = {"from":L[3153],
"go":function(ann_DASH_check_DASH_temp91145580) {
return $Hann_DASH_check_DASH_temp858745581(ann_DASH_check_DASH_temp91145580);
}};
$e4557045571.stack[R.EXN_STACKHEIGHT++] = $ss4557445575;
}
if(R.isPyretException($e4557045571)) {
$e4557045571.pyretStack.push(L[3153]);
}
throw $e4557045571;
}
var $ret4557645577 = $Hann_DASH_check_DASH_temp858745581($z4557245573);
++R.GAS;
return $ret4557645577;
};
var $Hann_DASH_check_DASH_temp858745581 = function(ann_DASH_check_DASH_temp91145580) {
return ann_DASH_check_DASH_temp91145580;
};
var $Hanf_arg858617569 = function(anf_arg90117567,self11117568,_plus55,torepr65) {
var anf_arg90245592 = G(self11117568,"file",L[3136]);
var $z4558445585 = D;
var $f4559045591 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg90245592):R.ffi.throwNonFunApp(L[3136],torepr65,[anf_arg90245592]);
};
try {
if(--R.GAS > 0) {
$z4558445585 = $f4559045591();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4559045591,
"from":L[3136]});
}
} catch($e4558245583) {
if(R.isCont($e4558245583)) {
var $ss4558645587 = {"from":L[3136],
"go":function(anf_arg90345593) {
return $Hanf_arg858545594(anf_arg90345593,anf_arg90117567,_plus55);
}};
$e4558245583.stack[R.EXN_STACKHEIGHT++] = $ss4558645587;
}
if(R.isPyretException($e4558245583)) {
$e4558245583.pyretStack.push(L[3136]);
}
throw $e4558245583;
}
var $ret4558845589 = $Hanf_arg858545594($z4558445585,anf_arg90117567,_plus55);
++R.GAS;
return $ret4558845589;
};
var $Hanf_arg858545594 = function(anf_arg90345593,anf_arg90117567,_plus55) {
var $z4559745598 = D;
var $f4560345604 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg90345593):R.ffi.throwNonFunApp(L[3136],_plus55,[(", "),anf_arg90345593]);
};
try {
if(--R.GAS > 0) {
$z4559745598 = $f4560345604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4560345604,
"from":L[3136]});
}
} catch($e4559545596) {
if(R.isCont($e4559545596)) {
var $ss4559945600 = {"from":L[3136],
"go":function(anf_arg90445605) {
return $Hanf_arg858445606(anf_arg90445605,anf_arg90117567,_plus55);
}};
$e4559545596.stack[R.EXN_STACKHEIGHT++] = $ss4559945600;
}
if(R.isPyretException($e4559545596)) {
$e4559545596.pyretStack.push(L[3136]);
}
throw $e4559545596;
}
var $ret4560145602 = $Hanf_arg858445606($z4559745598,anf_arg90117567,_plus55);
++R.GAS;
return $ret4560145602;
};
var $Hanf_arg858445606 = function(anf_arg90445605,anf_arg90117567,_plus55) {
var $z4560945610 = D;
var $f4561545616 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg90117567,anf_arg90445605):R.ffi.throwNonFunApp(L[3136],_plus55,[anf_arg90117567,anf_arg90445605]);
};
try {
if(--R.GAS > 0) {
$z4560945610 = $f4561545616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4561545616,
"from":L[3136]});
}
} catch($e4560745608) {
if(R.isCont($e4560745608)) {
var $ss4561145612 = {"from":L[3136],
"go":function(anf_arg90545617) {
return $Hanf_arg858345618(anf_arg90545617,_plus55);
}};
$e4560745608.stack[R.EXN_STACKHEIGHT++] = $ss4561145612;
}
if(R.isPyretException($e4560745608)) {
$e4560745608.pyretStack.push(L[3136]);
}
throw $e4560745608;
}
var $ret4561345614 = $Hanf_arg858345618($z4560945610,_plus55);
++R.GAS;
return $ret4561345614;
};
var $Hanf_arg858345618 = function(anf_arg90545617,_plus55) {
var $z4562145622 = D;
var $f4562745628 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg90545617,(")")):R.ffi.throwNonFunApp(L[3136],_plus55,[anf_arg90545617,(")")]);
};
try {
if(--R.GAS > 0) {
$z4562145622 = $f4562745628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4562745628,
"from":L[3136]});
}
} catch($e4561945620) {
if(R.isCont($e4561945620)) {
var $ss4562345624 = {"from":L[3136],
"go":function(anf_arg90645629) {
return $Hanf_arg858245630(anf_arg90645629,_plus55);
}};
$e4561945620.stack[R.EXN_STACKHEIGHT++] = $ss4562345624;
}
if(R.isPyretException($e4561945620)) {
$e4561945620.pyretStack.push(L[3136]);
}
throw $e4561945620;
}
var $ret4562545626 = $Hanf_arg858245630($z4562145622,_plus55);
++R.GAS;
return $ret4562545626;
};
var $Hanf_arg858245630 = function(anf_arg90645629,_plus55) {
var $z4563345634 = D;
var $f4563945640 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg90645629):R.ffi.throwNonFunApp(L[3136],_plus55,[("("),anf_arg90645629]);
};
try {
if(--R.GAS > 0) {
$z4563345634 = $f4563945640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4563945640,
"from":L[3136]});
}
} catch($e4563145632) {
if(R.isCont($e4563145632)) {
var $ss4563545636 = {"from":L[3136],
"go":function(anf_arg90745641) {
return $Hanf_arg858145642(anf_arg90745641,_plus55);
}};
$e4563145632.stack[R.EXN_STACKHEIGHT++] = $ss4563545636;
}
if(R.isPyretException($e4563145632)) {
$e4563145632.pyretStack.push(L[3136]);
}
throw $e4563145632;
}
var $ret4563745638 = $Hanf_arg858145642($z4563345634,_plus55);
++R.GAS;
return $ret4563745638;
};
var $Hanf_arg858145642 = function(anf_arg90745641,_plus55) {
var $z4564545646 = D;
var $f4565145652 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-file-import"),anf_arg90745641):R.ffi.throwNonFunApp(L[3136],_plus55,[("s-file-import"),anf_arg90745641]);
};
try {
if(--R.GAS > 0) {
$z4564545646 = $f4565145652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4565145652,
"from":L[3136]});
}
} catch($e4564345644) {
if(R.isCont($e4564345644)) {
var $ss4564745648 = {"from":L[3136],
"go":function(ann_DASH_check_DASH_temp89945653) {
return $Hann_DASH_check_DASH_temp858045654(ann_DASH_check_DASH_temp89945653);
}};
$e4564345644.stack[R.EXN_STACKHEIGHT++] = $ss4564745648;
}
if(R.isPyretException($e4564345644)) {
$e4564345644.pyretStack.push(L[3136]);
}
throw $e4564345644;
}
var $ret4564945650 = $Hann_DASH_check_DASH_temp858045654($z4564545646);
++R.GAS;
return $ret4564945650;
};
var $Hann_DASH_check_DASH_temp858045654 = function(ann_DASH_check_DASH_temp89945653) {
return ann_DASH_check_DASH_temp89945653;
};
var $Hcont_tail_arg857817585 = function(cont_tail_arg89617583,if_helper88717584) {
if(--R.GAS > 0) {
$z4565545656 = R.isFunction(if_helper88717584)?if_helper88717584.app(cont_tail_arg89617583):R.ffi.throwNonFunApp(L[3136],if_helper88717584,[cont_tail_arg89617583]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper88717584)?if_helper88717584.app(cont_tail_arg89617583):R.ffi.throwNonFunApp(L[3136],if_helper88717584,[cont_tail_arg89617583]);
},
"from":L[3136]});
}
++R.GAS;
return $z4565545656;
};
var $Hcont_tail_arg857917600 = function(cont_tail_arg89217599,if_helper88717584) {
if(--R.GAS > 0) {
$z4565745658 = R.isFunction(if_helper88717584)?if_helper88717584.app(cont_tail_arg89217599):R.ffi.throwNonFunApp(L[3136],if_helper88717584,[cont_tail_arg89217599]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper88717584)?if_helper88717584.app(cont_tail_arg89217599):R.ffi.throwNonFunApp(L[3136],if_helper88717584,[cont_tail_arg89217599]);
},
"from":L[3136]});
}
++R.GAS;
return $z4565745658;
};
var $Hann_DASH_check_DASH_temp857717622 = function(ann_DASH_check_DASH_temp87817621) {
return ann_DASH_check_DASH_temp87817621;
};
var $Hanf_arg857617635 = function(anf_arg88217634,_plus55,raise62) {
var $z4566145662 = D;
var $f4566745668 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg88217634):R.ffi.throwNonFunApp(L[4773],_plus55,[("No visitor field for "),anf_arg88217634]);
};
try {
if(--R.GAS > 0) {
$z4566145662 = $f4566745668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4566745668,
"from":L[4773]});
}
} catch($e4565945660) {
if(R.isCont($e4565945660)) {
var $ss4566345664 = {"from":L[4773],
"go":function(anf_arg88345669) {
return $Hanf_arg857545670(anf_arg88345669,raise62);
}};
$e4565945660.stack[R.EXN_STACKHEIGHT++] = $ss4566345664;
}
if(R.isPyretException($e4565945660)) {
$e4565945660.pyretStack.push(L[4773]);
}
throw $e4565945660;
}
var $ret4566545666 = $Hanf_arg857545670($z4566145662,raise62);
++R.GAS;
return $ret4566545666;
};
var $Hanf_arg857545670 = function(anf_arg88345669,raise62) {
var $z4567345674 = D;
var $f4567945680 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg88345669):R.ffi.throwNonFunApp(L[3158],raise62,[anf_arg88345669]);
};
try {
if(--R.GAS > 0) {
$z4567345674 = $f4567945680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4567945680,
"from":L[3158]});
}
} catch($e4567145672) {
if(R.isCont($e4567145672)) {
var $ss4567545676 = {"from":L[3158],
"go":function(ann_DASH_check_DASH_temp88045681) {
return $Hann_DASH_check_DASH_temp857445682(ann_DASH_check_DASH_temp88045681);
}};
$e4567145672.stack[R.EXN_STACKHEIGHT++] = $ss4567545676;
}
if(R.isPyretException($e4567145672)) {
$e4567145672.pyretStack.push(L[3158]);
}
throw $e4567145672;
}
var $ret4567745678 = $Hann_DASH_check_DASH_temp857445682($z4567345674);
++R.GAS;
return $ret4567745678;
};
var $Hann_DASH_check_DASH_temp857445682 = function(ann_DASH_check_DASH_temp88045681) {
return ann_DASH_check_DASH_temp88045681;
};
var $Hanf_arg857317684 = function(anf_arg86117683,_plus55) {
var $z4568545686 = D;
var $f4569145692 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg86117683,(")")):R.ffi.throwNonFunApp(L[3162],_plus55,[anf_arg86117683,(")")]);
};
try {
if(--R.GAS > 0) {
$z4568545686 = $f4569145692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4569145692,
"from":L[3162]});
}
} catch($e4568345684) {
if(R.isCont($e4568345684)) {
var $ss4568745688 = {"from":L[3162],
"go":function(anf_arg86245693) {
return $Hanf_arg857245694(anf_arg86245693,_plus55);
}};
$e4568345684.stack[R.EXN_STACKHEIGHT++] = $ss4568745688;
}
if(R.isPyretException($e4568345684)) {
$e4568345684.pyretStack.push(L[3162]);
}
throw $e4568345684;
}
var $ret4568945690 = $Hanf_arg857245694($z4568545686,_plus55);
++R.GAS;
return $ret4568945690;
};
var $Hanf_arg857245694 = function(anf_arg86245693,_plus55) {
var $z4569745698 = D;
var $f4570345704 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg86245693):R.ffi.throwNonFunApp(L[3162],_plus55,[("("),anf_arg86245693]);
};
try {
if(--R.GAS > 0) {
$z4569745698 = $f4570345704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4570345704,
"from":L[3162]});
}
} catch($e4569545696) {
if(R.isCont($e4569545696)) {
var $ss4569945700 = {"from":L[3162],
"go":function(anf_arg86345705) {
return $Hanf_arg857145706(anf_arg86345705,_plus55);
}};
$e4569545696.stack[R.EXN_STACKHEIGHT++] = $ss4569945700;
}
if(R.isPyretException($e4569545696)) {
$e4569545696.pyretStack.push(L[3162]);
}
throw $e4569545696;
}
var $ret4570145702 = $Hanf_arg857145706($z4569745698,_plus55);
++R.GAS;
return $ret4570145702;
};
var $Hanf_arg857145706 = function(anf_arg86345705,_plus55) {
var $z4570945710 = D;
var $f4571545716 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-provide-types-none"),anf_arg86345705):R.ffi.throwNonFunApp(L[3162],_plus55,[("s-provide-types-none"),anf_arg86345705]);
};
try {
if(--R.GAS > 0) {
$z4570945710 = $f4571545716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4571545716,
"from":L[3162]});
}
} catch($e4570745708) {
if(R.isCont($e4570745708)) {
var $ss4571145712 = {"from":L[3162],
"go":function(ann_DASH_check_DASH_temp85945717) {
return $Hann_DASH_check_DASH_temp857045718(ann_DASH_check_DASH_temp85945717);
}};
$e4570745708.stack[R.EXN_STACKHEIGHT++] = $ss4571145712;
}
if(R.isPyretException($e4570745708)) {
$e4570745708.pyretStack.push(L[3162]);
}
throw $e4570745708;
}
var $ret4571345714 = $Hann_DASH_check_DASH_temp857045718($z4570945710);
++R.GAS;
return $ret4571345714;
};
var $Hann_DASH_check_DASH_temp857045718 = function(ann_DASH_check_DASH_temp85945717) {
return ann_DASH_check_DASH_temp85945717;
};
var $Hcont_tail_arg856817700 = function(cont_tail_arg85617698,if_helper84817699) {
if(--R.GAS > 0) {
$z4571945720 = R.isFunction(if_helper84817699)?if_helper84817699.app(cont_tail_arg85617698):R.ffi.throwNonFunApp(L[3162],if_helper84817699,[cont_tail_arg85617698]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper84817699)?if_helper84817699.app(cont_tail_arg85617698):R.ffi.throwNonFunApp(L[3162],if_helper84817699,[cont_tail_arg85617698]);
},
"from":L[3162]});
}
++R.GAS;
return $z4571945720;
};
var $Hcont_tail_arg856917715 = function(cont_tail_arg85317714,if_helper84817699) {
if(--R.GAS > 0) {
$z4572145722 = R.isFunction(if_helper84817699)?if_helper84817699.app(cont_tail_arg85317714):R.ffi.throwNonFunApp(L[3162],if_helper84817699,[cont_tail_arg85317714]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper84817699)?if_helper84817699.app(cont_tail_arg85317714):R.ffi.throwNonFunApp(L[3162],if_helper84817699,[cont_tail_arg85317714]);
},
"from":L[3162]});
}
++R.GAS;
return $z4572145722;
};
var $Hanf_arg856717738 = function(anf_arg83917737,_plus55) {
var $z4572545726 = D;
var $f4573145732 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg83917737,(")")):R.ffi.throwNonFunApp(L[3163],_plus55,[anf_arg83917737,(")")]);
};
try {
if(--R.GAS > 0) {
$z4572545726 = $f4573145732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4573145732,
"from":L[3163]});
}
} catch($e4572345724) {
if(R.isCont($e4572345724)) {
var $ss4572745728 = {"from":L[3163],
"go":function(anf_arg84045733) {
return $Hanf_arg856645734(anf_arg84045733,_plus55);
}};
$e4572345724.stack[R.EXN_STACKHEIGHT++] = $ss4572745728;
}
if(R.isPyretException($e4572345724)) {
$e4572345724.pyretStack.push(L[3163]);
}
throw $e4572345724;
}
var $ret4572945730 = $Hanf_arg856645734($z4572545726,_plus55);
++R.GAS;
return $ret4572945730;
};
var $Hanf_arg856645734 = function(anf_arg84045733,_plus55) {
var $z4573745738 = D;
var $f4574345744 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg84045733):R.ffi.throwNonFunApp(L[3163],_plus55,[("("),anf_arg84045733]);
};
try {
if(--R.GAS > 0) {
$z4573745738 = $f4574345744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4574345744,
"from":L[3163]});
}
} catch($e4573545736) {
if(R.isCont($e4573545736)) {
var $ss4573945740 = {"from":L[3163],
"go":function(anf_arg84145745) {
return $Hanf_arg856545746(anf_arg84145745,_plus55);
}};
$e4573545736.stack[R.EXN_STACKHEIGHT++] = $ss4573945740;
}
if(R.isPyretException($e4573545736)) {
$e4573545736.pyretStack.push(L[3163]);
}
throw $e4573545736;
}
var $ret4574145742 = $Hanf_arg856545746($z4573745738,_plus55);
++R.GAS;
return $ret4574145742;
};
var $Hanf_arg856545746 = function(anf_arg84145745,_plus55) {
var $z4574945750 = D;
var $f4575545756 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-provide-types-all"),anf_arg84145745):R.ffi.throwNonFunApp(L[3163],_plus55,[("s-provide-types-all"),anf_arg84145745]);
};
try {
if(--R.GAS > 0) {
$z4574945750 = $f4575545756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4575545756,
"from":L[3163]});
}
} catch($e4574745748) {
if(R.isCont($e4574745748)) {
var $ss4575145752 = {"from":L[3163],
"go":function(ann_DASH_check_DASH_temp83745757) {
return $Hann_DASH_check_DASH_temp856445758(ann_DASH_check_DASH_temp83745757);
}};
$e4574745748.stack[R.EXN_STACKHEIGHT++] = $ss4575145752;
}
if(R.isPyretException($e4574745748)) {
$e4574745748.pyretStack.push(L[3163]);
}
throw $e4574745748;
}
var $ret4575345754 = $Hann_DASH_check_DASH_temp856445758($z4574945750);
++R.GAS;
return $ret4575345754;
};
var $Hann_DASH_check_DASH_temp856445758 = function(ann_DASH_check_DASH_temp83745757) {
return ann_DASH_check_DASH_temp83745757;
};
var $Hcont_tail_arg856217754 = function(cont_tail_arg83417752,if_helper82617753) {
if(--R.GAS > 0) {
$z4575945760 = R.isFunction(if_helper82617753)?if_helper82617753.app(cont_tail_arg83417752):R.ffi.throwNonFunApp(L[3163],if_helper82617753,[cont_tail_arg83417752]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper82617753)?if_helper82617753.app(cont_tail_arg83417752):R.ffi.throwNonFunApp(L[3163],if_helper82617753,[cont_tail_arg83417752]);
},
"from":L[3163]});
}
++R.GAS;
return $z4575945760;
};
var $Hcont_tail_arg856317769 = function(cont_tail_arg83117768,if_helper82617753) {
if(--R.GAS > 0) {
$z4576145762 = R.isFunction(if_helper82617753)?if_helper82617753.app(cont_tail_arg83117768):R.ffi.throwNonFunApp(L[3163],if_helper82617753,[cont_tail_arg83117768]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper82617753)?if_helper82617753.app(cont_tail_arg83117768):R.ffi.throwNonFunApp(L[3163],if_helper82617753,[cont_tail_arg83117768]);
},
"from":L[3163]});
}
++R.GAS;
return $z4576145762;
};
var $Hanf_arg856117790 = function(anf_arg80817787,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55) {
var anf_arg80945773 = G(PP170,"lbrace",L[4774]);
var $z4576545766 = D;
var $f4577145772 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg80817787,anf_arg80945773):R.ffi.throwNonFunApp(L[3180],_plus55,[anf_arg80817787,anf_arg80945773]);
};
try {
if(--R.GAS > 0) {
$z4576545766 = $f4577145772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4577145772,
"from":L[3180]});
}
} catch($e4576345764) {
if(R.isCont($e4576345764)) {
var $ss4576745768 = {"from":L[3180],
"go":function(anf_arg81045774) {
return $Hanf_arg856045775(anf_arg81045774,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55);
}};
$e4576345764.stack[R.EXN_STACKHEIGHT++] = $ss4576745768;
}
if(R.isPyretException($e4576345764)) {
$e4576345764.pyretStack.push(L[3180]);
}
throw $e4576345764;
}
var $ret4576945770 = $Hanf_arg856045775($z4576545766,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55);
++R.GAS;
return $ret4576945770;
};
var $Hanf_arg856045775 = function(anf_arg81045774,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55) {
var anf_arg81145786 = G(PP170,"rbrace",L[4775]);
var $z4577845779 = D;
var $f4578445785 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg81045774,anf_arg81145786):R.ffi.throwNonFunApp(L[3180],_plus55,[anf_arg81045774,anf_arg81145786]);
};
try {
if(--R.GAS > 0) {
$z4577845779 = $f4578445785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4578445785,
"from":L[3180]});
}
} catch($e4577645777) {
if(R.isCont($e4577645777)) {
var $ss4578045781 = {"from":L[3180],
"go":function(anf_arg81245787) {
return $Hanf_arg855945788(anf_arg81245787,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55);
}};
$e4577645777.stack[R.EXN_STACKHEIGHT++] = $ss4578045781;
}
if(R.isPyretException($e4577645777)) {
$e4577645777.pyretStack.push(L[3180]);
}
throw $e4577645777;
}
var $ret4578245783 = $Hanf_arg855945788($z4577845779,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55);
++R.GAS;
return $ret4578245783;
};
var $Hanf_arg855945788 = function(anf_arg81245787,INDENT118169,PP170,anf_fun80717788,break_DASH_one119168,self59717789,str_DASH_provide_DASH_types164754,_plus55) {
var $z4579145792 = D;
var $f4579745798 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_provide_DASH_types164754,break_DASH_one119168):R.ffi.throwNonFunApp(L[4776],_plus55,[str_DASH_provide_DASH_types164754,break_DASH_one119168]);
};
try {
if(--R.GAS > 0) {
$z4579145792 = $f4579745798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4579745798,
"from":L[4776]});
}
} catch($e4578945790) {
if(R.isCont($e4578945790)) {
var $ss4579345794 = {"from":L[4776],
"go":function(anf_arg81345799) {
return $Hanf_arg855845800(anf_arg81345799,INDENT118169,PP170,anf_arg81245787,anf_fun80717788,self59717789,_plus55);
}};
$e4578945790.stack[R.EXN_STACKHEIGHT++] = $ss4579345794;
}
if(R.isPyretException($e4578945790)) {
$e4578945790.pyretStack.push(L[4776]);
}
throw $e4578945790;
}
var $ret4579545796 = $Hanf_arg855845800($z4579145792,INDENT118169,PP170,anf_arg81245787,anf_fun80717788,self59717789,_plus55);
++R.GAS;
return $ret4579545796;
};
var $Hanf_arg855845800 = function(anf_arg81345799,INDENT118169,PP170,anf_arg81245787,anf_fun80717788,self59717789,_plus55) {
var anf_arg81445811 = G(PP170,"lbrace",L[4777]);
var $z4580345804 = D;
var $f4580945810 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg81345799,anf_arg81445811):R.ffi.throwNonFunApp(L[4776],_plus55,[anf_arg81345799,anf_arg81445811]);
};
try {
if(--R.GAS > 0) {
$z4580345804 = $f4580945810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4580945810,
"from":L[4776]});
}
} catch($e4580145802) {
if(R.isCont($e4580145802)) {
var $ss4580545806 = {"from":L[4776],
"go":function(anf_arg81545812) {
return $Hanf_arg855745813(anf_arg81545812,INDENT118169,PP170,anf_arg81245787,anf_fun80717788,self59717789);
}};
$e4580145802.stack[R.EXN_STACKHEIGHT++] = $ss4580545806;
}
if(R.isPyretException($e4580145802)) {
$e4580145802.pyretStack.push(L[4776]);
}
throw $e4580145802;
}
var $ret4580745808 = $Hanf_arg855745813($z4580345804,INDENT118169,PP170,anf_arg81245787,anf_fun80717788,self59717789);
++R.GAS;
return $ret4580745808;
};
var $Hanf_arg855745813 = function(anf_arg81545812,INDENT118169,PP170,anf_arg81245787,anf_fun80717788,self59717789) {
var anf_arg81645827 = G(PP170,"commabreak",L[4783]);
var anf_arg81745828 = G(PP170,"rbrace",L[4782]);
var anf_bracket81845844 = G(self59717789,"ann",L[4781]);
var anf_fun81945824 = G(anf_bracket81845844,"map",L[4780]);
var anf_arg82245825 = R.makeFunction(function(recv_DASH_9445830) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4779],1,arguments);
}
var anf_fun82145841 = G(recv_DASH_9445830,"tosource",L[4779]);
var $z4583345834 = D;
var $f4583945840 = function(_) {
return R.isFunction(anf_fun82145841)?anf_fun82145841.app():R.ffi.throwNonFunApp(L[4779],anf_fun82145841,[]);
};
try {
if(--R.GAS > 0) {
$z4583345834 = $f4583945840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4583945840,
"from":L[4779]});
}
} catch($e4583145832) {
if(R.isCont($e4583145832)) {
var $ss4583545836 = {"from":L[4779],
"go":function(ann_DASH_check_DASH_temp82045842) {
return $Hann_DASH_check_DASH_temp855445843(ann_DASH_check_DASH_temp82045842);
}};
$e4583145832.stack[R.EXN_STACKHEIGHT++] = $ss4583545836;
}
if(R.isPyretException($e4583145832)) {
$e4583145832.pyretStack.push(L[4779]);
}
throw $e4583145832;
}
var $ret4583745838 = $Hann_DASH_check_DASH_temp855445843($z4583345834);
++R.GAS;
return $ret4583745838;
});
var $z4581645817 = D;
var $f4582245823 = function(_) {
return R.isFunction(anf_fun81945824)?anf_fun81945824.app(anf_arg82245825):R.ffi.throwNonFunApp(L[4778],anf_fun81945824,[anf_arg82245825]);
};
try {
if(--R.GAS > 0) {
$z4581645817 = $f4582245823();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4582245823,
"from":L[4778]});
}
} catch($e4581445815) {
if(R.isCont($e4581445815)) {
var $ss4581845819 = {"from":L[4778],
"go":function(anf_arg82345826) {
return $Hanf_arg855645829(anf_arg82345826,INDENT118169,anf_arg81245787,anf_arg81545812,anf_arg81645827,anf_arg81745828,anf_fun80717788);
}};
$e4581445815.stack[R.EXN_STACKHEIGHT++] = $ss4581845819;
}
if(R.isPyretException($e4581445815)) {
$e4581445815.pyretStack.push(L[4778]);
}
throw $e4581445815;
}
var $ret4582045821 = $Hanf_arg855645829($z4581645817,INDENT118169,anf_arg81245787,anf_arg81545812,anf_arg81645827,anf_arg81745828,anf_fun80717788);
++R.GAS;
return $ret4582045821;
};
var $Hanf_arg855645829 = function(anf_arg82345826,INDENT118169,anf_arg81245787,anf_arg81545812,anf_arg81645827,anf_arg81745828,anf_fun80717788) {
var $z4584745848 = D;
var $f4585345854 = function(_) {
return R.isFunction(anf_fun80717788)?anf_fun80717788.app(INDENT118169,(1),anf_arg81245787,anf_arg81545812,anf_arg81645827,anf_arg81745828,anf_arg82345826):R.ffi.throwNonFunApp(L[3182],anf_fun80717788,[INDENT118169,(1),anf_arg81245787,anf_arg81545812,anf_arg81645827,anf_arg81745828,anf_arg82345826]);
};
try {
if(--R.GAS > 0) {
$z4584745848 = $f4585345854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4585345854,
"from":L[3182]});
}
} catch($e4584545846) {
if(R.isCont($e4584545846)) {
var $ss4584945850 = {"from":L[3182],
"go":function(ann_DASH_check_DASH_temp80645855) {
return $Hann_DASH_check_DASH_temp855545856(ann_DASH_check_DASH_temp80645855);
}};
$e4584545846.stack[R.EXN_STACKHEIGHT++] = $ss4584945850;
}
if(R.isPyretException($e4584545846)) {
$e4584545846.pyretStack.push(L[3182]);
}
throw $e4584545846;
}
var $ret4585145852 = $Hann_DASH_check_DASH_temp855545856($z4584745848);
++R.GAS;
return $ret4585145852;
};
var $Hann_DASH_check_DASH_temp855545856 = function(ann_DASH_check_DASH_temp80645855) {
return ann_DASH_check_DASH_temp80645855;
};
var $Hann_DASH_check_DASH_temp855445843 = function(ann_DASH_check_DASH_temp82045842) {
return ann_DASH_check_DASH_temp82045842;
};
var $Hanf_arg855317805 = function(anf_arg79617803,self9217804,_plus55,torepr65) {
var anf_arg79745867 = G(self9217804,"ann",L[3164]);
var $z4585945860 = D;
var $f4586545866 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg79745867):R.ffi.throwNonFunApp(L[3164],torepr65,[anf_arg79745867]);
};
try {
if(--R.GAS > 0) {
$z4585945860 = $f4586545866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4586545866,
"from":L[3164]});
}
} catch($e4585745858) {
if(R.isCont($e4585745858)) {
var $ss4586145862 = {"from":L[3164],
"go":function(anf_arg79845868) {
return $Hanf_arg855245869(anf_arg79845868,anf_arg79617803,_plus55);
}};
$e4585745858.stack[R.EXN_STACKHEIGHT++] = $ss4586145862;
}
if(R.isPyretException($e4585745858)) {
$e4585745858.pyretStack.push(L[3164]);
}
throw $e4585745858;
}
var $ret4586345864 = $Hanf_arg855245869($z4585945860,anf_arg79617803,_plus55);
++R.GAS;
return $ret4586345864;
};
var $Hanf_arg855245869 = function(anf_arg79845868,anf_arg79617803,_plus55) {
var $z4587245873 = D;
var $f4587845879 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg79845868):R.ffi.throwNonFunApp(L[3164],_plus55,[(", "),anf_arg79845868]);
};
try {
if(--R.GAS > 0) {
$z4587245873 = $f4587845879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4587845879,
"from":L[3164]});
}
} catch($e4587045871) {
if(R.isCont($e4587045871)) {
var $ss4587445875 = {"from":L[3164],
"go":function(anf_arg79945880) {
return $Hanf_arg855145881(anf_arg79945880,anf_arg79617803,_plus55);
}};
$e4587045871.stack[R.EXN_STACKHEIGHT++] = $ss4587445875;
}
if(R.isPyretException($e4587045871)) {
$e4587045871.pyretStack.push(L[3164]);
}
throw $e4587045871;
}
var $ret4587645877 = $Hanf_arg855145881($z4587245873,anf_arg79617803,_plus55);
++R.GAS;
return $ret4587645877;
};
var $Hanf_arg855145881 = function(anf_arg79945880,anf_arg79617803,_plus55) {
var $z4588445885 = D;
var $f4589045891 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg79617803,anf_arg79945880):R.ffi.throwNonFunApp(L[3164],_plus55,[anf_arg79617803,anf_arg79945880]);
};
try {
if(--R.GAS > 0) {
$z4588445885 = $f4589045891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4589045891,
"from":L[3164]});
}
} catch($e4588245883) {
if(R.isCont($e4588245883)) {
var $ss4588645887 = {"from":L[3164],
"go":function(anf_arg80045892) {
return $Hanf_arg855045893(anf_arg80045892,_plus55);
}};
$e4588245883.stack[R.EXN_STACKHEIGHT++] = $ss4588645887;
}
if(R.isPyretException($e4588245883)) {
$e4588245883.pyretStack.push(L[3164]);
}
throw $e4588245883;
}
var $ret4588845889 = $Hanf_arg855045893($z4588445885,_plus55);
++R.GAS;
return $ret4588845889;
};
var $Hanf_arg855045893 = function(anf_arg80045892,_plus55) {
var $z4589645897 = D;
var $f4590245903 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg80045892,(")")):R.ffi.throwNonFunApp(L[3164],_plus55,[anf_arg80045892,(")")]);
};
try {
if(--R.GAS > 0) {
$z4589645897 = $f4590245903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4590245903,
"from":L[3164]});
}
} catch($e4589445895) {
if(R.isCont($e4589445895)) {
var $ss4589845899 = {"from":L[3164],
"go":function(anf_arg80145904) {
return $Hanf_arg854945905(anf_arg80145904,_plus55);
}};
$e4589445895.stack[R.EXN_STACKHEIGHT++] = $ss4589845899;
}
if(R.isPyretException($e4589445895)) {
$e4589445895.pyretStack.push(L[3164]);
}
throw $e4589445895;
}
var $ret4590045901 = $Hanf_arg854945905($z4589645897,_plus55);
++R.GAS;
return $ret4590045901;
};
var $Hanf_arg854945905 = function(anf_arg80145904,_plus55) {
var $z4590845909 = D;
var $f4591445915 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg80145904):R.ffi.throwNonFunApp(L[3164],_plus55,[("("),anf_arg80145904]);
};
try {
if(--R.GAS > 0) {
$z4590845909 = $f4591445915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4591445915,
"from":L[3164]});
}
} catch($e4590645907) {
if(R.isCont($e4590645907)) {
var $ss4591045911 = {"from":L[3164],
"go":function(anf_arg80245916) {
return $Hanf_arg854845917(anf_arg80245916,_plus55);
}};
$e4590645907.stack[R.EXN_STACKHEIGHT++] = $ss4591045911;
}
if(R.isPyretException($e4590645907)) {
$e4590645907.pyretStack.push(L[3164]);
}
throw $e4590645907;
}
var $ret4591245913 = $Hanf_arg854845917($z4590845909,_plus55);
++R.GAS;
return $ret4591245913;
};
var $Hanf_arg854845917 = function(anf_arg80245916,_plus55) {
var $z4592045921 = D;
var $f4592645927 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-provide-types"),anf_arg80245916):R.ffi.throwNonFunApp(L[3164],_plus55,[("s-provide-types"),anf_arg80245916]);
};
try {
if(--R.GAS > 0) {
$z4592045921 = $f4592645927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4592645927,
"from":L[3164]});
}
} catch($e4591845919) {
if(R.isCont($e4591845919)) {
var $ss4592245923 = {"from":L[3164],
"go":function(ann_DASH_check_DASH_temp79445928) {
return $Hann_DASH_check_DASH_temp854745929(ann_DASH_check_DASH_temp79445928);
}};
$e4591845919.stack[R.EXN_STACKHEIGHT++] = $ss4592245923;
}
if(R.isPyretException($e4591845919)) {
$e4591845919.pyretStack.push(L[3164]);
}
throw $e4591845919;
}
var $ret4592445925 = $Hann_DASH_check_DASH_temp854745929($z4592045921);
++R.GAS;
return $ret4592445925;
};
var $Hann_DASH_check_DASH_temp854745929 = function(ann_DASH_check_DASH_temp79445928) {
return ann_DASH_check_DASH_temp79445928;
};
var $Hcont_tail_arg854517821 = function(cont_tail_arg79117819,if_helper78217820) {
if(--R.GAS > 0) {
$z4593045931 = R.isFunction(if_helper78217820)?if_helper78217820.app(cont_tail_arg79117819):R.ffi.throwNonFunApp(L[3164],if_helper78217820,[cont_tail_arg79117819]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper78217820)?if_helper78217820.app(cont_tail_arg79117819):R.ffi.throwNonFunApp(L[3164],if_helper78217820,[cont_tail_arg79117819]);
},
"from":L[3164]});
}
++R.GAS;
return $z4593045931;
};
var $Hcont_tail_arg854617836 = function(cont_tail_arg78717835,if_helper78217820) {
if(--R.GAS > 0) {
$z4593245933 = R.isFunction(if_helper78217820)?if_helper78217820.app(cont_tail_arg78717835):R.ffi.throwNonFunApp(L[3164],if_helper78217820,[cont_tail_arg78717835]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper78217820)?if_helper78217820.app(cont_tail_arg78717835):R.ffi.throwNonFunApp(L[3164],if_helper78217820,[cont_tail_arg78717835]);
},
"from":L[3164]});
}
++R.GAS;
return $z4593245933;
};
var $Hann_DASH_check_DASH_temp854417858 = function(ann_DASH_check_DASH_temp77317857) {
return ann_DASH_check_DASH_temp77317857;
};
var $Hanf_arg854317871 = function(anf_arg77717870,_plus55,raise62) {
var $z4593645937 = D;
var $f4594245943 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg77717870):R.ffi.throwNonFunApp(L[4784],_plus55,[("No visitor field for "),anf_arg77717870]);
};
try {
if(--R.GAS > 0) {
$z4593645937 = $f4594245943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4594245943,
"from":L[4784]});
}
} catch($e4593445935) {
if(R.isCont($e4593445935)) {
var $ss4593845939 = {"from":L[4784],
"go":function(anf_arg77845944) {
return $Hanf_arg854245945(anf_arg77845944,raise62);
}};
$e4593445935.stack[R.EXN_STACKHEIGHT++] = $ss4593845939;
}
if(R.isPyretException($e4593445935)) {
$e4593445935.pyretStack.push(L[4784]);
}
throw $e4593445935;
}
var $ret4594045941 = $Hanf_arg854245945($z4593645937,raise62);
++R.GAS;
return $ret4594045941;
};
var $Hanf_arg854245945 = function(anf_arg77845944,raise62) {
var $z4594845949 = D;
var $f4595445955 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg77845944):R.ffi.throwNonFunApp(L[3187],raise62,[anf_arg77845944]);
};
try {
if(--R.GAS > 0) {
$z4594845949 = $f4595445955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4595445955,
"from":L[3187]});
}
} catch($e4594645947) {
if(R.isCont($e4594645947)) {
var $ss4595045951 = {"from":L[3187],
"go":function(ann_DASH_check_DASH_temp77545956) {
return $Hann_DASH_check_DASH_temp854145957(ann_DASH_check_DASH_temp77545956);
}};
$e4594645947.stack[R.EXN_STACKHEIGHT++] = $ss4595045951;
}
if(R.isPyretException($e4594645947)) {
$e4594645947.pyretStack.push(L[3187]);
}
throw $e4594645947;
}
var $ret4595245953 = $Hann_DASH_check_DASH_temp854145957($z4594845949);
++R.GAS;
return $ret4595245953;
};
var $Hann_DASH_check_DASH_temp854145957 = function(ann_DASH_check_DASH_temp77545956) {
return ann_DASH_check_DASH_temp77545956;
};
var $Hanf_arg854017920 = function(anf_arg75617919,_plus55) {
var $z4596045961 = D;
var $f4596645967 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg75617919,(")")):R.ffi.throwNonFunApp(L[3191],_plus55,[anf_arg75617919,(")")]);
};
try {
if(--R.GAS > 0) {
$z4596045961 = $f4596645967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4596645967,
"from":L[3191]});
}
} catch($e4595845959) {
if(R.isCont($e4595845959)) {
var $ss4596245963 = {"from":L[3191],
"go":function(anf_arg75745968) {
return $Hanf_arg853945969(anf_arg75745968,_plus55);
}};
$e4595845959.stack[R.EXN_STACKHEIGHT++] = $ss4596245963;
}
if(R.isPyretException($e4595845959)) {
$e4595845959.pyretStack.push(L[3191]);
}
throw $e4595845959;
}
var $ret4596445965 = $Hanf_arg853945969($z4596045961,_plus55);
++R.GAS;
return $ret4596445965;
};
var $Hanf_arg853945969 = function(anf_arg75745968,_plus55) {
var $z4597245973 = D;
var $f4597845979 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg75745968):R.ffi.throwNonFunApp(L[3191],_plus55,[("("),anf_arg75745968]);
};
try {
if(--R.GAS > 0) {
$z4597245973 = $f4597845979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4597845979,
"from":L[3191]});
}
} catch($e4597045971) {
if(R.isCont($e4597045971)) {
var $ss4597445975 = {"from":L[3191],
"go":function(anf_arg75845980) {
return $Hanf_arg853845981(anf_arg75845980,_plus55);
}};
$e4597045971.stack[R.EXN_STACKHEIGHT++] = $ss4597445975;
}
if(R.isPyretException($e4597045971)) {
$e4597045971.pyretStack.push(L[3191]);
}
throw $e4597045971;
}
var $ret4597645977 = $Hanf_arg853845981($z4597245973,_plus55);
++R.GAS;
return $ret4597645977;
};
var $Hanf_arg853845981 = function(anf_arg75845980,_plus55) {
var $z4598445985 = D;
var $f4599045991 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-provide-none"),anf_arg75845980):R.ffi.throwNonFunApp(L[3191],_plus55,[("s-provide-none"),anf_arg75845980]);
};
try {
if(--R.GAS > 0) {
$z4598445985 = $f4599045991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4599045991,
"from":L[3191]});
}
} catch($e4598245983) {
if(R.isCont($e4598245983)) {
var $ss4598645987 = {"from":L[3191],
"go":function(ann_DASH_check_DASH_temp75445992) {
return $Hann_DASH_check_DASH_temp853745993(ann_DASH_check_DASH_temp75445992);
}};
$e4598245983.stack[R.EXN_STACKHEIGHT++] = $ss4598645987;
}
if(R.isPyretException($e4598245983)) {
$e4598245983.pyretStack.push(L[3191]);
}
throw $e4598245983;
}
var $ret4598845989 = $Hann_DASH_check_DASH_temp853745993($z4598445985);
++R.GAS;
return $ret4598845989;
};
var $Hann_DASH_check_DASH_temp853745993 = function(ann_DASH_check_DASH_temp75445992) {
return ann_DASH_check_DASH_temp75445992;
};
var $Hcont_tail_arg853517936 = function(cont_tail_arg75117934,if_helper74317935) {
if(--R.GAS > 0) {
$z4599445995 = R.isFunction(if_helper74317935)?if_helper74317935.app(cont_tail_arg75117934):R.ffi.throwNonFunApp(L[3191],if_helper74317935,[cont_tail_arg75117934]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper74317935)?if_helper74317935.app(cont_tail_arg75117934):R.ffi.throwNonFunApp(L[3191],if_helper74317935,[cont_tail_arg75117934]);
},
"from":L[3191]});
}
++R.GAS;
return $z4599445995;
};
var $Hcont_tail_arg853617951 = function(cont_tail_arg74817950,if_helper74317935) {
if(--R.GAS > 0) {
$z4599645997 = R.isFunction(if_helper74317935)?if_helper74317935.app(cont_tail_arg74817950):R.ffi.throwNonFunApp(L[3191],if_helper74317935,[cont_tail_arg74817950]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper74317935)?if_helper74317935.app(cont_tail_arg74817950):R.ffi.throwNonFunApp(L[3191],if_helper74317935,[cont_tail_arg74817950]);
},
"from":L[3191]});
}
++R.GAS;
return $z4599645997;
};
var $Hanf_arg853417974 = function(anf_arg73417973,_plus55) {
var $z4600046001 = D;
var $f4600646007 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg73417973,(")")):R.ffi.throwNonFunApp(L[3192],_plus55,[anf_arg73417973,(")")]);
};
try {
if(--R.GAS > 0) {
$z4600046001 = $f4600646007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4600646007,
"from":L[3192]});
}
} catch($e4599845999) {
if(R.isCont($e4599845999)) {
var $ss4600246003 = {"from":L[3192],
"go":function(anf_arg73546008) {
return $Hanf_arg853346009(anf_arg73546008,_plus55);
}};
$e4599845999.stack[R.EXN_STACKHEIGHT++] = $ss4600246003;
}
if(R.isPyretException($e4599845999)) {
$e4599845999.pyretStack.push(L[3192]);
}
throw $e4599845999;
}
var $ret4600446005 = $Hanf_arg853346009($z4600046001,_plus55);
++R.GAS;
return $ret4600446005;
};
var $Hanf_arg853346009 = function(anf_arg73546008,_plus55) {
var $z4601246013 = D;
var $f4601846019 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg73546008):R.ffi.throwNonFunApp(L[3192],_plus55,[("("),anf_arg73546008]);
};
try {
if(--R.GAS > 0) {
$z4601246013 = $f4601846019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4601846019,
"from":L[3192]});
}
} catch($e4601046011) {
if(R.isCont($e4601046011)) {
var $ss4601446015 = {"from":L[3192],
"go":function(anf_arg73646020) {
return $Hanf_arg853246021(anf_arg73646020,_plus55);
}};
$e4601046011.stack[R.EXN_STACKHEIGHT++] = $ss4601446015;
}
if(R.isPyretException($e4601046011)) {
$e4601046011.pyretStack.push(L[3192]);
}
throw $e4601046011;
}
var $ret4601646017 = $Hanf_arg853246021($z4601246013,_plus55);
++R.GAS;
return $ret4601646017;
};
var $Hanf_arg853246021 = function(anf_arg73646020,_plus55) {
var $z4602446025 = D;
var $f4603046031 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-provide-all"),anf_arg73646020):R.ffi.throwNonFunApp(L[3192],_plus55,[("s-provide-all"),anf_arg73646020]);
};
try {
if(--R.GAS > 0) {
$z4602446025 = $f4603046031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4603046031,
"from":L[3192]});
}
} catch($e4602246023) {
if(R.isCont($e4602246023)) {
var $ss4602646027 = {"from":L[3192],
"go":function(ann_DASH_check_DASH_temp73246032) {
return $Hann_DASH_check_DASH_temp853146033(ann_DASH_check_DASH_temp73246032);
}};
$e4602246023.stack[R.EXN_STACKHEIGHT++] = $ss4602646027;
}
if(R.isPyretException($e4602246023)) {
$e4602246023.pyretStack.push(L[3192]);
}
throw $e4602246023;
}
var $ret4602846029 = $Hann_DASH_check_DASH_temp853146033($z4602446025);
++R.GAS;
return $ret4602846029;
};
var $Hann_DASH_check_DASH_temp853146033 = function(ann_DASH_check_DASH_temp73246032) {
return ann_DASH_check_DASH_temp73246032;
};
var $Hcont_tail_arg852917990 = function(cont_tail_arg72917988,if_helper72117989) {
if(--R.GAS > 0) {
$z4603446035 = R.isFunction(if_helper72117989)?if_helper72117989.app(cont_tail_arg72917988):R.ffi.throwNonFunApp(L[3192],if_helper72117989,[cont_tail_arg72917988]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper72117989)?if_helper72117989.app(cont_tail_arg72917988):R.ffi.throwNonFunApp(L[3192],if_helper72117989,[cont_tail_arg72917988]);
},
"from":L[3192]});
}
++R.GAS;
return $z4603446035;
};
var $Hcont_tail_arg853018005 = function(cont_tail_arg72618004,if_helper72117989) {
if(--R.GAS > 0) {
$z4603646037 = R.isFunction(if_helper72117989)?if_helper72117989.app(cont_tail_arg72618004):R.ffi.throwNonFunApp(L[3192],if_helper72117989,[cont_tail_arg72618004]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper72117989)?if_helper72117989.app(cont_tail_arg72618004):R.ffi.throwNonFunApp(L[3192],if_helper72117989,[cont_tail_arg72618004]);
},
"from":L[3192]});
}
++R.GAS;
return $z4603646037;
};
var $Hanf_arg852818026 = function(anf_arg71818024,INDENT118169,anf_fun71518025,str_DASH_end148546,str_DASH_provide163741) {
var $z4604046041 = D;
var $f4604646047 = function(_) {
return R.isFunction(anf_fun71518025)?anf_fun71518025.app(INDENT118169,(1),str_DASH_provide163741,anf_arg71818024,str_DASH_end148546):R.ffi.throwNonFunApp(L[3213],anf_fun71518025,[INDENT118169,(1),str_DASH_provide163741,anf_arg71818024,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4604046041 = $f4604646047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4604646047,
"from":L[3213]});
}
} catch($e4603846039) {
if(R.isCont($e4603846039)) {
var $ss4604246043 = {"from":L[3213],
"go":function(ann_DASH_check_DASH_temp71446048) {
return $Hann_DASH_check_DASH_temp852746049(ann_DASH_check_DASH_temp71446048);
}};
$e4603846039.stack[R.EXN_STACKHEIGHT++] = $ss4604246043;
}
if(R.isPyretException($e4603846039)) {
$e4603846039.pyretStack.push(L[3213]);
}
throw $e4603846039;
}
var $ret4604446045 = $Hann_DASH_check_DASH_temp852746049($z4604046041);
++R.GAS;
return $ret4604446045;
};
var $Hann_DASH_check_DASH_temp852746049 = function(ann_DASH_check_DASH_temp71446048) {
return ann_DASH_check_DASH_temp71446048;
};
var $Hanf_arg852618043 = function(anf_arg70418041,self7418042,_plus55,torepr65) {
var anf_arg70546060 = G(self7418042,"block",L[3193]);
var $z4605246053 = D;
var $f4605846059 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg70546060):R.ffi.throwNonFunApp(L[3193],torepr65,[anf_arg70546060]);
};
try {
if(--R.GAS > 0) {
$z4605246053 = $f4605846059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4605846059,
"from":L[3193]});
}
} catch($e4605046051) {
if(R.isCont($e4605046051)) {
var $ss4605446055 = {"from":L[3193],
"go":function(anf_arg70646061) {
return $Hanf_arg852546062(anf_arg70646061,anf_arg70418041,_plus55);
}};
$e4605046051.stack[R.EXN_STACKHEIGHT++] = $ss4605446055;
}
if(R.isPyretException($e4605046051)) {
$e4605046051.pyretStack.push(L[3193]);
}
throw $e4605046051;
}
var $ret4605646057 = $Hanf_arg852546062($z4605246053,anf_arg70418041,_plus55);
++R.GAS;
return $ret4605646057;
};
var $Hanf_arg852546062 = function(anf_arg70646061,anf_arg70418041,_plus55) {
var $z4606546066 = D;
var $f4607146072 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg70646061):R.ffi.throwNonFunApp(L[3193],_plus55,[(", "),anf_arg70646061]);
};
try {
if(--R.GAS > 0) {
$z4606546066 = $f4607146072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4607146072,
"from":L[3193]});
}
} catch($e4606346064) {
if(R.isCont($e4606346064)) {
var $ss4606746068 = {"from":L[3193],
"go":function(anf_arg70746073) {
return $Hanf_arg852446074(anf_arg70746073,anf_arg70418041,_plus55);
}};
$e4606346064.stack[R.EXN_STACKHEIGHT++] = $ss4606746068;
}
if(R.isPyretException($e4606346064)) {
$e4606346064.pyretStack.push(L[3193]);
}
throw $e4606346064;
}
var $ret4606946070 = $Hanf_arg852446074($z4606546066,anf_arg70418041,_plus55);
++R.GAS;
return $ret4606946070;
};
var $Hanf_arg852446074 = function(anf_arg70746073,anf_arg70418041,_plus55) {
var $z4607746078 = D;
var $f4608346084 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg70418041,anf_arg70746073):R.ffi.throwNonFunApp(L[3193],_plus55,[anf_arg70418041,anf_arg70746073]);
};
try {
if(--R.GAS > 0) {
$z4607746078 = $f4608346084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4608346084,
"from":L[3193]});
}
} catch($e4607546076) {
if(R.isCont($e4607546076)) {
var $ss4607946080 = {"from":L[3193],
"go":function(anf_arg70846085) {
return $Hanf_arg852346086(anf_arg70846085,_plus55);
}};
$e4607546076.stack[R.EXN_STACKHEIGHT++] = $ss4607946080;
}
if(R.isPyretException($e4607546076)) {
$e4607546076.pyretStack.push(L[3193]);
}
throw $e4607546076;
}
var $ret4608146082 = $Hanf_arg852346086($z4607746078,_plus55);
++R.GAS;
return $ret4608146082;
};
var $Hanf_arg852346086 = function(anf_arg70846085,_plus55) {
var $z4608946090 = D;
var $f4609546096 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg70846085,(")")):R.ffi.throwNonFunApp(L[3193],_plus55,[anf_arg70846085,(")")]);
};
try {
if(--R.GAS > 0) {
$z4608946090 = $f4609546096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4609546096,
"from":L[3193]});
}
} catch($e4608746088) {
if(R.isCont($e4608746088)) {
var $ss4609146092 = {"from":L[3193],
"go":function(anf_arg70946097) {
return $Hanf_arg852246098(anf_arg70946097,_plus55);
}};
$e4608746088.stack[R.EXN_STACKHEIGHT++] = $ss4609146092;
}
if(R.isPyretException($e4608746088)) {
$e4608746088.pyretStack.push(L[3193]);
}
throw $e4608746088;
}
var $ret4609346094 = $Hanf_arg852246098($z4608946090,_plus55);
++R.GAS;
return $ret4609346094;
};
var $Hanf_arg852246098 = function(anf_arg70946097,_plus55) {
var $z4610146102 = D;
var $f4610746108 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg70946097):R.ffi.throwNonFunApp(L[3193],_plus55,[("("),anf_arg70946097]);
};
try {
if(--R.GAS > 0) {
$z4610146102 = $f4610746108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4610746108,
"from":L[3193]});
}
} catch($e4609946100) {
if(R.isCont($e4609946100)) {
var $ss4610346104 = {"from":L[3193],
"go":function(anf_arg71046109) {
return $Hanf_arg852146110(anf_arg71046109,_plus55);
}};
$e4609946100.stack[R.EXN_STACKHEIGHT++] = $ss4610346104;
}
if(R.isPyretException($e4609946100)) {
$e4609946100.pyretStack.push(L[3193]);
}
throw $e4609946100;
}
var $ret4610546106 = $Hanf_arg852146110($z4610146102,_plus55);
++R.GAS;
return $ret4610546106;
};
var $Hanf_arg852146110 = function(anf_arg71046109,_plus55) {
var $z4611346114 = D;
var $f4611946120 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-provide"),anf_arg71046109):R.ffi.throwNonFunApp(L[3193],_plus55,[("s-provide"),anf_arg71046109]);
};
try {
if(--R.GAS > 0) {
$z4611346114 = $f4611946120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4611946120,
"from":L[3193]});
}
} catch($e4611146112) {
if(R.isCont($e4611146112)) {
var $ss4611546116 = {"from":L[3193],
"go":function(ann_DASH_check_DASH_temp70246121) {
return $Hann_DASH_check_DASH_temp852046122(ann_DASH_check_DASH_temp70246121);
}};
$e4611146112.stack[R.EXN_STACKHEIGHT++] = $ss4611546116;
}
if(R.isPyretException($e4611146112)) {
$e4611146112.pyretStack.push(L[3193]);
}
throw $e4611146112;
}
var $ret4611746118 = $Hann_DASH_check_DASH_temp852046122($z4611346114);
++R.GAS;
return $ret4611746118;
};
var $Hann_DASH_check_DASH_temp852046122 = function(ann_DASH_check_DASH_temp70246121) {
return ann_DASH_check_DASH_temp70246121;
};
var $Hcont_tail_arg851818059 = function(cont_tail_arg69918057,if_helper69018058) {
if(--R.GAS > 0) {
$z4612346124 = R.isFunction(if_helper69018058)?if_helper69018058.app(cont_tail_arg69918057):R.ffi.throwNonFunApp(L[3193],if_helper69018058,[cont_tail_arg69918057]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper69018058)?if_helper69018058.app(cont_tail_arg69918057):R.ffi.throwNonFunApp(L[3193],if_helper69018058,[cont_tail_arg69918057]);
},
"from":L[3193]});
}
++R.GAS;
return $z4612346124;
};
var $Hcont_tail_arg851918074 = function(cont_tail_arg69518073,if_helper69018058) {
if(--R.GAS > 0) {
$z4612546126 = R.isFunction(if_helper69018058)?if_helper69018058.app(cont_tail_arg69518073):R.ffi.throwNonFunApp(L[3193],if_helper69018058,[cont_tail_arg69518073]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper69018058)?if_helper69018058.app(cont_tail_arg69518073):R.ffi.throwNonFunApp(L[3193],if_helper69018058,[cont_tail_arg69518073]);
},
"from":L[3193]});
}
++R.GAS;
return $z4612546126;
};
var $Hann_DASH_check_DASH_temp851718096 = function(ann_DASH_check_DASH_temp68118095) {
return ann_DASH_check_DASH_temp68118095;
};
var $Hanf_arg851618109 = function(anf_arg68518108,_plus55,raise62) {
var $z4612946130 = D;
var $f4613546136 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg68518108):R.ffi.throwNonFunApp(L[4785],_plus55,[("No visitor field for "),anf_arg68518108]);
};
try {
if(--R.GAS > 0) {
$z4612946130 = $f4613546136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4613546136,
"from":L[4785]});
}
} catch($e4612746128) {
if(R.isCont($e4612746128)) {
var $ss4613146132 = {"from":L[4785],
"go":function(anf_arg68646137) {
return $Hanf_arg851546138(anf_arg68646137,raise62);
}};
$e4612746128.stack[R.EXN_STACKHEIGHT++] = $ss4613146132;
}
if(R.isPyretException($e4612746128)) {
$e4612746128.pyretStack.push(L[4785]);
}
throw $e4612746128;
}
var $ret4613346134 = $Hanf_arg851546138($z4612946130,raise62);
++R.GAS;
return $ret4613346134;
};
var $Hanf_arg851546138 = function(anf_arg68646137,raise62) {
var $z4614146142 = D;
var $f4614746148 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg68646137):R.ffi.throwNonFunApp(L[3218],raise62,[anf_arg68646137]);
};
try {
if(--R.GAS > 0) {
$z4614146142 = $f4614746148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4614746148,
"from":L[3218]});
}
} catch($e4613946140) {
if(R.isCont($e4613946140)) {
var $ss4614346144 = {"from":L[3218],
"go":function(ann_DASH_check_DASH_temp68346149) {
return $Hann_DASH_check_DASH_temp851446150(ann_DASH_check_DASH_temp68346149);
}};
$e4613946140.stack[R.EXN_STACKHEIGHT++] = $ss4614346144;
}
if(R.isPyretException($e4613946140)) {
$e4613946140.pyretStack.push(L[3218]);
}
throw $e4613946140;
}
var $ret4614546146 = $Hann_DASH_check_DASH_temp851446150($z4614146142);
++R.GAS;
return $ret4614546146;
};
var $Hann_DASH_check_DASH_temp851446150 = function(ann_DASH_check_DASH_temp68346149) {
return ann_DASH_check_DASH_temp68346149;
};
var $Hanf_array_val851318167 = function(anf_array_val66618163,anf_fun65818164,anf_fun65918165,self57918166,str_DASH_from151585,str_DASH_import157663) {
var anf_bracket66746164 = G(self57918166,"file",L[4788]);
var anf_fun66846161 = G(anf_bracket66746164,"tosource",L[4787]);
var $z4615346154 = D;
var $f4615946160 = function(_) {
return R.isFunction(anf_fun66846161)?anf_fun66846161.app():R.ffi.throwNonFunApp(L[4786],anf_fun66846161,[]);
};
try {
if(--R.GAS > 0) {
$z4615346154 = $f4615946160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4615946160,
"from":L[4786]});
}
} catch($e4615146152) {
if(R.isCont($e4615146152)) {
var $ss4615546156 = {"from":L[4786],
"go":function(anf_array_val66946162) {
return $Hanf_array_val851246163(anf_array_val66946162,anf_array_val66618163,anf_fun65818164,anf_fun65918165,str_DASH_from151585,str_DASH_import157663);
}};
$e4615146152.stack[R.EXN_STACKHEIGHT++] = $ss4615546156;
}
if(R.isPyretException($e4615146152)) {
$e4615146152.pyretStack.push(L[4786]);
}
throw $e4615146152;
}
var $ret4615746158 = $Hanf_array_val851246163($z4615346154,anf_array_val66618163,anf_fun65818164,anf_fun65918165,str_DASH_from151585,str_DASH_import157663);
++R.GAS;
return $ret4615746158;
};
var $Hanf_array_val851246163 = function(anf_array_val66946162,anf_array_val66618163,anf_fun65818164,anf_fun65918165,str_DASH_from151585,str_DASH_import157663) {
var $z4616746168 = D;
var $f4617346174 = function(_) {
return R.isFunction(anf_fun65918165)?anf_fun65918165.app([str_DASH_import157663,anf_array_val66618163,str_DASH_from151585,anf_array_val66946162]):R.ffi.throwNonFunApp(L[3244],anf_fun65918165,[[str_DASH_import157663,anf_array_val66618163,str_DASH_from151585,anf_array_val66946162]]);
};
try {
if(--R.GAS > 0) {
$z4616746168 = $f4617346174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4617346174,
"from":L[3244]});
}
} catch($e4616546166) {
if(R.isCont($e4616546166)) {
var $ss4616946170 = {"from":L[3244],
"go":function(anf_arg67046175) {
return $Hanf_arg851146176(anf_arg67046175,anf_fun65818164);
}};
$e4616546166.stack[R.EXN_STACKHEIGHT++] = $ss4616946170;
}
if(R.isPyretException($e4616546166)) {
$e4616546166.pyretStack.push(L[3244]);
}
throw $e4616546166;
}
var $ret4617146172 = $Hanf_arg851146176($z4616746168,anf_fun65818164);
++R.GAS;
return $ret4617146172;
};
var $Hanf_arg851146176 = function(anf_arg67046175,anf_fun65818164) {
var $z4617946180 = D;
var $f4618546186 = function(_) {
return R.isFunction(anf_fun65818164)?anf_fun65818164.app(anf_arg67046175):R.ffi.throwNonFunApp(L[3246],anf_fun65818164,[anf_arg67046175]);
};
try {
if(--R.GAS > 0) {
$z4617946180 = $f4618546186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4618546186,
"from":L[3246]});
}
} catch($e4617746178) {
if(R.isCont($e4617746178)) {
var $ss4618146182 = {"from":L[3246],
"go":function(ann_DASH_check_DASH_temp65746187) {
return $Hann_DASH_check_DASH_temp851046188(ann_DASH_check_DASH_temp65746187);
}};
$e4617746178.stack[R.EXN_STACKHEIGHT++] = $ss4618146182;
}
if(R.isPyretException($e4617746178)) {
$e4617746178.pyretStack.push(L[3246]);
}
throw $e4617746178;
}
var $ret4618346184 = $Hann_DASH_check_DASH_temp851046188($z4617946180);
++R.GAS;
return $ret4618346184;
};
var $Hann_DASH_check_DASH_temp851046188 = function(ann_DASH_check_DASH_temp65746187) {
return ann_DASH_check_DASH_temp65746187;
};
var $Hann_DASH_check_DASH_temp850918181 = function(ann_DASH_check_DASH_temp66218180) {
return ann_DASH_check_DASH_temp66218180;
};
var $Hanf_arg850818196 = function(anf_arg64318194,self6718195,_plus55,torepr65) {
var anf_arg64446199 = G(self6718195,"fields",L[3222]);
var $z4619146192 = D;
var $f4619746198 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg64446199):R.ffi.throwNonFunApp(L[3222],torepr65,[anf_arg64446199]);
};
try {
if(--R.GAS > 0) {
$z4619146192 = $f4619746198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4619746198,
"from":L[3222]});
}
} catch($e4618946190) {
if(R.isCont($e4618946190)) {
var $ss4619346194 = {"from":L[3222],
"go":function(anf_arg64546200) {
return $Hanf_arg850746201(anf_arg64546200,anf_arg64318194,self6718195,_plus55,torepr65);
}};
$e4618946190.stack[R.EXN_STACKHEIGHT++] = $ss4619346194;
}
if(R.isPyretException($e4618946190)) {
$e4618946190.pyretStack.push(L[3222]);
}
throw $e4618946190;
}
var $ret4619546196 = $Hanf_arg850746201($z4619146192,anf_arg64318194,self6718195,_plus55,torepr65);
++R.GAS;
return $ret4619546196;
};
var $Hanf_arg850746201 = function(anf_arg64546200,anf_arg64318194,self6718195,_plus55,torepr65) {
var $z4620446205 = D;
var $f4621046211 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg64546200):R.ffi.throwNonFunApp(L[3222],_plus55,[(", "),anf_arg64546200]);
};
try {
if(--R.GAS > 0) {
$z4620446205 = $f4621046211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4621046211,
"from":L[3222]});
}
} catch($e4620246203) {
if(R.isCont($e4620246203)) {
var $ss4620646207 = {"from":L[3222],
"go":function(anf_arg64646212) {
return $Hanf_arg850646213(anf_arg64646212,anf_arg64318194,self6718195,_plus55,torepr65);
}};
$e4620246203.stack[R.EXN_STACKHEIGHT++] = $ss4620646207;
}
if(R.isPyretException($e4620246203)) {
$e4620246203.pyretStack.push(L[3222]);
}
throw $e4620246203;
}
var $ret4620846209 = $Hanf_arg850646213($z4620446205,anf_arg64318194,self6718195,_plus55,torepr65);
++R.GAS;
return $ret4620846209;
};
var $Hanf_arg850646213 = function(anf_arg64646212,anf_arg64318194,self6718195,_plus55,torepr65) {
var $z4621646217 = D;
var $f4622246223 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg64318194,anf_arg64646212):R.ffi.throwNonFunApp(L[3222],_plus55,[anf_arg64318194,anf_arg64646212]);
};
try {
if(--R.GAS > 0) {
$z4621646217 = $f4622246223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4622246223,
"from":L[3222]});
}
} catch($e4621446215) {
if(R.isCont($e4621446215)) {
var $ss4621846219 = {"from":L[3222],
"go":function(anf_arg64746224) {
return $Hanf_arg850546225(anf_arg64746224,self6718195,_plus55,torepr65);
}};
$e4621446215.stack[R.EXN_STACKHEIGHT++] = $ss4621846219;
}
if(R.isPyretException($e4621446215)) {
$e4621446215.pyretStack.push(L[3222]);
}
throw $e4621446215;
}
var $ret4622046221 = $Hanf_arg850546225($z4621646217,self6718195,_plus55,torepr65);
++R.GAS;
return $ret4622046221;
};
var $Hanf_arg850546225 = function(anf_arg64746224,self6718195,_plus55,torepr65) {
var anf_arg64846236 = G(self6718195,"file",L[3222]);
var $z4622846229 = D;
var $f4623446235 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg64846236):R.ffi.throwNonFunApp(L[3222],torepr65,[anf_arg64846236]);
};
try {
if(--R.GAS > 0) {
$z4622846229 = $f4623446235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4623446235,
"from":L[3222]});
}
} catch($e4622646227) {
if(R.isCont($e4622646227)) {
var $ss4623046231 = {"from":L[3222],
"go":function(anf_arg64946237) {
return $Hanf_arg850446238(anf_arg64946237,anf_arg64746224,_plus55);
}};
$e4622646227.stack[R.EXN_STACKHEIGHT++] = $ss4623046231;
}
if(R.isPyretException($e4622646227)) {
$e4622646227.pyretStack.push(L[3222]);
}
throw $e4622646227;
}
var $ret4623246233 = $Hanf_arg850446238($z4622846229,anf_arg64746224,_plus55);
++R.GAS;
return $ret4623246233;
};
var $Hanf_arg850446238 = function(anf_arg64946237,anf_arg64746224,_plus55) {
var $z4624146242 = D;
var $f4624746248 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg64946237):R.ffi.throwNonFunApp(L[3222],_plus55,[(", "),anf_arg64946237]);
};
try {
if(--R.GAS > 0) {
$z4624146242 = $f4624746248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4624746248,
"from":L[3222]});
}
} catch($e4623946240) {
if(R.isCont($e4623946240)) {
var $ss4624346244 = {"from":L[3222],
"go":function(anf_arg65046249) {
return $Hanf_arg850346250(anf_arg65046249,anf_arg64746224,_plus55);
}};
$e4623946240.stack[R.EXN_STACKHEIGHT++] = $ss4624346244;
}
if(R.isPyretException($e4623946240)) {
$e4623946240.pyretStack.push(L[3222]);
}
throw $e4623946240;
}
var $ret4624546246 = $Hanf_arg850346250($z4624146242,anf_arg64746224,_plus55);
++R.GAS;
return $ret4624546246;
};
var $Hanf_arg850346250 = function(anf_arg65046249,anf_arg64746224,_plus55) {
var $z4625346254 = D;
var $f4625946260 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg64746224,anf_arg65046249):R.ffi.throwNonFunApp(L[3222],_plus55,[anf_arg64746224,anf_arg65046249]);
};
try {
if(--R.GAS > 0) {
$z4625346254 = $f4625946260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4625946260,
"from":L[3222]});
}
} catch($e4625146252) {
if(R.isCont($e4625146252)) {
var $ss4625546256 = {"from":L[3222],
"go":function(anf_arg65146261) {
return $Hanf_arg850246262(anf_arg65146261,_plus55);
}};
$e4625146252.stack[R.EXN_STACKHEIGHT++] = $ss4625546256;
}
if(R.isPyretException($e4625146252)) {
$e4625146252.pyretStack.push(L[3222]);
}
throw $e4625146252;
}
var $ret4625746258 = $Hanf_arg850246262($z4625346254,_plus55);
++R.GAS;
return $ret4625746258;
};
var $Hanf_arg850246262 = function(anf_arg65146261,_plus55) {
var $z4626546266 = D;
var $f4627146272 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg65146261,(")")):R.ffi.throwNonFunApp(L[3222],_plus55,[anf_arg65146261,(")")]);
};
try {
if(--R.GAS > 0) {
$z4626546266 = $f4627146272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4627146272,
"from":L[3222]});
}
} catch($e4626346264) {
if(R.isCont($e4626346264)) {
var $ss4626746268 = {"from":L[3222],
"go":function(anf_arg65246273) {
return $Hanf_arg850146274(anf_arg65246273,_plus55);
}};
$e4626346264.stack[R.EXN_STACKHEIGHT++] = $ss4626746268;
}
if(R.isPyretException($e4626346264)) {
$e4626346264.pyretStack.push(L[3222]);
}
throw $e4626346264;
}
var $ret4626946270 = $Hanf_arg850146274($z4626546266,_plus55);
++R.GAS;
return $ret4626946270;
};
var $Hanf_arg850146274 = function(anf_arg65246273,_plus55) {
var $z4627746278 = D;
var $f4628346284 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg65246273):R.ffi.throwNonFunApp(L[3222],_plus55,[("("),anf_arg65246273]);
};
try {
if(--R.GAS > 0) {
$z4627746278 = $f4628346284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4628346284,
"from":L[3222]});
}
} catch($e4627546276) {
if(R.isCont($e4627546276)) {
var $ss4627946280 = {"from":L[3222],
"go":function(anf_arg65346285) {
return $Hanf_arg850046286(anf_arg65346285,_plus55);
}};
$e4627546276.stack[R.EXN_STACKHEIGHT++] = $ss4627946280;
}
if(R.isPyretException($e4627546276)) {
$e4627546276.pyretStack.push(L[3222]);
}
throw $e4627546276;
}
var $ret4628146282 = $Hanf_arg850046286($z4627746278,_plus55);
++R.GAS;
return $ret4628146282;
};
var $Hanf_arg850046286 = function(anf_arg65346285,_plus55) {
var $z4628946290 = D;
var $f4629546296 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-import-fields"),anf_arg65346285):R.ffi.throwNonFunApp(L[3222],_plus55,[("s-import-fields"),anf_arg65346285]);
};
try {
if(--R.GAS > 0) {
$z4628946290 = $f4629546296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4629546296,
"from":L[3222]});
}
} catch($e4628746288) {
if(R.isCont($e4628746288)) {
var $ss4629146292 = {"from":L[3222],
"go":function(ann_DASH_check_DASH_temp64146297) {
return $Hann_DASH_check_DASH_temp849946298(ann_DASH_check_DASH_temp64146297);
}};
$e4628746288.stack[R.EXN_STACKHEIGHT++] = $ss4629146292;
}
if(R.isPyretException($e4628746288)) {
$e4628746288.pyretStack.push(L[3222]);
}
throw $e4628746288;
}
var $ret4629346294 = $Hann_DASH_check_DASH_temp849946298($z4628946290);
++R.GAS;
return $ret4629346294;
};
var $Hann_DASH_check_DASH_temp849946298 = function(ann_DASH_check_DASH_temp64146297) {
return ann_DASH_check_DASH_temp64146297;
};
var $Hcont_tail_arg849718213 = function(cont_tail_arg63818211,if_helper62818212) {
if(--R.GAS > 0) {
$z4629946300 = R.isFunction(if_helper62818212)?if_helper62818212.app(cont_tail_arg63818211):R.ffi.throwNonFunApp(L[3222],if_helper62818212,[cont_tail_arg63818211]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper62818212)?if_helper62818212.app(cont_tail_arg63818211):R.ffi.throwNonFunApp(L[3222],if_helper62818212,[cont_tail_arg63818211]);
},
"from":L[3222]});
}
++R.GAS;
return $z4629946300;
};
var $Hcont_tail_arg849818228 = function(cont_tail_arg63318227,if_helper62818212) {
if(--R.GAS > 0) {
$z4630146302 = R.isFunction(if_helper62818212)?if_helper62818212.app(cont_tail_arg63318227):R.ffi.throwNonFunApp(L[3222],if_helper62818212,[cont_tail_arg63318227]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper62818212)?if_helper62818212.app(cont_tail_arg63318227):R.ffi.throwNonFunApp(L[3222],if_helper62818212,[cont_tail_arg63318227]);
},
"from":L[3222]});
}
++R.GAS;
return $z4630146302;
};
var $Hanf_array_val849618251 = function(anf_array_val61718247,PP170,anf_fun61318248,anf_fun61418249,self57418250,str_DASH_as123221,str_DASH_import157663) {
var anf_bracket61846316 = G(self57418250,"name",L[4791]);
var anf_fun61946313 = G(anf_bracket61846316,"tosource",L[4790]);
var $z4630546306 = D;
var $f4631146312 = function(_) {
return R.isFunction(anf_fun61946313)?anf_fun61946313.app():R.ffi.throwNonFunApp(L[4789],anf_fun61946313,[]);
};
try {
if(--R.GAS > 0) {
$z4630546306 = $f4631146312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4631146312,
"from":L[4789]});
}
} catch($e4630346304) {
if(R.isCont($e4630346304)) {
var $ss4630746308 = {"from":L[4789],
"go":function(anf_array_val62046314) {
return $Hanf_array_val849546315(anf_array_val62046314,PP170,anf_array_val61718247,anf_fun61318248,anf_fun61418249,self57418250,str_DASH_as123221,str_DASH_import157663);
}};
$e4630346304.stack[R.EXN_STACKHEIGHT++] = $ss4630746308;
}
if(R.isPyretException($e4630346304)) {
$e4630346304.pyretStack.push(L[4789]);
}
throw $e4630346304;
}
var $ret4630946310 = $Hanf_array_val849546315($z4630546306,PP170,anf_array_val61718247,anf_fun61318248,anf_fun61418249,self57418250,str_DASH_as123221,str_DASH_import157663);
++R.GAS;
return $ret4630946310;
};
var $Hanf_array_val849546315 = function(anf_array_val62046314,PP170,anf_array_val61718247,anf_fun61318248,anf_fun61418249,self57418250,str_DASH_as123221,str_DASH_import157663) {
var anf_array_val62146329 = G(PP170,"comma",L[4795]);
var anf_bracket62246331 = G(self57418250,"types",L[4794]);
var anf_fun62346327 = G(anf_bracket62246331,"tosource",L[4793]);
var $z4631946320 = D;
var $f4632546326 = function(_) {
return R.isFunction(anf_fun62346327)?anf_fun62346327.app():R.ffi.throwNonFunApp(L[4792],anf_fun62346327,[]);
};
try {
if(--R.GAS > 0) {
$z4631946320 = $f4632546326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4632546326,
"from":L[4792]});
}
} catch($e4631746318) {
if(R.isCont($e4631746318)) {
var $ss4632146322 = {"from":L[4792],
"go":function(anf_array_val62446328) {
return $Hanf_array_val849446330(anf_array_val62446328,anf_array_val61718247,anf_array_val62046314,anf_array_val62146329,anf_fun61318248,anf_fun61418249,str_DASH_as123221,str_DASH_import157663);
}};
$e4631746318.stack[R.EXN_STACKHEIGHT++] = $ss4632146322;
}
if(R.isPyretException($e4631746318)) {
$e4631746318.pyretStack.push(L[4792]);
}
throw $e4631746318;
}
var $ret4632346324 = $Hanf_array_val849446330($z4631946320,anf_array_val61718247,anf_array_val62046314,anf_array_val62146329,anf_fun61318248,anf_fun61418249,str_DASH_as123221,str_DASH_import157663);
++R.GAS;
return $ret4632346324;
};
var $Hanf_array_val849446330 = function(anf_array_val62446328,anf_array_val61718247,anf_array_val62046314,anf_array_val62146329,anf_fun61318248,anf_fun61418249,str_DASH_as123221,str_DASH_import157663) {
var $z4633446335 = D;
var $f4634046341 = function(_) {
return R.isFunction(anf_fun61418249)?anf_fun61418249.app([str_DASH_import157663,anf_array_val61718247,str_DASH_as123221,anf_array_val62046314,anf_array_val62146329,anf_array_val62446328]):R.ffi.throwNonFunApp(L[3254],anf_fun61418249,[[str_DASH_import157663,anf_array_val61718247,str_DASH_as123221,anf_array_val62046314,anf_array_val62146329,anf_array_val62446328]]);
};
try {
if(--R.GAS > 0) {
$z4633446335 = $f4634046341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4634046341,
"from":L[3254]});
}
} catch($e4633246333) {
if(R.isCont($e4633246333)) {
var $ss4633646337 = {"from":L[3254],
"go":function(anf_arg62546342) {
return $Hanf_arg849346343(anf_arg62546342,anf_fun61318248);
}};
$e4633246333.stack[R.EXN_STACKHEIGHT++] = $ss4633646337;
}
if(R.isPyretException($e4633246333)) {
$e4633246333.pyretStack.push(L[3254]);
}
throw $e4633246333;
}
var $ret4633846339 = $Hanf_arg849346343($z4633446335,anf_fun61318248);
++R.GAS;
return $ret4633846339;
};
var $Hanf_arg849346343 = function(anf_arg62546342,anf_fun61318248) {
var $z4634646347 = D;
var $f4635246353 = function(_) {
return R.isFunction(anf_fun61318248)?anf_fun61318248.app(anf_arg62546342):R.ffi.throwNonFunApp(L[3256],anf_fun61318248,[anf_arg62546342]);
};
try {
if(--R.GAS > 0) {
$z4634646347 = $f4635246353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4635246353,
"from":L[3256]});
}
} catch($e4634446345) {
if(R.isCont($e4634446345)) {
var $ss4634846349 = {"from":L[3256],
"go":function(ann_DASH_check_DASH_temp61246354) {
return $Hann_DASH_check_DASH_temp849246355(ann_DASH_check_DASH_temp61246354);
}};
$e4634446345.stack[R.EXN_STACKHEIGHT++] = $ss4634846349;
}
if(R.isPyretException($e4634446345)) {
$e4634446345.pyretStack.push(L[3256]);
}
throw $e4634446345;
}
var $ret4635046351 = $Hann_DASH_check_DASH_temp849246355($z4634646347);
++R.GAS;
return $ret4635046351;
};
var $Hann_DASH_check_DASH_temp849246355 = function(ann_DASH_check_DASH_temp61246354) {
return ann_DASH_check_DASH_temp61246354;
};
var $Hanf_arg849118268 = function(anf_arg59418266,self6118267,_plus55,torepr65) {
var anf_arg59546366 = G(self6118267,"file",L[3223]);
var $z4635846359 = D;
var $f4636446365 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg59546366):R.ffi.throwNonFunApp(L[3223],torepr65,[anf_arg59546366]);
};
try {
if(--R.GAS > 0) {
$z4635846359 = $f4636446365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4636446365,
"from":L[3223]});
}
} catch($e4635646357) {
if(R.isCont($e4635646357)) {
var $ss4636046361 = {"from":L[3223],
"go":function(anf_arg59646367) {
return $Hanf_arg849046368(anf_arg59646367,anf_arg59418266,self6118267,_plus55,torepr65);
}};
$e4635646357.stack[R.EXN_STACKHEIGHT++] = $ss4636046361;
}
if(R.isPyretException($e4635646357)) {
$e4635646357.pyretStack.push(L[3223]);
}
throw $e4635646357;
}
var $ret4636246363 = $Hanf_arg849046368($z4635846359,anf_arg59418266,self6118267,_plus55,torepr65);
++R.GAS;
return $ret4636246363;
};
var $Hanf_arg849046368 = function(anf_arg59646367,anf_arg59418266,self6118267,_plus55,torepr65) {
var $z4637146372 = D;
var $f4637746378 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg59646367):R.ffi.throwNonFunApp(L[3223],_plus55,[(", "),anf_arg59646367]);
};
try {
if(--R.GAS > 0) {
$z4637146372 = $f4637746378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4637746378,
"from":L[3223]});
}
} catch($e4636946370) {
if(R.isCont($e4636946370)) {
var $ss4637346374 = {"from":L[3223],
"go":function(anf_arg59746379) {
return $Hanf_arg848946380(anf_arg59746379,anf_arg59418266,self6118267,_plus55,torepr65);
}};
$e4636946370.stack[R.EXN_STACKHEIGHT++] = $ss4637346374;
}
if(R.isPyretException($e4636946370)) {
$e4636946370.pyretStack.push(L[3223]);
}
throw $e4636946370;
}
var $ret4637546376 = $Hanf_arg848946380($z4637146372,anf_arg59418266,self6118267,_plus55,torepr65);
++R.GAS;
return $ret4637546376;
};
var $Hanf_arg848946380 = function(anf_arg59746379,anf_arg59418266,self6118267,_plus55,torepr65) {
var $z4638346384 = D;
var $f4638946390 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg59418266,anf_arg59746379):R.ffi.throwNonFunApp(L[3223],_plus55,[anf_arg59418266,anf_arg59746379]);
};
try {
if(--R.GAS > 0) {
$z4638346384 = $f4638946390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4638946390,
"from":L[3223]});
}
} catch($e4638146382) {
if(R.isCont($e4638146382)) {
var $ss4638546386 = {"from":L[3223],
"go":function(anf_arg59846391) {
return $Hanf_arg848846392(anf_arg59846391,self6118267,_plus55,torepr65);
}};
$e4638146382.stack[R.EXN_STACKHEIGHT++] = $ss4638546386;
}
if(R.isPyretException($e4638146382)) {
$e4638146382.pyretStack.push(L[3223]);
}
throw $e4638146382;
}
var $ret4638746388 = $Hanf_arg848846392($z4638346384,self6118267,_plus55,torepr65);
++R.GAS;
return $ret4638746388;
};
var $Hanf_arg848846392 = function(anf_arg59846391,self6118267,_plus55,torepr65) {
var anf_arg59946403 = G(self6118267,"name",L[3223]);
var $z4639546396 = D;
var $f4640146402 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg59946403):R.ffi.throwNonFunApp(L[3223],torepr65,[anf_arg59946403]);
};
try {
if(--R.GAS > 0) {
$z4639546396 = $f4640146402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4640146402,
"from":L[3223]});
}
} catch($e4639346394) {
if(R.isCont($e4639346394)) {
var $ss4639746398 = {"from":L[3223],
"go":function(anf_arg60046404) {
return $Hanf_arg848746405(anf_arg60046404,anf_arg59846391,self6118267,_plus55,torepr65);
}};
$e4639346394.stack[R.EXN_STACKHEIGHT++] = $ss4639746398;
}
if(R.isPyretException($e4639346394)) {
$e4639346394.pyretStack.push(L[3223]);
}
throw $e4639346394;
}
var $ret4639946400 = $Hanf_arg848746405($z4639546396,anf_arg59846391,self6118267,_plus55,torepr65);
++R.GAS;
return $ret4639946400;
};
var $Hanf_arg848746405 = function(anf_arg60046404,anf_arg59846391,self6118267,_plus55,torepr65) {
var $z4640846409 = D;
var $f4641446415 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg60046404):R.ffi.throwNonFunApp(L[3223],_plus55,[(", "),anf_arg60046404]);
};
try {
if(--R.GAS > 0) {
$z4640846409 = $f4641446415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4641446415,
"from":L[3223]});
}
} catch($e4640646407) {
if(R.isCont($e4640646407)) {
var $ss4641046411 = {"from":L[3223],
"go":function(anf_arg60146416) {
return $Hanf_arg848646417(anf_arg60146416,anf_arg59846391,self6118267,_plus55,torepr65);
}};
$e4640646407.stack[R.EXN_STACKHEIGHT++] = $ss4641046411;
}
if(R.isPyretException($e4640646407)) {
$e4640646407.pyretStack.push(L[3223]);
}
throw $e4640646407;
}
var $ret4641246413 = $Hanf_arg848646417($z4640846409,anf_arg59846391,self6118267,_plus55,torepr65);
++R.GAS;
return $ret4641246413;
};
var $Hanf_arg848646417 = function(anf_arg60146416,anf_arg59846391,self6118267,_plus55,torepr65) {
var $z4642046421 = D;
var $f4642646427 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg59846391,anf_arg60146416):R.ffi.throwNonFunApp(L[3223],_plus55,[anf_arg59846391,anf_arg60146416]);
};
try {
if(--R.GAS > 0) {
$z4642046421 = $f4642646427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4642646427,
"from":L[3223]});
}
} catch($e4641846419) {
if(R.isCont($e4641846419)) {
var $ss4642246423 = {"from":L[3223],
"go":function(anf_arg60246428) {
return $Hanf_arg848546429(anf_arg60246428,self6118267,_plus55,torepr65);
}};
$e4641846419.stack[R.EXN_STACKHEIGHT++] = $ss4642246423;
}
if(R.isPyretException($e4641846419)) {
$e4641846419.pyretStack.push(L[3223]);
}
throw $e4641846419;
}
var $ret4642446425 = $Hanf_arg848546429($z4642046421,self6118267,_plus55,torepr65);
++R.GAS;
return $ret4642446425;
};
var $Hanf_arg848546429 = function(anf_arg60246428,self6118267,_plus55,torepr65) {
var anf_arg60346440 = G(self6118267,"types",L[3223]);
var $z4643246433 = D;
var $f4643846439 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg60346440):R.ffi.throwNonFunApp(L[3223],torepr65,[anf_arg60346440]);
};
try {
if(--R.GAS > 0) {
$z4643246433 = $f4643846439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4643846439,
"from":L[3223]});
}
} catch($e4643046431) {
if(R.isCont($e4643046431)) {
var $ss4643446435 = {"from":L[3223],
"go":function(anf_arg60446441) {
return $Hanf_arg848446442(anf_arg60446441,anf_arg60246428,_plus55);
}};
$e4643046431.stack[R.EXN_STACKHEIGHT++] = $ss4643446435;
}
if(R.isPyretException($e4643046431)) {
$e4643046431.pyretStack.push(L[3223]);
}
throw $e4643046431;
}
var $ret4643646437 = $Hanf_arg848446442($z4643246433,anf_arg60246428,_plus55);
++R.GAS;
return $ret4643646437;
};
var $Hanf_arg848446442 = function(anf_arg60446441,anf_arg60246428,_plus55) {
var $z4644546446 = D;
var $f4645146452 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg60446441):R.ffi.throwNonFunApp(L[3223],_plus55,[(", "),anf_arg60446441]);
};
try {
if(--R.GAS > 0) {
$z4644546446 = $f4645146452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4645146452,
"from":L[3223]});
}
} catch($e4644346444) {
if(R.isCont($e4644346444)) {
var $ss4644746448 = {"from":L[3223],
"go":function(anf_arg60546453) {
return $Hanf_arg848346454(anf_arg60546453,anf_arg60246428,_plus55);
}};
$e4644346444.stack[R.EXN_STACKHEIGHT++] = $ss4644746448;
}
if(R.isPyretException($e4644346444)) {
$e4644346444.pyretStack.push(L[3223]);
}
throw $e4644346444;
}
var $ret4644946450 = $Hanf_arg848346454($z4644546446,anf_arg60246428,_plus55);
++R.GAS;
return $ret4644946450;
};
var $Hanf_arg848346454 = function(anf_arg60546453,anf_arg60246428,_plus55) {
var $z4645746458 = D;
var $f4646346464 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg60246428,anf_arg60546453):R.ffi.throwNonFunApp(L[3223],_plus55,[anf_arg60246428,anf_arg60546453]);
};
try {
if(--R.GAS > 0) {
$z4645746458 = $f4646346464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4646346464,
"from":L[3223]});
}
} catch($e4645546456) {
if(R.isCont($e4645546456)) {
var $ss4645946460 = {"from":L[3223],
"go":function(anf_arg60646465) {
return $Hanf_arg848246466(anf_arg60646465,_plus55);
}};
$e4645546456.stack[R.EXN_STACKHEIGHT++] = $ss4645946460;
}
if(R.isPyretException($e4645546456)) {
$e4645546456.pyretStack.push(L[3223]);
}
throw $e4645546456;
}
var $ret4646146462 = $Hanf_arg848246466($z4645746458,_plus55);
++R.GAS;
return $ret4646146462;
};
var $Hanf_arg848246466 = function(anf_arg60646465,_plus55) {
var $z4646946470 = D;
var $f4647546476 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg60646465,(")")):R.ffi.throwNonFunApp(L[3223],_plus55,[anf_arg60646465,(")")]);
};
try {
if(--R.GAS > 0) {
$z4646946470 = $f4647546476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4647546476,
"from":L[3223]});
}
} catch($e4646746468) {
if(R.isCont($e4646746468)) {
var $ss4647146472 = {"from":L[3223],
"go":function(anf_arg60746477) {
return $Hanf_arg848146478(anf_arg60746477,_plus55);
}};
$e4646746468.stack[R.EXN_STACKHEIGHT++] = $ss4647146472;
}
if(R.isPyretException($e4646746468)) {
$e4646746468.pyretStack.push(L[3223]);
}
throw $e4646746468;
}
var $ret4647346474 = $Hanf_arg848146478($z4646946470,_plus55);
++R.GAS;
return $ret4647346474;
};
var $Hanf_arg848146478 = function(anf_arg60746477,_plus55) {
var $z4648146482 = D;
var $f4648746488 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg60746477):R.ffi.throwNonFunApp(L[3223],_plus55,[("("),anf_arg60746477]);
};
try {
if(--R.GAS > 0) {
$z4648146482 = $f4648746488();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4648746488,
"from":L[3223]});
}
} catch($e4647946480) {
if(R.isCont($e4647946480)) {
var $ss4648346484 = {"from":L[3223],
"go":function(anf_arg60846489) {
return $Hanf_arg848046490(anf_arg60846489,_plus55);
}};
$e4647946480.stack[R.EXN_STACKHEIGHT++] = $ss4648346484;
}
if(R.isPyretException($e4647946480)) {
$e4647946480.pyretStack.push(L[3223]);
}
throw $e4647946480;
}
var $ret4648546486 = $Hanf_arg848046490($z4648146482,_plus55);
++R.GAS;
return $ret4648546486;
};
var $Hanf_arg848046490 = function(anf_arg60846489,_plus55) {
var $z4649346494 = D;
var $f4649946500 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-import-types"),anf_arg60846489):R.ffi.throwNonFunApp(L[3223],_plus55,[("s-import-types"),anf_arg60846489]);
};
try {
if(--R.GAS > 0) {
$z4649346494 = $f4649946500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4649946500,
"from":L[3223]});
}
} catch($e4649146492) {
if(R.isCont($e4649146492)) {
var $ss4649546496 = {"from":L[3223],
"go":function(ann_DASH_check_DASH_temp59246501) {
return $Hann_DASH_check_DASH_temp847946502(ann_DASH_check_DASH_temp59246501);
}};
$e4649146492.stack[R.EXN_STACKHEIGHT++] = $ss4649546496;
}
if(R.isPyretException($e4649146492)) {
$e4649146492.pyretStack.push(L[3223]);
}
throw $e4649146492;
}
var $ret4649746498 = $Hann_DASH_check_DASH_temp847946502($z4649346494);
++R.GAS;
return $ret4649746498;
};
var $Hann_DASH_check_DASH_temp847946502 = function(ann_DASH_check_DASH_temp59246501) {
return ann_DASH_check_DASH_temp59246501;
};
var $Hcont_tail_arg847718286 = function(cont_tail_arg58918284,if_helper57818285) {
if(--R.GAS > 0) {
$z4650346504 = R.isFunction(if_helper57818285)?if_helper57818285.app(cont_tail_arg58918284):R.ffi.throwNonFunApp(L[3223],if_helper57818285,[cont_tail_arg58918284]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper57818285)?if_helper57818285.app(cont_tail_arg58918284):R.ffi.throwNonFunApp(L[3223],if_helper57818285,[cont_tail_arg58918284]);
},
"from":L[3223]});
}
++R.GAS;
return $z4650346504;
};
var $Hcont_tail_arg847818301 = function(cont_tail_arg58318300,if_helper57818285) {
if(--R.GAS > 0) {
$z4650546506 = R.isFunction(if_helper57818285)?if_helper57818285.app(cont_tail_arg58318300):R.ffi.throwNonFunApp(L[3223],if_helper57818285,[cont_tail_arg58318300]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper57818285)?if_helper57818285.app(cont_tail_arg58318300):R.ffi.throwNonFunApp(L[3223],if_helper57818285,[cont_tail_arg58318300]);
},
"from":L[3223]});
}
++R.GAS;
return $z4650546506;
};
var $Hanf_array_val847618324 = function(anf_array_val57118320,anf_fun56718321,anf_fun56818322,self56818323,str_DASH_as123221,str_DASH_import157663) {
var anf_bracket57246520 = G(self56818323,"name",L[4798]);
var anf_fun57346517 = G(anf_bracket57246520,"tosource",L[4797]);
var $z4650946510 = D;
var $f4651546516 = function(_) {
return R.isFunction(anf_fun57346517)?anf_fun57346517.app():R.ffi.throwNonFunApp(L[4796],anf_fun57346517,[]);
};
try {
if(--R.GAS > 0) {
$z4650946510 = $f4651546516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4651546516,
"from":L[4796]});
}
} catch($e4650746508) {
if(R.isCont($e4650746508)) {
var $ss4651146512 = {"from":L[4796],
"go":function(anf_array_val57446518) {
return $Hanf_array_val847546519(anf_array_val57446518,anf_array_val57118320,anf_fun56718321,anf_fun56818322,str_DASH_as123221,str_DASH_import157663);
}};
$e4650746508.stack[R.EXN_STACKHEIGHT++] = $ss4651146512;
}
if(R.isPyretException($e4650746508)) {
$e4650746508.pyretStack.push(L[4796]);
}
throw $e4650746508;
}
var $ret4651346514 = $Hanf_array_val847546519($z4650946510,anf_array_val57118320,anf_fun56718321,anf_fun56818322,str_DASH_as123221,str_DASH_import157663);
++R.GAS;
return $ret4651346514;
};
var $Hanf_array_val847546519 = function(anf_array_val57446518,anf_array_val57118320,anf_fun56718321,anf_fun56818322,str_DASH_as123221,str_DASH_import157663) {
var $z4652346524 = D;
var $f4652946530 = function(_) {
return R.isFunction(anf_fun56818322)?anf_fun56818322.app([str_DASH_import157663,anf_array_val57118320,str_DASH_as123221,anf_array_val57446518]):R.ffi.throwNonFunApp(L[3265],anf_fun56818322,[[str_DASH_import157663,anf_array_val57118320,str_DASH_as123221,anf_array_val57446518]]);
};
try {
if(--R.GAS > 0) {
$z4652346524 = $f4652946530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4652946530,
"from":L[3265]});
}
} catch($e4652146522) {
if(R.isCont($e4652146522)) {
var $ss4652546526 = {"from":L[3265],
"go":function(anf_arg57546531) {
return $Hanf_arg847446532(anf_arg57546531,anf_fun56718321);
}};
$e4652146522.stack[R.EXN_STACKHEIGHT++] = $ss4652546526;
}
if(R.isPyretException($e4652146522)) {
$e4652146522.pyretStack.push(L[3265]);
}
throw $e4652146522;
}
var $ret4652746528 = $Hanf_arg847446532($z4652346524,anf_fun56718321);
++R.GAS;
return $ret4652746528;
};
var $Hanf_arg847446532 = function(anf_arg57546531,anf_fun56718321) {
var $z4653546536 = D;
var $f4654146542 = function(_) {
return R.isFunction(anf_fun56718321)?anf_fun56718321.app(anf_arg57546531):R.ffi.throwNonFunApp(L[3267],anf_fun56718321,[anf_arg57546531]);
};
try {
if(--R.GAS > 0) {
$z4653546536 = $f4654146542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4654146542,
"from":L[3267]});
}
} catch($e4653346534) {
if(R.isCont($e4653346534)) {
var $ss4653746538 = {"from":L[3267],
"go":function(ann_DASH_check_DASH_temp56646543) {
return $Hann_DASH_check_DASH_temp847346544(ann_DASH_check_DASH_temp56646543);
}};
$e4653346534.stack[R.EXN_STACKHEIGHT++] = $ss4653746538;
}
if(R.isPyretException($e4653346534)) {
$e4653346534.pyretStack.push(L[3267]);
}
throw $e4653346534;
}
var $ret4653946540 = $Hann_DASH_check_DASH_temp847346544($z4653546536);
++R.GAS;
return $ret4653946540;
};
var $Hann_DASH_check_DASH_temp847346544 = function(ann_DASH_check_DASH_temp56646543) {
return ann_DASH_check_DASH_temp56646543;
};
var $Hanf_arg847218341 = function(anf_arg55218339,self5518340,_plus55,torepr65) {
var anf_arg55346555 = G(self5518340,"file",L[3224]);
var $z4654746548 = D;
var $f4655346554 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg55346555):R.ffi.throwNonFunApp(L[3224],torepr65,[anf_arg55346555]);
};
try {
if(--R.GAS > 0) {
$z4654746548 = $f4655346554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4655346554,
"from":L[3224]});
}
} catch($e4654546546) {
if(R.isCont($e4654546546)) {
var $ss4654946550 = {"from":L[3224],
"go":function(anf_arg55446556) {
return $Hanf_arg847146557(anf_arg55446556,anf_arg55218339,self5518340,_plus55,torepr65);
}};
$e4654546546.stack[R.EXN_STACKHEIGHT++] = $ss4654946550;
}
if(R.isPyretException($e4654546546)) {
$e4654546546.pyretStack.push(L[3224]);
}
throw $e4654546546;
}
var $ret4655146552 = $Hanf_arg847146557($z4654746548,anf_arg55218339,self5518340,_plus55,torepr65);
++R.GAS;
return $ret4655146552;
};
var $Hanf_arg847146557 = function(anf_arg55446556,anf_arg55218339,self5518340,_plus55,torepr65) {
var $z4656046561 = D;
var $f4656646567 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg55446556):R.ffi.throwNonFunApp(L[3224],_plus55,[(", "),anf_arg55446556]);
};
try {
if(--R.GAS > 0) {
$z4656046561 = $f4656646567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4656646567,
"from":L[3224]});
}
} catch($e4655846559) {
if(R.isCont($e4655846559)) {
var $ss4656246563 = {"from":L[3224],
"go":function(anf_arg55546568) {
return $Hanf_arg847046569(anf_arg55546568,anf_arg55218339,self5518340,_plus55,torepr65);
}};
$e4655846559.stack[R.EXN_STACKHEIGHT++] = $ss4656246563;
}
if(R.isPyretException($e4655846559)) {
$e4655846559.pyretStack.push(L[3224]);
}
throw $e4655846559;
}
var $ret4656446565 = $Hanf_arg847046569($z4656046561,anf_arg55218339,self5518340,_plus55,torepr65);
++R.GAS;
return $ret4656446565;
};
var $Hanf_arg847046569 = function(anf_arg55546568,anf_arg55218339,self5518340,_plus55,torepr65) {
var $z4657246573 = D;
var $f4657846579 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg55218339,anf_arg55546568):R.ffi.throwNonFunApp(L[3224],_plus55,[anf_arg55218339,anf_arg55546568]);
};
try {
if(--R.GAS > 0) {
$z4657246573 = $f4657846579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4657846579,
"from":L[3224]});
}
} catch($e4657046571) {
if(R.isCont($e4657046571)) {
var $ss4657446575 = {"from":L[3224],
"go":function(anf_arg55646580) {
return $Hanf_arg846946581(anf_arg55646580,self5518340,_plus55,torepr65);
}};
$e4657046571.stack[R.EXN_STACKHEIGHT++] = $ss4657446575;
}
if(R.isPyretException($e4657046571)) {
$e4657046571.pyretStack.push(L[3224]);
}
throw $e4657046571;
}
var $ret4657646577 = $Hanf_arg846946581($z4657246573,self5518340,_plus55,torepr65);
++R.GAS;
return $ret4657646577;
};
var $Hanf_arg846946581 = function(anf_arg55646580,self5518340,_plus55,torepr65) {
var anf_arg55746592 = G(self5518340,"name",L[3224]);
var $z4658446585 = D;
var $f4659046591 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg55746592):R.ffi.throwNonFunApp(L[3224],torepr65,[anf_arg55746592]);
};
try {
if(--R.GAS > 0) {
$z4658446585 = $f4659046591();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4659046591,
"from":L[3224]});
}
} catch($e4658246583) {
if(R.isCont($e4658246583)) {
var $ss4658646587 = {"from":L[3224],
"go":function(anf_arg55846593) {
return $Hanf_arg846846594(anf_arg55846593,anf_arg55646580,_plus55);
}};
$e4658246583.stack[R.EXN_STACKHEIGHT++] = $ss4658646587;
}
if(R.isPyretException($e4658246583)) {
$e4658246583.pyretStack.push(L[3224]);
}
throw $e4658246583;
}
var $ret4658846589 = $Hanf_arg846846594($z4658446585,anf_arg55646580,_plus55);
++R.GAS;
return $ret4658846589;
};
var $Hanf_arg846846594 = function(anf_arg55846593,anf_arg55646580,_plus55) {
var $z4659746598 = D;
var $f4660346604 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg55846593):R.ffi.throwNonFunApp(L[3224],_plus55,[(", "),anf_arg55846593]);
};
try {
if(--R.GAS > 0) {
$z4659746598 = $f4660346604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4660346604,
"from":L[3224]});
}
} catch($e4659546596) {
if(R.isCont($e4659546596)) {
var $ss4659946600 = {"from":L[3224],
"go":function(anf_arg55946605) {
return $Hanf_arg846746606(anf_arg55946605,anf_arg55646580,_plus55);
}};
$e4659546596.stack[R.EXN_STACKHEIGHT++] = $ss4659946600;
}
if(R.isPyretException($e4659546596)) {
$e4659546596.pyretStack.push(L[3224]);
}
throw $e4659546596;
}
var $ret4660146602 = $Hanf_arg846746606($z4659746598,anf_arg55646580,_plus55);
++R.GAS;
return $ret4660146602;
};
var $Hanf_arg846746606 = function(anf_arg55946605,anf_arg55646580,_plus55) {
var $z4660946610 = D;
var $f4661546616 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg55646580,anf_arg55946605):R.ffi.throwNonFunApp(L[3224],_plus55,[anf_arg55646580,anf_arg55946605]);
};
try {
if(--R.GAS > 0) {
$z4660946610 = $f4661546616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4661546616,
"from":L[3224]});
}
} catch($e4660746608) {
if(R.isCont($e4660746608)) {
var $ss4661146612 = {"from":L[3224],
"go":function(anf_arg56046617) {
return $Hanf_arg846646618(anf_arg56046617,_plus55);
}};
$e4660746608.stack[R.EXN_STACKHEIGHT++] = $ss4661146612;
}
if(R.isPyretException($e4660746608)) {
$e4660746608.pyretStack.push(L[3224]);
}
throw $e4660746608;
}
var $ret4661346614 = $Hanf_arg846646618($z4660946610,_plus55);
++R.GAS;
return $ret4661346614;
};
var $Hanf_arg846646618 = function(anf_arg56046617,_plus55) {
var $z4662146622 = D;
var $f4662746628 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg56046617,(")")):R.ffi.throwNonFunApp(L[3224],_plus55,[anf_arg56046617,(")")]);
};
try {
if(--R.GAS > 0) {
$z4662146622 = $f4662746628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4662746628,
"from":L[3224]});
}
} catch($e4661946620) {
if(R.isCont($e4661946620)) {
var $ss4662346624 = {"from":L[3224],
"go":function(anf_arg56146629) {
return $Hanf_arg846546630(anf_arg56146629,_plus55);
}};
$e4661946620.stack[R.EXN_STACKHEIGHT++] = $ss4662346624;
}
if(R.isPyretException($e4661946620)) {
$e4661946620.pyretStack.push(L[3224]);
}
throw $e4661946620;
}
var $ret4662546626 = $Hanf_arg846546630($z4662146622,_plus55);
++R.GAS;
return $ret4662546626;
};
var $Hanf_arg846546630 = function(anf_arg56146629,_plus55) {
var $z4663346634 = D;
var $f4663946640 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg56146629):R.ffi.throwNonFunApp(L[3224],_plus55,[("("),anf_arg56146629]);
};
try {
if(--R.GAS > 0) {
$z4663346634 = $f4663946640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4663946640,
"from":L[3224]});
}
} catch($e4663146632) {
if(R.isCont($e4663146632)) {
var $ss4663546636 = {"from":L[3224],
"go":function(anf_arg56246641) {
return $Hanf_arg846446642(anf_arg56246641,_plus55);
}};
$e4663146632.stack[R.EXN_STACKHEIGHT++] = $ss4663546636;
}
if(R.isPyretException($e4663146632)) {
$e4663146632.pyretStack.push(L[3224]);
}
throw $e4663146632;
}
var $ret4663746638 = $Hanf_arg846446642($z4663346634,_plus55);
++R.GAS;
return $ret4663746638;
};
var $Hanf_arg846446642 = function(anf_arg56246641,_plus55) {
var $z4664546646 = D;
var $f4665146652 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-import"),anf_arg56246641):R.ffi.throwNonFunApp(L[3224],_plus55,[("s-import"),anf_arg56246641]);
};
try {
if(--R.GAS > 0) {
$z4664546646 = $f4665146652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4665146652,
"from":L[3224]});
}
} catch($e4664346644) {
if(R.isCont($e4664346644)) {
var $ss4664746648 = {"from":L[3224],
"go":function(ann_DASH_check_DASH_temp55046653) {
return $Hann_DASH_check_DASH_temp846346654(ann_DASH_check_DASH_temp55046653);
}};
$e4664346644.stack[R.EXN_STACKHEIGHT++] = $ss4664746648;
}
if(R.isPyretException($e4664346644)) {
$e4664346644.pyretStack.push(L[3224]);
}
throw $e4664346644;
}
var $ret4664946650 = $Hann_DASH_check_DASH_temp846346654($z4664546646);
++R.GAS;
return $ret4664946650;
};
var $Hann_DASH_check_DASH_temp846346654 = function(ann_DASH_check_DASH_temp55046653) {
return ann_DASH_check_DASH_temp55046653;
};
var $Hcont_tail_arg846118358 = function(cont_tail_arg54718356,if_helper53718357) {
if(--R.GAS > 0) {
$z4665546656 = R.isFunction(if_helper53718357)?if_helper53718357.app(cont_tail_arg54718356):R.ffi.throwNonFunApp(L[3224],if_helper53718357,[cont_tail_arg54718356]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53718357)?if_helper53718357.app(cont_tail_arg54718356):R.ffi.throwNonFunApp(L[3224],if_helper53718357,[cont_tail_arg54718356]);
},
"from":L[3224]});
}
++R.GAS;
return $z4665546656;
};
var $Hcont_tail_arg846218373 = function(cont_tail_arg54218372,if_helper53718357) {
if(--R.GAS > 0) {
$z4665746658 = R.isFunction(if_helper53718357)?if_helper53718357.app(cont_tail_arg54218372):R.ffi.throwNonFunApp(L[3224],if_helper53718357,[cont_tail_arg54218372]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper53718357)?if_helper53718357.app(cont_tail_arg54218372):R.ffi.throwNonFunApp(L[3224],if_helper53718357,[cont_tail_arg54218372]);
},
"from":L[3224]});
}
++R.GAS;
return $z4665746658;
};
var $Hann_DASH_check_DASH_temp846018395 = function(ann_DASH_check_DASH_temp52818394) {
return ann_DASH_check_DASH_temp52818394;
};
var $Hanf_arg845918408 = function(anf_arg53218407,_plus55,raise62) {
var $z4666146662 = D;
var $f4666746668 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg53218407):R.ffi.throwNonFunApp(L[4799],_plus55,[("No visitor field for "),anf_arg53218407]);
};
try {
if(--R.GAS > 0) {
$z4666146662 = $f4666746668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4666746668,
"from":L[4799]});
}
} catch($e4665946660) {
if(R.isCont($e4665946660)) {
var $ss4666346664 = {"from":L[4799],
"go":function(anf_arg53346669) {
return $Hanf_arg845846670(anf_arg53346669,raise62);
}};
$e4665946660.stack[R.EXN_STACKHEIGHT++] = $ss4666346664;
}
if(R.isPyretException($e4665946660)) {
$e4665946660.pyretStack.push(L[4799]);
}
throw $e4665946660;
}
var $ret4666546666 = $Hanf_arg845846670($z4666146662,raise62);
++R.GAS;
return $ret4666546666;
};
var $Hanf_arg845846670 = function(anf_arg53346669,raise62) {
var $z4667346674 = D;
var $f4667946680 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg53346669):R.ffi.throwNonFunApp(L[3273],raise62,[anf_arg53346669]);
};
try {
if(--R.GAS > 0) {
$z4667346674 = $f4667946680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4667946680,
"from":L[3273]});
}
} catch($e4667146672) {
if(R.isCont($e4667146672)) {
var $ss4667546676 = {"from":L[3273],
"go":function(ann_DASH_check_DASH_temp53046681) {
return $Hann_DASH_check_DASH_temp845746682(ann_DASH_check_DASH_temp53046681);
}};
$e4667146672.stack[R.EXN_STACKHEIGHT++] = $ss4667546676;
}
if(R.isPyretException($e4667146672)) {
$e4667146672.pyretStack.push(L[3273]);
}
throw $e4667146672;
}
var $ret4667746678 = $Hann_DASH_check_DASH_temp845746682($z4667346674);
++R.GAS;
return $ret4667746678;
};
var $Hann_DASH_check_DASH_temp845746682 = function(ann_DASH_check_DASH_temp53046681) {
return ann_DASH_check_DASH_temp53046681;
};
var $Hanf_array_val845618441 = function(anf_array_val50318436,anf_fun49818437,anf_fun49918438,anf_fun50018439,list25154,self56118440,_plus55) {
var anf_bracket50446696 = G(self56118440,"provided-types",L[4802]);
var anf_fun50546693 = G(anf_bracket50446696,"tosource",L[4801]);
var $z4668546686 = D;
var $f4669146692 = function(_) {
return R.isFunction(anf_fun50546693)?anf_fun50546693.app():R.ffi.throwNonFunApp(L[4800],anf_fun50546693,[]);
};
try {
if(--R.GAS > 0) {
$z4668546686 = $f4669146692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4669146692,
"from":L[4800]});
}
} catch($e4668346684) {
if(R.isCont($e4668346684)) {
var $ss4668746688 = {"from":L[4800],
"go":function(anf_array_val50646694) {
return $Hanf_array_val845546695(anf_array_val50646694,anf_array_val50318436,anf_fun49818437,anf_fun49918438,anf_fun50018439,list25154,self56118440,_plus55);
}};
$e4668346684.stack[R.EXN_STACKHEIGHT++] = $ss4668746688;
}
if(R.isPyretException($e4668346684)) {
$e4668346684.pyretStack.push(L[4800]);
}
throw $e4668346684;
}
var $ret4668946690 = $Hanf_array_val845546695($z4668546686,anf_array_val50318436,anf_fun49818437,anf_fun49918438,anf_fun50018439,list25154,self56118440,_plus55);
++R.GAS;
return $ret4668946690;
};
var $Hanf_array_val845546695 = function(anf_array_val50646694,anf_array_val50318436,anf_fun49818437,anf_fun49918438,anf_fun50018439,list25154,self56118440,_plus55) {
var $z4669946700 = D;
var $f4670546706 = function(_) {
return R.isFunction(anf_fun50018439)?anf_fun50018439.app([anf_array_val50318436,anf_array_val50646694]):R.ffi.throwNonFunApp(L[3288],anf_fun50018439,[[anf_array_val50318436,anf_array_val50646694]]);
};
try {
if(--R.GAS > 0) {
$z4669946700 = $f4670546706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4670546706,
"from":L[3288]});
}
} catch($e4669746698) {
if(R.isCont($e4669746698)) {
var $ss4670146702 = {"from":L[3288],
"go":function(anf_arg50746707) {
return $Hanf_arg845446708(anf_arg50746707,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55);
}};
$e4669746698.stack[R.EXN_STACKHEIGHT++] = $ss4670146702;
}
if(R.isPyretException($e4669746698)) {
$e4669746698.pyretStack.push(L[3288]);
}
throw $e4669746698;
}
var $ret4670346704 = $Hanf_arg845446708($z4669946700,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55);
++R.GAS;
return $ret4670346704;
};
var $Hanf_arg845446708 = function(anf_arg50746707,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55) {
var anf_bracket50846737 = G(self56118440,"imports",L[4806]);
var anf_fun50946719 = G(anf_bracket50846737,"map",L[4805]);
var anf_arg51246720 = R.makeFunction(function(recv_DASH_5046723) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4804],1,arguments);
}
var anf_fun51146734 = G(recv_DASH_5046723,"tosource",L[4804]);
var $z4672646727 = D;
var $f4673246733 = function(_) {
return R.isFunction(anf_fun51146734)?anf_fun51146734.app():R.ffi.throwNonFunApp(L[4804],anf_fun51146734,[]);
};
try {
if(--R.GAS > 0) {
$z4672646727 = $f4673246733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4673246733,
"from":L[4804]});
}
} catch($e4672446725) {
if(R.isCont($e4672446725)) {
var $ss4672846729 = {"from":L[4804],
"go":function(ann_DASH_check_DASH_temp51046735) {
return $Hann_DASH_check_DASH_temp844646736(ann_DASH_check_DASH_temp51046735);
}};
$e4672446725.stack[R.EXN_STACKHEIGHT++] = $ss4672846729;
}
if(R.isPyretException($e4672446725)) {
$e4672446725.pyretStack.push(L[4804]);
}
throw $e4672446725;
}
var $ret4673046731 = $Hann_DASH_check_DASH_temp844646736($z4672646727);
++R.GAS;
return $ret4673046731;
});
var $z4671146712 = D;
var $f4671746718 = function(_) {
return R.isFunction(anf_fun50946719)?anf_fun50946719.app(anf_arg51246720):R.ffi.throwNonFunApp(L[4803],anf_fun50946719,[anf_arg51246720]);
};
try {
if(--R.GAS > 0) {
$z4671146712 = $f4671746718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4671746718,
"from":L[4803]});
}
} catch($e4670946710) {
if(R.isCont($e4670946710)) {
var $ss4671346714 = {"from":L[4803],
"go":function(anf_arg51346721) {
return $Hanf_arg845346722(anf_arg51346721,anf_arg50746707,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55);
}};
$e4670946710.stack[R.EXN_STACKHEIGHT++] = $ss4671346714;
}
if(R.isPyretException($e4670946710)) {
$e4670946710.pyretStack.push(L[4803]);
}
throw $e4670946710;
}
var $ret4671546716 = $Hanf_arg845346722($z4671146712,anf_arg50746707,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55);
++R.GAS;
return $ret4671546716;
};
var $Hanf_arg845346722 = function(anf_arg51346721,anf_arg50746707,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55) {
var $z4674046741 = D;
var $f4674646747 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg50746707,anf_arg51346721):R.ffi.throwNonFunApp(L[4807],_plus55,[anf_arg50746707,anf_arg51346721]);
};
try {
if(--R.GAS > 0) {
$z4674046741 = $f4674646747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4674646747,
"from":L[4807]});
}
} catch($e4673846739) {
if(R.isCont($e4673846739)) {
var $ss4674246743 = {"from":L[4807],
"go":function(anf_arg51446748) {
return $Hanf_arg845246749(anf_arg51446748,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55);
}};
$e4673846739.stack[R.EXN_STACKHEIGHT++] = $ss4674246743;
}
if(R.isPyretException($e4673846739)) {
$e4673846739.pyretStack.push(L[4807]);
}
throw $e4673846739;
}
var $ret4674446745 = $Hanf_arg845246749($z4674046741,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55);
++R.GAS;
return $ret4674446745;
};
var $Hanf_arg845246749 = function(anf_arg51446748,anf_fun49818437,anf_fun49918438,list25154,self56118440,_plus55) {
var anf_fun51546762 = G(list25154,"make",L[4811]);
var anf_bracket51646764 = G(self56118440,"block",L[4810]);
var anf_fun51746760 = G(anf_bracket51646764,"tosource",L[4809]);
var $z4675246753 = D;
var $f4675846759 = function(_) {
return R.isFunction(anf_fun51746760)?anf_fun51746760.app():R.ffi.throwNonFunApp(L[4808],anf_fun51746760,[]);
};
try {
if(--R.GAS > 0) {
$z4675246753 = $f4675846759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4675846759,
"from":L[4808]});
}
} catch($e4675046751) {
if(R.isCont($e4675046751)) {
var $ss4675446755 = {"from":L[4808],
"go":function(anf_array_val51846761) {
return $Hanf_array_val845146763(anf_array_val51846761,anf_arg51446748,anf_fun49818437,anf_fun49918438,anf_fun51546762,_plus55);
}};
$e4675046751.stack[R.EXN_STACKHEIGHT++] = $ss4675446755;
}
if(R.isPyretException($e4675046751)) {
$e4675046751.pyretStack.push(L[4808]);
}
throw $e4675046751;
}
var $ret4675646757 = $Hanf_array_val845146763($z4675246753,anf_arg51446748,anf_fun49818437,anf_fun49918438,anf_fun51546762,_plus55);
++R.GAS;
return $ret4675646757;
};
var $Hanf_array_val845146763 = function(anf_array_val51846761,anf_arg51446748,anf_fun49818437,anf_fun49918438,anf_fun51546762,_plus55) {
var $z4676746768 = D;
var $f4677346774 = function(_) {
return R.isFunction(anf_fun51546762)?anf_fun51546762.app([anf_array_val51846761]):R.ffi.throwNonFunApp(L[4811],anf_fun51546762,[[anf_array_val51846761]]);
};
try {
if(--R.GAS > 0) {
$z4676746768 = $f4677346774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4677346774,
"from":L[4811]});
}
} catch($e4676546766) {
if(R.isCont($e4676546766)) {
var $ss4676946770 = {"from":L[4811],
"go":function(anf_arg51946775) {
return $Hanf_arg845046776(anf_arg51946775,anf_arg51446748,anf_fun49818437,anf_fun49918438,_plus55);
}};
$e4676546766.stack[R.EXN_STACKHEIGHT++] = $ss4676946770;
}
if(R.isPyretException($e4676546766)) {
$e4676546766.pyretStack.push(L[4811]);
}
throw $e4676546766;
}
var $ret4677146772 = $Hanf_arg845046776($z4676746768,anf_arg51446748,anf_fun49818437,anf_fun49918438,_plus55);
++R.GAS;
return $ret4677146772;
};
var $Hanf_arg845046776 = function(anf_arg51946775,anf_arg51446748,anf_fun49818437,anf_fun49918438,_plus55) {
var $z4677946780 = D;
var $f4678546786 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg51446748,anf_arg51946775):R.ffi.throwNonFunApp(L[4807],_plus55,[anf_arg51446748,anf_arg51946775]);
};
try {
if(--R.GAS > 0) {
$z4677946780 = $f4678546786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4678546786,
"from":L[4807]});
}
} catch($e4677746778) {
if(R.isCont($e4677746778)) {
var $ss4678146782 = {"from":L[4807],
"go":function(anf_arg52046787) {
return $Hanf_arg844946788(anf_arg52046787,anf_fun49818437,anf_fun49918438);
}};
$e4677746778.stack[R.EXN_STACKHEIGHT++] = $ss4678146782;
}
if(R.isPyretException($e4677746778)) {
$e4677746778.pyretStack.push(L[4807]);
}
throw $e4677746778;
}
var $ret4678346784 = $Hanf_arg844946788($z4677946780,anf_fun49818437,anf_fun49918438);
++R.GAS;
return $ret4678346784;
};
var $Hanf_arg844946788 = function(anf_arg52046787,anf_fun49818437,anf_fun49918438) {
var $z4679146792 = D;
var $f4679746798 = function(_) {
return R.isFunction(anf_fun49918438)?anf_fun49918438.app(anf_arg52046787):R.ffi.throwNonFunApp(L[4812],anf_fun49918438,[anf_arg52046787]);
};
try {
if(--R.GAS > 0) {
$z4679146792 = $f4679746798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4679746798,
"from":L[4812]});
}
} catch($e4678946790) {
if(R.isCont($e4678946790)) {
var $ss4679346794 = {"from":L[4812],
"go":function(anf_arg52146799) {
return $Hanf_arg844846800(anf_arg52146799,anf_fun49818437);
}};
$e4678946790.stack[R.EXN_STACKHEIGHT++] = $ss4679346794;
}
if(R.isPyretException($e4678946790)) {
$e4678946790.pyretStack.push(L[4812]);
}
throw $e4678946790;
}
var $ret4679546796 = $Hanf_arg844846800($z4679146792,anf_fun49818437);
++R.GAS;
return $ret4679546796;
};
var $Hanf_arg844846800 = function(anf_arg52146799,anf_fun49818437) {
var $z4680346804 = D;
var $f4680946810 = function(_) {
return R.isFunction(anf_fun49818437)?anf_fun49818437.app(anf_arg52146799):R.ffi.throwNonFunApp(L[3291],anf_fun49818437,[anf_arg52146799]);
};
try {
if(--R.GAS > 0) {
$z4680346804 = $f4680946810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4680946810,
"from":L[3291]});
}
} catch($e4680146802) {
if(R.isCont($e4680146802)) {
var $ss4680546806 = {"from":L[3291],
"go":function(ann_DASH_check_DASH_temp49746811) {
return $Hann_DASH_check_DASH_temp844746812(ann_DASH_check_DASH_temp49746811);
}};
$e4680146802.stack[R.EXN_STACKHEIGHT++] = $ss4680546806;
}
if(R.isPyretException($e4680146802)) {
$e4680146802.pyretStack.push(L[3291]);
}
throw $e4680146802;
}
var $ret4680746808 = $Hann_DASH_check_DASH_temp844746812($z4680346804);
++R.GAS;
return $ret4680746808;
};
var $Hann_DASH_check_DASH_temp844746812 = function(ann_DASH_check_DASH_temp49746811) {
return ann_DASH_check_DASH_temp49746811;
};
var $Hann_DASH_check_DASH_temp844646736 = function(ann_DASH_check_DASH_temp51046735) {
return ann_DASH_check_DASH_temp51046735;
};
var $Hanf_arg844518458 = function(anf_arg47518456,self4818457,_plus55,torepr65) {
var anf_arg47646823 = G(self4818457,"_provide",L[3277]);
var $z4681546816 = D;
var $f4682146822 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg47646823):R.ffi.throwNonFunApp(L[3277],torepr65,[anf_arg47646823]);
};
try {
if(--R.GAS > 0) {
$z4681546816 = $f4682146822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4682146822,
"from":L[3277]});
}
} catch($e4681346814) {
if(R.isCont($e4681346814)) {
var $ss4681746818 = {"from":L[3277],
"go":function(anf_arg47746824) {
return $Hanf_arg844446825(anf_arg47746824,anf_arg47518456,self4818457,_plus55,torepr65);
}};
$e4681346814.stack[R.EXN_STACKHEIGHT++] = $ss4681746818;
}
if(R.isPyretException($e4681346814)) {
$e4681346814.pyretStack.push(L[3277]);
}
throw $e4681346814;
}
var $ret4681946820 = $Hanf_arg844446825($z4681546816,anf_arg47518456,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4681946820;
};
var $Hanf_arg844446825 = function(anf_arg47746824,anf_arg47518456,self4818457,_plus55,torepr65) {
var $z4682846829 = D;
var $f4683446835 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg47746824):R.ffi.throwNonFunApp(L[3277],_plus55,[(", "),anf_arg47746824]);
};
try {
if(--R.GAS > 0) {
$z4682846829 = $f4683446835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4683446835,
"from":L[3277]});
}
} catch($e4682646827) {
if(R.isCont($e4682646827)) {
var $ss4683046831 = {"from":L[3277],
"go":function(anf_arg47846836) {
return $Hanf_arg844346837(anf_arg47846836,anf_arg47518456,self4818457,_plus55,torepr65);
}};
$e4682646827.stack[R.EXN_STACKHEIGHT++] = $ss4683046831;
}
if(R.isPyretException($e4682646827)) {
$e4682646827.pyretStack.push(L[3277]);
}
throw $e4682646827;
}
var $ret4683246833 = $Hanf_arg844346837($z4682846829,anf_arg47518456,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4683246833;
};
var $Hanf_arg844346837 = function(anf_arg47846836,anf_arg47518456,self4818457,_plus55,torepr65) {
var $z4684046841 = D;
var $f4684646847 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg47518456,anf_arg47846836):R.ffi.throwNonFunApp(L[3277],_plus55,[anf_arg47518456,anf_arg47846836]);
};
try {
if(--R.GAS > 0) {
$z4684046841 = $f4684646847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4684646847,
"from":L[3277]});
}
} catch($e4683846839) {
if(R.isCont($e4683846839)) {
var $ss4684246843 = {"from":L[3277],
"go":function(anf_arg47946848) {
return $Hanf_arg844246849(anf_arg47946848,self4818457,_plus55,torepr65);
}};
$e4683846839.stack[R.EXN_STACKHEIGHT++] = $ss4684246843;
}
if(R.isPyretException($e4683846839)) {
$e4683846839.pyretStack.push(L[3277]);
}
throw $e4683846839;
}
var $ret4684446845 = $Hanf_arg844246849($z4684046841,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4684446845;
};
var $Hanf_arg844246849 = function(anf_arg47946848,self4818457,_plus55,torepr65) {
var anf_arg48046860 = G(self4818457,"provided-types",L[3277]);
var $z4685246853 = D;
var $f4685846859 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg48046860):R.ffi.throwNonFunApp(L[3277],torepr65,[anf_arg48046860]);
};
try {
if(--R.GAS > 0) {
$z4685246853 = $f4685846859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4685846859,
"from":L[3277]});
}
} catch($e4685046851) {
if(R.isCont($e4685046851)) {
var $ss4685446855 = {"from":L[3277],
"go":function(anf_arg48146861) {
return $Hanf_arg844146862(anf_arg48146861,anf_arg47946848,self4818457,_plus55,torepr65);
}};
$e4685046851.stack[R.EXN_STACKHEIGHT++] = $ss4685446855;
}
if(R.isPyretException($e4685046851)) {
$e4685046851.pyretStack.push(L[3277]);
}
throw $e4685046851;
}
var $ret4685646857 = $Hanf_arg844146862($z4685246853,anf_arg47946848,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4685646857;
};
var $Hanf_arg844146862 = function(anf_arg48146861,anf_arg47946848,self4818457,_plus55,torepr65) {
var $z4686546866 = D;
var $f4687146872 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg48146861):R.ffi.throwNonFunApp(L[3277],_plus55,[(", "),anf_arg48146861]);
};
try {
if(--R.GAS > 0) {
$z4686546866 = $f4687146872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4687146872,
"from":L[3277]});
}
} catch($e4686346864) {
if(R.isCont($e4686346864)) {
var $ss4686746868 = {"from":L[3277],
"go":function(anf_arg48246873) {
return $Hanf_arg844046874(anf_arg48246873,anf_arg47946848,self4818457,_plus55,torepr65);
}};
$e4686346864.stack[R.EXN_STACKHEIGHT++] = $ss4686746868;
}
if(R.isPyretException($e4686346864)) {
$e4686346864.pyretStack.push(L[3277]);
}
throw $e4686346864;
}
var $ret4686946870 = $Hanf_arg844046874($z4686546866,anf_arg47946848,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4686946870;
};
var $Hanf_arg844046874 = function(anf_arg48246873,anf_arg47946848,self4818457,_plus55,torepr65) {
var $z4687746878 = D;
var $f4688346884 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg47946848,anf_arg48246873):R.ffi.throwNonFunApp(L[3277],_plus55,[anf_arg47946848,anf_arg48246873]);
};
try {
if(--R.GAS > 0) {
$z4687746878 = $f4688346884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4688346884,
"from":L[3277]});
}
} catch($e4687546876) {
if(R.isCont($e4687546876)) {
var $ss4687946880 = {"from":L[3277],
"go":function(anf_arg48346885) {
return $Hanf_arg843946886(anf_arg48346885,self4818457,_plus55,torepr65);
}};
$e4687546876.stack[R.EXN_STACKHEIGHT++] = $ss4687946880;
}
if(R.isPyretException($e4687546876)) {
$e4687546876.pyretStack.push(L[3277]);
}
throw $e4687546876;
}
var $ret4688146882 = $Hanf_arg843946886($z4687746878,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4688146882;
};
var $Hanf_arg843946886 = function(anf_arg48346885,self4818457,_plus55,torepr65) {
var anf_arg48446897 = G(self4818457,"imports",L[3277]);
var $z4688946890 = D;
var $f4689546896 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg48446897):R.ffi.throwNonFunApp(L[3277],torepr65,[anf_arg48446897]);
};
try {
if(--R.GAS > 0) {
$z4688946890 = $f4689546896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4689546896,
"from":L[3277]});
}
} catch($e4688746888) {
if(R.isCont($e4688746888)) {
var $ss4689146892 = {"from":L[3277],
"go":function(anf_arg48546898) {
return $Hanf_arg843846899(anf_arg48546898,anf_arg48346885,self4818457,_plus55,torepr65);
}};
$e4688746888.stack[R.EXN_STACKHEIGHT++] = $ss4689146892;
}
if(R.isPyretException($e4688746888)) {
$e4688746888.pyretStack.push(L[3277]);
}
throw $e4688746888;
}
var $ret4689346894 = $Hanf_arg843846899($z4688946890,anf_arg48346885,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4689346894;
};
var $Hanf_arg843846899 = function(anf_arg48546898,anf_arg48346885,self4818457,_plus55,torepr65) {
var $z4690246903 = D;
var $f4690846909 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg48546898):R.ffi.throwNonFunApp(L[3277],_plus55,[(", "),anf_arg48546898]);
};
try {
if(--R.GAS > 0) {
$z4690246903 = $f4690846909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4690846909,
"from":L[3277]});
}
} catch($e4690046901) {
if(R.isCont($e4690046901)) {
var $ss4690446905 = {"from":L[3277],
"go":function(anf_arg48646910) {
return $Hanf_arg843746911(anf_arg48646910,anf_arg48346885,self4818457,_plus55,torepr65);
}};
$e4690046901.stack[R.EXN_STACKHEIGHT++] = $ss4690446905;
}
if(R.isPyretException($e4690046901)) {
$e4690046901.pyretStack.push(L[3277]);
}
throw $e4690046901;
}
var $ret4690646907 = $Hanf_arg843746911($z4690246903,anf_arg48346885,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4690646907;
};
var $Hanf_arg843746911 = function(anf_arg48646910,anf_arg48346885,self4818457,_plus55,torepr65) {
var $z4691446915 = D;
var $f4692046921 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg48346885,anf_arg48646910):R.ffi.throwNonFunApp(L[3277],_plus55,[anf_arg48346885,anf_arg48646910]);
};
try {
if(--R.GAS > 0) {
$z4691446915 = $f4692046921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4692046921,
"from":L[3277]});
}
} catch($e4691246913) {
if(R.isCont($e4691246913)) {
var $ss4691646917 = {"from":L[3277],
"go":function(anf_arg48746922) {
return $Hanf_arg843646923(anf_arg48746922,self4818457,_plus55,torepr65);
}};
$e4691246913.stack[R.EXN_STACKHEIGHT++] = $ss4691646917;
}
if(R.isPyretException($e4691246913)) {
$e4691246913.pyretStack.push(L[3277]);
}
throw $e4691246913;
}
var $ret4691846919 = $Hanf_arg843646923($z4691446915,self4818457,_plus55,torepr65);
++R.GAS;
return $ret4691846919;
};
var $Hanf_arg843646923 = function(anf_arg48746922,self4818457,_plus55,torepr65) {
var anf_arg48846934 = G(self4818457,"block",L[3277]);
var $z4692646927 = D;
var $f4693246933 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg48846934):R.ffi.throwNonFunApp(L[3277],torepr65,[anf_arg48846934]);
};
try {
if(--R.GAS > 0) {
$z4692646927 = $f4693246933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4693246933,
"from":L[3277]});
}
} catch($e4692446925) {
if(R.isCont($e4692446925)) {
var $ss4692846929 = {"from":L[3277],
"go":function(anf_arg48946935) {
return $Hanf_arg843546936(anf_arg48946935,anf_arg48746922,_plus55);
}};
$e4692446925.stack[R.EXN_STACKHEIGHT++] = $ss4692846929;
}
if(R.isPyretException($e4692446925)) {
$e4692446925.pyretStack.push(L[3277]);
}
throw $e4692446925;
}
var $ret4693046931 = $Hanf_arg843546936($z4692646927,anf_arg48746922,_plus55);
++R.GAS;
return $ret4693046931;
};
var $Hanf_arg843546936 = function(anf_arg48946935,anf_arg48746922,_plus55) {
var $z4693946940 = D;
var $f4694546946 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg48946935):R.ffi.throwNonFunApp(L[3277],_plus55,[(", "),anf_arg48946935]);
};
try {
if(--R.GAS > 0) {
$z4693946940 = $f4694546946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4694546946,
"from":L[3277]});
}
} catch($e4693746938) {
if(R.isCont($e4693746938)) {
var $ss4694146942 = {"from":L[3277],
"go":function(anf_arg49046947) {
return $Hanf_arg843446948(anf_arg49046947,anf_arg48746922,_plus55);
}};
$e4693746938.stack[R.EXN_STACKHEIGHT++] = $ss4694146942;
}
if(R.isPyretException($e4693746938)) {
$e4693746938.pyretStack.push(L[3277]);
}
throw $e4693746938;
}
var $ret4694346944 = $Hanf_arg843446948($z4693946940,anf_arg48746922,_plus55);
++R.GAS;
return $ret4694346944;
};
var $Hanf_arg843446948 = function(anf_arg49046947,anf_arg48746922,_plus55) {
var $z4695146952 = D;
var $f4695746958 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg48746922,anf_arg49046947):R.ffi.throwNonFunApp(L[3277],_plus55,[anf_arg48746922,anf_arg49046947]);
};
try {
if(--R.GAS > 0) {
$z4695146952 = $f4695746958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4695746958,
"from":L[3277]});
}
} catch($e4694946950) {
if(R.isCont($e4694946950)) {
var $ss4695346954 = {"from":L[3277],
"go":function(anf_arg49146959) {
return $Hanf_arg843346960(anf_arg49146959,_plus55);
}};
$e4694946950.stack[R.EXN_STACKHEIGHT++] = $ss4695346954;
}
if(R.isPyretException($e4694946950)) {
$e4694946950.pyretStack.push(L[3277]);
}
throw $e4694946950;
}
var $ret4695546956 = $Hanf_arg843346960($z4695146952,_plus55);
++R.GAS;
return $ret4695546956;
};
var $Hanf_arg843346960 = function(anf_arg49146959,_plus55) {
var $z4696346964 = D;
var $f4696946970 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg49146959,(")")):R.ffi.throwNonFunApp(L[3277],_plus55,[anf_arg49146959,(")")]);
};
try {
if(--R.GAS > 0) {
$z4696346964 = $f4696946970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4696946970,
"from":L[3277]});
}
} catch($e4696146962) {
if(R.isCont($e4696146962)) {
var $ss4696546966 = {"from":L[3277],
"go":function(anf_arg49246971) {
return $Hanf_arg843246972(anf_arg49246971,_plus55);
}};
$e4696146962.stack[R.EXN_STACKHEIGHT++] = $ss4696546966;
}
if(R.isPyretException($e4696146962)) {
$e4696146962.pyretStack.push(L[3277]);
}
throw $e4696146962;
}
var $ret4696746968 = $Hanf_arg843246972($z4696346964,_plus55);
++R.GAS;
return $ret4696746968;
};
var $Hanf_arg843246972 = function(anf_arg49246971,_plus55) {
var $z4697546976 = D;
var $f4698146982 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg49246971):R.ffi.throwNonFunApp(L[3277],_plus55,[("("),anf_arg49246971]);
};
try {
if(--R.GAS > 0) {
$z4697546976 = $f4698146982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4698146982,
"from":L[3277]});
}
} catch($e4697346974) {
if(R.isCont($e4697346974)) {
var $ss4697746978 = {"from":L[3277],
"go":function(anf_arg49346983) {
return $Hanf_arg843146984(anf_arg49346983,_plus55);
}};
$e4697346974.stack[R.EXN_STACKHEIGHT++] = $ss4697746978;
}
if(R.isPyretException($e4697346974)) {
$e4697346974.pyretStack.push(L[3277]);
}
throw $e4697346974;
}
var $ret4697946980 = $Hanf_arg843146984($z4697546976,_plus55);
++R.GAS;
return $ret4697946980;
};
var $Hanf_arg843146984 = function(anf_arg49346983,_plus55) {
var $z4698746988 = D;
var $f4699346994 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-program"),anf_arg49346983):R.ffi.throwNonFunApp(L[3277],_plus55,[("s-program"),anf_arg49346983]);
};
try {
if(--R.GAS > 0) {
$z4698746988 = $f4699346994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4699346994,
"from":L[3277]});
}
} catch($e4698546986) {
if(R.isCont($e4698546986)) {
var $ss4698946990 = {"from":L[3277],
"go":function(ann_DASH_check_DASH_temp47346995) {
return $Hann_DASH_check_DASH_temp843046996(ann_DASH_check_DASH_temp47346995);
}};
$e4698546986.stack[R.EXN_STACKHEIGHT++] = $ss4698946990;
}
if(R.isPyretException($e4698546986)) {
$e4698546986.pyretStack.push(L[3277]);
}
throw $e4698546986;
}
var $ret4699146992 = $Hann_DASH_check_DASH_temp843046996($z4698746988);
++R.GAS;
return $ret4699146992;
};
var $Hann_DASH_check_DASH_temp843046996 = function(ann_DASH_check_DASH_temp47346995) {
return ann_DASH_check_DASH_temp47346995;
};
var $Hcont_tail_arg842818477 = function(cont_tail_arg47018475,if_helper45818476) {
if(--R.GAS > 0) {
$z4699746998 = R.isFunction(if_helper45818476)?if_helper45818476.app(cont_tail_arg47018475):R.ffi.throwNonFunApp(L[3277],if_helper45818476,[cont_tail_arg47018475]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper45818476)?if_helper45818476.app(cont_tail_arg47018475):R.ffi.throwNonFunApp(L[3277],if_helper45818476,[cont_tail_arg47018475]);
},
"from":L[3277]});
}
++R.GAS;
return $z4699746998;
};
var $Hcont_tail_arg842918492 = function(cont_tail_arg46318491,if_helper45818476) {
if(--R.GAS > 0) {
$z4699947000 = R.isFunction(if_helper45818476)?if_helper45818476.app(cont_tail_arg46318491):R.ffi.throwNonFunApp(L[3277],if_helper45818476,[cont_tail_arg46318491]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper45818476)?if_helper45818476.app(cont_tail_arg46318491):R.ffi.throwNonFunApp(L[3277],if_helper45818476,[cont_tail_arg46318491]);
},
"from":L[3277]});
}
++R.GAS;
return $z4699947000;
};
var $Hann_DASH_check_DASH_temp842718514 = function(ann_DASH_check_DASH_temp44918513) {
return ann_DASH_check_DASH_temp44918513;
};
var $Hanf_arg842618527 = function(anf_arg45318526,_plus55,raise62) {
var $z4700347004 = D;
var $f4700947010 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg45318526):R.ffi.throwNonFunApp(L[4813],_plus55,[("No visitor field for "),anf_arg45318526]);
};
try {
if(--R.GAS > 0) {
$z4700347004 = $f4700947010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4700947010,
"from":L[4813]});
}
} catch($e4700147002) {
if(R.isCont($e4700147002)) {
var $ss4700547006 = {"from":L[4813],
"go":function(anf_arg45447011) {
return $Hanf_arg842547012(anf_arg45447011,raise62);
}};
$e4700147002.stack[R.EXN_STACKHEIGHT++] = $ss4700547006;
}
if(R.isPyretException($e4700147002)) {
$e4700147002.pyretStack.push(L[4813]);
}
throw $e4700147002;
}
var $ret4700747008 = $Hanf_arg842547012($z4700347004,raise62);
++R.GAS;
return $ret4700747008;
};
var $Hanf_arg842547012 = function(anf_arg45447011,raise62) {
var $z4701547016 = D;
var $f4702147022 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg45447011):R.ffi.throwNonFunApp(L[3299],raise62,[anf_arg45447011]);
};
try {
if(--R.GAS > 0) {
$z4701547016 = $f4702147022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4702147022,
"from":L[3299]});
}
} catch($e4701347014) {
if(R.isCont($e4701347014)) {
var $ss4701747018 = {"from":L[3299],
"go":function(ann_DASH_check_DASH_temp45147023) {
return $Hann_DASH_check_DASH_temp842447024(ann_DASH_check_DASH_temp45147023);
}};
$e4701347014.stack[R.EXN_STACKHEIGHT++] = $ss4701747018;
}
if(R.isPyretException($e4701347014)) {
$e4701347014.pyretStack.push(L[3299]);
}
throw $e4701347014;
}
var $ret4701947020 = $Hann_DASH_check_DASH_temp842447024($z4701547016);
++R.GAS;
return $ret4701947020;
};
var $Hann_DASH_check_DASH_temp842447024 = function(ann_DASH_check_DASH_temp45147023) {
return ann_DASH_check_DASH_temp45147023;
};
var $Hif_DASH_842318548 = function(if_DASH_3318547,INDENT118169,PP170,PP278,_check54318536,ann54018533,args53918532,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,params53818531,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var if_helper32347027 = R.makeFunction(function(if_helper_arg32447066) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3304],1,arguments);
}
var typarams54447082 = if_helper_arg32447066;
var anf_fun32547080 = G(PP170,"nest",L[4827]);
var anf_fun32647081 = G(PP170,"surround-separate",L[4826]);
var anf_arg32747077 = G(PP170,"lparen",L[4825]);
var anf_arg32847078 = G(PP170,"rparen",L[4824]);
var $z4706947070 = D;
var $f4707547076 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg32747077,anf_arg32847078):R.ffi.throwNonFunApp(L[4823],_plus55,[anf_arg32747077,anf_arg32847078]);
};
try {
if(--R.GAS > 0) {
$z4706947070 = $f4707547076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4707547076,
"from":L[4823]});
}
} catch($e4706747068) {
if(R.isCont($e4706747068)) {
var $ss4707147072 = {"from":L[4823],
"go":function(anf_arg32947079) {
return $Hanf_arg841947083(anf_arg32947079,INDENT118169,PP170,PP278,_check54318536,anf_fun32547080,anf_fun32647081,ann54018533,args53918532,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58);
}};
$e4706747068.stack[R.EXN_STACKHEIGHT++] = $ss4707147072;
}
if(R.isPyretException($e4706747068)) {
$e4706747068.pyretStack.push(L[4823]);
}
throw $e4706747068;
}
var $ret4707347074 = $Hanf_arg841947083($z4706947070,INDENT118169,PP170,PP278,_check54318536,anf_fun32547080,anf_fun32647081,ann54018533,args53918532,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4707347074;
});
var anf_if43347065 = R.isBoolean(if_DASH_3318547);
if(R.isPyretTrue(anf_if43347065)) {
if(R.isPyretTrue(if_DASH_3318547)) {
var cont_tail_arg44647028 = G(PP170,"mt-doc",L[4814]);
if(--R.GAS > 0) {
$z4702547026 = R.isFunction(if_helper32347027)?if_helper32347027.app(cont_tail_arg44647028):R.ffi.throwNonFunApp(L[4814],if_helper32347027,[cont_tail_arg44647028]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper32347027)?if_helper32347027.app(cont_tail_arg44647028):R.ffi.throwNonFunApp(L[4814],if_helper32347027,[cont_tail_arg44647028]);
},
"from":L[4814]});
}
++R.GAS;
return $z4702547026;
} else {
var anf_fun43447046 = G(PP170,"surround-separate",L[4822]);
var anf_arg43547042 = G(PP170,"mt-doc",L[4821]);
var anf_arg43647043 = G(PP170,"langle",L[4820]);
var anf_arg43747044 = G(PP170,"commabreak",L[4819]);
var anf_arg43847045 = G(PP170,"rangle",L[4818]);
var anf_fun43947039 = G(params53818531,"map",L[4817]);
var anf_arg44247040 = R.makeFunction(function(recv_DASH_3247048) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4816],1,arguments);
}
var anf_fun44147059 = G(recv_DASH_3247048,"tosource",L[4816]);
var $z4705147052 = D;
var $f4705747058 = function(_) {
return R.isFunction(anf_fun44147059)?anf_fun44147059.app():R.ffi.throwNonFunApp(L[4816],anf_fun44147059,[]);
};
try {
if(--R.GAS > 0) {
$z4705147052 = $f4705747058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4705747058,
"from":L[4816]});
}
} catch($e4704947050) {
if(R.isCont($e4704947050)) {
var $ss4705347054 = {"from":L[4816],
"go":function(ann_DASH_check_DASH_temp44047060) {
return $Hann_DASH_check_DASH_temp842047061(ann_DASH_check_DASH_temp44047060);
}};
$e4704947050.stack[R.EXN_STACKHEIGHT++] = $ss4705347054;
}
if(R.isPyretException($e4704947050)) {
$e4704947050.pyretStack.push(L[4816]);
}
throw $e4704947050;
}
var $ret4705547056 = $Hann_DASH_check_DASH_temp842047061($z4705147052);
++R.GAS;
return $ret4705547056;
});
var $z4703147032 = D;
var $f4703747038 = function(_) {
return R.isFunction(anf_fun43947039)?anf_fun43947039.app(anf_arg44247040):R.ffi.throwNonFunApp(L[4815],anf_fun43947039,[anf_arg44247040]);
};
try {
if(--R.GAS > 0) {
$z4703147032 = $f4703747038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4703747038,
"from":L[4815]});
}
} catch($e4702947030) {
if(R.isCont($e4702947030)) {
var $ss4703347034 = {"from":L[4815],
"go":function(anf_arg44347041) {
return $Hanf_arg842247047(anf_arg44347041,INDENT118169,anf_arg43547042,anf_arg43647043,anf_arg43747044,anf_arg43847045,anf_fun43447046,if_helper32347027);
}};
$e4702947030.stack[R.EXN_STACKHEIGHT++] = $ss4703347034;
}
if(R.isPyretException($e4702947030)) {
$e4702947030.pyretStack.push(L[4815]);
}
throw $e4702947030;
}
var $ret4703547036 = $Hanf_arg842247047($z4703147032,INDENT118169,anf_arg43547042,anf_arg43647043,anf_arg43747044,anf_arg43847045,anf_fun43447046,if_helper32347027);
++R.GAS;
return $ret4703547036;
}
} else {
var cont_tail_arg43147064 = R.throwNonBooleanCondition(L[3304],("if"),if_DASH_3318547);
if(--R.GAS > 0) {
$z4706247063 = R.isFunction(if_helper32347027)?if_helper32347027.app(cont_tail_arg43147064):R.ffi.throwNonFunApp(L[3304],if_helper32347027,[cont_tail_arg43147064]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper32347027)?if_helper32347027.app(cont_tail_arg43147064):R.ffi.throwNonFunApp(L[3304],if_helper32347027,[cont_tail_arg43147064]);
},
"from":L[3304]});
}
++R.GAS;
return $z4706247063;
}
};
var $Hanf_arg842247047 = function(anf_arg44347041,INDENT118169,anf_arg43547042,anf_arg43647043,anf_arg43747044,anf_arg43847045,anf_fun43447046,if_helper32347027) {
var $z4708647087 = D;
var $f4709247093 = function(_) {
return R.isFunction(anf_fun43447046)?anf_fun43447046.app(INDENT118169,(0),anf_arg43547042,anf_arg43647043,anf_arg43747044,anf_arg43847045,anf_arg44347041):R.ffi.throwNonFunApp(L[4828],anf_fun43447046,[INDENT118169,(0),anf_arg43547042,anf_arg43647043,anf_arg43747044,anf_arg43847045,anf_arg44347041]);
};
try {
if(--R.GAS > 0) {
$z4708647087 = $f4709247093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4709247093,
"from":L[4828]});
}
} catch($e4708447085) {
if(R.isCont($e4708447085)) {
var $ss4708847089 = {"from":L[4828],
"go":function(cont_tail_arg44447094) {
return $Hcont_tail_arg842147095(cont_tail_arg44447094,if_helper32347027);
}};
$e4708447085.stack[R.EXN_STACKHEIGHT++] = $ss4708847089;
}
if(R.isPyretException($e4708447085)) {
$e4708447085.pyretStack.push(L[4828]);
}
throw $e4708447085;
}
var $ret4709047091 = $Hcont_tail_arg842147095($z4708647087,if_helper32347027);
++R.GAS;
return $ret4709047091;
};
var $Hcont_tail_arg842147095 = function(cont_tail_arg44447094,if_helper32347027) {
if(--R.GAS > 0) {
$z4709647097 = R.isFunction(if_helper32347027)?if_helper32347027.app(cont_tail_arg44447094):R.ffi.throwNonFunApp(L[4828],if_helper32347027,[cont_tail_arg44447094]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper32347027)?if_helper32347027.app(cont_tail_arg44447094):R.ffi.throwNonFunApp(L[4828],if_helper32347027,[cont_tail_arg44447094]);
},
"from":L[4828]});
}
++R.GAS;
return $z4709647097;
};
var $Hann_DASH_check_DASH_temp842047061 = function(ann_DASH_check_DASH_temp44047060) {
return ann_DASH_check_DASH_temp44047060;
};
var $Hanf_arg841947083 = function(anf_arg32947079,INDENT118169,PP170,PP278,_check54318536,anf_fun32547080,anf_fun32647081,ann54018533,args53918532,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58) {
var anf_arg33047111 = G(PP170,"lparen",L[4835]);
var anf_arg33147112 = G(PP170,"commabreak",L[4834]);
var anf_arg33247113 = G(PP170,"rparen",L[4833]);
var anf_fun33347108 = G(args53918532,"map",L[4832]);
var anf_arg33647109 = R.makeFunction(function(a54647115) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4830],1,arguments);
}
var anf_fun33547126 = G(a54647115,"tosource",L[4831]);
var $z4711847119 = D;
var $f4712447125 = function(_) {
return R.isFunction(anf_fun33547126)?anf_fun33547126.app():R.ffi.throwNonFunApp(L[4830],anf_fun33547126,[]);
};
try {
if(--R.GAS > 0) {
$z4711847119 = $f4712447125();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4712447125,
"from":L[4830]});
}
} catch($e4711647117) {
if(R.isCont($e4711647117)) {
var $ss4712047121 = {"from":L[4830],
"go":function(ann_DASH_check_DASH_temp33447127) {
return $Hann_DASH_check_DASH_temp838147128(ann_DASH_check_DASH_temp33447127);
}};
$e4711647117.stack[R.EXN_STACKHEIGHT++] = $ss4712047121;
}
if(R.isPyretException($e4711647117)) {
$e4711647117.pyretStack.push(L[4830]);
}
throw $e4711647117;
}
var $ret4712247123 = $Hann_DASH_check_DASH_temp838147128($z4711847119);
++R.GAS;
return $ret4712247123;
});
var $z4710047101 = D;
var $f4710647107 = function(_) {
return R.isFunction(anf_fun33347108)?anf_fun33347108.app(anf_arg33647109):R.ffi.throwNonFunApp(L[4829],anf_fun33347108,[anf_arg33647109]);
};
try {
if(--R.GAS > 0) {
$z4710047101 = $f4710647107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4710647107,
"from":L[4829]});
}
} catch($e4709847099) {
if(R.isCont($e4709847099)) {
var $ss4710247103 = {"from":L[4829],
"go":function(anf_arg33747110) {
return $Hanf_arg841847114(anf_arg33747110,INDENT118169,PP170,PP278,_check54318536,anf_arg32947079,anf_arg33047111,anf_arg33147112,anf_arg33247113,anf_fun32547080,anf_fun32647081,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58);
}};
$e4709847099.stack[R.EXN_STACKHEIGHT++] = $ss4710247103;
}
if(R.isPyretException($e4709847099)) {
$e4709847099.pyretStack.push(L[4829]);
}
throw $e4709847099;
}
var $ret4710447105 = $Hanf_arg841847114($z4710047101,INDENT118169,PP170,PP278,_check54318536,anf_arg32947079,anf_arg33047111,anf_arg33147112,anf_arg33247113,anf_fun32547080,anf_fun32647081,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4710447105;
};
var $Hanf_arg841847114 = function(anf_arg33747110,INDENT118169,PP170,PP278,_check54318536,anf_arg32947079,anf_arg33047111,anf_arg33147112,anf_arg33247113,anf_fun32547080,anf_fun32647081,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58) {
var $z4713147132 = D;
var $f4713747138 = function(_) {
return R.isFunction(anf_fun32647081)?anf_fun32647081.app(INDENT118169,(0),anf_arg32947079,anf_arg33047111,anf_arg33147112,anf_arg33247113,anf_arg33747110):R.ffi.throwNonFunApp(L[4836],anf_fun32647081,[INDENT118169,(0),anf_arg32947079,anf_arg33047111,anf_arg33147112,anf_arg33247113,anf_arg33747110]);
};
try {
if(--R.GAS > 0) {
$z4713147132 = $f4713747138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4713747138,
"from":L[4836]});
}
} catch($e4712947130) {
if(R.isCont($e4712947130)) {
var $ss4713347134 = {"from":L[4836],
"go":function(anf_arg33847139) {
return $Hanf_arg841747140(anf_arg33847139,INDENT118169,PP170,PP278,_check54318536,anf_fun32547080,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58);
}};
$e4712947130.stack[R.EXN_STACKHEIGHT++] = $ss4713347134;
}
if(R.isPyretException($e4712947130)) {
$e4712947130.pyretStack.push(L[4836]);
}
throw $e4712947130;
}
var $ret4713547136 = $Hanf_arg841747140($z4713147132,INDENT118169,PP170,PP278,_check54318536,anf_fun32547080,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4713547136;
};
var $Hanf_arg841747140 = function(anf_arg33847139,INDENT118169,PP170,PP278,_check54318536,anf_fun32547080,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58) {
var $z4714347144 = D;
var $f4714947150 = function(_) {
return R.isFunction(anf_fun32547080)?anf_fun32547080.app(INDENT118169,anf_arg33847139):R.ffi.throwNonFunApp(L[4837],anf_fun32547080,[INDENT118169,anf_arg33847139]);
};
try {
if(--R.GAS > 0) {
$z4714347144 = $f4714947150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4714947150,
"from":L[4837]});
}
} catch($e4714147142) {
if(R.isCont($e4714147142)) {
var $ss4714547146 = {"from":L[4837],
"go":function(arg_DASH_list54547151) {
return $Harg_DASH_list841647152(arg_DASH_list54547151,INDENT118169,PP170,PP278,_check54318536,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58);
}};
$e4714147142.stack[R.EXN_STACKHEIGHT++] = $ss4714547146;
}
if(R.isPyretException($e4714147142)) {
$e4714147142.pyretStack.push(L[4837]);
}
throw $e4714147142;
}
var $ret4714747148 = $Harg_DASH_list841647152($z4714347144,INDENT118169,PP170,PP278,_check54318536,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4714747148;
};
var $Harg_DASH_list841647152 = function(arg_DASH_list54547151,INDENT118169,PP170,PP278,_check54318536,ann54018533,body54218535,break_DASH_one119168,doc54118534,funtype53618529,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,typarams54447082,_plus55,is_DASH_nothing58) {
var $z4715547156 = D;
var $f4716147162 = function(_) {
return R.isFunction(_plus55)?_plus55.app(funtype53618529,typarams54447082):R.ffi.throwNonFunApp(L[4838],_plus55,[funtype53618529,typarams54447082]);
};
try {
if(--R.GAS > 0) {
$z4715547156 = $f4716147162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4716147162,
"from":L[4838]});
}
} catch($e4715347154) {
if(R.isCont($e4715347154)) {
var $ss4715747158 = {"from":L[4838],
"go":function(ftype54747163) {
return $Hftype841547164(ftype54747163,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4715347154.stack[R.EXN_STACKHEIGHT++] = $ss4715747158;
}
if(R.isPyretException($e4715347154)) {
$e4715347154.pyretStack.push(L[4838]);
}
throw $e4715347154;
}
var $ret4715947160 = $Hftype841547164($z4715547156,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4715947160;
};
var $Hftype841547164 = function(ftype54747163,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var $z4716747168 = D;
var $f4717347174 = function(_) {
return R.isFunction(is_DASH_nothing58)?is_DASH_nothing58.app(name53718530):R.ffi.throwNonFunApp(L[4839],is_DASH_nothing58,[name53718530]);
};
try {
if(--R.GAS > 0) {
$z4716747168 = $f4717347174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4717347174,
"from":L[4839]});
}
} catch($e4716547166) {
if(R.isCont($e4716547166)) {
var $ss4716947170 = {"from":L[4839],
"go":function(if_DASH_3547175) {
return $Hif_DASH_841447176(if_DASH_3547175,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,ftype54747163,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4716547166.stack[R.EXN_STACKHEIGHT++] = $ss4716947170;
}
if(R.isPyretException($e4716547166)) {
$e4716547166.pyretStack.push(L[4839]);
}
throw $e4716547166;
}
var $ret4717147172 = $Hif_DASH_841447176($z4716747168,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,ftype54747163,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4717147172;
};
var $Hif_DASH_841447176 = function(if_DASH_3547175,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,ftype54747163,is_DASH_a_DASH_blank5062313,name53718530,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var if_helper33947187 = R.makeFunction(function(if_helper_arg34047207) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4839],1,arguments);
}
var fname54847219 = if_helper_arg34047207;
var $z4721047211 = D;
var $f4721647217 = function(_) {
return R.isFunction(is_DASH_a_DASH_blank5062313.$var === D?U(L[4843],"is-a-blank"):is_DASH_a_DASH_blank5062313.$var)?is_DASH_a_DASH_blank5062313.$var === D?U(L[4843],"is-a-blank"):is_DASH_a_DASH_blank5062313.$var.app(ann54018533):R.ffi.throwNonFunApp(L[4844],is_DASH_a_DASH_blank5062313.$var === D?U(L[4843],"is-a-blank"):is_DASH_a_DASH_blank5062313.$var,[ann54018533]);
};
try {
if(--R.GAS > 0) {
$z4721047211 = $f4721647217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4721647217,
"from":L[4844]});
}
} catch($e4720847209) {
if(R.isCont($e4720847209)) {
var $ss4721247213 = {"from":L[4844],
"go":function(or_DASH_oper_DASH_3747218) {
return $Hor_DASH_oper_DASH_840747220(or_DASH_oper_DASH_3747218,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,fname54847219,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4720847209.stack[R.EXN_STACKHEIGHT++] = $ss4721247213;
}
if(R.isPyretException($e4720847209)) {
$e4720847209.pyretStack.push(L[4844]);
}
throw $e4720847209;
}
var $ret4721447215 = $Hor_DASH_oper_DASH_840747220($z4721047211,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,fname54847219,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4721447215;
});
var anf_if41747206 = R.isBoolean(if_DASH_3547175);
if(R.isPyretTrue(anf_if41747206)) {
if(R.isPyretTrue(if_DASH_3547175)) {
var $z4717947180 = D;
var $f4718547186 = function(_) {
return R.isFunction(if_helper33947187)?if_helper33947187.app(ftype54747163):R.ffi.throwNonFunApp(L[4840],if_helper33947187,[ftype54747163]);
};
try {
if(--R.GAS > 0) {
$z4717947180 = $f4718547186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4718547186,
"from":L[4840]});
}
} catch($e4717747178) {
if(R.isCont($e4717747178)) {
var $ss4718147182 = {"from":L[4840],
"go":function(cont_tail_app43047188) {
return $Hcont_tail_app840847189(cont_tail_app43047188);
}};
$e4717747178.stack[R.EXN_STACKHEIGHT++] = $ss4718147182;
}
if(R.isPyretException($e4717747178)) {
$e4717747178.pyretStack.push(L[4840]);
}
throw $e4717747178;
}
var $ret4718347184 = $Hcont_tail_app840847189($z4717947180);
++R.GAS;
return $ret4718347184;
} else {
var anf_fun41847200 = G(PP170,"is-mt-doc",L[4842]);
var $z4719247193 = D;
var $f4719847199 = function(_) {
return R.isFunction(anf_fun41847200)?anf_fun41847200.app(ftype54747163):R.ffi.throwNonFunApp(L[4841],anf_fun41847200,[ftype54747163]);
};
try {
if(--R.GAS > 0) {
$z4719247193 = $f4719847199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4719847199,
"from":L[4841]});
}
} catch($e4719047191) {
if(R.isCont($e4719047191)) {
var $ss4719447195 = {"from":L[4841],
"go":function(if_DASH_3447201) {
return $Hif_DASH_841347202(if_DASH_3447201,PP170,ftype54747163,if_helper33947187,name53718530,_plus55);
}};
$e4719047191.stack[R.EXN_STACKHEIGHT++] = $ss4719447195;
}
if(R.isPyretException($e4719047191)) {
$e4719047191.pyretStack.push(L[4841]);
}
throw $e4719047191;
}
var $ret4719647197 = $Hif_DASH_841347202($z4719247193,PP170,ftype54747163,if_helper33947187,name53718530,_plus55);
++R.GAS;
return $ret4719647197;
}
} else {
var cont_tail_arg41547205 = R.throwNonBooleanCondition(L[4839],("if"),if_DASH_3547175);
if(--R.GAS > 0) {
$z4720347204 = R.isFunction(if_helper33947187)?if_helper33947187.app(cont_tail_arg41547205):R.ffi.throwNonFunApp(L[4839],if_helper33947187,[cont_tail_arg41547205]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper33947187)?if_helper33947187.app(cont_tail_arg41547205):R.ffi.throwNonFunApp(L[4839],if_helper33947187,[cont_tail_arg41547205]);
},
"from":L[4839]});
}
++R.GAS;
return $z4720347204;
}
};
var $Hcont_tail_app840847189 = function(cont_tail_app43047188) {
return cont_tail_app43047188;
};
var $Hif_DASH_841347202 = function(if_DASH_3447201,PP170,ftype54747163,if_helper33947187,name53718530,_plus55) {
var anf_if42147250 = R.isBoolean(if_DASH_3447201);
if(R.isPyretTrue(anf_if42147250)) {
if(R.isPyretTrue(if_DASH_3447201)) {
var anf_fun42747231 = G(PP170,"str",L[4846]);
var $z4722347224 = D;
var $f4722947230 = function(_) {
return R.isFunction(anf_fun42747231)?anf_fun42747231.app(name53718530):R.ffi.throwNonFunApp(L[4845],anf_fun42747231,[name53718530]);
};
try {
if(--R.GAS > 0) {
$z4722347224 = $f4722947230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4722947230,
"from":L[4845]});
}
} catch($e4722147222) {
if(R.isCont($e4722147222)) {
var $ss4722547226 = {"from":L[4845],
"go":function(cont_tail_arg42847232) {
return $Hcont_tail_arg840947233(cont_tail_arg42847232,if_helper33947187);
}};
$e4722147222.stack[R.EXN_STACKHEIGHT++] = $ss4722547226;
}
if(R.isPyretException($e4722147222)) {
$e4722147222.pyretStack.push(L[4845]);
}
throw $e4722147222;
}
var $ret4722747228 = $Hcont_tail_arg840947233($z4722347224,if_helper33947187);
++R.GAS;
return $ret4722747228;
} else {
var anf_fun42247245 = G(PP170,"str",L[4848]);
var $z4723647237 = D;
var $f4724247243 = function(_) {
return R.isFunction(_plus55)?_plus55.app((" "),name53718530):R.ffi.throwNonFunApp(L[4847],_plus55,[(" "),name53718530]);
};
try {
if(--R.GAS > 0) {
$z4723647237 = $f4724247243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4724247243,
"from":L[4847]});
}
} catch($e4723447235) {
if(R.isCont($e4723447235)) {
var $ss4723847239 = {"from":L[4847],
"go":function(anf_arg42347244) {
return $Hanf_arg841247246(anf_arg42347244,anf_fun42247245,ftype54747163,if_helper33947187,_plus55);
}};
$e4723447235.stack[R.EXN_STACKHEIGHT++] = $ss4723847239;
}
if(R.isPyretException($e4723447235)) {
$e4723447235.pyretStack.push(L[4847]);
}
throw $e4723447235;
}
var $ret4724047241 = $Hanf_arg841247246($z4723647237,anf_fun42247245,ftype54747163,if_helper33947187,_plus55);
++R.GAS;
return $ret4724047241;
}
} else {
var cont_tail_arg41947249 = R.throwNonBooleanCondition(L[4849],("if"),if_DASH_3447201);
if(--R.GAS > 0) {
$z4724747248 = R.isFunction(if_helper33947187)?if_helper33947187.app(cont_tail_arg41947249):R.ffi.throwNonFunApp(L[4849],if_helper33947187,[cont_tail_arg41947249]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper33947187)?if_helper33947187.app(cont_tail_arg41947249):R.ffi.throwNonFunApp(L[4849],if_helper33947187,[cont_tail_arg41947249]);
},
"from":L[4849]});
}
++R.GAS;
return $z4724747248;
}
};
var $Hcont_tail_arg840947233 = function(cont_tail_arg42847232,if_helper33947187) {
if(--R.GAS > 0) {
$z4725147252 = R.isFunction(if_helper33947187)?if_helper33947187.app(cont_tail_arg42847232):R.ffi.throwNonFunApp(L[4845],if_helper33947187,[cont_tail_arg42847232]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper33947187)?if_helper33947187.app(cont_tail_arg42847232):R.ffi.throwNonFunApp(L[4845],if_helper33947187,[cont_tail_arg42847232]);
},
"from":L[4845]});
}
++R.GAS;
return $z4725147252;
};
var $Hanf_arg841247246 = function(anf_arg42347244,anf_fun42247245,ftype54747163,if_helper33947187,_plus55) {
var $z4725547256 = D;
var $f4726147262 = function(_) {
return R.isFunction(anf_fun42247245)?anf_fun42247245.app(anf_arg42347244):R.ffi.throwNonFunApp(L[4850],anf_fun42247245,[anf_arg42347244]);
};
try {
if(--R.GAS > 0) {
$z4725547256 = $f4726147262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4726147262,
"from":L[4850]});
}
} catch($e4725347254) {
if(R.isCont($e4725347254)) {
var $ss4725747258 = {"from":L[4850],
"go":function(anf_arg42447263) {
return $Hanf_arg841147264(anf_arg42447263,ftype54747163,if_helper33947187,_plus55);
}};
$e4725347254.stack[R.EXN_STACKHEIGHT++] = $ss4725747258;
}
if(R.isPyretException($e4725347254)) {
$e4725347254.pyretStack.push(L[4850]);
}
throw $e4725347254;
}
var $ret4725947260 = $Hanf_arg841147264($z4725547256,ftype54747163,if_helper33947187,_plus55);
++R.GAS;
return $ret4725947260;
};
var $Hanf_arg841147264 = function(anf_arg42447263,ftype54747163,if_helper33947187,_plus55) {
var $z4726747268 = D;
var $f4727347274 = function(_) {
return R.isFunction(_plus55)?_plus55.app(ftype54747163,anf_arg42447263):R.ffi.throwNonFunApp(L[4851],_plus55,[ftype54747163,anf_arg42447263]);
};
try {
if(--R.GAS > 0) {
$z4726747268 = $f4727347274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4727347274,
"from":L[4851]});
}
} catch($e4726547266) {
if(R.isCont($e4726547266)) {
var $ss4726947270 = {"from":L[4851],
"go":function(cont_tail_arg42547275) {
return $Hcont_tail_arg841047276(cont_tail_arg42547275,if_helper33947187);
}};
$e4726547266.stack[R.EXN_STACKHEIGHT++] = $ss4726947270;
}
if(R.isPyretException($e4726547266)) {
$e4726547266.pyretStack.push(L[4851]);
}
throw $e4726547266;
}
var $ret4727147272 = $Hcont_tail_arg841047276($z4726747268,if_helper33947187);
++R.GAS;
return $ret4727147272;
};
var $Hcont_tail_arg841047276 = function(cont_tail_arg42547275,if_helper33947187) {
if(--R.GAS > 0) {
$z4727747278 = R.isFunction(if_helper33947187)?if_helper33947187.app(cont_tail_arg42547275):R.ffi.throwNonFunApp(L[4851],if_helper33947187,[cont_tail_arg42547275]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper33947187)?if_helper33947187.app(cont_tail_arg42547275):R.ffi.throwNonFunApp(L[4851],if_helper33947187,[cont_tail_arg42547275]);
},
"from":L[4851]});
}
++R.GAS;
return $z4727747278;
};
var $Hor_DASH_oper_DASH_840747220 = function(or_DASH_oper_DASH_3747218,INDENT118169,PP170,PP278,_check54318536,ann54018533,arg_DASH_list54547151,body54218535,break_DASH_one119168,doc54118534,fname54847219,str_DASH_arrowspace122208,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var if_helper34147289 = R.makeFunction(function(if_helper_arg34247308) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4844],1,arguments);
}
var if_DASH_3647325 = if_helper_arg34247308;
var if_helper34347311 = R.makeFunction(function(if_helper_arg34447330) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4844],1,arguments);
}
var fann54947343 = if_helper_arg34447330;
var anf_fun34547342 = G(PP170,"group",L[4856]);
var $z4733347334 = D;
var $f4733947340 = function(_) {
return R.isFunction(_plus55)?_plus55.app(fname54847219,arg_DASH_list54547151):R.ffi.throwNonFunApp(L[4855],_plus55,[fname54847219,arg_DASH_list54547151]);
};
try {
if(--R.GAS > 0) {
$z4733347334 = $f4733947340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4733947340,
"from":L[4855]});
}
} catch($e4733147332) {
if(R.isCont($e4733147332)) {
var $ss4733547336 = {"from":L[4855],
"go":function(anf_arg34647341) {
return $Hanf_arg840047344(anf_arg34647341,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,fann54947343,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4733147332.stack[R.EXN_STACKHEIGHT++] = $ss4733547336;
}
if(R.isPyretException($e4733147332)) {
$e4733147332.pyretStack.push(L[4855]);
}
throw $e4733147332;
}
var $ret4733747338 = $Hanf_arg840047344($z4733347334,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,fann54947343,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4733747338;
});
var anf_if39947329 = R.isBoolean(if_DASH_3647325);
if(R.isPyretTrue(anf_if39947329)) {
if(R.isPyretTrue(if_DASH_3647325)) {
var cont_tail_arg40547312 = G(PP170,"mt-doc",L[4853]);
if(--R.GAS > 0) {
$z4730947310 = R.isFunction(if_helper34347311)?if_helper34347311.app(cont_tail_arg40547312):R.ffi.throwNonFunApp(L[4853],if_helper34347311,[cont_tail_arg40547312]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper34347311)?if_helper34347311.app(cont_tail_arg40547312):R.ffi.throwNonFunApp(L[4853],if_helper34347311,[cont_tail_arg40547312]);
},
"from":L[4853]});
}
++R.GAS;
return $z4730947310;
} else {
var $z4731547316 = D;
var $f4732147322 = function(_) {
return R.isFunction(_plus55)?_plus55.app(break_DASH_one119168,str_DASH_arrowspace122208):R.ffi.throwNonFunApp(L[4854],_plus55,[break_DASH_one119168,str_DASH_arrowspace122208]);
};
try {
if(--R.GAS > 0) {
$z4731547316 = $f4732147322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4732147322,
"from":L[4854]});
}
} catch($e4731347314) {
if(R.isCont($e4731347314)) {
var $ss4731747318 = {"from":L[4854],
"go":function(anf_arg40047323) {
return $Hanf_arg840347324(anf_arg40047323,ann54018533,if_helper34347311,_plus55);
}};
$e4731347314.stack[R.EXN_STACKHEIGHT++] = $ss4731747318;
}
if(R.isPyretException($e4731347314)) {
$e4731347314.pyretStack.push(L[4854]);
}
throw $e4731347314;
}
var $ret4731947320 = $Hanf_arg840347324($z4731547316,ann54018533,if_helper34347311,_plus55);
++R.GAS;
return $ret4731947320;
}
} else {
var cont_tail_arg39747328 = R.throwNonBooleanCondition(L[4844],("if"),if_DASH_3647325);
if(--R.GAS > 0) {
$z4732647327 = R.isFunction(if_helper34347311)?if_helper34347311.app(cont_tail_arg39747328):R.ffi.throwNonFunApp(L[4844],if_helper34347311,[cont_tail_arg39747328]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper34347311)?if_helper34347311.app(cont_tail_arg39747328):R.ffi.throwNonFunApp(L[4844],if_helper34347311,[cont_tail_arg39747328]);
},
"from":L[4844]});
}
++R.GAS;
return $z4732647327;
}
});
var anf_if40947307 = R.isBoolean(or_DASH_oper_DASH_3747218);
if(R.isPyretTrue(anf_if40947307)) {
if(R.isPyretTrue(or_DASH_oper_DASH_3747218)) {
var $z4728147282 = D;
var $f4728747288 = function(_) {
return R.isFunction(if_helper34147289)?if_helper34147289.app((true)):R.ffi.throwNonFunApp(L[4844],if_helper34147289,[(true)]);
};
try {
if(--R.GAS > 0) {
$z4728147282 = $f4728747288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4728747288,
"from":L[4844]});
}
} catch($e4727947280) {
if(R.isCont($e4727947280)) {
var $ss4728347284 = {"from":L[4844],
"go":function(cont_tail_app41447290) {
return $Hcont_tail_app840447291(cont_tail_app41447290);
}};
$e4727947280.stack[R.EXN_STACKHEIGHT++] = $ss4728347284;
}
if(R.isPyretException($e4727947280)) {
$e4727947280.pyretStack.push(L[4844]);
}
throw $e4727947280;
}
var $ret4728547286 = $Hcont_tail_app840447291($z4728147282);
++R.GAS;
return $ret4728547286;
} else {
var $z4729447295 = D;
var $f4730047301 = function(_) {
return R.isFunction(is_DASH_nothing58)?is_DASH_nothing58.app(ann54018533):R.ffi.throwNonFunApp(L[4844],is_DASH_nothing58,[ann54018533]);
};
try {
if(--R.GAS > 0) {
$z4729447295 = $f4730047301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4730047301,
"from":L[4844]});
}
} catch($e4729247293) {
if(R.isCont($e4729247293)) {
var $ss4729647297 = {"from":L[4844],
"go":function(or_DASH_oper_DASH_3847302) {
return $Hor_DASH_oper_DASH_840647303(or_DASH_oper_DASH_3847302,if_helper34147289);
}};
$e4729247293.stack[R.EXN_STACKHEIGHT++] = $ss4729647297;
}
if(R.isPyretException($e4729247293)) {
$e4729247293.pyretStack.push(L[4844]);
}
throw $e4729247293;
}
var $ret4729847299 = $Hor_DASH_oper_DASH_840647303($z4729447295,if_helper34147289);
++R.GAS;
return $ret4729847299;
}
} else {
var cont_tail_arg40747306 = R.throwNonBooleanOp(L[4852],("first"),("or"),or_DASH_oper_DASH_3747218);
if(--R.GAS > 0) {
$z4730447305 = R.isFunction(if_helper34147289)?if_helper34147289.app(cont_tail_arg40747306):R.ffi.throwNonFunApp(L[4852],if_helper34147289,[cont_tail_arg40747306]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper34147289)?if_helper34147289.app(cont_tail_arg40747306):R.ffi.throwNonFunApp(L[4852],if_helper34147289,[cont_tail_arg40747306]);
},
"from":L[4852]});
}
++R.GAS;
return $z4730447305;
}
};
var $Hcont_tail_app840447291 = function(cont_tail_app41447290) {
return cont_tail_app41447290;
};
var $Hor_DASH_oper_DASH_840647303 = function(or_DASH_oper_DASH_3847302,if_helper34147289) {
var anf_if41247360 = R.isBoolean(or_DASH_oper_DASH_3847302);
if(R.isPyretTrue(anf_if41247360)) {
var $z4734747348 = D;
var $f4735347354 = function(_) {
return R.isFunction(if_helper34147289)?if_helper34147289.app(or_DASH_oper_DASH_3847302):R.ffi.throwNonFunApp(L[4844],if_helper34147289,[or_DASH_oper_DASH_3847302]);
};
try {
if(--R.GAS > 0) {
$z4734747348 = $f4735347354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4735347354,
"from":L[4844]});
}
} catch($e4734547346) {
if(R.isCont($e4734547346)) {
var $ss4734947350 = {"from":L[4844],
"go":function(cont_tail_app41347355) {
return $Hcont_tail_app840547356(cont_tail_app41347355);
}};
$e4734547346.stack[R.EXN_STACKHEIGHT++] = $ss4734947350;
}
if(R.isPyretException($e4734547346)) {
$e4734547346.pyretStack.push(L[4844]);
}
throw $e4734547346;
}
var $ret4735147352 = $Hcont_tail_app840547356($z4734747348);
++R.GAS;
return $ret4735147352;
} else {
var cont_tail_arg41047359 = R.throwNonBooleanOp(L[4857],("second"),("or"),or_DASH_oper_DASH_3847302);
if(--R.GAS > 0) {
$z4735747358 = R.isFunction(if_helper34147289)?if_helper34147289.app(cont_tail_arg41047359):R.ffi.throwNonFunApp(L[4857],if_helper34147289,[cont_tail_arg41047359]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper34147289)?if_helper34147289.app(cont_tail_arg41047359):R.ffi.throwNonFunApp(L[4857],if_helper34147289,[cont_tail_arg41047359]);
},
"from":L[4857]});
}
++R.GAS;
return $z4735747358;
}
};
var $Hcont_tail_app840547356 = function(cont_tail_app41347355) {
return cont_tail_app41347355;
};
var $Hanf_arg840347324 = function(anf_arg40047323,ann54018533,if_helper34347311,_plus55) {
var anf_fun40147371 = G(ann54018533,"tosource",L[4859]);
var $z4736347364 = D;
var $f4736947370 = function(_) {
return R.isFunction(anf_fun40147371)?anf_fun40147371.app():R.ffi.throwNonFunApp(L[4858],anf_fun40147371,[]);
};
try {
if(--R.GAS > 0) {
$z4736347364 = $f4736947370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4736947370,
"from":L[4858]});
}
} catch($e4736147362) {
if(R.isCont($e4736147362)) {
var $ss4736547366 = {"from":L[4858],
"go":function(anf_arg40247372) {
return $Hanf_arg840247373(anf_arg40247372,anf_arg40047323,if_helper34347311,_plus55);
}};
$e4736147362.stack[R.EXN_STACKHEIGHT++] = $ss4736547366;
}
if(R.isPyretException($e4736147362)) {
$e4736147362.pyretStack.push(L[4858]);
}
throw $e4736147362;
}
var $ret4736747368 = $Hanf_arg840247373($z4736347364,anf_arg40047323,if_helper34347311,_plus55);
++R.GAS;
return $ret4736747368;
};
var $Hanf_arg840247373 = function(anf_arg40247372,anf_arg40047323,if_helper34347311,_plus55) {
var $z4737647377 = D;
var $f4738247383 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg40047323,anf_arg40247372):R.ffi.throwNonFunApp(L[4854],_plus55,[anf_arg40047323,anf_arg40247372]);
};
try {
if(--R.GAS > 0) {
$z4737647377 = $f4738247383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4738247383,
"from":L[4854]});
}
} catch($e4737447375) {
if(R.isCont($e4737447375)) {
var $ss4737847379 = {"from":L[4854],
"go":function(cont_tail_arg40347384) {
return $Hcont_tail_arg840147385(cont_tail_arg40347384,if_helper34347311);
}};
$e4737447375.stack[R.EXN_STACKHEIGHT++] = $ss4737847379;
}
if(R.isPyretException($e4737447375)) {
$e4737447375.pyretStack.push(L[4854]);
}
throw $e4737447375;
}
var $ret4738047381 = $Hcont_tail_arg840147385($z4737647377,if_helper34347311);
++R.GAS;
return $ret4738047381;
};
var $Hcont_tail_arg840147385 = function(cont_tail_arg40347384,if_helper34347311) {
if(--R.GAS > 0) {
$z4738647387 = R.isFunction(if_helper34347311)?if_helper34347311.app(cont_tail_arg40347384):R.ffi.throwNonFunApp(L[4854],if_helper34347311,[cont_tail_arg40347384]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper34347311)?if_helper34347311.app(cont_tail_arg40347384):R.ffi.throwNonFunApp(L[4854],if_helper34347311,[cont_tail_arg40347384]);
},
"from":L[4854]});
}
++R.GAS;
return $z4738647387;
};
var $Hanf_arg840047344 = function(anf_arg34647341,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,fann54947343,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var $z4739047391 = D;
var $f4739647397 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg34647341,fann54947343):R.ffi.throwNonFunApp(L[4855],_plus55,[anf_arg34647341,fann54947343]);
};
try {
if(--R.GAS > 0) {
$z4739047391 = $f4739647397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4739647397,
"from":L[4855]});
}
} catch($e4738847389) {
if(R.isCont($e4738847389)) {
var $ss4739247393 = {"from":L[4855],
"go":function(anf_arg34747398) {
return $Hanf_arg839947399(anf_arg34747398,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4738847389.stack[R.EXN_STACKHEIGHT++] = $ss4739247393;
}
if(R.isPyretException($e4738847389)) {
$e4738847389.pyretStack.push(L[4855]);
}
throw $e4738847389;
}
var $ret4739447395 = $Hanf_arg839947399($z4739047391,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4739447395;
};
var $Hanf_arg839947399 = function(anf_arg34747398,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,str_DASH_colon134364,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var $z4740247403 = D;
var $f4740847409 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg34747398,str_DASH_colon134364):R.ffi.throwNonFunApp(L[4855],_plus55,[anf_arg34747398,str_DASH_colon134364]);
};
try {
if(--R.GAS > 0) {
$z4740247403 = $f4740847409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4740847409,
"from":L[4855]});
}
} catch($e4740047401) {
if(R.isCont($e4740047401)) {
var $ss4740447405 = {"from":L[4855],
"go":function(anf_arg34847410) {
return $Hanf_arg839847411(anf_arg34847410,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4740047401.stack[R.EXN_STACKHEIGHT++] = $ss4740447405;
}
if(R.isPyretException($e4740047401)) {
$e4740047401.pyretStack.push(L[4855]);
}
throw $e4740047401;
}
var $ret4740647407 = $Hanf_arg839847411($z4740247403,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4740647407;
};
var $Hanf_arg839847411 = function(anf_arg34847410,INDENT118169,PP170,PP278,_check54318536,anf_fun34547342,body54218535,doc54118534,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var $z4741447415 = D;
var $f4742047421 = function(_) {
return R.isFunction(anf_fun34547342)?anf_fun34547342.app(anf_arg34847410):R.ffi.throwNonFunApp(L[4860],anf_fun34547342,[anf_arg34847410]);
};
try {
if(--R.GAS > 0) {
$z4741447415 = $f4742047421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4742047421,
"from":L[4860]});
}
} catch($e4741247413) {
if(R.isCont($e4741247413)) {
var $ss4741647417 = {"from":L[4860],
"go":function(header55047422) {
return $Hheader839747423(header55047422,INDENT118169,PP170,PP278,_check54318536,body54218535,doc54118534,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4741247413.stack[R.EXN_STACKHEIGHT++] = $ss4741647417;
}
if(R.isPyretException($e4741247413)) {
$e4741247413.pyretStack.push(L[4860]);
}
throw $e4741247413;
}
var $ret4741847419 = $Hheader839747423($z4741447415,INDENT118169,PP170,PP278,_check54318536,body54218535,doc54118534,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4741847419;
};
var $Hheader839747423 = function(header55047422,INDENT118169,PP170,PP278,_check54318536,body54218535,doc54118534,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var cases_DASH_val3947457 = _check54318536;
var anf_fun34947434 = G(cases_DASH_val3947457,"_match",L[4862]);
var anf_obj35147440 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4865],0,arguments);
}
var ann_DASH_check_DASH_temp35047456 = G(PP170,"mt-doc",L[4866]);
return ann_DASH_check_DASH_temp35047456;
});
var anf_obj35447441 = R.makeFunction(function(chk55247442) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4863],1,arguments);
}
var anf_fun35347453 = G(chk55247442,"tosource",L[4864]);
var $z4744547446 = D;
var $f4745147452 = function(_) {
return R.isFunction(anf_fun35347453)?anf_fun35347453.app():R.ffi.throwNonFunApp(L[4863],anf_fun35347453,[]);
};
try {
if(--R.GAS > 0) {
$z4744547446 = $f4745147452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4745147452,
"from":L[4863]});
}
} catch($e4744347444) {
if(R.isCont($e4744347444)) {
var $ss4744747448 = {"from":L[4863],
"go":function(ann_DASH_check_DASH_temp35247454) {
return $Hann_DASH_check_DASH_temp838247455(ann_DASH_check_DASH_temp35247454);
}};
$e4744347444.stack[R.EXN_STACKHEIGHT++] = $ss4744747448;
}
if(R.isPyretException($e4744347444)) {
$e4744347444.pyretStack.push(L[4863]);
}
throw $e4744347444;
}
var $ret4744947450 = $Hann_DASH_check_DASH_temp838247455($z4744547446);
++R.GAS;
return $ret4744947450;
});
var anf_arg35547435 = R.makeObject({"none":anf_obj35147440,
"some":anf_obj35447441});
var anf_arg35747436 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[4862],0,arguments);
}
var ann_DASH_check_DASH_temp35647439 = R.throwNoBranchesMatched(L[4862],("cases"));
return ann_DASH_check_DASH_temp35647439;
});
var $z4742647427 = D;
var $f4743247433 = function(_) {
return R.isFunction(anf_fun34947434)?anf_fun34947434.app(anf_arg35547435,anf_arg35747436):R.ffi.throwNonFunApp(L[4861],anf_fun34947434,[anf_arg35547435,anf_arg35747436]);
};
try {
if(--R.GAS > 0) {
$z4742647427 = $f4743247433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4743247433,
"from":L[4861]});
}
} catch($e4742447425) {
if(R.isCont($e4742447425)) {
var $ss4742847429 = {"from":L[4861],
"go":function(checker55147437) {
return $Hchecker839647438(checker55147437,INDENT118169,PP170,PP278,body54218535,doc54118534,header55047422,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4742447425.stack[R.EXN_STACKHEIGHT++] = $ss4742847429;
}
if(R.isPyretException($e4742447425)) {
$e4742447425.pyretStack.push(L[4861]);
}
throw $e4742447425;
}
var $ret4743047431 = $Hchecker839647438($z4742647427,INDENT118169,PP170,PP278,body54218535,doc54118534,header55047422,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4743047431;
};
var $Hchecker839647438 = function(checker55147437,INDENT118169,PP170,PP278,body54218535,doc54118534,header55047422,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var anf_fun35847468 = G(PP170,"is-mt-doc",L[4868]);
var $z4746047461 = D;
var $f4746647467 = function(_) {
return R.isFunction(anf_fun35847468)?anf_fun35847468.app(checker55147437):R.ffi.throwNonFunApp(L[4867],anf_fun35847468,[checker55147437]);
};
try {
if(--R.GAS > 0) {
$z4746047461 = $f4746647467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4746647467,
"from":L[4867]});
}
} catch($e4745847459) {
if(R.isCont($e4745847459)) {
var $ss4746247463 = {"from":L[4867],
"go":function(if_DASH_4047469) {
return $Hif_DASH_839547470(if_DASH_4047469,INDENT118169,PP170,PP278,body54218535,checker55147437,doc54118534,header55047422,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
}};
$e4745847459.stack[R.EXN_STACKHEIGHT++] = $ss4746247463;
}
if(R.isPyretException($e4745847459)) {
$e4745847459.pyretStack.push(L[4867]);
}
throw $e4745847459;
}
var $ret4746447465 = $Hif_DASH_839547470($z4746047461,INDENT118169,PP170,PP278,body54218535,checker55147437,doc54118534,header55047422,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58);
++R.GAS;
return $ret4746447465;
};
var $Hif_DASH_839547470 = function(if_DASH_4047469,INDENT118169,PP170,PP278,body54218535,checker55147437,doc54118534,header55047422,str_DASH_doc143481,str_DASH_end148546,str_DASH_where182988,_plus55,is_DASH_nothing58) {
var if_helper35947481 = R.makeFunction(function(if_helper_arg36047501) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4867],1,arguments);
}
var footer55347513 = if_helper_arg36047501;
var $z4750447505 = D;
var $f4751047511 = function(_) {
return R.isFunction(is_DASH_nothing58)?is_DASH_nothing58.app(doc54118534):R.ffi.throwNonFunApp(L[4872],is_DASH_nothing58,[doc54118534]);
};
try {
if(--R.GAS > 0) {
$z4750447505 = $f4751047511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4751047511,
"from":L[4872]});
}
} catch($e4750247503) {
if(R.isCont($e4750247503)) {
var $ss4750647507 = {"from":L[4872],
"go":function(or_DASH_oper_DASH_4247512) {
return $Hor_DASH_oper_DASH_839247514(or_DASH_oper_DASH_4247512,INDENT118169,PP170,PP278,body54218535,doc54118534,footer55347513,header55047422,str_DASH_doc143481,_plus55);
}};
$e4750247503.stack[R.EXN_STACKHEIGHT++] = $ss4750647507;
}
if(R.isPyretException($e4750247503)) {
$e4750247503.pyretStack.push(L[4872]);
}
throw $e4750247503;
}
var $ret4750847509 = $Hor_DASH_oper_DASH_839247514($z4750447505,INDENT118169,PP170,PP278,body54218535,doc54118534,footer55347513,header55047422,str_DASH_doc143481,_plus55);
++R.GAS;
return $ret4750847509;
});
var anf_if39247500 = R.isBoolean(if_DASH_4047469);
if(R.isPyretTrue(anf_if39247500)) {
if(R.isPyretTrue(if_DASH_4047469)) {
var $z4747347474 = D;
var $f4747947480 = function(_) {
return R.isFunction(if_helper35947481)?if_helper35947481.app(str_DASH_end148546):R.ffi.throwNonFunApp(L[4869],if_helper35947481,[str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4747347474 = $f4747947480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4747947480,
"from":L[4869]});
}
} catch($e4747147472) {
if(R.isCont($e4747147472)) {
var $ss4747547476 = {"from":L[4869],
"go":function(cont_tail_app39647482) {
return $Hcont_tail_app839347483(cont_tail_app39647482);
}};
$e4747147472.stack[R.EXN_STACKHEIGHT++] = $ss4747547476;
}
if(R.isPyretException($e4747147472)) {
$e4747147472.pyretStack.push(L[4869]);
}
throw $e4747147472;
}
var $ret4747747478 = $Hcont_tail_app839347483($z4747347474);
++R.GAS;
return $ret4747747478;
} else {
var anf_fun39347494 = G(PP170,"surround",L[4871]);
var $z4748647487 = D;
var $f4749247493 = function(_) {
return R.isFunction(anf_fun39347494)?anf_fun39347494.app(INDENT118169,(1),str_DASH_where182988,checker55147437,str_DASH_end148546):R.ffi.throwNonFunApp(L[4870],anf_fun39347494,[INDENT118169,(1),str_DASH_where182988,checker55147437,str_DASH_end148546]);
};
try {
if(--R.GAS > 0) {
$z4748647487 = $f4749247493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4749247493,
"from":L[4870]});
}
} catch($e4748447485) {
if(R.isCont($e4748447485)) {
var $ss4748847489 = {"from":L[4870],
"go":function(cont_tail_arg39447495) {
return $Hcont_tail_arg839447496(cont_tail_arg39447495,if_helper35947481);
}};
$e4748447485.stack[R.EXN_STACKHEIGHT++] = $ss4748847489;
}
if(R.isPyretException($e4748447485)) {
$e4748447485.pyretStack.push(L[4870]);
}
throw $e4748447485;
}
var $ret4749047491 = $Hcont_tail_arg839447496($z4748647487,if_helper35947481);
++R.GAS;
return $ret4749047491;
}
} else {
var cont_tail_arg39047499 = R.throwNonBooleanCondition(L[4867],("if"),if_DASH_4047469);
if(--R.GAS > 0) {
$z4749747498 = R.isFunction(if_helper35947481)?if_helper35947481.app(cont_tail_arg39047499):R.ffi.throwNonFunApp(L[4867],if_helper35947481,[cont_tail_arg39047499]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper35947481)?if_helper35947481.app(cont_tail_arg39047499):R.ffi.throwNonFunApp(L[4867],if_helper35947481,[cont_tail_arg39047499]);
},
"from":L[4867]});
}
++R.GAS;
return $z4749747498;
}
};
var $Hcont_tail_app839347483 = function(cont_tail_app39647482) {
return cont_tail_app39647482;
};
var $Hcont_tail_arg839447496 = function(cont_tail_arg39447495,if_helper35947481) {
if(--R.GAS > 0) {
$z4751547516 = R.isFunction(if_helper35947481)?if_helper35947481.app(cont_tail_arg39447495):R.ffi.throwNonFunApp(L[4870],if_helper35947481,[cont_tail_arg39447495]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper35947481)?if_helper35947481.app(cont_tail_arg39447495):R.ffi.throwNonFunApp(L[4870],if_helper35947481,[cont_tail_arg39447495]);
},
"from":L[4870]});
}
++R.GAS;
return $z4751547516;
};
var $Hor_DASH_oper_DASH_839247514 = function(or_DASH_oper_DASH_4247512,INDENT118169,PP170,PP278,body54218535,doc54118534,footer55347513,header55047422,str_DASH_doc143481,_plus55) {
var if_helper36147527 = R.makeFunction(function(if_helper_arg36247551) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4872],1,arguments);
}
var if_DASH_4147570 = if_helper_arg36247551;
var if_helper36347554 = R.makeFunction(function(if_helper_arg36447575) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4872],1,arguments);
}
var docstr55447589 = if_helper_arg36447575;
var anf_fun36547588 = G(PP170,"surround",L[4881]);
var anf_fun36647586 = G(body54218535,"tosource",L[4880]);
var $z4757847579 = D;
var $f4758447585 = function(_) {
return R.isFunction(anf_fun36647586)?anf_fun36647586.app():R.ffi.throwNonFunApp(L[4879],anf_fun36647586,[]);
};
try {
if(--R.GAS > 0) {
$z4757847579 = $f4758447585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4758447585,
"from":L[4879]});
}
} catch($e4757647577) {
if(R.isCont($e4757647577)) {
var $ss4758047581 = {"from":L[4879],
"go":function(anf_arg36747587) {
return $Hanf_arg838547590(anf_arg36747587,INDENT118169,PP278,anf_fun36547588,docstr55447589,footer55347513,header55047422,_plus55);
}};
$e4757647577.stack[R.EXN_STACKHEIGHT++] = $ss4758047581;
}
if(R.isPyretException($e4757647577)) {
$e4757647577.pyretStack.push(L[4879]);
}
throw $e4757647577;
}
var $ret4758247583 = $Hanf_arg838547590($z4757847579,INDENT118169,PP278,anf_fun36547588,docstr55447589,footer55347513,header55047422,_plus55);
++R.GAS;
return $ret4758247583;
});
var anf_if37147574 = R.isBoolean(if_DASH_4147570);
if(R.isPyretTrue(anf_if37147574)) {
if(R.isPyretTrue(if_DASH_4147570)) {
var cont_tail_arg38047555 = G(PP170,"mt-doc",L[4875]);
if(--R.GAS > 0) {
$z4755247553 = R.isFunction(if_helper36347554)?if_helper36347554.app(cont_tail_arg38047555):R.ffi.throwNonFunApp(L[4875],if_helper36347554,[cont_tail_arg38047555]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper36347554)?if_helper36347554.app(cont_tail_arg38047555):R.ffi.throwNonFunApp(L[4875],if_helper36347554,[cont_tail_arg38047555]);
},
"from":L[4875]});
}
++R.GAS;
return $z4755247553;
} else {
var anf_fun37247568 = G(PP170,"dquote",L[4878]);
var anf_fun37347566 = G(PP170,"str",L[4877]);
var $z4755847559 = D;
var $f4756447565 = function(_) {
return R.isFunction(anf_fun37347566)?anf_fun37347566.app(doc54118534):R.ffi.throwNonFunApp(L[4876],anf_fun37347566,[doc54118534]);
};
try {
if(--R.GAS > 0) {
$z4755847559 = $f4756447565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4756447565,
"from":L[4876]});
}
} catch($e4755647557) {
if(R.isCont($e4755647557)) {
var $ss4756047561 = {"from":L[4876],
"go":function(anf_arg37447567) {
return $Hanf_arg838947569(anf_arg37447567,PP170,anf_fun37247568,if_helper36347554,str_DASH_doc143481,_plus55);
}};
$e4755647557.stack[R.EXN_STACKHEIGHT++] = $ss4756047561;
}
if(R.isPyretException($e4755647557)) {
$e4755647557.pyretStack.push(L[4876]);
}
throw $e4755647557;
}
var $ret4756247563 = $Hanf_arg838947569($z4755847559,PP170,anf_fun37247568,if_helper36347554,str_DASH_doc143481,_plus55);
++R.GAS;
return $ret4756247563;
}
} else {
var cont_tail_arg36947573 = R.throwNonBooleanCondition(L[4872],("if"),if_DASH_4147570);
if(--R.GAS > 0) {
$z4757147572 = R.isFunction(if_helper36347554)?if_helper36347554.app(cont_tail_arg36947573):R.ffi.throwNonFunApp(L[4872],if_helper36347554,[cont_tail_arg36947573]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper36347554)?if_helper36347554.app(cont_tail_arg36947573):R.ffi.throwNonFunApp(L[4872],if_helper36347554,[cont_tail_arg36947573]);
},
"from":L[4872]});
}
++R.GAS;
return $z4757147572;
}
});
var anf_if38447550 = R.isBoolean(or_DASH_oper_DASH_4247512);
if(R.isPyretTrue(anf_if38447550)) {
if(R.isPyretTrue(or_DASH_oper_DASH_4247512)) {
var $z4751947520 = D;
var $f4752547526 = function(_) {
return R.isFunction(if_helper36147527)?if_helper36147527.app((true)):R.ffi.throwNonFunApp(L[4872],if_helper36147527,[(true)]);
};
try {
if(--R.GAS > 0) {
$z4751947520 = $f4752547526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4752547526,
"from":L[4872]});
}
} catch($e4751747518) {
if(R.isCont($e4751747518)) {
var $ss4752147522 = {"from":L[4872],
"go":function(cont_tail_app38947528) {
return $Hcont_tail_app839047529(cont_tail_app38947528);
}};
$e4751747518.stack[R.EXN_STACKHEIGHT++] = $ss4752147522;
}
if(R.isPyretException($e4751747518)) {
$e4751747518.pyretStack.push(L[4872]);
}
throw $e4751747518;
}
var $ret4752347524 = $Hcont_tail_app839047529($z4751947520);
++R.GAS;
return $ret4752347524;
} else {
var or_DASH_oper_DASH_4347540 = R.equiv(doc54118534,(""));
var anf_if38747546 = R.isBoolean(or_DASH_oper_DASH_4347540);
if(R.isPyretTrue(anf_if38747546)) {
var $z4753247533 = D;
var $f4753847539 = function(_) {
return R.isFunction(if_helper36147527)?if_helper36147527.app(or_DASH_oper_DASH_4347540):R.ffi.throwNonFunApp(L[4872],if_helper36147527,[or_DASH_oper_DASH_4347540]);
};
try {
if(--R.GAS > 0) {
$z4753247533 = $f4753847539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4753847539,
"from":L[4872]});
}
} catch($e4753047531) {
if(R.isCont($e4753047531)) {
var $ss4753447535 = {"from":L[4872],
"go":function(cont_tail_app38847541) {
return $Hcont_tail_app839147542(cont_tail_app38847541);
}};
$e4753047531.stack[R.EXN_STACKHEIGHT++] = $ss4753447535;
}
if(R.isPyretException($e4753047531)) {
$e4753047531.pyretStack.push(L[4872]);
}
throw $e4753047531;
}
var $ret4753647537 = $Hcont_tail_app839147542($z4753247533);
++R.GAS;
return $ret4753647537;
} else {
var cont_tail_arg38547545 = R.throwNonBooleanOp(L[4873],("second"),("or"),or_DASH_oper_DASH_4347540);
if(--R.GAS > 0) {
$z4754347544 = R.isFunction(if_helper36147527)?if_helper36147527.app(cont_tail_arg38547545):R.ffi.throwNonFunApp(L[4873],if_helper36147527,[cont_tail_arg38547545]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper36147527)?if_helper36147527.app(cont_tail_arg38547545):R.ffi.throwNonFunApp(L[4873],if_helper36147527,[cont_tail_arg38547545]);
},
"from":L[4873]});
}
++R.GAS;
return $z4754347544;
}
}
} else {
var cont_tail_arg38247549 = R.throwNonBooleanOp(L[4874],("first"),("or"),or_DASH_oper_DASH_4247512);
if(--R.GAS > 0) {
$z4754747548 = R.isFunction(if_helper36147527)?if_helper36147527.app(cont_tail_arg38247549):R.ffi.throwNonFunApp(L[4874],if_helper36147527,[cont_tail_arg38247549]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper36147527)?if_helper36147527.app(cont_tail_arg38247549):R.ffi.throwNonFunApp(L[4874],if_helper36147527,[cont_tail_arg38247549]);
},
"from":L[4874]});
}
++R.GAS;
return $z4754747548;
}
};
var $Hcont_tail_app839047529 = function(cont_tail_app38947528) {
return cont_tail_app38947528;
};
var $Hcont_tail_app839147542 = function(cont_tail_app38847541) {
return cont_tail_app38847541;
};
var $Hanf_arg838947569 = function(anf_arg37447567,PP170,anf_fun37247568,if_helper36347554,str_DASH_doc143481,_plus55) {
var $z4759347594 = D;
var $f4759947600 = function(_) {
return R.isFunction(anf_fun37247568)?anf_fun37247568.app(anf_arg37447567):R.ffi.throwNonFunApp(L[4882],anf_fun37247568,[anf_arg37447567]);
};
try {
if(--R.GAS > 0) {
$z4759347594 = $f4759947600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4759947600,
"from":L[4882]});
}
} catch($e4759147592) {
if(R.isCont($e4759147592)) {
var $ss4759547596 = {"from":L[4882],
"go":function(anf_arg37547601) {
return $Hanf_arg838847602(anf_arg37547601,PP170,if_helper36347554,str_DASH_doc143481,_plus55);
}};
$e4759147592.stack[R.EXN_STACKHEIGHT++] = $ss4759547596;
}
if(R.isPyretException($e4759147592)) {
$e4759147592.pyretStack.push(L[4882]);
}
throw $e4759147592;
}
var $ret4759747598 = $Hanf_arg838847602($z4759347594,PP170,if_helper36347554,str_DASH_doc143481,_plus55);
++R.GAS;
return $ret4759747598;
};
var $Hanf_arg838847602 = function(anf_arg37547601,PP170,if_helper36347554,str_DASH_doc143481,_plus55) {
var $z4760547606 = D;
var $f4761147612 = function(_) {
return R.isFunction(_plus55)?_plus55.app(str_DASH_doc143481,anf_arg37547601):R.ffi.throwNonFunApp(L[4883],_plus55,[str_DASH_doc143481,anf_arg37547601]);
};
try {
if(--R.GAS > 0) {
$z4760547606 = $f4761147612();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4761147612,
"from":L[4883]});
}
} catch($e4760347604) {
if(R.isCont($e4760347604)) {
var $ss4760747608 = {"from":L[4883],
"go":function(anf_arg37647613) {
return $Hanf_arg838747614(anf_arg37647613,PP170,if_helper36347554,_plus55);
}};
$e4760347604.stack[R.EXN_STACKHEIGHT++] = $ss4760747608;
}
if(R.isPyretException($e4760347604)) {
$e4760347604.pyretStack.push(L[4883]);
}
throw $e4760347604;
}
var $ret4760947610 = $Hanf_arg838747614($z4760547606,PP170,if_helper36347554,_plus55);
++R.GAS;
return $ret4760947610;
};
var $Hanf_arg838747614 = function(anf_arg37647613,PP170,if_helper36347554,_plus55) {
var anf_arg37747625 = G(PP170,"hardline",L[4884]);
var $z4761747618 = D;
var $f4762347624 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg37647613,anf_arg37747625):R.ffi.throwNonFunApp(L[4883],_plus55,[anf_arg37647613,anf_arg37747625]);
};
try {
if(--R.GAS > 0) {
$z4761747618 = $f4762347624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4762347624,
"from":L[4883]});
}
} catch($e4761547616) {
if(R.isCont($e4761547616)) {
var $ss4761947620 = {"from":L[4883],
"go":function(cont_tail_arg37847626) {
return $Hcont_tail_arg838647627(cont_tail_arg37847626,if_helper36347554);
}};
$e4761547616.stack[R.EXN_STACKHEIGHT++] = $ss4761947620;
}
if(R.isPyretException($e4761547616)) {
$e4761547616.pyretStack.push(L[4883]);
}
throw $e4761547616;
}
var $ret4762147622 = $Hcont_tail_arg838647627($z4761747618,if_helper36347554);
++R.GAS;
return $ret4762147622;
};
var $Hcont_tail_arg838647627 = function(cont_tail_arg37847626,if_helper36347554) {
if(--R.GAS > 0) {
$z4762847629 = R.isFunction(if_helper36347554)?if_helper36347554.app(cont_tail_arg37847626):R.ffi.throwNonFunApp(L[4883],if_helper36347554,[cont_tail_arg37847626]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper36347554)?if_helper36347554.app(cont_tail_arg37847626):R.ffi.throwNonFunApp(L[4883],if_helper36347554,[cont_tail_arg37847626]);
},
"from":L[4883]});
}
++R.GAS;
return $z4762847629;
};
var $Hanf_arg838547590 = function(anf_arg36747587,INDENT118169,PP278,anf_fun36547588,docstr55447589,footer55347513,header55047422,_plus55) {
var $z4763247633 = D;
var $f4763847639 = function(_) {
return R.isFunction(_plus55)?_plus55.app(docstr55447589,anf_arg36747587):R.ffi.throwNonFunApp(L[4885],_plus55,[docstr55447589,anf_arg36747587]);
};
try {
if(--R.GAS > 0) {
$z4763247633 = $f4763847639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4763847639,
"from":L[4885]});
}
} catch($e4763047631) {
if(R.isCont($e4763047631)) {
var $ss4763447635 = {"from":L[4885],
"go":function(anf_arg36847640) {
return $Hanf_arg838447641(anf_arg36847640,INDENT118169,PP278,anf_fun36547588,footer55347513,header55047422);
}};
$e4763047631.stack[R.EXN_STACKHEIGHT++] = $ss4763447635;
}
if(R.isPyretException($e4763047631)) {
$e4763047631.pyretStack.push(L[4885]);
}
throw $e4763047631;
}
var $ret4763647637 = $Hanf_arg838447641($z4763247633,INDENT118169,PP278,anf_fun36547588,footer55347513,header55047422);
++R.GAS;
return $ret4763647637;
};
var $Hanf_arg838447641 = function(anf_arg36847640,INDENT118169,PP278,anf_fun36547588,footer55347513,header55047422) {
var $z4764447645 = D;
var $f4765047651 = function(_) {
return R.isFunction(anf_fun36547588)?anf_fun36547588.app(INDENT118169,(1),header55047422,anf_arg36847640,footer55347513):R.ffi.throwNonFunApp(L[3303],anf_fun36547588,[INDENT118169,(1),header55047422,anf_arg36847640,footer55347513]);
};
try {
if(--R.GAS > 0) {
$z4764447645 = $f4765047651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4765047651,
"from":L[3303]});
}
} catch($e4764247643) {
if(R.isCont($e4764247643)) {
var $ss4764647647 = {"from":L[3303],
"go":function(ann_DASH_check_DASH_temp32247652) {
return $Hann_DASH_check_DASH_temp838347653(ann_DASH_check_DASH_temp32247652,PP278);
}};
$e4764247643.stack[R.EXN_STACKHEIGHT++] = $ss4764647647;
}
if(R.isPyretException($e4764247643)) {
$e4764247643.pyretStack.push(L[3303]);
}
throw $e4764247643;
}
var $ret4764847649 = $Hann_DASH_check_DASH_temp838347653($z4764447645,PP278);
++R.GAS;
return $ret4764847649;
};
var $Hann_DASH_check_DASH_temp838347653 = function(ann_DASH_check_DASH_temp32247652,PP278) {
return ann_DASH_check_DASH_temp32247652;
};
var $Hann_DASH_check_DASH_temp838247455 = function(ann_DASH_check_DASH_temp35247454) {
return ann_DASH_check_DASH_temp35247454;
};
var $Hann_DASH_check_DASH_temp838147128 = function(ann_DASH_check_DASH_temp33447127) {
return ann_DASH_check_DASH_temp33447127;
};
var $Hanf_arg83801060 = function(anf_arg3091058,base2481047,count2461059,s_DASH_atom1961027,_plus55,not60,nothing61,raise62,torepr65) {
var $z4765647657 = D;
var $f4766247663 = function(_) {
return R.isFunction(not60)?not60.app(anf_arg3091058):R.ffi.throwNonFunApp(L[4886],not60,[anf_arg3091058]);
};
try {
if(--R.GAS > 0) {
$z4765647657 = $f4766247663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4766247663,
"from":L[4886]});
}
} catch($e4765447655) {
if(R.isCont($e4765447655)) {
var $ss4765847659 = {"from":L[4886],
"go":function(when_DASH_3147664) {
return $Hwhen_DASH_837947665(when_DASH_3147664,base2481047,count2461059,s_DASH_atom1961027,_plus55,nothing61,raise62,torepr65);
}};
$e4765447655.stack[R.EXN_STACKHEIGHT++] = $ss4765847659;
}
if(R.isPyretException($e4765447655)) {
$e4765447655.pyretStack.push(L[4886]);
}
throw $e4765447655;
}
var $ret4766047661 = $Hwhen_DASH_837947665($z4765647657,base2481047,count2461059,s_DASH_atom1961027,_plus55,nothing61,raise62,torepr65);
++R.GAS;
return $ret4766047661;
};
var $Hwhen_DASH_837947665 = function(when_DASH_3147664,base2481047,count2461059,s_DASH_atom1961027,_plus55,nothing61,raise62,torepr65) {
var if_helper31047677 = R.makeFunction(function(if_helper_arg31147695) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4886],1,arguments);
}
if_helper_arg31147695;
var $z4769847699 = D;
var $f4770447705 = function(_) {
return R.isFunction(_plus55)?_plus55.app((1),count2461059.$var):R.ffi.throwNonFunApp(L[4889],_plus55,[(1),count2461059.$var]);
};
try {
if(--R.GAS > 0) {
$z4769847699 = $f4770447705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4770447705,
"from":L[4889]});
}
} catch($e4769647697) {
if(R.isCont($e4769647697)) {
var $ss4770047701 = {"from":L[4889],
"go":function(anf_assign31247706) {
return $Hanf_assign837247707(anf_assign31247706,base2481047,count2461059,s_DASH_atom1961027);
}};
$e4769647697.stack[R.EXN_STACKHEIGHT++] = $ss4770047701;
}
if(R.isPyretException($e4769647697)) {
$e4769647697.pyretStack.push(L[4889]);
}
throw $e4769647697;
}
var $ret4770247703 = $Hanf_assign837247707($z4769847699,base2481047,count2461059,s_DASH_atom1961027);
++R.GAS;
return $ret4770247703;
});
var anf_if31547694 = R.isBoolean(when_DASH_3147664);
if(R.isPyretTrue(anf_if31547694)) {
if(R.isPyretTrue(when_DASH_3147664)) {
var $z4766847669 = D;
var $f4767447675 = function(_) {
return R.isFunction(torepr65)?torepr65.app(base2481047):R.ffi.throwNonFunApp(L[4887],torepr65,[base2481047]);
};
try {
if(--R.GAS > 0) {
$z4766847669 = $f4767447675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4767447675,
"from":L[4887]});
}
} catch($e4766647667) {
if(R.isCont($e4766647667)) {
var $ss4767047671 = {"from":L[4887],
"go":function(anf_arg31747676) {
return $Hanf_arg837747678(anf_arg31747676,if_helper31047677,_plus55,nothing61,raise62);
}};
$e4766647667.stack[R.EXN_STACKHEIGHT++] = $ss4767047671;
}
if(R.isPyretException($e4766647667)) {
$e4766647667.pyretStack.push(L[4887]);
}
throw $e4766647667;
}
var $ret4767247673 = $Hanf_arg837747678($z4766847669,if_helper31047677,_plus55,nothing61,raise62);
++R.GAS;
return $ret4767247673;
} else {
var $z4768147682 = D;
var $f4768747688 = function(_) {
return R.isFunction(if_helper31047677)?if_helper31047677.app(nothing61):R.ffi.throwNonFunApp(L[4886],if_helper31047677,[nothing61]);
};
try {
if(--R.GAS > 0) {
$z4768147682 = $f4768747688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4768747688,
"from":L[4886]});
}
} catch($e4767947680) {
if(R.isCont($e4767947680)) {
var $ss4768347684 = {"from":L[4886],
"go":function(cont_tail_app31647689) {
return $Hcont_tail_app837847690(cont_tail_app31647689);
}};
$e4767947680.stack[R.EXN_STACKHEIGHT++] = $ss4768347684;
}
if(R.isPyretException($e4767947680)) {
$e4767947680.pyretStack.push(L[4886]);
}
throw $e4767947680;
}
var $ret4768547686 = $Hcont_tail_app837847690($z4768147682);
++R.GAS;
return $ret4768547686;
}
} else {
var cont_tail_arg31347693 = R.throwNonBooleanCondition(L[4888],("when"),when_DASH_3147664);
if(--R.GAS > 0) {
$z4769147692 = R.isFunction(if_helper31047677)?if_helper31047677.app(cont_tail_arg31347693):R.ffi.throwNonFunApp(L[4888],if_helper31047677,[cont_tail_arg31347693]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper31047677)?if_helper31047677.app(cont_tail_arg31347693):R.ffi.throwNonFunApp(L[4888],if_helper31047677,[cont_tail_arg31347693]);
},
"from":L[4888]});
}
++R.GAS;
return $z4769147692;
}
};
var $Hanf_arg837747678 = function(anf_arg31747676,if_helper31047677,_plus55,nothing61,raise62) {
var $z4771047711 = D;
var $f4771647717 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("Got a non-string in make-atom: "),anf_arg31747676):R.ffi.throwNonFunApp(L[4890],_plus55,[("Got a non-string in make-atom: "),anf_arg31747676]);
};
try {
if(--R.GAS > 0) {
$z4771047711 = $f4771647717();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4771647717,
"from":L[4890]});
}
} catch($e4770847709) {
if(R.isCont($e4770847709)) {
var $ss4771247713 = {"from":L[4890],
"go":function(anf_arg31847718) {
return $Hanf_arg837647719(anf_arg31847718,if_helper31047677,nothing61,raise62);
}};
$e4770847709.stack[R.EXN_STACKHEIGHT++] = $ss4771247713;
}
if(R.isPyretException($e4770847709)) {
$e4770847709.pyretStack.push(L[4890]);
}
throw $e4770847709;
}
var $ret4771447715 = $Hanf_arg837647719($z4771047711,if_helper31047677,nothing61,raise62);
++R.GAS;
return $ret4771447715;
};
var $Hanf_arg837647719 = function(anf_arg31847718,if_helper31047677,nothing61,raise62) {
var $z4772247723 = D;
var $f4772847729 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg31847718):R.ffi.throwNonFunApp(L[4891],raise62,[anf_arg31847718]);
};
try {
if(--R.GAS > 0) {
$z4772247723 = $f4772847729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4772847729,
"from":L[4891]});
}
} catch($e4772047721) {
if(R.isCont($e4772047721)) {
var $ss4772447725 = {"from":L[4891],
"go":function(anf_begin_app_dropped837347730) {
return $Hanf_begin_app_dropped837547731(anf_begin_app_dropped837347730,if_helper31047677,nothing61);
}};
$e4772047721.stack[R.EXN_STACKHEIGHT++] = $ss4772447725;
}
if(R.isPyretException($e4772047721)) {
$e4772047721.pyretStack.push(L[4891]);
}
throw $e4772047721;
}
var $ret4772647727 = $Hanf_begin_app_dropped837547731($z4772247723,if_helper31047677,nothing61);
++R.GAS;
return $ret4772647727;
};
var $Hanf_begin_app_dropped837547731 = function(anf_begin_app_dropped837347730,if_helper31047677,nothing61) {
var $z4773447735 = D;
var $f4774047741 = function(_) {
return R.isFunction(if_helper31047677)?if_helper31047677.app(nothing61):R.ffi.throwNonFunApp(L[4886],if_helper31047677,[nothing61]);
};
try {
if(--R.GAS > 0) {
$z4773447735 = $f4774047741();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4774047741,
"from":L[4886]});
}
} catch($e4773247733) {
if(R.isCont($e4773247733)) {
var $ss4773647737 = {"from":L[4886],
"go":function(cont_tail_app31947742) {
return $Hcont_tail_app837447743(cont_tail_app31947742);
}};
$e4773247733.stack[R.EXN_STACKHEIGHT++] = $ss4773647737;
}
if(R.isPyretException($e4773247733)) {
$e4773247733.pyretStack.push(L[4886]);
}
throw $e4773247733;
}
var $ret4773847739 = $Hcont_tail_app837447743($z4773447735);
++R.GAS;
return $ret4773847739;
};
var $Hcont_tail_app837447743 = function(cont_tail_app31947742) {
return cont_tail_app31947742;
};
var $Hcont_tail_app837847690 = function(cont_tail_app31647689) {
return cont_tail_app31647689;
};
var $Hanf_assign837247707 = function(anf_assign31247706,base2481047,count2461059,s_DASH_atom1961027) {
count2461059.$var = anf_assign31247706;
var $z4774647747 = D;
var $f4775247753 = function(_) {
return R.isFunction(s_DASH_atom1961027.$var)?s_DASH_atom1961027.$var.app(base2481047,count2461059.$var):R.ffi.throwNonFunApp(L[132],s_DASH_atom1961027.$var,[base2481047,count2461059.$var]);
};
try {
if(--R.GAS > 0) {
$z4774647747 = $f4775247753();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4775247753,
"from":L[132]});
}
} catch($e4774447745) {
if(R.isCont($e4774447745)) {
var $ss4774847749 = {"from":L[132],
"go":function(ann_DASH_check_DASH_temp30847754) {
return $Hann_DASH_check_DASH_temp837147755(ann_DASH_check_DASH_temp30847754);
}};
$e4774447745.stack[R.EXN_STACKHEIGHT++] = $ss4774847749;
}
if(R.isPyretException($e4774447745)) {
$e4774447745.pyretStack.push(L[132]);
}
throw $e4774447745;
}
var $ret4775047751 = $Hann_DASH_check_DASH_temp837147755($z4774647747);
++R.GAS;
return $ret4775047751;
};
var $Hann_DASH_check_DASH_temp837147755 = function(ann_DASH_check_DASH_temp30847754) {
return ann_DASH_check_DASH_temp30847754;
};
var $Hanf_arg83701151 = function(anf_arg2901149,self2341150,_plus55,tostring66) {
var anf_arg29147766 = G(self2341150,"serial",L[4893]);
var $z4775847759 = D;
var $f4776447765 = function(_) {
return R.isFunction(tostring66)?tostring66.app(anf_arg29147766):R.ffi.throwNonFunApp(L[4892],tostring66,[anf_arg29147766]);
};
try {
if(--R.GAS > 0) {
$z4775847759 = $f4776447765();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4776447765,
"from":L[4892]});
}
} catch($e4775647757) {
if(R.isCont($e4775647757)) {
var $ss4776047761 = {"from":L[4892],
"go":function(anf_arg29247767) {
return $Hanf_arg836947768(anf_arg29247767,anf_arg2901149,_plus55);
}};
$e4775647757.stack[R.EXN_STACKHEIGHT++] = $ss4776047761;
}
if(R.isPyretException($e4775647757)) {
$e4775647757.pyretStack.push(L[4892]);
}
throw $e4775647757;
}
var $ret4776247763 = $Hanf_arg836947768($z4775847759,anf_arg2901149,_plus55);
++R.GAS;
return $ret4776247763;
};
var $Hanf_arg836947768 = function(anf_arg29247767,anf_arg2901149,_plus55) {
var $z4777147772 = D;
var $f4777747778 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg2901149,anf_arg29247767):R.ffi.throwNonFunApp(L[154],_plus55,[anf_arg2901149,anf_arg29247767]);
};
try {
if(--R.GAS > 0) {
$z4777147772 = $f4777747778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4777747778,
"from":L[154]});
}
} catch($e4776947770) {
if(R.isCont($e4776947770)) {
var $ss4777347774 = {"from":L[154],
"go":function(ann_DASH_check_DASH_temp28847779) {
return $Hann_DASH_check_DASH_temp836847780(ann_DASH_check_DASH_temp28847779);
}};
$e4776947770.stack[R.EXN_STACKHEIGHT++] = $ss4777347774;
}
if(R.isPyretException($e4776947770)) {
$e4776947770.pyretStack.push(L[154]);
}
throw $e4776947770;
}
var $ret4777547776 = $Hann_DASH_check_DASH_temp836847780($z4777147772);
++R.GAS;
return $ret4777547776;
};
var $Hann_DASH_check_DASH_temp836847780 = function(ann_DASH_check_DASH_temp28847779) {
return ann_DASH_check_DASH_temp28847779;
};
var $Hann_DASH_check_DASH_temp83671166 = function(ann_DASH_check_DASH_temp2831165) {
return ann_DASH_check_DASH_temp2831165;
};
var $Hanf_arg83661181 = function(anf_arg2811179,anf_fun2791180) {
var $z4778347784 = D;
var $f4778947790 = function(_) {
return R.isFunction(anf_fun2791180)?anf_fun2791180.app(anf_arg2811179):R.ffi.throwNonFunApp(L[162],anf_fun2791180,[anf_arg2811179]);
};
try {
if(--R.GAS > 0) {
$z4778347784 = $f4778947790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4778947790,
"from":L[162]});
}
} catch($e4778147782) {
if(R.isCont($e4778147782)) {
var $ss4778547786 = {"from":L[162],
"go":function(ann_DASH_check_DASH_temp27847791) {
return $Hann_DASH_check_DASH_temp836547792(ann_DASH_check_DASH_temp27847791);
}};
$e4778147782.stack[R.EXN_STACKHEIGHT++] = $ss4778547786;
}
if(R.isPyretException($e4778147782)) {
$e4778147782.pyretStack.push(L[162]);
}
throw $e4778147782;
}
var $ret4778747788 = $Hann_DASH_check_DASH_temp836547792($z4778347784);
++R.GAS;
return $ret4778747788;
};
var $Hann_DASH_check_DASH_temp836547792 = function(ann_DASH_check_DASH_temp27847791) {
return ann_DASH_check_DASH_temp27847791;
};
var $Hanf_arg83641196 = function(anf_arg2761194,anf_arg2741195,_plus55) {
var $z4779547796 = D;
var $f4780147802 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg2741195,anf_arg2761194):R.ffi.throwNonFunApp(L[166],_plus55,[anf_arg2741195,anf_arg2761194]);
};
try {
if(--R.GAS > 0) {
$z4779547796 = $f4780147802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4780147802,
"from":L[166]});
}
} catch($e4779347794) {
if(R.isCont($e4779347794)) {
var $ss4779747798 = {"from":L[166],
"go":function(ann_DASH_check_DASH_temp27347803) {
return $Hann_DASH_check_DASH_temp836347804(ann_DASH_check_DASH_temp27347803);
}};
$e4779347794.stack[R.EXN_STACKHEIGHT++] = $ss4779747798;
}
if(R.isPyretException($e4779347794)) {
$e4779347794.pyretStack.push(L[166]);
}
throw $e4779347794;
}
var $ret4779947800 = $Hann_DASH_check_DASH_temp836347804($z4779547796);
++R.GAS;
return $ret4779947800;
};
var $Hann_DASH_check_DASH_temp836347804 = function(ann_DASH_check_DASH_temp27347803) {
return ann_DASH_check_DASH_temp27347803;
};
var $Hanf_arg83621211 = function(anf_arg2711209,anf_fun2691210) {
var $z4780747808 = D;
var $f4781347814 = function(_) {
return R.isFunction(anf_fun2691210)?anf_fun2691210.app(anf_arg2711209):R.ffi.throwNonFunApp(L[170],anf_fun2691210,[anf_arg2711209]);
};
try {
if(--R.GAS > 0) {
$z4780747808 = $f4781347814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4781347814,
"from":L[170]});
}
} catch($e4780547806) {
if(R.isCont($e4780547806)) {
var $ss4780947810 = {"from":L[170],
"go":function(ann_DASH_check_DASH_temp26847815) {
return $Hann_DASH_check_DASH_temp836147816(ann_DASH_check_DASH_temp26847815);
}};
$e4780547806.stack[R.EXN_STACKHEIGHT++] = $ss4780947810;
}
if(R.isPyretException($e4780547806)) {
$e4780547806.pyretStack.push(L[170]);
}
throw $e4780547806;
}
var $ret4781147812 = $Hann_DASH_check_DASH_temp836147816($z4780747808);
++R.GAS;
return $ret4781147812;
};
var $Hann_DASH_check_DASH_temp836147816 = function(ann_DASH_check_DASH_temp26847815) {
return ann_DASH_check_DASH_temp26847815;
};
var $Hanf_arg83601226 = function(anf_arg2601224,self291225,_plus55,torepr65) {
var anf_arg26147827 = G(self291225,"serial",L[134]);
var $z4781947820 = D;
var $f4782547826 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg26147827):R.ffi.throwNonFunApp(L[134],torepr65,[anf_arg26147827]);
};
try {
if(--R.GAS > 0) {
$z4781947820 = $f4782547826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4782547826,
"from":L[134]});
}
} catch($e4781747818) {
if(R.isCont($e4781747818)) {
var $ss4782147822 = {"from":L[134],
"go":function(anf_arg26247828) {
return $Hanf_arg835947829(anf_arg26247828,anf_arg2601224,_plus55);
}};
$e4781747818.stack[R.EXN_STACKHEIGHT++] = $ss4782147822;
}
if(R.isPyretException($e4781747818)) {
$e4781747818.pyretStack.push(L[134]);
}
throw $e4781747818;
}
var $ret4782347824 = $Hanf_arg835947829($z4781947820,anf_arg2601224,_plus55);
++R.GAS;
return $ret4782347824;
};
var $Hanf_arg835947829 = function(anf_arg26247828,anf_arg2601224,_plus55) {
var $z4783247833 = D;
var $f4783847839 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg26247828):R.ffi.throwNonFunApp(L[134],_plus55,[(", "),anf_arg26247828]);
};
try {
if(--R.GAS > 0) {
$z4783247833 = $f4783847839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4783847839,
"from":L[134]});
}
} catch($e4783047831) {
if(R.isCont($e4783047831)) {
var $ss4783447835 = {"from":L[134],
"go":function(anf_arg26347840) {
return $Hanf_arg835847841(anf_arg26347840,anf_arg2601224,_plus55);
}};
$e4783047831.stack[R.EXN_STACKHEIGHT++] = $ss4783447835;
}
if(R.isPyretException($e4783047831)) {
$e4783047831.pyretStack.push(L[134]);
}
throw $e4783047831;
}
var $ret4783647837 = $Hanf_arg835847841($z4783247833,anf_arg2601224,_plus55);
++R.GAS;
return $ret4783647837;
};
var $Hanf_arg835847841 = function(anf_arg26347840,anf_arg2601224,_plus55) {
var $z4784447845 = D;
var $f4785047851 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg2601224,anf_arg26347840):R.ffi.throwNonFunApp(L[134],_plus55,[anf_arg2601224,anf_arg26347840]);
};
try {
if(--R.GAS > 0) {
$z4784447845 = $f4785047851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4785047851,
"from":L[134]});
}
} catch($e4784247843) {
if(R.isCont($e4784247843)) {
var $ss4784647847 = {"from":L[134],
"go":function(anf_arg26447852) {
return $Hanf_arg835747853(anf_arg26447852,_plus55);
}};
$e4784247843.stack[R.EXN_STACKHEIGHT++] = $ss4784647847;
}
if(R.isPyretException($e4784247843)) {
$e4784247843.pyretStack.push(L[134]);
}
throw $e4784247843;
}
var $ret4784847849 = $Hanf_arg835747853($z4784447845,_plus55);
++R.GAS;
return $ret4784847849;
};
var $Hanf_arg835747853 = function(anf_arg26447852,_plus55) {
var $z4785647857 = D;
var $f4786247863 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg26447852,(")")):R.ffi.throwNonFunApp(L[134],_plus55,[anf_arg26447852,(")")]);
};
try {
if(--R.GAS > 0) {
$z4785647857 = $f4786247863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4786247863,
"from":L[134]});
}
} catch($e4785447855) {
if(R.isCont($e4785447855)) {
var $ss4785847859 = {"from":L[134],
"go":function(anf_arg26547864) {
return $Hanf_arg835647865(anf_arg26547864,_plus55);
}};
$e4785447855.stack[R.EXN_STACKHEIGHT++] = $ss4785847859;
}
if(R.isPyretException($e4785447855)) {
$e4785447855.pyretStack.push(L[134]);
}
throw $e4785447855;
}
var $ret4786047861 = $Hanf_arg835647865($z4785647857,_plus55);
++R.GAS;
return $ret4786047861;
};
var $Hanf_arg835647865 = function(anf_arg26547864,_plus55) {
var $z4786847869 = D;
var $f4787447875 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg26547864):R.ffi.throwNonFunApp(L[134],_plus55,[("("),anf_arg26547864]);
};
try {
if(--R.GAS > 0) {
$z4786847869 = $f4787447875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4787447875,
"from":L[134]});
}
} catch($e4786647867) {
if(R.isCont($e4786647867)) {
var $ss4787047871 = {"from":L[134],
"go":function(anf_arg26647876) {
return $Hanf_arg835547877(anf_arg26647876,_plus55);
}};
$e4786647867.stack[R.EXN_STACKHEIGHT++] = $ss4787047871;
}
if(R.isPyretException($e4786647867)) {
$e4786647867.pyretStack.push(L[134]);
}
throw $e4786647867;
}
var $ret4787247873 = $Hanf_arg835547877($z4786847869,_plus55);
++R.GAS;
return $ret4787247873;
};
var $Hanf_arg835547877 = function(anf_arg26647876,_plus55) {
var $z4788047881 = D;
var $f4788647887 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-atom"),anf_arg26647876):R.ffi.throwNonFunApp(L[134],_plus55,[("s-atom"),anf_arg26647876]);
};
try {
if(--R.GAS > 0) {
$z4788047881 = $f4788647887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4788647887,
"from":L[134]});
}
} catch($e4787847879) {
if(R.isCont($e4787847879)) {
var $ss4788247883 = {"from":L[134],
"go":function(ann_DASH_check_DASH_temp25847888) {
return $Hann_DASH_check_DASH_temp835447889(ann_DASH_check_DASH_temp25847888);
}};
$e4787847879.stack[R.EXN_STACKHEIGHT++] = $ss4788247883;
}
if(R.isPyretException($e4787847879)) {
$e4787847879.pyretStack.push(L[134]);
}
throw $e4787847879;
}
var $ret4788447885 = $Hann_DASH_check_DASH_temp835447889($z4788047881);
++R.GAS;
return $ret4788447885;
};
var $Hann_DASH_check_DASH_temp835447889 = function(ann_DASH_check_DASH_temp25847888) {
return ann_DASH_check_DASH_temp25847888;
};
var $Hcont_tail_arg83521242 = function(cont_tail_arg2551240,if_helper2461241) {
if(--R.GAS > 0) {
$z4789047891 = R.isFunction(if_helper2461241)?if_helper2461241.app(cont_tail_arg2551240):R.ffi.throwNonFunApp(L[134],if_helper2461241,[cont_tail_arg2551240]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper2461241)?if_helper2461241.app(cont_tail_arg2551240):R.ffi.throwNonFunApp(L[134],if_helper2461241,[cont_tail_arg2551240]);
},
"from":L[134]});
}
++R.GAS;
return $z4789047891;
};
var $Hcont_tail_arg83531257 = function(cont_tail_arg2511256,if_helper2461241) {
if(--R.GAS > 0) {
$z4789247893 = R.isFunction(if_helper2461241)?if_helper2461241.app(cont_tail_arg2511256):R.ffi.throwNonFunApp(L[134],if_helper2461241,[cont_tail_arg2511256]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper2461241)?if_helper2461241.app(cont_tail_arg2511256):R.ffi.throwNonFunApp(L[134],if_helper2461241,[cont_tail_arg2511256]);
},
"from":L[134]});
}
++R.GAS;
return $z4789247893;
};
var $Hann_DASH_check_DASH_temp83511278 = function(ann_DASH_check_DASH_temp2421277) {
return ann_DASH_check_DASH_temp2421277;
};
var $Hann_DASH_check_DASH_temp83501294 = function(ann_DASH_check_DASH_temp2371293) {
return ann_DASH_check_DASH_temp2371293;
};
var $Hann_DASH_check_DASH_temp83491309 = function(ann_DASH_check_DASH_temp2331308) {
return ann_DASH_check_DASH_temp2331308;
};
var $Hann_DASH_check_DASH_temp83481323 = function(ann_DASH_check_DASH_temp2301322) {
return ann_DASH_check_DASH_temp2301322;
};
var $Hanf_arg83471338 = function(anf_arg2281336,anf_fun2261337) {
var $z4789647897 = D;
var $f4790247903 = function(_) {
return R.isFunction(anf_fun2261337)?anf_fun2261337.app(anf_arg2281336):R.ffi.throwNonFunApp(L[187],anf_fun2261337,[anf_arg2281336]);
};
try {
if(--R.GAS > 0) {
$z4789647897 = $f4790247903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4790247903,
"from":L[187]});
}
} catch($e4789447895) {
if(R.isCont($e4789447895)) {
var $ss4789847899 = {"from":L[187],
"go":function(ann_DASH_check_DASH_temp22547904) {
return $Hann_DASH_check_DASH_temp834647905(ann_DASH_check_DASH_temp22547904);
}};
$e4789447895.stack[R.EXN_STACKHEIGHT++] = $ss4789847899;
}
if(R.isPyretException($e4789447895)) {
$e4789447895.pyretStack.push(L[187]);
}
throw $e4789447895;
}
var $ret4790047901 = $Hann_DASH_check_DASH_temp834647905($z4789647897);
++R.GAS;
return $ret4790047901;
};
var $Hann_DASH_check_DASH_temp834647905 = function(ann_DASH_check_DASH_temp22547904) {
return ann_DASH_check_DASH_temp22547904;
};
var $Hanf_arg83451352 = function(anf_arg2211351,_plus55) {
var $z4790847909 = D;
var $f4791447915 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg2211351,(")")):R.ffi.throwNonFunApp(L[135],_plus55,[anf_arg2211351,(")")]);
};
try {
if(--R.GAS > 0) {
$z4790847909 = $f4791447915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4791447915,
"from":L[135]});
}
} catch($e4790647907) {
if(R.isCont($e4790647907)) {
var $ss4791047911 = {"from":L[135],
"go":function(anf_arg22247916) {
return $Hanf_arg834447917(anf_arg22247916,_plus55);
}};
$e4790647907.stack[R.EXN_STACKHEIGHT++] = $ss4791047911;
}
if(R.isPyretException($e4790647907)) {
$e4790647907.pyretStack.push(L[135]);
}
throw $e4790647907;
}
var $ret4791247913 = $Hanf_arg834447917($z4790847909,_plus55);
++R.GAS;
return $ret4791247913;
};
var $Hanf_arg834447917 = function(anf_arg22247916,_plus55) {
var $z4792047921 = D;
var $f4792647927 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg22247916):R.ffi.throwNonFunApp(L[135],_plus55,[("("),anf_arg22247916]);
};
try {
if(--R.GAS > 0) {
$z4792047921 = $f4792647927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4792647927,
"from":L[135]});
}
} catch($e4791847919) {
if(R.isCont($e4791847919)) {
var $ss4792247923 = {"from":L[135],
"go":function(anf_arg22347928) {
return $Hanf_arg834347929(anf_arg22347928,_plus55);
}};
$e4791847919.stack[R.EXN_STACKHEIGHT++] = $ss4792247923;
}
if(R.isPyretException($e4791847919)) {
$e4791847919.pyretStack.push(L[135]);
}
throw $e4791847919;
}
var $ret4792447925 = $Hanf_arg834347929($z4792047921,_plus55);
++R.GAS;
return $ret4792447925;
};
var $Hanf_arg834347929 = function(anf_arg22347928,_plus55) {
var $z4793247933 = D;
var $f4793847939 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-type-global"),anf_arg22347928):R.ffi.throwNonFunApp(L[135],_plus55,[("s-type-global"),anf_arg22347928]);
};
try {
if(--R.GAS > 0) {
$z4793247933 = $f4793847939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4793847939,
"from":L[135]});
}
} catch($e4793047931) {
if(R.isCont($e4793047931)) {
var $ss4793447935 = {"from":L[135],
"go":function(ann_DASH_check_DASH_temp21947940) {
return $Hann_DASH_check_DASH_temp834247941(ann_DASH_check_DASH_temp21947940);
}};
$e4793047931.stack[R.EXN_STACKHEIGHT++] = $ss4793447935;
}
if(R.isPyretException($e4793047931)) {
$e4793047931.pyretStack.push(L[135]);
}
throw $e4793047931;
}
var $ret4793647937 = $Hann_DASH_check_DASH_temp834247941($z4793247933);
++R.GAS;
return $ret4793647937;
};
var $Hann_DASH_check_DASH_temp834247941 = function(ann_DASH_check_DASH_temp21947940) {
return ann_DASH_check_DASH_temp21947940;
};
var $Hcont_tail_arg83401368 = function(cont_tail_arg2161366,if_helper2081367) {
if(--R.GAS > 0) {
$z4794247943 = R.isFunction(if_helper2081367)?if_helper2081367.app(cont_tail_arg2161366):R.ffi.throwNonFunApp(L[135],if_helper2081367,[cont_tail_arg2161366]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper2081367)?if_helper2081367.app(cont_tail_arg2161366):R.ffi.throwNonFunApp(L[135],if_helper2081367,[cont_tail_arg2161366]);
},
"from":L[135]});
}
++R.GAS;
return $z4794247943;
};
var $Hcont_tail_arg83411383 = function(cont_tail_arg2131382,if_helper2081367) {
if(--R.GAS > 0) {
$z4794447945 = R.isFunction(if_helper2081367)?if_helper2081367.app(cont_tail_arg2131382):R.ffi.throwNonFunApp(L[135],if_helper2081367,[cont_tail_arg2131382]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper2081367)?if_helper2081367.app(cont_tail_arg2131382):R.ffi.throwNonFunApp(L[135],if_helper2081367,[cont_tail_arg2131382]);
},
"from":L[135]});
}
++R.GAS;
return $z4794447945;
};
var $Hann_DASH_check_DASH_temp83391403 = function(ann_DASH_check_DASH_temp2041402) {
return ann_DASH_check_DASH_temp2041402;
};
var $Hann_DASH_check_DASH_temp83381422 = function(ann_DASH_check_DASH_temp1961421) {
return ann_DASH_check_DASH_temp1961421;
};
var $Hanf_arg83371439 = function(anf_arg1921437,anf_fun1901438) {
var $z4794847949 = D;
var $f4795447955 = function(_) {
return R.isFunction(anf_fun1901438)?anf_fun1901438.app(anf_arg1921437):R.ffi.throwNonFunApp(L[203],anf_fun1901438,[anf_arg1921437]);
};
try {
if(--R.GAS > 0) {
$z4794847949 = $f4795447955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4795447955,
"from":L[203]});
}
} catch($e4794647947) {
if(R.isCont($e4794647947)) {
var $ss4795047951 = {"from":L[203],
"go":function(ann_DASH_check_DASH_temp18947956) {
return $Hann_DASH_check_DASH_temp833647957(ann_DASH_check_DASH_temp18947956);
}};
$e4794647947.stack[R.EXN_STACKHEIGHT++] = $ss4795047951;
}
if(R.isPyretException($e4794647947)) {
$e4794647947.pyretStack.push(L[203]);
}
throw $e4794647947;
}
var $ret4795247953 = $Hann_DASH_check_DASH_temp833647957($z4794847949);
++R.GAS;
return $ret4795247953;
};
var $Hann_DASH_check_DASH_temp833647957 = function(ann_DASH_check_DASH_temp18947956) {
return ann_DASH_check_DASH_temp18947956;
};
var $Hanf_arg83351453 = function(anf_arg1851452,_plus55) {
var $z4796047961 = D;
var $f4796647967 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg1851452,(")")):R.ffi.throwNonFunApp(L[136],_plus55,[anf_arg1851452,(")")]);
};
try {
if(--R.GAS > 0) {
$z4796047961 = $f4796647967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4796647967,
"from":L[136]});
}
} catch($e4795847959) {
if(R.isCont($e4795847959)) {
var $ss4796247963 = {"from":L[136],
"go":function(anf_arg18647968) {
return $Hanf_arg833447969(anf_arg18647968,_plus55);
}};
$e4795847959.stack[R.EXN_STACKHEIGHT++] = $ss4796247963;
}
if(R.isPyretException($e4795847959)) {
$e4795847959.pyretStack.push(L[136]);
}
throw $e4795847959;
}
var $ret4796447965 = $Hanf_arg833447969($z4796047961,_plus55);
++R.GAS;
return $ret4796447965;
};
var $Hanf_arg833447969 = function(anf_arg18647968,_plus55) {
var $z4797247973 = D;
var $f4797847979 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg18647968):R.ffi.throwNonFunApp(L[136],_plus55,[("("),anf_arg18647968]);
};
try {
if(--R.GAS > 0) {
$z4797247973 = $f4797847979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4797847979,
"from":L[136]});
}
} catch($e4797047971) {
if(R.isCont($e4797047971)) {
var $ss4797447975 = {"from":L[136],
"go":function(anf_arg18747980) {
return $Hanf_arg833347981(anf_arg18747980,_plus55);
}};
$e4797047971.stack[R.EXN_STACKHEIGHT++] = $ss4797447975;
}
if(R.isPyretException($e4797047971)) {
$e4797047971.pyretStack.push(L[136]);
}
throw $e4797047971;
}
var $ret4797647977 = $Hanf_arg833347981($z4797247973,_plus55);
++R.GAS;
return $ret4797647977;
};
var $Hanf_arg833347981 = function(anf_arg18747980,_plus55) {
var $z4798447985 = D;
var $f4799047991 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-global"),anf_arg18747980):R.ffi.throwNonFunApp(L[136],_plus55,[("s-global"),anf_arg18747980]);
};
try {
if(--R.GAS > 0) {
$z4798447985 = $f4799047991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4799047991,
"from":L[136]});
}
} catch($e4798247983) {
if(R.isCont($e4798247983)) {
var $ss4798647987 = {"from":L[136],
"go":function(ann_DASH_check_DASH_temp18347992) {
return $Hann_DASH_check_DASH_temp833247993(ann_DASH_check_DASH_temp18347992);
}};
$e4798247983.stack[R.EXN_STACKHEIGHT++] = $ss4798647987;
}
if(R.isPyretException($e4798247983)) {
$e4798247983.pyretStack.push(L[136]);
}
throw $e4798247983;
}
var $ret4798847989 = $Hann_DASH_check_DASH_temp833247993($z4798447985);
++R.GAS;
return $ret4798847989;
};
var $Hann_DASH_check_DASH_temp833247993 = function(ann_DASH_check_DASH_temp18347992) {
return ann_DASH_check_DASH_temp18347992;
};
var $Hcont_tail_arg83301469 = function(cont_tail_arg1801467,if_helper1721468) {
if(--R.GAS > 0) {
$z4799447995 = R.isFunction(if_helper1721468)?if_helper1721468.app(cont_tail_arg1801467):R.ffi.throwNonFunApp(L[136],if_helper1721468,[cont_tail_arg1801467]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper1721468)?if_helper1721468.app(cont_tail_arg1801467):R.ffi.throwNonFunApp(L[136],if_helper1721468,[cont_tail_arg1801467]);
},
"from":L[136]});
}
++R.GAS;
return $z4799447995;
};
var $Hcont_tail_arg83311484 = function(cont_tail_arg1771483,if_helper1721468) {
if(--R.GAS > 0) {
$z4799647997 = R.isFunction(if_helper1721468)?if_helper1721468.app(cont_tail_arg1771483):R.ffi.throwNonFunApp(L[136],if_helper1721468,[cont_tail_arg1771483]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper1721468)?if_helper1721468.app(cont_tail_arg1771483):R.ffi.throwNonFunApp(L[136],if_helper1721468,[cont_tail_arg1771483]);
},
"from":L[136]});
}
++R.GAS;
return $z4799647997;
};
var $Hann_DASH_check_DASH_temp83291504 = function(ann_DASH_check_DASH_temp1681503) {
return ann_DASH_check_DASH_temp1681503;
};
var $Hann_DASH_check_DASH_temp83281523 = function(ann_DASH_check_DASH_temp1601522) {
return ann_DASH_check_DASH_temp1601522;
};
var $Hanf_arg83271537 = function(anf_arg1581536,raise62) {
var $z4800048001 = D;
var $f4800648007 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg1581536):R.ffi.throwNonFunApp(L[216],raise62,[anf_arg1581536]);
};
try {
if(--R.GAS > 0) {
$z4800048001 = $f4800648007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4800648007,
"from":L[216]});
}
} catch($e4799847999) {
if(R.isCont($e4799847999)) {
var $ss4800248003 = {"from":L[216],
"go":function(ann_DASH_check_DASH_temp15648008) {
return $Hann_DASH_check_DASH_temp832648009(ann_DASH_check_DASH_temp15648008);
}};
$e4799847999.stack[R.EXN_STACKHEIGHT++] = $ss4800248003;
}
if(R.isPyretException($e4799847999)) {
$e4799847999.pyretStack.push(L[216]);
}
throw $e4799847999;
}
var $ret4800448005 = $Hann_DASH_check_DASH_temp832648009($z4800048001);
++R.GAS;
return $ret4800448005;
};
var $Hann_DASH_check_DASH_temp832648009 = function(ann_DASH_check_DASH_temp15648008) {
return ann_DASH_check_DASH_temp15648008;
};
var $Hanf_arg83251551 = function(anf_arg1541550,raise62) {
var $z4801248013 = D;
var $f4801848019 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg1541550):R.ffi.throwNonFunApp(L[219],raise62,[anf_arg1541550]);
};
try {
if(--R.GAS > 0) {
$z4801248013 = $f4801848019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4801848019,
"from":L[219]});
}
} catch($e4801048011) {
if(R.isCont($e4801048011)) {
var $ss4801448015 = {"from":L[219],
"go":function(ann_DASH_check_DASH_temp15248020) {
return $Hann_DASH_check_DASH_temp832448021(ann_DASH_check_DASH_temp15248020);
}};
$e4801048011.stack[R.EXN_STACKHEIGHT++] = $ss4801448015;
}
if(R.isPyretException($e4801048011)) {
$e4801048011.pyretStack.push(L[219]);
}
throw $e4801048011;
}
var $ret4801648017 = $Hann_DASH_check_DASH_temp832448021($z4801248013);
++R.GAS;
return $ret4801648017;
};
var $Hann_DASH_check_DASH_temp832448021 = function(ann_DASH_check_DASH_temp15248020) {
return ann_DASH_check_DASH_temp15248020;
};
var $Hanf_arg83231566 = function(anf_arg1441564,self111565,_plus55,torepr65) {
var anf_arg14548032 = G(self111565,"s",L[137]);
var $z4802448025 = D;
var $f4803048031 = function(_) {
return R.isFunction(torepr65)?torepr65.app(anf_arg14548032):R.ffi.throwNonFunApp(L[137],torepr65,[anf_arg14548032]);
};
try {
if(--R.GAS > 0) {
$z4802448025 = $f4803048031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4803048031,
"from":L[137]});
}
} catch($e4802248023) {
if(R.isCont($e4802248023)) {
var $ss4802648027 = {"from":L[137],
"go":function(anf_arg14648033) {
return $Hanf_arg832248034(anf_arg14648033,anf_arg1441564,_plus55);
}};
$e4802248023.stack[R.EXN_STACKHEIGHT++] = $ss4802648027;
}
if(R.isPyretException($e4802248023)) {
$e4802248023.pyretStack.push(L[137]);
}
throw $e4802248023;
}
var $ret4802848029 = $Hanf_arg832248034($z4802448025,anf_arg1441564,_plus55);
++R.GAS;
return $ret4802848029;
};
var $Hanf_arg832248034 = function(anf_arg14648033,anf_arg1441564,_plus55) {
var $z4803748038 = D;
var $f4804348044 = function(_) {
return R.isFunction(_plus55)?_plus55.app((", "),anf_arg14648033):R.ffi.throwNonFunApp(L[137],_plus55,[(", "),anf_arg14648033]);
};
try {
if(--R.GAS > 0) {
$z4803748038 = $f4804348044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4804348044,
"from":L[137]});
}
} catch($e4803548036) {
if(R.isCont($e4803548036)) {
var $ss4803948040 = {"from":L[137],
"go":function(anf_arg14748045) {
return $Hanf_arg832148046(anf_arg14748045,anf_arg1441564,_plus55);
}};
$e4803548036.stack[R.EXN_STACKHEIGHT++] = $ss4803948040;
}
if(R.isPyretException($e4803548036)) {
$e4803548036.pyretStack.push(L[137]);
}
throw $e4803548036;
}
var $ret4804148042 = $Hanf_arg832148046($z4803748038,anf_arg1441564,_plus55);
++R.GAS;
return $ret4804148042;
};
var $Hanf_arg832148046 = function(anf_arg14748045,anf_arg1441564,_plus55) {
var $z4804948050 = D;
var $f4805548056 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg1441564,anf_arg14748045):R.ffi.throwNonFunApp(L[137],_plus55,[anf_arg1441564,anf_arg14748045]);
};
try {
if(--R.GAS > 0) {
$z4804948050 = $f4805548056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4805548056,
"from":L[137]});
}
} catch($e4804748048) {
if(R.isCont($e4804748048)) {
var $ss4805148052 = {"from":L[137],
"go":function(anf_arg14848057) {
return $Hanf_arg832048058(anf_arg14848057,_plus55);
}};
$e4804748048.stack[R.EXN_STACKHEIGHT++] = $ss4805148052;
}
if(R.isPyretException($e4804748048)) {
$e4804748048.pyretStack.push(L[137]);
}
throw $e4804748048;
}
var $ret4805348054 = $Hanf_arg832048058($z4804948050,_plus55);
++R.GAS;
return $ret4805348054;
};
var $Hanf_arg832048058 = function(anf_arg14848057,_plus55) {
var $z4806148062 = D;
var $f4806748068 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg14848057,(")")):R.ffi.throwNonFunApp(L[137],_plus55,[anf_arg14848057,(")")]);
};
try {
if(--R.GAS > 0) {
$z4806148062 = $f4806748068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4806748068,
"from":L[137]});
}
} catch($e4805948060) {
if(R.isCont($e4805948060)) {
var $ss4806348064 = {"from":L[137],
"go":function(anf_arg14948069) {
return $Hanf_arg831948070(anf_arg14948069,_plus55);
}};
$e4805948060.stack[R.EXN_STACKHEIGHT++] = $ss4806348064;
}
if(R.isPyretException($e4805948060)) {
$e4805948060.pyretStack.push(L[137]);
}
throw $e4805948060;
}
var $ret4806548066 = $Hanf_arg831948070($z4806148062,_plus55);
++R.GAS;
return $ret4806548066;
};
var $Hanf_arg831948070 = function(anf_arg14948069,_plus55) {
var $z4807348074 = D;
var $f4807948080 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg14948069):R.ffi.throwNonFunApp(L[137],_plus55,[("("),anf_arg14948069]);
};
try {
if(--R.GAS > 0) {
$z4807348074 = $f4807948080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4807948080,
"from":L[137]});
}
} catch($e4807148072) {
if(R.isCont($e4807148072)) {
var $ss4807548076 = {"from":L[137],
"go":function(anf_arg15048081) {
return $Hanf_arg831848082(anf_arg15048081,_plus55);
}};
$e4807148072.stack[R.EXN_STACKHEIGHT++] = $ss4807548076;
}
if(R.isPyretException($e4807148072)) {
$e4807148072.pyretStack.push(L[137]);
}
throw $e4807148072;
}
var $ret4807748078 = $Hanf_arg831848082($z4807348074,_plus55);
++R.GAS;
return $ret4807748078;
};
var $Hanf_arg831848082 = function(anf_arg15048081,_plus55) {
var $z4808548086 = D;
var $f4809148092 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-name"),anf_arg15048081):R.ffi.throwNonFunApp(L[137],_plus55,[("s-name"),anf_arg15048081]);
};
try {
if(--R.GAS > 0) {
$z4808548086 = $f4809148092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4809148092,
"from":L[137]});
}
} catch($e4808348084) {
if(R.isCont($e4808348084)) {
var $ss4808748088 = {"from":L[137],
"go":function(ann_DASH_check_DASH_temp14248093) {
return $Hann_DASH_check_DASH_temp831748094(ann_DASH_check_DASH_temp14248093);
}};
$e4808348084.stack[R.EXN_STACKHEIGHT++] = $ss4808748088;
}
if(R.isPyretException($e4808348084)) {
$e4808348084.pyretStack.push(L[137]);
}
throw $e4808348084;
}
var $ret4808948090 = $Hann_DASH_check_DASH_temp831748094($z4808548086);
++R.GAS;
return $ret4808948090;
};
var $Hann_DASH_check_DASH_temp831748094 = function(ann_DASH_check_DASH_temp14248093) {
return ann_DASH_check_DASH_temp14248093;
};
var $Hcont_tail_arg83151582 = function(cont_tail_arg1391580,if_helper1301581) {
if(--R.GAS > 0) {
$z4809548096 = R.isFunction(if_helper1301581)?if_helper1301581.app(cont_tail_arg1391580):R.ffi.throwNonFunApp(L[137],if_helper1301581,[cont_tail_arg1391580]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper1301581)?if_helper1301581.app(cont_tail_arg1391580):R.ffi.throwNonFunApp(L[137],if_helper1301581,[cont_tail_arg1391580]);
},
"from":L[137]});
}
++R.GAS;
return $z4809548096;
};
var $Hcont_tail_arg83161597 = function(cont_tail_arg1351596,if_helper1301581) {
if(--R.GAS > 0) {
$z4809748098 = R.isFunction(if_helper1301581)?if_helper1301581.app(cont_tail_arg1351596):R.ffi.throwNonFunApp(L[137],if_helper1301581,[cont_tail_arg1351596]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper1301581)?if_helper1301581.app(cont_tail_arg1351596):R.ffi.throwNonFunApp(L[137],if_helper1301581,[cont_tail_arg1351596]);
},
"from":L[137]});
}
++R.GAS;
return $z4809748098;
};
var $Hann_DASH_check_DASH_temp83141618 = function(ann_DASH_check_DASH_temp1251617) {
return ann_DASH_check_DASH_temp1251617;
};
var $Hann_DASH_check_DASH_temp83131634 = function(ann_DASH_check_DASH_temp1201633) {
return ann_DASH_check_DASH_temp1201633;
};
var $Hann_DASH_check_DASH_temp83121647 = function(ann_DASH_check_DASH_temp1181646) {
return ann_DASH_check_DASH_temp1181646;
};
var $Hann_DASH_check_DASH_temp83111660 = function(ann_DASH_check_DASH_temp1161659) {
return ann_DASH_check_DASH_temp1161659;
};
var $Hanf_arg83101674 = function(anf_arg1121673,_plus55) {
var $z4810148102 = D;
var $f4810748108 = function(_) {
return R.isFunction(_plus55)?_plus55.app(anf_arg1121673,(")")):R.ffi.throwNonFunApp(L[138],_plus55,[anf_arg1121673,(")")]);
};
try {
if(--R.GAS > 0) {
$z4810148102 = $f4810748108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4810748108,
"from":L[138]});
}
} catch($e4809948100) {
if(R.isCont($e4809948100)) {
var $ss4810348104 = {"from":L[138],
"go":function(anf_arg11348109) {
return $Hanf_arg830948110(anf_arg11348109,_plus55);
}};
$e4809948100.stack[R.EXN_STACKHEIGHT++] = $ss4810348104;
}
if(R.isPyretException($e4809948100)) {
$e4809948100.pyretStack.push(L[138]);
}
throw $e4809948100;
}
var $ret4810548106 = $Hanf_arg830948110($z4810148102,_plus55);
++R.GAS;
return $ret4810548106;
};
var $Hanf_arg830948110 = function(anf_arg11348109,_plus55) {
var $z4811348114 = D;
var $f4811948120 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("("),anf_arg11348109):R.ffi.throwNonFunApp(L[138],_plus55,[("("),anf_arg11348109]);
};
try {
if(--R.GAS > 0) {
$z4811348114 = $f4811948120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4811948120,
"from":L[138]});
}
} catch($e4811148112) {
if(R.isCont($e4811148112)) {
var $ss4811548116 = {"from":L[138],
"go":function(anf_arg11448121) {
return $Hanf_arg830848122(anf_arg11448121,_plus55);
}};
$e4811148112.stack[R.EXN_STACKHEIGHT++] = $ss4811548116;
}
if(R.isPyretException($e4811148112)) {
$e4811148112.pyretStack.push(L[138]);
}
throw $e4811148112;
}
var $ret4811748118 = $Hanf_arg830848122($z4811348114,_plus55);
++R.GAS;
return $ret4811748118;
};
var $Hanf_arg830848122 = function(anf_arg11448121,_plus55) {
var $z4812548126 = D;
var $f4813148132 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("s-underscore"),anf_arg11448121):R.ffi.throwNonFunApp(L[138],_plus55,[("s-underscore"),anf_arg11448121]);
};
try {
if(--R.GAS > 0) {
$z4812548126 = $f4813148132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4813148132,
"from":L[138]});
}
} catch($e4812348124) {
if(R.isCont($e4812348124)) {
var $ss4812748128 = {"from":L[138],
"go":function(ann_DASH_check_DASH_temp11048133) {
return $Hann_DASH_check_DASH_temp830748134(ann_DASH_check_DASH_temp11048133);
}};
$e4812348124.stack[R.EXN_STACKHEIGHT++] = $ss4812748128;
}
if(R.isPyretException($e4812348124)) {
$e4812348124.pyretStack.push(L[138]);
}
throw $e4812348124;
}
var $ret4812948130 = $Hann_DASH_check_DASH_temp830748134($z4812548126);
++R.GAS;
return $ret4812948130;
};
var $Hann_DASH_check_DASH_temp830748134 = function(ann_DASH_check_DASH_temp11048133) {
return ann_DASH_check_DASH_temp11048133;
};
var $Hcont_tail_arg83051690 = function(cont_tail_arg1071688,if_helper991689) {
if(--R.GAS > 0) {
$z4813548136 = R.isFunction(if_helper991689)?if_helper991689.app(cont_tail_arg1071688):R.ffi.throwNonFunApp(L[138],if_helper991689,[cont_tail_arg1071688]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper991689)?if_helper991689.app(cont_tail_arg1071688):R.ffi.throwNonFunApp(L[138],if_helper991689,[cont_tail_arg1071688]);
},
"from":L[138]});
}
++R.GAS;
return $z4813548136;
};
var $Hcont_tail_arg83061705 = function(cont_tail_arg1041704,if_helper991689) {
if(--R.GAS > 0) {
$z4813748138 = R.isFunction(if_helper991689)?if_helper991689.app(cont_tail_arg1041704):R.ffi.throwNonFunApp(L[138],if_helper991689,[cont_tail_arg1041704]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1262) {
return R.isFunction(if_helper991689)?if_helper991689.app(cont_tail_arg1041704):R.ffi.throwNonFunApp(L[138],if_helper991689,[cont_tail_arg1041704]);
},
"from":L[138]});
}
++R.GAS;
return $z4813748138;
};
var $Hann_DASH_check_DASH_temp83041727 = function(ann_DASH_check_DASH_temp911726) {
return ann_DASH_check_DASH_temp911726;
};
var $Hanf_arg83031740 = function(anf_arg941739,_plus55,raise62) {
var $z4814148142 = D;
var $f4814748148 = function(_) {
return R.isFunction(_plus55)?_plus55.app(("No visitor field for "),anf_arg941739):R.ffi.throwNonFunApp(L[4894],_plus55,[("No visitor field for "),anf_arg941739]);
};
try {
if(--R.GAS > 0) {
$z4814148142 = $f4814748148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4814748148,
"from":L[4894]});
}
} catch($e4813948140) {
if(R.isCont($e4813948140)) {
var $ss4814348144 = {"from":L[4894],
"go":function(anf_arg9548149) {
return $Hanf_arg830248150(anf_arg9548149,raise62);
}};
$e4813948140.stack[R.EXN_STACKHEIGHT++] = $ss4814348144;
}
if(R.isPyretException($e4813948140)) {
$e4813948140.pyretStack.push(L[4894]);
}
throw $e4813948140;
}
var $ret4814548146 = $Hanf_arg830248150($z4814148142,raise62);
++R.GAS;
return $ret4814548146;
};
var $Hanf_arg830248150 = function(anf_arg9548149,raise62) {
var $z4815348154 = D;
var $f4815948160 = function(_) {
return R.isFunction(raise62)?raise62.app(anf_arg9548149):R.ffi.throwNonFunApp(L[231],raise62,[anf_arg9548149]);
};
try {
if(--R.GAS > 0) {
$z4815348154 = $f4815948160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4815948160,
"from":L[231]});
}
} catch($e4815148152) {
if(R.isCont($e4815148152)) {
var $ss4815548156 = {"from":L[231],
"go":function(ann_DASH_check_DASH_temp9348161) {
return $Hann_DASH_check_DASH_temp830148162(ann_DASH_check_DASH_temp9348161);
}};
$e4815148152.stack[R.EXN_STACKHEIGHT++] = $ss4815548156;
}
if(R.isPyretException($e4815148152)) {
$e4815148152.pyretStack.push(L[231]);
}
throw $e4815148152;
}
var $ret4815748158 = $Hann_DASH_check_DASH_temp830148162($z4815348154);
++R.GAS;
return $ret4815748158;
};
var $Hann_DASH_check_DASH_temp830148162 = function(ann_DASH_check_DASH_temp9348161) {
return ann_DASH_check_DASH_temp9348161;
};
var $Hanf_arg83001754 = function(anf_arg871752,other2421753,_greaterequal51) {
var anf_fun8848173 = G(other2421753,"key",L[4896]);
var $z4816548166 = D;
var $f4817148172 = function(_) {
return R.isFunction(anf_fun8848173)?anf_fun8848173.app():R.ffi.throwNonFunApp(L[4895],anf_fun8848173,[]);
};
try {
if(--R.GAS > 0) {
$z4816548166 = $f4817148172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4817148172,
"from":L[4895]});
}
} catch($e4816348164) {
if(R.isCont($e4816348164)) {
var $ss4816748168 = {"from":L[4895],
"go":function(anf_arg8948174) {
return $Hanf_arg829948175(anf_arg8948174,anf_arg871752,_greaterequal51);
}};
$e4816348164.stack[R.EXN_STACKHEIGHT++] = $ss4816748168;
}
if(R.isPyretException($e4816348164)) {
$e4816348164.pyretStack.push(L[4895]);
}
throw $e4816348164;
}
var $ret4816948170 = $Hanf_arg829948175($z4816548166,anf_arg871752,_greaterequal51);
++R.GAS;
return $ret4816948170;
};
var $Hanf_arg829948175 = function(anf_arg8948174,anf_arg871752,_greaterequal51) {
var $z4817848179 = D;
var $f4818448185 = function(_) {
return R.isFunction(_greaterequal51)?_greaterequal51.app(anf_arg871752,anf_arg8948174):R.ffi.throwNonFunApp(L[236],_greaterequal51,[anf_arg871752,anf_arg8948174]);
};
try {
if(--R.GAS > 0) {
$z4817848179 = $f4818448185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4818448185,
"from":L[236]});
}
} catch($e4817648177) {
if(R.isCont($e4817648177)) {
var $ss4818048181 = {"from":L[236],
"go":function(ann_DASH_check_DASH_temp8548186) {
return $Hann_DASH_check_DASH_temp829848187(ann_DASH_check_DASH_temp8548186);
}};
$e4817648177.stack[R.EXN_STACKHEIGHT++] = $ss4818048181;
}
if(R.isPyretException($e4817648177)) {
$e4817648177.pyretStack.push(L[236]);
}
throw $e4817648177;
}
var $ret4818248183 = $Hann_DASH_check_DASH_temp829848187($z4817848179);
++R.GAS;
return $ret4818248183;
};
var $Hann_DASH_check_DASH_temp829848187 = function(ann_DASH_check_DASH_temp8548186) {
return ann_DASH_check_DASH_temp8548186;
};
var $Hanf_arg82971769 = function(anf_arg811767,other2401768,_greaterthan52) {
var anf_fun8248198 = G(other2401768,"key",L[4898]);
var $z4819048191 = D;
var $f4819648197 = function(_) {
return R.isFunction(anf_fun8248198)?anf_fun8248198.app():R.ffi.throwNonFunApp(L[4897],anf_fun8248198,[]);
};
try {
if(--R.GAS > 0) {
$z4819048191 = $f4819648197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4819648197,
"from":L[4897]});
}
} catch($e4818848189) {
if(R.isCont($e4818848189)) {
var $ss4819248193 = {"from":L[4897],
"go":function(anf_arg8348199) {
return $Hanf_arg829648200(anf_arg8348199,anf_arg811767,_greaterthan52);
}};
$e4818848189.stack[R.EXN_STACKHEIGHT++] = $ss4819248193;
}
if(R.isPyretException($e4818848189)) {
$e4818848189.pyretStack.push(L[4897]);
}
throw $e4818848189;
}
var $ret4819448195 = $Hanf_arg829648200($z4819048191,anf_arg811767,_greaterthan52);
++R.GAS;
return $ret4819448195;
};
var $Hanf_arg829648200 = function(anf_arg8348199,anf_arg811767,_greaterthan52) {
var $z4820348204 = D;
var $f4820948210 = function(_) {
return R.isFunction(_greaterthan52)?_greaterthan52.app(anf_arg811767,anf_arg8348199):R.ffi.throwNonFunApp(L[239],_greaterthan52,[anf_arg811767,anf_arg8348199]);
};
try {
if(--R.GAS > 0) {
$z4820348204 = $f4820948210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4820948210,
"from":L[239]});
}
} catch($e4820148202) {
if(R.isCont($e4820148202)) {
var $ss4820548206 = {"from":L[239],
"go":function(ann_DASH_check_DASH_temp7948211) {
return $Hann_DASH_check_DASH_temp829548212(ann_DASH_check_DASH_temp7948211);
}};
$e4820148202.stack[R.EXN_STACKHEIGHT++] = $ss4820548206;
}
if(R.isPyretException($e4820148202)) {
$e4820148202.pyretStack.push(L[239]);
}
throw $e4820148202;
}
var $ret4820748208 = $Hann_DASH_check_DASH_temp829548212($z4820348204);
++R.GAS;
return $ret4820748208;
};
var $Hann_DASH_check_DASH_temp829548212 = function(ann_DASH_check_DASH_temp7948211) {
return ann_DASH_check_DASH_temp7948211;
};
var $Hanf_arg82941784 = function(anf_arg751782,other2381783,_lessequal53) {
var anf_fun7648223 = G(other2381783,"key",L[4900]);
var $z4821548216 = D;
var $f4822148222 = function(_) {
return R.isFunction(anf_fun7648223)?anf_fun7648223.app():R.ffi.throwNonFunApp(L[4899],anf_fun7648223,[]);
};
try {
if(--R.GAS > 0) {
$z4821548216 = $f4822148222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4822148222,
"from":L[4899]});
}
} catch($e4821348214) {
if(R.isCont($e4821348214)) {
var $ss4821748218 = {"from":L[4899],
"go":function(anf_arg7748224) {
return $Hanf_arg829348225(anf_arg7748224,anf_arg751782,_lessequal53);
}};
$e4821348214.stack[R.EXN_STACKHEIGHT++] = $ss4821748218;
}
if(R.isPyretException($e4821348214)) {
$e4821348214.pyretStack.push(L[4899]);
}
throw $e4821348214;
}
var $ret4821948220 = $Hanf_arg829348225($z4821548216,anf_arg751782,_lessequal53);
++R.GAS;
return $ret4821948220;
};
var $Hanf_arg829348225 = function(anf_arg7748224,anf_arg751782,_lessequal53) {
var $z4822848229 = D;
var $f4823448235 = function(_) {
return R.isFunction(_lessequal53)?_lessequal53.app(anf_arg751782,anf_arg7748224):R.ffi.throwNonFunApp(L[242],_lessequal53,[anf_arg751782,anf_arg7748224]);
};
try {
if(--R.GAS > 0) {
$z4822848229 = $f4823448235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4823448235,
"from":L[242]});
}
} catch($e4822648227) {
if(R.isCont($e4822648227)) {
var $ss4823048231 = {"from":L[242],
"go":function(ann_DASH_check_DASH_temp7348236) {
return $Hann_DASH_check_DASH_temp829248237(ann_DASH_check_DASH_temp7348236);
}};
$e4822648227.stack[R.EXN_STACKHEIGHT++] = $ss4823048231;
}
if(R.isPyretException($e4822648227)) {
$e4822648227.pyretStack.push(L[242]);
}
throw $e4822648227;
}
var $ret4823248233 = $Hann_DASH_check_DASH_temp829248237($z4822848229);
++R.GAS;
return $ret4823248233;
};
var $Hann_DASH_check_DASH_temp829248237 = function(ann_DASH_check_DASH_temp7348236) {
return ann_DASH_check_DASH_temp7348236;
};
var $Hanf_arg82911799 = function(anf_arg691797,other2361798,_lessthan54) {
var anf_fun7048248 = G(other2361798,"key",L[4902]);
var $z4824048241 = D;
var $f4824648247 = function(_) {
return R.isFunction(anf_fun7048248)?anf_fun7048248.app():R.ffi.throwNonFunApp(L[4901],anf_fun7048248,[]);
};
try {
if(--R.GAS > 0) {
$z4824048241 = $f4824648247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4824648247,
"from":L[4901]});
}
} catch($e4823848239) {
if(R.isCont($e4823848239)) {
var $ss4824248243 = {"from":L[4901],
"go":function(anf_arg7148249) {
return $Hanf_arg829048250(anf_arg7148249,anf_arg691797,_lessthan54);
}};
$e4823848239.stack[R.EXN_STACKHEIGHT++] = $ss4824248243;
}
if(R.isPyretException($e4823848239)) {
$e4823848239.pyretStack.push(L[4901]);
}
throw $e4823848239;
}
var $ret4824448245 = $Hanf_arg829048250($z4824048241,anf_arg691797,_lessthan54);
++R.GAS;
return $ret4824448245;
};
var $Hanf_arg829048250 = function(anf_arg7148249,anf_arg691797,_lessthan54) {
var $z4825348254 = D;
var $f4825948260 = function(_) {
return R.isFunction(_lessthan54)?_lessthan54.app(anf_arg691797,anf_arg7148249):R.ffi.throwNonFunApp(L[245],_lessthan54,[anf_arg691797,anf_arg7148249]);
};
try {
if(--R.GAS > 0) {
$z4825348254 = $f4825948260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4825948260,
"from":L[245]});
}
} catch($e4825148252) {
if(R.isCont($e4825148252)) {
var $ss4825548256 = {"from":L[245],
"go":function(ann_DASH_check_DASH_temp6748261) {
return $Hann_DASH_check_DASH_temp828948262(ann_DASH_check_DASH_temp6748261);
}};
$e4825148252.stack[R.EXN_STACKHEIGHT++] = $ss4825548256;
}
if(R.isPyretException($e4825148252)) {
$e4825148252.pyretStack.push(L[245]);
}
throw $e4825148252;
}
var $ret4825748258 = $Hann_DASH_check_DASH_temp828948262($z4825348254);
++R.GAS;
return $ret4825748258;
};
var $Hann_DASH_check_DASH_temp828948262 = function(ann_DASH_check_DASH_temp6748261) {
return ann_DASH_check_DASH_temp6748261;
};
return R.loadModulesNew(NAMESPACE,[$PP17087,$S37188,$C57289,$arrays77390,$lists97491,$option117592,$error137693,$sets157794],function($PP17087,$S37188,$C57289,$arrays77390,$lists97491,$option117592,$error137693,$sets157794) {
var PP170 = R.getField($PP17087,"values");
var S371 = R.getField($S37188,"values");
var C572 = R.getField($C57289,"values");
var arrays773 = R.getField($arrays77390,"values");
var lists974 = R.getField($lists97491,"values");
var option1175 = R.getField($option117592,"values");
var error1376 = R.getField($error137693,"values");
var sets1577 = R.getField($sets157794,"values");
var PP278 = R.getField($PP17087,"types");
var S479 = R.getField($S37188,"types");
var C680 = R.getField($C57289,"types");
var arrays881 = R.getField($arrays77390,"types");
var lists1082 = R.getField($lists97491,"types");
var option1283 = R.getField($option117592,"types");
var error1484 = R.getField($error137693,"types");
var sets1685 = R.getField($sets157794,"types");
return R.safeCall(function() {
var List17129 = R.getDotAnn(L[4903],"lists",lists1082,"List");
var Option18135 = R.getDotAnn(L[4903],"option",option1283,"Option");
var Array1948263 = R.getDotAnn(L[4903],"arrays",arrays881,"Array");
var Set2048264 = R.getDotAnn(L[4903],"sets",sets1685,"Set");
var array2148313 = G(arrays773,"array",L[4903]);
var build_DASH_array2248312 = G(arrays773,"build-array",L[4903]);
var array_DASH_from_DASH_list2348311 = G(arrays773,"array-from-list",L[4903]);
var is_DASH_array2448310 = G(arrays773,"is-array",L[4903]);
var list25154 = G(lists974,"list",L[4903]);
var is_DASH_empty26152 = G(lists974,"is-empty",L[4903]);
var is_DASH_link2748309 = G(lists974,"is-link",L[4903]);
var empty28150 = G(lists974,"empty",L[4903]);
var link29153 = G(lists974,"link",L[4903]);
var range3048308 = G(lists974,"range",L[4903]);
var repeat3148307 = G(lists974,"repeat",L[4903]);
var filter3248306 = G(lists974,"filter",L[4903]);
var partition3348305 = G(lists974,"partition",L[4903]);
var split_DASH_at3448304 = G(lists974,"split-at",L[4903]);
var any3548303 = G(lists974,"any",L[4903]);
var find3648302 = G(lists974,"find",L[4903]);
var map3748301 = G(lists974,"map",L[4903]);
var map23848300 = G(lists974,"map2",L[4903]);
var map33948299 = G(lists974,"map3",L[4903]);
var map44048298 = G(lists974,"map4",L[4903]);
var map_n4148297 = G(lists974,"map_n",L[4903]);
var map2_n4248296 = G(lists974,"map2_n",L[4903]);
var map3_n4348295 = G(lists974,"map3_n",L[4903]);
var map4_n4448294 = G(lists974,"map4_n",L[4903]);
var each4548293 = G(lists974,"each",L[4903]);
var each24648292 = G(lists974,"each2",L[4903]);
var each34748291 = G(lists974,"each3",L[4903]);
var each44848290 = G(lists974,"each4",L[4903]);
var each_n4948289 = G(lists974,"each_n",L[4903]);
var each2_n5048288 = G(lists974,"each2_n",L[4903]);
var each3_n5148287 = G(lists974,"each3_n",L[4903]);
var each4_n5248286 = G(lists974,"each4_n",L[4903]);
var fold53151 = G(lists974,"fold",L[4903]);
var fold25448285 = G(lists974,"fold2",L[4903]);
var fold35548284 = G(lists974,"fold3",L[4903]);
var fold45648283 = G(lists974,"fold4",L[4903]);
var index5748282 = G(lists974,"index",L[4903]);
var Option5848281 = G(option1175,"Option",L[4903]);
var is_DASH_none5948280 = G(option1175,"is-none",L[4903]);
var is_DASH_some6048279 = G(option1175,"is-some",L[4903]);
var none61155 = G(option1175,"none",L[4903]);
var some62156 = G(option1175,"some",L[4903]);
var set6348278 = G(sets1577,"set",L[4903]);
var tree_DASH_set6448277 = G(sets1577,"tree-set",L[4903]);
var list_DASH_set6548276 = G(sets1577,"list-set",L[4903]);
var NameT167134 = R.namedBrander("Name");
var Name66133 = R.makeBranderAnn(NameT167134,"Name");
var ProgramT269137 = R.namedBrander("Program");
var Program68136 = R.makeBranderAnn(ProgramT269137,"Program");
var ImportT371122 = R.namedBrander("Import");
var Import70121 = R.makeBranderAnn(ImportT371122,"Import");
var ProvideT473139 = R.namedBrander("Provide");
var Provide72138 = R.makeBranderAnn(ProvideT473139,"Provide");
var ProvideTypesT575141 = R.namedBrander("ProvideTypes");
var ProvideTypes74140 = R.makeBranderAnn(ProvideTypesT575141,"ProvideTypes");
var ImportTypeT677124 = R.namedBrander("ImportType");
var ImportType76123 = R.makeBranderAnn(ImportTypeT677124,"ImportType");
var HintT779116 = R.namedBrander("Hint");
var Hint78115 = R.makeBranderAnn(HintT779116,"Hint");
var LetBindT881126 = R.namedBrander("LetBind");
var LetBind80125 = R.makeBranderAnn(LetBindT881126,"LetBind");
var LetrecBindT983128 = R.namedBrander("LetrecBind");
var LetrecBind82127 = R.makeBranderAnn(LetrecBindT983128,"LetrecBind");
var TypeLetBindT1085143 = R.namedBrander("TypeLetBind");
var TypeLetBind84142 = R.makeBranderAnn(TypeLetBindT1085143,"TypeLetBind");
var ExprT1187112 = R.namedBrander("Expr");
var Expr86111 = R.makeBranderAnn(ExprT1187112,"Expr");
var ConstructModifierT1289106 = R.namedBrander("ConstructModifier");
var ConstructModifier88105 = R.makeBranderAnn(ConstructModifierT1289106,"ConstructModifier");
var BindT1391102 = R.namedBrander("Bind");
var Bind90101 = R.makeBranderAnn(BindT1391102,"Bind");
var MemberT1493132 = R.namedBrander("Member");
var Member92131 = R.makeBranderAnn(MemberT1493132,"Member");
var ForBindT1595114 = R.namedBrander("ForBind");
var ForBind94113 = R.makeBranderAnn(ForBindT1595114,"ForBind");
var VariantMemberTypeT1697148 = R.namedBrander("VariantMemberType");
var VariantMemberType96147 = R.makeBranderAnn(VariantMemberTypeT1697148,"VariantMemberType");
var VariantMemberT1799146 = R.namedBrander("VariantMember");
var VariantMember98145 = R.makeBranderAnn(VariantMemberT1799146,"VariantMember");
var VariantT18101149 = R.namedBrander("Variant");
var Variant100144 = R.makeBranderAnn(VariantT18101149,"Variant");
var DatatypeVariantT19103110 = R.namedBrander("DatatypeVariant");
var DatatypeVariant102109 = R.makeBranderAnn(DatatypeVariantT19103110,"DatatypeVariant");
var ConstructorT20105108 = R.namedBrander("Constructor");
var Constructor104107 = R.makeBranderAnn(ConstructorT20105108,"Constructor");
var IfBranchT21107118 = R.namedBrander("IfBranch");
var IfBranch106117 = R.makeBranderAnn(IfBranchT21107118,"IfBranch");
var IfPipeBranchT22109120 = R.namedBrander("IfPipeBranch");
var IfPipeBranch108119 = R.makeBranderAnn(IfPipeBranchT22109120,"IfPipeBranch");
var CasesBranchT23111104 = R.namedBrander("CasesBranch");
var CasesBranch110103 = R.makeBranderAnn(CasesBranchT23111104,"CasesBranch");
var AnnT24113100 = R.namedBrander("Ann");
var Ann11299 = R.makeBranderAnn(AnnT24113100,"Ann");
var AFieldT2511598 = R.namedBrander("AField");
var AField11497 = R.makeBranderAnn(AFieldT2511598,"AField");
var Loc116130 = R.getDotAnn(L[4904],"S",S479,"Srcloc");
var anf_fun148275 = G(S371,"builtin",L[4906]);
var $z4826748268 = D;
var $f4827348274 = function(_) {
return R.isFunction(anf_fun148275)?anf_fun148275.app(("dummy location")):R.ffi.throwNonFunApp(L[4905],anf_fun148275,[("dummy location")]);
};
try {
if(--R.GAS > 0) {
$z4826748268 = $f4827348274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4827348274,
"from":L[4905]});
}
} catch($e4826548266) {
if(R.isCont($e4826548266)) {
var $ss4826948270 = {"from":L[4905],
"go":function(dummy_DASH_loc11796) {
return $Hdummy_DASH_loc1150995(dummy_DASH_loc11796,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
}};
$e4826548266.stack[R.EXN_STACKHEIGHT++] = $ss4826948270;
}
if(R.isPyretException($e4826548266)) {
$e4826548266.pyretStack.push(L[4905]);
}
throw $e4826548266;
}
var $ret4827148272 = $Hdummy_DASH_loc1150995($z4826748268,AField11497,AFieldT2511598,Ann11299,AnnT24113100,Bind90101,BindT1391102,CasesBranch110103,CasesBranchT23111104,ConstructModifier88105,ConstructModifierT1289106,Constructor104107,ConstructorT20105108,DatatypeVariant102109,DatatypeVariantT19103110,Expr86111,ExprT1187112,ForBind94113,ForBindT1595114,Hint78115,HintT779116,IfBranch106117,IfBranchT21107118,IfPipeBranch108119,IfPipeBranchT22109120,Import70121,ImportT371122,ImportType76123,ImportTypeT677124,LetBind80125,LetBindT881126,LetrecBind82127,LetrecBindT983128,List17129,Loc116130,Member92131,MemberT1493132,Name66133,NameT167134,Option18135,PP170,PP278,Program68136,ProgramT269137,Provide72138,ProvideT473139,ProvideTypes74140,ProvideTypesT575141,TypeLetBind84142,TypeLetBindT1085143,Variant100144,VariantMember98145,VariantMemberT1799146,VariantMemberType96147,VariantMemberTypeT1697148,VariantT18101149,empty28150,fold53151,is_DASH_empty26152,link29153,list25154,lists974,none61155,some62156,_greaterequal51,_greaterthan52,_lessequal53,_lessthan54,_plus55,_times56,builtins57,is_DASH_nothing58,is_DASH_string59,not60,nothing61,raise62,string_DASH_length63,string_DASH_substring64,torepr65,tostring66,$type$Boolean67,$type$Number68,$type$String69);
++R.GAS;
return $ret4827148272;
},function(moduleVal) {
R.modules["$src/arr/trove/ast.arr86"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/compile-structs.arr',["trove/ast",
"trove/srcloc",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($A12035,$SL32136,$arrays52237,$lists72338,$option92439,$error112540,$sets132641) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/compile-structs.arr34"]) {
return R.modules["$src/arr/compiler/compile-structs.arr34"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/compile-structs.arr";
var D = R.undefined;
var L = [[M,88,0,3403,97,2,3548],
[M,101,34,3626,101,49,3641],
[M,100,2,3585,106,5,3815],
[M,101,4,3596,101,50,3642],
[M,102,35,3679,102,52,3696],
[M,102,4,3648,102,53,3697],
[M,103,35,3734,103,51,3750],
[M,103,4,3703,103,52,3751],
[M,104,33,3786,104,46,3799],
[M,104,4,3757,104,47,3800],
[M,99,0,3550,106,5,3815],
[M,113,41,3975,187,1,5152],
[M,113,19,3953,113,28,3962],
[M,110,2,3869,110,61,3928],
[M,109,2,3840,109,28,3866],
[M,108,0,3817,111,3,3932],
[M,109,4,3842,109,28,3866],
[M,109,21,3859,109,27,3865],
[M,110,4,3871,110,61,3928],
[M,110,28,3895,110,34,3901],
[M,110,48,3915,110,60,3927],
[M,110,36,3903,110,60,3927],
[M,110,20,3887,110,34,3901],
[M,109,15,3853,109,27,3865],
[M,113,0,3934,187,2,5153],
[M,189,26,5181,189,34,5189],
[M,189,36,5191,189,44,5199],
[M,189,0,5155,189,45,5200],
[M,191,0,5202,191,63,5265],
[M,194,34,5335,230,3,5885],
[M,194,2,5303,230,5,5887],
[M,194,9,5310,230,4,5886],
[M,194,2,5303,353,5,7640],
[M,231,43,5933,353,3,7638],
[M,231,21,5911,231,30,5920],
[M,231,21,5911,353,4,7639],
[M,193,0,5267,355,1,7658],
[M,359,6,7730,359,25,7749],
[M,358,23,7716,415,5,8919],
[M,360,6,7757,360,26,7777],
[M,361,32,7811,366,9,7922],
[M,361,6,7785,366,10,7923],
[M,367,31,7956,401,9,8611],
[M,367,6,7931,401,10,8612],
[M,402,32,8646,408,9,8760],
[M,402,6,8620,408,10,8761],
[M,409,31,8794,409,39,8802],
[M,409,6,8769,409,40,8803],
[M,410,30,8835,414,9,8912],
[M,410,6,8811,414,10,8913],
[M,358,4,7697,415,6,8920],
[M,357,0,7660,417,5,8945],
[M,10,0,98,13,3,144],
[M,85,2,3333,85,66,3397],
[M,84,2,3307,84,25,3330],
[M,78,6,3104,79,85,3266],
[M,78,60,3158,78,82,3180],
[M,78,69,3167,78,81,3179],
[M,79,47,3228,79,83,3264],
[M,79,70,3251,79,82,3263],
[M,79,47,3228,79,69,3250],
[M,79,47,3228,79,59,3240],
[M,79,23,3204,79,42,3223],
[M,79,23,3204,79,35,3216],
[M,79,43,3224,79,84,3265],
[M,79,23,3204,79,85,3266],
[M,77,4,3082,80,7,3274],
[M,76,2,3011,80,7,3274],
[M,73,6,2824,74,106,3000],
[M,73,53,2871,73,75,2893],
[M,73,62,2880,73,74,2892],
[M,74,68,2962,74,104,2998],
[M,74,91,2985,74,103,2997],
[M,74,68,2962,74,90,2984],
[M,74,68,2962,74,80,2974],
[M,74,44,2938,74,63,2957],
[M,74,44,2938,74,56,2950],
[M,74,64,2958,74,105,2999],
[M,74,44,2938,74,106,3000],
[M,72,4,2802,75,7,3008],
[M,71,2,2734,75,7,3008],
[M,68,57,2590,68,79,2612],
[M,68,66,2599,68,78,2611],
[M,68,6,2539,69,104,2723],
[M,69,61,2680,69,96,2715],
[M,69,84,2703,69,95,2714],
[M,69,61,2680,69,83,2702],
[M,69,61,2680,69,73,2692],
[M,69,38,2657,69,56,2675],
[M,69,38,2657,69,49,2668],
[M,69,57,2676,69,97,2716],
[M,69,38,2657,69,98,2717],
[M,67,4,2517,70,7,2731],
[M,66,2,2447,70,7,2731],
[M,62,6,2191,64,79,2436],
[M,62,53,2238,62,71,2256],
[M,62,62,2247,62,70,2255],
[M,63,64,2321,63,97,2354],
[M,63,83,2340,63,96,2353],
[M,63,64,2321,63,82,2339],
[M,63,64,2321,63,72,2329],
[M,63,39,2296,63,59,2316],
[M,63,39,2296,63,52,2309],
[M,63,60,2317,63,98,2355],
[M,63,39,2296,63,99,2356],
[M,61,4,2169,65,7,2444],
[M,60,2,2099,65,7,2444],
[M,58,6,2001,58,93,2088],
[M,57,4,1979,59,7,2096],
[M,56,2,1938,59,7,2096],
[M,54,6,1844,54,89,1927],
[M,53,4,1822,55,7,1935],
[M,52,2,1784,55,7,1935],
[M,50,6,1642,50,137,1773],
[M,50,81,1717,50,99,1735],
[M,50,90,1726,50,98,1734],
[M,49,4,1620,51,7,1781],
[M,48,2,1560,51,7,1781],
[M,46,6,1423,46,132,1549],
[M,46,77,1494,46,96,1513],
[M,46,86,1503,46,95,1512],
[M,46,86,1503,46,93,1510],
[M,45,4,1401,47,7,1557],
[M,44,2,1359,47,7,1557],
[M,42,6,1276,42,78,1348],
[M,42,60,1330,42,78,1348],
[M,42,69,1339,42,77,1347],
[M,41,4,1254,43,7,1356],
[M,40,2,1204,43,7,1356],
[M,38,6,1093,38,106,1193],
[M,38,62,1149,38,81,1168],
[M,38,71,1158,38,80,1167],
[M,38,71,1158,38,78,1165],
[M,37,4,1071,39,7,1201],
[M,36,2,1034,39,7,1201],
[M,34,6,893,34,136,1023],
[M,34,118,1005,34,136,1023],
[M,34,127,1014,34,135,1022],
[M,33,4,871,35,7,1031],
[M,32,2,829,35,7,1031],
[M,31,6,735,31,93,822],
[M,31,75,804,31,93,822],
[M,31,84,813,31,92,821],
[M,30,4,713,31,97,826],
[M,29,2,661,31,97,826],
[M,28,20,575,28,99,654],
[M,28,62,617,28,84,639],
[M,28,62,617,28,74,629],
[M,28,62,617,28,70,625],
[M,28,62,617,28,99,654],
[M,28,62,617,28,93,648],
[M,28,4,559,28,103,658],
[M,27,2,499,28,103,658],
[M,26,20,432,26,80,492],
[M,26,62,474,26,80,492],
[M,26,71,483,26,79,491],
[M,26,4,416,26,84,496],
[M,25,2,368,26,84,496],
[M,21,2,304,21,39,341],
[M,20,2,286,20,17,301],
[M,16,2,173,16,84,255],
[M,12,2,129,12,13,140],
[M,11,2,119,11,9,126],
[M,3,0,13,417,5,8945],
[M,8,11,87,8,20,96],
[M,88,35,3438,97,1,3547],
[M,88,16,3419,88,25,3428],
[M,83,0,3280,86,3,3401],
[M,84,4,3309,84,25,3330],
[M,84,18,3323,84,24,3329],
[M,85,4,3335,85,66,3397],
[M,85,33,3364,85,39,3370],
[M,85,53,3384,85,65,3396],
[M,85,41,3372,85,65,3396],
[M,85,25,3356,85,39,3370],
[M,84,12,3317,84,24,3329],
[M,24,0,347,81,3,3278],
[M,25,4,370,25,39,405],
[M,25,33,399,25,38,404],
[M,25,18,384,25,24,390],
[M,27,4,501,27,51,548],
[M,27,24,521,27,30,527],
[M,27,39,536,27,50,547],
[M,29,4,663,29,43,702],
[M,29,25,684,29,28,687],
[M,29,36,695,29,42,701],
[M,32,4,831,32,33,860],
[M,36,4,1036,36,28,1060],
[M,36,21,1053,36,27,1059],
[M,40,4,1206,40,41,1243],
[M,40,22,1224,40,28,1230],
[M,40,37,1239,40,40,1242],
[M,44,4,1361,44,33,1390],
[M,44,27,1384,44,32,1389],
[M,48,4,1562,48,51,1609],
[M,48,44,1602,48,50,1608],
[M,48,31,1589,48,34,1592],
[M,52,4,1786,52,29,1811],
[M,52,25,1807,52,28,1810],
[M,56,4,1940,56,32,1968],
[M,56,28,1964,56,31,1967],
[M,60,4,2101,60,61,2158],
[M,60,25,2122,60,31,2128],
[M,60,40,2137,60,43,2140],
[M,60,57,2154,60,60,2157],
[M,66,4,2449,66,61,2506],
[M,66,23,2468,66,29,2474],
[M,66,42,2487,66,45,2490],
[M,66,57,2502,66,60,2505],
[M,71,4,2736,71,59,2791],
[M,71,20,2752,71,26,2758],
[M,71,39,2771,71,42,2774],
[M,71,55,2787,71,58,2790],
[M,76,4,3013,76,62,3071],
[M,76,23,3032,76,29,3038],
[M,76,42,3051,76,45,3054],
[M,76,58,3067,76,61,3070],
[M,78,22,3120,78,29,3127],
[M,76,47,3056,76,61,3070],
[M,76,31,3040,76,45,3054],
[M,76,17,3026,76,29,3038],
[M,73,22,2840,73,29,2847],
[M,71,44,2776,71,58,2790],
[M,71,28,2760,71,42,2774],
[M,71,14,2746,71,26,2758],
[M,68,6,2539,68,13,2546],
[M,66,47,2492,66,60,2505],
[M,66,31,2476,66,45,2490],
[M,66,17,2462,66,29,2474],
[M,62,22,2207,62,29,2214],
[M,60,45,2142,60,60,2157],
[M,60,33,2130,60,43,2140],
[M,60,19,2116,60,31,2128],
[M,58,39,2034,58,57,2052],
[M,58,48,2043,58,56,2051],
[M,56,21,1957,56,31,1967],
[M,54,45,1883,54,63,1901],
[M,54,54,1892,54,62,1900],
[M,52,18,1800,52,28,1810],
[M,50,22,1658,50,41,1677],
[M,50,31,1667,50,40,1676],
[M,48,36,1594,48,50,1608],
[M,48,24,1582,48,34,1592],
[M,46,22,1439,46,42,1459],
[M,46,22,1439,46,40,1457],
[M,46,22,1439,46,33,1450],
[M,46,22,1439,46,30,1447],
[M,44,20,1377,44,32,1389],
[M,42,41,1311,42,48,1318],
[M,40,30,1232,40,40,1242],
[M,40,16,1218,40,28,1230],
[M,38,22,1109,38,42,1129],
[M,38,31,1118,38,41,1128],
[M,38,31,1118,38,38,1125],
[M,36,15,1047,36,27,1059],
[M,34,82,969,34,106,993],
[M,34,91,978,34,105,992],
[M,32,23,850,32,32,859],
[M,32,18,845,32,21,848],
[M,31,39,768,31,46,775],
[M,29,30,689,29,42,701],
[M,29,18,677,29,28,687],
[M,28,42,597,28,50,605],
[M,27,32,529,27,50,547],
[M,27,17,514,27,30,527],
[M,26,42,454,26,50,462],
[M,25,26,392,25,38,404],
[M,25,11,377,25,24,390],
[M,19,0,261,22,3,345],
[M,20,4,288,20,17,301],
[M,21,4,306,21,39,341],
[M,21,20,322,21,38,340],
[M,21,8,310,21,38,340],
[M,20,7,291,20,16,300],
[M,15,0,146,17,3,259],
[M,16,4,175,16,84,255],
[M,16,28,199,16,48,219],
[M,16,59,230,16,83,254],
[M,16,50,221,16,83,254],
[M,16,16,187,16,48,219]];
var _plus13 = NAMESPACE.get("_plus");
var builtins14 = NAMESPACE.get("builtins");
var not15 = NAMESPACE.get("not");
var nothing16 = NAMESPACE.get("nothing");
var torepr17 = NAMESPACE.get("torepr");
var tostring18 = NAMESPACE.get("tostring");
var $type$String19 = NAMESPACE.get("$type$String");
var $Hanf_arg107242 = function(anf_arg65943,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun65760,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var $z109110 = D;
var $f115116 = function(_) {
return R.isFunction(anf_fun65760)?anf_fun65760.app(type_DASH_id13198.$var,anf_arg65943):R.ffi.throwNonFunApp(L[0],anf_fun65760,[type_DASH_id13198.$var,anf_arg65943]);
};
try {
if(--R.GAS > 0) {
$z109110 = $f115116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f115116,
"from":L[0]});
}
} catch($e107108) {
if(R.isCont($e107108)) {
var $ss111112 = {"from":L[0],
"go":function(runtime_DASH_types184117) {
return $Hruntime_DASH_types1071118(runtime_DASH_types184117,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e107108.stack[R.EXN_STACKHEIGHT++] = $ss111112;
}
if(R.isPyretException($e107108)) {
$e107108.pyretStack.push(L[0]);
}
throw $e107108;
}
var $ret113114 = $Hruntime_DASH_types1071118($z109110,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret113114;
};
var $Hruntime_DASH_types1071118 = function(runtime_DASH_types184117,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var anf_fun660131 = G(list2391,"make",L[2]);
var anf_fun661129 = G(list2391,"make",L[1]);
var $z121122 = D;
var $f127128 = function(_) {
return R.isFunction(anf_fun661129)?anf_fun661129.app([("List")]):R.ffi.throwNonFunApp(L[1],anf_fun661129,[[("List")]]);
};
try {
if(--R.GAS > 0) {
$z121122 = $f127128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f127128,
"from":L[1]});
}
} catch($e119120) {
if(R.isCont($e119120)) {
var $ss123124 = {"from":L[1],
"go":function(anf_arg662130) {
return $Hanf_arg1070132(anf_arg662130,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e119120.stack[R.EXN_STACKHEIGHT++] = $ss123124;
}
if(R.isPyretException($e119120)) {
$e119120.pyretStack.push(L[1]);
}
throw $e119120;
}
var $ret125126 = $Hanf_arg1070132($z121122,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret125126;
};
var $Hanf_arg1070132 = function(anf_arg662130,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var $z135136 = D;
var $f141142 = function(_) {
return R.isFunction(type_DASH_module_DASH_bindings13399.$var)?type_DASH_module_DASH_bindings13399.$var.app(("lists"),anf_arg662130):R.ffi.throwNonFunApp(L[3],type_DASH_module_DASH_bindings13399.$var,[("lists"),anf_arg662130]);
};
try {
if(--R.GAS > 0) {
$z135136 = $f141142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f141142,
"from":L[3]});
}
} catch($e133134) {
if(R.isCont($e133134)) {
var $ss137138 = {"from":L[3],
"go":function(anf_array_val663143) {
return $Hanf_array_val1069144(anf_array_val663143,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e133134.stack[R.EXN_STACKHEIGHT++] = $ss137138;
}
if(R.isPyretException($e133134)) {
$e133134.pyretStack.push(L[3]);
}
throw $e133134;
}
var $ret139140 = $Hanf_array_val1069144($z135136,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret139140;
};
var $Hanf_array_val1069144 = function(anf_array_val663143,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var anf_fun664155 = G(list2391,"make",L[4]);
var $z147148 = D;
var $f153154 = function(_) {
return R.isFunction(anf_fun664155)?anf_fun664155.app([("Option")]):R.ffi.throwNonFunApp(L[4],anf_fun664155,[[("Option")]]);
};
try {
if(--R.GAS > 0) {
$z147148 = $f153154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f153154,
"from":L[4]});
}
} catch($e145146) {
if(R.isCont($e145146)) {
var $ss149150 = {"from":L[4],
"go":function(anf_arg665156) {
return $Hanf_arg1068157(anf_arg665156,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e145146.stack[R.EXN_STACKHEIGHT++] = $ss149150;
}
if(R.isPyretException($e145146)) {
$e145146.pyretStack.push(L[4]);
}
throw $e145146;
}
var $ret151152 = $Hanf_arg1068157($z147148,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret151152;
};
var $Hanf_arg1068157 = function(anf_arg665156,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var $z160161 = D;
var $f166167 = function(_) {
return R.isFunction(type_DASH_module_DASH_bindings13399.$var)?type_DASH_module_DASH_bindings13399.$var.app(("option"),anf_arg665156):R.ffi.throwNonFunApp(L[5],type_DASH_module_DASH_bindings13399.$var,[("option"),anf_arg665156]);
};
try {
if(--R.GAS > 0) {
$z160161 = $f166167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f166167,
"from":L[5]});
}
} catch($e158159) {
if(R.isCont($e158159)) {
var $ss162163 = {"from":L[5],
"go":function(anf_array_val666168) {
return $Hanf_array_val1067169(anf_array_val666168,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e158159.stack[R.EXN_STACKHEIGHT++] = $ss162163;
}
if(R.isPyretException($e158159)) {
$e158159.pyretStack.push(L[5]);
}
throw $e158159;
}
var $ret164165 = $Hanf_array_val1067169($z160161,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret164165;
};
var $Hanf_array_val1067169 = function(anf_array_val666168,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var anf_fun667180 = G(list2391,"make",L[6]);
var $z172173 = D;
var $f178179 = function(_) {
return R.isFunction(anf_fun667180)?anf_fun667180.app([("Array")]):R.ffi.throwNonFunApp(L[6],anf_fun667180,[[("Array")]]);
};
try {
if(--R.GAS > 0) {
$z172173 = $f178179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f178179,
"from":L[6]});
}
} catch($e170171) {
if(R.isCont($e170171)) {
var $ss174175 = {"from":L[6],
"go":function(anf_arg668181) {
return $Hanf_arg1066182(anf_arg668181,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e170171.stack[R.EXN_STACKHEIGHT++] = $ss174175;
}
if(R.isPyretException($e170171)) {
$e170171.pyretStack.push(L[6]);
}
throw $e170171;
}
var $ret176177 = $Hanf_arg1066182($z172173,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret176177;
};
var $Hanf_arg1066182 = function(anf_arg668181,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var $z185186 = D;
var $f191192 = function(_) {
return R.isFunction(type_DASH_module_DASH_bindings13399.$var)?type_DASH_module_DASH_bindings13399.$var.app(("arrays"),anf_arg668181):R.ffi.throwNonFunApp(L[7],type_DASH_module_DASH_bindings13399.$var,[("arrays"),anf_arg668181]);
};
try {
if(--R.GAS > 0) {
$z185186 = $f191192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f191192,
"from":L[7]});
}
} catch($e183184) {
if(R.isCont($e183184)) {
var $ss187188 = {"from":L[7],
"go":function(anf_array_val669193) {
return $Hanf_array_val1065194(anf_array_val669193,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e183184.stack[R.EXN_STACKHEIGHT++] = $ss187188;
}
if(R.isPyretException($e183184)) {
$e183184.pyretStack.push(L[7]);
}
throw $e183184;
}
var $ret189190 = $Hanf_array_val1065194($z185186,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret189190;
};
var $Hanf_array_val1065194 = function(anf_array_val669193,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var anf_fun670205 = G(list2391,"make",L[8]);
var $z197198 = D;
var $f203204 = function(_) {
return R.isFunction(anf_fun670205)?anf_fun670205.app([("Set")]):R.ffi.throwNonFunApp(L[8],anf_fun670205,[[("Set")]]);
};
try {
if(--R.GAS > 0) {
$z197198 = $f203204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f203204,
"from":L[8]});
}
} catch($e195196) {
if(R.isCont($e195196)) {
var $ss199200 = {"from":L[8],
"go":function(anf_arg671206) {
return $Hanf_arg1064207(anf_arg671206,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_array_val669193,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e195196.stack[R.EXN_STACKHEIGHT++] = $ss199200;
}
if(R.isPyretException($e195196)) {
$e195196.pyretStack.push(L[8]);
}
throw $e195196;
}
var $ret201202 = $Hanf_arg1064207($z197198,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_array_val669193,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret201202;
};
var $Hanf_arg1064207 = function(anf_arg671206,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_array_val669193,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var $z210211 = D;
var $f216217 = function(_) {
return R.isFunction(type_DASH_module_DASH_bindings13399.$var)?type_DASH_module_DASH_bindings13399.$var.app(("sets"),anf_arg671206):R.ffi.throwNonFunApp(L[9],type_DASH_module_DASH_bindings13399.$var,[("sets"),anf_arg671206]);
};
try {
if(--R.GAS > 0) {
$z210211 = $f216217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f216217,
"from":L[9]});
}
} catch($e208209) {
if(R.isCont($e208209)) {
var $ss212213 = {"from":L[9],
"go":function(anf_array_val672218) {
return $Hanf_array_val1063219(anf_array_val672218,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_array_val669193,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e208209.stack[R.EXN_STACKHEIGHT++] = $ss212213;
}
if(R.isPyretException($e208209)) {
$e208209.pyretStack.push(L[9]);
}
throw $e208209;
}
var $ret214215 = $Hanf_array_val1063219($z210211,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_array_val669193,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret214215;
};
var $Hanf_array_val1063219 = function(anf_array_val672218,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val663143,anf_array_val666168,anf_array_val669193,anf_fun660131,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var $z222223 = D;
var $f228229 = function(_) {
return R.isFunction(anf_fun660131)?anf_fun660131.app([anf_array_val663143,anf_array_val666168,anf_array_val669193,anf_array_val672218]):R.ffi.throwNonFunApp(L[2],anf_fun660131,[[anf_array_val663143,anf_array_val666168,anf_array_val669193,anf_array_val672218]]);
};
try {
if(--R.GAS > 0) {
$z222223 = $f228229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f228229,
"from":L[2]});
}
} catch($e220221) {
if(R.isCont($e220221)) {
var $ss224225 = {"from":L[2],
"go":function(anf_arg673230) {
return $Hanf_arg1062231(anf_arg673230,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e220221.stack[R.EXN_STACKHEIGHT++] = $ss224225;
}
if(R.isPyretException($e220221)) {
$e220221.pyretStack.push(L[2]);
}
throw $e220221;
}
var $ret226227 = $Hanf_arg1062231($z222223,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret226227;
};
var $Hanf_arg1062231 = function(anf_arg673230,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var $z234235 = D;
var $f240241 = function(_) {
return R.isFunction(_plus13)?_plus13.app(runtime_DASH_types184117,anf_arg673230):R.ffi.throwNonFunApp(L[10],_plus13,[runtime_DASH_types184117,anf_arg673230]);
};
try {
if(--R.GAS > 0) {
$z234235 = $f240241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f240241,
"from":L[10]});
}
} catch($e232233) {
if(R.isCont($e232233)) {
var $ss236237 = {"from":L[10],
"go":function(standard_DASH_types185242) {
return $Hstandard_DASH_types1061243(standard_DASH_types185242,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e232233.stack[R.EXN_STACKHEIGHT++] = $ss236237;
}
if(R.isPyretException($e232233)) {
$e232233.pyretStack.push(L[10]);
}
throw $e232233;
}
var $ret238239 = $Hstandard_DASH_types1061243($z234235,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret238239;
};
var $Hstandard_DASH_types1061243 = function(standard_DASH_types185242,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19) {
var CompileBinding12186244 = {"$var":D,
"$name":"CompileBinding12"};
var CompileBinding187246 = {"$var":D,
"$name":"CompileBinding"};
var is_DASH_CompileBinding188248 = {"$var":D,
"$name":"is-CompileBinding"};
var is_DASH_builtin_DASH_id189250 = {"$var":D,
"$name":"is-builtin-id"};
var builtin_DASH_id190252 = {"$var":D,
"$name":"builtin-id"};
var is_DASH_module_DASH_bindings191254 = {"$var":D,
"$name":"is-module-bindings"};
var module_DASH_bindings192256 = {"$var":D,
"$name":"module-bindings"};
var anf_variant_member685277 = R.makeMethod(function(self128371) {
return function(cases_DASH_funs129372,else_DASH_clause130383) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[14],2,arguments);
}
var if_DASH_132386 = R.hasField(cases_DASH_funs129372,("builtin-id"));
var if_helper675369 = R.makeFunction(function(if_helper_arg676391) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[14],1,arguments);
}
var ann_DASH_check_DASH_temp674392 = if_helper_arg676391;
return ann_DASH_check_DASH_temp674392;
});
var anf_if679390 = R.isBoolean(if_DASH_132386);
if(R.isPyretTrue(anf_if679390)) {
if(R.isPyretTrue(if_DASH_132386)) {
var call_DASH_builtin_DASH_id127366 = G(cases_DASH_funs129372,"builtin-id",L[14]);
var anf_arg682367 = G(self128371,"id",L[23]);
var $z358359 = D;
var $f364365 = function(_) {
return R.isFunction(call_DASH_builtin_DASH_id127366)?call_DASH_builtin_DASH_id127366.app(anf_arg682367):R.ffi.throwNonFunApp(L[14],call_DASH_builtin_DASH_id127366,[anf_arg682367]);
};
try {
if(--R.GAS > 0) {
$z358359 = $f364365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f364365,
"from":L[14]});
}
} catch($e356357) {
if(R.isCont($e356357)) {
var $ss360361 = {"from":L[14],
"go":function(cont_tail_arg683368) {
return $Hcont_tail_arg1015370(cont_tail_arg683368,if_helper675369);
}};
$e356357.stack[R.EXN_STACKHEIGHT++] = $ss360361;
}
if(R.isPyretException($e356357)) {
$e356357.pyretStack.push(L[14]);
}
throw $e356357;
}
var $ret362363 = $Hcont_tail_arg1015370($z358359,if_helper675369);
++R.GAS;
return $ret362363;
} else {
var $z375376 = D;
var $f381382 = function(_) {
return R.isFunction(else_DASH_clause130383)?else_DASH_clause130383.app():R.ffi.throwNonFunApp(L[14],else_DASH_clause130383,[]);
};
try {
if(--R.GAS > 0) {
$z375376 = $f381382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f381382,
"from":L[14]});
}
} catch($e373374) {
if(R.isCont($e373374)) {
var $ss377378 = {"from":L[14],
"go":function(cont_tail_arg680384) {
return $Hcont_tail_arg1016385(cont_tail_arg680384,if_helper675369);
}};
$e373374.stack[R.EXN_STACKHEIGHT++] = $ss377378;
}
if(R.isPyretException($e373374)) {
$e373374.pyretStack.push(L[14]);
}
throw $e373374;
}
var $ret379380 = $Hcont_tail_arg1016385($z375376,if_helper675369);
++R.GAS;
return $ret379380;
}
} else {
var cont_tail_arg677389 = R.throwNonBooleanCondition(L[14],("if"),if_DASH_132386);
if(--R.GAS > 0) {
$z387388 = R.isFunction(if_helper675369)?if_helper675369.app(cont_tail_arg677389):R.ffi.throwNonFunApp(L[14],if_helper675369,[cont_tail_arg677389]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper675369)?if_helper675369.app(cont_tail_arg677389):R.ffi.throwNonFunApp(L[14],if_helper675369,[cont_tail_arg677389]);
},
"from":L[14]});
}
++R.GAS;
return $z387388;
}
};
},{"length":3});
var anf_variant_member691278 = R.makeMethod(function(self131355) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[14],0,arguments);
}
var anf_arg687352 = G(self131355,"id",L[14]);
var $z344345 = D;
var $f350351 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg687352):R.ffi.throwNonFunApp(L[14],torepr17,[anf_arg687352]);
};
try {
if(--R.GAS > 0) {
$z344345 = $f350351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f350351,
"from":L[14]});
}
} catch($e342343) {
if(R.isCont($e342343)) {
var $ss346347 = {"from":L[14],
"go":function(anf_arg688353) {
return $Hanf_arg1020354(anf_arg688353,_plus13);
}};
$e342343.stack[R.EXN_STACKHEIGHT++] = $ss346347;
}
if(R.isPyretException($e342343)) {
$e342343.pyretStack.push(L[14]);
}
throw $e342343;
}
var $ret348349 = $Hanf_arg1020354($z344345,_plus13);
++R.GAS;
return $ret348349;
};
},{"length":1});
var anf_variant_member704285 = R.makeMethod(function(self134319) {
return function(cases_DASH_funs135320,else_DASH_clause136331) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[13],2,arguments);
}
var if_DASH_138334 = R.hasField(cases_DASH_funs135320,("module-bindings"));
var if_helper693317 = R.makeFunction(function(if_helper_arg694340) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[13],1,arguments);
}
var ann_DASH_check_DASH_temp692341 = if_helper_arg694340;
return ann_DASH_check_DASH_temp692341;
});
var anf_if697339 = R.isBoolean(if_DASH_138334);
if(R.isPyretTrue(anf_if697339)) {
if(R.isPyretTrue(if_DASH_138334)) {
var call_DASH_module_DASH_bindings133313 = G(cases_DASH_funs135320,"module-bindings",L[13]);
var anf_arg700314 = G(self134319,"name",L[22]);
var anf_arg701315 = G(self134319,"bindings",L[21]);
var $z305306 = D;
var $f311312 = function(_) {
return R.isFunction(call_DASH_module_DASH_bindings133313)?call_DASH_module_DASH_bindings133313.app(anf_arg700314,anf_arg701315):R.ffi.throwNonFunApp(L[13],call_DASH_module_DASH_bindings133313,[anf_arg700314,anf_arg701315]);
};
try {
if(--R.GAS > 0) {
$z305306 = $f311312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f311312,
"from":L[13]});
}
} catch($e303304) {
if(R.isCont($e303304)) {
var $ss307308 = {"from":L[13],
"go":function(cont_tail_arg702316) {
return $Hcont_tail_arg1021318(cont_tail_arg702316,if_helper693317);
}};
$e303304.stack[R.EXN_STACKHEIGHT++] = $ss307308;
}
if(R.isPyretException($e303304)) {
$e303304.pyretStack.push(L[13]);
}
throw $e303304;
}
var $ret309310 = $Hcont_tail_arg1021318($z305306,if_helper693317);
++R.GAS;
return $ret309310;
} else {
var $z323324 = D;
var $f329330 = function(_) {
return R.isFunction(else_DASH_clause136331)?else_DASH_clause136331.app():R.ffi.throwNonFunApp(L[13],else_DASH_clause136331,[]);
};
try {
if(--R.GAS > 0) {
$z323324 = $f329330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f329330,
"from":L[13]});
}
} catch($e321322) {
if(R.isCont($e321322)) {
var $ss325326 = {"from":L[13],
"go":function(cont_tail_arg698332) {
return $Hcont_tail_arg1022333(cont_tail_arg698332,if_helper693317);
}};
$e321322.stack[R.EXN_STACKHEIGHT++] = $ss325326;
}
if(R.isPyretException($e321322)) {
$e321322.pyretStack.push(L[13]);
}
throw $e321322;
}
var $ret327328 = $Hcont_tail_arg1022333($z323324,if_helper693317);
++R.GAS;
return $ret327328;
}
} else {
var cont_tail_arg695337 = R.throwNonBooleanCondition(L[13],("if"),if_DASH_138334);
if(--R.GAS > 0) {
$z335336 = R.isFunction(if_helper693317)?if_helper693317.app(cont_tail_arg695337):R.ffi.throwNonFunApp(L[13],if_helper693317,[cont_tail_arg695337]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper693317)?if_helper693317.app(cont_tail_arg695337):R.ffi.throwNonFunApp(L[13],if_helper693317,[cont_tail_arg695337]);
},
"from":L[13]});
}
++R.GAS;
return $z335336;
}
};
},{"length":3});
var anf_variant_member714286 = R.makeMethod(function(self137301) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[13],0,arguments);
}
var anf_arg706299 = G(self137301,"name",L[13]);
var $z291292 = D;
var $f297298 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg706299):R.ffi.throwNonFunApp(L[13],torepr17,[anf_arg706299]);
};
try {
if(--R.GAS > 0) {
$z291292 = $f297298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f297298,
"from":L[13]});
}
} catch($e289290) {
if(R.isCont($e289290)) {
var $ss293294 = {"from":L[13],
"go":function(anf_arg707300) {
return $Hanf_arg1029302(anf_arg707300,self137301,_plus13,torepr17);
}};
$e289290.stack[R.EXN_STACKHEIGHT++] = $ss293294;
}
if(R.isPyretException($e289290)) {
$e289290.pyretStack.push(L[13]);
}
throw $e289290;
}
var $ret295296 = $Hanf_arg1029302($z291292,self137301,_plus13,torepr17);
++R.GAS;
return $ret295296;
};
},{"length":1});
var anf_assign715245 = (function() {
var $builtin_DASH_id_DASH_base272273 = {"_match":anf_variant_member685277,
"_torepr":anf_variant_member691278};
var $builtin_DASH_id_DASH_brands275276 = {"$brand-builtin-id274":true};
$builtin_DASH_id_DASH_brands275276[CompileBindingT67546._brand] = true
var $module_DASH_bindings_DASH_base280281 = {"_match":anf_variant_member704285,
"_torepr":anf_variant_member714286};
var $module_DASH_bindings_DASH_brands283284 = {"$brand-module-bindings282":true};
$module_DASH_bindings_DASH_brands283284[CompileBindingT67546._brand] = true
return R.makeObject({"CompileBinding":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[15],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CompileBindingT67546._brand));
}),
"is-builtin-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[14],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-builtin-id274"));
}),
"builtin-id":R.makeFunction(function(id193279) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[16],1,arguments);
}
return R.checkAnnArgs([$type$String19],[id193279],[L[17]],function() {
var dict = R.create($builtin_DASH_id_DASH_base272273);
dict["id"] = id193279
return R.makeBrandedObject(dict,$builtin_DASH_id_DASH_brands275276);
});
}),
"is-module-bindings":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[13],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-module-bindings282"));
}),
"module-bindings":R.makeFunction(function(name194287,bindings195288) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[18],2,arguments);
}
return R.checkAnnArgs([$type$String19,List1555],[name194287,bindings195288],[L[19],L[20]],function() {
var dict = R.create($module_DASH_bindings_DASH_base280281);
dict["name"] = name194287
dict["bindings"] = bindings195288
return R.makeBrandedObject(dict,$module_DASH_bindings_DASH_brands283284);
});
})});
})();
CompileBinding12186244.$var = anf_assign715245;
var anf_assign716247 = G(CompileBinding12186244.$var,"CompileBinding",L[15]);
CompileBinding187246.$var = anf_assign716247;
var anf_assign717249 = G(CompileBinding12186244.$var,"CompileBinding",L[15]);
is_DASH_CompileBinding188248.$var = anf_assign717249;
var anf_assign718251 = G(CompileBinding12186244.$var,"is-builtin-id",L[14]);
is_DASH_builtin_DASH_id189250.$var = anf_assign718251;
var anf_assign719253 = G(CompileBinding12186244.$var,"builtin-id",L[14]);
builtin_DASH_id190252.$var = anf_assign719253;
var anf_assign720255 = G(CompileBinding12186244.$var,"is-module-bindings",L[13]);
is_DASH_module_DASH_bindings191254.$var = anf_assign720255;
var anf_assign721257 = G(CompileBinding12186244.$var,"module-bindings",L[13]);
module_DASH_bindings192256.$var = anf_assign721257;
var anf_fun722270 = G(lists723,"map",L[12]);
var anf_fun723268 = G(list2391,"make",L[11]);
var $z260261 = D;
var $f266267 = function(_) {
return R.isFunction(anf_fun723268)?anf_fun723268.app([("test-print"),("print"),("display"),("print-error"),("display-error"),("tostring"),("torepr"),("brander"),("raise"),("nothing"),("builtins"),("not"),("is-nothing"),("is-number"),("is-string"),("is-boolean"),("is-object"),("is-function"),("is-raw-array"),("gensym"),("random"),("run-task"),("_plus"),("_minus"),("_times"),("_divide"),("_lessthan"),("_lessequal"),("_greaterthan"),("_greaterequal"),("strings-equal"),("string-contains"),("string-append"),("string-length"),("string-tonumber"),("string-repeat"),("string-substring"),("string-replace"),("string-split"),("string-char-at"),("string-toupper"),("string-tolower"),("string-explode"),("string-index-of"),("num-max"),("num-min"),("nums-equal"),("num-abs"),("num-sin"),("num-cos"),("num-tan"),("num-asin"),("num-acos"),("num-atan"),("num-modulo"),("num-truncate"),("num-sqrt"),("num-sqr"),("num-ceiling"),("num-floor"),("num-log"),("num-exp"),("num-exact"),("num-is-integer"),("num-is-fixnum"),("num-expt"),("num-tostring"),("raw-array-get"),("raw-array-set"),("raw-array-of"),("raw-array-length"),("raw-array-to-list"),("raw-array-fold")]):R.ffi.throwNonFunApp(L[11],anf_fun723268,[[("test-print"),("print"),("display"),("print-error"),("display-error"),("tostring"),("torepr"),("brander"),("raise"),("nothing"),("builtins"),("not"),("is-nothing"),("is-number"),("is-string"),("is-boolean"),("is-object"),("is-function"),("is-raw-array"),("gensym"),("random"),("run-task"),("_plus"),("_minus"),("_times"),("_divide"),("_lessthan"),("_lessequal"),("_greaterthan"),("_greaterequal"),("strings-equal"),("string-contains"),("string-append"),("string-length"),("string-tonumber"),("string-repeat"),("string-substring"),("string-replace"),("string-split"),("string-char-at"),("string-toupper"),("string-tolower"),("string-explode"),("string-index-of"),("num-max"),("num-min"),("nums-equal"),("num-abs"),("num-sin"),("num-cos"),("num-tan"),("num-asin"),("num-acos"),("num-atan"),("num-modulo"),("num-truncate"),("num-sqrt"),("num-sqr"),("num-ceiling"),("num-floor"),("num-log"),("num-exp"),("num-exact"),("num-is-integer"),("num-is-fixnum"),("num-expt"),("num-tostring"),("raw-array-get"),("raw-array-set"),("raw-array-of"),("raw-array-length"),("raw-array-to-list"),("raw-array-fold")]]);
};
try {
if(--R.GAS > 0) {
$z260261 = $f266267();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f266267,
"from":L[11]});
}
} catch($e258259) {
if(R.isCont($e258259)) {
var $ss262263 = {"from":L[11],
"go":function(anf_arg724269) {
return $Hanf_arg1060271(anf_arg724269,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun722270,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e258259.stack[R.EXN_STACKHEIGHT++] = $ss262263;
}
if(R.isPyretException($e258259)) {
$e258259.pyretStack.push(L[11]);
}
throw $e258259;
}
var $ret264265 = $Hanf_arg1060271($z260261,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun722270,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret264265;
};
var $Hanf_arg1060271 = function(anf_arg724269,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun722270,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z395396 = D;
var $f401402 = function(_) {
return R.isFunction(anf_fun722270)?anf_fun722270.app(builtin_DASH_id190252.$var,anf_arg724269):R.ffi.throwNonFunApp(L[24],anf_fun722270,[builtin_DASH_id190252.$var,anf_arg724269]);
};
try {
if(--R.GAS > 0) {
$z395396 = $f401402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f401402,
"from":L[24]});
}
} catch($e393394) {
if(R.isCont($e393394)) {
var $ss397398 = {"from":L[24],
"go":function(runtime_DASH_builtins196403) {
return $Hruntime_DASH_builtins1059404(runtime_DASH_builtins196403,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e393394.stack[R.EXN_STACKHEIGHT++] = $ss397398;
}
if(R.isPyretException($e393394)) {
$e393394.pyretStack.push(L[24]);
}
throw $e393394;
}
var $ret399400 = $Hruntime_DASH_builtins1059404($z395396,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret399400;
};
var $Hruntime_DASH_builtins1059404 = function(runtime_DASH_builtins196403,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun725415 = G(list2391,"make",L[25]);
var $z407408 = D;
var $f413414 = function(_) {
return R.isFunction(anf_fun725415)?anf_fun725415.app([]):R.ffi.throwNonFunApp(L[25],anf_fun725415,[[]]);
};
try {
if(--R.GAS > 0) {
$z407408 = $f413414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f413414,
"from":L[25]});
}
} catch($e405406) {
if(R.isCont($e405406)) {
var $ss409410 = {"from":L[25],
"go":function(anf_arg726416) {
return $Hanf_arg1058417(anf_arg726416,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e405406.stack[R.EXN_STACKHEIGHT++] = $ss409410;
}
if(R.isPyretException($e405406)) {
$e405406.pyretStack.push(L[25]);
}
throw $e405406;
}
var $ret411412 = $Hanf_arg1058417($z407408,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret411412;
};
var $Hanf_arg1058417 = function(anf_arg726416,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun727428 = G(list2391,"make",L[26]);
var $z420421 = D;
var $f426427 = function(_) {
return R.isFunction(anf_fun727428)?anf_fun727428.app([]):R.ffi.throwNonFunApp(L[26],anf_fun727428,[[]]);
};
try {
if(--R.GAS > 0) {
$z420421 = $f426427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f426427,
"from":L[26]});
}
} catch($e418419) {
if(R.isCont($e418419)) {
var $ss422423 = {"from":L[26],
"go":function(anf_arg728429) {
return $Hanf_arg1057430(anf_arg728429,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg726416,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e418419.stack[R.EXN_STACKHEIGHT++] = $ss422423;
}
if(R.isPyretException($e418419)) {
$e418419.pyretStack.push(L[26]);
}
throw $e418419;
}
var $ret424425 = $Hanf_arg1057430($z420421,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg726416,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret424425;
};
var $Hanf_arg1057430 = function(anf_arg728429,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg726416,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z433434 = D;
var $f439440 = function(_) {
return R.isFunction(compile_DASH_env8862.$var)?compile_DASH_env8862.$var.app(anf_arg726416,anf_arg728429):R.ffi.throwNonFunApp(L[27],compile_DASH_env8862.$var,[anf_arg726416,anf_arg728429]);
};
try {
if(--R.GAS > 0) {
$z433434 = $f439440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f439440,
"from":L[27]});
}
} catch($e431432) {
if(R.isCont($e431432)) {
var $ss435436 = {"from":L[27],
"go":function(no_DASH_builtins197441) {
return $Hno_DASH_builtins1056442(no_DASH_builtins197441,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e431432.stack[R.EXN_STACKHEIGHT++] = $ss435436;
}
if(R.isPyretException($e431432)) {
$e431432.pyretStack.push(L[27]);
}
throw $e431432;
}
var $ret437438 = $Hno_DASH_builtins1056442($z433434,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret437438;
};
var $Hno_DASH_builtins1056442 = function(no_DASH_builtins197441,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z445446 = D;
var $f451452 = function(_) {
return R.isFunction(compile_DASH_env8862.$var)?compile_DASH_env8862.$var.app(runtime_DASH_builtins196403,runtime_DASH_types184117):R.ffi.throwNonFunApp(L[28],compile_DASH_env8862.$var,[runtime_DASH_builtins196403,runtime_DASH_types184117]);
};
try {
if(--R.GAS > 0) {
$z445446 = $f451452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f451452,
"from":L[28]});
}
} catch($e443444) {
if(R.isCont($e443444)) {
var $ss447448 = {"from":L[28],
"go":function(minimal_DASH_builtins198453) {
return $Hminimal_DASH_builtins1055454(minimal_DASH_builtins198453,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e443444.stack[R.EXN_STACKHEIGHT++] = $ss447448;
}
if(R.isPyretException($e443444)) {
$e443444.pyretStack.push(L[28]);
}
throw $e443444;
}
var $ret449450 = $Hminimal_DASH_builtins1055454($z445446,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret449450;
};
var $Hminimal_DASH_builtins1055454 = function(minimal_DASH_builtins198453,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun729467 = G(list2391,"make",L[30]);
var anf_fun730465 = G(list2391,"make",L[29]);
var $z457458 = D;
var $f463464 = function(_) {
return R.isFunction(anf_fun730465)?anf_fun730465.app([("list"),("is-empty"),("is-link"),("empty"),("link"),("range"),("repeat"),("filter"),("partition"),("split-at"),("any"),("all"),("find"),("map"),("map2"),("map3"),("map4"),("map_n"),("map2_n"),("map3_n"),("map4_n"),("each"),("each2"),("each3"),("each4"),("each_n"),("each2_n"),("each3_n"),("each4_n"),("fold-while"),("fold"),("fold2"),("fold3"),("fold4"),("index")]):R.ffi.throwNonFunApp(L[29],anf_fun730465,[[("list"),("is-empty"),("is-link"),("empty"),("link"),("range"),("repeat"),("filter"),("partition"),("split-at"),("any"),("all"),("find"),("map"),("map2"),("map3"),("map4"),("map_n"),("map2_n"),("map3_n"),("map4_n"),("each"),("each2"),("each3"),("each4"),("each_n"),("each2_n"),("each3_n"),("each4_n"),("fold-while"),("fold"),("fold2"),("fold3"),("fold4"),("index")]]);
};
try {
if(--R.GAS > 0) {
$z457458 = $f463464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f463464,
"from":L[29]});
}
} catch($e455456) {
if(R.isCont($e455456)) {
var $ss459460 = {"from":L[29],
"go":function(anf_arg731466) {
return $Hanf_arg1054468(anf_arg731466,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun729467,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e455456.stack[R.EXN_STACKHEIGHT++] = $ss459460;
}
if(R.isPyretException($e455456)) {
$e455456.pyretStack.push(L[29]);
}
throw $e455456;
}
var $ret461462 = $Hanf_arg1054468($z457458,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun729467,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret461462;
};
var $Hanf_arg1054468 = function(anf_arg731466,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun729467,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z471472 = D;
var $f477478 = function(_) {
return R.isFunction(module_DASH_bindings192256.$var)?module_DASH_bindings192256.$var.app(("lists"),anf_arg731466):R.ffi.throwNonFunApp(L[31],module_DASH_bindings192256.$var,[("lists"),anf_arg731466]);
};
try {
if(--R.GAS > 0) {
$z471472 = $f477478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f477478,
"from":L[31]});
}
} catch($e469470) {
if(R.isCont($e469470)) {
var $ss473474 = {"from":L[31],
"go":function(anf_array_val732479) {
return $Hanf_array_val1053480(anf_array_val732479,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun729467,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e469470.stack[R.EXN_STACKHEIGHT++] = $ss473474;
}
if(R.isPyretException($e469470)) {
$e469470.pyretStack.push(L[31]);
}
throw $e469470;
}
var $ret475476 = $Hanf_array_val1053480($z471472,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun729467,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret475476;
};
var $Hanf_array_val1053480 = function(anf_array_val732479,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun729467,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z483484 = D;
var $f489490 = function(_) {
return R.isFunction(anf_fun729467)?anf_fun729467.app([anf_array_val732479]):R.ffi.throwNonFunApp(L[30],anf_fun729467,[[anf_array_val732479]]);
};
try {
if(--R.GAS > 0) {
$z483484 = $f489490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f489490,
"from":L[30]});
}
} catch($e481482) {
if(R.isCont($e481482)) {
var $ss485486 = {"from":L[30],
"go":function(anf_arg733491) {
return $Hanf_arg1052492(anf_arg733491,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e481482.stack[R.EXN_STACKHEIGHT++] = $ss485486;
}
if(R.isPyretException($e481482)) {
$e481482.pyretStack.push(L[30]);
}
throw $e481482;
}
var $ret487488 = $Hanf_arg1052492($z483484,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret487488;
};
var $Hanf_arg1052492 = function(anf_arg733491,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z495496 = D;
var $f501502 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg733491,runtime_DASH_builtins196403):R.ffi.throwNonFunApp(L[32],_plus13,[anf_arg733491,runtime_DASH_builtins196403]);
};
try {
if(--R.GAS > 0) {
$z495496 = $f501502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f501502,
"from":L[32]});
}
} catch($e493494) {
if(R.isCont($e493494)) {
var $ss497498 = {"from":L[32],
"go":function(anf_arg734503) {
return $Hanf_arg1051504(anf_arg734503,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e493494.stack[R.EXN_STACKHEIGHT++] = $ss497498;
}
if(R.isPyretException($e493494)) {
$e493494.pyretStack.push(L[32]);
}
throw $e493494;
}
var $ret499500 = $Hanf_arg1051504($z495496,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret499500;
};
var $Hanf_arg1051504 = function(anf_arg734503,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun735517 = G(lists723,"map",L[34]);
var anf_fun736515 = G(list2391,"make",L[33]);
var $z507508 = D;
var $f513514 = function(_) {
return R.isFunction(anf_fun736515)?anf_fun736515.app([("_link"),("_empty"),("add"),("sub"),("div"),("mul"),("less"),("greater"),("greaterequal"),("lessequal"),("both"),("either"),("not"),("max"),("min"),("abs"),("sin"),("cos"),("tan"),("asin"),("acos"),("atan"),("modulo"),("truncate"),("sqrt"),("sqr"),("ceiling"),("floor"),("log"),("exp"),("exact"),("is-integer"),("is-fixnum"),("expt"),("circle"),("is-image-color"),("is-mode"),("is-x-place"),("is-y-place"),("is-angle"),("is-side-count"),("is-step-count"),("is-image"),("bitmap-url"),("open-image-url"),("image-url"),("images-equal"),("text"),("normal"),("text-font"),("overlay"),("middle"),("overlay-xy"),("overlay-align"),("underlay"),("middle"),("underlay-xy"),("underlay-align"),("beside-align"),("beside"),("above"),("middle"),("above-align"),("empty-scene"),("put-image"),("place-image"),("place-image-align"),("rotate"),("scale"),("scale-xy"),("flip-horizontal"),("flip-vertical"),("frame"),("crop"),("line"),("add-line"),("scene-line"),("square"),("rectangle"),("regular-polygon"),("ellipse"),("triangle"),("triangle-sas"),("triangle-sss"),("triangle-ass"),("triangle-ssa"),("triangle-aas"),("triangle-asa"),("triangle-saa"),("right-triangle"),("isosceles-triangle"),("star"),("star-sized"),("radial-star"),("star-polygon"),("rhombus"),("image-to-color-list"),("color-list-to-image"),("color-list-to-bitmap"),("image-width"),("image-height"),("image-baseline"),("name-to-color"),("big-bang"),("on-tick"),("on-tick-n"),("to-draw"),("on-mouse"),("on-key"),("stop-when"),("is-key-equal")]):R.ffi.throwNonFunApp(L[33],anf_fun736515,[[("_link"),("_empty"),("add"),("sub"),("div"),("mul"),("less"),("greater"),("greaterequal"),("lessequal"),("both"),("either"),("not"),("max"),("min"),("abs"),("sin"),("cos"),("tan"),("asin"),("acos"),("atan"),("modulo"),("truncate"),("sqrt"),("sqr"),("ceiling"),("floor"),("log"),("exp"),("exact"),("is-integer"),("is-fixnum"),("expt"),("circle"),("is-image-color"),("is-mode"),("is-x-place"),("is-y-place"),("is-angle"),("is-side-count"),("is-step-count"),("is-image"),("bitmap-url"),("open-image-url"),("image-url"),("images-equal"),("text"),("normal"),("text-font"),("overlay"),("middle"),("overlay-xy"),("overlay-align"),("underlay"),("middle"),("underlay-xy"),("underlay-align"),("beside-align"),("beside"),("above"),("middle"),("above-align"),("empty-scene"),("put-image"),("place-image"),("place-image-align"),("rotate"),("scale"),("scale-xy"),("flip-horizontal"),("flip-vertical"),("frame"),("crop"),("line"),("add-line"),("scene-line"),("square"),("rectangle"),("regular-polygon"),("ellipse"),("triangle"),("triangle-sas"),("triangle-sss"),("triangle-ass"),("triangle-ssa"),("triangle-aas"),("triangle-asa"),("triangle-saa"),("right-triangle"),("isosceles-triangle"),("star"),("star-sized"),("radial-star"),("star-polygon"),("rhombus"),("image-to-color-list"),("color-list-to-image"),("color-list-to-bitmap"),("image-width"),("image-height"),("image-baseline"),("name-to-color"),("big-bang"),("on-tick"),("on-tick-n"),("to-draw"),("on-mouse"),("on-key"),("stop-when"),("is-key-equal")]]);
};
try {
if(--R.GAS > 0) {
$z507508 = $f513514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f513514,
"from":L[33]});
}
} catch($e505506) {
if(R.isCont($e505506)) {
var $ss509510 = {"from":L[33],
"go":function(anf_arg737516) {
return $Hanf_arg1050518(anf_arg737516,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg734503,anf_fun735517,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e505506.stack[R.EXN_STACKHEIGHT++] = $ss509510;
}
if(R.isPyretException($e505506)) {
$e505506.pyretStack.push(L[33]);
}
throw $e505506;
}
var $ret511512 = $Hanf_arg1050518($z507508,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg734503,anf_fun735517,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret511512;
};
var $Hanf_arg1050518 = function(anf_arg737516,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg734503,anf_fun735517,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z521522 = D;
var $f527528 = function(_) {
return R.isFunction(anf_fun735517)?anf_fun735517.app(builtin_DASH_id190252.$var,anf_arg737516):R.ffi.throwNonFunApp(L[35],anf_fun735517,[builtin_DASH_id190252.$var,anf_arg737516]);
};
try {
if(--R.GAS > 0) {
$z521522 = $f527528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f527528,
"from":L[35]});
}
} catch($e519520) {
if(R.isCont($e519520)) {
var $ss523524 = {"from":L[35],
"go":function(anf_arg738529) {
return $Hanf_arg1049530(anf_arg738529,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg734503,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e519520.stack[R.EXN_STACKHEIGHT++] = $ss523524;
}
if(R.isPyretException($e519520)) {
$e519520.pyretStack.push(L[35]);
}
throw $e519520;
}
var $ret525526 = $Hanf_arg1049530($z521522,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg734503,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret525526;
};
var $Hanf_arg1049530 = function(anf_arg738529,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_arg734503,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z533534 = D;
var $f539540 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg734503,anf_arg738529):R.ffi.throwNonFunApp(L[32],_plus13,[anf_arg734503,anf_arg738529]);
};
try {
if(--R.GAS > 0) {
$z533534 = $f539540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f539540,
"from":L[32]});
}
} catch($e531532) {
if(R.isCont($e531532)) {
var $ss535536 = {"from":L[32],
"go":function(anf_arg739541) {
return $Hanf_arg1048542(anf_arg739541,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e531532.stack[R.EXN_STACKHEIGHT++] = $ss535536;
}
if(R.isPyretException($e531532)) {
$e531532.pyretStack.push(L[32]);
}
throw $e531532;
}
var $ret537538 = $Hanf_arg1048542($z533534,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret537538;
};
var $Hanf_arg1048542 = function(anf_arg739541,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z545546 = D;
var $f551552 = function(_) {
return R.isFunction(compile_DASH_env8862.$var)?compile_DASH_env8862.$var.app(anf_arg739541,runtime_DASH_types184117):R.ffi.throwNonFunApp(L[36],compile_DASH_env8862.$var,[anf_arg739541,runtime_DASH_types184117]);
};
try {
if(--R.GAS > 0) {
$z545546 = $f551552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f551552,
"from":L[36]});
}
} catch($e543544) {
if(R.isCont($e543544)) {
var $ss547548 = {"from":L[36],
"go":function(bootstrap_DASH_builtins199553) {
return $Hbootstrap_DASH_builtins1047554(bootstrap_DASH_builtins199553,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e543544.stack[R.EXN_STACKHEIGHT++] = $ss547548;
}
if(R.isPyretException($e543544)) {
$e543544.pyretStack.push(L[36]);
}
throw $e543544;
}
var $ret549550 = $Hbootstrap_DASH_builtins1047554($z545546,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret549550;
};
var $Hbootstrap_DASH_builtins1047554 = function(bootstrap_DASH_builtins199553,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun740566 = G(list2391,"make",L[38]);
var $z557558 = D;
var $f563564 = function(_) {
return R.isFunction(builtin_DASH_id190252.$var)?builtin_DASH_id190252.$var.app(("_link")):R.ffi.throwNonFunApp(L[37],builtin_DASH_id190252.$var,[("_link")]);
};
try {
if(--R.GAS > 0) {
$z557558 = $f563564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f563564,
"from":L[37]});
}
} catch($e555556) {
if(R.isCont($e555556)) {
var $ss559560 = {"from":L[37],
"go":function(anf_array_val741565) {
return $Hanf_array_val1046567(anf_array_val741565,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e555556.stack[R.EXN_STACKHEIGHT++] = $ss559560;
}
if(R.isPyretException($e555556)) {
$e555556.pyretStack.push(L[37]);
}
throw $e555556;
}
var $ret561562 = $Hanf_array_val1046567($z557558,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret561562;
};
var $Hanf_array_val1046567 = function(anf_array_val741565,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z570571 = D;
var $f576577 = function(_) {
return R.isFunction(builtin_DASH_id190252.$var)?builtin_DASH_id190252.$var.app(("_empty")):R.ffi.throwNonFunApp(L[39],builtin_DASH_id190252.$var,[("_empty")]);
};
try {
if(--R.GAS > 0) {
$z570571 = $f576577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f576577,
"from":L[39]});
}
} catch($e568569) {
if(R.isCont($e568569)) {
var $ss572573 = {"from":L[39],
"go":function(anf_array_val742578) {
return $Hanf_array_val1045579(anf_array_val742578,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e568569.stack[R.EXN_STACKHEIGHT++] = $ss572573;
}
if(R.isPyretException($e568569)) {
$e568569.pyretStack.push(L[39]);
}
throw $e568569;
}
var $ret574575 = $Hanf_array_val1045579($z570571,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret574575;
};
var $Hanf_array_val1045579 = function(anf_array_val742578,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun743590 = G(list2391,"make",L[40]);
var $z582583 = D;
var $f588589 = function(_) {
return R.isFunction(anf_fun743590)?anf_fun743590.app([("array"),("build-array"),("array-from-list"),("is-array")]):R.ffi.throwNonFunApp(L[40],anf_fun743590,[[("array"),("build-array"),("array-from-list"),("is-array")]]);
};
try {
if(--R.GAS > 0) {
$z582583 = $f588589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f588589,
"from":L[40]});
}
} catch($e580581) {
if(R.isCont($e580581)) {
var $ss584585 = {"from":L[40],
"go":function(anf_arg744591) {
return $Hanf_arg1044592(anf_arg744591,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e580581.stack[R.EXN_STACKHEIGHT++] = $ss584585;
}
if(R.isPyretException($e580581)) {
$e580581.pyretStack.push(L[40]);
}
throw $e580581;
}
var $ret586587 = $Hanf_arg1044592($z582583,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret586587;
};
var $Hanf_arg1044592 = function(anf_arg744591,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z595596 = D;
var $f601602 = function(_) {
return R.isFunction(module_DASH_bindings192256.$var)?module_DASH_bindings192256.$var.app(("arrays"),anf_arg744591):R.ffi.throwNonFunApp(L[41],module_DASH_bindings192256.$var,[("arrays"),anf_arg744591]);
};
try {
if(--R.GAS > 0) {
$z595596 = $f601602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f601602,
"from":L[41]});
}
} catch($e593594) {
if(R.isCont($e593594)) {
var $ss597598 = {"from":L[41],
"go":function(anf_array_val745603) {
return $Hanf_array_val1043604(anf_array_val745603,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e593594.stack[R.EXN_STACKHEIGHT++] = $ss597598;
}
if(R.isPyretException($e593594)) {
$e593594.pyretStack.push(L[41]);
}
throw $e593594;
}
var $ret599600 = $Hanf_array_val1043604($z595596,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret599600;
};
var $Hanf_array_val1043604 = function(anf_array_val745603,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun746615 = G(list2391,"make",L[42]);
var $z607608 = D;
var $f613614 = function(_) {
return R.isFunction(anf_fun746615)?anf_fun746615.app([("list"),("is-empty"),("is-link"),("empty"),("link"),("range"),("repeat"),("filter"),("partition"),("split-at"),("any"),("find"),("map"),("map2"),("map3"),("map4"),("map_n"),("map2_n"),("map3_n"),("map4_n"),("each"),("each2"),("each3"),("each4"),("each_n"),("each2_n"),("each3_n"),("each4_n"),("fold"),("fold2"),("fold3"),("fold4"),("index")]):R.ffi.throwNonFunApp(L[42],anf_fun746615,[[("list"),("is-empty"),("is-link"),("empty"),("link"),("range"),("repeat"),("filter"),("partition"),("split-at"),("any"),("find"),("map"),("map2"),("map3"),("map4"),("map_n"),("map2_n"),("map3_n"),("map4_n"),("each"),("each2"),("each3"),("each4"),("each_n"),("each2_n"),("each3_n"),("each4_n"),("fold"),("fold2"),("fold3"),("fold4"),("index")]]);
};
try {
if(--R.GAS > 0) {
$z607608 = $f613614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f613614,
"from":L[42]});
}
} catch($e605606) {
if(R.isCont($e605606)) {
var $ss609610 = {"from":L[42],
"go":function(anf_arg747616) {
return $Hanf_arg1042617(anf_arg747616,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e605606.stack[R.EXN_STACKHEIGHT++] = $ss609610;
}
if(R.isPyretException($e605606)) {
$e605606.pyretStack.push(L[42]);
}
throw $e605606;
}
var $ret611612 = $Hanf_arg1042617($z607608,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret611612;
};
var $Hanf_arg1042617 = function(anf_arg747616,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z620621 = D;
var $f626627 = function(_) {
return R.isFunction(module_DASH_bindings192256.$var)?module_DASH_bindings192256.$var.app(("lists"),anf_arg747616):R.ffi.throwNonFunApp(L[43],module_DASH_bindings192256.$var,[("lists"),anf_arg747616]);
};
try {
if(--R.GAS > 0) {
$z620621 = $f626627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f626627,
"from":L[43]});
}
} catch($e618619) {
if(R.isCont($e618619)) {
var $ss622623 = {"from":L[43],
"go":function(anf_array_val748628) {
return $Hanf_array_val1041629(anf_array_val748628,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e618619.stack[R.EXN_STACKHEIGHT++] = $ss622623;
}
if(R.isPyretException($e618619)) {
$e618619.pyretStack.push(L[43]);
}
throw $e618619;
}
var $ret624625 = $Hanf_array_val1041629($z620621,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret624625;
};
var $Hanf_array_val1041629 = function(anf_array_val748628,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun749640 = G(list2391,"make",L[44]);
var $z632633 = D;
var $f638639 = function(_) {
return R.isFunction(anf_fun749640)?anf_fun749640.app([("Option"),("is-none"),("is-some"),("none"),("some")]):R.ffi.throwNonFunApp(L[44],anf_fun749640,[[("Option"),("is-none"),("is-some"),("none"),("some")]]);
};
try {
if(--R.GAS > 0) {
$z632633 = $f638639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f638639,
"from":L[44]});
}
} catch($e630631) {
if(R.isCont($e630631)) {
var $ss634635 = {"from":L[44],
"go":function(anf_arg750641) {
return $Hanf_arg1040642(anf_arg750641,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e630631.stack[R.EXN_STACKHEIGHT++] = $ss634635;
}
if(R.isPyretException($e630631)) {
$e630631.pyretStack.push(L[44]);
}
throw $e630631;
}
var $ret636637 = $Hanf_arg1040642($z632633,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret636637;
};
var $Hanf_arg1040642 = function(anf_arg750641,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z645646 = D;
var $f651652 = function(_) {
return R.isFunction(module_DASH_bindings192256.$var)?module_DASH_bindings192256.$var.app(("option"),anf_arg750641):R.ffi.throwNonFunApp(L[45],module_DASH_bindings192256.$var,[("option"),anf_arg750641]);
};
try {
if(--R.GAS > 0) {
$z645646 = $f651652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f651652,
"from":L[45]});
}
} catch($e643644) {
if(R.isCont($e643644)) {
var $ss647648 = {"from":L[45],
"go":function(anf_array_val751653) {
return $Hanf_array_val1039654(anf_array_val751653,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e643644.stack[R.EXN_STACKHEIGHT++] = $ss647648;
}
if(R.isPyretException($e643644)) {
$e643644.pyretStack.push(L[45]);
}
throw $e643644;
}
var $ret649650 = $Hanf_array_val1039654($z645646,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret649650;
};
var $Hanf_array_val1039654 = function(anf_array_val751653,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun752665 = G(list2391,"make",L[46]);
var $z657658 = D;
var $f663664 = function(_) {
return R.isFunction(anf_fun752665)?anf_fun752665.app([]):R.ffi.throwNonFunApp(L[46],anf_fun752665,[[]]);
};
try {
if(--R.GAS > 0) {
$z657658 = $f663664();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f663664,
"from":L[46]});
}
} catch($e655656) {
if(R.isCont($e655656)) {
var $ss659660 = {"from":L[46],
"go":function(anf_arg753666) {
return $Hanf_arg1038667(anf_arg753666,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e655656.stack[R.EXN_STACKHEIGHT++] = $ss659660;
}
if(R.isPyretException($e655656)) {
$e655656.pyretStack.push(L[46]);
}
throw $e655656;
}
var $ret661662 = $Hanf_arg1038667($z657658,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret661662;
};
var $Hanf_arg1038667 = function(anf_arg753666,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z670671 = D;
var $f676677 = function(_) {
return R.isFunction(module_DASH_bindings192256.$var)?module_DASH_bindings192256.$var.app(("error"),anf_arg753666):R.ffi.throwNonFunApp(L[47],module_DASH_bindings192256.$var,[("error"),anf_arg753666]);
};
try {
if(--R.GAS > 0) {
$z670671 = $f676677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f676677,
"from":L[47]});
}
} catch($e668669) {
if(R.isCont($e668669)) {
var $ss672673 = {"from":L[47],
"go":function(anf_array_val754678) {
return $Hanf_array_val1037679(anf_array_val754678,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e668669.stack[R.EXN_STACKHEIGHT++] = $ss672673;
}
if(R.isPyretException($e668669)) {
$e668669.pyretStack.push(L[47]);
}
throw $e668669;
}
var $ret674675 = $Hanf_array_val1037679($z670671,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret674675;
};
var $Hanf_array_val1037679 = function(anf_array_val754678,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var anf_fun755690 = G(list2391,"make",L[48]);
var $z682683 = D;
var $f688689 = function(_) {
return R.isFunction(anf_fun755690)?anf_fun755690.app([("set"),("tree-set"),("list-set")]):R.ffi.throwNonFunApp(L[48],anf_fun755690,[[("set"),("tree-set"),("list-set")]]);
};
try {
if(--R.GAS > 0) {
$z682683 = $f688689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f688689,
"from":L[48]});
}
} catch($e680681) {
if(R.isCont($e680681)) {
var $ss684685 = {"from":L[48],
"go":function(anf_arg756691) {
return $Hanf_arg1036692(anf_arg756691,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_array_val754678,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e680681.stack[R.EXN_STACKHEIGHT++] = $ss684685;
}
if(R.isPyretException($e680681)) {
$e680681.pyretStack.push(L[48]);
}
throw $e680681;
}
var $ret686687 = $Hanf_arg1036692($z682683,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_array_val754678,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret686687;
};
var $Hanf_arg1036692 = function(anf_arg756691,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_array_val754678,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z695696 = D;
var $f701702 = function(_) {
return R.isFunction(module_DASH_bindings192256.$var)?module_DASH_bindings192256.$var.app(("sets"),anf_arg756691):R.ffi.throwNonFunApp(L[49],module_DASH_bindings192256.$var,[("sets"),anf_arg756691]);
};
try {
if(--R.GAS > 0) {
$z695696 = $f701702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f701702,
"from":L[49]});
}
} catch($e693694) {
if(R.isCont($e693694)) {
var $ss697698 = {"from":L[49],
"go":function(anf_array_val757703) {
return $Hanf_array_val1035704(anf_array_val757703,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_array_val754678,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e693694.stack[R.EXN_STACKHEIGHT++] = $ss697698;
}
if(R.isPyretException($e693694)) {
$e693694.pyretStack.push(L[49]);
}
throw $e693694;
}
var $ret699700 = $Hanf_array_val1035704($z695696,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_array_val754678,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret699700;
};
var $Hanf_array_val1035704 = function(anf_array_val757703,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_array_val754678,anf_fun740566,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z707708 = D;
var $f713714 = function(_) {
return R.isFunction(anf_fun740566)?anf_fun740566.app([anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_array_val754678,anf_array_val757703]):R.ffi.throwNonFunApp(L[38],anf_fun740566,[[anf_array_val741565,anf_array_val742578,anf_array_val745603,anf_array_val748628,anf_array_val751653,anf_array_val754678,anf_array_val757703]]);
};
try {
if(--R.GAS > 0) {
$z707708 = $f713714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f713714,
"from":L[38]});
}
} catch($e705706) {
if(R.isCont($e705706)) {
var $ss709710 = {"from":L[38],
"go":function(anf_arg758715) {
return $Hanf_arg1034716(anf_arg758715,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
}};
$e705706.stack[R.EXN_STACKHEIGHT++] = $ss709710;
}
if(R.isPyretException($e705706)) {
$e705706.pyretStack.push(L[38]);
}
throw $e705706;
}
var $ret711712 = $Hanf_arg1034716($z707708,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16);
++R.GAS;
return $ret711712;
};
var $Hanf_arg1034716 = function(anf_arg758715,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16) {
var $z719720 = D;
var $f725726 = function(_) {
return R.isFunction(_plus13)?_plus13.app(runtime_DASH_builtins196403,anf_arg758715):R.ffi.throwNonFunApp(L[50],_plus13,[runtime_DASH_builtins196403,anf_arg758715]);
};
try {
if(--R.GAS > 0) {
$z719720 = $f725726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f725726,
"from":L[50]});
}
} catch($e717718) {
if(R.isCont($e717718)) {
var $ss721722 = {"from":L[50],
"go":function(anf_arg759727) {
return $Hanf_arg1033728(anf_arg759727,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,builtins14,nothing16);
}};
$e717718.stack[R.EXN_STACKHEIGHT++] = $ss721722;
}
if(R.isPyretException($e717718)) {
$e717718.pyretStack.push(L[50]);
}
throw $e717718;
}
var $ret723724 = $Hanf_arg1033728($z719720,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,builtins14,nothing16);
++R.GAS;
return $ret723724;
};
var $Hanf_arg1033728 = function(anf_arg759727,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,builtins14,nothing16) {
var $z731732 = D;
var $f737738 = function(_) {
return R.isFunction(compile_DASH_env8862.$var)?compile_DASH_env8862.$var.app(anf_arg759727,standard_DASH_types185242):R.ffi.throwNonFunApp(L[51],compile_DASH_env8862.$var,[anf_arg759727,standard_DASH_types185242]);
};
try {
if(--R.GAS > 0) {
$z731732 = $f737738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f737738,
"from":L[51]});
}
} catch($e729730) {
if(R.isCont($e729730)) {
var $ss733734 = {"from":L[51],
"go":function(standard_DASH_builtins200739) {
return $Hstandard_DASH_builtins1032740(standard_DASH_builtins200739,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,builtins14,nothing16);
}};
$e729730.stack[R.EXN_STACKHEIGHT++] = $ss733734;
}
if(R.isPyretException($e729730)) {
$e729730.pyretStack.push(L[51]);
}
throw $e729730;
}
var $ret735736 = $Hstandard_DASH_builtins1032740($z731732,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,builtins14,nothing16);
++R.GAS;
return $ret735736;
};
var $Hstandard_DASH_builtins1032740 = function(standard_DASH_builtins200739,Bootstrap8344,CompileBinding187246,CompileBinding7445,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,bad_DASH_assignment12061,bootstrap_DASH_builtins199553,builtin_DASH_id190252,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileBinding188248,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_builtin_DASH_id189250,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_module_DASH_bindings191254,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,minimal_DASH_builtins198453,mixed_DASH_id_DASH_var12292,module_DASH_bindings192256,no_DASH_builtins197441,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,runtime_DASH_builtins196403,runtime_DASH_types184117,shadow_DASH_id12497,standard_DASH_types185242,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,builtins14,nothing16) {
var provides760753 = R.makeObject({"PyretDialect":PyretDialect7859.$var,
"is-PyretDialect":is_DASH_PyretDialect7971.$var,
"Pyret":Pyret8157.$var,
"is-Pyret":is_DASH_Pyret8070.$var,
"Bootstrap":Bootstrap8344.$var,
"is-Bootstrap":is_DASH_Bootstrap8265.$var,
"CompileEnvironment":CompileEnvironment8548.$var,
"is-CompileEnvironment":is_DASH_CompileEnvironment8666.$var,
"compile-env":compile_DASH_env8862.$var,
"is-compile-env":is_DASH_compile_DASH_env8773.$var,
"CompileResult":CompileResult9052.$var,
"is-CompileResult":is_DASH_CompileResult9168.$var,
"ok":ok9393.$var,
"is-ok":is_DASH_ok9277.$var,
"err":err9564.$var,
"is-err":is_DASH_err9475.$var,
"CompileError":CompileError9750.$var,
"is-CompileError":is_DASH_CompileError9867.$var,
"wf-err":wf_DASH_err100105.$var,
"is-wf-err":is_DASH_wf_DASH_err9989.$var,
"wf-err-split":wf_DASH_err_DASH_split102104.$var,
"is-wf-err-split":is_DASH_wf_DASH_err_DASH_split10188.$var,
"reserved-name":reserved_DASH_name10496.$var,
"is-reserved-name":is_DASH_reserved_DASH_name10380.$var,
"zero-fraction":zero_DASH_fraction106106.$var,
"is-zero-fraction":is_DASH_zero_DASH_fraction10590.$var,
"unbound-id":unbound_DASH_id108100.$var,
"is-unbound-id":is_DASH_unbound_DASH_id10784.$var,
"unbound-var":unbound_DASH_var110102.$var,
"is-unbound-var":is_DASH_unbound_DASH_var10986.$var,
"unbound-type-id":unbound_DASH_type_DASH_id112101.$var,
"is-unbound-type-id":is_DASH_unbound_DASH_type_DASH_id11185.$var,
"unexpected-type-var":unexpected_DASH_type_DASH_var114103.$var,
"is-unexpected-type-var":is_DASH_unexpected_DASH_type_DASH_var11387.$var,
"pointless-var":pointless_DASH_var11695.$var,
"is-pointless-var":is_DASH_pointless_DASH_var11579.$var,
"pointless-shadow":pointless_DASH_shadow11894.$var,
"is-pointless-shadow":is_DASH_pointless_DASH_shadow11778.$var,
"bad-assignment":bad_DASH_assignment12061.$var,
"is-bad-assignment":is_DASH_bad_DASH_assignment11972.$var,
"mixed-id-var":mixed_DASH_id_DASH_var12292.$var,
"is-mixed-id-var":is_DASH_mixed_DASH_id_DASH_var12176.$var,
"shadow-id":shadow_DASH_id12497.$var,
"is-shadow-id":is_DASH_shadow_DASH_id12381.$var,
"duplicate-id":duplicate_DASH_id12663.$var,
"is-duplicate-id":is_DASH_duplicate_DASH_id12574.$var,
"CompileTypeBinding":CompileTypeBinding12853.$var,
"is-CompileTypeBinding":is_DASH_CompileTypeBinding12969.$var,
"type-id":type_DASH_id13198.$var,
"is-type-id":is_DASH_type_DASH_id13082.$var,
"type-module-bindings":type_DASH_module_DASH_bindings13399.$var,
"is-type-module-bindings":is_DASH_type_DASH_module_DASH_bindings13283.$var,
"runtime-types":runtime_DASH_types184117,
"standard-types":standard_DASH_types185242,
"CompileBinding":CompileBinding187246.$var,
"is-CompileBinding":is_DASH_CompileBinding188248.$var,
"builtin-id":builtin_DASH_id190252.$var,
"is-builtin-id":is_DASH_builtin_DASH_id189250.$var,
"module-bindings":module_DASH_bindings192256.$var,
"is-module-bindings":is_DASH_module_DASH_bindings191254.$var,
"runtime-builtins":runtime_DASH_builtins196403,
"no-builtins":no_DASH_builtins197441,
"minimal-builtins":minimal_DASH_builtins198453,
"bootstrap-builtins":bootstrap_DASH_builtins199553,
"standard-builtins":standard_DASH_builtins200739});
var anf_fun761751 = G(builtins14,"current-checker",L[52]);
var $z743744 = D;
var $f749750 = function(_) {
return R.isFunction(anf_fun761751)?anf_fun761751.app():R.ffi.throwNonFunApp(L[52],anf_fun761751,[]);
};
try {
if(--R.GAS > 0) {
$z743744 = $f749750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f749750,
"from":L[52]});
}
} catch($e741742) {
if(R.isCont($e741742)) {
var $ss745746 = {"from":L[52],
"go":function(anf_bracket762752) {
return $Hanf_bracket1031754(anf_bracket762752,CompileBinding7445,CompileEnvironment6647,CompileError7049,CompileResult6851,CompileTypeBinding7254,Loc7656,PyretDialect6458,provides760753,nothing16);
}};
$e741742.stack[R.EXN_STACKHEIGHT++] = $ss745746;
}
if(R.isPyretException($e741742)) {
$e741742.pyretStack.push(L[52]);
}
throw $e741742;
}
var $ret747748 = $Hanf_bracket1031754($z743744,CompileBinding7445,CompileEnvironment6647,CompileError7049,CompileResult6851,CompileTypeBinding7254,Loc7656,PyretDialect6458,provides760753,nothing16);
++R.GAS;
return $ret747748;
};
var $Hanf_bracket1031754 = function(anf_bracket762752,CompileBinding7445,CompileEnvironment6647,CompileError7049,CompileResult6851,CompileTypeBinding7254,Loc7656,PyretDialect6458,provides760753,nothing16) {
var anf_fun763765 = G(anf_bracket762752,"results",L[52]);
var $z757758 = D;
var $f763764 = function(_) {
return R.isFunction(anf_fun763765)?anf_fun763765.app():R.ffi.throwNonFunApp(L[52],anf_fun763765,[]);
};
try {
if(--R.GAS > 0) {
$z757758 = $f763764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f763764,
"from":L[52]});
}
} catch($e755756) {
if(R.isCont($e755756)) {
var $ss759760 = {"from":L[52],
"go":function(checks764766) {
return $Hchecks1030767(checks764766,CompileBinding7445,CompileEnvironment6647,CompileError7049,CompileResult6851,CompileTypeBinding7254,Loc7656,PyretDialect6458,provides760753,nothing16);
}};
$e755756.stack[R.EXN_STACKHEIGHT++] = $ss759760;
}
if(R.isPyretException($e755756)) {
$e755756.pyretStack.push(L[52]);
}
throw $e755756;
}
var $ret761762 = $Hchecks1030767($z757758,CompileBinding7445,CompileEnvironment6647,CompileError7049,CompileResult6851,CompileTypeBinding7254,Loc7656,PyretDialect6458,provides760753,nothing16);
++R.GAS;
return $ret761762;
};
var $Hchecks1030767 = function(checks764766,CompileBinding7445,CompileEnvironment6647,CompileError7049,CompileResult6851,CompileTypeBinding7254,Loc7656,PyretDialect6458,provides760753,nothing16) {
return R.makeObject({"answer":nothing16,
"provide-plus-types":R.makeObject({"values":provides760753,
"types":{"Loc":Loc7656,
"PyretDialect":PyretDialect6458,
"CompileEnvironment":CompileEnvironment6647,
"CompileResult":CompileResult6851,
"CompileError":CompileError7049,
"CompileTypeBinding":CompileTypeBinding7254,
"CompileBinding":CompileBinding7445}}),
"checks":checks764766});
};
var $Hanf_arg1029302 = function(anf_arg707300,self137301,_plus13,torepr17) {
var anf_arg708778 = G(self137301,"bindings",L[13]);
var $z770771 = D;
var $f776777 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg708778):R.ffi.throwNonFunApp(L[13],torepr17,[anf_arg708778]);
};
try {
if(--R.GAS > 0) {
$z770771 = $f776777();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f776777,
"from":L[13]});
}
} catch($e768769) {
if(R.isCont($e768769)) {
var $ss772773 = {"from":L[13],
"go":function(anf_arg709779) {
return $Hanf_arg1028780(anf_arg709779,anf_arg707300,_plus13);
}};
$e768769.stack[R.EXN_STACKHEIGHT++] = $ss772773;
}
if(R.isPyretException($e768769)) {
$e768769.pyretStack.push(L[13]);
}
throw $e768769;
}
var $ret774775 = $Hanf_arg1028780($z770771,anf_arg707300,_plus13);
++R.GAS;
return $ret774775;
};
var $Hanf_arg1028780 = function(anf_arg709779,anf_arg707300,_plus13) {
var $z783784 = D;
var $f789790 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg709779):R.ffi.throwNonFunApp(L[13],_plus13,[(", "),anf_arg709779]);
};
try {
if(--R.GAS > 0) {
$z783784 = $f789790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f789790,
"from":L[13]});
}
} catch($e781782) {
if(R.isCont($e781782)) {
var $ss785786 = {"from":L[13],
"go":function(anf_arg710791) {
return $Hanf_arg1027792(anf_arg710791,anf_arg707300,_plus13);
}};
$e781782.stack[R.EXN_STACKHEIGHT++] = $ss785786;
}
if(R.isPyretException($e781782)) {
$e781782.pyretStack.push(L[13]);
}
throw $e781782;
}
var $ret787788 = $Hanf_arg1027792($z783784,anf_arg707300,_plus13);
++R.GAS;
return $ret787788;
};
var $Hanf_arg1027792 = function(anf_arg710791,anf_arg707300,_plus13) {
var $z795796 = D;
var $f801802 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg707300,anf_arg710791):R.ffi.throwNonFunApp(L[13],_plus13,[anf_arg707300,anf_arg710791]);
};
try {
if(--R.GAS > 0) {
$z795796 = $f801802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f801802,
"from":L[13]});
}
} catch($e793794) {
if(R.isCont($e793794)) {
var $ss797798 = {"from":L[13],
"go":function(anf_arg711803) {
return $Hanf_arg1026804(anf_arg711803,_plus13);
}};
$e793794.stack[R.EXN_STACKHEIGHT++] = $ss797798;
}
if(R.isPyretException($e793794)) {
$e793794.pyretStack.push(L[13]);
}
throw $e793794;
}
var $ret799800 = $Hanf_arg1026804($z795796,_plus13);
++R.GAS;
return $ret799800;
};
var $Hanf_arg1026804 = function(anf_arg711803,_plus13) {
var $z807808 = D;
var $f813814 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg711803,(")")):R.ffi.throwNonFunApp(L[13],_plus13,[anf_arg711803,(")")]);
};
try {
if(--R.GAS > 0) {
$z807808 = $f813814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f813814,
"from":L[13]});
}
} catch($e805806) {
if(R.isCont($e805806)) {
var $ss809810 = {"from":L[13],
"go":function(anf_arg712815) {
return $Hanf_arg1025816(anf_arg712815,_plus13);
}};
$e805806.stack[R.EXN_STACKHEIGHT++] = $ss809810;
}
if(R.isPyretException($e805806)) {
$e805806.pyretStack.push(L[13]);
}
throw $e805806;
}
var $ret811812 = $Hanf_arg1025816($z807808,_plus13);
++R.GAS;
return $ret811812;
};
var $Hanf_arg1025816 = function(anf_arg712815,_plus13) {
var $z819820 = D;
var $f825826 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg712815):R.ffi.throwNonFunApp(L[13],_plus13,[("("),anf_arg712815]);
};
try {
if(--R.GAS > 0) {
$z819820 = $f825826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f825826,
"from":L[13]});
}
} catch($e817818) {
if(R.isCont($e817818)) {
var $ss821822 = {"from":L[13],
"go":function(anf_arg713827) {
return $Hanf_arg1024828(anf_arg713827,_plus13);
}};
$e817818.stack[R.EXN_STACKHEIGHT++] = $ss821822;
}
if(R.isPyretException($e817818)) {
$e817818.pyretStack.push(L[13]);
}
throw $e817818;
}
var $ret823824 = $Hanf_arg1024828($z819820,_plus13);
++R.GAS;
return $ret823824;
};
var $Hanf_arg1024828 = function(anf_arg713827,_plus13) {
var $z831832 = D;
var $f837838 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("module-bindings"),anf_arg713827):R.ffi.throwNonFunApp(L[13],_plus13,[("module-bindings"),anf_arg713827]);
};
try {
if(--R.GAS > 0) {
$z831832 = $f837838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f837838,
"from":L[13]});
}
} catch($e829830) {
if(R.isCont($e829830)) {
var $ss833834 = {"from":L[13],
"go":function(ann_DASH_check_DASH_temp705839) {
return $Hann_DASH_check_DASH_temp1023840(ann_DASH_check_DASH_temp705839);
}};
$e829830.stack[R.EXN_STACKHEIGHT++] = $ss833834;
}
if(R.isPyretException($e829830)) {
$e829830.pyretStack.push(L[13]);
}
throw $e829830;
}
var $ret835836 = $Hann_DASH_check_DASH_temp1023840($z831832);
++R.GAS;
return $ret835836;
};
var $Hann_DASH_check_DASH_temp1023840 = function(ann_DASH_check_DASH_temp705839) {
return ann_DASH_check_DASH_temp705839;
};
var $Hcont_tail_arg1021318 = function(cont_tail_arg702316,if_helper693317) {
if(--R.GAS > 0) {
$z841842 = R.isFunction(if_helper693317)?if_helper693317.app(cont_tail_arg702316):R.ffi.throwNonFunApp(L[13],if_helper693317,[cont_tail_arg702316]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper693317)?if_helper693317.app(cont_tail_arg702316):R.ffi.throwNonFunApp(L[13],if_helper693317,[cont_tail_arg702316]);
},
"from":L[13]});
}
++R.GAS;
return $z841842;
};
var $Hcont_tail_arg1022333 = function(cont_tail_arg698332,if_helper693317) {
if(--R.GAS > 0) {
$z843844 = R.isFunction(if_helper693317)?if_helper693317.app(cont_tail_arg698332):R.ffi.throwNonFunApp(L[13],if_helper693317,[cont_tail_arg698332]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper693317)?if_helper693317.app(cont_tail_arg698332):R.ffi.throwNonFunApp(L[13],if_helper693317,[cont_tail_arg698332]);
},
"from":L[13]});
}
++R.GAS;
return $z843844;
};
var $Hanf_arg1020354 = function(anf_arg688353,_plus13) {
var $z847848 = D;
var $f853854 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg688353,(")")):R.ffi.throwNonFunApp(L[14],_plus13,[anf_arg688353,(")")]);
};
try {
if(--R.GAS > 0) {
$z847848 = $f853854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f853854,
"from":L[14]});
}
} catch($e845846) {
if(R.isCont($e845846)) {
var $ss849850 = {"from":L[14],
"go":function(anf_arg689855) {
return $Hanf_arg1019856(anf_arg689855,_plus13);
}};
$e845846.stack[R.EXN_STACKHEIGHT++] = $ss849850;
}
if(R.isPyretException($e845846)) {
$e845846.pyretStack.push(L[14]);
}
throw $e845846;
}
var $ret851852 = $Hanf_arg1019856($z847848,_plus13);
++R.GAS;
return $ret851852;
};
var $Hanf_arg1019856 = function(anf_arg689855,_plus13) {
var $z859860 = D;
var $f865866 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg689855):R.ffi.throwNonFunApp(L[14],_plus13,[("("),anf_arg689855]);
};
try {
if(--R.GAS > 0) {
$z859860 = $f865866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f865866,
"from":L[14]});
}
} catch($e857858) {
if(R.isCont($e857858)) {
var $ss861862 = {"from":L[14],
"go":function(anf_arg690867) {
return $Hanf_arg1018868(anf_arg690867,_plus13);
}};
$e857858.stack[R.EXN_STACKHEIGHT++] = $ss861862;
}
if(R.isPyretException($e857858)) {
$e857858.pyretStack.push(L[14]);
}
throw $e857858;
}
var $ret863864 = $Hanf_arg1018868($z859860,_plus13);
++R.GAS;
return $ret863864;
};
var $Hanf_arg1018868 = function(anf_arg690867,_plus13) {
var $z871872 = D;
var $f877878 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("builtin-id"),anf_arg690867):R.ffi.throwNonFunApp(L[14],_plus13,[("builtin-id"),anf_arg690867]);
};
try {
if(--R.GAS > 0) {
$z871872 = $f877878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f877878,
"from":L[14]});
}
} catch($e869870) {
if(R.isCont($e869870)) {
var $ss873874 = {"from":L[14],
"go":function(ann_DASH_check_DASH_temp686879) {
return $Hann_DASH_check_DASH_temp1017880(ann_DASH_check_DASH_temp686879);
}};
$e869870.stack[R.EXN_STACKHEIGHT++] = $ss873874;
}
if(R.isPyretException($e869870)) {
$e869870.pyretStack.push(L[14]);
}
throw $e869870;
}
var $ret875876 = $Hann_DASH_check_DASH_temp1017880($z871872);
++R.GAS;
return $ret875876;
};
var $Hann_DASH_check_DASH_temp1017880 = function(ann_DASH_check_DASH_temp686879) {
return ann_DASH_check_DASH_temp686879;
};
var $Hcont_tail_arg1015370 = function(cont_tail_arg683368,if_helper675369) {
if(--R.GAS > 0) {
$z881882 = R.isFunction(if_helper675369)?if_helper675369.app(cont_tail_arg683368):R.ffi.throwNonFunApp(L[14],if_helper675369,[cont_tail_arg683368]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper675369)?if_helper675369.app(cont_tail_arg683368):R.ffi.throwNonFunApp(L[14],if_helper675369,[cont_tail_arg683368]);
},
"from":L[14]});
}
++R.GAS;
return $z881882;
};
var $Hcont_tail_arg1016385 = function(cont_tail_arg680384,if_helper675369) {
if(--R.GAS > 0) {
$z883884 = R.isFunction(if_helper675369)?if_helper675369.app(cont_tail_arg680384):R.ffi.throwNonFunApp(L[14],if_helper675369,[cont_tail_arg680384]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper675369)?if_helper675369.app(cont_tail_arg680384):R.ffi.throwNonFunApp(L[14],if_helper675369,[cont_tail_arg680384]);
},
"from":L[14]});
}
++R.GAS;
return $z883884;
};
var $Hanf_arg1014885 = function(anf_arg642886,self125887,_plus13,torepr17) {
var anf_arg643898 = G(self125887,"bindings",L[53]);
var $z890891 = D;
var $f896897 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg643898):R.ffi.throwNonFunApp(L[53],torepr17,[anf_arg643898]);
};
try {
if(--R.GAS > 0) {
$z890891 = $f896897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f896897,
"from":L[53]});
}
} catch($e888889) {
if(R.isCont($e888889)) {
var $ss892893 = {"from":L[53],
"go":function(anf_arg644899) {
return $Hanf_arg1013900(anf_arg644899,anf_arg642886,_plus13);
}};
$e888889.stack[R.EXN_STACKHEIGHT++] = $ss892893;
}
if(R.isPyretException($e888889)) {
$e888889.pyretStack.push(L[53]);
}
throw $e888889;
}
var $ret894895 = $Hanf_arg1013900($z890891,anf_arg642886,_plus13);
++R.GAS;
return $ret894895;
};
var $Hanf_arg1013900 = function(anf_arg644899,anf_arg642886,_plus13) {
var $z903904 = D;
var $f909910 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg644899):R.ffi.throwNonFunApp(L[53],_plus13,[(", "),anf_arg644899]);
};
try {
if(--R.GAS > 0) {
$z903904 = $f909910();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f909910,
"from":L[53]});
}
} catch($e901902) {
if(R.isCont($e901902)) {
var $ss905906 = {"from":L[53],
"go":function(anf_arg645911) {
return $Hanf_arg1012912(anf_arg645911,anf_arg642886,_plus13);
}};
$e901902.stack[R.EXN_STACKHEIGHT++] = $ss905906;
}
if(R.isPyretException($e901902)) {
$e901902.pyretStack.push(L[53]);
}
throw $e901902;
}
var $ret907908 = $Hanf_arg1012912($z903904,anf_arg642886,_plus13);
++R.GAS;
return $ret907908;
};
var $Hanf_arg1012912 = function(anf_arg645911,anf_arg642886,_plus13) {
var $z915916 = D;
var $f921922 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg642886,anf_arg645911):R.ffi.throwNonFunApp(L[53],_plus13,[anf_arg642886,anf_arg645911]);
};
try {
if(--R.GAS > 0) {
$z915916 = $f921922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f921922,
"from":L[53]});
}
} catch($e913914) {
if(R.isCont($e913914)) {
var $ss917918 = {"from":L[53],
"go":function(anf_arg646923) {
return $Hanf_arg1011924(anf_arg646923,_plus13);
}};
$e913914.stack[R.EXN_STACKHEIGHT++] = $ss917918;
}
if(R.isPyretException($e913914)) {
$e913914.pyretStack.push(L[53]);
}
throw $e913914;
}
var $ret919920 = $Hanf_arg1011924($z915916,_plus13);
++R.GAS;
return $ret919920;
};
var $Hanf_arg1011924 = function(anf_arg646923,_plus13) {
var $z927928 = D;
var $f933934 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg646923,(")")):R.ffi.throwNonFunApp(L[53],_plus13,[anf_arg646923,(")")]);
};
try {
if(--R.GAS > 0) {
$z927928 = $f933934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f933934,
"from":L[53]});
}
} catch($e925926) {
if(R.isCont($e925926)) {
var $ss929930 = {"from":L[53],
"go":function(anf_arg647935) {
return $Hanf_arg1010936(anf_arg647935,_plus13);
}};
$e925926.stack[R.EXN_STACKHEIGHT++] = $ss929930;
}
if(R.isPyretException($e925926)) {
$e925926.pyretStack.push(L[53]);
}
throw $e925926;
}
var $ret931932 = $Hanf_arg1010936($z927928,_plus13);
++R.GAS;
return $ret931932;
};
var $Hanf_arg1010936 = function(anf_arg647935,_plus13) {
var $z939940 = D;
var $f945946 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg647935):R.ffi.throwNonFunApp(L[53],_plus13,[("("),anf_arg647935]);
};
try {
if(--R.GAS > 0) {
$z939940 = $f945946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f945946,
"from":L[53]});
}
} catch($e937938) {
if(R.isCont($e937938)) {
var $ss941942 = {"from":L[53],
"go":function(anf_arg648947) {
return $Hanf_arg1009948(anf_arg648947,_plus13);
}};
$e937938.stack[R.EXN_STACKHEIGHT++] = $ss941942;
}
if(R.isPyretException($e937938)) {
$e937938.pyretStack.push(L[53]);
}
throw $e937938;
}
var $ret943944 = $Hanf_arg1009948($z939940,_plus13);
++R.GAS;
return $ret943944;
};
var $Hanf_arg1009948 = function(anf_arg648947,_plus13) {
var $z951952 = D;
var $f957958 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("type-module-bindings"),anf_arg648947):R.ffi.throwNonFunApp(L[53],_plus13,[("type-module-bindings"),anf_arg648947]);
};
try {
if(--R.GAS > 0) {
$z951952 = $f957958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f957958,
"from":L[53]});
}
} catch($e949950) {
if(R.isCont($e949950)) {
var $ss953954 = {"from":L[53],
"go":function(ann_DASH_check_DASH_temp640959) {
return $Hann_DASH_check_DASH_temp1008960(ann_DASH_check_DASH_temp640959);
}};
$e949950.stack[R.EXN_STACKHEIGHT++] = $ss953954;
}
if(R.isPyretException($e949950)) {
$e949950.pyretStack.push(L[53]);
}
throw $e949950;
}
var $ret955956 = $Hann_DASH_check_DASH_temp1008960($z951952);
++R.GAS;
return $ret955956;
};
var $Hann_DASH_check_DASH_temp1008960 = function(ann_DASH_check_DASH_temp640959) {
return ann_DASH_check_DASH_temp640959;
};
var $Hcont_tail_arg1006961 = function(cont_tail_arg637962,if_helper628963) {
if(--R.GAS > 0) {
$z964965 = R.isFunction(if_helper628963)?if_helper628963.app(cont_tail_arg637962):R.ffi.throwNonFunApp(L[53],if_helper628963,[cont_tail_arg637962]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper628963)?if_helper628963.app(cont_tail_arg637962):R.ffi.throwNonFunApp(L[53],if_helper628963,[cont_tail_arg637962]);
},
"from":L[53]});
}
++R.GAS;
return $z964965;
};
var $Hcont_tail_arg1007966 = function(cont_tail_arg633967,if_helper628963) {
if(--R.GAS > 0) {
$z968969 = R.isFunction(if_helper628963)?if_helper628963.app(cont_tail_arg633967):R.ffi.throwNonFunApp(L[53],if_helper628963,[cont_tail_arg633967]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper628963)?if_helper628963.app(cont_tail_arg633967):R.ffi.throwNonFunApp(L[53],if_helper628963,[cont_tail_arg633967]);
},
"from":L[53]});
}
++R.GAS;
return $z968969;
};
var $Hanf_arg1005970 = function(anf_arg623971,_plus13) {
var $z974975 = D;
var $f980981 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg623971,(")")):R.ffi.throwNonFunApp(L[54],_plus13,[anf_arg623971,(")")]);
};
try {
if(--R.GAS > 0) {
$z974975 = $f980981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f980981,
"from":L[54]});
}
} catch($e972973) {
if(R.isCont($e972973)) {
var $ss976977 = {"from":L[54],
"go":function(anf_arg624982) {
return $Hanf_arg1004983(anf_arg624982,_plus13);
}};
$e972973.stack[R.EXN_STACKHEIGHT++] = $ss976977;
}
if(R.isPyretException($e972973)) {
$e972973.pyretStack.push(L[54]);
}
throw $e972973;
}
var $ret978979 = $Hanf_arg1004983($z974975,_plus13);
++R.GAS;
return $ret978979;
};
var $Hanf_arg1004983 = function(anf_arg624982,_plus13) {
var $z986987 = D;
var $f992993 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg624982):R.ffi.throwNonFunApp(L[54],_plus13,[("("),anf_arg624982]);
};
try {
if(--R.GAS > 0) {
$z986987 = $f992993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f992993,
"from":L[54]});
}
} catch($e984985) {
if(R.isCont($e984985)) {
var $ss988989 = {"from":L[54],
"go":function(anf_arg625994) {
return $Hanf_arg1003995(anf_arg625994,_plus13);
}};
$e984985.stack[R.EXN_STACKHEIGHT++] = $ss988989;
}
if(R.isPyretException($e984985)) {
$e984985.pyretStack.push(L[54]);
}
throw $e984985;
}
var $ret990991 = $Hanf_arg1003995($z986987,_plus13);
++R.GAS;
return $ret990991;
};
var $Hanf_arg1003995 = function(anf_arg625994,_plus13) {
var $z998999 = D;
var $f10041005 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("type-id"),anf_arg625994):R.ffi.throwNonFunApp(L[54],_plus13,[("type-id"),anf_arg625994]);
};
try {
if(--R.GAS > 0) {
$z998999 = $f10041005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10041005,
"from":L[54]});
}
} catch($e996997) {
if(R.isCont($e996997)) {
var $ss10001001 = {"from":L[54],
"go":function(ann_DASH_check_DASH_temp6211006) {
return $Hann_DASH_check_DASH_temp10021007(ann_DASH_check_DASH_temp6211006);
}};
$e996997.stack[R.EXN_STACKHEIGHT++] = $ss10001001;
}
if(R.isPyretException($e996997)) {
$e996997.pyretStack.push(L[54]);
}
throw $e996997;
}
var $ret10021003 = $Hann_DASH_check_DASH_temp10021007($z998999);
++R.GAS;
return $ret10021003;
};
var $Hann_DASH_check_DASH_temp10021007 = function(ann_DASH_check_DASH_temp6211006) {
return ann_DASH_check_DASH_temp6211006;
};
var $Hcont_tail_arg10001008 = function(cont_tail_arg6181009,if_helper6101010) {
if(--R.GAS > 0) {
$z10111012 = R.isFunction(if_helper6101010)?if_helper6101010.app(cont_tail_arg6181009):R.ffi.throwNonFunApp(L[54],if_helper6101010,[cont_tail_arg6181009]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper6101010)?if_helper6101010.app(cont_tail_arg6181009):R.ffi.throwNonFunApp(L[54],if_helper6101010,[cont_tail_arg6181009]);
},
"from":L[54]});
}
++R.GAS;
return $z10111012;
};
var $Hcont_tail_arg10011013 = function(cont_tail_arg6151014,if_helper6101010) {
if(--R.GAS > 0) {
$z10151016 = R.isFunction(if_helper6101010)?if_helper6101010.app(cont_tail_arg6151014):R.ffi.throwNonFunApp(L[54],if_helper6101010,[cont_tail_arg6151014]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper6101010)?if_helper6101010.app(cont_tail_arg6151014):R.ffi.throwNonFunApp(L[54],if_helper6101010,[cont_tail_arg6151014]);
},
"from":L[54]});
}
++R.GAS;
return $z10151016;
};
var $Hanf_arg9991017 = function(anf_arg5631018,self1801019,_plus13,not15,tostring18) {
var $z10221023 = D;
var $f10281029 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5631018,(" is declared twice, at ")):R.ffi.throwNonFunApp(L[55],_plus13,[anf_arg5631018,(" is declared twice, at ")]);
};
try {
if(--R.GAS > 0) {
$z10221023 = $f10281029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10281029,
"from":L[55]});
}
} catch($e10201021) {
if(R.isCont($e10201021)) {
var $ss10241025 = {"from":L[55],
"go":function(anf_arg5641030) {
return $Hanf_arg9981031(anf_arg5641030,self1801019,_plus13,not15,tostring18);
}};
$e10201021.stack[R.EXN_STACKHEIGHT++] = $ss10241025;
}
if(R.isPyretException($e10201021)) {
$e10201021.pyretStack.push(L[55]);
}
throw $e10201021;
}
var $ret10261027 = $Hanf_arg9981031($z10221023,self1801019,_plus13,not15,tostring18);
++R.GAS;
return $ret10261027;
};
var $Hanf_arg9981031 = function(anf_arg5641030,self1801019,_plus13,not15,tostring18) {
var anf_arg5651042 = G(self1801019,"new-loc",L[57]);
var $z10341035 = D;
var $f10401041 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg5651042):R.ffi.throwNonFunApp(L[56],tostring18,[anf_arg5651042]);
};
try {
if(--R.GAS > 0) {
$z10341035 = $f10401041();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10401041,
"from":L[56]});
}
} catch($e10321033) {
if(R.isCont($e10321033)) {
var $ss10361037 = {"from":L[56],
"go":function(anf_arg5661043) {
return $Hanf_arg9971044(anf_arg5661043,anf_arg5641030,self1801019,_plus13,not15);
}};
$e10321033.stack[R.EXN_STACKHEIGHT++] = $ss10361037;
}
if(R.isPyretException($e10321033)) {
$e10321033.pyretStack.push(L[56]);
}
throw $e10321033;
}
var $ret10381039 = $Hanf_arg9971044($z10341035,anf_arg5641030,self1801019,_plus13,not15);
++R.GAS;
return $ret10381039;
};
var $Hanf_arg9971044 = function(anf_arg5661043,anf_arg5641030,self1801019,_plus13,not15) {
var $z10471048 = D;
var $f10531054 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5641030,anf_arg5661043):R.ffi.throwNonFunApp(L[55],_plus13,[anf_arg5641030,anf_arg5661043]);
};
try {
if(--R.GAS > 0) {
$z10471048 = $f10531054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10531054,
"from":L[55]});
}
} catch($e10451046) {
if(R.isCont($e10451046)) {
var $ss10491050 = {"from":L[55],
"go":function(anf_arg5671055) {
return $Hanf_arg9961056(anf_arg5671055,self1801019,_plus13,not15);
}};
$e10451046.stack[R.EXN_STACKHEIGHT++] = $ss10491050;
}
if(R.isPyretException($e10451046)) {
$e10451046.pyretStack.push(L[55]);
}
throw $e10451046;
}
var $ret10511052 = $Hanf_arg9961056($z10471048,self1801019,_plus13,not15);
++R.GAS;
return $ret10511052;
};
var $Hanf_arg9961056 = function(anf_arg5671055,self1801019,_plus13,not15) {
var $z10591060 = D;
var $f10651066 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5671055,(" and at ")):R.ffi.throwNonFunApp(L[55],_plus13,[anf_arg5671055,(" and at ")]);
};
try {
if(--R.GAS > 0) {
$z10591060 = $f10651066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10651066,
"from":L[55]});
}
} catch($e10571058) {
if(R.isCont($e10571058)) {
var $ss10611062 = {"from":L[55],
"go":function(anf_arg5681067) {
return $Hanf_arg9951068(anf_arg5681067,self1801019,_plus13,not15);
}};
$e10571058.stack[R.EXN_STACKHEIGHT++] = $ss10611062;
}
if(R.isPyretException($e10571058)) {
$e10571058.pyretStack.push(L[55]);
}
throw $e10571058;
}
var $ret10631064 = $Hanf_arg9951068($z10591060,self1801019,_plus13,not15);
++R.GAS;
return $ret10631064;
};
var $Hanf_arg9951068 = function(anf_arg5681067,self1801019,_plus13,not15) {
var anf_bracket5691085 = G(self1801019,"old-loc",L[63]);
var anf_fun5701082 = G(anf_bracket5691085,"format",L[62]);
var anf_bracket5711084 = G(self1801019,"new-loc",L[61]);
var anf_fun5721079 = G(anf_bracket5711084,"same-file",L[60]);
var anf_arg5731080 = G(self1801019,"old-loc",L[59]);
var $z10711072 = D;
var $f10771078 = function(_) {
return R.isFunction(anf_fun5721079)?anf_fun5721079.app(anf_arg5731080):R.ffi.throwNonFunApp(L[58],anf_fun5721079,[anf_arg5731080]);
};
try {
if(--R.GAS > 0) {
$z10711072 = $f10771078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10771078,
"from":L[58]});
}
} catch($e10691070) {
if(R.isCont($e10691070)) {
var $ss10731074 = {"from":L[58],
"go":function(anf_arg5741081) {
return $Hanf_arg9941083(anf_arg5741081,anf_arg5681067,anf_fun5701082,_plus13,not15);
}};
$e10691070.stack[R.EXN_STACKHEIGHT++] = $ss10731074;
}
if(R.isPyretException($e10691070)) {
$e10691070.pyretStack.push(L[58]);
}
throw $e10691070;
}
var $ret10751076 = $Hanf_arg9941083($z10711072,anf_arg5681067,anf_fun5701082,_plus13,not15);
++R.GAS;
return $ret10751076;
};
var $Hanf_arg9941083 = function(anf_arg5741081,anf_arg5681067,anf_fun5701082,_plus13,not15) {
var $z10881089 = D;
var $f10941095 = function(_) {
return R.isFunction(not15)?not15.app(anf_arg5741081):R.ffi.throwNonFunApp(L[64],not15,[anf_arg5741081]);
};
try {
if(--R.GAS > 0) {
$z10881089 = $f10941095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10941095,
"from":L[64]});
}
} catch($e10861087) {
if(R.isCont($e10861087)) {
var $ss10901091 = {"from":L[64],
"go":function(anf_arg5751096) {
return $Hanf_arg9931097(anf_arg5751096,anf_arg5681067,anf_fun5701082,_plus13);
}};
$e10861087.stack[R.EXN_STACKHEIGHT++] = $ss10901091;
}
if(R.isPyretException($e10861087)) {
$e10861087.pyretStack.push(L[64]);
}
throw $e10861087;
}
var $ret10921093 = $Hanf_arg9931097($z10881089,anf_arg5681067,anf_fun5701082,_plus13);
++R.GAS;
return $ret10921093;
};
var $Hanf_arg9931097 = function(anf_arg5751096,anf_arg5681067,anf_fun5701082,_plus13) {
var $z11001101 = D;
var $f11061107 = function(_) {
return R.isFunction(anf_fun5701082)?anf_fun5701082.app(anf_arg5751096):R.ffi.throwNonFunApp(L[65],anf_fun5701082,[anf_arg5751096]);
};
try {
if(--R.GAS > 0) {
$z11001101 = $f11061107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11061107,
"from":L[65]});
}
} catch($e10981099) {
if(R.isCont($e10981099)) {
var $ss11021103 = {"from":L[65],
"go":function(anf_arg5761108) {
return $Hanf_arg9921109(anf_arg5761108,anf_arg5681067,_plus13);
}};
$e10981099.stack[R.EXN_STACKHEIGHT++] = $ss11021103;
}
if(R.isPyretException($e10981099)) {
$e10981099.pyretStack.push(L[65]);
}
throw $e10981099;
}
var $ret11041105 = $Hanf_arg9921109($z11001101,anf_arg5681067,_plus13);
++R.GAS;
return $ret11041105;
};
var $Hanf_arg9921109 = function(anf_arg5761108,anf_arg5681067,_plus13) {
var $z11121113 = D;
var $f11181119 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5681067,anf_arg5761108):R.ffi.throwNonFunApp(L[66],_plus13,[anf_arg5681067,anf_arg5761108]);
};
try {
if(--R.GAS > 0) {
$z11121113 = $f11181119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11181119,
"from":L[66]});
}
} catch($e11101111) {
if(R.isCont($e11101111)) {
var $ss11141115 = {"from":L[66],
"go":function(ann_DASH_check_DASH_temp5611120) {
return $Hann_DASH_check_DASH_temp9911121(ann_DASH_check_DASH_temp5611120);
}};
$e11101111.stack[R.EXN_STACKHEIGHT++] = $ss11141115;
}
if(R.isPyretException($e11101111)) {
$e11101111.pyretStack.push(L[66]);
}
throw $e11101111;
}
var $ret11161117 = $Hann_DASH_check_DASH_temp9911121($z11121113);
++R.GAS;
return $ret11161117;
};
var $Hann_DASH_check_DASH_temp9911121 = function(ann_DASH_check_DASH_temp5611120) {
return ann_DASH_check_DASH_temp5611120;
};
var $Hanf_arg9901122 = function(anf_arg5491123,self1131124,_plus13,torepr17) {
var anf_arg5501135 = G(self1131124,"new-loc",L[67]);
var $z11271128 = D;
var $f11331134 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg5501135):R.ffi.throwNonFunApp(L[67],torepr17,[anf_arg5501135]);
};
try {
if(--R.GAS > 0) {
$z11271128 = $f11331134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11331134,
"from":L[67]});
}
} catch($e11251126) {
if(R.isCont($e11251126)) {
var $ss11291130 = {"from":L[67],
"go":function(anf_arg5511136) {
return $Hanf_arg9891137(anf_arg5511136,anf_arg5491123,self1131124,_plus13,torepr17);
}};
$e11251126.stack[R.EXN_STACKHEIGHT++] = $ss11291130;
}
if(R.isPyretException($e11251126)) {
$e11251126.pyretStack.push(L[67]);
}
throw $e11251126;
}
var $ret11311132 = $Hanf_arg9891137($z11271128,anf_arg5491123,self1131124,_plus13,torepr17);
++R.GAS;
return $ret11311132;
};
var $Hanf_arg9891137 = function(anf_arg5511136,anf_arg5491123,self1131124,_plus13,torepr17) {
var $z11401141 = D;
var $f11461147 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg5511136):R.ffi.throwNonFunApp(L[67],_plus13,[(", "),anf_arg5511136]);
};
try {
if(--R.GAS > 0) {
$z11401141 = $f11461147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11461147,
"from":L[67]});
}
} catch($e11381139) {
if(R.isCont($e11381139)) {
var $ss11421143 = {"from":L[67],
"go":function(anf_arg5521148) {
return $Hanf_arg9881149(anf_arg5521148,anf_arg5491123,self1131124,_plus13,torepr17);
}};
$e11381139.stack[R.EXN_STACKHEIGHT++] = $ss11421143;
}
if(R.isPyretException($e11381139)) {
$e11381139.pyretStack.push(L[67]);
}
throw $e11381139;
}
var $ret11441145 = $Hanf_arg9881149($z11401141,anf_arg5491123,self1131124,_plus13,torepr17);
++R.GAS;
return $ret11441145;
};
var $Hanf_arg9881149 = function(anf_arg5521148,anf_arg5491123,self1131124,_plus13,torepr17) {
var $z11521153 = D;
var $f11581159 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5491123,anf_arg5521148):R.ffi.throwNonFunApp(L[67],_plus13,[anf_arg5491123,anf_arg5521148]);
};
try {
if(--R.GAS > 0) {
$z11521153 = $f11581159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11581159,
"from":L[67]});
}
} catch($e11501151) {
if(R.isCont($e11501151)) {
var $ss11541155 = {"from":L[67],
"go":function(anf_arg5531160) {
return $Hanf_arg9871161(anf_arg5531160,self1131124,_plus13,torepr17);
}};
$e11501151.stack[R.EXN_STACKHEIGHT++] = $ss11541155;
}
if(R.isPyretException($e11501151)) {
$e11501151.pyretStack.push(L[67]);
}
throw $e11501151;
}
var $ret11561157 = $Hanf_arg9871161($z11521153,self1131124,_plus13,torepr17);
++R.GAS;
return $ret11561157;
};
var $Hanf_arg9871161 = function(anf_arg5531160,self1131124,_plus13,torepr17) {
var anf_arg5541172 = G(self1131124,"old-loc",L[67]);
var $z11641165 = D;
var $f11701171 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg5541172):R.ffi.throwNonFunApp(L[67],torepr17,[anf_arg5541172]);
};
try {
if(--R.GAS > 0) {
$z11641165 = $f11701171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11701171,
"from":L[67]});
}
} catch($e11621163) {
if(R.isCont($e11621163)) {
var $ss11661167 = {"from":L[67],
"go":function(anf_arg5551173) {
return $Hanf_arg9861174(anf_arg5551173,anf_arg5531160,_plus13);
}};
$e11621163.stack[R.EXN_STACKHEIGHT++] = $ss11661167;
}
if(R.isPyretException($e11621163)) {
$e11621163.pyretStack.push(L[67]);
}
throw $e11621163;
}
var $ret11681169 = $Hanf_arg9861174($z11641165,anf_arg5531160,_plus13);
++R.GAS;
return $ret11681169;
};
var $Hanf_arg9861174 = function(anf_arg5551173,anf_arg5531160,_plus13) {
var $z11771178 = D;
var $f11831184 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg5551173):R.ffi.throwNonFunApp(L[67],_plus13,[(", "),anf_arg5551173]);
};
try {
if(--R.GAS > 0) {
$z11771178 = $f11831184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11831184,
"from":L[67]});
}
} catch($e11751176) {
if(R.isCont($e11751176)) {
var $ss11791180 = {"from":L[67],
"go":function(anf_arg5561185) {
return $Hanf_arg9851186(anf_arg5561185,anf_arg5531160,_plus13);
}};
$e11751176.stack[R.EXN_STACKHEIGHT++] = $ss11791180;
}
if(R.isPyretException($e11751176)) {
$e11751176.pyretStack.push(L[67]);
}
throw $e11751176;
}
var $ret11811182 = $Hanf_arg9851186($z11771178,anf_arg5531160,_plus13);
++R.GAS;
return $ret11811182;
};
var $Hanf_arg9851186 = function(anf_arg5561185,anf_arg5531160,_plus13) {
var $z11891190 = D;
var $f11951196 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5531160,anf_arg5561185):R.ffi.throwNonFunApp(L[67],_plus13,[anf_arg5531160,anf_arg5561185]);
};
try {
if(--R.GAS > 0) {
$z11891190 = $f11951196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11951196,
"from":L[67]});
}
} catch($e11871188) {
if(R.isCont($e11871188)) {
var $ss11911192 = {"from":L[67],
"go":function(anf_arg5571197) {
return $Hanf_arg9841198(anf_arg5571197,_plus13);
}};
$e11871188.stack[R.EXN_STACKHEIGHT++] = $ss11911192;
}
if(R.isPyretException($e11871188)) {
$e11871188.pyretStack.push(L[67]);
}
throw $e11871188;
}
var $ret11931194 = $Hanf_arg9841198($z11891190,_plus13);
++R.GAS;
return $ret11931194;
};
var $Hanf_arg9841198 = function(anf_arg5571197,_plus13) {
var $z12011202 = D;
var $f12071208 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5571197,(")")):R.ffi.throwNonFunApp(L[67],_plus13,[anf_arg5571197,(")")]);
};
try {
if(--R.GAS > 0) {
$z12011202 = $f12071208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12071208,
"from":L[67]});
}
} catch($e11991200) {
if(R.isCont($e11991200)) {
var $ss12031204 = {"from":L[67],
"go":function(anf_arg5581209) {
return $Hanf_arg9831210(anf_arg5581209,_plus13);
}};
$e11991200.stack[R.EXN_STACKHEIGHT++] = $ss12031204;
}
if(R.isPyretException($e11991200)) {
$e11991200.pyretStack.push(L[67]);
}
throw $e11991200;
}
var $ret12051206 = $Hanf_arg9831210($z12011202,_plus13);
++R.GAS;
return $ret12051206;
};
var $Hanf_arg9831210 = function(anf_arg5581209,_plus13) {
var $z12131214 = D;
var $f12191220 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg5581209):R.ffi.throwNonFunApp(L[67],_plus13,[("("),anf_arg5581209]);
};
try {
if(--R.GAS > 0) {
$z12131214 = $f12191220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12191220,
"from":L[67]});
}
} catch($e12111212) {
if(R.isCont($e12111212)) {
var $ss12151216 = {"from":L[67],
"go":function(anf_arg5591221) {
return $Hanf_arg9821222(anf_arg5591221,_plus13);
}};
$e12111212.stack[R.EXN_STACKHEIGHT++] = $ss12151216;
}
if(R.isPyretException($e12111212)) {
$e12111212.pyretStack.push(L[67]);
}
throw $e12111212;
}
var $ret12171218 = $Hanf_arg9821222($z12131214,_plus13);
++R.GAS;
return $ret12171218;
};
var $Hanf_arg9821222 = function(anf_arg5591221,_plus13) {
var $z12251226 = D;
var $f12311232 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("duplicate-id"),anf_arg5591221):R.ffi.throwNonFunApp(L[67],_plus13,[("duplicate-id"),anf_arg5591221]);
};
try {
if(--R.GAS > 0) {
$z12251226 = $f12311232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12311232,
"from":L[67]});
}
} catch($e12231224) {
if(R.isCont($e12231224)) {
var $ss12271228 = {"from":L[67],
"go":function(ann_DASH_check_DASH_temp5471233) {
return $Hann_DASH_check_DASH_temp9811234(ann_DASH_check_DASH_temp5471233);
}};
$e12231224.stack[R.EXN_STACKHEIGHT++] = $ss12271228;
}
if(R.isPyretException($e12231224)) {
$e12231224.pyretStack.push(L[67]);
}
throw $e12231224;
}
var $ret12291230 = $Hann_DASH_check_DASH_temp9811234($z12251226);
++R.GAS;
return $ret12291230;
};
var $Hann_DASH_check_DASH_temp9811234 = function(ann_DASH_check_DASH_temp5471233) {
return ann_DASH_check_DASH_temp5471233;
};
var $Hcont_tail_arg9791235 = function(cont_tail_arg5441236,if_helper5341237) {
if(--R.GAS > 0) {
$z12381239 = R.isFunction(if_helper5341237)?if_helper5341237.app(cont_tail_arg5441236):R.ffi.throwNonFunApp(L[67],if_helper5341237,[cont_tail_arg5441236]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper5341237)?if_helper5341237.app(cont_tail_arg5441236):R.ffi.throwNonFunApp(L[67],if_helper5341237,[cont_tail_arg5441236]);
},
"from":L[67]});
}
++R.GAS;
return $z12381239;
};
var $Hcont_tail_arg9801240 = function(cont_tail_arg5391241,if_helper5341237) {
if(--R.GAS > 0) {
$z12421243 = R.isFunction(if_helper5341237)?if_helper5341237.app(cont_tail_arg5391241):R.ffi.throwNonFunApp(L[67],if_helper5341237,[cont_tail_arg5391241]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper5341237)?if_helper5341237.app(cont_tail_arg5391241):R.ffi.throwNonFunApp(L[67],if_helper5341237,[cont_tail_arg5391241]);
},
"from":L[67]});
}
++R.GAS;
return $z12421243;
};
var $Hanf_arg9781244 = function(anf_arg5181245,self1761246,_plus13,not15,tostring18) {
var $z12491250 = D;
var $f12551256 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5181245,(" is declared at ")):R.ffi.throwNonFunApp(L[68],_plus13,[anf_arg5181245,(" is declared at ")]);
};
try {
if(--R.GAS > 0) {
$z12491250 = $f12551256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12551256,
"from":L[68]});
}
} catch($e12471248) {
if(R.isCont($e12471248)) {
var $ss12511252 = {"from":L[68],
"go":function(anf_arg5191257) {
return $Hanf_arg9771258(anf_arg5191257,self1761246,_plus13,not15,tostring18);
}};
$e12471248.stack[R.EXN_STACKHEIGHT++] = $ss12511252;
}
if(R.isPyretException($e12471248)) {
$e12471248.pyretStack.push(L[68]);
}
throw $e12471248;
}
var $ret12531254 = $Hanf_arg9771258($z12491250,self1761246,_plus13,not15,tostring18);
++R.GAS;
return $ret12531254;
};
var $Hanf_arg9771258 = function(anf_arg5191257,self1761246,_plus13,not15,tostring18) {
var anf_arg5201269 = G(self1761246,"new-loc",L[70]);
var $z12611262 = D;
var $f12671268 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg5201269):R.ffi.throwNonFunApp(L[69],tostring18,[anf_arg5201269]);
};
try {
if(--R.GAS > 0) {
$z12611262 = $f12671268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12671268,
"from":L[69]});
}
} catch($e12591260) {
if(R.isCont($e12591260)) {
var $ss12631264 = {"from":L[69],
"go":function(anf_arg5211270) {
return $Hanf_arg9761271(anf_arg5211270,anf_arg5191257,self1761246,_plus13,not15);
}};
$e12591260.stack[R.EXN_STACKHEIGHT++] = $ss12631264;
}
if(R.isPyretException($e12591260)) {
$e12591260.pyretStack.push(L[69]);
}
throw $e12591260;
}
var $ret12651266 = $Hanf_arg9761271($z12611262,anf_arg5191257,self1761246,_plus13,not15);
++R.GAS;
return $ret12651266;
};
var $Hanf_arg9761271 = function(anf_arg5211270,anf_arg5191257,self1761246,_plus13,not15) {
var $z12741275 = D;
var $f12801281 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5191257,anf_arg5211270):R.ffi.throwNonFunApp(L[68],_plus13,[anf_arg5191257,anf_arg5211270]);
};
try {
if(--R.GAS > 0) {
$z12741275 = $f12801281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12801281,
"from":L[68]});
}
} catch($e12721273) {
if(R.isCont($e12721273)) {
var $ss12761277 = {"from":L[68],
"go":function(anf_arg5221282) {
return $Hanf_arg9751283(anf_arg5221282,self1761246,_plus13,not15);
}};
$e12721273.stack[R.EXN_STACKHEIGHT++] = $ss12761277;
}
if(R.isPyretException($e12721273)) {
$e12721273.pyretStack.push(L[68]);
}
throw $e12721273;
}
var $ret12781279 = $Hanf_arg9751283($z12741275,self1761246,_plus13,not15);
++R.GAS;
return $ret12781279;
};
var $Hanf_arg9751283 = function(anf_arg5221282,self1761246,_plus13,not15) {
var $z12861287 = D;
var $f12921293 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5221282,(", but is already declared at ")):R.ffi.throwNonFunApp(L[68],_plus13,[anf_arg5221282,(", but is already declared at ")]);
};
try {
if(--R.GAS > 0) {
$z12861287 = $f12921293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12921293,
"from":L[68]});
}
} catch($e12841285) {
if(R.isCont($e12841285)) {
var $ss12881289 = {"from":L[68],
"go":function(anf_arg5231294) {
return $Hanf_arg9741295(anf_arg5231294,self1761246,_plus13,not15);
}};
$e12841285.stack[R.EXN_STACKHEIGHT++] = $ss12881289;
}
if(R.isPyretException($e12841285)) {
$e12841285.pyretStack.push(L[68]);
}
throw $e12841285;
}
var $ret12901291 = $Hanf_arg9741295($z12861287,self1761246,_plus13,not15);
++R.GAS;
return $ret12901291;
};
var $Hanf_arg9741295 = function(anf_arg5231294,self1761246,_plus13,not15) {
var anf_bracket5241312 = G(self1761246,"old-loc",L[76]);
var anf_fun5251309 = G(anf_bracket5241312,"format",L[75]);
var anf_bracket5261311 = G(self1761246,"new-loc",L[74]);
var anf_fun5271306 = G(anf_bracket5261311,"same-file",L[73]);
var anf_arg5281307 = G(self1761246,"old-loc",L[72]);
var $z12981299 = D;
var $f13041305 = function(_) {
return R.isFunction(anf_fun5271306)?anf_fun5271306.app(anf_arg5281307):R.ffi.throwNonFunApp(L[71],anf_fun5271306,[anf_arg5281307]);
};
try {
if(--R.GAS > 0) {
$z12981299 = $f13041305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13041305,
"from":L[71]});
}
} catch($e12961297) {
if(R.isCont($e12961297)) {
var $ss13001301 = {"from":L[71],
"go":function(anf_arg5291308) {
return $Hanf_arg9731310(anf_arg5291308,anf_arg5231294,anf_fun5251309,_plus13,not15);
}};
$e12961297.stack[R.EXN_STACKHEIGHT++] = $ss13001301;
}
if(R.isPyretException($e12961297)) {
$e12961297.pyretStack.push(L[71]);
}
throw $e12961297;
}
var $ret13021303 = $Hanf_arg9731310($z12981299,anf_arg5231294,anf_fun5251309,_plus13,not15);
++R.GAS;
return $ret13021303;
};
var $Hanf_arg9731310 = function(anf_arg5291308,anf_arg5231294,anf_fun5251309,_plus13,not15) {
var $z13151316 = D;
var $f13211322 = function(_) {
return R.isFunction(not15)?not15.app(anf_arg5291308):R.ffi.throwNonFunApp(L[77],not15,[anf_arg5291308]);
};
try {
if(--R.GAS > 0) {
$z13151316 = $f13211322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13211322,
"from":L[77]});
}
} catch($e13131314) {
if(R.isCont($e13131314)) {
var $ss13171318 = {"from":L[77],
"go":function(anf_arg5301323) {
return $Hanf_arg9721324(anf_arg5301323,anf_arg5231294,anf_fun5251309,_plus13);
}};
$e13131314.stack[R.EXN_STACKHEIGHT++] = $ss13171318;
}
if(R.isPyretException($e13131314)) {
$e13131314.pyretStack.push(L[77]);
}
throw $e13131314;
}
var $ret13191320 = $Hanf_arg9721324($z13151316,anf_arg5231294,anf_fun5251309,_plus13);
++R.GAS;
return $ret13191320;
};
var $Hanf_arg9721324 = function(anf_arg5301323,anf_arg5231294,anf_fun5251309,_plus13) {
var $z13271328 = D;
var $f13331334 = function(_) {
return R.isFunction(anf_fun5251309)?anf_fun5251309.app(anf_arg5301323):R.ffi.throwNonFunApp(L[78],anf_fun5251309,[anf_arg5301323]);
};
try {
if(--R.GAS > 0) {
$z13271328 = $f13331334();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13331334,
"from":L[78]});
}
} catch($e13251326) {
if(R.isCont($e13251326)) {
var $ss13291330 = {"from":L[78],
"go":function(anf_arg5311335) {
return $Hanf_arg9711336(anf_arg5311335,anf_arg5231294,_plus13);
}};
$e13251326.stack[R.EXN_STACKHEIGHT++] = $ss13291330;
}
if(R.isPyretException($e13251326)) {
$e13251326.pyretStack.push(L[78]);
}
throw $e13251326;
}
var $ret13311332 = $Hanf_arg9711336($z13271328,anf_arg5231294,_plus13);
++R.GAS;
return $ret13311332;
};
var $Hanf_arg9711336 = function(anf_arg5311335,anf_arg5231294,_plus13) {
var $z13391340 = D;
var $f13451346 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5231294,anf_arg5311335):R.ffi.throwNonFunApp(L[79],_plus13,[anf_arg5231294,anf_arg5311335]);
};
try {
if(--R.GAS > 0) {
$z13391340 = $f13451346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13451346,
"from":L[79]});
}
} catch($e13371338) {
if(R.isCont($e13371338)) {
var $ss13411342 = {"from":L[79],
"go":function(ann_DASH_check_DASH_temp5161347) {
return $Hann_DASH_check_DASH_temp9701348(ann_DASH_check_DASH_temp5161347);
}};
$e13371338.stack[R.EXN_STACKHEIGHT++] = $ss13411342;
}
if(R.isPyretException($e13371338)) {
$e13371338.pyretStack.push(L[79]);
}
throw $e13371338;
}
var $ret13431344 = $Hann_DASH_check_DASH_temp9701348($z13391340);
++R.GAS;
return $ret13431344;
};
var $Hann_DASH_check_DASH_temp9701348 = function(ann_DASH_check_DASH_temp5161347) {
return ann_DASH_check_DASH_temp5161347;
};
var $Hanf_arg9691349 = function(anf_arg5041350,self1071351,_plus13,torepr17) {
var anf_arg5051362 = G(self1071351,"new-loc",L[80]);
var $z13541355 = D;
var $f13601361 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg5051362):R.ffi.throwNonFunApp(L[80],torepr17,[anf_arg5051362]);
};
try {
if(--R.GAS > 0) {
$z13541355 = $f13601361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13601361,
"from":L[80]});
}
} catch($e13521353) {
if(R.isCont($e13521353)) {
var $ss13561357 = {"from":L[80],
"go":function(anf_arg5061363) {
return $Hanf_arg9681364(anf_arg5061363,anf_arg5041350,self1071351,_plus13,torepr17);
}};
$e13521353.stack[R.EXN_STACKHEIGHT++] = $ss13561357;
}
if(R.isPyretException($e13521353)) {
$e13521353.pyretStack.push(L[80]);
}
throw $e13521353;
}
var $ret13581359 = $Hanf_arg9681364($z13541355,anf_arg5041350,self1071351,_plus13,torepr17);
++R.GAS;
return $ret13581359;
};
var $Hanf_arg9681364 = function(anf_arg5061363,anf_arg5041350,self1071351,_plus13,torepr17) {
var $z13671368 = D;
var $f13731374 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg5061363):R.ffi.throwNonFunApp(L[80],_plus13,[(", "),anf_arg5061363]);
};
try {
if(--R.GAS > 0) {
$z13671368 = $f13731374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13731374,
"from":L[80]});
}
} catch($e13651366) {
if(R.isCont($e13651366)) {
var $ss13691370 = {"from":L[80],
"go":function(anf_arg5071375) {
return $Hanf_arg9671376(anf_arg5071375,anf_arg5041350,self1071351,_plus13,torepr17);
}};
$e13651366.stack[R.EXN_STACKHEIGHT++] = $ss13691370;
}
if(R.isPyretException($e13651366)) {
$e13651366.pyretStack.push(L[80]);
}
throw $e13651366;
}
var $ret13711372 = $Hanf_arg9671376($z13671368,anf_arg5041350,self1071351,_plus13,torepr17);
++R.GAS;
return $ret13711372;
};
var $Hanf_arg9671376 = function(anf_arg5071375,anf_arg5041350,self1071351,_plus13,torepr17) {
var $z13791380 = D;
var $f13851386 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5041350,anf_arg5071375):R.ffi.throwNonFunApp(L[80],_plus13,[anf_arg5041350,anf_arg5071375]);
};
try {
if(--R.GAS > 0) {
$z13791380 = $f13851386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13851386,
"from":L[80]});
}
} catch($e13771378) {
if(R.isCont($e13771378)) {
var $ss13811382 = {"from":L[80],
"go":function(anf_arg5081387) {
return $Hanf_arg9661388(anf_arg5081387,self1071351,_plus13,torepr17);
}};
$e13771378.stack[R.EXN_STACKHEIGHT++] = $ss13811382;
}
if(R.isPyretException($e13771378)) {
$e13771378.pyretStack.push(L[80]);
}
throw $e13771378;
}
var $ret13831384 = $Hanf_arg9661388($z13791380,self1071351,_plus13,torepr17);
++R.GAS;
return $ret13831384;
};
var $Hanf_arg9661388 = function(anf_arg5081387,self1071351,_plus13,torepr17) {
var anf_arg5091399 = G(self1071351,"old-loc",L[80]);
var $z13911392 = D;
var $f13971398 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg5091399):R.ffi.throwNonFunApp(L[80],torepr17,[anf_arg5091399]);
};
try {
if(--R.GAS > 0) {
$z13911392 = $f13971398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13971398,
"from":L[80]});
}
} catch($e13891390) {
if(R.isCont($e13891390)) {
var $ss13931394 = {"from":L[80],
"go":function(anf_arg5101400) {
return $Hanf_arg9651401(anf_arg5101400,anf_arg5081387,_plus13);
}};
$e13891390.stack[R.EXN_STACKHEIGHT++] = $ss13931394;
}
if(R.isPyretException($e13891390)) {
$e13891390.pyretStack.push(L[80]);
}
throw $e13891390;
}
var $ret13951396 = $Hanf_arg9651401($z13911392,anf_arg5081387,_plus13);
++R.GAS;
return $ret13951396;
};
var $Hanf_arg9651401 = function(anf_arg5101400,anf_arg5081387,_plus13) {
var $z14041405 = D;
var $f14101411 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg5101400):R.ffi.throwNonFunApp(L[80],_plus13,[(", "),anf_arg5101400]);
};
try {
if(--R.GAS > 0) {
$z14041405 = $f14101411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14101411,
"from":L[80]});
}
} catch($e14021403) {
if(R.isCont($e14021403)) {
var $ss14061407 = {"from":L[80],
"go":function(anf_arg5111412) {
return $Hanf_arg9641413(anf_arg5111412,anf_arg5081387,_plus13);
}};
$e14021403.stack[R.EXN_STACKHEIGHT++] = $ss14061407;
}
if(R.isPyretException($e14021403)) {
$e14021403.pyretStack.push(L[80]);
}
throw $e14021403;
}
var $ret14081409 = $Hanf_arg9641413($z14041405,anf_arg5081387,_plus13);
++R.GAS;
return $ret14081409;
};
var $Hanf_arg9641413 = function(anf_arg5111412,anf_arg5081387,_plus13) {
var $z14161417 = D;
var $f14221423 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5081387,anf_arg5111412):R.ffi.throwNonFunApp(L[80],_plus13,[anf_arg5081387,anf_arg5111412]);
};
try {
if(--R.GAS > 0) {
$z14161417 = $f14221423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14221423,
"from":L[80]});
}
} catch($e14141415) {
if(R.isCont($e14141415)) {
var $ss14181419 = {"from":L[80],
"go":function(anf_arg5121424) {
return $Hanf_arg9631425(anf_arg5121424,_plus13);
}};
$e14141415.stack[R.EXN_STACKHEIGHT++] = $ss14181419;
}
if(R.isPyretException($e14141415)) {
$e14141415.pyretStack.push(L[80]);
}
throw $e14141415;
}
var $ret14201421 = $Hanf_arg9631425($z14161417,_plus13);
++R.GAS;
return $ret14201421;
};
var $Hanf_arg9631425 = function(anf_arg5121424,_plus13) {
var $z14281429 = D;
var $f14341435 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg5121424,(")")):R.ffi.throwNonFunApp(L[80],_plus13,[anf_arg5121424,(")")]);
};
try {
if(--R.GAS > 0) {
$z14281429 = $f14341435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14341435,
"from":L[80]});
}
} catch($e14261427) {
if(R.isCont($e14261427)) {
var $ss14301431 = {"from":L[80],
"go":function(anf_arg5131436) {
return $Hanf_arg9621437(anf_arg5131436,_plus13);
}};
$e14261427.stack[R.EXN_STACKHEIGHT++] = $ss14301431;
}
if(R.isPyretException($e14261427)) {
$e14261427.pyretStack.push(L[80]);
}
throw $e14261427;
}
var $ret14321433 = $Hanf_arg9621437($z14281429,_plus13);
++R.GAS;
return $ret14321433;
};
var $Hanf_arg9621437 = function(anf_arg5131436,_plus13) {
var $z14401441 = D;
var $f14461447 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg5131436):R.ffi.throwNonFunApp(L[80],_plus13,[("("),anf_arg5131436]);
};
try {
if(--R.GAS > 0) {
$z14401441 = $f14461447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14461447,
"from":L[80]});
}
} catch($e14381439) {
if(R.isCont($e14381439)) {
var $ss14421443 = {"from":L[80],
"go":function(anf_arg5141448) {
return $Hanf_arg9611449(anf_arg5141448,_plus13);
}};
$e14381439.stack[R.EXN_STACKHEIGHT++] = $ss14421443;
}
if(R.isPyretException($e14381439)) {
$e14381439.pyretStack.push(L[80]);
}
throw $e14381439;
}
var $ret14441445 = $Hanf_arg9611449($z14401441,_plus13);
++R.GAS;
return $ret14441445;
};
var $Hanf_arg9611449 = function(anf_arg5141448,_plus13) {
var $z14521453 = D;
var $f14581459 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("shadow-id"),anf_arg5141448):R.ffi.throwNonFunApp(L[80],_plus13,[("shadow-id"),anf_arg5141448]);
};
try {
if(--R.GAS > 0) {
$z14521453 = $f14581459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14581459,
"from":L[80]});
}
} catch($e14501451) {
if(R.isCont($e14501451)) {
var $ss14541455 = {"from":L[80],
"go":function(ann_DASH_check_DASH_temp5021460) {
return $Hann_DASH_check_DASH_temp9601461(ann_DASH_check_DASH_temp5021460);
}};
$e14501451.stack[R.EXN_STACKHEIGHT++] = $ss14541455;
}
if(R.isPyretException($e14501451)) {
$e14501451.pyretStack.push(L[80]);
}
throw $e14501451;
}
var $ret14561457 = $Hann_DASH_check_DASH_temp9601461($z14521453);
++R.GAS;
return $ret14561457;
};
var $Hann_DASH_check_DASH_temp9601461 = function(ann_DASH_check_DASH_temp5021460) {
return ann_DASH_check_DASH_temp5021460;
};
var $Hcont_tail_arg9581462 = function(cont_tail_arg4991463,if_helper4891464) {
if(--R.GAS > 0) {
$z14651466 = R.isFunction(if_helper4891464)?if_helper4891464.app(cont_tail_arg4991463):R.ffi.throwNonFunApp(L[80],if_helper4891464,[cont_tail_arg4991463]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper4891464)?if_helper4891464.app(cont_tail_arg4991463):R.ffi.throwNonFunApp(L[80],if_helper4891464,[cont_tail_arg4991463]);
},
"from":L[80]});
}
++R.GAS;
return $z14651466;
};
var $Hcont_tail_arg9591467 = function(cont_tail_arg4941468,if_helper4891464) {
if(--R.GAS > 0) {
$z14691470 = R.isFunction(if_helper4891464)?if_helper4891464.app(cont_tail_arg4941468):R.ffi.throwNonFunApp(L[80],if_helper4891464,[cont_tail_arg4941468]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper4891464)?if_helper4891464.app(cont_tail_arg4941468):R.ffi.throwNonFunApp(L[80],if_helper4891464,[cont_tail_arg4941468]);
},
"from":L[80]});
}
++R.GAS;
return $z14691470;
};
var $Hanf_arg9571471 = function(anf_arg4721472,self1721473,_plus13,not15,tostring18) {
var anf_arg4731484 = G(self1721473,"var-loc",L[82]);
var $z14761477 = D;
var $f14821483 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg4731484):R.ffi.throwNonFunApp(L[81],tostring18,[anf_arg4731484]);
};
try {
if(--R.GAS > 0) {
$z14761477 = $f14821483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14821483,
"from":L[81]});
}
} catch($e14741475) {
if(R.isCont($e14741475)) {
var $ss14781479 = {"from":L[81],
"go":function(anf_arg4741485) {
return $Hanf_arg9561486(anf_arg4741485,anf_arg4721472,self1721473,_plus13,not15);
}};
$e14741475.stack[R.EXN_STACKHEIGHT++] = $ss14781479;
}
if(R.isPyretException($e14741475)) {
$e14741475.pyretStack.push(L[81]);
}
throw $e14741475;
}
var $ret14801481 = $Hanf_arg9561486($z14761477,anf_arg4721472,self1721473,_plus13,not15);
++R.GAS;
return $ret14801481;
};
var $Hanf_arg9561486 = function(anf_arg4741485,anf_arg4721472,self1721473,_plus13,not15) {
var $z14891490 = D;
var $f14951496 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4721472,anf_arg4741485):R.ffi.throwNonFunApp(L[83],_plus13,[anf_arg4721472,anf_arg4741485]);
};
try {
if(--R.GAS > 0) {
$z14891490 = $f14951496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14951496,
"from":L[83]});
}
} catch($e14871488) {
if(R.isCont($e14871488)) {
var $ss14911492 = {"from":L[83],
"go":function(anf_arg4751497) {
return $Hanf_arg9551498(anf_arg4751497,self1721473,_plus13,not15);
}};
$e14871488.stack[R.EXN_STACKHEIGHT++] = $ss14911492;
}
if(R.isPyretException($e14871488)) {
$e14871488.pyretStack.push(L[83]);
}
throw $e14871488;
}
var $ret14931494 = $Hanf_arg9551498($z14891490,self1721473,_plus13,not15);
++R.GAS;
return $ret14931494;
};
var $Hanf_arg9551498 = function(anf_arg4751497,self1721473,_plus13,not15) {
var $z15011502 = D;
var $f15071508 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4751497,(")")):R.ffi.throwNonFunApp(L[83],_plus13,[anf_arg4751497,(")")]);
};
try {
if(--R.GAS > 0) {
$z15011502 = $f15071508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15071508,
"from":L[83]});
}
} catch($e14991500) {
if(R.isCont($e14991500)) {
var $ss15031504 = {"from":L[83],
"go":function(anf_arg4761509) {
return $Hanf_arg9541510(anf_arg4761509,self1721473,_plus13,not15);
}};
$e14991500.stack[R.EXN_STACKHEIGHT++] = $ss15031504;
}
if(R.isPyretException($e14991500)) {
$e14991500.pyretStack.push(L[83]);
}
throw $e14991500;
}
var $ret15051506 = $Hanf_arg9541510($z15011502,self1721473,_plus13,not15);
++R.GAS;
return $ret15051506;
};
var $Hanf_arg9541510 = function(anf_arg4761509,self1721473,_plus13,not15) {
var $z15131514 = D;
var $f15191520 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4761509,(" and an identifier (at ")):R.ffi.throwNonFunApp(L[83],_plus13,[anf_arg4761509,(" and an identifier (at ")]);
};
try {
if(--R.GAS > 0) {
$z15131514 = $f15191520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15191520,
"from":L[83]});
}
} catch($e15111512) {
if(R.isCont($e15111512)) {
var $ss15151516 = {"from":L[83],
"go":function(anf_arg4771521) {
return $Hanf_arg9531522(anf_arg4771521,self1721473,_plus13,not15);
}};
$e15111512.stack[R.EXN_STACKHEIGHT++] = $ss15151516;
}
if(R.isPyretException($e15111512)) {
$e15111512.pyretStack.push(L[83]);
}
throw $e15111512;
}
var $ret15171518 = $Hanf_arg9531522($z15131514,self1721473,_plus13,not15);
++R.GAS;
return $ret15171518;
};
var $Hanf_arg9531522 = function(anf_arg4771521,self1721473,_plus13,not15) {
var anf_bracket4781539 = G(self1721473,"id-loc",L[89]);
var anf_fun4791536 = G(anf_bracket4781539,"format",L[88]);
var anf_bracket4801538 = G(self1721473,"var-loc",L[87]);
var anf_fun4811533 = G(anf_bracket4801538,"same-file",L[86]);
var anf_arg4821534 = G(self1721473,"id-loc",L[85]);
var $z15251526 = D;
var $f15311532 = function(_) {
return R.isFunction(anf_fun4811533)?anf_fun4811533.app(anf_arg4821534):R.ffi.throwNonFunApp(L[84],anf_fun4811533,[anf_arg4821534]);
};
try {
if(--R.GAS > 0) {
$z15251526 = $f15311532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15311532,
"from":L[84]});
}
} catch($e15231524) {
if(R.isCont($e15231524)) {
var $ss15271528 = {"from":L[84],
"go":function(anf_arg4831535) {
return $Hanf_arg9521537(anf_arg4831535,anf_arg4771521,anf_fun4791536,_plus13,not15);
}};
$e15231524.stack[R.EXN_STACKHEIGHT++] = $ss15271528;
}
if(R.isPyretException($e15231524)) {
$e15231524.pyretStack.push(L[84]);
}
throw $e15231524;
}
var $ret15291530 = $Hanf_arg9521537($z15251526,anf_arg4771521,anf_fun4791536,_plus13,not15);
++R.GAS;
return $ret15291530;
};
var $Hanf_arg9521537 = function(anf_arg4831535,anf_arg4771521,anf_fun4791536,_plus13,not15) {
var $z15421543 = D;
var $f15481549 = function(_) {
return R.isFunction(not15)?not15.app(anf_arg4831535):R.ffi.throwNonFunApp(L[90],not15,[anf_arg4831535]);
};
try {
if(--R.GAS > 0) {
$z15421543 = $f15481549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15481549,
"from":L[90]});
}
} catch($e15401541) {
if(R.isCont($e15401541)) {
var $ss15441545 = {"from":L[90],
"go":function(anf_arg4841550) {
return $Hanf_arg9511551(anf_arg4841550,anf_arg4771521,anf_fun4791536,_plus13);
}};
$e15401541.stack[R.EXN_STACKHEIGHT++] = $ss15441545;
}
if(R.isPyretException($e15401541)) {
$e15401541.pyretStack.push(L[90]);
}
throw $e15401541;
}
var $ret15461547 = $Hanf_arg9511551($z15421543,anf_arg4771521,anf_fun4791536,_plus13);
++R.GAS;
return $ret15461547;
};
var $Hanf_arg9511551 = function(anf_arg4841550,anf_arg4771521,anf_fun4791536,_plus13) {
var $z15541555 = D;
var $f15601561 = function(_) {
return R.isFunction(anf_fun4791536)?anf_fun4791536.app(anf_arg4841550):R.ffi.throwNonFunApp(L[91],anf_fun4791536,[anf_arg4841550]);
};
try {
if(--R.GAS > 0) {
$z15541555 = $f15601561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15601561,
"from":L[91]});
}
} catch($e15521553) {
if(R.isCont($e15521553)) {
var $ss15561557 = {"from":L[91],
"go":function(anf_arg4851562) {
return $Hanf_arg9501563(anf_arg4851562,anf_arg4771521,_plus13);
}};
$e15521553.stack[R.EXN_STACKHEIGHT++] = $ss15561557;
}
if(R.isPyretException($e15521553)) {
$e15521553.pyretStack.push(L[91]);
}
throw $e15521553;
}
var $ret15581559 = $Hanf_arg9501563($z15541555,anf_arg4771521,_plus13);
++R.GAS;
return $ret15581559;
};
var $Hanf_arg9501563 = function(anf_arg4851562,anf_arg4771521,_plus13) {
var $z15661567 = D;
var $f15721573 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4771521,anf_arg4851562):R.ffi.throwNonFunApp(L[83],_plus13,[anf_arg4771521,anf_arg4851562]);
};
try {
if(--R.GAS > 0) {
$z15661567 = $f15721573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15721573,
"from":L[83]});
}
} catch($e15641565) {
if(R.isCont($e15641565)) {
var $ss15681569 = {"from":L[83],
"go":function(anf_arg4861574) {
return $Hanf_arg9491575(anf_arg4861574,_plus13);
}};
$e15641565.stack[R.EXN_STACKHEIGHT++] = $ss15681569;
}
if(R.isPyretException($e15641565)) {
$e15641565.pyretStack.push(L[83]);
}
throw $e15641565;
}
var $ret15701571 = $Hanf_arg9491575($z15661567,_plus13);
++R.GAS;
return $ret15701571;
};
var $Hanf_arg9491575 = function(anf_arg4861574,_plus13) {
var $z15781579 = D;
var $f15841585 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4861574,(")")):R.ffi.throwNonFunApp(L[92],_plus13,[anf_arg4861574,(")")]);
};
try {
if(--R.GAS > 0) {
$z15781579 = $f15841585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15841585,
"from":L[92]});
}
} catch($e15761577) {
if(R.isCont($e15761577)) {
var $ss15801581 = {"from":L[92],
"go":function(ann_DASH_check_DASH_temp4701586) {
return $Hann_DASH_check_DASH_temp9481587(ann_DASH_check_DASH_temp4701586);
}};
$e15761577.stack[R.EXN_STACKHEIGHT++] = $ss15801581;
}
if(R.isPyretException($e15761577)) {
$e15761577.pyretStack.push(L[92]);
}
throw $e15761577;
}
var $ret15821583 = $Hann_DASH_check_DASH_temp9481587($z15781579);
++R.GAS;
return $ret15821583;
};
var $Hann_DASH_check_DASH_temp9481587 = function(ann_DASH_check_DASH_temp4701586) {
return ann_DASH_check_DASH_temp4701586;
};
var $Hanf_arg9471588 = function(anf_arg4581589,self1011590,_plus13,torepr17) {
var anf_arg4591601 = G(self1011590,"var-loc",L[93]);
var $z15931594 = D;
var $f15991600 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg4591601):R.ffi.throwNonFunApp(L[93],torepr17,[anf_arg4591601]);
};
try {
if(--R.GAS > 0) {
$z15931594 = $f15991600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15991600,
"from":L[93]});
}
} catch($e15911592) {
if(R.isCont($e15911592)) {
var $ss15951596 = {"from":L[93],
"go":function(anf_arg4601602) {
return $Hanf_arg9461603(anf_arg4601602,anf_arg4581589,self1011590,_plus13,torepr17);
}};
$e15911592.stack[R.EXN_STACKHEIGHT++] = $ss15951596;
}
if(R.isPyretException($e15911592)) {
$e15911592.pyretStack.push(L[93]);
}
throw $e15911592;
}
var $ret15971598 = $Hanf_arg9461603($z15931594,anf_arg4581589,self1011590,_plus13,torepr17);
++R.GAS;
return $ret15971598;
};
var $Hanf_arg9461603 = function(anf_arg4601602,anf_arg4581589,self1011590,_plus13,torepr17) {
var $z16061607 = D;
var $f16121613 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg4601602):R.ffi.throwNonFunApp(L[93],_plus13,[(", "),anf_arg4601602]);
};
try {
if(--R.GAS > 0) {
$z16061607 = $f16121613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16121613,
"from":L[93]});
}
} catch($e16041605) {
if(R.isCont($e16041605)) {
var $ss16081609 = {"from":L[93],
"go":function(anf_arg4611614) {
return $Hanf_arg9451615(anf_arg4611614,anf_arg4581589,self1011590,_plus13,torepr17);
}};
$e16041605.stack[R.EXN_STACKHEIGHT++] = $ss16081609;
}
if(R.isPyretException($e16041605)) {
$e16041605.pyretStack.push(L[93]);
}
throw $e16041605;
}
var $ret16101611 = $Hanf_arg9451615($z16061607,anf_arg4581589,self1011590,_plus13,torepr17);
++R.GAS;
return $ret16101611;
};
var $Hanf_arg9451615 = function(anf_arg4611614,anf_arg4581589,self1011590,_plus13,torepr17) {
var $z16181619 = D;
var $f16241625 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4581589,anf_arg4611614):R.ffi.throwNonFunApp(L[93],_plus13,[anf_arg4581589,anf_arg4611614]);
};
try {
if(--R.GAS > 0) {
$z16181619 = $f16241625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16241625,
"from":L[93]});
}
} catch($e16161617) {
if(R.isCont($e16161617)) {
var $ss16201621 = {"from":L[93],
"go":function(anf_arg4621626) {
return $Hanf_arg9441627(anf_arg4621626,self1011590,_plus13,torepr17);
}};
$e16161617.stack[R.EXN_STACKHEIGHT++] = $ss16201621;
}
if(R.isPyretException($e16161617)) {
$e16161617.pyretStack.push(L[93]);
}
throw $e16161617;
}
var $ret16221623 = $Hanf_arg9441627($z16181619,self1011590,_plus13,torepr17);
++R.GAS;
return $ret16221623;
};
var $Hanf_arg9441627 = function(anf_arg4621626,self1011590,_plus13,torepr17) {
var anf_arg4631638 = G(self1011590,"id-loc",L[93]);
var $z16301631 = D;
var $f16361637 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg4631638):R.ffi.throwNonFunApp(L[93],torepr17,[anf_arg4631638]);
};
try {
if(--R.GAS > 0) {
$z16301631 = $f16361637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16361637,
"from":L[93]});
}
} catch($e16281629) {
if(R.isCont($e16281629)) {
var $ss16321633 = {"from":L[93],
"go":function(anf_arg4641639) {
return $Hanf_arg9431640(anf_arg4641639,anf_arg4621626,_plus13);
}};
$e16281629.stack[R.EXN_STACKHEIGHT++] = $ss16321633;
}
if(R.isPyretException($e16281629)) {
$e16281629.pyretStack.push(L[93]);
}
throw $e16281629;
}
var $ret16341635 = $Hanf_arg9431640($z16301631,anf_arg4621626,_plus13);
++R.GAS;
return $ret16341635;
};
var $Hanf_arg9431640 = function(anf_arg4641639,anf_arg4621626,_plus13) {
var $z16431644 = D;
var $f16491650 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg4641639):R.ffi.throwNonFunApp(L[93],_plus13,[(", "),anf_arg4641639]);
};
try {
if(--R.GAS > 0) {
$z16431644 = $f16491650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16491650,
"from":L[93]});
}
} catch($e16411642) {
if(R.isCont($e16411642)) {
var $ss16451646 = {"from":L[93],
"go":function(anf_arg4651651) {
return $Hanf_arg9421652(anf_arg4651651,anf_arg4621626,_plus13);
}};
$e16411642.stack[R.EXN_STACKHEIGHT++] = $ss16451646;
}
if(R.isPyretException($e16411642)) {
$e16411642.pyretStack.push(L[93]);
}
throw $e16411642;
}
var $ret16471648 = $Hanf_arg9421652($z16431644,anf_arg4621626,_plus13);
++R.GAS;
return $ret16471648;
};
var $Hanf_arg9421652 = function(anf_arg4651651,anf_arg4621626,_plus13) {
var $z16551656 = D;
var $f16611662 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4621626,anf_arg4651651):R.ffi.throwNonFunApp(L[93],_plus13,[anf_arg4621626,anf_arg4651651]);
};
try {
if(--R.GAS > 0) {
$z16551656 = $f16611662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16611662,
"from":L[93]});
}
} catch($e16531654) {
if(R.isCont($e16531654)) {
var $ss16571658 = {"from":L[93],
"go":function(anf_arg4661663) {
return $Hanf_arg9411664(anf_arg4661663,_plus13);
}};
$e16531654.stack[R.EXN_STACKHEIGHT++] = $ss16571658;
}
if(R.isPyretException($e16531654)) {
$e16531654.pyretStack.push(L[93]);
}
throw $e16531654;
}
var $ret16591660 = $Hanf_arg9411664($z16551656,_plus13);
++R.GAS;
return $ret16591660;
};
var $Hanf_arg9411664 = function(anf_arg4661663,_plus13) {
var $z16671668 = D;
var $f16731674 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4661663,(")")):R.ffi.throwNonFunApp(L[93],_plus13,[anf_arg4661663,(")")]);
};
try {
if(--R.GAS > 0) {
$z16671668 = $f16731674();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16731674,
"from":L[93]});
}
} catch($e16651666) {
if(R.isCont($e16651666)) {
var $ss16691670 = {"from":L[93],
"go":function(anf_arg4671675) {
return $Hanf_arg9401676(anf_arg4671675,_plus13);
}};
$e16651666.stack[R.EXN_STACKHEIGHT++] = $ss16691670;
}
if(R.isPyretException($e16651666)) {
$e16651666.pyretStack.push(L[93]);
}
throw $e16651666;
}
var $ret16711672 = $Hanf_arg9401676($z16671668,_plus13);
++R.GAS;
return $ret16711672;
};
var $Hanf_arg9401676 = function(anf_arg4671675,_plus13) {
var $z16791680 = D;
var $f16851686 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg4671675):R.ffi.throwNonFunApp(L[93],_plus13,[("("),anf_arg4671675]);
};
try {
if(--R.GAS > 0) {
$z16791680 = $f16851686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16851686,
"from":L[93]});
}
} catch($e16771678) {
if(R.isCont($e16771678)) {
var $ss16811682 = {"from":L[93],
"go":function(anf_arg4681687) {
return $Hanf_arg9391688(anf_arg4681687,_plus13);
}};
$e16771678.stack[R.EXN_STACKHEIGHT++] = $ss16811682;
}
if(R.isPyretException($e16771678)) {
$e16771678.pyretStack.push(L[93]);
}
throw $e16771678;
}
var $ret16831684 = $Hanf_arg9391688($z16791680,_plus13);
++R.GAS;
return $ret16831684;
};
var $Hanf_arg9391688 = function(anf_arg4681687,_plus13) {
var $z16911692 = D;
var $f16971698 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("mixed-id-var"),anf_arg4681687):R.ffi.throwNonFunApp(L[93],_plus13,[("mixed-id-var"),anf_arg4681687]);
};
try {
if(--R.GAS > 0) {
$z16911692 = $f16971698();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16971698,
"from":L[93]});
}
} catch($e16891690) {
if(R.isCont($e16891690)) {
var $ss16931694 = {"from":L[93],
"go":function(ann_DASH_check_DASH_temp4561699) {
return $Hann_DASH_check_DASH_temp9381700(ann_DASH_check_DASH_temp4561699);
}};
$e16891690.stack[R.EXN_STACKHEIGHT++] = $ss16931694;
}
if(R.isPyretException($e16891690)) {
$e16891690.pyretStack.push(L[93]);
}
throw $e16891690;
}
var $ret16951696 = $Hann_DASH_check_DASH_temp9381700($z16911692);
++R.GAS;
return $ret16951696;
};
var $Hann_DASH_check_DASH_temp9381700 = function(ann_DASH_check_DASH_temp4561699) {
return ann_DASH_check_DASH_temp4561699;
};
var $Hcont_tail_arg9361701 = function(cont_tail_arg4531702,if_helper4431703) {
if(--R.GAS > 0) {
$z17041705 = R.isFunction(if_helper4431703)?if_helper4431703.app(cont_tail_arg4531702):R.ffi.throwNonFunApp(L[93],if_helper4431703,[cont_tail_arg4531702]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper4431703)?if_helper4431703.app(cont_tail_arg4531702):R.ffi.throwNonFunApp(L[93],if_helper4431703,[cont_tail_arg4531702]);
},
"from":L[93]});
}
++R.GAS;
return $z17041705;
};
var $Hcont_tail_arg9371706 = function(cont_tail_arg4481707,if_helper4431703) {
if(--R.GAS > 0) {
$z17081709 = R.isFunction(if_helper4431703)?if_helper4431703.app(cont_tail_arg4481707):R.ffi.throwNonFunApp(L[93],if_helper4431703,[cont_tail_arg4481707]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper4431703)?if_helper4431703.app(cont_tail_arg4481707):R.ffi.throwNonFunApp(L[93],if_helper4431703,[cont_tail_arg4481707]);
},
"from":L[93]});
}
++R.GAS;
return $z17081709;
};
var $Hanf_arg9351710 = function(anf_arg4261711,self1681712,_plus13,not15,tostring18) {
var $z17151716 = D;
var $f17211722 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4261711,(" is assigned at ")):R.ffi.throwNonFunApp(L[94],_plus13,[anf_arg4261711,(" is assigned at ")]);
};
try {
if(--R.GAS > 0) {
$z17151716 = $f17211722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17211722,
"from":L[94]});
}
} catch($e17131714) {
if(R.isCont($e17131714)) {
var $ss17171718 = {"from":L[94],
"go":function(anf_arg4271723) {
return $Hanf_arg9341724(anf_arg4271723,self1681712,_plus13,not15,tostring18);
}};
$e17131714.stack[R.EXN_STACKHEIGHT++] = $ss17171718;
}
if(R.isPyretException($e17131714)) {
$e17131714.pyretStack.push(L[94]);
}
throw $e17131714;
}
var $ret17191720 = $Hanf_arg9341724($z17151716,self1681712,_plus13,not15,tostring18);
++R.GAS;
return $ret17191720;
};
var $Hanf_arg9341724 = function(anf_arg4271723,self1681712,_plus13,not15,tostring18) {
var anf_arg4281735 = G(self1681712,"loc",L[96]);
var $z17271728 = D;
var $f17331734 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg4281735):R.ffi.throwNonFunApp(L[95],tostring18,[anf_arg4281735]);
};
try {
if(--R.GAS > 0) {
$z17271728 = $f17331734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17331734,
"from":L[95]});
}
} catch($e17251726) {
if(R.isCont($e17251726)) {
var $ss17291730 = {"from":L[95],
"go":function(anf_arg4291736) {
return $Hanf_arg9331737(anf_arg4291736,anf_arg4271723,self1681712,_plus13,not15);
}};
$e17251726.stack[R.EXN_STACKHEIGHT++] = $ss17291730;
}
if(R.isPyretException($e17251726)) {
$e17251726.pyretStack.push(L[95]);
}
throw $e17251726;
}
var $ret17311732 = $Hanf_arg9331737($z17271728,anf_arg4271723,self1681712,_plus13,not15);
++R.GAS;
return $ret17311732;
};
var $Hanf_arg9331737 = function(anf_arg4291736,anf_arg4271723,self1681712,_plus13,not15) {
var $z17401741 = D;
var $f17461747 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4271723,anf_arg4291736):R.ffi.throwNonFunApp(L[94],_plus13,[anf_arg4271723,anf_arg4291736]);
};
try {
if(--R.GAS > 0) {
$z17401741 = $f17461747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17461747,
"from":L[94]});
}
} catch($e17381739) {
if(R.isCont($e17381739)) {
var $ss17421743 = {"from":L[94],
"go":function(anf_arg4301748) {
return $Hanf_arg9321749(anf_arg4301748,self1681712,_plus13,not15);
}};
$e17381739.stack[R.EXN_STACKHEIGHT++] = $ss17421743;
}
if(R.isPyretException($e17381739)) {
$e17381739.pyretStack.push(L[94]);
}
throw $e17381739;
}
var $ret17441745 = $Hanf_arg9321749($z17401741,self1681712,_plus13,not15);
++R.GAS;
return $ret17441745;
};
var $Hanf_arg9321749 = function(anf_arg4301748,self1681712,_plus13,not15) {
var $z17521753 = D;
var $f17581759 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4301748,(", but its definition at ")):R.ffi.throwNonFunApp(L[94],_plus13,[anf_arg4301748,(", but its definition at ")]);
};
try {
if(--R.GAS > 0) {
$z17521753 = $f17581759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17581759,
"from":L[94]});
}
} catch($e17501751) {
if(R.isCont($e17501751)) {
var $ss17541755 = {"from":L[94],
"go":function(anf_arg4311760) {
return $Hanf_arg9311761(anf_arg4311760,self1681712,_plus13,not15);
}};
$e17501751.stack[R.EXN_STACKHEIGHT++] = $ss17541755;
}
if(R.isPyretException($e17501751)) {
$e17501751.pyretStack.push(L[94]);
}
throw $e17501751;
}
var $ret17561757 = $Hanf_arg9311761($z17521753,self1681712,_plus13,not15);
++R.GAS;
return $ret17561757;
};
var $Hanf_arg9311761 = function(anf_arg4311760,self1681712,_plus13,not15) {
var anf_bracket4321778 = G(self1681712,"prev-loc",L[102]);
var anf_fun4331775 = G(anf_bracket4321778,"format",L[101]);
var anf_bracket4341777 = G(self1681712,"loc",L[100]);
var anf_fun4351772 = G(anf_bracket4341777,"same-file",L[99]);
var anf_arg4361773 = G(self1681712,"prev-loc",L[98]);
var $z17641765 = D;
var $f17701771 = function(_) {
return R.isFunction(anf_fun4351772)?anf_fun4351772.app(anf_arg4361773):R.ffi.throwNonFunApp(L[97],anf_fun4351772,[anf_arg4361773]);
};
try {
if(--R.GAS > 0) {
$z17641765 = $f17701771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17701771,
"from":L[97]});
}
} catch($e17621763) {
if(R.isCont($e17621763)) {
var $ss17661767 = {"from":L[97],
"go":function(anf_arg4371774) {
return $Hanf_arg9301776(anf_arg4371774,anf_arg4311760,anf_fun4331775,_plus13,not15);
}};
$e17621763.stack[R.EXN_STACKHEIGHT++] = $ss17661767;
}
if(R.isPyretException($e17621763)) {
$e17621763.pyretStack.push(L[97]);
}
throw $e17621763;
}
var $ret17681769 = $Hanf_arg9301776($z17641765,anf_arg4311760,anf_fun4331775,_plus13,not15);
++R.GAS;
return $ret17681769;
};
var $Hanf_arg9301776 = function(anf_arg4371774,anf_arg4311760,anf_fun4331775,_plus13,not15) {
var $z17811782 = D;
var $f17871788 = function(_) {
return R.isFunction(not15)?not15.app(anf_arg4371774):R.ffi.throwNonFunApp(L[103],not15,[anf_arg4371774]);
};
try {
if(--R.GAS > 0) {
$z17811782 = $f17871788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17871788,
"from":L[103]});
}
} catch($e17791780) {
if(R.isCont($e17791780)) {
var $ss17831784 = {"from":L[103],
"go":function(anf_arg4381789) {
return $Hanf_arg9291790(anf_arg4381789,anf_arg4311760,anf_fun4331775,_plus13);
}};
$e17791780.stack[R.EXN_STACKHEIGHT++] = $ss17831784;
}
if(R.isPyretException($e17791780)) {
$e17791780.pyretStack.push(L[103]);
}
throw $e17791780;
}
var $ret17851786 = $Hanf_arg9291790($z17811782,anf_arg4311760,anf_fun4331775,_plus13);
++R.GAS;
return $ret17851786;
};
var $Hanf_arg9291790 = function(anf_arg4381789,anf_arg4311760,anf_fun4331775,_plus13) {
var $z17931794 = D;
var $f17991800 = function(_) {
return R.isFunction(anf_fun4331775)?anf_fun4331775.app(anf_arg4381789):R.ffi.throwNonFunApp(L[104],anf_fun4331775,[anf_arg4381789]);
};
try {
if(--R.GAS > 0) {
$z17931794 = $f17991800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17991800,
"from":L[104]});
}
} catch($e17911792) {
if(R.isCont($e17911792)) {
var $ss17951796 = {"from":L[104],
"go":function(anf_arg4391801) {
return $Hanf_arg9281802(anf_arg4391801,anf_arg4311760,_plus13);
}};
$e17911792.stack[R.EXN_STACKHEIGHT++] = $ss17951796;
}
if(R.isPyretException($e17911792)) {
$e17911792.pyretStack.push(L[104]);
}
throw $e17911792;
}
var $ret17971798 = $Hanf_arg9281802($z17931794,anf_arg4311760,_plus13);
++R.GAS;
return $ret17971798;
};
var $Hanf_arg9281802 = function(anf_arg4391801,anf_arg4311760,_plus13) {
var $z18051806 = D;
var $f18111812 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4311760,anf_arg4391801):R.ffi.throwNonFunApp(L[94],_plus13,[anf_arg4311760,anf_arg4391801]);
};
try {
if(--R.GAS > 0) {
$z18051806 = $f18111812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18111812,
"from":L[94]});
}
} catch($e18031804) {
if(R.isCont($e18031804)) {
var $ss18071808 = {"from":L[94],
"go":function(anf_arg4401813) {
return $Hanf_arg9271814(anf_arg4401813,_plus13);
}};
$e18031804.stack[R.EXN_STACKHEIGHT++] = $ss18071808;
}
if(R.isPyretException($e18031804)) {
$e18031804.pyretStack.push(L[94]);
}
throw $e18031804;
}
var $ret18091810 = $Hanf_arg9271814($z18051806,_plus13);
++R.GAS;
return $ret18091810;
};
var $Hanf_arg9271814 = function(anf_arg4401813,_plus13) {
var $z18171818 = D;
var $f18231824 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4401813,(" is not assignable.  (Only names declared with var are assignable.)")):R.ffi.throwNonFunApp(L[105],_plus13,[anf_arg4401813,(" is not assignable.  (Only names declared with var are assignable.)")]);
};
try {
if(--R.GAS > 0) {
$z18171818 = $f18231824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18231824,
"from":L[105]});
}
} catch($e18151816) {
if(R.isCont($e18151816)) {
var $ss18191820 = {"from":L[105],
"go":function(ann_DASH_check_DASH_temp4241825) {
return $Hann_DASH_check_DASH_temp9261826(ann_DASH_check_DASH_temp4241825);
}};
$e18151816.stack[R.EXN_STACKHEIGHT++] = $ss18191820;
}
if(R.isPyretException($e18151816)) {
$e18151816.pyretStack.push(L[105]);
}
throw $e18151816;
}
var $ret18211822 = $Hann_DASH_check_DASH_temp9261826($z18171818);
++R.GAS;
return $ret18211822;
};
var $Hann_DASH_check_DASH_temp9261826 = function(ann_DASH_check_DASH_temp4241825) {
return ann_DASH_check_DASH_temp4241825;
};
var $Hanf_arg9251827 = function(anf_arg4121828,self951829,_plus13,torepr17) {
var anf_arg4131840 = G(self951829,"loc",L[106]);
var $z18321833 = D;
var $f18381839 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg4131840):R.ffi.throwNonFunApp(L[106],torepr17,[anf_arg4131840]);
};
try {
if(--R.GAS > 0) {
$z18321833 = $f18381839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18381839,
"from":L[106]});
}
} catch($e18301831) {
if(R.isCont($e18301831)) {
var $ss18341835 = {"from":L[106],
"go":function(anf_arg4141841) {
return $Hanf_arg9241842(anf_arg4141841,anf_arg4121828,self951829,_plus13,torepr17);
}};
$e18301831.stack[R.EXN_STACKHEIGHT++] = $ss18341835;
}
if(R.isPyretException($e18301831)) {
$e18301831.pyretStack.push(L[106]);
}
throw $e18301831;
}
var $ret18361837 = $Hanf_arg9241842($z18321833,anf_arg4121828,self951829,_plus13,torepr17);
++R.GAS;
return $ret18361837;
};
var $Hanf_arg9241842 = function(anf_arg4141841,anf_arg4121828,self951829,_plus13,torepr17) {
var $z18451846 = D;
var $f18511852 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg4141841):R.ffi.throwNonFunApp(L[106],_plus13,[(", "),anf_arg4141841]);
};
try {
if(--R.GAS > 0) {
$z18451846 = $f18511852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18511852,
"from":L[106]});
}
} catch($e18431844) {
if(R.isCont($e18431844)) {
var $ss18471848 = {"from":L[106],
"go":function(anf_arg4151853) {
return $Hanf_arg9231854(anf_arg4151853,anf_arg4121828,self951829,_plus13,torepr17);
}};
$e18431844.stack[R.EXN_STACKHEIGHT++] = $ss18471848;
}
if(R.isPyretException($e18431844)) {
$e18431844.pyretStack.push(L[106]);
}
throw $e18431844;
}
var $ret18491850 = $Hanf_arg9231854($z18451846,anf_arg4121828,self951829,_plus13,torepr17);
++R.GAS;
return $ret18491850;
};
var $Hanf_arg9231854 = function(anf_arg4151853,anf_arg4121828,self951829,_plus13,torepr17) {
var $z18571858 = D;
var $f18631864 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4121828,anf_arg4151853):R.ffi.throwNonFunApp(L[106],_plus13,[anf_arg4121828,anf_arg4151853]);
};
try {
if(--R.GAS > 0) {
$z18571858 = $f18631864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18631864,
"from":L[106]});
}
} catch($e18551856) {
if(R.isCont($e18551856)) {
var $ss18591860 = {"from":L[106],
"go":function(anf_arg4161865) {
return $Hanf_arg9221866(anf_arg4161865,self951829,_plus13,torepr17);
}};
$e18551856.stack[R.EXN_STACKHEIGHT++] = $ss18591860;
}
if(R.isPyretException($e18551856)) {
$e18551856.pyretStack.push(L[106]);
}
throw $e18551856;
}
var $ret18611862 = $Hanf_arg9221866($z18571858,self951829,_plus13,torepr17);
++R.GAS;
return $ret18611862;
};
var $Hanf_arg9221866 = function(anf_arg4161865,self951829,_plus13,torepr17) {
var anf_arg4171877 = G(self951829,"prev-loc",L[106]);
var $z18691870 = D;
var $f18751876 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg4171877):R.ffi.throwNonFunApp(L[106],torepr17,[anf_arg4171877]);
};
try {
if(--R.GAS > 0) {
$z18691870 = $f18751876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18751876,
"from":L[106]});
}
} catch($e18671868) {
if(R.isCont($e18671868)) {
var $ss18711872 = {"from":L[106],
"go":function(anf_arg4181878) {
return $Hanf_arg9211879(anf_arg4181878,anf_arg4161865,_plus13);
}};
$e18671868.stack[R.EXN_STACKHEIGHT++] = $ss18711872;
}
if(R.isPyretException($e18671868)) {
$e18671868.pyretStack.push(L[106]);
}
throw $e18671868;
}
var $ret18731874 = $Hanf_arg9211879($z18691870,anf_arg4161865,_plus13);
++R.GAS;
return $ret18731874;
};
var $Hanf_arg9211879 = function(anf_arg4181878,anf_arg4161865,_plus13) {
var $z18821883 = D;
var $f18881889 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg4181878):R.ffi.throwNonFunApp(L[106],_plus13,[(", "),anf_arg4181878]);
};
try {
if(--R.GAS > 0) {
$z18821883 = $f18881889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18881889,
"from":L[106]});
}
} catch($e18801881) {
if(R.isCont($e18801881)) {
var $ss18841885 = {"from":L[106],
"go":function(anf_arg4191890) {
return $Hanf_arg9201891(anf_arg4191890,anf_arg4161865,_plus13);
}};
$e18801881.stack[R.EXN_STACKHEIGHT++] = $ss18841885;
}
if(R.isPyretException($e18801881)) {
$e18801881.pyretStack.push(L[106]);
}
throw $e18801881;
}
var $ret18861887 = $Hanf_arg9201891($z18821883,anf_arg4161865,_plus13);
++R.GAS;
return $ret18861887;
};
var $Hanf_arg9201891 = function(anf_arg4191890,anf_arg4161865,_plus13) {
var $z18941895 = D;
var $f19001901 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4161865,anf_arg4191890):R.ffi.throwNonFunApp(L[106],_plus13,[anf_arg4161865,anf_arg4191890]);
};
try {
if(--R.GAS > 0) {
$z18941895 = $f19001901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19001901,
"from":L[106]});
}
} catch($e18921893) {
if(R.isCont($e18921893)) {
var $ss18961897 = {"from":L[106],
"go":function(anf_arg4201902) {
return $Hanf_arg9191903(anf_arg4201902,_plus13);
}};
$e18921893.stack[R.EXN_STACKHEIGHT++] = $ss18961897;
}
if(R.isPyretException($e18921893)) {
$e18921893.pyretStack.push(L[106]);
}
throw $e18921893;
}
var $ret18981899 = $Hanf_arg9191903($z18941895,_plus13);
++R.GAS;
return $ret18981899;
};
var $Hanf_arg9191903 = function(anf_arg4201902,_plus13) {
var $z19061907 = D;
var $f19121913 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4201902,(")")):R.ffi.throwNonFunApp(L[106],_plus13,[anf_arg4201902,(")")]);
};
try {
if(--R.GAS > 0) {
$z19061907 = $f19121913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19121913,
"from":L[106]});
}
} catch($e19041905) {
if(R.isCont($e19041905)) {
var $ss19081909 = {"from":L[106],
"go":function(anf_arg4211914) {
return $Hanf_arg9181915(anf_arg4211914,_plus13);
}};
$e19041905.stack[R.EXN_STACKHEIGHT++] = $ss19081909;
}
if(R.isPyretException($e19041905)) {
$e19041905.pyretStack.push(L[106]);
}
throw $e19041905;
}
var $ret19101911 = $Hanf_arg9181915($z19061907,_plus13);
++R.GAS;
return $ret19101911;
};
var $Hanf_arg9181915 = function(anf_arg4211914,_plus13) {
var $z19181919 = D;
var $f19241925 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg4211914):R.ffi.throwNonFunApp(L[106],_plus13,[("("),anf_arg4211914]);
};
try {
if(--R.GAS > 0) {
$z19181919 = $f19241925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19241925,
"from":L[106]});
}
} catch($e19161917) {
if(R.isCont($e19161917)) {
var $ss19201921 = {"from":L[106],
"go":function(anf_arg4221926) {
return $Hanf_arg9171927(anf_arg4221926,_plus13);
}};
$e19161917.stack[R.EXN_STACKHEIGHT++] = $ss19201921;
}
if(R.isPyretException($e19161917)) {
$e19161917.pyretStack.push(L[106]);
}
throw $e19161917;
}
var $ret19221923 = $Hanf_arg9171927($z19181919,_plus13);
++R.GAS;
return $ret19221923;
};
var $Hanf_arg9171927 = function(anf_arg4221926,_plus13) {
var $z19301931 = D;
var $f19361937 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("bad-assignment"),anf_arg4221926):R.ffi.throwNonFunApp(L[106],_plus13,[("bad-assignment"),anf_arg4221926]);
};
try {
if(--R.GAS > 0) {
$z19301931 = $f19361937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19361937,
"from":L[106]});
}
} catch($e19281929) {
if(R.isCont($e19281929)) {
var $ss19321933 = {"from":L[106],
"go":function(ann_DASH_check_DASH_temp4101938) {
return $Hann_DASH_check_DASH_temp9161939(ann_DASH_check_DASH_temp4101938);
}};
$e19281929.stack[R.EXN_STACKHEIGHT++] = $ss19321933;
}
if(R.isPyretException($e19281929)) {
$e19281929.pyretStack.push(L[106]);
}
throw $e19281929;
}
var $ret19341935 = $Hann_DASH_check_DASH_temp9161939($z19301931);
++R.GAS;
return $ret19341935;
};
var $Hann_DASH_check_DASH_temp9161939 = function(ann_DASH_check_DASH_temp4101938) {
return ann_DASH_check_DASH_temp4101938;
};
var $Hcont_tail_arg9141940 = function(cont_tail_arg4071941,if_helper3971942) {
if(--R.GAS > 0) {
$z19431944 = R.isFunction(if_helper3971942)?if_helper3971942.app(cont_tail_arg4071941):R.ffi.throwNonFunApp(L[106],if_helper3971942,[cont_tail_arg4071941]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3971942)?if_helper3971942.app(cont_tail_arg4071941):R.ffi.throwNonFunApp(L[106],if_helper3971942,[cont_tail_arg4071941]);
},
"from":L[106]});
}
++R.GAS;
return $z19431944;
};
var $Hcont_tail_arg9151945 = function(cont_tail_arg4021946,if_helper3971942) {
if(--R.GAS > 0) {
$z19471948 = R.isFunction(if_helper3971942)?if_helper3971942.app(cont_tail_arg4021946):R.ffi.throwNonFunApp(L[106],if_helper3971942,[cont_tail_arg4021946]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3971942)?if_helper3971942.app(cont_tail_arg4021946):R.ffi.throwNonFunApp(L[106],if_helper3971942,[cont_tail_arg4021946]);
},
"from":L[106]});
}
++R.GAS;
return $z19471948;
};
var $Hanf_arg9131949 = function(anf_arg3931950,_plus13) {
var $z19531954 = D;
var $f19591960 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("The anonymous identifier at "),anf_arg3931950):R.ffi.throwNonFunApp(L[107],_plus13,[("The anonymous identifier at "),anf_arg3931950]);
};
try {
if(--R.GAS > 0) {
$z19531954 = $f19591960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19591960,
"from":L[107]});
}
} catch($e19511952) {
if(R.isCont($e19511952)) {
var $ss19551956 = {"from":L[107],
"go":function(anf_arg3941961) {
return $Hanf_arg9121962(anf_arg3941961,_plus13);
}};
$e19511952.stack[R.EXN_STACKHEIGHT++] = $ss19551956;
}
if(R.isPyretException($e19511952)) {
$e19511952.pyretStack.push(L[107]);
}
throw $e19511952;
}
var $ret19571958 = $Hanf_arg9121962($z19531954,_plus13);
++R.GAS;
return $ret19571958;
};
var $Hanf_arg9121962 = function(anf_arg3941961,_plus13) {
var $z19651966 = D;
var $f19711972 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3941961,(" can't actually shadow anything")):R.ffi.throwNonFunApp(L[108],_plus13,[anf_arg3941961,(" can't actually shadow anything")]);
};
try {
if(--R.GAS > 0) {
$z19651966 = $f19711972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19711972,
"from":L[108]});
}
} catch($e19631964) {
if(R.isCont($e19631964)) {
var $ss19671968 = {"from":L[108],
"go":function(ann_DASH_check_DASH_temp3911973) {
return $Hann_DASH_check_DASH_temp9111974(ann_DASH_check_DASH_temp3911973);
}};
$e19631964.stack[R.EXN_STACKHEIGHT++] = $ss19671968;
}
if(R.isPyretException($e19631964)) {
$e19631964.pyretStack.push(L[108]);
}
throw $e19631964;
}
var $ret19691970 = $Hann_DASH_check_DASH_temp9111974($z19651966);
++R.GAS;
return $ret19691970;
};
var $Hann_DASH_check_DASH_temp9111974 = function(ann_DASH_check_DASH_temp3911973) {
return ann_DASH_check_DASH_temp3911973;
};
var $Hanf_arg9101975 = function(anf_arg3871976,_plus13) {
var $z19791980 = D;
var $f19851986 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3871976,(")")):R.ffi.throwNonFunApp(L[109],_plus13,[anf_arg3871976,(")")]);
};
try {
if(--R.GAS > 0) {
$z19791980 = $f19851986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19851986,
"from":L[109]});
}
} catch($e19771978) {
if(R.isCont($e19771978)) {
var $ss19811982 = {"from":L[109],
"go":function(anf_arg3881987) {
return $Hanf_arg9091988(anf_arg3881987,_plus13);
}};
$e19771978.stack[R.EXN_STACKHEIGHT++] = $ss19811982;
}
if(R.isPyretException($e19771978)) {
$e19771978.pyretStack.push(L[109]);
}
throw $e19771978;
}
var $ret19831984 = $Hanf_arg9091988($z19791980,_plus13);
++R.GAS;
return $ret19831984;
};
var $Hanf_arg9091988 = function(anf_arg3881987,_plus13) {
var $z19911992 = D;
var $f19971998 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg3881987):R.ffi.throwNonFunApp(L[109],_plus13,[("("),anf_arg3881987]);
};
try {
if(--R.GAS > 0) {
$z19911992 = $f19971998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19971998,
"from":L[109]});
}
} catch($e19891990) {
if(R.isCont($e19891990)) {
var $ss19931994 = {"from":L[109],
"go":function(anf_arg3891999) {
return $Hanf_arg9082000(anf_arg3891999,_plus13);
}};
$e19891990.stack[R.EXN_STACKHEIGHT++] = $ss19931994;
}
if(R.isPyretException($e19891990)) {
$e19891990.pyretStack.push(L[109]);
}
throw $e19891990;
}
var $ret19951996 = $Hanf_arg9082000($z19911992,_plus13);
++R.GAS;
return $ret19951996;
};
var $Hanf_arg9082000 = function(anf_arg3891999,_plus13) {
var $z20032004 = D;
var $f20092010 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("pointless-shadow"),anf_arg3891999):R.ffi.throwNonFunApp(L[109],_plus13,[("pointless-shadow"),anf_arg3891999]);
};
try {
if(--R.GAS > 0) {
$z20032004 = $f20092010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20092010,
"from":L[109]});
}
} catch($e20012002) {
if(R.isCont($e20012002)) {
var $ss20052006 = {"from":L[109],
"go":function(ann_DASH_check_DASH_temp3852011) {
return $Hann_DASH_check_DASH_temp9072012(ann_DASH_check_DASH_temp3852011);
}};
$e20012002.stack[R.EXN_STACKHEIGHT++] = $ss20052006;
}
if(R.isPyretException($e20012002)) {
$e20012002.pyretStack.push(L[109]);
}
throw $e20012002;
}
var $ret20072008 = $Hann_DASH_check_DASH_temp9072012($z20032004);
++R.GAS;
return $ret20072008;
};
var $Hann_DASH_check_DASH_temp9072012 = function(ann_DASH_check_DASH_temp3852011) {
return ann_DASH_check_DASH_temp3852011;
};
var $Hcont_tail_arg9052013 = function(cont_tail_arg3822014,if_helper3742015) {
if(--R.GAS > 0) {
$z20162017 = R.isFunction(if_helper3742015)?if_helper3742015.app(cont_tail_arg3822014):R.ffi.throwNonFunApp(L[109],if_helper3742015,[cont_tail_arg3822014]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3742015)?if_helper3742015.app(cont_tail_arg3822014):R.ffi.throwNonFunApp(L[109],if_helper3742015,[cont_tail_arg3822014]);
},
"from":L[109]});
}
++R.GAS;
return $z20162017;
};
var $Hcont_tail_arg9062018 = function(cont_tail_arg3792019,if_helper3742015) {
if(--R.GAS > 0) {
$z20202021 = R.isFunction(if_helper3742015)?if_helper3742015.app(cont_tail_arg3792019):R.ffi.throwNonFunApp(L[109],if_helper3742015,[cont_tail_arg3792019]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3742015)?if_helper3742015.app(cont_tail_arg3792019):R.ffi.throwNonFunApp(L[109],if_helper3742015,[cont_tail_arg3792019]);
},
"from":L[109]});
}
++R.GAS;
return $z20202021;
};
var $Hanf_arg9042022 = function(anf_arg3702023,_plus13) {
var $z20262027 = D;
var $f20322033 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("The anonymous mutable variable at "),anf_arg3702023):R.ffi.throwNonFunApp(L[110],_plus13,[("The anonymous mutable variable at "),anf_arg3702023]);
};
try {
if(--R.GAS > 0) {
$z20262027 = $f20322033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20322033,
"from":L[110]});
}
} catch($e20242025) {
if(R.isCont($e20242025)) {
var $ss20282029 = {"from":L[110],
"go":function(anf_arg3712034) {
return $Hanf_arg9032035(anf_arg3712034,_plus13);
}};
$e20242025.stack[R.EXN_STACKHEIGHT++] = $ss20282029;
}
if(R.isPyretException($e20242025)) {
$e20242025.pyretStack.push(L[110]);
}
throw $e20242025;
}
var $ret20302031 = $Hanf_arg9032035($z20262027,_plus13);
++R.GAS;
return $ret20302031;
};
var $Hanf_arg9032035 = function(anf_arg3712034,_plus13) {
var $z20382039 = D;
var $f20442045 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3712034,(" can never be re-used")):R.ffi.throwNonFunApp(L[111],_plus13,[anf_arg3712034,(" can never be re-used")]);
};
try {
if(--R.GAS > 0) {
$z20382039 = $f20442045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20442045,
"from":L[111]});
}
} catch($e20362037) {
if(R.isCont($e20362037)) {
var $ss20402041 = {"from":L[111],
"go":function(ann_DASH_check_DASH_temp3682046) {
return $Hann_DASH_check_DASH_temp9022047(ann_DASH_check_DASH_temp3682046);
}};
$e20362037.stack[R.EXN_STACKHEIGHT++] = $ss20402041;
}
if(R.isPyretException($e20362037)) {
$e20362037.pyretStack.push(L[111]);
}
throw $e20362037;
}
var $ret20422043 = $Hann_DASH_check_DASH_temp9022047($z20382039);
++R.GAS;
return $ret20422043;
};
var $Hann_DASH_check_DASH_temp9022047 = function(ann_DASH_check_DASH_temp3682046) {
return ann_DASH_check_DASH_temp3682046;
};
var $Hanf_arg9012048 = function(anf_arg3642049,_plus13) {
var $z20522053 = D;
var $f20582059 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3642049,(")")):R.ffi.throwNonFunApp(L[112],_plus13,[anf_arg3642049,(")")]);
};
try {
if(--R.GAS > 0) {
$z20522053 = $f20582059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20582059,
"from":L[112]});
}
} catch($e20502051) {
if(R.isCont($e20502051)) {
var $ss20542055 = {"from":L[112],
"go":function(anf_arg3652060) {
return $Hanf_arg9002061(anf_arg3652060,_plus13);
}};
$e20502051.stack[R.EXN_STACKHEIGHT++] = $ss20542055;
}
if(R.isPyretException($e20502051)) {
$e20502051.pyretStack.push(L[112]);
}
throw $e20502051;
}
var $ret20562057 = $Hanf_arg9002061($z20522053,_plus13);
++R.GAS;
return $ret20562057;
};
var $Hanf_arg9002061 = function(anf_arg3652060,_plus13) {
var $z20642065 = D;
var $f20702071 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg3652060):R.ffi.throwNonFunApp(L[112],_plus13,[("("),anf_arg3652060]);
};
try {
if(--R.GAS > 0) {
$z20642065 = $f20702071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20702071,
"from":L[112]});
}
} catch($e20622063) {
if(R.isCont($e20622063)) {
var $ss20662067 = {"from":L[112],
"go":function(anf_arg3662072) {
return $Hanf_arg8992073(anf_arg3662072,_plus13);
}};
$e20622063.stack[R.EXN_STACKHEIGHT++] = $ss20662067;
}
if(R.isPyretException($e20622063)) {
$e20622063.pyretStack.push(L[112]);
}
throw $e20622063;
}
var $ret20682069 = $Hanf_arg8992073($z20642065,_plus13);
++R.GAS;
return $ret20682069;
};
var $Hanf_arg8992073 = function(anf_arg3662072,_plus13) {
var $z20762077 = D;
var $f20822083 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("pointless-var"),anf_arg3662072):R.ffi.throwNonFunApp(L[112],_plus13,[("pointless-var"),anf_arg3662072]);
};
try {
if(--R.GAS > 0) {
$z20762077 = $f20822083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20822083,
"from":L[112]});
}
} catch($e20742075) {
if(R.isCont($e20742075)) {
var $ss20782079 = {"from":L[112],
"go":function(ann_DASH_check_DASH_temp3622084) {
return $Hann_DASH_check_DASH_temp8982085(ann_DASH_check_DASH_temp3622084);
}};
$e20742075.stack[R.EXN_STACKHEIGHT++] = $ss20782079;
}
if(R.isPyretException($e20742075)) {
$e20742075.pyretStack.push(L[112]);
}
throw $e20742075;
}
var $ret20802081 = $Hann_DASH_check_DASH_temp8982085($z20762077);
++R.GAS;
return $ret20802081;
};
var $Hann_DASH_check_DASH_temp8982085 = function(ann_DASH_check_DASH_temp3622084) {
return ann_DASH_check_DASH_temp3622084;
};
var $Hcont_tail_arg8962086 = function(cont_tail_arg3592087,if_helper3512088) {
if(--R.GAS > 0) {
$z20892090 = R.isFunction(if_helper3512088)?if_helper3512088.app(cont_tail_arg3592087):R.ffi.throwNonFunApp(L[112],if_helper3512088,[cont_tail_arg3592087]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3512088)?if_helper3512088.app(cont_tail_arg3592087):R.ffi.throwNonFunApp(L[112],if_helper3512088,[cont_tail_arg3592087]);
},
"from":L[112]});
}
++R.GAS;
return $z20892090;
};
var $Hcont_tail_arg8972091 = function(cont_tail_arg3562092,if_helper3512088) {
if(--R.GAS > 0) {
$z20932094 = R.isFunction(if_helper3512088)?if_helper3512088.app(cont_tail_arg3562092):R.ffi.throwNonFunApp(L[112],if_helper3512088,[cont_tail_arg3562092]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3512088)?if_helper3512088.app(cont_tail_arg3562092):R.ffi.throwNonFunApp(L[112],if_helper3512088,[cont_tail_arg3562092]);
},
"from":L[112]});
}
++R.GAS;
return $z20932094;
};
var $Hanf_arg8952095 = function(anf_arg3432096,self1602097,_plus13,tostring18) {
var $z21002101 = D;
var $f21062107 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Identifier "),anf_arg3432096):R.ffi.throwNonFunApp(L[113],_plus13,[("Identifier "),anf_arg3432096]);
};
try {
if(--R.GAS > 0) {
$z21002101 = $f21062107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21062107,
"from":L[113]});
}
} catch($e20982099) {
if(R.isCont($e20982099)) {
var $ss21022103 = {"from":L[113],
"go":function(anf_arg3442108) {
return $Hanf_arg8942109(anf_arg3442108,self1602097,_plus13,tostring18);
}};
$e20982099.stack[R.EXN_STACKHEIGHT++] = $ss21022103;
}
if(R.isPyretException($e20982099)) {
$e20982099.pyretStack.push(L[113]);
}
throw $e20982099;
}
var $ret21042105 = $Hanf_arg8942109($z21002101,self1602097,_plus13,tostring18);
++R.GAS;
return $ret21042105;
};
var $Hanf_arg8942109 = function(anf_arg3442108,self1602097,_plus13,tostring18) {
var $z21122113 = D;
var $f21182119 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3442108,(" is used in a dot-annotation at ")):R.ffi.throwNonFunApp(L[113],_plus13,[anf_arg3442108,(" is used in a dot-annotation at ")]);
};
try {
if(--R.GAS > 0) {
$z21122113 = $f21182119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21182119,
"from":L[113]});
}
} catch($e21102111) {
if(R.isCont($e21102111)) {
var $ss21142115 = {"from":L[113],
"go":function(anf_arg3452120) {
return $Hanf_arg8932121(anf_arg3452120,self1602097,_plus13,tostring18);
}};
$e21102111.stack[R.EXN_STACKHEIGHT++] = $ss21142115;
}
if(R.isPyretException($e21102111)) {
$e21102111.pyretStack.push(L[113]);
}
throw $e21102111;
}
var $ret21162117 = $Hanf_arg8932121($z21122113,self1602097,_plus13,tostring18);
++R.GAS;
return $ret21162117;
};
var $Hanf_arg8932121 = function(anf_arg3452120,self1602097,_plus13,tostring18) {
var anf_arg3462132 = G(self1602097,"loc",L[115]);
var $z21242125 = D;
var $f21302131 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg3462132):R.ffi.throwNonFunApp(L[114],tostring18,[anf_arg3462132]);
};
try {
if(--R.GAS > 0) {
$z21242125 = $f21302131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21302131,
"from":L[114]});
}
} catch($e21222123) {
if(R.isCont($e21222123)) {
var $ss21262127 = {"from":L[114],
"go":function(anf_arg3472133) {
return $Hanf_arg8922134(anf_arg3472133,anf_arg3452120,_plus13);
}};
$e21222123.stack[R.EXN_STACKHEIGHT++] = $ss21262127;
}
if(R.isPyretException($e21222123)) {
$e21222123.pyretStack.push(L[114]);
}
throw $e21222123;
}
var $ret21282129 = $Hanf_arg8922134($z21242125,anf_arg3452120,_plus13);
++R.GAS;
return $ret21282129;
};
var $Hanf_arg8922134 = function(anf_arg3472133,anf_arg3452120,_plus13) {
var $z21372138 = D;
var $f21432144 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3452120,anf_arg3472133):R.ffi.throwNonFunApp(L[113],_plus13,[anf_arg3452120,anf_arg3472133]);
};
try {
if(--R.GAS > 0) {
$z21372138 = $f21432144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21432144,
"from":L[113]});
}
} catch($e21352136) {
if(R.isCont($e21352136)) {
var $ss21392140 = {"from":L[113],
"go":function(anf_arg3482145) {
return $Hanf_arg8912146(anf_arg3482145,_plus13);
}};
$e21352136.stack[R.EXN_STACKHEIGHT++] = $ss21392140;
}
if(R.isPyretException($e21352136)) {
$e21352136.pyretStack.push(L[113]);
}
throw $e21352136;
}
var $ret21412142 = $Hanf_arg8912146($z21372138,_plus13);
++R.GAS;
return $ret21412142;
};
var $Hanf_arg8912146 = function(anf_arg3482145,_plus13) {
var $z21492150 = D;
var $f21552156 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3482145,(", but is bound as a type variable")):R.ffi.throwNonFunApp(L[116],_plus13,[anf_arg3482145,(", but is bound as a type variable")]);
};
try {
if(--R.GAS > 0) {
$z21492150 = $f21552156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21552156,
"from":L[116]});
}
} catch($e21472148) {
if(R.isCont($e21472148)) {
var $ss21512152 = {"from":L[116],
"go":function(ann_DASH_check_DASH_temp3412157) {
return $Hann_DASH_check_DASH_temp8902158(ann_DASH_check_DASH_temp3412157);
}};
$e21472148.stack[R.EXN_STACKHEIGHT++] = $ss21512152;
}
if(R.isPyretException($e21472148)) {
$e21472148.pyretStack.push(L[116]);
}
throw $e21472148;
}
var $ret21532154 = $Hann_DASH_check_DASH_temp8902158($z21492150);
++R.GAS;
return $ret21532154;
};
var $Hann_DASH_check_DASH_temp8902158 = function(ann_DASH_check_DASH_temp3412157) {
return ann_DASH_check_DASH_temp3412157;
};
var $Hanf_arg8892159 = function(anf_arg3332160,self772161,_plus13,torepr17) {
var anf_arg3342172 = G(self772161,"name",L[117]);
var $z21642165 = D;
var $f21702171 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg3342172):R.ffi.throwNonFunApp(L[117],torepr17,[anf_arg3342172]);
};
try {
if(--R.GAS > 0) {
$z21642165 = $f21702171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21702171,
"from":L[117]});
}
} catch($e21622163) {
if(R.isCont($e21622163)) {
var $ss21662167 = {"from":L[117],
"go":function(anf_arg3352173) {
return $Hanf_arg8882174(anf_arg3352173,anf_arg3332160,_plus13);
}};
$e21622163.stack[R.EXN_STACKHEIGHT++] = $ss21662167;
}
if(R.isPyretException($e21622163)) {
$e21622163.pyretStack.push(L[117]);
}
throw $e21622163;
}
var $ret21682169 = $Hanf_arg8882174($z21642165,anf_arg3332160,_plus13);
++R.GAS;
return $ret21682169;
};
var $Hanf_arg8882174 = function(anf_arg3352173,anf_arg3332160,_plus13) {
var $z21772178 = D;
var $f21832184 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg3352173):R.ffi.throwNonFunApp(L[117],_plus13,[(", "),anf_arg3352173]);
};
try {
if(--R.GAS > 0) {
$z21772178 = $f21832184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21832184,
"from":L[117]});
}
} catch($e21752176) {
if(R.isCont($e21752176)) {
var $ss21792180 = {"from":L[117],
"go":function(anf_arg3362185) {
return $Hanf_arg8872186(anf_arg3362185,anf_arg3332160,_plus13);
}};
$e21752176.stack[R.EXN_STACKHEIGHT++] = $ss21792180;
}
if(R.isPyretException($e21752176)) {
$e21752176.pyretStack.push(L[117]);
}
throw $e21752176;
}
var $ret21812182 = $Hanf_arg8872186($z21772178,anf_arg3332160,_plus13);
++R.GAS;
return $ret21812182;
};
var $Hanf_arg8872186 = function(anf_arg3362185,anf_arg3332160,_plus13) {
var $z21892190 = D;
var $f21952196 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3332160,anf_arg3362185):R.ffi.throwNonFunApp(L[117],_plus13,[anf_arg3332160,anf_arg3362185]);
};
try {
if(--R.GAS > 0) {
$z21892190 = $f21952196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21952196,
"from":L[117]});
}
} catch($e21872188) {
if(R.isCont($e21872188)) {
var $ss21912192 = {"from":L[117],
"go":function(anf_arg3372197) {
return $Hanf_arg8862198(anf_arg3372197,_plus13);
}};
$e21872188.stack[R.EXN_STACKHEIGHT++] = $ss21912192;
}
if(R.isPyretException($e21872188)) {
$e21872188.pyretStack.push(L[117]);
}
throw $e21872188;
}
var $ret21932194 = $Hanf_arg8862198($z21892190,_plus13);
++R.GAS;
return $ret21932194;
};
var $Hanf_arg8862198 = function(anf_arg3372197,_plus13) {
var $z22012202 = D;
var $f22072208 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3372197,(")")):R.ffi.throwNonFunApp(L[117],_plus13,[anf_arg3372197,(")")]);
};
try {
if(--R.GAS > 0) {
$z22012202 = $f22072208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22072208,
"from":L[117]});
}
} catch($e21992200) {
if(R.isCont($e21992200)) {
var $ss22032204 = {"from":L[117],
"go":function(anf_arg3382209) {
return $Hanf_arg8852210(anf_arg3382209,_plus13);
}};
$e21992200.stack[R.EXN_STACKHEIGHT++] = $ss22032204;
}
if(R.isPyretException($e21992200)) {
$e21992200.pyretStack.push(L[117]);
}
throw $e21992200;
}
var $ret22052206 = $Hanf_arg8852210($z22012202,_plus13);
++R.GAS;
return $ret22052206;
};
var $Hanf_arg8852210 = function(anf_arg3382209,_plus13) {
var $z22132214 = D;
var $f22192220 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg3382209):R.ffi.throwNonFunApp(L[117],_plus13,[("("),anf_arg3382209]);
};
try {
if(--R.GAS > 0) {
$z22132214 = $f22192220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22192220,
"from":L[117]});
}
} catch($e22112212) {
if(R.isCont($e22112212)) {
var $ss22152216 = {"from":L[117],
"go":function(anf_arg3392221) {
return $Hanf_arg8842222(anf_arg3392221,_plus13);
}};
$e22112212.stack[R.EXN_STACKHEIGHT++] = $ss22152216;
}
if(R.isPyretException($e22112212)) {
$e22112212.pyretStack.push(L[117]);
}
throw $e22112212;
}
var $ret22172218 = $Hanf_arg8842222($z22132214,_plus13);
++R.GAS;
return $ret22172218;
};
var $Hanf_arg8842222 = function(anf_arg3392221,_plus13) {
var $z22252226 = D;
var $f22312232 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("unexpected-type-var"),anf_arg3392221):R.ffi.throwNonFunApp(L[117],_plus13,[("unexpected-type-var"),anf_arg3392221]);
};
try {
if(--R.GAS > 0) {
$z22252226 = $f22312232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22312232,
"from":L[117]});
}
} catch($e22232224) {
if(R.isCont($e22232224)) {
var $ss22272228 = {"from":L[117],
"go":function(ann_DASH_check_DASH_temp3312233) {
return $Hann_DASH_check_DASH_temp8832234(ann_DASH_check_DASH_temp3312233);
}};
$e22232224.stack[R.EXN_STACKHEIGHT++] = $ss22272228;
}
if(R.isPyretException($e22232224)) {
$e22232224.pyretStack.push(L[117]);
}
throw $e22232224;
}
var $ret22292230 = $Hann_DASH_check_DASH_temp8832234($z22252226);
++R.GAS;
return $ret22292230;
};
var $Hann_DASH_check_DASH_temp8832234 = function(ann_DASH_check_DASH_temp3312233) {
return ann_DASH_check_DASH_temp3312233;
};
var $Hcont_tail_arg8812235 = function(cont_tail_arg3282236,if_helper3192237) {
if(--R.GAS > 0) {
$z22382239 = R.isFunction(if_helper3192237)?if_helper3192237.app(cont_tail_arg3282236):R.ffi.throwNonFunApp(L[117],if_helper3192237,[cont_tail_arg3282236]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3192237)?if_helper3192237.app(cont_tail_arg3282236):R.ffi.throwNonFunApp(L[117],if_helper3192237,[cont_tail_arg3282236]);
},
"from":L[117]});
}
++R.GAS;
return $z22382239;
};
var $Hcont_tail_arg8822240 = function(cont_tail_arg3242241,if_helper3192237) {
if(--R.GAS > 0) {
$z22422243 = R.isFunction(if_helper3192237)?if_helper3192237.app(cont_tail_arg3242241):R.ffi.throwNonFunApp(L[117],if_helper3192237,[cont_tail_arg3242241]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3192237)?if_helper3192237.app(cont_tail_arg3242241):R.ffi.throwNonFunApp(L[117],if_helper3192237,[cont_tail_arg3242241]);
},
"from":L[117]});
}
++R.GAS;
return $z22422243;
};
var $Hanf_arg8802244 = function(anf_arg3102245,self1572246,_plus13,tostring18) {
var $z22492250 = D;
var $f22552256 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Identifier "),anf_arg3102245):R.ffi.throwNonFunApp(L[118],_plus13,[("Identifier "),anf_arg3102245]);
};
try {
if(--R.GAS > 0) {
$z22492250 = $f22552256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22552256,
"from":L[118]});
}
} catch($e22472248) {
if(R.isCont($e22472248)) {
var $ss22512252 = {"from":L[118],
"go":function(anf_arg3112257) {
return $Hanf_arg8792258(anf_arg3112257,self1572246,_plus13,tostring18);
}};
$e22472248.stack[R.EXN_STACKHEIGHT++] = $ss22512252;
}
if(R.isPyretException($e22472248)) {
$e22472248.pyretStack.push(L[118]);
}
throw $e22472248;
}
var $ret22532254 = $Hanf_arg8792258($z22492250,self1572246,_plus13,tostring18);
++R.GAS;
return $ret22532254;
};
var $Hanf_arg8792258 = function(anf_arg3112257,self1572246,_plus13,tostring18) {
var $z22612262 = D;
var $f22672268 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3112257,(" is used as a type name at ")):R.ffi.throwNonFunApp(L[118],_plus13,[anf_arg3112257,(" is used as a type name at ")]);
};
try {
if(--R.GAS > 0) {
$z22612262 = $f22672268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22672268,
"from":L[118]});
}
} catch($e22592260) {
if(R.isCont($e22592260)) {
var $ss22632264 = {"from":L[118],
"go":function(anf_arg3122269) {
return $Hanf_arg8782270(anf_arg3122269,self1572246,_plus13,tostring18);
}};
$e22592260.stack[R.EXN_STACKHEIGHT++] = $ss22632264;
}
if(R.isPyretException($e22592260)) {
$e22592260.pyretStack.push(L[118]);
}
throw $e22592260;
}
var $ret22652266 = $Hanf_arg8782270($z22612262,self1572246,_plus13,tostring18);
++R.GAS;
return $ret22652266;
};
var $Hanf_arg8782270 = function(anf_arg3122269,self1572246,_plus13,tostring18) {
var anf_bracket3132284 = G(self1572246,"id",L[121]);
var anf_arg3142281 = G(anf_bracket3132284,"l",L[120]);
var $z22732274 = D;
var $f22792280 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg3142281):R.ffi.throwNonFunApp(L[119],tostring18,[anf_arg3142281]);
};
try {
if(--R.GAS > 0) {
$z22732274 = $f22792280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22792280,
"from":L[119]});
}
} catch($e22712272) {
if(R.isCont($e22712272)) {
var $ss22752276 = {"from":L[119],
"go":function(anf_arg3152282) {
return $Hanf_arg8772283(anf_arg3152282,anf_arg3122269,_plus13);
}};
$e22712272.stack[R.EXN_STACKHEIGHT++] = $ss22752276;
}
if(R.isPyretException($e22712272)) {
$e22712272.pyretStack.push(L[119]);
}
throw $e22712272;
}
var $ret22772278 = $Hanf_arg8772283($z22732274,anf_arg3122269,_plus13);
++R.GAS;
return $ret22772278;
};
var $Hanf_arg8772283 = function(anf_arg3152282,anf_arg3122269,_plus13) {
var $z22872288 = D;
var $f22932294 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3122269,anf_arg3152282):R.ffi.throwNonFunApp(L[118],_plus13,[anf_arg3122269,anf_arg3152282]);
};
try {
if(--R.GAS > 0) {
$z22872288 = $f22932294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22932294,
"from":L[118]});
}
} catch($e22852286) {
if(R.isCont($e22852286)) {
var $ss22892290 = {"from":L[118],
"go":function(anf_arg3162295) {
return $Hanf_arg8762296(anf_arg3162295,_plus13);
}};
$e22852286.stack[R.EXN_STACKHEIGHT++] = $ss22892290;
}
if(R.isPyretException($e22852286)) {
$e22852286.pyretStack.push(L[118]);
}
throw $e22852286;
}
var $ret22912292 = $Hanf_arg8762296($z22872288,_plus13);
++R.GAS;
return $ret22912292;
};
var $Hanf_arg8762296 = function(anf_arg3162295,_plus13) {
var $z22992300 = D;
var $f23052306 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3162295,(", but is not defined as a type.")):R.ffi.throwNonFunApp(L[122],_plus13,[anf_arg3162295,(", but is not defined as a type.")]);
};
try {
if(--R.GAS > 0) {
$z22992300 = $f23052306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23052306,
"from":L[122]});
}
} catch($e22972298) {
if(R.isCont($e22972298)) {
var $ss23012302 = {"from":L[122],
"go":function(ann_DASH_check_DASH_temp3062307) {
return $Hann_DASH_check_DASH_temp8752308(ann_DASH_check_DASH_temp3062307);
}};
$e22972298.stack[R.EXN_STACKHEIGHT++] = $ss23012302;
}
if(R.isPyretException($e22972298)) {
$e22972298.pyretStack.push(L[122]);
}
throw $e22972298;
}
var $ret23032304 = $Hann_DASH_check_DASH_temp8752308($z22992300);
++R.GAS;
return $ret23032304;
};
var $Hann_DASH_check_DASH_temp8752308 = function(ann_DASH_check_DASH_temp3062307) {
return ann_DASH_check_DASH_temp3062307;
};
var $Hanf_arg8742309 = function(anf_arg3022310,_plus13) {
var $z23132314 = D;
var $f23192320 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg3022310,(")")):R.ffi.throwNonFunApp(L[123],_plus13,[anf_arg3022310,(")")]);
};
try {
if(--R.GAS > 0) {
$z23132314 = $f23192320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23192320,
"from":L[123]});
}
} catch($e23112312) {
if(R.isCont($e23112312)) {
var $ss23152316 = {"from":L[123],
"go":function(anf_arg3032321) {
return $Hanf_arg8732322(anf_arg3032321,_plus13);
}};
$e23112312.stack[R.EXN_STACKHEIGHT++] = $ss23152316;
}
if(R.isPyretException($e23112312)) {
$e23112312.pyretStack.push(L[123]);
}
throw $e23112312;
}
var $ret23172318 = $Hanf_arg8732322($z23132314,_plus13);
++R.GAS;
return $ret23172318;
};
var $Hanf_arg8732322 = function(anf_arg3032321,_plus13) {
var $z23252326 = D;
var $f23312332 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg3032321):R.ffi.throwNonFunApp(L[123],_plus13,[("("),anf_arg3032321]);
};
try {
if(--R.GAS > 0) {
$z23252326 = $f23312332();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23312332,
"from":L[123]});
}
} catch($e23232324) {
if(R.isCont($e23232324)) {
var $ss23272328 = {"from":L[123],
"go":function(anf_arg3042333) {
return $Hanf_arg8722334(anf_arg3042333,_plus13);
}};
$e23232324.stack[R.EXN_STACKHEIGHT++] = $ss23272328;
}
if(R.isPyretException($e23232324)) {
$e23232324.pyretStack.push(L[123]);
}
throw $e23232324;
}
var $ret23292330 = $Hanf_arg8722334($z23252326,_plus13);
++R.GAS;
return $ret23292330;
};
var $Hanf_arg8722334 = function(anf_arg3042333,_plus13) {
var $z23372338 = D;
var $f23432344 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("unbound-type-id"),anf_arg3042333):R.ffi.throwNonFunApp(L[123],_plus13,[("unbound-type-id"),anf_arg3042333]);
};
try {
if(--R.GAS > 0) {
$z23372338 = $f23432344();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23432344,
"from":L[123]});
}
} catch($e23352336) {
if(R.isCont($e23352336)) {
var $ss23392340 = {"from":L[123],
"go":function(ann_DASH_check_DASH_temp3002345) {
return $Hann_DASH_check_DASH_temp8712346(ann_DASH_check_DASH_temp3002345);
}};
$e23352336.stack[R.EXN_STACKHEIGHT++] = $ss23392340;
}
if(R.isPyretException($e23352336)) {
$e23352336.pyretStack.push(L[123]);
}
throw $e23352336;
}
var $ret23412342 = $Hann_DASH_check_DASH_temp8712346($z23372338);
++R.GAS;
return $ret23412342;
};
var $Hann_DASH_check_DASH_temp8712346 = function(ann_DASH_check_DASH_temp3002345) {
return ann_DASH_check_DASH_temp3002345;
};
var $Hcont_tail_arg8692347 = function(cont_tail_arg2972348,if_helper2892349) {
if(--R.GAS > 0) {
$z23502351 = R.isFunction(if_helper2892349)?if_helper2892349.app(cont_tail_arg2972348):R.ffi.throwNonFunApp(L[123],if_helper2892349,[cont_tail_arg2972348]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2892349)?if_helper2892349.app(cont_tail_arg2972348):R.ffi.throwNonFunApp(L[123],if_helper2892349,[cont_tail_arg2972348]);
},
"from":L[123]});
}
++R.GAS;
return $z23502351;
};
var $Hcont_tail_arg8702352 = function(cont_tail_arg2942353,if_helper2892349) {
if(--R.GAS > 0) {
$z23542355 = R.isFunction(if_helper2892349)?if_helper2892349.app(cont_tail_arg2942353):R.ffi.throwNonFunApp(L[123],if_helper2892349,[cont_tail_arg2942353]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2892349)?if_helper2892349.app(cont_tail_arg2942353):R.ffi.throwNonFunApp(L[123],if_helper2892349,[cont_tail_arg2942353]);
},
"from":L[123]});
}
++R.GAS;
return $z23542355;
};
var $Hanf_arg8682356 = function(anf_arg2832357,self1552358,_plus13,tostring18) {
var $z23612362 = D;
var $f23672368 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2832357,(" at ")):R.ffi.throwNonFunApp(L[124],_plus13,[anf_arg2832357,(" at ")]);
};
try {
if(--R.GAS > 0) {
$z23612362 = $f23672368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23672368,
"from":L[124]});
}
} catch($e23592360) {
if(R.isCont($e23592360)) {
var $ss23632364 = {"from":L[124],
"go":function(anf_arg2842369) {
return $Hanf_arg8672370(anf_arg2842369,self1552358,_plus13,tostring18);
}};
$e23592360.stack[R.EXN_STACKHEIGHT++] = $ss23632364;
}
if(R.isPyretException($e23592360)) {
$e23592360.pyretStack.push(L[124]);
}
throw $e23592360;
}
var $ret23652366 = $Hanf_arg8672370($z23612362,self1552358,_plus13,tostring18);
++R.GAS;
return $ret23652366;
};
var $Hanf_arg8672370 = function(anf_arg2842369,self1552358,_plus13,tostring18) {
var anf_arg2852381 = G(self1552358,"loc",L[126]);
var $z23732374 = D;
var $f23792380 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg2852381):R.ffi.throwNonFunApp(L[125],tostring18,[anf_arg2852381]);
};
try {
if(--R.GAS > 0) {
$z23732374 = $f23792380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23792380,
"from":L[125]});
}
} catch($e23712372) {
if(R.isCont($e23712372)) {
var $ss23752376 = {"from":L[125],
"go":function(anf_arg2862382) {
return $Hanf_arg8662383(anf_arg2862382,anf_arg2842369,_plus13);
}};
$e23712372.stack[R.EXN_STACKHEIGHT++] = $ss23752376;
}
if(R.isPyretException($e23712372)) {
$e23712372.pyretStack.push(L[125]);
}
throw $e23712372;
}
var $ret23772378 = $Hanf_arg8662383($z23732374,anf_arg2842369,_plus13);
++R.GAS;
return $ret23772378;
};
var $Hanf_arg8662383 = function(anf_arg2862382,anf_arg2842369,_plus13) {
var $z23862387 = D;
var $f23922393 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2842369,anf_arg2862382):R.ffi.throwNonFunApp(L[127],_plus13,[anf_arg2842369,anf_arg2862382]);
};
try {
if(--R.GAS > 0) {
$z23862387 = $f23922393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23922393,
"from":L[127]});
}
} catch($e23842385) {
if(R.isCont($e23842385)) {
var $ss23882389 = {"from":L[127],
"go":function(ann_DASH_check_DASH_temp2812394) {
return $Hann_DASH_check_DASH_temp8652395(ann_DASH_check_DASH_temp2812394);
}};
$e23842385.stack[R.EXN_STACKHEIGHT++] = $ss23882389;
}
if(R.isPyretException($e23842385)) {
$e23842385.pyretStack.push(L[127]);
}
throw $e23842385;
}
var $ret23902391 = $Hann_DASH_check_DASH_temp8652395($z23862387);
++R.GAS;
return $ret23902391;
};
var $Hann_DASH_check_DASH_temp8652395 = function(ann_DASH_check_DASH_temp2812394) {
return ann_DASH_check_DASH_temp2812394;
};
var $Hanf_arg8642396 = function(anf_arg2732397,self652398,_plus13,torepr17) {
var anf_arg2742409 = G(self652398,"loc",L[128]);
var $z24012402 = D;
var $f24072408 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg2742409):R.ffi.throwNonFunApp(L[128],torepr17,[anf_arg2742409]);
};
try {
if(--R.GAS > 0) {
$z24012402 = $f24072408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24072408,
"from":L[128]});
}
} catch($e23992400) {
if(R.isCont($e23992400)) {
var $ss24032404 = {"from":L[128],
"go":function(anf_arg2752410) {
return $Hanf_arg8632411(anf_arg2752410,anf_arg2732397,_plus13);
}};
$e23992400.stack[R.EXN_STACKHEIGHT++] = $ss24032404;
}
if(R.isPyretException($e23992400)) {
$e23992400.pyretStack.push(L[128]);
}
throw $e23992400;
}
var $ret24052406 = $Hanf_arg8632411($z24012402,anf_arg2732397,_plus13);
++R.GAS;
return $ret24052406;
};
var $Hanf_arg8632411 = function(anf_arg2752410,anf_arg2732397,_plus13) {
var $z24142415 = D;
var $f24202421 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg2752410):R.ffi.throwNonFunApp(L[128],_plus13,[(", "),anf_arg2752410]);
};
try {
if(--R.GAS > 0) {
$z24142415 = $f24202421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24202421,
"from":L[128]});
}
} catch($e24122413) {
if(R.isCont($e24122413)) {
var $ss24162417 = {"from":L[128],
"go":function(anf_arg2762422) {
return $Hanf_arg8622423(anf_arg2762422,anf_arg2732397,_plus13);
}};
$e24122413.stack[R.EXN_STACKHEIGHT++] = $ss24162417;
}
if(R.isPyretException($e24122413)) {
$e24122413.pyretStack.push(L[128]);
}
throw $e24122413;
}
var $ret24182419 = $Hanf_arg8622423($z24142415,anf_arg2732397,_plus13);
++R.GAS;
return $ret24182419;
};
var $Hanf_arg8622423 = function(anf_arg2762422,anf_arg2732397,_plus13) {
var $z24262427 = D;
var $f24322433 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2732397,anf_arg2762422):R.ffi.throwNonFunApp(L[128],_plus13,[anf_arg2732397,anf_arg2762422]);
};
try {
if(--R.GAS > 0) {
$z24262427 = $f24322433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24322433,
"from":L[128]});
}
} catch($e24242425) {
if(R.isCont($e24242425)) {
var $ss24282429 = {"from":L[128],
"go":function(anf_arg2772434) {
return $Hanf_arg8612435(anf_arg2772434,_plus13);
}};
$e24242425.stack[R.EXN_STACKHEIGHT++] = $ss24282429;
}
if(R.isPyretException($e24242425)) {
$e24242425.pyretStack.push(L[128]);
}
throw $e24242425;
}
var $ret24302431 = $Hanf_arg8612435($z24262427,_plus13);
++R.GAS;
return $ret24302431;
};
var $Hanf_arg8612435 = function(anf_arg2772434,_plus13) {
var $z24382439 = D;
var $f24442445 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2772434,(")")):R.ffi.throwNonFunApp(L[128],_plus13,[anf_arg2772434,(")")]);
};
try {
if(--R.GAS > 0) {
$z24382439 = $f24442445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24442445,
"from":L[128]});
}
} catch($e24362437) {
if(R.isCont($e24362437)) {
var $ss24402441 = {"from":L[128],
"go":function(anf_arg2782446) {
return $Hanf_arg8602447(anf_arg2782446,_plus13);
}};
$e24362437.stack[R.EXN_STACKHEIGHT++] = $ss24402441;
}
if(R.isPyretException($e24362437)) {
$e24362437.pyretStack.push(L[128]);
}
throw $e24362437;
}
var $ret24422443 = $Hanf_arg8602447($z24382439,_plus13);
++R.GAS;
return $ret24422443;
};
var $Hanf_arg8602447 = function(anf_arg2782446,_plus13) {
var $z24502451 = D;
var $f24562457 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg2782446):R.ffi.throwNonFunApp(L[128],_plus13,[("("),anf_arg2782446]);
};
try {
if(--R.GAS > 0) {
$z24502451 = $f24562457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24562457,
"from":L[128]});
}
} catch($e24482449) {
if(R.isCont($e24482449)) {
var $ss24522453 = {"from":L[128],
"go":function(anf_arg2792458) {
return $Hanf_arg8592459(anf_arg2792458,_plus13);
}};
$e24482449.stack[R.EXN_STACKHEIGHT++] = $ss24522453;
}
if(R.isPyretException($e24482449)) {
$e24482449.pyretStack.push(L[128]);
}
throw $e24482449;
}
var $ret24542455 = $Hanf_arg8592459($z24502451,_plus13);
++R.GAS;
return $ret24542455;
};
var $Hanf_arg8592459 = function(anf_arg2792458,_plus13) {
var $z24622463 = D;
var $f24682469 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("unbound-var"),anf_arg2792458):R.ffi.throwNonFunApp(L[128],_plus13,[("unbound-var"),anf_arg2792458]);
};
try {
if(--R.GAS > 0) {
$z24622463 = $f24682469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24682469,
"from":L[128]});
}
} catch($e24602461) {
if(R.isCont($e24602461)) {
var $ss24642465 = {"from":L[128],
"go":function(ann_DASH_check_DASH_temp2712470) {
return $Hann_DASH_check_DASH_temp8582471(ann_DASH_check_DASH_temp2712470);
}};
$e24602461.stack[R.EXN_STACKHEIGHT++] = $ss24642465;
}
if(R.isPyretException($e24602461)) {
$e24602461.pyretStack.push(L[128]);
}
throw $e24602461;
}
var $ret24662467 = $Hann_DASH_check_DASH_temp8582471($z24622463);
++R.GAS;
return $ret24662467;
};
var $Hann_DASH_check_DASH_temp8582471 = function(ann_DASH_check_DASH_temp2712470) {
return ann_DASH_check_DASH_temp2712470;
};
var $Hcont_tail_arg8562472 = function(cont_tail_arg2682473,if_helper2592474) {
if(--R.GAS > 0) {
$z24752476 = R.isFunction(if_helper2592474)?if_helper2592474.app(cont_tail_arg2682473):R.ffi.throwNonFunApp(L[128],if_helper2592474,[cont_tail_arg2682473]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2592474)?if_helper2592474.app(cont_tail_arg2682473):R.ffi.throwNonFunApp(L[128],if_helper2592474,[cont_tail_arg2682473]);
},
"from":L[128]});
}
++R.GAS;
return $z24752476;
};
var $Hcont_tail_arg8572477 = function(cont_tail_arg2642478,if_helper2592474) {
if(--R.GAS > 0) {
$z24792480 = R.isFunction(if_helper2592474)?if_helper2592474.app(cont_tail_arg2642478):R.ffi.throwNonFunApp(L[128],if_helper2592474,[cont_tail_arg2642478]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2592474)?if_helper2592474.app(cont_tail_arg2642478):R.ffi.throwNonFunApp(L[128],if_helper2592474,[cont_tail_arg2642478]);
},
"from":L[128]});
}
++R.GAS;
return $z24792480;
};
var $Hanf_arg8552481 = function(anf_arg2502482,self1522483,_plus13,tostring18) {
var $z24862487 = D;
var $f24922493 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Identifier "),anf_arg2502482):R.ffi.throwNonFunApp(L[129],_plus13,[("Identifier "),anf_arg2502482]);
};
try {
if(--R.GAS > 0) {
$z24862487 = $f24922493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24922493,
"from":L[129]});
}
} catch($e24842485) {
if(R.isCont($e24842485)) {
var $ss24882489 = {"from":L[129],
"go":function(anf_arg2512494) {
return $Hanf_arg8542495(anf_arg2512494,self1522483,_plus13,tostring18);
}};
$e24842485.stack[R.EXN_STACKHEIGHT++] = $ss24882489;
}
if(R.isPyretException($e24842485)) {
$e24842485.pyretStack.push(L[129]);
}
throw $e24842485;
}
var $ret24902491 = $Hanf_arg8542495($z24862487,self1522483,_plus13,tostring18);
++R.GAS;
return $ret24902491;
};
var $Hanf_arg8542495 = function(anf_arg2512494,self1522483,_plus13,tostring18) {
var $z24982499 = D;
var $f25042505 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2512494,(" is used at ")):R.ffi.throwNonFunApp(L[129],_plus13,[anf_arg2512494,(" is used at ")]);
};
try {
if(--R.GAS > 0) {
$z24982499 = $f25042505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25042505,
"from":L[129]});
}
} catch($e24962497) {
if(R.isCont($e24962497)) {
var $ss25002501 = {"from":L[129],
"go":function(anf_arg2522506) {
return $Hanf_arg8532507(anf_arg2522506,self1522483,_plus13,tostring18);
}};
$e24962497.stack[R.EXN_STACKHEIGHT++] = $ss25002501;
}
if(R.isPyretException($e24962497)) {
$e24962497.pyretStack.push(L[129]);
}
throw $e24962497;
}
var $ret25022503 = $Hanf_arg8532507($z24982499,self1522483,_plus13,tostring18);
++R.GAS;
return $ret25022503;
};
var $Hanf_arg8532507 = function(anf_arg2522506,self1522483,_plus13,tostring18) {
var anf_bracket2532521 = G(self1522483,"id",L[132]);
var anf_arg2542518 = G(anf_bracket2532521,"l",L[131]);
var $z25102511 = D;
var $f25162517 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg2542518):R.ffi.throwNonFunApp(L[130],tostring18,[anf_arg2542518]);
};
try {
if(--R.GAS > 0) {
$z25102511 = $f25162517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25162517,
"from":L[130]});
}
} catch($e25082509) {
if(R.isCont($e25082509)) {
var $ss25122513 = {"from":L[130],
"go":function(anf_arg2552519) {
return $Hanf_arg8522520(anf_arg2552519,anf_arg2522506,_plus13);
}};
$e25082509.stack[R.EXN_STACKHEIGHT++] = $ss25122513;
}
if(R.isPyretException($e25082509)) {
$e25082509.pyretStack.push(L[130]);
}
throw $e25082509;
}
var $ret25142515 = $Hanf_arg8522520($z25102511,anf_arg2522506,_plus13);
++R.GAS;
return $ret25142515;
};
var $Hanf_arg8522520 = function(anf_arg2552519,anf_arg2522506,_plus13) {
var $z25242525 = D;
var $f25302531 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2522506,anf_arg2552519):R.ffi.throwNonFunApp(L[129],_plus13,[anf_arg2522506,anf_arg2552519]);
};
try {
if(--R.GAS > 0) {
$z25242525 = $f25302531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25302531,
"from":L[129]});
}
} catch($e25222523) {
if(R.isCont($e25222523)) {
var $ss25262527 = {"from":L[129],
"go":function(anf_arg2562532) {
return $Hanf_arg8512533(anf_arg2562532,_plus13);
}};
$e25222523.stack[R.EXN_STACKHEIGHT++] = $ss25262527;
}
if(R.isPyretException($e25222523)) {
$e25222523.pyretStack.push(L[129]);
}
throw $e25222523;
}
var $ret25282529 = $Hanf_arg8512533($z25242525,_plus13);
++R.GAS;
return $ret25282529;
};
var $Hanf_arg8512533 = function(anf_arg2562532,_plus13) {
var $z25362537 = D;
var $f25422543 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2562532,(", but is not defined")):R.ffi.throwNonFunApp(L[133],_plus13,[anf_arg2562532,(", but is not defined")]);
};
try {
if(--R.GAS > 0) {
$z25362537 = $f25422543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25422543,
"from":L[133]});
}
} catch($e25342535) {
if(R.isCont($e25342535)) {
var $ss25382539 = {"from":L[133],
"go":function(ann_DASH_check_DASH_temp2472544) {
return $Hann_DASH_check_DASH_temp8502545(ann_DASH_check_DASH_temp2472544);
}};
$e25342535.stack[R.EXN_STACKHEIGHT++] = $ss25382539;
}
if(R.isPyretException($e25342535)) {
$e25342535.pyretStack.push(L[133]);
}
throw $e25342535;
}
var $ret25402541 = $Hann_DASH_check_DASH_temp8502545($z25362537);
++R.GAS;
return $ret25402541;
};
var $Hann_DASH_check_DASH_temp8502545 = function(ann_DASH_check_DASH_temp2472544) {
return ann_DASH_check_DASH_temp2472544;
};
var $Hanf_arg8492546 = function(anf_arg2432547,_plus13) {
var $z25502551 = D;
var $f25562557 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2432547,(")")):R.ffi.throwNonFunApp(L[134],_plus13,[anf_arg2432547,(")")]);
};
try {
if(--R.GAS > 0) {
$z25502551 = $f25562557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25562557,
"from":L[134]});
}
} catch($e25482549) {
if(R.isCont($e25482549)) {
var $ss25522553 = {"from":L[134],
"go":function(anf_arg2442558) {
return $Hanf_arg8482559(anf_arg2442558,_plus13);
}};
$e25482549.stack[R.EXN_STACKHEIGHT++] = $ss25522553;
}
if(R.isPyretException($e25482549)) {
$e25482549.pyretStack.push(L[134]);
}
throw $e25482549;
}
var $ret25542555 = $Hanf_arg8482559($z25502551,_plus13);
++R.GAS;
return $ret25542555;
};
var $Hanf_arg8482559 = function(anf_arg2442558,_plus13) {
var $z25622563 = D;
var $f25682569 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg2442558):R.ffi.throwNonFunApp(L[134],_plus13,[("("),anf_arg2442558]);
};
try {
if(--R.GAS > 0) {
$z25622563 = $f25682569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25682569,
"from":L[134]});
}
} catch($e25602561) {
if(R.isCont($e25602561)) {
var $ss25642565 = {"from":L[134],
"go":function(anf_arg2452570) {
return $Hanf_arg8472571(anf_arg2452570,_plus13);
}};
$e25602561.stack[R.EXN_STACKHEIGHT++] = $ss25642565;
}
if(R.isPyretException($e25602561)) {
$e25602561.pyretStack.push(L[134]);
}
throw $e25602561;
}
var $ret25662567 = $Hanf_arg8472571($z25622563,_plus13);
++R.GAS;
return $ret25662567;
};
var $Hanf_arg8472571 = function(anf_arg2452570,_plus13) {
var $z25742575 = D;
var $f25802581 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("unbound-id"),anf_arg2452570):R.ffi.throwNonFunApp(L[134],_plus13,[("unbound-id"),anf_arg2452570]);
};
try {
if(--R.GAS > 0) {
$z25742575 = $f25802581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25802581,
"from":L[134]});
}
} catch($e25722573) {
if(R.isCont($e25722573)) {
var $ss25762577 = {"from":L[134],
"go":function(ann_DASH_check_DASH_temp2412582) {
return $Hann_DASH_check_DASH_temp8462583(ann_DASH_check_DASH_temp2412582);
}};
$e25722573.stack[R.EXN_STACKHEIGHT++] = $ss25762577;
}
if(R.isPyretException($e25722573)) {
$e25722573.pyretStack.push(L[134]);
}
throw $e25722573;
}
var $ret25782579 = $Hann_DASH_check_DASH_temp8462583($z25742575);
++R.GAS;
return $ret25782579;
};
var $Hann_DASH_check_DASH_temp8462583 = function(ann_DASH_check_DASH_temp2412582) {
return ann_DASH_check_DASH_temp2412582;
};
var $Hcont_tail_arg8442584 = function(cont_tail_arg2382585,if_helper2302586) {
if(--R.GAS > 0) {
$z25872588 = R.isFunction(if_helper2302586)?if_helper2302586.app(cont_tail_arg2382585):R.ffi.throwNonFunApp(L[134],if_helper2302586,[cont_tail_arg2382585]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2302586)?if_helper2302586.app(cont_tail_arg2382585):R.ffi.throwNonFunApp(L[134],if_helper2302586,[cont_tail_arg2382585]);
},
"from":L[134]});
}
++R.GAS;
return $z25872588;
};
var $Hcont_tail_arg8452589 = function(cont_tail_arg2352590,if_helper2302586) {
if(--R.GAS > 0) {
$z25912592 = R.isFunction(if_helper2302586)?if_helper2302586.app(cont_tail_arg2352590):R.ffi.throwNonFunApp(L[134],if_helper2302586,[cont_tail_arg2352590]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2302586)?if_helper2302586.app(cont_tail_arg2352590):R.ffi.throwNonFunApp(L[134],if_helper2302586,[cont_tail_arg2352590]);
},
"from":L[134]});
}
++R.GAS;
return $z25912592;
};
var $Hanf_arg8432593 = function(anf_arg2232594,self1502595,_plus13,tostring18) {
var $z25982599 = D;
var $f26042605 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("well-formedness: fraction literal with zero denominator (numerator was "),anf_arg2232594):R.ffi.throwNonFunApp(L[135],_plus13,[("well-formedness: fraction literal with zero denominator (numerator was "),anf_arg2232594]);
};
try {
if(--R.GAS > 0) {
$z25982599 = $f26042605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26042605,
"from":L[135]});
}
} catch($e25962597) {
if(R.isCont($e25962597)) {
var $ss26002601 = {"from":L[135],
"go":function(anf_arg2242606) {
return $Hanf_arg8422607(anf_arg2242606,self1502595,_plus13,tostring18);
}};
$e25962597.stack[R.EXN_STACKHEIGHT++] = $ss26002601;
}
if(R.isPyretException($e25962597)) {
$e25962597.pyretStack.push(L[135]);
}
throw $e25962597;
}
var $ret26022603 = $Hanf_arg8422607($z25982599,self1502595,_plus13,tostring18);
++R.GAS;
return $ret26022603;
};
var $Hanf_arg8422607 = function(anf_arg2242606,self1502595,_plus13,tostring18) {
var $z26102611 = D;
var $f26162617 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2242606,(" at ")):R.ffi.throwNonFunApp(L[135],_plus13,[anf_arg2242606,(" at ")]);
};
try {
if(--R.GAS > 0) {
$z26102611 = $f26162617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26162617,
"from":L[135]});
}
} catch($e26082609) {
if(R.isCont($e26082609)) {
var $ss26122613 = {"from":L[135],
"go":function(anf_arg2252618) {
return $Hanf_arg8412619(anf_arg2252618,self1502595,_plus13,tostring18);
}};
$e26082609.stack[R.EXN_STACKHEIGHT++] = $ss26122613;
}
if(R.isPyretException($e26082609)) {
$e26082609.pyretStack.push(L[135]);
}
throw $e26082609;
}
var $ret26142615 = $Hanf_arg8412619($z26102611,self1502595,_plus13,tostring18);
++R.GAS;
return $ret26142615;
};
var $Hanf_arg8412619 = function(anf_arg2252618,self1502595,_plus13,tostring18) {
var anf_arg2262630 = G(self1502595,"loc",L[137]);
var $z26222623 = D;
var $f26282629 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg2262630):R.ffi.throwNonFunApp(L[136],tostring18,[anf_arg2262630]);
};
try {
if(--R.GAS > 0) {
$z26222623 = $f26282629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26282629,
"from":L[136]});
}
} catch($e26202621) {
if(R.isCont($e26202621)) {
var $ss26242625 = {"from":L[136],
"go":function(anf_arg2272631) {
return $Hanf_arg8402632(anf_arg2272631,anf_arg2252618,_plus13);
}};
$e26202621.stack[R.EXN_STACKHEIGHT++] = $ss26242625;
}
if(R.isPyretException($e26202621)) {
$e26202621.pyretStack.push(L[136]);
}
throw $e26202621;
}
var $ret26262627 = $Hanf_arg8402632($z26222623,anf_arg2252618,_plus13);
++R.GAS;
return $ret26262627;
};
var $Hanf_arg8402632 = function(anf_arg2272631,anf_arg2252618,_plus13) {
var $z26352636 = D;
var $f26412642 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2252618,anf_arg2272631):R.ffi.throwNonFunApp(L[138],_plus13,[anf_arg2252618,anf_arg2272631]);
};
try {
if(--R.GAS > 0) {
$z26352636 = $f26412642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26412642,
"from":L[138]});
}
} catch($e26332634) {
if(R.isCont($e26332634)) {
var $ss26372638 = {"from":L[138],
"go":function(ann_DASH_check_DASH_temp2212643) {
return $Hann_DASH_check_DASH_temp8392644(ann_DASH_check_DASH_temp2212643);
}};
$e26332634.stack[R.EXN_STACKHEIGHT++] = $ss26372638;
}
if(R.isPyretException($e26332634)) {
$e26332634.pyretStack.push(L[138]);
}
throw $e26332634;
}
var $ret26392640 = $Hann_DASH_check_DASH_temp8392644($z26352636);
++R.GAS;
return $ret26392640;
};
var $Hann_DASH_check_DASH_temp8392644 = function(ann_DASH_check_DASH_temp2212643) {
return ann_DASH_check_DASH_temp2212643;
};
var $Hanf_arg8382645 = function(anf_arg2132646,self532647,_plus13,torepr17) {
var anf_arg2142658 = G(self532647,"numerator",L[139]);
var $z26502651 = D;
var $f26562657 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg2142658):R.ffi.throwNonFunApp(L[139],torepr17,[anf_arg2142658]);
};
try {
if(--R.GAS > 0) {
$z26502651 = $f26562657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26562657,
"from":L[139]});
}
} catch($e26482649) {
if(R.isCont($e26482649)) {
var $ss26522653 = {"from":L[139],
"go":function(anf_arg2152659) {
return $Hanf_arg8372660(anf_arg2152659,anf_arg2132646,_plus13);
}};
$e26482649.stack[R.EXN_STACKHEIGHT++] = $ss26522653;
}
if(R.isPyretException($e26482649)) {
$e26482649.pyretStack.push(L[139]);
}
throw $e26482649;
}
var $ret26542655 = $Hanf_arg8372660($z26502651,anf_arg2132646,_plus13);
++R.GAS;
return $ret26542655;
};
var $Hanf_arg8372660 = function(anf_arg2152659,anf_arg2132646,_plus13) {
var $z26632664 = D;
var $f26692670 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg2152659):R.ffi.throwNonFunApp(L[139],_plus13,[(", "),anf_arg2152659]);
};
try {
if(--R.GAS > 0) {
$z26632664 = $f26692670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26692670,
"from":L[139]});
}
} catch($e26612662) {
if(R.isCont($e26612662)) {
var $ss26652666 = {"from":L[139],
"go":function(anf_arg2162671) {
return $Hanf_arg8362672(anf_arg2162671,anf_arg2132646,_plus13);
}};
$e26612662.stack[R.EXN_STACKHEIGHT++] = $ss26652666;
}
if(R.isPyretException($e26612662)) {
$e26612662.pyretStack.push(L[139]);
}
throw $e26612662;
}
var $ret26672668 = $Hanf_arg8362672($z26632664,anf_arg2132646,_plus13);
++R.GAS;
return $ret26672668;
};
var $Hanf_arg8362672 = function(anf_arg2162671,anf_arg2132646,_plus13) {
var $z26752676 = D;
var $f26812682 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2132646,anf_arg2162671):R.ffi.throwNonFunApp(L[139],_plus13,[anf_arg2132646,anf_arg2162671]);
};
try {
if(--R.GAS > 0) {
$z26752676 = $f26812682();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26812682,
"from":L[139]});
}
} catch($e26732674) {
if(R.isCont($e26732674)) {
var $ss26772678 = {"from":L[139],
"go":function(anf_arg2172683) {
return $Hanf_arg8352684(anf_arg2172683,_plus13);
}};
$e26732674.stack[R.EXN_STACKHEIGHT++] = $ss26772678;
}
if(R.isPyretException($e26732674)) {
$e26732674.pyretStack.push(L[139]);
}
throw $e26732674;
}
var $ret26792680 = $Hanf_arg8352684($z26752676,_plus13);
++R.GAS;
return $ret26792680;
};
var $Hanf_arg8352684 = function(anf_arg2172683,_plus13) {
var $z26872688 = D;
var $f26932694 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg2172683,(")")):R.ffi.throwNonFunApp(L[139],_plus13,[anf_arg2172683,(")")]);
};
try {
if(--R.GAS > 0) {
$z26872688 = $f26932694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26932694,
"from":L[139]});
}
} catch($e26852686) {
if(R.isCont($e26852686)) {
var $ss26892690 = {"from":L[139],
"go":function(anf_arg2182695) {
return $Hanf_arg8342696(anf_arg2182695,_plus13);
}};
$e26852686.stack[R.EXN_STACKHEIGHT++] = $ss26892690;
}
if(R.isPyretException($e26852686)) {
$e26852686.pyretStack.push(L[139]);
}
throw $e26852686;
}
var $ret26912692 = $Hanf_arg8342696($z26872688,_plus13);
++R.GAS;
return $ret26912692;
};
var $Hanf_arg8342696 = function(anf_arg2182695,_plus13) {
var $z26992700 = D;
var $f27052706 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg2182695):R.ffi.throwNonFunApp(L[139],_plus13,[("("),anf_arg2182695]);
};
try {
if(--R.GAS > 0) {
$z26992700 = $f27052706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27052706,
"from":L[139]});
}
} catch($e26972698) {
if(R.isCont($e26972698)) {
var $ss27012702 = {"from":L[139],
"go":function(anf_arg2192707) {
return $Hanf_arg8332708(anf_arg2192707,_plus13);
}};
$e26972698.stack[R.EXN_STACKHEIGHT++] = $ss27012702;
}
if(R.isPyretException($e26972698)) {
$e26972698.pyretStack.push(L[139]);
}
throw $e26972698;
}
var $ret27032704 = $Hanf_arg8332708($z26992700,_plus13);
++R.GAS;
return $ret27032704;
};
var $Hanf_arg8332708 = function(anf_arg2192707,_plus13) {
var $z27112712 = D;
var $f27172718 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("zero-fraction"),anf_arg2192707):R.ffi.throwNonFunApp(L[139],_plus13,[("zero-fraction"),anf_arg2192707]);
};
try {
if(--R.GAS > 0) {
$z27112712 = $f27172718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27172718,
"from":L[139]});
}
} catch($e27092710) {
if(R.isCont($e27092710)) {
var $ss27132714 = {"from":L[139],
"go":function(ann_DASH_check_DASH_temp2112719) {
return $Hann_DASH_check_DASH_temp8322720(ann_DASH_check_DASH_temp2112719);
}};
$e27092710.stack[R.EXN_STACKHEIGHT++] = $ss27132714;
}
if(R.isPyretException($e27092710)) {
$e27092710.pyretStack.push(L[139]);
}
throw $e27092710;
}
var $ret27152716 = $Hann_DASH_check_DASH_temp8322720($z27112712);
++R.GAS;
return $ret27152716;
};
var $Hann_DASH_check_DASH_temp8322720 = function(ann_DASH_check_DASH_temp2112719) {
return ann_DASH_check_DASH_temp2112719;
};
var $Hcont_tail_arg8302721 = function(cont_tail_arg2082722,if_helper1992723) {
if(--R.GAS > 0) {
$z27242725 = R.isFunction(if_helper1992723)?if_helper1992723.app(cont_tail_arg2082722):R.ffi.throwNonFunApp(L[139],if_helper1992723,[cont_tail_arg2082722]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1992723)?if_helper1992723.app(cont_tail_arg2082722):R.ffi.throwNonFunApp(L[139],if_helper1992723,[cont_tail_arg2082722]);
},
"from":L[139]});
}
++R.GAS;
return $z27242725;
};
var $Hcont_tail_arg8312726 = function(cont_tail_arg2042727,if_helper1992723) {
if(--R.GAS > 0) {
$z27282729 = R.isFunction(if_helper1992723)?if_helper1992723.app(cont_tail_arg2042727):R.ffi.throwNonFunApp(L[139],if_helper1992723,[cont_tail_arg2042727]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1992723)?if_helper1992723.app(cont_tail_arg2042727):R.ffi.throwNonFunApp(L[139],if_helper1992723,[cont_tail_arg2042727]);
},
"from":L[139]});
}
++R.GAS;
return $z27282729;
};
var $Hanf_arg8292730 = function(anf_arg1932731,self1472732,_plus13,tostring18) {
var $z27352736 = D;
var $f27412742 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1932731,(" as an identifier at ")):R.ffi.throwNonFunApp(L[140],_plus13,[anf_arg1932731,(" as an identifier at ")]);
};
try {
if(--R.GAS > 0) {
$z27352736 = $f27412742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27412742,
"from":L[140]});
}
} catch($e27332734) {
if(R.isCont($e27332734)) {
var $ss27372738 = {"from":L[140],
"go":function(anf_arg1942743) {
return $Hanf_arg8282744(anf_arg1942743,self1472732,_plus13,tostring18);
}};
$e27332734.stack[R.EXN_STACKHEIGHT++] = $ss27372738;
}
if(R.isPyretException($e27332734)) {
$e27332734.pyretStack.push(L[140]);
}
throw $e27332734;
}
var $ret27392740 = $Hanf_arg8282744($z27352736,self1472732,_plus13,tostring18);
++R.GAS;
return $ret27392740;
};
var $Hanf_arg8282744 = function(anf_arg1942743,self1472732,_plus13,tostring18) {
var anf_arg1952755 = G(self1472732,"loc",L[142]);
var $z27472748 = D;
var $f27532754 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg1952755):R.ffi.throwNonFunApp(L[141],tostring18,[anf_arg1952755]);
};
try {
if(--R.GAS > 0) {
$z27472748 = $f27532754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27532754,
"from":L[141]});
}
} catch($e27452746) {
if(R.isCont($e27452746)) {
var $ss27492750 = {"from":L[141],
"go":function(anf_arg1962756) {
return $Hanf_arg8272757(anf_arg1962756,anf_arg1942743,_plus13);
}};
$e27452746.stack[R.EXN_STACKHEIGHT++] = $ss27492750;
}
if(R.isPyretException($e27452746)) {
$e27452746.pyretStack.push(L[141]);
}
throw $e27452746;
}
var $ret27512752 = $Hanf_arg8272757($z27472748,anf_arg1942743,_plus13);
++R.GAS;
return $ret27512752;
};
var $Hanf_arg8272757 = function(anf_arg1962756,anf_arg1942743,_plus13) {
var $z27602761 = D;
var $f27662767 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1942743,anf_arg1962756):R.ffi.throwNonFunApp(L[143],_plus13,[anf_arg1942743,anf_arg1962756]);
};
try {
if(--R.GAS > 0) {
$z27602761 = $f27662767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27662767,
"from":L[143]});
}
} catch($e27582759) {
if(R.isCont($e27582759)) {
var $ss27622763 = {"from":L[143],
"go":function(ann_DASH_check_DASH_temp1912768) {
return $Hann_DASH_check_DASH_temp8262769(ann_DASH_check_DASH_temp1912768);
}};
$e27582759.stack[R.EXN_STACKHEIGHT++] = $ss27622763;
}
if(R.isPyretException($e27582759)) {
$e27582759.pyretStack.push(L[143]);
}
throw $e27582759;
}
var $ret27642765 = $Hann_DASH_check_DASH_temp8262769($z27602761);
++R.GAS;
return $ret27642765;
};
var $Hann_DASH_check_DASH_temp8262769 = function(ann_DASH_check_DASH_temp1912768) {
return ann_DASH_check_DASH_temp1912768;
};
var $Hanf_arg8252770 = function(anf_arg1832771,self472772,_plus13,torepr17) {
var anf_arg1842783 = G(self472772,"id",L[144]);
var $z27752776 = D;
var $f27812782 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg1842783):R.ffi.throwNonFunApp(L[144],torepr17,[anf_arg1842783]);
};
try {
if(--R.GAS > 0) {
$z27752776 = $f27812782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27812782,
"from":L[144]});
}
} catch($e27732774) {
if(R.isCont($e27732774)) {
var $ss27772778 = {"from":L[144],
"go":function(anf_arg1852784) {
return $Hanf_arg8242785(anf_arg1852784,anf_arg1832771,_plus13);
}};
$e27732774.stack[R.EXN_STACKHEIGHT++] = $ss27772778;
}
if(R.isPyretException($e27732774)) {
$e27732774.pyretStack.push(L[144]);
}
throw $e27732774;
}
var $ret27792780 = $Hanf_arg8242785($z27752776,anf_arg1832771,_plus13);
++R.GAS;
return $ret27792780;
};
var $Hanf_arg8242785 = function(anf_arg1852784,anf_arg1832771,_plus13) {
var $z27882789 = D;
var $f27942795 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg1852784):R.ffi.throwNonFunApp(L[144],_plus13,[(", "),anf_arg1852784]);
};
try {
if(--R.GAS > 0) {
$z27882789 = $f27942795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27942795,
"from":L[144]});
}
} catch($e27862787) {
if(R.isCont($e27862787)) {
var $ss27902791 = {"from":L[144],
"go":function(anf_arg1862796) {
return $Hanf_arg8232797(anf_arg1862796,anf_arg1832771,_plus13);
}};
$e27862787.stack[R.EXN_STACKHEIGHT++] = $ss27902791;
}
if(R.isPyretException($e27862787)) {
$e27862787.pyretStack.push(L[144]);
}
throw $e27862787;
}
var $ret27922793 = $Hanf_arg8232797($z27882789,anf_arg1832771,_plus13);
++R.GAS;
return $ret27922793;
};
var $Hanf_arg8232797 = function(anf_arg1862796,anf_arg1832771,_plus13) {
var $z28002801 = D;
var $f28062807 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1832771,anf_arg1862796):R.ffi.throwNonFunApp(L[144],_plus13,[anf_arg1832771,anf_arg1862796]);
};
try {
if(--R.GAS > 0) {
$z28002801 = $f28062807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28062807,
"from":L[144]});
}
} catch($e27982799) {
if(R.isCont($e27982799)) {
var $ss28022803 = {"from":L[144],
"go":function(anf_arg1872808) {
return $Hanf_arg8222809(anf_arg1872808,_plus13);
}};
$e27982799.stack[R.EXN_STACKHEIGHT++] = $ss28022803;
}
if(R.isPyretException($e27982799)) {
$e27982799.pyretStack.push(L[144]);
}
throw $e27982799;
}
var $ret28042805 = $Hanf_arg8222809($z28002801,_plus13);
++R.GAS;
return $ret28042805;
};
var $Hanf_arg8222809 = function(anf_arg1872808,_plus13) {
var $z28122813 = D;
var $f28182819 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1872808,(")")):R.ffi.throwNonFunApp(L[144],_plus13,[anf_arg1872808,(")")]);
};
try {
if(--R.GAS > 0) {
$z28122813 = $f28182819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28182819,
"from":L[144]});
}
} catch($e28102811) {
if(R.isCont($e28102811)) {
var $ss28142815 = {"from":L[144],
"go":function(anf_arg1882820) {
return $Hanf_arg8212821(anf_arg1882820,_plus13);
}};
$e28102811.stack[R.EXN_STACKHEIGHT++] = $ss28142815;
}
if(R.isPyretException($e28102811)) {
$e28102811.pyretStack.push(L[144]);
}
throw $e28102811;
}
var $ret28162817 = $Hanf_arg8212821($z28122813,_plus13);
++R.GAS;
return $ret28162817;
};
var $Hanf_arg8212821 = function(anf_arg1882820,_plus13) {
var $z28242825 = D;
var $f28302831 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg1882820):R.ffi.throwNonFunApp(L[144],_plus13,[("("),anf_arg1882820]);
};
try {
if(--R.GAS > 0) {
$z28242825 = $f28302831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28302831,
"from":L[144]});
}
} catch($e28222823) {
if(R.isCont($e28222823)) {
var $ss28262827 = {"from":L[144],
"go":function(anf_arg1892832) {
return $Hanf_arg8202833(anf_arg1892832,_plus13);
}};
$e28222823.stack[R.EXN_STACKHEIGHT++] = $ss28262827;
}
if(R.isPyretException($e28222823)) {
$e28222823.pyretStack.push(L[144]);
}
throw $e28222823;
}
var $ret28282829 = $Hanf_arg8202833($z28242825,_plus13);
++R.GAS;
return $ret28282829;
};
var $Hanf_arg8202833 = function(anf_arg1892832,_plus13) {
var $z28362837 = D;
var $f28422843 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("reserved-name"),anf_arg1892832):R.ffi.throwNonFunApp(L[144],_plus13,[("reserved-name"),anf_arg1892832]);
};
try {
if(--R.GAS > 0) {
$z28362837 = $f28422843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28422843,
"from":L[144]});
}
} catch($e28342835) {
if(R.isCont($e28342835)) {
var $ss28382839 = {"from":L[144],
"go":function(ann_DASH_check_DASH_temp1812844) {
return $Hann_DASH_check_DASH_temp8192845(ann_DASH_check_DASH_temp1812844);
}};
$e28342835.stack[R.EXN_STACKHEIGHT++] = $ss28382839;
}
if(R.isPyretException($e28342835)) {
$e28342835.pyretStack.push(L[144]);
}
throw $e28342835;
}
var $ret28402841 = $Hann_DASH_check_DASH_temp8192845($z28362837);
++R.GAS;
return $ret28402841;
};
var $Hann_DASH_check_DASH_temp8192845 = function(ann_DASH_check_DASH_temp1812844) {
return ann_DASH_check_DASH_temp1812844;
};
var $Hcont_tail_arg8172846 = function(cont_tail_arg1782847,if_helper1692848) {
if(--R.GAS > 0) {
$z28492850 = R.isFunction(if_helper1692848)?if_helper1692848.app(cont_tail_arg1782847):R.ffi.throwNonFunApp(L[144],if_helper1692848,[cont_tail_arg1782847]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1692848)?if_helper1692848.app(cont_tail_arg1782847):R.ffi.throwNonFunApp(L[144],if_helper1692848,[cont_tail_arg1782847]);
},
"from":L[144]});
}
++R.GAS;
return $z28492850;
};
var $Hcont_tail_arg8182851 = function(cont_tail_arg1742852,if_helper1692848) {
if(--R.GAS > 0) {
$z28532854 = R.isFunction(if_helper1692848)?if_helper1692848.app(cont_tail_arg1742852):R.ffi.throwNonFunApp(L[144],if_helper1692848,[cont_tail_arg1742852]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1692848)?if_helper1692848.app(cont_tail_arg1742852):R.ffi.throwNonFunApp(L[144],if_helper1692848,[cont_tail_arg1742852]);
},
"from":L[144]});
}
++R.GAS;
return $z28532854;
};
var $Hanf_arg8162855 = function(anf_arg1602856,self1442857,_plus13,tostring18) {
var $z28602861 = D;
var $f28662867 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1602856,(" at ")):R.ffi.throwNonFunApp(L[145],_plus13,[anf_arg1602856,(" at ")]);
};
try {
if(--R.GAS > 0) {
$z28602861 = $f28662867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28662867,
"from":L[145]});
}
} catch($e28582859) {
if(R.isCont($e28582859)) {
var $ss28622863 = {"from":L[145],
"go":function(anf_arg1612868) {
return $Hanf_arg8152869(anf_arg1612868,self1442857,_plus13,tostring18);
}};
$e28582859.stack[R.EXN_STACKHEIGHT++] = $ss28622863;
}
if(R.isPyretException($e28582859)) {
$e28582859.pyretStack.push(L[145]);
}
throw $e28582859;
}
var $ret28642865 = $Hanf_arg8152869($z28602861,self1442857,_plus13,tostring18);
++R.GAS;
return $ret28642865;
};
var $Hanf_arg8152869 = function(anf_arg1612868,self1442857,_plus13,tostring18) {
var anf_bracket1622883 = G(self1442857,"loc",L[148]);
var anf_fun1632880 = G(anf_bracket1622883,"map",L[147]);
var $z28722873 = D;
var $f28782879 = function(_) {
return R.isFunction(anf_fun1632880)?anf_fun1632880.app(tostring18):R.ffi.throwNonFunApp(L[146],anf_fun1632880,[tostring18]);
};
try {
if(--R.GAS > 0) {
$z28722873 = $f28782879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28782879,
"from":L[146]});
}
} catch($e28702871) {
if(R.isCont($e28702871)) {
var $ss28742875 = {"from":L[146],
"go":function(anf_bracket1642881) {
return $Hanf_bracket8142882(anf_bracket1642881,anf_arg1612868,_plus13);
}};
$e28702871.stack[R.EXN_STACKHEIGHT++] = $ss28742875;
}
if(R.isPyretException($e28702871)) {
$e28702871.pyretStack.push(L[146]);
}
throw $e28702871;
}
var $ret28762877 = $Hanf_bracket8142882($z28722873,anf_arg1612868,_plus13);
++R.GAS;
return $ret28762877;
};
var $Hanf_bracket8142882 = function(anf_bracket1642881,anf_arg1612868,_plus13) {
var anf_fun1652894 = G(anf_bracket1642881,"join-str",L[150]);
var $z28862887 = D;
var $f28922893 = function(_) {
return R.isFunction(anf_fun1652894)?anf_fun1652894.app((", ")):R.ffi.throwNonFunApp(L[149],anf_fun1652894,[(", ")]);
};
try {
if(--R.GAS > 0) {
$z28862887 = $f28922893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28922893,
"from":L[149]});
}
} catch($e28842885) {
if(R.isCont($e28842885)) {
var $ss28882889 = {"from":L[149],
"go":function(anf_arg1662895) {
return $Hanf_arg8132896(anf_arg1662895,anf_arg1612868,_plus13);
}};
$e28842885.stack[R.EXN_STACKHEIGHT++] = $ss28882889;
}
if(R.isPyretException($e28842885)) {
$e28842885.pyretStack.push(L[149]);
}
throw $e28842885;
}
var $ret28902891 = $Hanf_arg8132896($z28862887,anf_arg1612868,_plus13);
++R.GAS;
return $ret28902891;
};
var $Hanf_arg8132896 = function(anf_arg1662895,anf_arg1612868,_plus13) {
var $z28992900 = D;
var $f29052906 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1612868,anf_arg1662895):R.ffi.throwNonFunApp(L[151],_plus13,[anf_arg1612868,anf_arg1662895]);
};
try {
if(--R.GAS > 0) {
$z28992900 = $f29052906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29052906,
"from":L[151]});
}
} catch($e28972898) {
if(R.isCont($e28972898)) {
var $ss29012902 = {"from":L[151],
"go":function(ann_DASH_check_DASH_temp1582907) {
return $Hann_DASH_check_DASH_temp8122908(ann_DASH_check_DASH_temp1582907);
}};
$e28972898.stack[R.EXN_STACKHEIGHT++] = $ss29012902;
}
if(R.isPyretException($e28972898)) {
$e28972898.pyretStack.push(L[151]);
}
throw $e28972898;
}
var $ret29032904 = $Hann_DASH_check_DASH_temp8122908($z28992900);
++R.GAS;
return $ret29032904;
};
var $Hann_DASH_check_DASH_temp8122908 = function(ann_DASH_check_DASH_temp1582907) {
return ann_DASH_check_DASH_temp1582907;
};
var $Hanf_arg8112909 = function(anf_arg1502910,self412911,_plus13,torepr17) {
var anf_arg1512922 = G(self412911,"loc",L[152]);
var $z29142915 = D;
var $f29202921 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg1512922):R.ffi.throwNonFunApp(L[152],torepr17,[anf_arg1512922]);
};
try {
if(--R.GAS > 0) {
$z29142915 = $f29202921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29202921,
"from":L[152]});
}
} catch($e29122913) {
if(R.isCont($e29122913)) {
var $ss29162917 = {"from":L[152],
"go":function(anf_arg1522923) {
return $Hanf_arg8102924(anf_arg1522923,anf_arg1502910,_plus13);
}};
$e29122913.stack[R.EXN_STACKHEIGHT++] = $ss29162917;
}
if(R.isPyretException($e29122913)) {
$e29122913.pyretStack.push(L[152]);
}
throw $e29122913;
}
var $ret29182919 = $Hanf_arg8102924($z29142915,anf_arg1502910,_plus13);
++R.GAS;
return $ret29182919;
};
var $Hanf_arg8102924 = function(anf_arg1522923,anf_arg1502910,_plus13) {
var $z29272928 = D;
var $f29332934 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg1522923):R.ffi.throwNonFunApp(L[152],_plus13,[(", "),anf_arg1522923]);
};
try {
if(--R.GAS > 0) {
$z29272928 = $f29332934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29332934,
"from":L[152]});
}
} catch($e29252926) {
if(R.isCont($e29252926)) {
var $ss29292930 = {"from":L[152],
"go":function(anf_arg1532935) {
return $Hanf_arg8092936(anf_arg1532935,anf_arg1502910,_plus13);
}};
$e29252926.stack[R.EXN_STACKHEIGHT++] = $ss29292930;
}
if(R.isPyretException($e29252926)) {
$e29252926.pyretStack.push(L[152]);
}
throw $e29252926;
}
var $ret29312932 = $Hanf_arg8092936($z29272928,anf_arg1502910,_plus13);
++R.GAS;
return $ret29312932;
};
var $Hanf_arg8092936 = function(anf_arg1532935,anf_arg1502910,_plus13) {
var $z29392940 = D;
var $f29452946 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1502910,anf_arg1532935):R.ffi.throwNonFunApp(L[152],_plus13,[anf_arg1502910,anf_arg1532935]);
};
try {
if(--R.GAS > 0) {
$z29392940 = $f29452946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29452946,
"from":L[152]});
}
} catch($e29372938) {
if(R.isCont($e29372938)) {
var $ss29412942 = {"from":L[152],
"go":function(anf_arg1542947) {
return $Hanf_arg8082948(anf_arg1542947,_plus13);
}};
$e29372938.stack[R.EXN_STACKHEIGHT++] = $ss29412942;
}
if(R.isPyretException($e29372938)) {
$e29372938.pyretStack.push(L[152]);
}
throw $e29372938;
}
var $ret29432944 = $Hanf_arg8082948($z29392940,_plus13);
++R.GAS;
return $ret29432944;
};
var $Hanf_arg8082948 = function(anf_arg1542947,_plus13) {
var $z29512952 = D;
var $f29572958 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1542947,(")")):R.ffi.throwNonFunApp(L[152],_plus13,[anf_arg1542947,(")")]);
};
try {
if(--R.GAS > 0) {
$z29512952 = $f29572958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29572958,
"from":L[152]});
}
} catch($e29492950) {
if(R.isCont($e29492950)) {
var $ss29532954 = {"from":L[152],
"go":function(anf_arg1552959) {
return $Hanf_arg8072960(anf_arg1552959,_plus13);
}};
$e29492950.stack[R.EXN_STACKHEIGHT++] = $ss29532954;
}
if(R.isPyretException($e29492950)) {
$e29492950.pyretStack.push(L[152]);
}
throw $e29492950;
}
var $ret29552956 = $Hanf_arg8072960($z29512952,_plus13);
++R.GAS;
return $ret29552956;
};
var $Hanf_arg8072960 = function(anf_arg1552959,_plus13) {
var $z29632964 = D;
var $f29692970 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg1552959):R.ffi.throwNonFunApp(L[152],_plus13,[("("),anf_arg1552959]);
};
try {
if(--R.GAS > 0) {
$z29632964 = $f29692970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29692970,
"from":L[152]});
}
} catch($e29612962) {
if(R.isCont($e29612962)) {
var $ss29652966 = {"from":L[152],
"go":function(anf_arg1562971) {
return $Hanf_arg8062972(anf_arg1562971,_plus13);
}};
$e29612962.stack[R.EXN_STACKHEIGHT++] = $ss29652966;
}
if(R.isPyretException($e29612962)) {
$e29612962.pyretStack.push(L[152]);
}
throw $e29612962;
}
var $ret29672968 = $Hanf_arg8062972($z29632964,_plus13);
++R.GAS;
return $ret29672968;
};
var $Hanf_arg8062972 = function(anf_arg1562971,_plus13) {
var $z29752976 = D;
var $f29812982 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("wf-err-split"),anf_arg1562971):R.ffi.throwNonFunApp(L[152],_plus13,[("wf-err-split"),anf_arg1562971]);
};
try {
if(--R.GAS > 0) {
$z29752976 = $f29812982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29812982,
"from":L[152]});
}
} catch($e29732974) {
if(R.isCont($e29732974)) {
var $ss29772978 = {"from":L[152],
"go":function(ann_DASH_check_DASH_temp1482983) {
return $Hann_DASH_check_DASH_temp8052984(ann_DASH_check_DASH_temp1482983);
}};
$e29732974.stack[R.EXN_STACKHEIGHT++] = $ss29772978;
}
if(R.isPyretException($e29732974)) {
$e29732974.pyretStack.push(L[152]);
}
throw $e29732974;
}
var $ret29792980 = $Hann_DASH_check_DASH_temp8052984($z29752976);
++R.GAS;
return $ret29792980;
};
var $Hann_DASH_check_DASH_temp8052984 = function(ann_DASH_check_DASH_temp1482983) {
return ann_DASH_check_DASH_temp1482983;
};
var $Hcont_tail_arg8032985 = function(cont_tail_arg1452986,if_helper1362987) {
if(--R.GAS > 0) {
$z29882989 = R.isFunction(if_helper1362987)?if_helper1362987.app(cont_tail_arg1452986):R.ffi.throwNonFunApp(L[152],if_helper1362987,[cont_tail_arg1452986]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1362987)?if_helper1362987.app(cont_tail_arg1452986):R.ffi.throwNonFunApp(L[152],if_helper1362987,[cont_tail_arg1452986]);
},
"from":L[152]});
}
++R.GAS;
return $z29882989;
};
var $Hcont_tail_arg8042990 = function(cont_tail_arg1412991,if_helper1362987) {
if(--R.GAS > 0) {
$z29922993 = R.isFunction(if_helper1362987)?if_helper1362987.app(cont_tail_arg1412991):R.ffi.throwNonFunApp(L[152],if_helper1362987,[cont_tail_arg1412991]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1362987)?if_helper1362987.app(cont_tail_arg1412991):R.ffi.throwNonFunApp(L[152],if_helper1362987,[cont_tail_arg1412991]);
},
"from":L[152]});
}
++R.GAS;
return $z29922993;
};
var $Hanf_arg8022994 = function(anf_arg1302995,self1412996,_plus13,tostring18) {
var $z29993000 = D;
var $f30053006 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1302995,(" at ")):R.ffi.throwNonFunApp(L[153],_plus13,[anf_arg1302995,(" at ")]);
};
try {
if(--R.GAS > 0) {
$z29993000 = $f30053006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30053006,
"from":L[153]});
}
} catch($e29972998) {
if(R.isCont($e29972998)) {
var $ss30013002 = {"from":L[153],
"go":function(anf_arg1313007) {
return $Hanf_arg8013008(anf_arg1313007,self1412996,_plus13,tostring18);
}};
$e29972998.stack[R.EXN_STACKHEIGHT++] = $ss30013002;
}
if(R.isPyretException($e29972998)) {
$e29972998.pyretStack.push(L[153]);
}
throw $e29972998;
}
var $ret30033004 = $Hanf_arg8013008($z29993000,self1412996,_plus13,tostring18);
++R.GAS;
return $ret30033004;
};
var $Hanf_arg8013008 = function(anf_arg1313007,self1412996,_plus13,tostring18) {
var anf_arg1323019 = G(self1412996,"loc",L[155]);
var $z30113012 = D;
var $f30173018 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg1323019):R.ffi.throwNonFunApp(L[154],tostring18,[anf_arg1323019]);
};
try {
if(--R.GAS > 0) {
$z30113012 = $f30173018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30173018,
"from":L[154]});
}
} catch($e30093010) {
if(R.isCont($e30093010)) {
var $ss30133014 = {"from":L[154],
"go":function(anf_arg1333020) {
return $Hanf_arg8003021(anf_arg1333020,anf_arg1313007,_plus13);
}};
$e30093010.stack[R.EXN_STACKHEIGHT++] = $ss30133014;
}
if(R.isPyretException($e30093010)) {
$e30093010.pyretStack.push(L[154]);
}
throw $e30093010;
}
var $ret30153016 = $Hanf_arg8003021($z30113012,anf_arg1313007,_plus13);
++R.GAS;
return $ret30153016;
};
var $Hanf_arg8003021 = function(anf_arg1333020,anf_arg1313007,_plus13) {
var $z30243025 = D;
var $f30303031 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1313007,anf_arg1333020):R.ffi.throwNonFunApp(L[156],_plus13,[anf_arg1313007,anf_arg1333020]);
};
try {
if(--R.GAS > 0) {
$z30243025 = $f30303031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30303031,
"from":L[156]});
}
} catch($e30223023) {
if(R.isCont($e30223023)) {
var $ss30263027 = {"from":L[156],
"go":function(ann_DASH_check_DASH_temp1283032) {
return $Hann_DASH_check_DASH_temp7993033(ann_DASH_check_DASH_temp1283032);
}};
$e30223023.stack[R.EXN_STACKHEIGHT++] = $ss30263027;
}
if(R.isPyretException($e30223023)) {
$e30223023.pyretStack.push(L[156]);
}
throw $e30223023;
}
var $ret30283029 = $Hann_DASH_check_DASH_temp7993033($z30243025);
++R.GAS;
return $ret30283029;
};
var $Hann_DASH_check_DASH_temp7993033 = function(ann_DASH_check_DASH_temp1283032) {
return ann_DASH_check_DASH_temp1283032;
};
var $Hanf_arg7983034 = function(anf_arg1203035,self353036,_plus13,torepr17) {
var anf_arg1213047 = G(self353036,"loc",L[157]);
var $z30393040 = D;
var $f30453046 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg1213047):R.ffi.throwNonFunApp(L[157],torepr17,[anf_arg1213047]);
};
try {
if(--R.GAS > 0) {
$z30393040 = $f30453046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30453046,
"from":L[157]});
}
} catch($e30373038) {
if(R.isCont($e30373038)) {
var $ss30413042 = {"from":L[157],
"go":function(anf_arg1223048) {
return $Hanf_arg7973049(anf_arg1223048,anf_arg1203035,_plus13);
}};
$e30373038.stack[R.EXN_STACKHEIGHT++] = $ss30413042;
}
if(R.isPyretException($e30373038)) {
$e30373038.pyretStack.push(L[157]);
}
throw $e30373038;
}
var $ret30433044 = $Hanf_arg7973049($z30393040,anf_arg1203035,_plus13);
++R.GAS;
return $ret30433044;
};
var $Hanf_arg7973049 = function(anf_arg1223048,anf_arg1203035,_plus13) {
var $z30523053 = D;
var $f30583059 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg1223048):R.ffi.throwNonFunApp(L[157],_plus13,[(", "),anf_arg1223048]);
};
try {
if(--R.GAS > 0) {
$z30523053 = $f30583059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30583059,
"from":L[157]});
}
} catch($e30503051) {
if(R.isCont($e30503051)) {
var $ss30543055 = {"from":L[157],
"go":function(anf_arg1233060) {
return $Hanf_arg7963061(anf_arg1233060,anf_arg1203035,_plus13);
}};
$e30503051.stack[R.EXN_STACKHEIGHT++] = $ss30543055;
}
if(R.isPyretException($e30503051)) {
$e30503051.pyretStack.push(L[157]);
}
throw $e30503051;
}
var $ret30563057 = $Hanf_arg7963061($z30523053,anf_arg1203035,_plus13);
++R.GAS;
return $ret30563057;
};
var $Hanf_arg7963061 = function(anf_arg1233060,anf_arg1203035,_plus13) {
var $z30643065 = D;
var $f30703071 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1203035,anf_arg1233060):R.ffi.throwNonFunApp(L[157],_plus13,[anf_arg1203035,anf_arg1233060]);
};
try {
if(--R.GAS > 0) {
$z30643065 = $f30703071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30703071,
"from":L[157]});
}
} catch($e30623063) {
if(R.isCont($e30623063)) {
var $ss30663067 = {"from":L[157],
"go":function(anf_arg1243072) {
return $Hanf_arg7953073(anf_arg1243072,_plus13);
}};
$e30623063.stack[R.EXN_STACKHEIGHT++] = $ss30663067;
}
if(R.isPyretException($e30623063)) {
$e30623063.pyretStack.push(L[157]);
}
throw $e30623063;
}
var $ret30683069 = $Hanf_arg7953073($z30643065,_plus13);
++R.GAS;
return $ret30683069;
};
var $Hanf_arg7953073 = function(anf_arg1243072,_plus13) {
var $z30763077 = D;
var $f30823083 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg1243072,(")")):R.ffi.throwNonFunApp(L[157],_plus13,[anf_arg1243072,(")")]);
};
try {
if(--R.GAS > 0) {
$z30763077 = $f30823083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30823083,
"from":L[157]});
}
} catch($e30743075) {
if(R.isCont($e30743075)) {
var $ss30783079 = {"from":L[157],
"go":function(anf_arg1253084) {
return $Hanf_arg7943085(anf_arg1253084,_plus13);
}};
$e30743075.stack[R.EXN_STACKHEIGHT++] = $ss30783079;
}
if(R.isPyretException($e30743075)) {
$e30743075.pyretStack.push(L[157]);
}
throw $e30743075;
}
var $ret30803081 = $Hanf_arg7943085($z30763077,_plus13);
++R.GAS;
return $ret30803081;
};
var $Hanf_arg7943085 = function(anf_arg1253084,_plus13) {
var $z30883089 = D;
var $f30943095 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg1253084):R.ffi.throwNonFunApp(L[157],_plus13,[("("),anf_arg1253084]);
};
try {
if(--R.GAS > 0) {
$z30883089 = $f30943095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30943095,
"from":L[157]});
}
} catch($e30863087) {
if(R.isCont($e30863087)) {
var $ss30903091 = {"from":L[157],
"go":function(anf_arg1263096) {
return $Hanf_arg7933097(anf_arg1263096,_plus13);
}};
$e30863087.stack[R.EXN_STACKHEIGHT++] = $ss30903091;
}
if(R.isPyretException($e30863087)) {
$e30863087.pyretStack.push(L[157]);
}
throw $e30863087;
}
var $ret30923093 = $Hanf_arg7933097($z30883089,_plus13);
++R.GAS;
return $ret30923093;
};
var $Hanf_arg7933097 = function(anf_arg1263096,_plus13) {
var $z31003101 = D;
var $f31063107 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("wf-err"),anf_arg1263096):R.ffi.throwNonFunApp(L[157],_plus13,[("wf-err"),anf_arg1263096]);
};
try {
if(--R.GAS > 0) {
$z31003101 = $f31063107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31063107,
"from":L[157]});
}
} catch($e30983099) {
if(R.isCont($e30983099)) {
var $ss31023103 = {"from":L[157],
"go":function(ann_DASH_check_DASH_temp1183108) {
return $Hann_DASH_check_DASH_temp7923109(ann_DASH_check_DASH_temp1183108);
}};
$e30983099.stack[R.EXN_STACKHEIGHT++] = $ss31023103;
}
if(R.isPyretException($e30983099)) {
$e30983099.pyretStack.push(L[157]);
}
throw $e30983099;
}
var $ret31043105 = $Hann_DASH_check_DASH_temp7923109($z31003101);
++R.GAS;
return $ret31043105;
};
var $Hann_DASH_check_DASH_temp7923109 = function(ann_DASH_check_DASH_temp1183108) {
return ann_DASH_check_DASH_temp1183108;
};
var $Hcont_tail_arg7903110 = function(cont_tail_arg1153111,if_helper1063112) {
if(--R.GAS > 0) {
$z31133114 = R.isFunction(if_helper1063112)?if_helper1063112.app(cont_tail_arg1153111):R.ffi.throwNonFunApp(L[157],if_helper1063112,[cont_tail_arg1153111]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1063112)?if_helper1063112.app(cont_tail_arg1153111):R.ffi.throwNonFunApp(L[157],if_helper1063112,[cont_tail_arg1153111]);
},
"from":L[157]});
}
++R.GAS;
return $z31133114;
};
var $Hcont_tail_arg7913115 = function(cont_tail_arg1113116,if_helper1063112) {
if(--R.GAS > 0) {
$z31173118 = R.isFunction(if_helper1063112)?if_helper1063112.app(cont_tail_arg1113116):R.ffi.throwNonFunApp(L[157],if_helper1063112,[cont_tail_arg1113116]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1063112)?if_helper1063112.app(cont_tail_arg1113116):R.ffi.throwNonFunApp(L[157],if_helper1063112,[cont_tail_arg1113116]);
},
"from":L[157]});
}
++R.GAS;
return $z31173118;
};
var $Hanf_arg7893119 = function(anf_arg943120,_plus13) {
var $z31233124 = D;
var $f31293130 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg943120,(")")):R.ffi.throwNonFunApp(L[158],_plus13,[anf_arg943120,(")")]);
};
try {
if(--R.GAS > 0) {
$z31233124 = $f31293130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31293130,
"from":L[158]});
}
} catch($e31213122) {
if(R.isCont($e31213122)) {
var $ss31253126 = {"from":L[158],
"go":function(anf_arg953131) {
return $Hanf_arg7883132(anf_arg953131,_plus13);
}};
$e31213122.stack[R.EXN_STACKHEIGHT++] = $ss31253126;
}
if(R.isPyretException($e31213122)) {
$e31213122.pyretStack.push(L[158]);
}
throw $e31213122;
}
var $ret31273128 = $Hanf_arg7883132($z31233124,_plus13);
++R.GAS;
return $ret31273128;
};
var $Hanf_arg7883132 = function(anf_arg953131,_plus13) {
var $z31353136 = D;
var $f31413142 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg953131):R.ffi.throwNonFunApp(L[158],_plus13,[("("),anf_arg953131]);
};
try {
if(--R.GAS > 0) {
$z31353136 = $f31413142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31413142,
"from":L[158]});
}
} catch($e31333134) {
if(R.isCont($e31333134)) {
var $ss31373138 = {"from":L[158],
"go":function(anf_arg963143) {
return $Hanf_arg7873144(anf_arg963143,_plus13);
}};
$e31333134.stack[R.EXN_STACKHEIGHT++] = $ss31373138;
}
if(R.isPyretException($e31333134)) {
$e31333134.pyretStack.push(L[158]);
}
throw $e31333134;
}
var $ret31393140 = $Hanf_arg7873144($z31353136,_plus13);
++R.GAS;
return $ret31393140;
};
var $Hanf_arg7873144 = function(anf_arg963143,_plus13) {
var $z31473148 = D;
var $f31533154 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("err"),anf_arg963143):R.ffi.throwNonFunApp(L[158],_plus13,[("err"),anf_arg963143]);
};
try {
if(--R.GAS > 0) {
$z31473148 = $f31533154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31533154,
"from":L[158]});
}
} catch($e31453146) {
if(R.isCont($e31453146)) {
var $ss31493150 = {"from":L[158],
"go":function(ann_DASH_check_DASH_temp923155) {
return $Hann_DASH_check_DASH_temp7863156(ann_DASH_check_DASH_temp923155);
}};
$e31453146.stack[R.EXN_STACKHEIGHT++] = $ss31493150;
}
if(R.isPyretException($e31453146)) {
$e31453146.pyretStack.push(L[158]);
}
throw $e31453146;
}
var $ret31513152 = $Hann_DASH_check_DASH_temp7863156($z31473148);
++R.GAS;
return $ret31513152;
};
var $Hann_DASH_check_DASH_temp7863156 = function(ann_DASH_check_DASH_temp923155) {
return ann_DASH_check_DASH_temp923155;
};
var $Hcont_tail_arg7843157 = function(cont_tail_arg893158,if_helper813159) {
if(--R.GAS > 0) {
$z31603161 = R.isFunction(if_helper813159)?if_helper813159.app(cont_tail_arg893158):R.ffi.throwNonFunApp(L[158],if_helper813159,[cont_tail_arg893158]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper813159)?if_helper813159.app(cont_tail_arg893158):R.ffi.throwNonFunApp(L[158],if_helper813159,[cont_tail_arg893158]);
},
"from":L[158]});
}
++R.GAS;
return $z31603161;
};
var $Hcont_tail_arg7853162 = function(cont_tail_arg863163,if_helper813159) {
if(--R.GAS > 0) {
$z31643165 = R.isFunction(if_helper813159)?if_helper813159.app(cont_tail_arg863163):R.ffi.throwNonFunApp(L[158],if_helper813159,[cont_tail_arg863163]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper813159)?if_helper813159.app(cont_tail_arg863163):R.ffi.throwNonFunApp(L[158],if_helper813159,[cont_tail_arg863163]);
},
"from":L[158]});
}
++R.GAS;
return $z31643165;
};
var $Hanf_arg7833166 = function(anf_arg763167,_plus13) {
var $z31703171 = D;
var $f31763177 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg763167,(")")):R.ffi.throwNonFunApp(L[159],_plus13,[anf_arg763167,(")")]);
};
try {
if(--R.GAS > 0) {
$z31703171 = $f31763177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31763177,
"from":L[159]});
}
} catch($e31683169) {
if(R.isCont($e31683169)) {
var $ss31723173 = {"from":L[159],
"go":function(anf_arg773178) {
return $Hanf_arg7823179(anf_arg773178,_plus13);
}};
$e31683169.stack[R.EXN_STACKHEIGHT++] = $ss31723173;
}
if(R.isPyretException($e31683169)) {
$e31683169.pyretStack.push(L[159]);
}
throw $e31683169;
}
var $ret31743175 = $Hanf_arg7823179($z31703171,_plus13);
++R.GAS;
return $ret31743175;
};
var $Hanf_arg7823179 = function(anf_arg773178,_plus13) {
var $z31823183 = D;
var $f31883189 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg773178):R.ffi.throwNonFunApp(L[159],_plus13,[("("),anf_arg773178]);
};
try {
if(--R.GAS > 0) {
$z31823183 = $f31883189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31883189,
"from":L[159]});
}
} catch($e31803181) {
if(R.isCont($e31803181)) {
var $ss31843185 = {"from":L[159],
"go":function(anf_arg783190) {
return $Hanf_arg7813191(anf_arg783190,_plus13);
}};
$e31803181.stack[R.EXN_STACKHEIGHT++] = $ss31843185;
}
if(R.isPyretException($e31803181)) {
$e31803181.pyretStack.push(L[159]);
}
throw $e31803181;
}
var $ret31863187 = $Hanf_arg7813191($z31823183,_plus13);
++R.GAS;
return $ret31863187;
};
var $Hanf_arg7813191 = function(anf_arg783190,_plus13) {
var $z31943195 = D;
var $f32003201 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("ok"),anf_arg783190):R.ffi.throwNonFunApp(L[159],_plus13,[("ok"),anf_arg783190]);
};
try {
if(--R.GAS > 0) {
$z31943195 = $f32003201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32003201,
"from":L[159]});
}
} catch($e31923193) {
if(R.isCont($e31923193)) {
var $ss31963197 = {"from":L[159],
"go":function(ann_DASH_check_DASH_temp743202) {
return $Hann_DASH_check_DASH_temp7803203(ann_DASH_check_DASH_temp743202);
}};
$e31923193.stack[R.EXN_STACKHEIGHT++] = $ss31963197;
}
if(R.isPyretException($e31923193)) {
$e31923193.pyretStack.push(L[159]);
}
throw $e31923193;
}
var $ret31983199 = $Hann_DASH_check_DASH_temp7803203($z31943195);
++R.GAS;
return $ret31983199;
};
var $Hann_DASH_check_DASH_temp7803203 = function(ann_DASH_check_DASH_temp743202) {
return ann_DASH_check_DASH_temp743202;
};
var $Hcont_tail_arg7783204 = function(cont_tail_arg713205,if_helper633206) {
if(--R.GAS > 0) {
$z32073208 = R.isFunction(if_helper633206)?if_helper633206.app(cont_tail_arg713205):R.ffi.throwNonFunApp(L[159],if_helper633206,[cont_tail_arg713205]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper633206)?if_helper633206.app(cont_tail_arg713205):R.ffi.throwNonFunApp(L[159],if_helper633206,[cont_tail_arg713205]);
},
"from":L[159]});
}
++R.GAS;
return $z32073208;
};
var $Hcont_tail_arg7793209 = function(cont_tail_arg683210,if_helper633206) {
if(--R.GAS > 0) {
$z32113212 = R.isFunction(if_helper633206)?if_helper633206.app(cont_tail_arg683210):R.ffi.throwNonFunApp(L[159],if_helper633206,[cont_tail_arg683210]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper633206)?if_helper633206.app(cont_tail_arg683210):R.ffi.throwNonFunApp(L[159],if_helper633206,[cont_tail_arg683210]);
},
"from":L[159]});
}
++R.GAS;
return $z32113212;
};
var $Hanf_arg7773213 = function(anf_arg493214,self173215,_plus13,torepr17) {
var anf_arg503226 = G(self173215,"types",L[160]);
var $z32183219 = D;
var $f32243225 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg503226):R.ffi.throwNonFunApp(L[160],torepr17,[anf_arg503226]);
};
try {
if(--R.GAS > 0) {
$z32183219 = $f32243225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32243225,
"from":L[160]});
}
} catch($e32163217) {
if(R.isCont($e32163217)) {
var $ss32203221 = {"from":L[160],
"go":function(anf_arg513227) {
return $Hanf_arg7763228(anf_arg513227,anf_arg493214,_plus13);
}};
$e32163217.stack[R.EXN_STACKHEIGHT++] = $ss32203221;
}
if(R.isPyretException($e32163217)) {
$e32163217.pyretStack.push(L[160]);
}
throw $e32163217;
}
var $ret32223223 = $Hanf_arg7763228($z32183219,anf_arg493214,_plus13);
++R.GAS;
return $ret32223223;
};
var $Hanf_arg7763228 = function(anf_arg513227,anf_arg493214,_plus13) {
var $z32313232 = D;
var $f32373238 = function(_) {
return R.isFunction(_plus13)?_plus13.app((", "),anf_arg513227):R.ffi.throwNonFunApp(L[160],_plus13,[(", "),anf_arg513227]);
};
try {
if(--R.GAS > 0) {
$z32313232 = $f32373238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32373238,
"from":L[160]});
}
} catch($e32293230) {
if(R.isCont($e32293230)) {
var $ss32333234 = {"from":L[160],
"go":function(anf_arg523239) {
return $Hanf_arg7753240(anf_arg523239,anf_arg493214,_plus13);
}};
$e32293230.stack[R.EXN_STACKHEIGHT++] = $ss32333234;
}
if(R.isPyretException($e32293230)) {
$e32293230.pyretStack.push(L[160]);
}
throw $e32293230;
}
var $ret32353236 = $Hanf_arg7753240($z32313232,anf_arg493214,_plus13);
++R.GAS;
return $ret32353236;
};
var $Hanf_arg7753240 = function(anf_arg523239,anf_arg493214,_plus13) {
var $z32433244 = D;
var $f32493250 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg493214,anf_arg523239):R.ffi.throwNonFunApp(L[160],_plus13,[anf_arg493214,anf_arg523239]);
};
try {
if(--R.GAS > 0) {
$z32433244 = $f32493250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32493250,
"from":L[160]});
}
} catch($e32413242) {
if(R.isCont($e32413242)) {
var $ss32453246 = {"from":L[160],
"go":function(anf_arg533251) {
return $Hanf_arg7743252(anf_arg533251,_plus13);
}};
$e32413242.stack[R.EXN_STACKHEIGHT++] = $ss32453246;
}
if(R.isPyretException($e32413242)) {
$e32413242.pyretStack.push(L[160]);
}
throw $e32413242;
}
var $ret32473248 = $Hanf_arg7743252($z32433244,_plus13);
++R.GAS;
return $ret32473248;
};
var $Hanf_arg7743252 = function(anf_arg533251,_plus13) {
var $z32553256 = D;
var $f32613262 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg533251,(")")):R.ffi.throwNonFunApp(L[160],_plus13,[anf_arg533251,(")")]);
};
try {
if(--R.GAS > 0) {
$z32553256 = $f32613262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32613262,
"from":L[160]});
}
} catch($e32533254) {
if(R.isCont($e32533254)) {
var $ss32573258 = {"from":L[160],
"go":function(anf_arg543263) {
return $Hanf_arg7733264(anf_arg543263,_plus13);
}};
$e32533254.stack[R.EXN_STACKHEIGHT++] = $ss32573258;
}
if(R.isPyretException($e32533254)) {
$e32533254.pyretStack.push(L[160]);
}
throw $e32533254;
}
var $ret32593260 = $Hanf_arg7733264($z32553256,_plus13);
++R.GAS;
return $ret32593260;
};
var $Hanf_arg7733264 = function(anf_arg543263,_plus13) {
var $z32673268 = D;
var $f32733274 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("("),anf_arg543263):R.ffi.throwNonFunApp(L[160],_plus13,[("("),anf_arg543263]);
};
try {
if(--R.GAS > 0) {
$z32673268 = $f32733274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32733274,
"from":L[160]});
}
} catch($e32653266) {
if(R.isCont($e32653266)) {
var $ss32693270 = {"from":L[160],
"go":function(anf_arg553275) {
return $Hanf_arg7723276(anf_arg553275,_plus13);
}};
$e32653266.stack[R.EXN_STACKHEIGHT++] = $ss32693270;
}
if(R.isPyretException($e32653266)) {
$e32653266.pyretStack.push(L[160]);
}
throw $e32653266;
}
var $ret32713272 = $Hanf_arg7723276($z32673268,_plus13);
++R.GAS;
return $ret32713272;
};
var $Hanf_arg7723276 = function(anf_arg553275,_plus13) {
var $z32793280 = D;
var $f32853286 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("compile-env"),anf_arg553275):R.ffi.throwNonFunApp(L[160],_plus13,[("compile-env"),anf_arg553275]);
};
try {
if(--R.GAS > 0) {
$z32793280 = $f32853286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32853286,
"from":L[160]});
}
} catch($e32773278) {
if(R.isCont($e32773278)) {
var $ss32813282 = {"from":L[160],
"go":function(ann_DASH_check_DASH_temp473287) {
return $Hann_DASH_check_DASH_temp7713288(ann_DASH_check_DASH_temp473287);
}};
$e32773278.stack[R.EXN_STACKHEIGHT++] = $ss32813282;
}
if(R.isPyretException($e32773278)) {
$e32773278.pyretStack.push(L[160]);
}
throw $e32773278;
}
var $ret32833284 = $Hann_DASH_check_DASH_temp7713288($z32793280);
++R.GAS;
return $ret32833284;
};
var $Hann_DASH_check_DASH_temp7713288 = function(ann_DASH_check_DASH_temp473287) {
return ann_DASH_check_DASH_temp473287;
};
var $Hcont_tail_arg7693289 = function(cont_tail_arg443290,if_helper353291) {
if(--R.GAS > 0) {
$z32923293 = R.isFunction(if_helper353291)?if_helper353291.app(cont_tail_arg443290):R.ffi.throwNonFunApp(L[160],if_helper353291,[cont_tail_arg443290]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper353291)?if_helper353291.app(cont_tail_arg443290):R.ffi.throwNonFunApp(L[160],if_helper353291,[cont_tail_arg443290]);
},
"from":L[160]});
}
++R.GAS;
return $z32923293;
};
var $Hcont_tail_arg7703294 = function(cont_tail_arg403295,if_helper353291) {
if(--R.GAS > 0) {
$z32963297 = R.isFunction(if_helper353291)?if_helper353291.app(cont_tail_arg403295):R.ffi.throwNonFunApp(L[160],if_helper353291,[cont_tail_arg403295]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper353291)?if_helper353291.app(cont_tail_arg403295):R.ffi.throwNonFunApp(L[160],if_helper353291,[cont_tail_arg403295]);
},
"from":L[160]});
}
++R.GAS;
return $z32963297;
};
var $Hcont_tail_arg7673298 = function(cont_tail_arg223299,if_helper153300) {
if(--R.GAS > 0) {
$z33013302 = R.isFunction(if_helper153300)?if_helper153300.app(cont_tail_arg223299):R.ffi.throwNonFunApp(L[161],if_helper153300,[cont_tail_arg223299]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper153300)?if_helper153300.app(cont_tail_arg223299):R.ffi.throwNonFunApp(L[161],if_helper153300,[cont_tail_arg223299]);
},
"from":L[161]});
}
++R.GAS;
return $z33013302;
};
var $Hcont_tail_arg7683303 = function(cont_tail_arg203304,if_helper153300) {
if(--R.GAS > 0) {
$z33053306 = R.isFunction(if_helper153300)?if_helper153300.app(cont_tail_arg203304):R.ffi.throwNonFunApp(L[161],if_helper153300,[cont_tail_arg203304]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper153300)?if_helper153300.app(cont_tail_arg203304):R.ffi.throwNonFunApp(L[161],if_helper153300,[cont_tail_arg203304]);
},
"from":L[161]});
}
++R.GAS;
return $z33053306;
};
var $Hcont_tail_arg7653307 = function(cont_tail_arg93308,if_helper23309) {
if(--R.GAS > 0) {
$z33103311 = R.isFunction(if_helper23309)?if_helper23309.app(cont_tail_arg93308):R.ffi.throwNonFunApp(L[162],if_helper23309,[cont_tail_arg93308]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper23309)?if_helper23309.app(cont_tail_arg93308):R.ffi.throwNonFunApp(L[162],if_helper23309,[cont_tail_arg93308]);
},
"from":L[162]});
}
++R.GAS;
return $z33103311;
};
var $Hcont_tail_arg7663312 = function(cont_tail_arg73313,if_helper23309) {
if(--R.GAS > 0) {
$z33143315 = R.isFunction(if_helper23309)?if_helper23309.app(cont_tail_arg73313):R.ffi.throwNonFunApp(L[162],if_helper23309,[cont_tail_arg73313]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper23309)?if_helper23309.app(cont_tail_arg73313):R.ffi.throwNonFunApp(L[162],if_helper23309,[cont_tail_arg73313]);
},
"from":L[162]});
}
++R.GAS;
return $z33143315;
};
return R.loadModulesNew(NAMESPACE,[$A12035,$SL32136,$arrays52237,$lists72338,$option92439,$error112540,$sets132641],function($A12035,$SL32136,$arrays52237,$lists72338,$option92439,$error112540,$sets132641) {
var A120 = R.getField($A12035,"values");
var SL321 = R.getField($SL32136,"values");
var arrays522 = R.getField($arrays52237,"values");
var lists723 = R.getField($lists72338,"values");
var option924 = R.getField($option92439,"values");
var error1125 = R.getField($error112540,"values");
var sets1326 = R.getField($sets132641,"values");
var A227 = R.getField($A12035,"types");
var SL428 = R.getField($SL32136,"types");
var arrays629 = R.getField($arrays52237,"types");
var lists830 = R.getField($lists72338,"types");
var option1031 = R.getField($option92439,"types");
var error1232 = R.getField($error112540,"types");
var sets1433 = R.getField($sets132641,"types");
return R.safeCall(function() {
var List1555 = R.getDotAnn(L[163],"lists",lists830,"List");
var Option163316 = R.getDotAnn(L[163],"option",option1031,"Option");
var Array173317 = R.getDotAnn(L[163],"arrays",arrays629,"Array");
var Set183318 = R.getDotAnn(L[163],"sets",sets1433,"Set");
var array194701 = G(arrays522,"array",L[163]);
var build_DASH_array204700 = G(arrays522,"build-array",L[163]);
var array_DASH_from_DASH_list214699 = G(arrays522,"array-from-list",L[163]);
var is_DASH_array224698 = G(arrays522,"is-array",L[163]);
var list2391 = G(lists723,"list",L[163]);
var is_DASH_empty244697 = G(lists723,"is-empty",L[163]);
var is_DASH_link254696 = G(lists723,"is-link",L[163]);
var empty264695 = G(lists723,"empty",L[163]);
var link274694 = G(lists723,"link",L[163]);
var range284693 = G(lists723,"range",L[163]);
var repeat294692 = G(lists723,"repeat",L[163]);
var filter304691 = G(lists723,"filter",L[163]);
var partition314690 = G(lists723,"partition",L[163]);
var split_DASH_at324689 = G(lists723,"split-at",L[163]);
var any334688 = G(lists723,"any",L[163]);
var find344687 = G(lists723,"find",L[163]);
var map354686 = G(lists723,"map",L[163]);
var map2364685 = G(lists723,"map2",L[163]);
var map3374684 = G(lists723,"map3",L[163]);
var map4384683 = G(lists723,"map4",L[163]);
var map_n394682 = G(lists723,"map_n",L[163]);
var map2_n404681 = G(lists723,"map2_n",L[163]);
var map3_n414680 = G(lists723,"map3_n",L[163]);
var map4_n424679 = G(lists723,"map4_n",L[163]);
var each434678 = G(lists723,"each",L[163]);
var each2444677 = G(lists723,"each2",L[163]);
var each3454676 = G(lists723,"each3",L[163]);
var each4464675 = G(lists723,"each4",L[163]);
var each_n474674 = G(lists723,"each_n",L[163]);
var each2_n484673 = G(lists723,"each2_n",L[163]);
var each3_n494672 = G(lists723,"each3_n",L[163]);
var each4_n504671 = G(lists723,"each4_n",L[163]);
var fold514670 = G(lists723,"fold",L[163]);
var fold2524669 = G(lists723,"fold2",L[163]);
var fold3534668 = G(lists723,"fold3",L[163]);
var fold4544667 = G(lists723,"fold4",L[163]);
var index554666 = G(lists723,"index",L[163]);
var Option564665 = G(option924,"Option",L[163]);
var is_DASH_none574664 = G(option924,"is-none",L[163]);
var is_DASH_some584663 = G(option924,"is-some",L[163]);
var none594662 = G(option924,"none",L[163]);
var some604661 = G(option924,"some",L[163]);
var set614660 = G(sets1326,"set",L[163]);
var tree_DASH_set624659 = G(sets1326,"tree-set",L[163]);
var list_DASH_set634658 = G(sets1326,"list-set",L[163]);
var PyretDialectT1653319 = R.namedBrander("PyretDialect");
var PyretDialect6458 = R.makeBranderAnn(PyretDialectT1653319,"PyretDialect");
var CompileEnvironmentT2673320 = R.namedBrander("CompileEnvironment");
var CompileEnvironment6647 = R.makeBranderAnn(CompileEnvironmentT2673320,"CompileEnvironment");
var CompileResultT3693321 = R.namedBrander("CompileResult");
var CompileResult6851 = R.makeBranderAnn(CompileResultT3693321,"CompileResult");
var CompileErrorT4713322 = R.namedBrander("CompileError");
var CompileError7049 = R.makeBranderAnn(CompileErrorT4713322,"CompileError");
var CompileTypeBindingT5733323 = R.namedBrander("CompileTypeBinding");
var CompileTypeBinding7254 = R.makeBranderAnn(CompileTypeBindingT5733323,"CompileTypeBinding");
var CompileBindingT67546 = R.namedBrander("CompileBinding");
var CompileBinding7445 = R.makeBranderAnn(CompileBindingT67546,"CompileBinding");
var Loc7656 = R.getDotAnn(L[164],"SL",SL428,"Srcloc");
var PyretDialect7773324 = {"$var":D,
"$name":"PyretDialect7"};
var PyretDialect7859 = {"$var":D,
"$name":"PyretDialect"};
var is_DASH_PyretDialect7971 = {"$var":D,
"$name":"is-PyretDialect"};
var is_DASH_Pyret8070 = {"$var":D,
"$name":"is-Pyret"};
var Pyret8157 = {"$var":D,
"$name":"Pyret"};
var is_DASH_Bootstrap8265 = {"$var":D,
"$name":"is-Bootstrap"};
var Bootstrap8344 = {"$var":D,
"$name":"Bootstrap"};
var CompileEnvironment8843332 = {"$var":D,
"$name":"CompileEnvironment8"};
var CompileEnvironment8548 = {"$var":D,
"$name":"CompileEnvironment"};
var is_DASH_CompileEnvironment8666 = {"$var":D,
"$name":"is-CompileEnvironment"};
var is_DASH_compile_DASH_env8773 = {"$var":D,
"$name":"is-compile-env"};
var compile_DASH_env8862 = {"$var":D,
"$name":"compile-env"};
var CompileResult9893338 = {"$var":D,
"$name":"CompileResult9"};
var CompileResult9052 = {"$var":D,
"$name":"CompileResult"};
var is_DASH_CompileResult9168 = {"$var":D,
"$name":"is-CompileResult"};
var is_DASH_ok9277 = {"$var":D,
"$name":"is-ok"};
var ok9393 = {"$var":D,
"$name":"ok"};
var is_DASH_err9475 = {"$var":D,
"$name":"is-err"};
var err9564 = {"$var":D,
"$name":"err"};
var CompileError10963346 = {"$var":D,
"$name":"CompileError10"};
var CompileError9750 = {"$var":D,
"$name":"CompileError"};
var is_DASH_CompileError9867 = {"$var":D,
"$name":"is-CompileError"};
var is_DASH_wf_DASH_err9989 = {"$var":D,
"$name":"is-wf-err"};
var wf_DASH_err100105 = {"$var":D,
"$name":"wf-err"};
var is_DASH_wf_DASH_err_DASH_split10188 = {"$var":D,
"$name":"is-wf-err-split"};
var wf_DASH_err_DASH_split102104 = {"$var":D,
"$name":"wf-err-split"};
var is_DASH_reserved_DASH_name10380 = {"$var":D,
"$name":"is-reserved-name"};
var reserved_DASH_name10496 = {"$var":D,
"$name":"reserved-name"};
var is_DASH_zero_DASH_fraction10590 = {"$var":D,
"$name":"is-zero-fraction"};
var zero_DASH_fraction106106 = {"$var":D,
"$name":"zero-fraction"};
var is_DASH_unbound_DASH_id10784 = {"$var":D,
"$name":"is-unbound-id"};
var unbound_DASH_id108100 = {"$var":D,
"$name":"unbound-id"};
var is_DASH_unbound_DASH_var10986 = {"$var":D,
"$name":"is-unbound-var"};
var unbound_DASH_var110102 = {"$var":D,
"$name":"unbound-var"};
var is_DASH_unbound_DASH_type_DASH_id11185 = {"$var":D,
"$name":"is-unbound-type-id"};
var unbound_DASH_type_DASH_id112101 = {"$var":D,
"$name":"unbound-type-id"};
var is_DASH_unexpected_DASH_type_DASH_var11387 = {"$var":D,
"$name":"is-unexpected-type-var"};
var unexpected_DASH_type_DASH_var114103 = {"$var":D,
"$name":"unexpected-type-var"};
var is_DASH_pointless_DASH_var11579 = {"$var":D,
"$name":"is-pointless-var"};
var pointless_DASH_var11695 = {"$var":D,
"$name":"pointless-var"};
var is_DASH_pointless_DASH_shadow11778 = {"$var":D,
"$name":"is-pointless-shadow"};
var pointless_DASH_shadow11894 = {"$var":D,
"$name":"pointless-shadow"};
var is_DASH_bad_DASH_assignment11972 = {"$var":D,
"$name":"is-bad-assignment"};
var bad_DASH_assignment12061 = {"$var":D,
"$name":"bad-assignment"};
var is_DASH_mixed_DASH_id_DASH_var12176 = {"$var":D,
"$name":"is-mixed-id-var"};
var mixed_DASH_id_DASH_var12292 = {"$var":D,
"$name":"mixed-id-var"};
var is_DASH_shadow_DASH_id12381 = {"$var":D,
"$name":"is-shadow-id"};
var shadow_DASH_id12497 = {"$var":D,
"$name":"shadow-id"};
var is_DASH_duplicate_DASH_id12574 = {"$var":D,
"$name":"is-duplicate-id"};
var duplicate_DASH_id12663 = {"$var":D,
"$name":"duplicate-id"};
var CompileTypeBinding111273378 = {"$var":D,
"$name":"CompileTypeBinding11"};
var CompileTypeBinding12853 = {"$var":D,
"$name":"CompileTypeBinding"};
var is_DASH_CompileTypeBinding12969 = {"$var":D,
"$name":"is-CompileTypeBinding"};
var is_DASH_type_DASH_id13082 = {"$var":D,
"$name":"is-type-id"};
var type_DASH_id13198 = {"$var":D,
"$name":"type-id"};
var is_DASH_type_DASH_module_DASH_bindings13283 = {"$var":D,
"$name":"is-type-module-bindings"};
var type_DASH_module_DASH_bindings13399 = {"$var":D,
"$name":"type-module-bindings"};
var anf_singleton_variant_member114583 = R.makeMethod(function(self24657) {
return function(cases_DASH_funs34638,else_DASH_clause44649) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[162],2,arguments);
}
var if_DASH_64650 = R.hasField(cases_DASH_funs34638,("Pyret"));
var if_helper23309 = R.makeFunction(function(if_helper_arg34655) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[162],1,arguments);
}
var ann_DASH_check_DASH_temp14656 = if_helper_arg34655;
return ann_DASH_check_DASH_temp14656;
});
var anf_if64654 = R.isBoolean(if_DASH_64650);
if(R.isPyretTrue(anf_if64654)) {
if(R.isPyretTrue(if_DASH_64650)) {
var call_DASH_Pyret14637 = G(cases_DASH_funs34638,"Pyret",L[162]);
var $z46294630 = D;
var $f46354636 = function(_) {
return R.isFunction(call_DASH_Pyret14637)?call_DASH_Pyret14637.app():R.ffi.throwNonFunApp(L[162],call_DASH_Pyret14637,[]);
};
try {
if(--R.GAS > 0) {
$z46294630 = $f46354636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46354636,
"from":L[162]});
}
} catch($e46274628) {
if(R.isCont($e46274628)) {
var $ss46314632 = {"from":L[162],
"go":function(cont_tail_arg93308) {
return $Hcont_tail_arg7653307(cont_tail_arg93308,if_helper23309);
}};
$e46274628.stack[R.EXN_STACKHEIGHT++] = $ss46314632;
}
if(R.isPyretException($e46274628)) {
$e46274628.pyretStack.push(L[162]);
}
throw $e46274628;
}
var $ret46334634 = $Hcont_tail_arg7653307($z46294630,if_helper23309);
++R.GAS;
return $ret46334634;
} else {
var $z46414642 = D;
var $f46474648 = function(_) {
return R.isFunction(else_DASH_clause44649)?else_DASH_clause44649.app():R.ffi.throwNonFunApp(L[162],else_DASH_clause44649,[]);
};
try {
if(--R.GAS > 0) {
$z46414642 = $f46474648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46474648,
"from":L[162]});
}
} catch($e46394640) {
if(R.isCont($e46394640)) {
var $ss46434644 = {"from":L[162],
"go":function(cont_tail_arg73313) {
return $Hcont_tail_arg7663312(cont_tail_arg73313,if_helper23309);
}};
$e46394640.stack[R.EXN_STACKHEIGHT++] = $ss46434644;
}
if(R.isPyretException($e46394640)) {
$e46394640.pyretStack.push(L[162]);
}
throw $e46394640;
}
var $ret46454646 = $Hcont_tail_arg7663312($z46414642,if_helper23309);
++R.GAS;
return $ret46454646;
}
} else {
var cont_tail_arg44653 = R.throwNonBooleanCondition(L[162],("if"),if_DASH_64650);
if(--R.GAS > 0) {
$z46514652 = R.isFunction(if_helper23309)?if_helper23309.app(cont_tail_arg44653):R.ffi.throwNonFunApp(L[162],if_helper23309,[cont_tail_arg44653]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper23309)?if_helper23309.app(cont_tail_arg44653):R.ffi.throwNonFunApp(L[162],if_helper23309,[cont_tail_arg44653]);
},
"from":L[162]});
}
++R.GAS;
return $z46514652;
}
};
},{"length":3});
var anf_singleton_variant_member134584 = R.makeMethod(function(self54626) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[162],0,arguments);
}
var ann_DASH_check_DASH_temp124625 = ("Pyret");
return ann_DASH_check_DASH_temp124625;
};
},{"length":1});
var anf_singleton_variant_member244590 = R.makeMethod(function(self84624) {
return function(cases_DASH_funs94605,else_DASH_clause104616) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[161],2,arguments);
}
var if_DASH_124617 = R.hasField(cases_DASH_funs94605,("Bootstrap"));
var if_helper153300 = R.makeFunction(function(if_helper_arg164622) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[161],1,arguments);
}
var ann_DASH_check_DASH_temp144623 = if_helper_arg164622;
return ann_DASH_check_DASH_temp144623;
});
var anf_if194621 = R.isBoolean(if_DASH_124617);
if(R.isPyretTrue(anf_if194621)) {
if(R.isPyretTrue(if_DASH_124617)) {
var call_DASH_Bootstrap74604 = G(cases_DASH_funs94605,"Bootstrap",L[161]);
var $z45964597 = D;
var $f46024603 = function(_) {
return R.isFunction(call_DASH_Bootstrap74604)?call_DASH_Bootstrap74604.app():R.ffi.throwNonFunApp(L[161],call_DASH_Bootstrap74604,[]);
};
try {
if(--R.GAS > 0) {
$z45964597 = $f46024603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46024603,
"from":L[161]});
}
} catch($e45944595) {
if(R.isCont($e45944595)) {
var $ss45984599 = {"from":L[161],
"go":function(cont_tail_arg223299) {
return $Hcont_tail_arg7673298(cont_tail_arg223299,if_helper153300);
}};
$e45944595.stack[R.EXN_STACKHEIGHT++] = $ss45984599;
}
if(R.isPyretException($e45944595)) {
$e45944595.pyretStack.push(L[161]);
}
throw $e45944595;
}
var $ret46004601 = $Hcont_tail_arg7673298($z45964597,if_helper153300);
++R.GAS;
return $ret46004601;
} else {
var $z46084609 = D;
var $f46144615 = function(_) {
return R.isFunction(else_DASH_clause104616)?else_DASH_clause104616.app():R.ffi.throwNonFunApp(L[161],else_DASH_clause104616,[]);
};
try {
if(--R.GAS > 0) {
$z46084609 = $f46144615();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46144615,
"from":L[161]});
}
} catch($e46064607) {
if(R.isCont($e46064607)) {
var $ss46104611 = {"from":L[161],
"go":function(cont_tail_arg203304) {
return $Hcont_tail_arg7683303(cont_tail_arg203304,if_helper153300);
}};
$e46064607.stack[R.EXN_STACKHEIGHT++] = $ss46104611;
}
if(R.isPyretException($e46064607)) {
$e46064607.pyretStack.push(L[161]);
}
throw $e46064607;
}
var $ret46124613 = $Hcont_tail_arg7683303($z46084609,if_helper153300);
++R.GAS;
return $ret46124613;
}
} else {
var cont_tail_arg174620 = R.throwNonBooleanCondition(L[161],("if"),if_DASH_124617);
if(--R.GAS > 0) {
$z46184619 = R.isFunction(if_helper153300)?if_helper153300.app(cont_tail_arg174620):R.ffi.throwNonFunApp(L[161],if_helper153300,[cont_tail_arg174620]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper153300)?if_helper153300.app(cont_tail_arg174620):R.ffi.throwNonFunApp(L[161],if_helper153300,[cont_tail_arg174620]);
},
"from":L[161]});
}
++R.GAS;
return $z46184619;
}
};
},{"length":3});
var anf_singleton_variant_member264591 = R.makeMethod(function(self114593) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[161],0,arguments);
}
var ann_DASH_check_DASH_temp254592 = ("Bootstrap");
return ann_DASH_check_DASH_temp254592;
};
},{"length":1});
var anf_assign273325 = (function() {
var $Pyret_DASH_base45784579 = {"_match":anf_singleton_variant_member114583,
"_torepr":anf_singleton_variant_member134584};
var $Pyret_DASH_brands45814582 = {"$brand-Pyret4580":true};
$Pyret_DASH_brands45814582[PyretDialectT1653319._brand] = true
var $Bootstrap_DASH_base45854586 = {"_match":anf_singleton_variant_member244590,
"_torepr":anf_singleton_variant_member264591};
var $Bootstrap_DASH_brands45884589 = {"$brand-Bootstrap4587":true};
$Bootstrap_DASH_brands45884589[PyretDialectT1653319._brand] = true
return R.makeObject({"PyretDialect":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[52],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,PyretDialectT1653319._brand));
}),
"is-Pyret":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[162],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-Pyret4580"));
}),
"Pyret":R.makeBrandedObject($Pyret_DASH_base45784579,$Pyret_DASH_brands45814582),
"is-Bootstrap":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[161],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-Bootstrap4587"));
}),
"Bootstrap":R.makeBrandedObject($Bootstrap_DASH_base45854586,$Bootstrap_DASH_brands45884589)});
})();
PyretDialect7773324.$var = anf_assign273325;
var anf_assign283326 = G(PyretDialect7773324.$var,"PyretDialect",L[52]);
PyretDialect7859.$var = anf_assign283326;
var anf_assign293327 = G(PyretDialect7773324.$var,"PyretDialect",L[52]);
is_DASH_PyretDialect7971.$var = anf_assign293327;
var anf_assign303328 = G(PyretDialect7773324.$var,"is-Pyret",L[162]);
is_DASH_Pyret8070.$var = anf_assign303328;
var anf_assign313329 = G(PyretDialect7773324.$var,"Pyret",L[162]);
Pyret8157.$var = anf_assign313329;
var anf_assign323330 = G(PyretDialect7773324.$var,"is-Bootstrap",L[161]);
is_DASH_Bootstrap8265.$var = anf_assign323330;
var anf_assign333331 = G(PyretDialect7773324.$var,"Bootstrap",L[161]);
Bootstrap8344.$var = anf_assign333331;
var anf_variant_member464530 = R.makeMethod(function(self144558) {
return function(cases_DASH_funs154559,else_DASH_clause164570) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[160],2,arguments);
}
var if_DASH_184571 = R.hasField(cases_DASH_funs154559,("compile-env"));
var if_helper353291 = R.makeFunction(function(if_helper_arg364576) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[160],1,arguments);
}
var ann_DASH_check_DASH_temp344577 = if_helper_arg364576;
return ann_DASH_check_DASH_temp344577;
});
var anf_if394575 = R.isBoolean(if_DASH_184571);
if(R.isPyretTrue(anf_if394575)) {
if(R.isPyretTrue(if_DASH_184571)) {
var call_DASH_compile_DASH_env134555 = G(cases_DASH_funs154559,"compile-env",L[160]);
var anf_arg424556 = G(self144558,"bindings",L[279]);
var anf_arg434557 = G(self144558,"types",L[278]);
var $z45474548 = D;
var $f45534554 = function(_) {
return R.isFunction(call_DASH_compile_DASH_env134555)?call_DASH_compile_DASH_env134555.app(anf_arg424556,anf_arg434557):R.ffi.throwNonFunApp(L[160],call_DASH_compile_DASH_env134555,[anf_arg424556,anf_arg434557]);
};
try {
if(--R.GAS > 0) {
$z45474548 = $f45534554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45534554,
"from":L[160]});
}
} catch($e45454546) {
if(R.isCont($e45454546)) {
var $ss45494550 = {"from":L[160],
"go":function(cont_tail_arg443290) {
return $Hcont_tail_arg7693289(cont_tail_arg443290,if_helper353291);
}};
$e45454546.stack[R.EXN_STACKHEIGHT++] = $ss45494550;
}
if(R.isPyretException($e45454546)) {
$e45454546.pyretStack.push(L[160]);
}
throw $e45454546;
}
var $ret45514552 = $Hcont_tail_arg7693289($z45474548,if_helper353291);
++R.GAS;
return $ret45514552;
} else {
var $z45624563 = D;
var $f45684569 = function(_) {
return R.isFunction(else_DASH_clause164570)?else_DASH_clause164570.app():R.ffi.throwNonFunApp(L[160],else_DASH_clause164570,[]);
};
try {
if(--R.GAS > 0) {
$z45624563 = $f45684569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45684569,
"from":L[160]});
}
} catch($e45604561) {
if(R.isCont($e45604561)) {
var $ss45644565 = {"from":L[160],
"go":function(cont_tail_arg403295) {
return $Hcont_tail_arg7703294(cont_tail_arg403295,if_helper353291);
}};
$e45604561.stack[R.EXN_STACKHEIGHT++] = $ss45644565;
}
if(R.isPyretException($e45604561)) {
$e45604561.pyretStack.push(L[160]);
}
throw $e45604561;
}
var $ret45664567 = $Hcont_tail_arg7703294($z45624563,if_helper353291);
++R.GAS;
return $ret45664567;
}
} else {
var cont_tail_arg374574 = R.throwNonBooleanCondition(L[160],("if"),if_DASH_184571);
if(--R.GAS > 0) {
$z45724573 = R.isFunction(if_helper353291)?if_helper353291.app(cont_tail_arg374574):R.ffi.throwNonFunApp(L[160],if_helper353291,[cont_tail_arg374574]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper353291)?if_helper353291.app(cont_tail_arg374574):R.ffi.throwNonFunApp(L[160],if_helper353291,[cont_tail_arg374574]);
},
"from":L[160]});
}
++R.GAS;
return $z45724573;
}
};
},{"length":3});
var anf_variant_member564531 = R.makeMethod(function(self173215) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[160],0,arguments);
}
var anf_arg484544 = G(self173215,"bindings",L[160]);
var $z45364537 = D;
var $f45424543 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg484544):R.ffi.throwNonFunApp(L[160],torepr17,[anf_arg484544]);
};
try {
if(--R.GAS > 0) {
$z45364537 = $f45424543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45424543,
"from":L[160]});
}
} catch($e45344535) {
if(R.isCont($e45344535)) {
var $ss45384539 = {"from":L[160],
"go":function(anf_arg493214) {
return $Hanf_arg7773213(anf_arg493214,self173215,_plus13,torepr17);
}};
$e45344535.stack[R.EXN_STACKHEIGHT++] = $ss45384539;
}
if(R.isPyretException($e45344535)) {
$e45344535.pyretStack.push(L[160]);
}
throw $e45344535;
}
var $ret45404541 = $Hanf_arg7773213($z45364537,self173215,_plus13,torepr17);
++R.GAS;
return $ret45404541;
};
},{"length":1});
var anf_assign573333 = (function() {
var $compile_DASH_env_DASH_base45254526 = {"_match":anf_variant_member464530,
"_torepr":anf_variant_member564531};
var $compile_DASH_env_DASH_brands45284529 = {"$brand-compile-env4527":true};
$compile_DASH_env_DASH_brands45284529[CompileEnvironmentT2673320._brand] = true
return R.makeObject({"CompileEnvironment":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[274],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CompileEnvironmentT2673320._brand));
}),
"is-compile-env":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[160],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-compile-env4527"));
}),
"compile-env":R.makeFunction(function(bindings1344532,types1354533) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[275],2,arguments);
}
return R.checkAnnArgs([List1555,List1555],[bindings1344532,types1354533],[L[276],L[277]],function() {
var dict = R.create($compile_DASH_env_DASH_base45254526);
dict["bindings"] = bindings1344532
dict["types"] = types1354533
return R.makeBrandedObject(dict,$compile_DASH_env_DASH_brands45284529);
});
})});
})();
CompileEnvironment8843332.$var = anf_assign573333;
var anf_assign583334 = G(CompileEnvironment8843332.$var,"CompileEnvironment",L[274]);
CompileEnvironment8548.$var = anf_assign583334;
var anf_assign593335 = G(CompileEnvironment8843332.$var,"CompileEnvironment",L[274]);
is_DASH_CompileEnvironment8666.$var = anf_assign593335;
var anf_assign603336 = G(CompileEnvironment8843332.$var,"is-compile-env",L[160]);
is_DASH_compile_DASH_env8773.$var = anf_assign603336;
var anf_assign613337 = G(CompileEnvironment8843332.$var,"compile-env",L[160]);
compile_DASH_env8862.$var = anf_assign613337;
var anf_variant_member734426 = R.makeMethod(function(self204505) {
return function(cases_DASH_funs214506,else_DASH_clause224517) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[159],2,arguments);
}
var if_DASH_244518 = R.hasField(cases_DASH_funs214506,("ok"));
var if_helper633206 = R.makeFunction(function(if_helper_arg644523) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[159],1,arguments);
}
var ann_DASH_check_DASH_temp624524 = if_helper_arg644523;
return ann_DASH_check_DASH_temp624524;
});
var anf_if674522 = R.isBoolean(if_DASH_244518);
if(R.isPyretTrue(anf_if674522)) {
if(R.isPyretTrue(if_DASH_244518)) {
var call_DASH_ok194503 = G(cases_DASH_funs214506,"ok",L[159]);
var anf_arg704504 = G(self204505,"code",L[273]);
var $z44954496 = D;
var $f45014502 = function(_) {
return R.isFunction(call_DASH_ok194503)?call_DASH_ok194503.app(anf_arg704504):R.ffi.throwNonFunApp(L[159],call_DASH_ok194503,[anf_arg704504]);
};
try {
if(--R.GAS > 0) {
$z44954496 = $f45014502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45014502,
"from":L[159]});
}
} catch($e44934494) {
if(R.isCont($e44934494)) {
var $ss44974498 = {"from":L[159],
"go":function(cont_tail_arg713205) {
return $Hcont_tail_arg7783204(cont_tail_arg713205,if_helper633206);
}};
$e44934494.stack[R.EXN_STACKHEIGHT++] = $ss44974498;
}
if(R.isPyretException($e44934494)) {
$e44934494.pyretStack.push(L[159]);
}
throw $e44934494;
}
var $ret44994500 = $Hcont_tail_arg7783204($z44954496,if_helper633206);
++R.GAS;
return $ret44994500;
} else {
var $z45094510 = D;
var $f45154516 = function(_) {
return R.isFunction(else_DASH_clause224517)?else_DASH_clause224517.app():R.ffi.throwNonFunApp(L[159],else_DASH_clause224517,[]);
};
try {
if(--R.GAS > 0) {
$z45094510 = $f45154516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45154516,
"from":L[159]});
}
} catch($e45074508) {
if(R.isCont($e45074508)) {
var $ss45114512 = {"from":L[159],
"go":function(cont_tail_arg683210) {
return $Hcont_tail_arg7793209(cont_tail_arg683210,if_helper633206);
}};
$e45074508.stack[R.EXN_STACKHEIGHT++] = $ss45114512;
}
if(R.isPyretException($e45074508)) {
$e45074508.pyretStack.push(L[159]);
}
throw $e45074508;
}
var $ret45134514 = $Hcont_tail_arg7793209($z45094510,if_helper633206);
++R.GAS;
return $ret45134514;
}
} else {
var cont_tail_arg654521 = R.throwNonBooleanCondition(L[159],("if"),if_DASH_244518);
if(--R.GAS > 0) {
$z45194520 = R.isFunction(if_helper633206)?if_helper633206.app(cont_tail_arg654521):R.ffi.throwNonFunApp(L[159],if_helper633206,[cont_tail_arg654521]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper633206)?if_helper633206.app(cont_tail_arg654521):R.ffi.throwNonFunApp(L[159],if_helper633206,[cont_tail_arg654521]);
},
"from":L[159]});
}
++R.GAS;
return $z45194520;
}
};
},{"length":3});
var anf_variant_member794427 = R.makeMethod(function(self234492) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[159],0,arguments);
}
var anf_arg754491 = G(self234492,"code",L[159]);
var $z44834484 = D;
var $f44894490 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg754491):R.ffi.throwNonFunApp(L[159],torepr17,[anf_arg754491]);
};
try {
if(--R.GAS > 0) {
$z44834484 = $f44894490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44894490,
"from":L[159]});
}
} catch($e44814482) {
if(R.isCont($e44814482)) {
var $ss44854486 = {"from":L[159],
"go":function(anf_arg763167) {
return $Hanf_arg7833166(anf_arg763167,_plus13);
}};
$e44814482.stack[R.EXN_STACKHEIGHT++] = $ss44854486;
}
if(R.isPyretException($e44814482)) {
$e44814482.pyretStack.push(L[159]);
}
throw $e44814482;
}
var $ret44874488 = $Hanf_arg7833166($z44834484,_plus13);
++R.GAS;
return $ret44874488;
};
},{"length":1});
var anf_variant_member914434 = R.makeMethod(function(self264461) {
return function(cases_DASH_funs274462,else_DASH_clause284473) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[158],2,arguments);
}
var if_DASH_304474 = R.hasField(cases_DASH_funs274462,("err"));
var if_helper813159 = R.makeFunction(function(if_helper_arg824479) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[158],1,arguments);
}
var ann_DASH_check_DASH_temp804480 = if_helper_arg824479;
return ann_DASH_check_DASH_temp804480;
});
var anf_if854478 = R.isBoolean(if_DASH_304474);
if(R.isPyretTrue(anf_if854478)) {
if(R.isPyretTrue(if_DASH_304474)) {
var call_DASH_err254459 = G(cases_DASH_funs274462,"err",L[158]);
var anf_arg884460 = G(self264461,"problems",L[272]);
var $z44514452 = D;
var $f44574458 = function(_) {
return R.isFunction(call_DASH_err254459)?call_DASH_err254459.app(anf_arg884460):R.ffi.throwNonFunApp(L[158],call_DASH_err254459,[anf_arg884460]);
};
try {
if(--R.GAS > 0) {
$z44514452 = $f44574458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44574458,
"from":L[158]});
}
} catch($e44494450) {
if(R.isCont($e44494450)) {
var $ss44534454 = {"from":L[158],
"go":function(cont_tail_arg893158) {
return $Hcont_tail_arg7843157(cont_tail_arg893158,if_helper813159);
}};
$e44494450.stack[R.EXN_STACKHEIGHT++] = $ss44534454;
}
if(R.isPyretException($e44494450)) {
$e44494450.pyretStack.push(L[158]);
}
throw $e44494450;
}
var $ret44554456 = $Hcont_tail_arg7843157($z44514452,if_helper813159);
++R.GAS;
return $ret44554456;
} else {
var $z44654466 = D;
var $f44714472 = function(_) {
return R.isFunction(else_DASH_clause284473)?else_DASH_clause284473.app():R.ffi.throwNonFunApp(L[158],else_DASH_clause284473,[]);
};
try {
if(--R.GAS > 0) {
$z44654466 = $f44714472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44714472,
"from":L[158]});
}
} catch($e44634464) {
if(R.isCont($e44634464)) {
var $ss44674468 = {"from":L[158],
"go":function(cont_tail_arg863163) {
return $Hcont_tail_arg7853162(cont_tail_arg863163,if_helper813159);
}};
$e44634464.stack[R.EXN_STACKHEIGHT++] = $ss44674468;
}
if(R.isPyretException($e44634464)) {
$e44634464.pyretStack.push(L[158]);
}
throw $e44634464;
}
var $ret44694470 = $Hcont_tail_arg7853162($z44654466,if_helper813159);
++R.GAS;
return $ret44694470;
}
} else {
var cont_tail_arg834477 = R.throwNonBooleanCondition(L[158],("if"),if_DASH_304474);
if(--R.GAS > 0) {
$z44754476 = R.isFunction(if_helper813159)?if_helper813159.app(cont_tail_arg834477):R.ffi.throwNonFunApp(L[158],if_helper813159,[cont_tail_arg834477]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper813159)?if_helper813159.app(cont_tail_arg834477):R.ffi.throwNonFunApp(L[158],if_helper813159,[cont_tail_arg834477]);
},
"from":L[158]});
}
++R.GAS;
return $z44754476;
}
};
},{"length":3});
var anf_variant_member974435 = R.makeMethod(function(self294448) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[158],0,arguments);
}
var anf_arg934447 = G(self294448,"problems",L[158]);
var $z44394440 = D;
var $f44454446 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg934447):R.ffi.throwNonFunApp(L[158],torepr17,[anf_arg934447]);
};
try {
if(--R.GAS > 0) {
$z44394440 = $f44454446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44454446,
"from":L[158]});
}
} catch($e44374438) {
if(R.isCont($e44374438)) {
var $ss44414442 = {"from":L[158],
"go":function(anf_arg943120) {
return $Hanf_arg7893119(anf_arg943120,_plus13);
}};
$e44374438.stack[R.EXN_STACKHEIGHT++] = $ss44414442;
}
if(R.isPyretException($e44374438)) {
$e44374438.pyretStack.push(L[158]);
}
throw $e44374438;
}
var $ret44434444 = $Hanf_arg7893119($z44394440,_plus13);
++R.GAS;
return $ret44434444;
};
},{"length":1});
var anf_assign983339 = (function() {
var $ok_DASH_base44214422 = {"_match":anf_variant_member734426,
"_torepr":anf_variant_member794427};
var $ok_DASH_brands44244425 = {"$brand-ok4423":true};
$ok_DASH_brands44244425[CompileResultT3693321._brand] = true
var $err_DASH_base44294430 = {"_match":anf_variant_member914434,
"_torepr":anf_variant_member974435};
var $err_DASH_brands44324433 = {"$brand-err4431":true};
$err_DASH_brands44324433[CompileResultT3693321._brand] = true
return R.makeObject({"CompileResult":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[268],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CompileResultT3693321._brand));
}),
"is-ok":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[159],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-ok4423"));
}),
"ok":R.makeFunction(function(code1374428) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[269],1,arguments);
}
var dict = R.create($ok_DASH_base44214422);
dict["code"] = code1374428
return R.makeBrandedObject(dict,$ok_DASH_brands44244425);
}),
"is-err":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[158],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-err4431"));
}),
"err":R.makeFunction(function(problems1384436) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[270],1,arguments);
}
return R.checkAnnArgs([List1555],[problems1384436],[L[271]],function() {
var dict = R.create($err_DASH_base44294430);
dict["problems"] = problems1384436
return R.makeBrandedObject(dict,$err_DASH_brands44324433);
});
})});
})();
CompileResult9893338.$var = anf_assign983339;
var anf_assign993340 = G(CompileResult9893338.$var,"CompileResult",L[268]);
CompileResult9052.$var = anf_assign993340;
var anf_assign1003341 = G(CompileResult9893338.$var,"CompileResult",L[268]);
is_DASH_CompileResult9168.$var = anf_assign1003341;
var anf_assign1013342 = G(CompileResult9893338.$var,"is-ok",L[159]);
is_DASH_ok9277.$var = anf_assign1013342;
var anf_assign1023343 = G(CompileResult9893338.$var,"ok",L[159]);
ok9393.$var = anf_assign1023343;
var anf_assign1033344 = G(CompileResult9893338.$var,"is-err",L[158]);
is_DASH_err9475.$var = anf_assign1033344;
var anf_assign1043345 = G(CompileResult9893338.$var,"err",L[158]);
err9564.$var = anf_assign1043345;
var anf_variant_member1173507 = R.makeMethod(function(self324401) {
return function(cases_DASH_funs334402,else_DASH_clause344413) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[157],2,arguments);
}
var if_DASH_364414 = R.hasField(cases_DASH_funs334402,("wf-err"));
var if_helper1063112 = R.makeFunction(function(if_helper_arg1074419) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[157],1,arguments);
}
var ann_DASH_check_DASH_temp1054420 = if_helper_arg1074419;
return ann_DASH_check_DASH_temp1054420;
});
var anf_if1104418 = R.isBoolean(if_DASH_364414);
if(R.isPyretTrue(anf_if1104418)) {
if(R.isPyretTrue(if_DASH_364414)) {
var call_DASH_wf_DASH_err314398 = G(cases_DASH_funs334402,"wf-err",L[157]);
var anf_arg1134399 = G(self324401,"msg",L[267]);
var anf_arg1144400 = G(self324401,"loc",L[266]);
var $z43904391 = D;
var $f43964397 = function(_) {
return R.isFunction(call_DASH_wf_DASH_err314398)?call_DASH_wf_DASH_err314398.app(anf_arg1134399,anf_arg1144400):R.ffi.throwNonFunApp(L[157],call_DASH_wf_DASH_err314398,[anf_arg1134399,anf_arg1144400]);
};
try {
if(--R.GAS > 0) {
$z43904391 = $f43964397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43964397,
"from":L[157]});
}
} catch($e43884389) {
if(R.isCont($e43884389)) {
var $ss43924393 = {"from":L[157],
"go":function(cont_tail_arg1153111) {
return $Hcont_tail_arg7903110(cont_tail_arg1153111,if_helper1063112);
}};
$e43884389.stack[R.EXN_STACKHEIGHT++] = $ss43924393;
}
if(R.isPyretException($e43884389)) {
$e43884389.pyretStack.push(L[157]);
}
throw $e43884389;
}
var $ret43944395 = $Hcont_tail_arg7903110($z43904391,if_helper1063112);
++R.GAS;
return $ret43944395;
} else {
var $z44054406 = D;
var $f44114412 = function(_) {
return R.isFunction(else_DASH_clause344413)?else_DASH_clause344413.app():R.ffi.throwNonFunApp(L[157],else_DASH_clause344413,[]);
};
try {
if(--R.GAS > 0) {
$z44054406 = $f44114412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44114412,
"from":L[157]});
}
} catch($e44034404) {
if(R.isCont($e44034404)) {
var $ss44074408 = {"from":L[157],
"go":function(cont_tail_arg1113116) {
return $Hcont_tail_arg7913115(cont_tail_arg1113116,if_helper1063112);
}};
$e44034404.stack[R.EXN_STACKHEIGHT++] = $ss44074408;
}
if(R.isPyretException($e44034404)) {
$e44034404.pyretStack.push(L[157]);
}
throw $e44034404;
}
var $ret44094410 = $Hcont_tail_arg7913115($z44054406,if_helper1063112);
++R.GAS;
return $ret44094410;
}
} else {
var cont_tail_arg1084417 = R.throwNonBooleanCondition(L[157],("if"),if_DASH_364414);
if(--R.GAS > 0) {
$z44154416 = R.isFunction(if_helper1063112)?if_helper1063112.app(cont_tail_arg1084417):R.ffi.throwNonFunApp(L[157],if_helper1063112,[cont_tail_arg1084417]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1063112)?if_helper1063112.app(cont_tail_arg1084417):R.ffi.throwNonFunApp(L[157],if_helper1063112,[cont_tail_arg1084417]);
},
"from":L[157]});
}
++R.GAS;
return $z44154416;
}
};
},{"length":3});
var anf_variant_member1273508 = R.makeMethod(function(self353036) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[157],0,arguments);
}
var anf_arg1194387 = G(self353036,"msg",L[157]);
var $z43794380 = D;
var $f43854386 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg1194387):R.ffi.throwNonFunApp(L[157],torepr17,[anf_arg1194387]);
};
try {
if(--R.GAS > 0) {
$z43794380 = $f43854386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43854386,
"from":L[157]});
}
} catch($e43774378) {
if(R.isCont($e43774378)) {
var $ss43814382 = {"from":L[157],
"go":function(anf_arg1203035) {
return $Hanf_arg7983034(anf_arg1203035,self353036,_plus13,torepr17);
}};
$e43774378.stack[R.EXN_STACKHEIGHT++] = $ss43814382;
}
if(R.isPyretException($e43774378)) {
$e43774378.pyretStack.push(L[157]);
}
throw $e43774378;
}
var $ret43834384 = $Hanf_arg7983034($z43794380,self353036,_plus13,torepr17);
++R.GAS;
return $ret43834384;
};
},{"length":1});
var anf_variant_member1343509 = R.makeMethod(function(self1412996) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[156],0,arguments);
}
var anf_arg1294376 = G(self1412996,"msg",L[265]);
var $z43684369 = D;
var $f43744375 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("well-formedness: "),anf_arg1294376):R.ffi.throwNonFunApp(L[153],_plus13,[("well-formedness: "),anf_arg1294376]);
};
try {
if(--R.GAS > 0) {
$z43684369 = $f43744375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43744375,
"from":L[153]});
}
} catch($e43664367) {
if(R.isCont($e43664367)) {
var $ss43704371 = {"from":L[153],
"go":function(anf_arg1302995) {
return $Hanf_arg8022994(anf_arg1302995,self1412996,_plus13,tostring18);
}};
$e43664367.stack[R.EXN_STACKHEIGHT++] = $ss43704371;
}
if(R.isPyretException($e43664367)) {
$e43664367.pyretStack.push(L[153]);
}
throw $e43664367;
}
var $ret43724373 = $Hanf_arg8022994($z43684369,self1412996,_plus13,tostring18);
++R.GAS;
return $ret43724373;
};
},{"length":1});
var anf_variant_member1473517 = R.makeMethod(function(self384346) {
return function(cases_DASH_funs394347,else_DASH_clause404358) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[152],2,arguments);
}
var if_DASH_424359 = R.hasField(cases_DASH_funs394347,("wf-err-split"));
var if_helper1362987 = R.makeFunction(function(if_helper_arg1374364) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[152],1,arguments);
}
var ann_DASH_check_DASH_temp1354365 = if_helper_arg1374364;
return ann_DASH_check_DASH_temp1354365;
});
var anf_if1404363 = R.isBoolean(if_DASH_424359);
if(R.isPyretTrue(anf_if1404363)) {
if(R.isPyretTrue(if_DASH_424359)) {
var call_DASH_wf_DASH_err_DASH_split374343 = G(cases_DASH_funs394347,"wf-err-split",L[152]);
var anf_arg1434344 = G(self384346,"msg",L[264]);
var anf_arg1444345 = G(self384346,"loc",L[263]);
var $z43354336 = D;
var $f43414342 = function(_) {
return R.isFunction(call_DASH_wf_DASH_err_DASH_split374343)?call_DASH_wf_DASH_err_DASH_split374343.app(anf_arg1434344,anf_arg1444345):R.ffi.throwNonFunApp(L[152],call_DASH_wf_DASH_err_DASH_split374343,[anf_arg1434344,anf_arg1444345]);
};
try {
if(--R.GAS > 0) {
$z43354336 = $f43414342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43414342,
"from":L[152]});
}
} catch($e43334334) {
if(R.isCont($e43334334)) {
var $ss43374338 = {"from":L[152],
"go":function(cont_tail_arg1452986) {
return $Hcont_tail_arg8032985(cont_tail_arg1452986,if_helper1362987);
}};
$e43334334.stack[R.EXN_STACKHEIGHT++] = $ss43374338;
}
if(R.isPyretException($e43334334)) {
$e43334334.pyretStack.push(L[152]);
}
throw $e43334334;
}
var $ret43394340 = $Hcont_tail_arg8032985($z43354336,if_helper1362987);
++R.GAS;
return $ret43394340;
} else {
var $z43504351 = D;
var $f43564357 = function(_) {
return R.isFunction(else_DASH_clause404358)?else_DASH_clause404358.app():R.ffi.throwNonFunApp(L[152],else_DASH_clause404358,[]);
};
try {
if(--R.GAS > 0) {
$z43504351 = $f43564357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43564357,
"from":L[152]});
}
} catch($e43484349) {
if(R.isCont($e43484349)) {
var $ss43524353 = {"from":L[152],
"go":function(cont_tail_arg1412991) {
return $Hcont_tail_arg8042990(cont_tail_arg1412991,if_helper1362987);
}};
$e43484349.stack[R.EXN_STACKHEIGHT++] = $ss43524353;
}
if(R.isPyretException($e43484349)) {
$e43484349.pyretStack.push(L[152]);
}
throw $e43484349;
}
var $ret43544355 = $Hcont_tail_arg8042990($z43504351,if_helper1362987);
++R.GAS;
return $ret43544355;
}
} else {
var cont_tail_arg1384362 = R.throwNonBooleanCondition(L[152],("if"),if_DASH_424359);
if(--R.GAS > 0) {
$z43604361 = R.isFunction(if_helper1362987)?if_helper1362987.app(cont_tail_arg1384362):R.ffi.throwNonFunApp(L[152],if_helper1362987,[cont_tail_arg1384362]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1362987)?if_helper1362987.app(cont_tail_arg1384362):R.ffi.throwNonFunApp(L[152],if_helper1362987,[cont_tail_arg1384362]);
},
"from":L[152]});
}
++R.GAS;
return $z43604361;
}
};
},{"length":3});
var anf_variant_member1573518 = R.makeMethod(function(self412911) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[152],0,arguments);
}
var anf_arg1494332 = G(self412911,"msg",L[152]);
var $z43244325 = D;
var $f43304331 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg1494332):R.ffi.throwNonFunApp(L[152],torepr17,[anf_arg1494332]);
};
try {
if(--R.GAS > 0) {
$z43244325 = $f43304331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43304331,
"from":L[152]});
}
} catch($e43224323) {
if(R.isCont($e43224323)) {
var $ss43264327 = {"from":L[152],
"go":function(anf_arg1502910) {
return $Hanf_arg8112909(anf_arg1502910,self412911,_plus13,torepr17);
}};
$e43224323.stack[R.EXN_STACKHEIGHT++] = $ss43264327;
}
if(R.isPyretException($e43224323)) {
$e43224323.pyretStack.push(L[152]);
}
throw $e43224323;
}
var $ret43284329 = $Hanf_arg8112909($z43244325,self412911,_plus13,torepr17);
++R.GAS;
return $ret43284329;
};
},{"length":1});
var anf_variant_member1673519 = R.makeMethod(function(self1442857) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[151],0,arguments);
}
var anf_arg1594321 = G(self1442857,"msg",L[262]);
var $z43134314 = D;
var $f43194320 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("well-formedness: "),anf_arg1594321):R.ffi.throwNonFunApp(L[145],_plus13,[("well-formedness: "),anf_arg1594321]);
};
try {
if(--R.GAS > 0) {
$z43134314 = $f43194320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43194320,
"from":L[145]});
}
} catch($e43114312) {
if(R.isCont($e43114312)) {
var $ss43154316 = {"from":L[145],
"go":function(anf_arg1602856) {
return $Hanf_arg8162855(anf_arg1602856,self1442857,_plus13,tostring18);
}};
$e43114312.stack[R.EXN_STACKHEIGHT++] = $ss43154316;
}
if(R.isPyretException($e43114312)) {
$e43114312.pyretStack.push(L[145]);
}
throw $e43114312;
}
var $ret43174318 = $Hanf_arg8162855($z43134314,self1442857,_plus13,tostring18);
++R.GAS;
return $ret43174318;
};
},{"length":1});
var anf_variant_member1803527 = R.makeMethod(function(self444291) {
return function(cases_DASH_funs454292,else_DASH_clause464303) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[144],2,arguments);
}
var if_DASH_484304 = R.hasField(cases_DASH_funs454292,("reserved-name"));
var if_helper1692848 = R.makeFunction(function(if_helper_arg1704309) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[144],1,arguments);
}
var ann_DASH_check_DASH_temp1684310 = if_helper_arg1704309;
return ann_DASH_check_DASH_temp1684310;
});
var anf_if1734308 = R.isBoolean(if_DASH_484304);
if(R.isPyretTrue(anf_if1734308)) {
if(R.isPyretTrue(if_DASH_484304)) {
var call_DASH_reserved_DASH_name434288 = G(cases_DASH_funs454292,"reserved-name",L[144]);
var anf_arg1764289 = G(self444291,"loc",L[261]);
var anf_arg1774290 = G(self444291,"id",L[260]);
var $z42804281 = D;
var $f42864287 = function(_) {
return R.isFunction(call_DASH_reserved_DASH_name434288)?call_DASH_reserved_DASH_name434288.app(anf_arg1764289,anf_arg1774290):R.ffi.throwNonFunApp(L[144],call_DASH_reserved_DASH_name434288,[anf_arg1764289,anf_arg1774290]);
};
try {
if(--R.GAS > 0) {
$z42804281 = $f42864287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42864287,
"from":L[144]});
}
} catch($e42784279) {
if(R.isCont($e42784279)) {
var $ss42824283 = {"from":L[144],
"go":function(cont_tail_arg1782847) {
return $Hcont_tail_arg8172846(cont_tail_arg1782847,if_helper1692848);
}};
$e42784279.stack[R.EXN_STACKHEIGHT++] = $ss42824283;
}
if(R.isPyretException($e42784279)) {
$e42784279.pyretStack.push(L[144]);
}
throw $e42784279;
}
var $ret42844285 = $Hcont_tail_arg8172846($z42804281,if_helper1692848);
++R.GAS;
return $ret42844285;
} else {
var $z42954296 = D;
var $f43014302 = function(_) {
return R.isFunction(else_DASH_clause464303)?else_DASH_clause464303.app():R.ffi.throwNonFunApp(L[144],else_DASH_clause464303,[]);
};
try {
if(--R.GAS > 0) {
$z42954296 = $f43014302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43014302,
"from":L[144]});
}
} catch($e42934294) {
if(R.isCont($e42934294)) {
var $ss42974298 = {"from":L[144],
"go":function(cont_tail_arg1742852) {
return $Hcont_tail_arg8182851(cont_tail_arg1742852,if_helper1692848);
}};
$e42934294.stack[R.EXN_STACKHEIGHT++] = $ss42974298;
}
if(R.isPyretException($e42934294)) {
$e42934294.pyretStack.push(L[144]);
}
throw $e42934294;
}
var $ret42994300 = $Hcont_tail_arg8182851($z42954296,if_helper1692848);
++R.GAS;
return $ret42994300;
}
} else {
var cont_tail_arg1714307 = R.throwNonBooleanCondition(L[144],("if"),if_DASH_484304);
if(--R.GAS > 0) {
$z43054306 = R.isFunction(if_helper1692848)?if_helper1692848.app(cont_tail_arg1714307):R.ffi.throwNonFunApp(L[144],if_helper1692848,[cont_tail_arg1714307]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1692848)?if_helper1692848.app(cont_tail_arg1714307):R.ffi.throwNonFunApp(L[144],if_helper1692848,[cont_tail_arg1714307]);
},
"from":L[144]});
}
++R.GAS;
return $z43054306;
}
};
},{"length":3});
var anf_variant_member1903528 = R.makeMethod(function(self472772) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[144],0,arguments);
}
var anf_arg1824277 = G(self472772,"loc",L[144]);
var $z42694270 = D;
var $f42754276 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg1824277):R.ffi.throwNonFunApp(L[144],torepr17,[anf_arg1824277]);
};
try {
if(--R.GAS > 0) {
$z42694270 = $f42754276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42754276,
"from":L[144]});
}
} catch($e42674268) {
if(R.isCont($e42674268)) {
var $ss42714272 = {"from":L[144],
"go":function(anf_arg1832771) {
return $Hanf_arg8252770(anf_arg1832771,self472772,_plus13,torepr17);
}};
$e42674268.stack[R.EXN_STACKHEIGHT++] = $ss42714272;
}
if(R.isPyretException($e42674268)) {
$e42674268.pyretStack.push(L[144]);
}
throw $e42674268;
}
var $ret42734274 = $Hanf_arg8252770($z42694270,self472772,_plus13,torepr17);
++R.GAS;
return $ret42734274;
};
},{"length":1});
var anf_variant_member1973529 = R.makeMethod(function(self1472732) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[143],0,arguments);
}
var anf_arg1924266 = G(self1472732,"id",L[259]);
var $z42584259 = D;
var $f42644265 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("well-formedness: cannot use "),anf_arg1924266):R.ffi.throwNonFunApp(L[140],_plus13,[("well-formedness: cannot use "),anf_arg1924266]);
};
try {
if(--R.GAS > 0) {
$z42584259 = $f42644265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42644265,
"from":L[140]});
}
} catch($e42564257) {
if(R.isCont($e42564257)) {
var $ss42604261 = {"from":L[140],
"go":function(anf_arg1932731) {
return $Hanf_arg8292730(anf_arg1932731,self1472732,_plus13,tostring18);
}};
$e42564257.stack[R.EXN_STACKHEIGHT++] = $ss42604261;
}
if(R.isPyretException($e42564257)) {
$e42564257.pyretStack.push(L[140]);
}
throw $e42564257;
}
var $ret42624263 = $Hanf_arg8292730($z42584259,self1472732,_plus13,tostring18);
++R.GAS;
return $ret42624263;
};
},{"length":1});
var anf_variant_member2103537 = R.makeMethod(function(self504236) {
return function(cases_DASH_funs514237,else_DASH_clause524248) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[139],2,arguments);
}
var if_DASH_544249 = R.hasField(cases_DASH_funs514237,("zero-fraction"));
var if_helper1992723 = R.makeFunction(function(if_helper_arg2004254) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[139],1,arguments);
}
var ann_DASH_check_DASH_temp1984255 = if_helper_arg2004254;
return ann_DASH_check_DASH_temp1984255;
});
var anf_if2034253 = R.isBoolean(if_DASH_544249);
if(R.isPyretTrue(anf_if2034253)) {
if(R.isPyretTrue(if_DASH_544249)) {
var call_DASH_zero_DASH_fraction494233 = G(cases_DASH_funs514237,"zero-fraction",L[139]);
var anf_arg2064234 = G(self504236,"loc",L[258]);
var anf_arg2074235 = G(self504236,"numerator",L[257]);
var $z42254226 = D;
var $f42314232 = function(_) {
return R.isFunction(call_DASH_zero_DASH_fraction494233)?call_DASH_zero_DASH_fraction494233.app(anf_arg2064234,anf_arg2074235):R.ffi.throwNonFunApp(L[139],call_DASH_zero_DASH_fraction494233,[anf_arg2064234,anf_arg2074235]);
};
try {
if(--R.GAS > 0) {
$z42254226 = $f42314232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42314232,
"from":L[139]});
}
} catch($e42234224) {
if(R.isCont($e42234224)) {
var $ss42274228 = {"from":L[139],
"go":function(cont_tail_arg2082722) {
return $Hcont_tail_arg8302721(cont_tail_arg2082722,if_helper1992723);
}};
$e42234224.stack[R.EXN_STACKHEIGHT++] = $ss42274228;
}
if(R.isPyretException($e42234224)) {
$e42234224.pyretStack.push(L[139]);
}
throw $e42234224;
}
var $ret42294230 = $Hcont_tail_arg8302721($z42254226,if_helper1992723);
++R.GAS;
return $ret42294230;
} else {
var $z42404241 = D;
var $f42464247 = function(_) {
return R.isFunction(else_DASH_clause524248)?else_DASH_clause524248.app():R.ffi.throwNonFunApp(L[139],else_DASH_clause524248,[]);
};
try {
if(--R.GAS > 0) {
$z42404241 = $f42464247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42464247,
"from":L[139]});
}
} catch($e42384239) {
if(R.isCont($e42384239)) {
var $ss42424243 = {"from":L[139],
"go":function(cont_tail_arg2042727) {
return $Hcont_tail_arg8312726(cont_tail_arg2042727,if_helper1992723);
}};
$e42384239.stack[R.EXN_STACKHEIGHT++] = $ss42424243;
}
if(R.isPyretException($e42384239)) {
$e42384239.pyretStack.push(L[139]);
}
throw $e42384239;
}
var $ret42444245 = $Hcont_tail_arg8312726($z42404241,if_helper1992723);
++R.GAS;
return $ret42444245;
}
} else {
var cont_tail_arg2014252 = R.throwNonBooleanCondition(L[139],("if"),if_DASH_544249);
if(--R.GAS > 0) {
$z42504251 = R.isFunction(if_helper1992723)?if_helper1992723.app(cont_tail_arg2014252):R.ffi.throwNonFunApp(L[139],if_helper1992723,[cont_tail_arg2014252]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper1992723)?if_helper1992723.app(cont_tail_arg2014252):R.ffi.throwNonFunApp(L[139],if_helper1992723,[cont_tail_arg2014252]);
},
"from":L[139]});
}
++R.GAS;
return $z42504251;
}
};
},{"length":3});
var anf_variant_member2203538 = R.makeMethod(function(self532647) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[139],0,arguments);
}
var anf_arg2124222 = G(self532647,"loc",L[139]);
var $z42144215 = D;
var $f42204221 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg2124222):R.ffi.throwNonFunApp(L[139],torepr17,[anf_arg2124222]);
};
try {
if(--R.GAS > 0) {
$z42144215 = $f42204221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42204221,
"from":L[139]});
}
} catch($e42124213) {
if(R.isCont($e42124213)) {
var $ss42164217 = {"from":L[139],
"go":function(anf_arg2132646) {
return $Hanf_arg8382645(anf_arg2132646,self532647,_plus13,torepr17);
}};
$e42124213.stack[R.EXN_STACKHEIGHT++] = $ss42164217;
}
if(R.isPyretException($e42124213)) {
$e42124213.pyretStack.push(L[139]);
}
throw $e42124213;
}
var $ret42184219 = $Hanf_arg8382645($z42144215,self532647,_plus13,torepr17);
++R.GAS;
return $ret42184219;
};
},{"length":1});
var anf_variant_member2283539 = R.makeMethod(function(self1502595) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[138],0,arguments);
}
var anf_arg2224211 = G(self1502595,"numerator",L[256]);
var $z42034204 = D;
var $f42094210 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg2224211):R.ffi.throwNonFunApp(L[255],tostring18,[anf_arg2224211]);
};
try {
if(--R.GAS > 0) {
$z42034204 = $f42094210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42094210,
"from":L[255]});
}
} catch($e42014202) {
if(R.isCont($e42014202)) {
var $ss42054206 = {"from":L[255],
"go":function(anf_arg2232594) {
return $Hanf_arg8432593(anf_arg2232594,self1502595,_plus13,tostring18);
}};
$e42014202.stack[R.EXN_STACKHEIGHT++] = $ss42054206;
}
if(R.isPyretException($e42014202)) {
$e42014202.pyretStack.push(L[255]);
}
throw $e42014202;
}
var $ret42074208 = $Hanf_arg8432593($z42034204,self1502595,_plus13,tostring18);
++R.GAS;
return $ret42074208;
};
},{"length":1});
var anf_variant_member2403547 = R.makeMethod(function(self564181) {
return function(cases_DASH_funs574182,else_DASH_clause584193) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[134],2,arguments);
}
var if_DASH_604194 = R.hasField(cases_DASH_funs574182,("unbound-id"));
var if_helper2302586 = R.makeFunction(function(if_helper_arg2314199) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[134],1,arguments);
}
var ann_DASH_check_DASH_temp2294200 = if_helper_arg2314199;
return ann_DASH_check_DASH_temp2294200;
});
var anf_if2344198 = R.isBoolean(if_DASH_604194);
if(R.isPyretTrue(anf_if2344198)) {
if(R.isPyretTrue(if_DASH_604194)) {
var call_DASH_unbound_DASH_id554179 = G(cases_DASH_funs574182,"unbound-id",L[134]);
var anf_arg2374180 = G(self564181,"id",L[254]);
var $z41714172 = D;
var $f41774178 = function(_) {
return R.isFunction(call_DASH_unbound_DASH_id554179)?call_DASH_unbound_DASH_id554179.app(anf_arg2374180):R.ffi.throwNonFunApp(L[134],call_DASH_unbound_DASH_id554179,[anf_arg2374180]);
};
try {
if(--R.GAS > 0) {
$z41714172 = $f41774178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41774178,
"from":L[134]});
}
} catch($e41694170) {
if(R.isCont($e41694170)) {
var $ss41734174 = {"from":L[134],
"go":function(cont_tail_arg2382585) {
return $Hcont_tail_arg8442584(cont_tail_arg2382585,if_helper2302586);
}};
$e41694170.stack[R.EXN_STACKHEIGHT++] = $ss41734174;
}
if(R.isPyretException($e41694170)) {
$e41694170.pyretStack.push(L[134]);
}
throw $e41694170;
}
var $ret41754176 = $Hcont_tail_arg8442584($z41714172,if_helper2302586);
++R.GAS;
return $ret41754176;
} else {
var $z41854186 = D;
var $f41914192 = function(_) {
return R.isFunction(else_DASH_clause584193)?else_DASH_clause584193.app():R.ffi.throwNonFunApp(L[134],else_DASH_clause584193,[]);
};
try {
if(--R.GAS > 0) {
$z41854186 = $f41914192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41914192,
"from":L[134]});
}
} catch($e41834184) {
if(R.isCont($e41834184)) {
var $ss41874188 = {"from":L[134],
"go":function(cont_tail_arg2352590) {
return $Hcont_tail_arg8452589(cont_tail_arg2352590,if_helper2302586);
}};
$e41834184.stack[R.EXN_STACKHEIGHT++] = $ss41874188;
}
if(R.isPyretException($e41834184)) {
$e41834184.pyretStack.push(L[134]);
}
throw $e41834184;
}
var $ret41894190 = $Hcont_tail_arg8452589($z41854186,if_helper2302586);
++R.GAS;
return $ret41894190;
}
} else {
var cont_tail_arg2324197 = R.throwNonBooleanCondition(L[134],("if"),if_DASH_604194);
if(--R.GAS > 0) {
$z41954196 = R.isFunction(if_helper2302586)?if_helper2302586.app(cont_tail_arg2324197):R.ffi.throwNonFunApp(L[134],if_helper2302586,[cont_tail_arg2324197]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2302586)?if_helper2302586.app(cont_tail_arg2324197):R.ffi.throwNonFunApp(L[134],if_helper2302586,[cont_tail_arg2324197]);
},
"from":L[134]});
}
++R.GAS;
return $z41954196;
}
};
},{"length":3});
var anf_variant_member2463548 = R.makeMethod(function(self594168) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[134],0,arguments);
}
var anf_arg2424167 = G(self594168,"id",L[134]);
var $z41594160 = D;
var $f41654166 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg2424167):R.ffi.throwNonFunApp(L[134],torepr17,[anf_arg2424167]);
};
try {
if(--R.GAS > 0) {
$z41594160 = $f41654166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41654166,
"from":L[134]});
}
} catch($e41574158) {
if(R.isCont($e41574158)) {
var $ss41614162 = {"from":L[134],
"go":function(anf_arg2432547) {
return $Hanf_arg8492546(anf_arg2432547,_plus13);
}};
$e41574158.stack[R.EXN_STACKHEIGHT++] = $ss41614162;
}
if(R.isPyretException($e41574158)) {
$e41574158.pyretStack.push(L[134]);
}
throw $e41574158;
}
var $ret41634164 = $Hanf_arg8492546($z41594160,_plus13);
++R.GAS;
return $ret41634164;
};
},{"length":1});
var anf_variant_member2573549 = R.makeMethod(function(self1522483) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[133],0,arguments);
}
var anf_bracket2484156 = G(self1522483,"id",L[253]);
var anf_arg2494155 = G(anf_bracket2484156,"id",L[252]);
var $z41474148 = D;
var $f41534154 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg2494155):R.ffi.throwNonFunApp(L[251],tostring18,[anf_arg2494155]);
};
try {
if(--R.GAS > 0) {
$z41474148 = $f41534154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41534154,
"from":L[251]});
}
} catch($e41454146) {
if(R.isCont($e41454146)) {
var $ss41494150 = {"from":L[251],
"go":function(anf_arg2502482) {
return $Hanf_arg8552481(anf_arg2502482,self1522483,_plus13,tostring18);
}};
$e41454146.stack[R.EXN_STACKHEIGHT++] = $ss41494150;
}
if(R.isPyretException($e41454146)) {
$e41454146.pyretStack.push(L[251]);
}
throw $e41454146;
}
var $ret41514152 = $Hanf_arg8552481($z41474148,self1522483,_plus13,tostring18);
++R.GAS;
return $ret41514152;
};
},{"length":1});
var anf_variant_member2703556 = R.makeMethod(function(self624125) {
return function(cases_DASH_funs634126,else_DASH_clause644137) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[128],2,arguments);
}
var if_DASH_664138 = R.hasField(cases_DASH_funs634126,("unbound-var"));
var if_helper2592474 = R.makeFunction(function(if_helper_arg2604143) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[128],1,arguments);
}
var ann_DASH_check_DASH_temp2584144 = if_helper_arg2604143;
return ann_DASH_check_DASH_temp2584144;
});
var anf_if2634142 = R.isBoolean(if_DASH_664138);
if(R.isPyretTrue(anf_if2634142)) {
if(R.isPyretTrue(if_DASH_664138)) {
var call_DASH_unbound_DASH_var614122 = G(cases_DASH_funs634126,"unbound-var",L[128]);
var anf_arg2664123 = G(self624125,"id",L[250]);
var anf_arg2674124 = G(self624125,"loc",L[249]);
var $z41144115 = D;
var $f41204121 = function(_) {
return R.isFunction(call_DASH_unbound_DASH_var614122)?call_DASH_unbound_DASH_var614122.app(anf_arg2664123,anf_arg2674124):R.ffi.throwNonFunApp(L[128],call_DASH_unbound_DASH_var614122,[anf_arg2664123,anf_arg2674124]);
};
try {
if(--R.GAS > 0) {
$z41144115 = $f41204121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41204121,
"from":L[128]});
}
} catch($e41124113) {
if(R.isCont($e41124113)) {
var $ss41164117 = {"from":L[128],
"go":function(cont_tail_arg2682473) {
return $Hcont_tail_arg8562472(cont_tail_arg2682473,if_helper2592474);
}};
$e41124113.stack[R.EXN_STACKHEIGHT++] = $ss41164117;
}
if(R.isPyretException($e41124113)) {
$e41124113.pyretStack.push(L[128]);
}
throw $e41124113;
}
var $ret41184119 = $Hcont_tail_arg8562472($z41144115,if_helper2592474);
++R.GAS;
return $ret41184119;
} else {
var $z41294130 = D;
var $f41354136 = function(_) {
return R.isFunction(else_DASH_clause644137)?else_DASH_clause644137.app():R.ffi.throwNonFunApp(L[128],else_DASH_clause644137,[]);
};
try {
if(--R.GAS > 0) {
$z41294130 = $f41354136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41354136,
"from":L[128]});
}
} catch($e41274128) {
if(R.isCont($e41274128)) {
var $ss41314132 = {"from":L[128],
"go":function(cont_tail_arg2642478) {
return $Hcont_tail_arg8572477(cont_tail_arg2642478,if_helper2592474);
}};
$e41274128.stack[R.EXN_STACKHEIGHT++] = $ss41314132;
}
if(R.isPyretException($e41274128)) {
$e41274128.pyretStack.push(L[128]);
}
throw $e41274128;
}
var $ret41334134 = $Hcont_tail_arg8572477($z41294130,if_helper2592474);
++R.GAS;
return $ret41334134;
}
} else {
var cont_tail_arg2614141 = R.throwNonBooleanCondition(L[128],("if"),if_DASH_664138);
if(--R.GAS > 0) {
$z41394140 = R.isFunction(if_helper2592474)?if_helper2592474.app(cont_tail_arg2614141):R.ffi.throwNonFunApp(L[128],if_helper2592474,[cont_tail_arg2614141]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2592474)?if_helper2592474.app(cont_tail_arg2614141):R.ffi.throwNonFunApp(L[128],if_helper2592474,[cont_tail_arg2614141]);
},
"from":L[128]});
}
++R.GAS;
return $z41394140;
}
};
},{"length":3});
var anf_variant_member2803557 = R.makeMethod(function(self652398) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[128],0,arguments);
}
var anf_arg2724111 = G(self652398,"id",L[128]);
var $z41034104 = D;
var $f41094110 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg2724111):R.ffi.throwNonFunApp(L[128],torepr17,[anf_arg2724111]);
};
try {
if(--R.GAS > 0) {
$z41034104 = $f41094110();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41094110,
"from":L[128]});
}
} catch($e41014102) {
if(R.isCont($e41014102)) {
var $ss41054106 = {"from":L[128],
"go":function(anf_arg2732397) {
return $Hanf_arg8642396(anf_arg2732397,self652398,_plus13,torepr17);
}};
$e41014102.stack[R.EXN_STACKHEIGHT++] = $ss41054106;
}
if(R.isPyretException($e41014102)) {
$e41014102.pyretStack.push(L[128]);
}
throw $e41014102;
}
var $ret41074108 = $Hanf_arg8642396($z41034104,self652398,_plus13,torepr17);
++R.GAS;
return $ret41074108;
};
},{"length":1});
var anf_variant_member2873558 = R.makeMethod(function(self1552358) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[127],0,arguments);
}
var anf_arg2824100 = G(self1552358,"id",L[248]);
var $z40924093 = D;
var $f40984099 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Assigning to unbound variable "),anf_arg2824100):R.ffi.throwNonFunApp(L[124],_plus13,[("Assigning to unbound variable "),anf_arg2824100]);
};
try {
if(--R.GAS > 0) {
$z40924093 = $f40984099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40984099,
"from":L[124]});
}
} catch($e40904091) {
if(R.isCont($e40904091)) {
var $ss40944095 = {"from":L[124],
"go":function(anf_arg2832357) {
return $Hanf_arg8682356(anf_arg2832357,self1552358,_plus13,tostring18);
}};
$e40904091.stack[R.EXN_STACKHEIGHT++] = $ss40944095;
}
if(R.isPyretException($e40904091)) {
$e40904091.pyretStack.push(L[124]);
}
throw $e40904091;
}
var $ret40964097 = $Hanf_arg8682356($z40924093,self1552358,_plus13,tostring18);
++R.GAS;
return $ret40964097;
};
},{"length":1});
var anf_variant_member2993566 = R.makeMethod(function(self684070) {
return function(cases_DASH_funs694071,else_DASH_clause704082) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[123],2,arguments);
}
var if_DASH_724083 = R.hasField(cases_DASH_funs694071,("unbound-type-id"));
var if_helper2892349 = R.makeFunction(function(if_helper_arg2904088) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[123],1,arguments);
}
var ann_DASH_check_DASH_temp2884089 = if_helper_arg2904088;
return ann_DASH_check_DASH_temp2884089;
});
var anf_if2934087 = R.isBoolean(if_DASH_724083);
if(R.isPyretTrue(anf_if2934087)) {
if(R.isPyretTrue(if_DASH_724083)) {
var call_DASH_unbound_DASH_type_DASH_id674068 = G(cases_DASH_funs694071,"unbound-type-id",L[123]);
var anf_arg2964069 = G(self684070,"ann",L[247]);
var $z40604061 = D;
var $f40664067 = function(_) {
return R.isFunction(call_DASH_unbound_DASH_type_DASH_id674068)?call_DASH_unbound_DASH_type_DASH_id674068.app(anf_arg2964069):R.ffi.throwNonFunApp(L[123],call_DASH_unbound_DASH_type_DASH_id674068,[anf_arg2964069]);
};
try {
if(--R.GAS > 0) {
$z40604061 = $f40664067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40664067,
"from":L[123]});
}
} catch($e40584059) {
if(R.isCont($e40584059)) {
var $ss40624063 = {"from":L[123],
"go":function(cont_tail_arg2972348) {
return $Hcont_tail_arg8692347(cont_tail_arg2972348,if_helper2892349);
}};
$e40584059.stack[R.EXN_STACKHEIGHT++] = $ss40624063;
}
if(R.isPyretException($e40584059)) {
$e40584059.pyretStack.push(L[123]);
}
throw $e40584059;
}
var $ret40644065 = $Hcont_tail_arg8692347($z40604061,if_helper2892349);
++R.GAS;
return $ret40644065;
} else {
var $z40744075 = D;
var $f40804081 = function(_) {
return R.isFunction(else_DASH_clause704082)?else_DASH_clause704082.app():R.ffi.throwNonFunApp(L[123],else_DASH_clause704082,[]);
};
try {
if(--R.GAS > 0) {
$z40744075 = $f40804081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40804081,
"from":L[123]});
}
} catch($e40724073) {
if(R.isCont($e40724073)) {
var $ss40764077 = {"from":L[123],
"go":function(cont_tail_arg2942353) {
return $Hcont_tail_arg8702352(cont_tail_arg2942353,if_helper2892349);
}};
$e40724073.stack[R.EXN_STACKHEIGHT++] = $ss40764077;
}
if(R.isPyretException($e40724073)) {
$e40724073.pyretStack.push(L[123]);
}
throw $e40724073;
}
var $ret40784079 = $Hcont_tail_arg8702352($z40744075,if_helper2892349);
++R.GAS;
return $ret40784079;
}
} else {
var cont_tail_arg2914086 = R.throwNonBooleanCondition(L[123],("if"),if_DASH_724083);
if(--R.GAS > 0) {
$z40844085 = R.isFunction(if_helper2892349)?if_helper2892349.app(cont_tail_arg2914086):R.ffi.throwNonFunApp(L[123],if_helper2892349,[cont_tail_arg2914086]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper2892349)?if_helper2892349.app(cont_tail_arg2914086):R.ffi.throwNonFunApp(L[123],if_helper2892349,[cont_tail_arg2914086]);
},
"from":L[123]});
}
++R.GAS;
return $z40844085;
}
};
},{"length":3});
var anf_variant_member3053567 = R.makeMethod(function(self714057) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[123],0,arguments);
}
var anf_arg3014056 = G(self714057,"ann",L[123]);
var $z40484049 = D;
var $f40544055 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg3014056):R.ffi.throwNonFunApp(L[123],torepr17,[anf_arg3014056]);
};
try {
if(--R.GAS > 0) {
$z40484049 = $f40544055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40544055,
"from":L[123]});
}
} catch($e40464047) {
if(R.isCont($e40464047)) {
var $ss40504051 = {"from":L[123],
"go":function(anf_arg3022310) {
return $Hanf_arg8742309(anf_arg3022310,_plus13);
}};
$e40464047.stack[R.EXN_STACKHEIGHT++] = $ss40504051;
}
if(R.isPyretException($e40464047)) {
$e40464047.pyretStack.push(L[123]);
}
throw $e40464047;
}
var $ret40524053 = $Hanf_arg8742309($z40484049,_plus13);
++R.GAS;
return $ret40524053;
};
},{"length":1});
var anf_variant_member3173568 = R.makeMethod(function(self1572246) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[122],0,arguments);
}
var anf_bracket3074045 = G(self1572246,"ann",L[246]);
var anf_bracket3084044 = G(anf_bracket3074045,"id",L[245]);
var anf_fun3094043 = G(anf_bracket3084044,"toname",L[244]);
var $z40354036 = D;
var $f40414042 = function(_) {
return R.isFunction(anf_fun3094043)?anf_fun3094043.app():R.ffi.throwNonFunApp(L[243],anf_fun3094043,[]);
};
try {
if(--R.GAS > 0) {
$z40354036 = $f40414042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40414042,
"from":L[243]});
}
} catch($e40334034) {
if(R.isCont($e40334034)) {
var $ss40374038 = {"from":L[243],
"go":function(anf_arg3102245) {
return $Hanf_arg8802244(anf_arg3102245,self1572246,_plus13,tostring18);
}};
$e40334034.stack[R.EXN_STACKHEIGHT++] = $ss40374038;
}
if(R.isPyretException($e40334034)) {
$e40334034.pyretStack.push(L[243]);
}
throw $e40334034;
}
var $ret40394040 = $Hanf_arg8802244($z40354036,self1572246,_plus13,tostring18);
++R.GAS;
return $ret40394040;
};
},{"length":1});
var anf_variant_member3303575 = R.makeMethod(function(self744013) {
return function(cases_DASH_funs754014,else_DASH_clause764025) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[117],2,arguments);
}
var if_DASH_784026 = R.hasField(cases_DASH_funs754014,("unexpected-type-var"));
var if_helper3192237 = R.makeFunction(function(if_helper_arg3204031) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
var ann_DASH_check_DASH_temp3184032 = if_helper_arg3204031;
return ann_DASH_check_DASH_temp3184032;
});
var anf_if3234030 = R.isBoolean(if_DASH_784026);
if(R.isPyretTrue(anf_if3234030)) {
if(R.isPyretTrue(if_DASH_784026)) {
var call_DASH_unexpected_DASH_type_DASH_var734010 = G(cases_DASH_funs754014,"unexpected-type-var",L[117]);
var anf_arg3264011 = G(self744013,"loc",L[242]);
var anf_arg3274012 = G(self744013,"name",L[241]);
var $z40024003 = D;
var $f40084009 = function(_) {
return R.isFunction(call_DASH_unexpected_DASH_type_DASH_var734010)?call_DASH_unexpected_DASH_type_DASH_var734010.app(anf_arg3264011,anf_arg3274012):R.ffi.throwNonFunApp(L[117],call_DASH_unexpected_DASH_type_DASH_var734010,[anf_arg3264011,anf_arg3274012]);
};
try {
if(--R.GAS > 0) {
$z40024003 = $f40084009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40084009,
"from":L[117]});
}
} catch($e40004001) {
if(R.isCont($e40004001)) {
var $ss40044005 = {"from":L[117],
"go":function(cont_tail_arg3282236) {
return $Hcont_tail_arg8812235(cont_tail_arg3282236,if_helper3192237);
}};
$e40004001.stack[R.EXN_STACKHEIGHT++] = $ss40044005;
}
if(R.isPyretException($e40004001)) {
$e40004001.pyretStack.push(L[117]);
}
throw $e40004001;
}
var $ret40064007 = $Hcont_tail_arg8812235($z40024003,if_helper3192237);
++R.GAS;
return $ret40064007;
} else {
var $z40174018 = D;
var $f40234024 = function(_) {
return R.isFunction(else_DASH_clause764025)?else_DASH_clause764025.app():R.ffi.throwNonFunApp(L[117],else_DASH_clause764025,[]);
};
try {
if(--R.GAS > 0) {
$z40174018 = $f40234024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40234024,
"from":L[117]});
}
} catch($e40154016) {
if(R.isCont($e40154016)) {
var $ss40194020 = {"from":L[117],
"go":function(cont_tail_arg3242241) {
return $Hcont_tail_arg8822240(cont_tail_arg3242241,if_helper3192237);
}};
$e40154016.stack[R.EXN_STACKHEIGHT++] = $ss40194020;
}
if(R.isPyretException($e40154016)) {
$e40154016.pyretStack.push(L[117]);
}
throw $e40154016;
}
var $ret40214022 = $Hcont_tail_arg8822240($z40174018,if_helper3192237);
++R.GAS;
return $ret40214022;
}
} else {
var cont_tail_arg3214029 = R.throwNonBooleanCondition(L[117],("if"),if_DASH_784026);
if(--R.GAS > 0) {
$z40274028 = R.isFunction(if_helper3192237)?if_helper3192237.app(cont_tail_arg3214029):R.ffi.throwNonFunApp(L[117],if_helper3192237,[cont_tail_arg3214029]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3192237)?if_helper3192237.app(cont_tail_arg3214029):R.ffi.throwNonFunApp(L[117],if_helper3192237,[cont_tail_arg3214029]);
},
"from":L[117]});
}
++R.GAS;
return $z40274028;
}
};
},{"length":3});
var anf_variant_member3403576 = R.makeMethod(function(self772161) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[117],0,arguments);
}
var anf_arg3323999 = G(self772161,"loc",L[117]);
var $z39913992 = D;
var $f39973998 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg3323999):R.ffi.throwNonFunApp(L[117],torepr17,[anf_arg3323999]);
};
try {
if(--R.GAS > 0) {
$z39913992 = $f39973998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39973998,
"from":L[117]});
}
} catch($e39893990) {
if(R.isCont($e39893990)) {
var $ss39933994 = {"from":L[117],
"go":function(anf_arg3332160) {
return $Hanf_arg8892159(anf_arg3332160,self772161,_plus13,torepr17);
}};
$e39893990.stack[R.EXN_STACKHEIGHT++] = $ss39933994;
}
if(R.isPyretException($e39893990)) {
$e39893990.pyretStack.push(L[117]);
}
throw $e39893990;
}
var $ret39953996 = $Hanf_arg8892159($z39913992,self772161,_plus13,torepr17);
++R.GAS;
return $ret39953996;
};
},{"length":1});
var anf_variant_member3493577 = R.makeMethod(function(self1602097) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[116],0,arguments);
}
var anf_arg3423988 = G(self1602097,"name",L[240]);
var $z39803981 = D;
var $f39863987 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg3423988):R.ffi.throwNonFunApp(L[239],tostring18,[anf_arg3423988]);
};
try {
if(--R.GAS > 0) {
$z39803981 = $f39863987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39863987,
"from":L[239]});
}
} catch($e39783979) {
if(R.isCont($e39783979)) {
var $ss39823983 = {"from":L[239],
"go":function(anf_arg3432096) {
return $Hanf_arg8952095(anf_arg3432096,self1602097,_plus13,tostring18);
}};
$e39783979.stack[R.EXN_STACKHEIGHT++] = $ss39823983;
}
if(R.isPyretException($e39783979)) {
$e39783979.pyretStack.push(L[239]);
}
throw $e39783979;
}
var $ret39843985 = $Hanf_arg8952095($z39803981,self1602097,_plus13,tostring18);
++R.GAS;
return $ret39843985;
};
},{"length":1});
var anf_variant_member3613585 = R.makeMethod(function(self803958) {
return function(cases_DASH_funs813959,else_DASH_clause823970) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[112],2,arguments);
}
var if_DASH_843971 = R.hasField(cases_DASH_funs813959,("pointless-var"));
var if_helper3512088 = R.makeFunction(function(if_helper_arg3523976) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[112],1,arguments);
}
var ann_DASH_check_DASH_temp3503977 = if_helper_arg3523976;
return ann_DASH_check_DASH_temp3503977;
});
var anf_if3553975 = R.isBoolean(if_DASH_843971);
if(R.isPyretTrue(anf_if3553975)) {
if(R.isPyretTrue(if_DASH_843971)) {
var call_DASH_pointless_DASH_var793956 = G(cases_DASH_funs813959,"pointless-var",L[112]);
var anf_arg3583957 = G(self803958,"loc",L[238]);
var $z39483949 = D;
var $f39543955 = function(_) {
return R.isFunction(call_DASH_pointless_DASH_var793956)?call_DASH_pointless_DASH_var793956.app(anf_arg3583957):R.ffi.throwNonFunApp(L[112],call_DASH_pointless_DASH_var793956,[anf_arg3583957]);
};
try {
if(--R.GAS > 0) {
$z39483949 = $f39543955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39543955,
"from":L[112]});
}
} catch($e39463947) {
if(R.isCont($e39463947)) {
var $ss39503951 = {"from":L[112],
"go":function(cont_tail_arg3592087) {
return $Hcont_tail_arg8962086(cont_tail_arg3592087,if_helper3512088);
}};
$e39463947.stack[R.EXN_STACKHEIGHT++] = $ss39503951;
}
if(R.isPyretException($e39463947)) {
$e39463947.pyretStack.push(L[112]);
}
throw $e39463947;
}
var $ret39523953 = $Hcont_tail_arg8962086($z39483949,if_helper3512088);
++R.GAS;
return $ret39523953;
} else {
var $z39623963 = D;
var $f39683969 = function(_) {
return R.isFunction(else_DASH_clause823970)?else_DASH_clause823970.app():R.ffi.throwNonFunApp(L[112],else_DASH_clause823970,[]);
};
try {
if(--R.GAS > 0) {
$z39623963 = $f39683969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39683969,
"from":L[112]});
}
} catch($e39603961) {
if(R.isCont($e39603961)) {
var $ss39643965 = {"from":L[112],
"go":function(cont_tail_arg3562092) {
return $Hcont_tail_arg8972091(cont_tail_arg3562092,if_helper3512088);
}};
$e39603961.stack[R.EXN_STACKHEIGHT++] = $ss39643965;
}
if(R.isPyretException($e39603961)) {
$e39603961.pyretStack.push(L[112]);
}
throw $e39603961;
}
var $ret39663967 = $Hcont_tail_arg8972091($z39623963,if_helper3512088);
++R.GAS;
return $ret39663967;
}
} else {
var cont_tail_arg3533974 = R.throwNonBooleanCondition(L[112],("if"),if_DASH_843971);
if(--R.GAS > 0) {
$z39723973 = R.isFunction(if_helper3512088)?if_helper3512088.app(cont_tail_arg3533974):R.ffi.throwNonFunApp(L[112],if_helper3512088,[cont_tail_arg3533974]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3512088)?if_helper3512088.app(cont_tail_arg3533974):R.ffi.throwNonFunApp(L[112],if_helper3512088,[cont_tail_arg3533974]);
},
"from":L[112]});
}
++R.GAS;
return $z39723973;
}
};
},{"length":3});
var anf_variant_member3673586 = R.makeMethod(function(self833945) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[112],0,arguments);
}
var anf_arg3633944 = G(self833945,"loc",L[112]);
var $z39363937 = D;
var $f39423943 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg3633944):R.ffi.throwNonFunApp(L[112],torepr17,[anf_arg3633944]);
};
try {
if(--R.GAS > 0) {
$z39363937 = $f39423943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39423943,
"from":L[112]});
}
} catch($e39343935) {
if(R.isCont($e39343935)) {
var $ss39383939 = {"from":L[112],
"go":function(anf_arg3642049) {
return $Hanf_arg9012048(anf_arg3642049,_plus13);
}};
$e39343935.stack[R.EXN_STACKHEIGHT++] = $ss39383939;
}
if(R.isPyretException($e39343935)) {
$e39343935.pyretStack.push(L[112]);
}
throw $e39343935;
}
var $ret39403941 = $Hanf_arg9012048($z39363937,_plus13);
++R.GAS;
return $ret39403941;
};
},{"length":1});
var anf_variant_member3723587 = R.makeMethod(function(self1623933) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[111],0,arguments);
}
var anf_arg3693932 = G(self1623933,"loc",L[237]);
var $z39243925 = D;
var $f39303931 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg3693932):R.ffi.throwNonFunApp(L[236],tostring18,[anf_arg3693932]);
};
try {
if(--R.GAS > 0) {
$z39243925 = $f39303931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39303931,
"from":L[236]});
}
} catch($e39223923) {
if(R.isCont($e39223923)) {
var $ss39263927 = {"from":L[236],
"go":function(anf_arg3702023) {
return $Hanf_arg9042022(anf_arg3702023,_plus13);
}};
$e39223923.stack[R.EXN_STACKHEIGHT++] = $ss39263927;
}
if(R.isPyretException($e39223923)) {
$e39223923.pyretStack.push(L[236]);
}
throw $e39223923;
}
var $ret39283929 = $Hanf_arg9042022($z39243925,_plus13);
++R.GAS;
return $ret39283929;
};
},{"length":1});
var anf_variant_member3843594 = R.makeMethod(function(self863902) {
return function(cases_DASH_funs873903,else_DASH_clause883914) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[109],2,arguments);
}
var if_DASH_903915 = R.hasField(cases_DASH_funs873903,("pointless-shadow"));
var if_helper3742015 = R.makeFunction(function(if_helper_arg3753920) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[109],1,arguments);
}
var ann_DASH_check_DASH_temp3733921 = if_helper_arg3753920;
return ann_DASH_check_DASH_temp3733921;
});
var anf_if3783919 = R.isBoolean(if_DASH_903915);
if(R.isPyretTrue(anf_if3783919)) {
if(R.isPyretTrue(if_DASH_903915)) {
var call_DASH_pointless_DASH_shadow853900 = G(cases_DASH_funs873903,"pointless-shadow",L[109]);
var anf_arg3813901 = G(self863902,"loc",L[235]);
var $z38923893 = D;
var $f38983899 = function(_) {
return R.isFunction(call_DASH_pointless_DASH_shadow853900)?call_DASH_pointless_DASH_shadow853900.app(anf_arg3813901):R.ffi.throwNonFunApp(L[109],call_DASH_pointless_DASH_shadow853900,[anf_arg3813901]);
};
try {
if(--R.GAS > 0) {
$z38923893 = $f38983899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38983899,
"from":L[109]});
}
} catch($e38903891) {
if(R.isCont($e38903891)) {
var $ss38943895 = {"from":L[109],
"go":function(cont_tail_arg3822014) {
return $Hcont_tail_arg9052013(cont_tail_arg3822014,if_helper3742015);
}};
$e38903891.stack[R.EXN_STACKHEIGHT++] = $ss38943895;
}
if(R.isPyretException($e38903891)) {
$e38903891.pyretStack.push(L[109]);
}
throw $e38903891;
}
var $ret38963897 = $Hcont_tail_arg9052013($z38923893,if_helper3742015);
++R.GAS;
return $ret38963897;
} else {
var $z39063907 = D;
var $f39123913 = function(_) {
return R.isFunction(else_DASH_clause883914)?else_DASH_clause883914.app():R.ffi.throwNonFunApp(L[109],else_DASH_clause883914,[]);
};
try {
if(--R.GAS > 0) {
$z39063907 = $f39123913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39123913,
"from":L[109]});
}
} catch($e39043905) {
if(R.isCont($e39043905)) {
var $ss39083909 = {"from":L[109],
"go":function(cont_tail_arg3792019) {
return $Hcont_tail_arg9062018(cont_tail_arg3792019,if_helper3742015);
}};
$e39043905.stack[R.EXN_STACKHEIGHT++] = $ss39083909;
}
if(R.isPyretException($e39043905)) {
$e39043905.pyretStack.push(L[109]);
}
throw $e39043905;
}
var $ret39103911 = $Hcont_tail_arg9062018($z39063907,if_helper3742015);
++R.GAS;
return $ret39103911;
}
} else {
var cont_tail_arg3763918 = R.throwNonBooleanCondition(L[109],("if"),if_DASH_903915);
if(--R.GAS > 0) {
$z39163917 = R.isFunction(if_helper3742015)?if_helper3742015.app(cont_tail_arg3763918):R.ffi.throwNonFunApp(L[109],if_helper3742015,[cont_tail_arg3763918]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3742015)?if_helper3742015.app(cont_tail_arg3763918):R.ffi.throwNonFunApp(L[109],if_helper3742015,[cont_tail_arg3763918]);
},
"from":L[109]});
}
++R.GAS;
return $z39163917;
}
};
},{"length":3});
var anf_variant_member3903595 = R.makeMethod(function(self893889) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[109],0,arguments);
}
var anf_arg3863888 = G(self893889,"loc",L[109]);
var $z38803881 = D;
var $f38863887 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg3863888):R.ffi.throwNonFunApp(L[109],torepr17,[anf_arg3863888]);
};
try {
if(--R.GAS > 0) {
$z38803881 = $f38863887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38863887,
"from":L[109]});
}
} catch($e38783879) {
if(R.isCont($e38783879)) {
var $ss38823883 = {"from":L[109],
"go":function(anf_arg3871976) {
return $Hanf_arg9101975(anf_arg3871976,_plus13);
}};
$e38783879.stack[R.EXN_STACKHEIGHT++] = $ss38823883;
}
if(R.isPyretException($e38783879)) {
$e38783879.pyretStack.push(L[109]);
}
throw $e38783879;
}
var $ret38843885 = $Hanf_arg9101975($z38803881,_plus13);
++R.GAS;
return $ret38843885;
};
},{"length":1});
var anf_variant_member3953596 = R.makeMethod(function(self1643877) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[108],0,arguments);
}
var anf_arg3923876 = G(self1643877,"loc",L[234]);
var $z38683869 = D;
var $f38743875 = function(_) {
return R.isFunction(tostring18)?tostring18.app(anf_arg3923876):R.ffi.throwNonFunApp(L[233],tostring18,[anf_arg3923876]);
};
try {
if(--R.GAS > 0) {
$z38683869 = $f38743875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38743875,
"from":L[233]});
}
} catch($e38663867) {
if(R.isCont($e38663867)) {
var $ss38703871 = {"from":L[233],
"go":function(anf_arg3931950) {
return $Hanf_arg9131949(anf_arg3931950,_plus13);
}};
$e38663867.stack[R.EXN_STACKHEIGHT++] = $ss38703871;
}
if(R.isPyretException($e38663867)) {
$e38663867.pyretStack.push(L[233]);
}
throw $e38663867;
}
var $ret38723873 = $Hanf_arg9131949($z38683869,_plus13);
++R.GAS;
return $ret38723873;
};
},{"length":1});
var anf_variant_member4093603 = R.makeMethod(function(self923846) {
return function(cases_DASH_funs933847,else_DASH_clause943858) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[106],2,arguments);
}
var if_DASH_963859 = R.hasField(cases_DASH_funs933847,("bad-assignment"));
var if_helper3971942 = R.makeFunction(function(if_helper_arg3983864) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[106],1,arguments);
}
var ann_DASH_check_DASH_temp3963865 = if_helper_arg3983864;
return ann_DASH_check_DASH_temp3963865;
});
var anf_if4013863 = R.isBoolean(if_DASH_963859);
if(R.isPyretTrue(anf_if4013863)) {
if(R.isPyretTrue(if_DASH_963859)) {
var call_DASH_bad_DASH_assignment913842 = G(cases_DASH_funs933847,"bad-assignment",L[106]);
var anf_arg4043843 = G(self923846,"id",L[232]);
var anf_arg4053844 = G(self923846,"loc",L[231]);
var anf_arg4063845 = G(self923846,"prev-loc",L[230]);
var $z38343835 = D;
var $f38403841 = function(_) {
return R.isFunction(call_DASH_bad_DASH_assignment913842)?call_DASH_bad_DASH_assignment913842.app(anf_arg4043843,anf_arg4053844,anf_arg4063845):R.ffi.throwNonFunApp(L[106],call_DASH_bad_DASH_assignment913842,[anf_arg4043843,anf_arg4053844,anf_arg4063845]);
};
try {
if(--R.GAS > 0) {
$z38343835 = $f38403841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38403841,
"from":L[106]});
}
} catch($e38323833) {
if(R.isCont($e38323833)) {
var $ss38363837 = {"from":L[106],
"go":function(cont_tail_arg4071941) {
return $Hcont_tail_arg9141940(cont_tail_arg4071941,if_helper3971942);
}};
$e38323833.stack[R.EXN_STACKHEIGHT++] = $ss38363837;
}
if(R.isPyretException($e38323833)) {
$e38323833.pyretStack.push(L[106]);
}
throw $e38323833;
}
var $ret38383839 = $Hcont_tail_arg9141940($z38343835,if_helper3971942);
++R.GAS;
return $ret38383839;
} else {
var $z38503851 = D;
var $f38563857 = function(_) {
return R.isFunction(else_DASH_clause943858)?else_DASH_clause943858.app():R.ffi.throwNonFunApp(L[106],else_DASH_clause943858,[]);
};
try {
if(--R.GAS > 0) {
$z38503851 = $f38563857();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38563857,
"from":L[106]});
}
} catch($e38483849) {
if(R.isCont($e38483849)) {
var $ss38523853 = {"from":L[106],
"go":function(cont_tail_arg4021946) {
return $Hcont_tail_arg9151945(cont_tail_arg4021946,if_helper3971942);
}};
$e38483849.stack[R.EXN_STACKHEIGHT++] = $ss38523853;
}
if(R.isPyretException($e38483849)) {
$e38483849.pyretStack.push(L[106]);
}
throw $e38483849;
}
var $ret38543855 = $Hcont_tail_arg9151945($z38503851,if_helper3971942);
++R.GAS;
return $ret38543855;
}
} else {
var cont_tail_arg3993862 = R.throwNonBooleanCondition(L[106],("if"),if_DASH_963859);
if(--R.GAS > 0) {
$z38603861 = R.isFunction(if_helper3971942)?if_helper3971942.app(cont_tail_arg3993862):R.ffi.throwNonFunApp(L[106],if_helper3971942,[cont_tail_arg3993862]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper3971942)?if_helper3971942.app(cont_tail_arg3993862):R.ffi.throwNonFunApp(L[106],if_helper3971942,[cont_tail_arg3993862]);
},
"from":L[106]});
}
++R.GAS;
return $z38603861;
}
};
},{"length":3});
var anf_variant_member4233604 = R.makeMethod(function(self951829) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[106],0,arguments);
}
var anf_arg4113831 = G(self951829,"id",L[106]);
var $z38233824 = D;
var $f38293830 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg4113831):R.ffi.throwNonFunApp(L[106],torepr17,[anf_arg4113831]);
};
try {
if(--R.GAS > 0) {
$z38233824 = $f38293830();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38293830,
"from":L[106]});
}
} catch($e38213822) {
if(R.isCont($e38213822)) {
var $ss38253826 = {"from":L[106],
"go":function(anf_arg4121828) {
return $Hanf_arg9251827(anf_arg4121828,self951829,_plus13,torepr17);
}};
$e38213822.stack[R.EXN_STACKHEIGHT++] = $ss38253826;
}
if(R.isPyretException($e38213822)) {
$e38213822.pyretStack.push(L[106]);
}
throw $e38213822;
}
var $ret38273828 = $Hanf_arg9251827($z38233824,self951829,_plus13,torepr17);
++R.GAS;
return $ret38273828;
};
},{"length":1});
var anf_variant_member4413605 = R.makeMethod(function(self1681712) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[105],0,arguments);
}
var anf_arg4253820 = G(self1681712,"id",L[229]);
var $z38123813 = D;
var $f38183819 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Identifier "),anf_arg4253820):R.ffi.throwNonFunApp(L[94],_plus13,[("Identifier "),anf_arg4253820]);
};
try {
if(--R.GAS > 0) {
$z38123813 = $f38183819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38183819,
"from":L[94]});
}
} catch($e38103811) {
if(R.isCont($e38103811)) {
var $ss38143815 = {"from":L[94],
"go":function(anf_arg4261711) {
return $Hanf_arg9351710(anf_arg4261711,self1681712,_plus13,not15,tostring18);
}};
$e38103811.stack[R.EXN_STACKHEIGHT++] = $ss38143815;
}
if(R.isPyretException($e38103811)) {
$e38103811.pyretStack.push(L[94]);
}
throw $e38103811;
}
var $ret38163817 = $Hanf_arg9351710($z38123813,self1681712,_plus13,not15,tostring18);
++R.GAS;
return $ret38163817;
};
},{"length":1});
var anf_variant_member4553614 = R.makeMethod(function(self983790) {
return function(cases_DASH_funs993791,else_DASH_clause1003802) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[93],2,arguments);
}
var if_DASH_1023803 = R.hasField(cases_DASH_funs993791,("mixed-id-var"));
var if_helper4431703 = R.makeFunction(function(if_helper_arg4443808) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[93],1,arguments);
}
var ann_DASH_check_DASH_temp4423809 = if_helper_arg4443808;
return ann_DASH_check_DASH_temp4423809;
});
var anf_if4473807 = R.isBoolean(if_DASH_1023803);
if(R.isPyretTrue(anf_if4473807)) {
if(R.isPyretTrue(if_DASH_1023803)) {
var call_DASH_mixed_DASH_id_DASH_var973786 = G(cases_DASH_funs993791,"mixed-id-var",L[93]);
var anf_arg4503787 = G(self983790,"id",L[228]);
var anf_arg4513788 = G(self983790,"var-loc",L[227]);
var anf_arg4523789 = G(self983790,"id-loc",L[226]);
var $z37783779 = D;
var $f37843785 = function(_) {
return R.isFunction(call_DASH_mixed_DASH_id_DASH_var973786)?call_DASH_mixed_DASH_id_DASH_var973786.app(anf_arg4503787,anf_arg4513788,anf_arg4523789):R.ffi.throwNonFunApp(L[93],call_DASH_mixed_DASH_id_DASH_var973786,[anf_arg4503787,anf_arg4513788,anf_arg4523789]);
};
try {
if(--R.GAS > 0) {
$z37783779 = $f37843785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37843785,
"from":L[93]});
}
} catch($e37763777) {
if(R.isCont($e37763777)) {
var $ss37803781 = {"from":L[93],
"go":function(cont_tail_arg4531702) {
return $Hcont_tail_arg9361701(cont_tail_arg4531702,if_helper4431703);
}};
$e37763777.stack[R.EXN_STACKHEIGHT++] = $ss37803781;
}
if(R.isPyretException($e37763777)) {
$e37763777.pyretStack.push(L[93]);
}
throw $e37763777;
}
var $ret37823783 = $Hcont_tail_arg9361701($z37783779,if_helper4431703);
++R.GAS;
return $ret37823783;
} else {
var $z37943795 = D;
var $f38003801 = function(_) {
return R.isFunction(else_DASH_clause1003802)?else_DASH_clause1003802.app():R.ffi.throwNonFunApp(L[93],else_DASH_clause1003802,[]);
};
try {
if(--R.GAS > 0) {
$z37943795 = $f38003801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38003801,
"from":L[93]});
}
} catch($e37923793) {
if(R.isCont($e37923793)) {
var $ss37963797 = {"from":L[93],
"go":function(cont_tail_arg4481707) {
return $Hcont_tail_arg9371706(cont_tail_arg4481707,if_helper4431703);
}};
$e37923793.stack[R.EXN_STACKHEIGHT++] = $ss37963797;
}
if(R.isPyretException($e37923793)) {
$e37923793.pyretStack.push(L[93]);
}
throw $e37923793;
}
var $ret37983799 = $Hcont_tail_arg9371706($z37943795,if_helper4431703);
++R.GAS;
return $ret37983799;
}
} else {
var cont_tail_arg4453806 = R.throwNonBooleanCondition(L[93],("if"),if_DASH_1023803);
if(--R.GAS > 0) {
$z38043805 = R.isFunction(if_helper4431703)?if_helper4431703.app(cont_tail_arg4453806):R.ffi.throwNonFunApp(L[93],if_helper4431703,[cont_tail_arg4453806]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper4431703)?if_helper4431703.app(cont_tail_arg4453806):R.ffi.throwNonFunApp(L[93],if_helper4431703,[cont_tail_arg4453806]);
},
"from":L[93]});
}
++R.GAS;
return $z38043805;
}
};
},{"length":3});
var anf_variant_member4693615 = R.makeMethod(function(self1011590) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[93],0,arguments);
}
var anf_arg4573775 = G(self1011590,"id",L[93]);
var $z37673768 = D;
var $f37733774 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg4573775):R.ffi.throwNonFunApp(L[93],torepr17,[anf_arg4573775]);
};
try {
if(--R.GAS > 0) {
$z37673768 = $f37733774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37733774,
"from":L[93]});
}
} catch($e37653766) {
if(R.isCont($e37653766)) {
var $ss37693770 = {"from":L[93],
"go":function(anf_arg4581589) {
return $Hanf_arg9471588(anf_arg4581589,self1011590,_plus13,torepr17);
}};
$e37653766.stack[R.EXN_STACKHEIGHT++] = $ss37693770;
}
if(R.isPyretException($e37653766)) {
$e37653766.pyretStack.push(L[93]);
}
throw $e37653766;
}
var $ret37713772 = $Hanf_arg9471588($z37673768,self1011590,_plus13,torepr17);
++R.GAS;
return $ret37713772;
};
},{"length":1});
var anf_variant_member4873616 = R.makeMethod(function(self1721473) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[92],0,arguments);
}
var anf_arg4713764 = G(self1721473,"id",L[225]);
var $z37563757 = D;
var $f37623763 = function(_) {
return R.isFunction(_plus13)?_plus13.app(anf_arg4713764,(" is declared as both a variable (at ")):R.ffi.throwNonFunApp(L[83],_plus13,[anf_arg4713764,(" is declared as both a variable (at ")]);
};
try {
if(--R.GAS > 0) {
$z37563757 = $f37623763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37623763,
"from":L[83]});
}
} catch($e37543755) {
if(R.isCont($e37543755)) {
var $ss37583759 = {"from":L[83],
"go":function(anf_arg4721472) {
return $Hanf_arg9571471(anf_arg4721472,self1721473,_plus13,not15,tostring18);
}};
$e37543755.stack[R.EXN_STACKHEIGHT++] = $ss37583759;
}
if(R.isPyretException($e37543755)) {
$e37543755.pyretStack.push(L[83]);
}
throw $e37543755;
}
var $ret37603761 = $Hanf_arg9571471($z37563757,self1721473,_plus13,not15,tostring18);
++R.GAS;
return $ret37603761;
};
},{"length":1});
var anf_variant_member5013625 = R.makeMethod(function(self1043734) {
return function(cases_DASH_funs1053735,else_DASH_clause1063746) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[80],2,arguments);
}
var if_DASH_1083747 = R.hasField(cases_DASH_funs1053735,("shadow-id"));
var if_helper4891464 = R.makeFunction(function(if_helper_arg4903752) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[80],1,arguments);
}
var ann_DASH_check_DASH_temp4883753 = if_helper_arg4903752;
return ann_DASH_check_DASH_temp4883753;
});
var anf_if4933751 = R.isBoolean(if_DASH_1083747);
if(R.isPyretTrue(anf_if4933751)) {
if(R.isPyretTrue(if_DASH_1083747)) {
var call_DASH_shadow_DASH_id1033730 = G(cases_DASH_funs1053735,"shadow-id",L[80]);
var anf_arg4963731 = G(self1043734,"id",L[224]);
var anf_arg4973732 = G(self1043734,"new-loc",L[223]);
var anf_arg4983733 = G(self1043734,"old-loc",L[222]);
var $z37223723 = D;
var $f37283729 = function(_) {
return R.isFunction(call_DASH_shadow_DASH_id1033730)?call_DASH_shadow_DASH_id1033730.app(anf_arg4963731,anf_arg4973732,anf_arg4983733):R.ffi.throwNonFunApp(L[80],call_DASH_shadow_DASH_id1033730,[anf_arg4963731,anf_arg4973732,anf_arg4983733]);
};
try {
if(--R.GAS > 0) {
$z37223723 = $f37283729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37283729,
"from":L[80]});
}
} catch($e37203721) {
if(R.isCont($e37203721)) {
var $ss37243725 = {"from":L[80],
"go":function(cont_tail_arg4991463) {
return $Hcont_tail_arg9581462(cont_tail_arg4991463,if_helper4891464);
}};
$e37203721.stack[R.EXN_STACKHEIGHT++] = $ss37243725;
}
if(R.isPyretException($e37203721)) {
$e37203721.pyretStack.push(L[80]);
}
throw $e37203721;
}
var $ret37263727 = $Hcont_tail_arg9581462($z37223723,if_helper4891464);
++R.GAS;
return $ret37263727;
} else {
var $z37383739 = D;
var $f37443745 = function(_) {
return R.isFunction(else_DASH_clause1063746)?else_DASH_clause1063746.app():R.ffi.throwNonFunApp(L[80],else_DASH_clause1063746,[]);
};
try {
if(--R.GAS > 0) {
$z37383739 = $f37443745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37443745,
"from":L[80]});
}
} catch($e37363737) {
if(R.isCont($e37363737)) {
var $ss37403741 = {"from":L[80],
"go":function(cont_tail_arg4941468) {
return $Hcont_tail_arg9591467(cont_tail_arg4941468,if_helper4891464);
}};
$e37363737.stack[R.EXN_STACKHEIGHT++] = $ss37403741;
}
if(R.isPyretException($e37363737)) {
$e37363737.pyretStack.push(L[80]);
}
throw $e37363737;
}
var $ret37423743 = $Hcont_tail_arg9591467($z37383739,if_helper4891464);
++R.GAS;
return $ret37423743;
}
} else {
var cont_tail_arg4913750 = R.throwNonBooleanCondition(L[80],("if"),if_DASH_1083747);
if(--R.GAS > 0) {
$z37483749 = R.isFunction(if_helper4891464)?if_helper4891464.app(cont_tail_arg4913750):R.ffi.throwNonFunApp(L[80],if_helper4891464,[cont_tail_arg4913750]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper4891464)?if_helper4891464.app(cont_tail_arg4913750):R.ffi.throwNonFunApp(L[80],if_helper4891464,[cont_tail_arg4913750]);
},
"from":L[80]});
}
++R.GAS;
return $z37483749;
}
};
},{"length":3});
var anf_variant_member5153626 = R.makeMethod(function(self1071351) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[80],0,arguments);
}
var anf_arg5033719 = G(self1071351,"id",L[80]);
var $z37113712 = D;
var $f37173718 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg5033719):R.ffi.throwNonFunApp(L[80],torepr17,[anf_arg5033719]);
};
try {
if(--R.GAS > 0) {
$z37113712 = $f37173718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37173718,
"from":L[80]});
}
} catch($e37093710) {
if(R.isCont($e37093710)) {
var $ss37133714 = {"from":L[80],
"go":function(anf_arg5041350) {
return $Hanf_arg9691349(anf_arg5041350,self1071351,_plus13,torepr17);
}};
$e37093710.stack[R.EXN_STACKHEIGHT++] = $ss37133714;
}
if(R.isPyretException($e37093710)) {
$e37093710.pyretStack.push(L[80]);
}
throw $e37093710;
}
var $ret37153716 = $Hanf_arg9691349($z37113712,self1071351,_plus13,torepr17);
++R.GAS;
return $ret37153716;
};
},{"length":1});
var anf_variant_member5323627 = R.makeMethod(function(self1761246) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[79],0,arguments);
}
var anf_arg5173708 = G(self1761246,"id",L[221]);
var $z37003701 = D;
var $f37063707 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Identifier "),anf_arg5173708):R.ffi.throwNonFunApp(L[68],_plus13,[("Identifier "),anf_arg5173708]);
};
try {
if(--R.GAS > 0) {
$z37003701 = $f37063707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37063707,
"from":L[68]});
}
} catch($e36983699) {
if(R.isCont($e36983699)) {
var $ss37023703 = {"from":L[68],
"go":function(anf_arg5181245) {
return $Hanf_arg9781244(anf_arg5181245,self1761246,_plus13,not15,tostring18);
}};
$e36983699.stack[R.EXN_STACKHEIGHT++] = $ss37023703;
}
if(R.isPyretException($e36983699)) {
$e36983699.pyretStack.push(L[68]);
}
throw $e36983699;
}
var $ret37043705 = $Hanf_arg9781244($z37003701,self1761246,_plus13,not15,tostring18);
++R.GAS;
return $ret37043705;
};
},{"length":1});
var anf_variant_member5463636 = R.makeMethod(function(self1103678) {
return function(cases_DASH_funs1113679,else_DASH_clause1123690) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[67],2,arguments);
}
var if_DASH_1143691 = R.hasField(cases_DASH_funs1113679,("duplicate-id"));
var if_helper5341237 = R.makeFunction(function(if_helper_arg5353696) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[67],1,arguments);
}
var ann_DASH_check_DASH_temp5333697 = if_helper_arg5353696;
return ann_DASH_check_DASH_temp5333697;
});
var anf_if5383695 = R.isBoolean(if_DASH_1143691);
if(R.isPyretTrue(anf_if5383695)) {
if(R.isPyretTrue(if_DASH_1143691)) {
var call_DASH_duplicate_DASH_id1093674 = G(cases_DASH_funs1113679,"duplicate-id",L[67]);
var anf_arg5413675 = G(self1103678,"id",L[220]);
var anf_arg5423676 = G(self1103678,"new-loc",L[219]);
var anf_arg5433677 = G(self1103678,"old-loc",L[218]);
var $z36663667 = D;
var $f36723673 = function(_) {
return R.isFunction(call_DASH_duplicate_DASH_id1093674)?call_DASH_duplicate_DASH_id1093674.app(anf_arg5413675,anf_arg5423676,anf_arg5433677):R.ffi.throwNonFunApp(L[67],call_DASH_duplicate_DASH_id1093674,[anf_arg5413675,anf_arg5423676,anf_arg5433677]);
};
try {
if(--R.GAS > 0) {
$z36663667 = $f36723673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36723673,
"from":L[67]});
}
} catch($e36643665) {
if(R.isCont($e36643665)) {
var $ss36683669 = {"from":L[67],
"go":function(cont_tail_arg5441236) {
return $Hcont_tail_arg9791235(cont_tail_arg5441236,if_helper5341237);
}};
$e36643665.stack[R.EXN_STACKHEIGHT++] = $ss36683669;
}
if(R.isPyretException($e36643665)) {
$e36643665.pyretStack.push(L[67]);
}
throw $e36643665;
}
var $ret36703671 = $Hcont_tail_arg9791235($z36663667,if_helper5341237);
++R.GAS;
return $ret36703671;
} else {
var $z36823683 = D;
var $f36883689 = function(_) {
return R.isFunction(else_DASH_clause1123690)?else_DASH_clause1123690.app():R.ffi.throwNonFunApp(L[67],else_DASH_clause1123690,[]);
};
try {
if(--R.GAS > 0) {
$z36823683 = $f36883689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36883689,
"from":L[67]});
}
} catch($e36803681) {
if(R.isCont($e36803681)) {
var $ss36843685 = {"from":L[67],
"go":function(cont_tail_arg5391241) {
return $Hcont_tail_arg9801240(cont_tail_arg5391241,if_helper5341237);
}};
$e36803681.stack[R.EXN_STACKHEIGHT++] = $ss36843685;
}
if(R.isPyretException($e36803681)) {
$e36803681.pyretStack.push(L[67]);
}
throw $e36803681;
}
var $ret36863687 = $Hcont_tail_arg9801240($z36823683,if_helper5341237);
++R.GAS;
return $ret36863687;
}
} else {
var cont_tail_arg5363694 = R.throwNonBooleanCondition(L[67],("if"),if_DASH_1143691);
if(--R.GAS > 0) {
$z36923693 = R.isFunction(if_helper5341237)?if_helper5341237.app(cont_tail_arg5363694):R.ffi.throwNonFunApp(L[67],if_helper5341237,[cont_tail_arg5363694]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper5341237)?if_helper5341237.app(cont_tail_arg5363694):R.ffi.throwNonFunApp(L[67],if_helper5341237,[cont_tail_arg5363694]);
},
"from":L[67]});
}
++R.GAS;
return $z36923693;
}
};
},{"length":3});
var anf_variant_member5603637 = R.makeMethod(function(self1131124) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[67],0,arguments);
}
var anf_arg5483663 = G(self1131124,"id",L[67]);
var $z36553656 = D;
var $f36613662 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg5483663):R.ffi.throwNonFunApp(L[67],torepr17,[anf_arg5483663]);
};
try {
if(--R.GAS > 0) {
$z36553656 = $f36613662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36613662,
"from":L[67]});
}
} catch($e36533654) {
if(R.isCont($e36533654)) {
var $ss36573658 = {"from":L[67],
"go":function(anf_arg5491123) {
return $Hanf_arg9901122(anf_arg5491123,self1131124,_plus13,torepr17);
}};
$e36533654.stack[R.EXN_STACKHEIGHT++] = $ss36573658;
}
if(R.isPyretException($e36533654)) {
$e36533654.pyretStack.push(L[67]);
}
throw $e36533654;
}
var $ret36593660 = $Hanf_arg9901122($z36553656,self1131124,_plus13,torepr17);
++R.GAS;
return $ret36593660;
};
},{"length":1});
var anf_variant_member5773638 = R.makeMethod(function(self1801019) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[66],0,arguments);
}
var anf_arg5623652 = G(self1801019,"id",L[217]);
var $z36443645 = D;
var $f36503651 = function(_) {
return R.isFunction(_plus13)?_plus13.app(("Identifier "),anf_arg5623652):R.ffi.throwNonFunApp(L[55],_plus13,[("Identifier "),anf_arg5623652]);
};
try {
if(--R.GAS > 0) {
$z36443645 = $f36503651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36503651,
"from":L[55]});
}
} catch($e36423643) {
if(R.isCont($e36423643)) {
var $ss36463647 = {"from":L[55],
"go":function(anf_arg5631018) {
return $Hanf_arg9991017(anf_arg5631018,self1801019,_plus13,not15,tostring18);
}};
$e36423643.stack[R.EXN_STACKHEIGHT++] = $ss36463647;
}
if(R.isPyretException($e36423643)) {
$e36423643.pyretStack.push(L[55]);
}
throw $e36423643;
}
var $ret36483649 = $Hanf_arg9991017($z36443645,self1801019,_plus13,not15,tostring18);
++R.GAS;
return $ret36483649;
};
},{"length":1});
var anf_assign5783347 = (function() {
var $wf_DASH_err_DASH_base35023503 = {"_match":anf_variant_member1173507,
"_torepr":anf_variant_member1273508,
"tostring":anf_variant_member1343509};
var $wf_DASH_err_DASH_brands35053506 = {"$brand-wf-err3504":true};
$wf_DASH_err_DASH_brands35053506[CompileErrorT4713322._brand] = true
var $wf_DASH_err_DASH_split_DASH_base35123513 = {"_match":anf_variant_member1473517,
"_torepr":anf_variant_member1573518,
"tostring":anf_variant_member1673519};
var $wf_DASH_err_DASH_split_DASH_brands35153516 = {"$brand-wf-err-split3514":true};
$wf_DASH_err_DASH_split_DASH_brands35153516[CompileErrorT4713322._brand] = true
var $reserved_DASH_name_DASH_base35223523 = {"_match":anf_variant_member1803527,
"_torepr":anf_variant_member1903528,
"tostring":anf_variant_member1973529};
var $reserved_DASH_name_DASH_brands35253526 = {"$brand-reserved-name3524":true};
$reserved_DASH_name_DASH_brands35253526[CompileErrorT4713322._brand] = true
var $zero_DASH_fraction_DASH_base35323533 = {"_match":anf_variant_member2103537,
"_torepr":anf_variant_member2203538,
"tostring":anf_variant_member2283539};
var $zero_DASH_fraction_DASH_brands35353536 = {"$brand-zero-fraction3534":true};
$zero_DASH_fraction_DASH_brands35353536[CompileErrorT4713322._brand] = true
var $unbound_DASH_id_DASH_base35423543 = {"_match":anf_variant_member2403547,
"_torepr":anf_variant_member2463548,
"tostring":anf_variant_member2573549};
var $unbound_DASH_id_DASH_brands35453546 = {"$brand-unbound-id3544":true};
$unbound_DASH_id_DASH_brands35453546[CompileErrorT4713322._brand] = true
var $unbound_DASH_var_DASH_base35513552 = {"_match":anf_variant_member2703556,
"_torepr":anf_variant_member2803557,
"tostring":anf_variant_member2873558};
var $unbound_DASH_var_DASH_brands35543555 = {"$brand-unbound-var3553":true};
$unbound_DASH_var_DASH_brands35543555[CompileErrorT4713322._brand] = true
var $unbound_DASH_type_DASH_id_DASH_base35613562 = {"_match":anf_variant_member2993566,
"_torepr":anf_variant_member3053567,
"tostring":anf_variant_member3173568};
var $unbound_DASH_type_DASH_id_DASH_brands35643565 = {"$brand-unbound-type-id3563":true};
$unbound_DASH_type_DASH_id_DASH_brands35643565[CompileErrorT4713322._brand] = true
var $unexpected_DASH_type_DASH_var_DASH_base35703571 = {"_match":anf_variant_member3303575,
"_torepr":anf_variant_member3403576,
"tostring":anf_variant_member3493577};
var $unexpected_DASH_type_DASH_var_DASH_brands35733574 = {"$brand-unexpected-type-var3572":true};
$unexpected_DASH_type_DASH_var_DASH_brands35733574[CompileErrorT4713322._brand] = true
var $pointless_DASH_var_DASH_base35803581 = {"_match":anf_variant_member3613585,
"_torepr":anf_variant_member3673586,
"tostring":anf_variant_member3723587};
var $pointless_DASH_var_DASH_brands35833584 = {"$brand-pointless-var3582":true};
$pointless_DASH_var_DASH_brands35833584[CompileErrorT4713322._brand] = true
var $pointless_DASH_shadow_DASH_base35893590 = {"_match":anf_variant_member3843594,
"_torepr":anf_variant_member3903595,
"tostring":anf_variant_member3953596};
var $pointless_DASH_shadow_DASH_brands35923593 = {"$brand-pointless-shadow3591":true};
$pointless_DASH_shadow_DASH_brands35923593[CompileErrorT4713322._brand] = true
var $bad_DASH_assignment_DASH_base35983599 = {"_match":anf_variant_member4093603,
"_torepr":anf_variant_member4233604,
"tostring":anf_variant_member4413605};
var $bad_DASH_assignment_DASH_brands36013602 = {"$brand-bad-assignment3600":true};
$bad_DASH_assignment_DASH_brands36013602[CompileErrorT4713322._brand] = true
var $mixed_DASH_id_DASH_var_DASH_base36093610 = {"_match":anf_variant_member4553614,
"_torepr":anf_variant_member4693615,
"tostring":anf_variant_member4873616};
var $mixed_DASH_id_DASH_var_DASH_brands36123613 = {"$brand-mixed-id-var3611":true};
$mixed_DASH_id_DASH_var_DASH_brands36123613[CompileErrorT4713322._brand] = true
var $shadow_DASH_id_DASH_base36203621 = {"_match":anf_variant_member5013625,
"_torepr":anf_variant_member5153626,
"tostring":anf_variant_member5323627};
var $shadow_DASH_id_DASH_brands36233624 = {"$brand-shadow-id3622":true};
$shadow_DASH_id_DASH_brands36233624[CompileErrorT4713322._brand] = true
var $duplicate_DASH_id_DASH_base36313632 = {"_match":anf_variant_member5463636,
"_torepr":anf_variant_member5603637,
"tostring":anf_variant_member5773638};
var $duplicate_DASH_id_DASH_brands36343635 = {"$brand-duplicate-id3633":true};
$duplicate_DASH_id_DASH_brands36343635[CompileErrorT4713322._brand] = true
return R.makeObject({"CompileError":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[176],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CompileErrorT4713322._brand));
}),
"is-wf-err":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[157],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-wf-err3504"));
}),
"wf-err":R.makeFunction(function(msg1393510,loc1403511) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[177],2,arguments);
}
return R.checkAnnArgs([$type$String19,R.getDotAnn(L[178],"A",A227,"Loc")],[msg1393510,loc1403511],[L[179],L[178]],function() {
var dict = R.create($wf_DASH_err_DASH_base35023503);
dict["msg"] = msg1393510
dict["loc"] = loc1403511
return R.makeBrandedObject(dict,$wf_DASH_err_DASH_brands35053506);
});
}),
"is-wf-err-split":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[152],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-wf-err-split3514"));
}),
"wf-err-split":R.makeFunction(function(msg1423520,loc1433521) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[180],2,arguments);
}
return R.checkAnnArgs([$type$String19,List1555],[msg1423520,loc1433521],[L[181],L[182]],function() {
var dict = R.create($wf_DASH_err_DASH_split_DASH_base35123513);
dict["msg"] = msg1423520
dict["loc"] = loc1433521
return R.makeBrandedObject(dict,$wf_DASH_err_DASH_split_DASH_brands35153516);
});
}),
"is-reserved-name":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[144],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-reserved-name3524"));
}),
"reserved-name":R.makeFunction(function(loc1453530,id1463531) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[183],2,arguments);
}
return R.checkAnnArgs([Loc7656,$type$String19],[loc1453530,id1463531],[L[184],L[185]],function() {
var dict = R.create($reserved_DASH_name_DASH_base35223523);
dict["loc"] = loc1453530
dict["id"] = id1463531
return R.makeBrandedObject(dict,$reserved_DASH_name_DASH_brands35253526);
});
}),
"is-zero-fraction":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[139],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-zero-fraction3534"));
}),
"zero-fraction":R.makeFunction(function(loc1483540,numerator1493541) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[186],2,arguments);
}
var dict = R.create($zero_DASH_fraction_DASH_base35323533);
dict["loc"] = loc1483540
dict["numerator"] = numerator1493541
return R.makeBrandedObject(dict,$zero_DASH_fraction_DASH_brands35353536);
}),
"is-unbound-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[134],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-unbound-id3544"));
}),
"unbound-id":R.makeFunction(function(id1513550) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[187],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[188],"A",A227,"Expr")],[id1513550],[L[188]],function() {
var dict = R.create($unbound_DASH_id_DASH_base35423543);
dict["id"] = id1513550
return R.makeBrandedObject(dict,$unbound_DASH_id_DASH_brands35453546);
});
}),
"is-unbound-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[128],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-unbound-var3553"));
}),
"unbound-var":R.makeFunction(function(id1533559,loc1543560) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[189],2,arguments);
}
return R.checkAnnArgs([$type$String19,Loc7656],[id1533559,loc1543560],[L[190],L[191]],function() {
var dict = R.create($unbound_DASH_var_DASH_base35513552);
dict["id"] = id1533559
dict["loc"] = loc1543560
return R.makeBrandedObject(dict,$unbound_DASH_var_DASH_brands35543555);
});
}),
"is-unbound-type-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[123],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-unbound-type-id3563"));
}),
"unbound-type-id":R.makeFunction(function(ann1563569) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[192],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[193],"A",A227,"Ann")],[ann1563569],[L[193]],function() {
var dict = R.create($unbound_DASH_type_DASH_id_DASH_base35613562);
dict["ann"] = ann1563569
return R.makeBrandedObject(dict,$unbound_DASH_type_DASH_id_DASH_brands35643565);
});
}),
"is-unexpected-type-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-unexpected-type-var3572"));
}),
"unexpected-type-var":R.makeFunction(function(loc1583578,name1593579) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[194],2,arguments);
}
return R.checkAnnArgs([Loc7656,R.getDotAnn(L[195],"A",A227,"Name")],[loc1583578,name1593579],[L[196],L[195]],function() {
var dict = R.create($unexpected_DASH_type_DASH_var_DASH_base35703571);
dict["loc"] = loc1583578
dict["name"] = name1593579
return R.makeBrandedObject(dict,$unexpected_DASH_type_DASH_var_DASH_brands35733574);
});
}),
"is-pointless-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[112],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-pointless-var3582"));
}),
"pointless-var":R.makeFunction(function(loc1613588) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[197],1,arguments);
}
return R.checkAnnArgs([Loc7656],[loc1613588],[L[198]],function() {
var dict = R.create($pointless_DASH_var_DASH_base35803581);
dict["loc"] = loc1613588
return R.makeBrandedObject(dict,$pointless_DASH_var_DASH_brands35833584);
});
}),
"is-pointless-shadow":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[109],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-pointless-shadow3591"));
}),
"pointless-shadow":R.makeFunction(function(loc1633597) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[199],1,arguments);
}
return R.checkAnnArgs([Loc7656],[loc1633597],[L[200]],function() {
var dict = R.create($pointless_DASH_shadow_DASH_base35893590);
dict["loc"] = loc1633597
return R.makeBrandedObject(dict,$pointless_DASH_shadow_DASH_brands35923593);
});
}),
"is-bad-assignment":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[106],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-bad-assignment3600"));
}),
"bad-assignment":R.makeFunction(function(id1653606,loc1663607,prev_DASH_loc1673608) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[201],3,arguments);
}
return R.checkAnnArgs([$type$String19,Loc7656,Loc7656],[id1653606,loc1663607,prev_DASH_loc1673608],[L[202],L[203],L[204]],function() {
var dict = R.create($bad_DASH_assignment_DASH_base35983599);
dict["id"] = id1653606
dict["loc"] = loc1663607
dict["prev-loc"] = prev_DASH_loc1673608
return R.makeBrandedObject(dict,$bad_DASH_assignment_DASH_brands36013602);
});
}),
"is-mixed-id-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[93],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-mixed-id-var3611"));
}),
"mixed-id-var":R.makeFunction(function(id1693617,var_DASH_loc1703618,id_DASH_loc1713619) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[205],3,arguments);
}
return R.checkAnnArgs([$type$String19,Loc7656,Loc7656],[id1693617,var_DASH_loc1703618,id_DASH_loc1713619],[L[206],L[207],L[208]],function() {
var dict = R.create($mixed_DASH_id_DASH_var_DASH_base36093610);
dict["id"] = id1693617
dict["var-loc"] = var_DASH_loc1703618
dict["id-loc"] = id_DASH_loc1713619
return R.makeBrandedObject(dict,$mixed_DASH_id_DASH_var_DASH_brands36123613);
});
}),
"is-shadow-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[80],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-shadow-id3622"));
}),
"shadow-id":R.makeFunction(function(id1733628,new_DASH_loc1743629,old_DASH_loc1753630) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[209],3,arguments);
}
return R.checkAnnArgs([$type$String19,Loc7656,Loc7656],[id1733628,new_DASH_loc1743629,old_DASH_loc1753630],[L[210],L[211],L[212]],function() {
var dict = R.create($shadow_DASH_id_DASH_base36203621);
dict["id"] = id1733628
dict["new-loc"] = new_DASH_loc1743629
dict["old-loc"] = old_DASH_loc1753630
return R.makeBrandedObject(dict,$shadow_DASH_id_DASH_brands36233624);
});
}),
"is-duplicate-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[67],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-duplicate-id3633"));
}),
"duplicate-id":R.makeFunction(function(id1773639,new_DASH_loc1783640,old_DASH_loc1793641) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[213],3,arguments);
}
return R.checkAnnArgs([$type$String19,Loc7656,Loc7656],[id1773639,new_DASH_loc1783640,old_DASH_loc1793641],[L[214],L[215],L[216]],function() {
var dict = R.create($duplicate_DASH_id_DASH_base36313632);
dict["id"] = id1773639
dict["new-loc"] = new_DASH_loc1783640
dict["old-loc"] = old_DASH_loc1793641
return R.makeBrandedObject(dict,$duplicate_DASH_id_DASH_brands36343635);
});
})});
})();
CompileError10963346.$var = anf_assign5783347;
var anf_assign5793348 = G(CompileError10963346.$var,"CompileError",L[176]);
CompileError9750.$var = anf_assign5793348;
var anf_assign5803349 = G(CompileError10963346.$var,"CompileError",L[176]);
is_DASH_CompileError9867.$var = anf_assign5803349;
var anf_assign5813350 = G(CompileError10963346.$var,"is-wf-err",L[157]);
is_DASH_wf_DASH_err9989.$var = anf_assign5813350;
var anf_assign5823351 = G(CompileError10963346.$var,"wf-err",L[157]);
wf_DASH_err100105.$var = anf_assign5823351;
var anf_assign5833352 = G(CompileError10963346.$var,"is-wf-err-split",L[152]);
is_DASH_wf_DASH_err_DASH_split10188.$var = anf_assign5833352;
var anf_assign5843353 = G(CompileError10963346.$var,"wf-err-split",L[152]);
wf_DASH_err_DASH_split102104.$var = anf_assign5843353;
var anf_assign5853354 = G(CompileError10963346.$var,"is-reserved-name",L[144]);
is_DASH_reserved_DASH_name10380.$var = anf_assign5853354;
var anf_assign5863355 = G(CompileError10963346.$var,"reserved-name",L[144]);
reserved_DASH_name10496.$var = anf_assign5863355;
var anf_assign5873356 = G(CompileError10963346.$var,"is-zero-fraction",L[139]);
is_DASH_zero_DASH_fraction10590.$var = anf_assign5873356;
var anf_assign5883357 = G(CompileError10963346.$var,"zero-fraction",L[139]);
zero_DASH_fraction106106.$var = anf_assign5883357;
var anf_assign5893358 = G(CompileError10963346.$var,"is-unbound-id",L[134]);
is_DASH_unbound_DASH_id10784.$var = anf_assign5893358;
var anf_assign5903359 = G(CompileError10963346.$var,"unbound-id",L[134]);
unbound_DASH_id108100.$var = anf_assign5903359;
var anf_assign5913360 = G(CompileError10963346.$var,"is-unbound-var",L[128]);
is_DASH_unbound_DASH_var10986.$var = anf_assign5913360;
var anf_assign5923361 = G(CompileError10963346.$var,"unbound-var",L[128]);
unbound_DASH_var110102.$var = anf_assign5923361;
var anf_assign5933362 = G(CompileError10963346.$var,"is-unbound-type-id",L[123]);
is_DASH_unbound_DASH_type_DASH_id11185.$var = anf_assign5933362;
var anf_assign5943363 = G(CompileError10963346.$var,"unbound-type-id",L[123]);
unbound_DASH_type_DASH_id112101.$var = anf_assign5943363;
var anf_assign5953364 = G(CompileError10963346.$var,"is-unexpected-type-var",L[117]);
is_DASH_unexpected_DASH_type_DASH_var11387.$var = anf_assign5953364;
var anf_assign5963365 = G(CompileError10963346.$var,"unexpected-type-var",L[117]);
unexpected_DASH_type_DASH_var114103.$var = anf_assign5963365;
var anf_assign5973366 = G(CompileError10963346.$var,"is-pointless-var",L[112]);
is_DASH_pointless_DASH_var11579.$var = anf_assign5973366;
var anf_assign5983367 = G(CompileError10963346.$var,"pointless-var",L[112]);
pointless_DASH_var11695.$var = anf_assign5983367;
var anf_assign5993368 = G(CompileError10963346.$var,"is-pointless-shadow",L[109]);
is_DASH_pointless_DASH_shadow11778.$var = anf_assign5993368;
var anf_assign6003369 = G(CompileError10963346.$var,"pointless-shadow",L[109]);
pointless_DASH_shadow11894.$var = anf_assign6003369;
var anf_assign6013370 = G(CompileError10963346.$var,"is-bad-assignment",L[106]);
is_DASH_bad_DASH_assignment11972.$var = anf_assign6013370;
var anf_assign6023371 = G(CompileError10963346.$var,"bad-assignment",L[106]);
bad_DASH_assignment12061.$var = anf_assign6023371;
var anf_assign6033372 = G(CompileError10963346.$var,"is-mixed-id-var",L[93]);
is_DASH_mixed_DASH_id_DASH_var12176.$var = anf_assign6033372;
var anf_assign6043373 = G(CompileError10963346.$var,"mixed-id-var",L[93]);
mixed_DASH_id_DASH_var12292.$var = anf_assign6043373;
var anf_assign6053374 = G(CompileError10963346.$var,"is-shadow-id",L[80]);
is_DASH_shadow_DASH_id12381.$var = anf_assign6053374;
var anf_assign6063375 = G(CompileError10963346.$var,"shadow-id",L[80]);
shadow_DASH_id12497.$var = anf_assign6063375;
var anf_assign6073376 = G(CompileError10963346.$var,"is-duplicate-id",L[67]);
is_DASH_duplicate_DASH_id12574.$var = anf_assign6073376;
var anf_assign6083377 = G(CompileError10963346.$var,"duplicate-id",L[67]);
duplicate_DASH_id12663.$var = anf_assign6083377;
var anf_variant_member6203402 = R.makeMethod(function(self1163482) {
return function(cases_DASH_funs1173483,else_DASH_clause1183494) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[54],2,arguments);
}
var if_DASH_1203495 = R.hasField(cases_DASH_funs1173483,("type-id"));
var if_helper6101010 = R.makeFunction(function(if_helper_arg6113500) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[54],1,arguments);
}
var ann_DASH_check_DASH_temp6093501 = if_helper_arg6113500;
return ann_DASH_check_DASH_temp6093501;
});
var anf_if6143499 = R.isBoolean(if_DASH_1203495);
if(R.isPyretTrue(anf_if6143499)) {
if(R.isPyretTrue(if_DASH_1203495)) {
var call_DASH_type_DASH_id1153480 = G(cases_DASH_funs1173483,"type-id",L[54]);
var anf_arg6173481 = G(self1163482,"id",L[175]);
var $z34723473 = D;
var $f34783479 = function(_) {
return R.isFunction(call_DASH_type_DASH_id1153480)?call_DASH_type_DASH_id1153480.app(anf_arg6173481):R.ffi.throwNonFunApp(L[54],call_DASH_type_DASH_id1153480,[anf_arg6173481]);
};
try {
if(--R.GAS > 0) {
$z34723473 = $f34783479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34783479,
"from":L[54]});
}
} catch($e34703471) {
if(R.isCont($e34703471)) {
var $ss34743475 = {"from":L[54],
"go":function(cont_tail_arg6181009) {
return $Hcont_tail_arg10001008(cont_tail_arg6181009,if_helper6101010);
}};
$e34703471.stack[R.EXN_STACKHEIGHT++] = $ss34743475;
}
if(R.isPyretException($e34703471)) {
$e34703471.pyretStack.push(L[54]);
}
throw $e34703471;
}
var $ret34763477 = $Hcont_tail_arg10001008($z34723473,if_helper6101010);
++R.GAS;
return $ret34763477;
} else {
var $z34863487 = D;
var $f34923493 = function(_) {
return R.isFunction(else_DASH_clause1183494)?else_DASH_clause1183494.app():R.ffi.throwNonFunApp(L[54],else_DASH_clause1183494,[]);
};
try {
if(--R.GAS > 0) {
$z34863487 = $f34923493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34923493,
"from":L[54]});
}
} catch($e34843485) {
if(R.isCont($e34843485)) {
var $ss34883489 = {"from":L[54],
"go":function(cont_tail_arg6151014) {
return $Hcont_tail_arg10011013(cont_tail_arg6151014,if_helper6101010);
}};
$e34843485.stack[R.EXN_STACKHEIGHT++] = $ss34883489;
}
if(R.isPyretException($e34843485)) {
$e34843485.pyretStack.push(L[54]);
}
throw $e34843485;
}
var $ret34903491 = $Hcont_tail_arg10011013($z34863487,if_helper6101010);
++R.GAS;
return $ret34903491;
}
} else {
var cont_tail_arg6123498 = R.throwNonBooleanCondition(L[54],("if"),if_DASH_1203495);
if(--R.GAS > 0) {
$z34963497 = R.isFunction(if_helper6101010)?if_helper6101010.app(cont_tail_arg6123498):R.ffi.throwNonFunApp(L[54],if_helper6101010,[cont_tail_arg6123498]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper6101010)?if_helper6101010.app(cont_tail_arg6123498):R.ffi.throwNonFunApp(L[54],if_helper6101010,[cont_tail_arg6123498]);
},
"from":L[54]});
}
++R.GAS;
return $z34963497;
}
};
},{"length":3});
var anf_variant_member6263403 = R.makeMethod(function(self1193469) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[54],0,arguments);
}
var anf_arg6223468 = G(self1193469,"id",L[54]);
var $z34603461 = D;
var $f34663467 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg6223468):R.ffi.throwNonFunApp(L[54],torepr17,[anf_arg6223468]);
};
try {
if(--R.GAS > 0) {
$z34603461 = $f34663467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34663467,
"from":L[54]});
}
} catch($e34583459) {
if(R.isCont($e34583459)) {
var $ss34623463 = {"from":L[54],
"go":function(anf_arg623971) {
return $Hanf_arg1005970(anf_arg623971,_plus13);
}};
$e34583459.stack[R.EXN_STACKHEIGHT++] = $ss34623463;
}
if(R.isPyretException($e34583459)) {
$e34583459.pyretStack.push(L[54]);
}
throw $e34583459;
}
var $ret34643465 = $Hanf_arg1005970($z34603461,_plus13);
++R.GAS;
return $ret34643465;
};
},{"length":1});
var anf_variant_member6393410 = R.makeMethod(function(self1223438) {
return function(cases_DASH_funs1233439,else_DASH_clause1243450) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[53],2,arguments);
}
var if_DASH_1263451 = R.hasField(cases_DASH_funs1233439,("type-module-bindings"));
var if_helper628963 = R.makeFunction(function(if_helper_arg6293456) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[53],1,arguments);
}
var ann_DASH_check_DASH_temp6273457 = if_helper_arg6293456;
return ann_DASH_check_DASH_temp6273457;
});
var anf_if6323455 = R.isBoolean(if_DASH_1263451);
if(R.isPyretTrue(anf_if6323455)) {
if(R.isPyretTrue(if_DASH_1263451)) {
var call_DASH_type_DASH_module_DASH_bindings1213435 = G(cases_DASH_funs1233439,"type-module-bindings",L[53]);
var anf_arg6353436 = G(self1223438,"name",L[174]);
var anf_arg6363437 = G(self1223438,"bindings",L[173]);
var $z34273428 = D;
var $f34333434 = function(_) {
return R.isFunction(call_DASH_type_DASH_module_DASH_bindings1213435)?call_DASH_type_DASH_module_DASH_bindings1213435.app(anf_arg6353436,anf_arg6363437):R.ffi.throwNonFunApp(L[53],call_DASH_type_DASH_module_DASH_bindings1213435,[anf_arg6353436,anf_arg6363437]);
};
try {
if(--R.GAS > 0) {
$z34273428 = $f34333434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34333434,
"from":L[53]});
}
} catch($e34253426) {
if(R.isCont($e34253426)) {
var $ss34293430 = {"from":L[53],
"go":function(cont_tail_arg637962) {
return $Hcont_tail_arg1006961(cont_tail_arg637962,if_helper628963);
}};
$e34253426.stack[R.EXN_STACKHEIGHT++] = $ss34293430;
}
if(R.isPyretException($e34253426)) {
$e34253426.pyretStack.push(L[53]);
}
throw $e34253426;
}
var $ret34313432 = $Hcont_tail_arg1006961($z34273428,if_helper628963);
++R.GAS;
return $ret34313432;
} else {
var $z34423443 = D;
var $f34483449 = function(_) {
return R.isFunction(else_DASH_clause1243450)?else_DASH_clause1243450.app():R.ffi.throwNonFunApp(L[53],else_DASH_clause1243450,[]);
};
try {
if(--R.GAS > 0) {
$z34423443 = $f34483449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34483449,
"from":L[53]});
}
} catch($e34403441) {
if(R.isCont($e34403441)) {
var $ss34443445 = {"from":L[53],
"go":function(cont_tail_arg633967) {
return $Hcont_tail_arg1007966(cont_tail_arg633967,if_helper628963);
}};
$e34403441.stack[R.EXN_STACKHEIGHT++] = $ss34443445;
}
if(R.isPyretException($e34403441)) {
$e34403441.pyretStack.push(L[53]);
}
throw $e34403441;
}
var $ret34463447 = $Hcont_tail_arg1007966($z34423443,if_helper628963);
++R.GAS;
return $ret34463447;
}
} else {
var cont_tail_arg6303454 = R.throwNonBooleanCondition(L[53],("if"),if_DASH_1263451);
if(--R.GAS > 0) {
$z34523453 = R.isFunction(if_helper628963)?if_helper628963.app(cont_tail_arg6303454):R.ffi.throwNonFunApp(L[53],if_helper628963,[cont_tail_arg6303454]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored338) {
return R.isFunction(if_helper628963)?if_helper628963.app(cont_tail_arg6303454):R.ffi.throwNonFunApp(L[53],if_helper628963,[cont_tail_arg6303454]);
},
"from":L[53]});
}
++R.GAS;
return $z34523453;
}
};
},{"length":3});
var anf_variant_member6493411 = R.makeMethod(function(self125887) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[53],0,arguments);
}
var anf_arg6413424 = G(self125887,"name",L[53]);
var $z34163417 = D;
var $f34223423 = function(_) {
return R.isFunction(torepr17)?torepr17.app(anf_arg6413424):R.ffi.throwNonFunApp(L[53],torepr17,[anf_arg6413424]);
};
try {
if(--R.GAS > 0) {
$z34163417 = $f34223423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34223423,
"from":L[53]});
}
} catch($e34143415) {
if(R.isCont($e34143415)) {
var $ss34183419 = {"from":L[53],
"go":function(anf_arg642886) {
return $Hanf_arg1014885(anf_arg642886,self125887,_plus13,torepr17);
}};
$e34143415.stack[R.EXN_STACKHEIGHT++] = $ss34183419;
}
if(R.isPyretException($e34143415)) {
$e34143415.pyretStack.push(L[53]);
}
throw $e34143415;
}
var $ret34203421 = $Hanf_arg1014885($z34163417,self125887,_plus13,torepr17);
++R.GAS;
return $ret34203421;
};
},{"length":1});
var anf_assign6503379 = (function() {
var $type_DASH_id_DASH_base33973398 = {"_match":anf_variant_member6203402,
"_torepr":anf_variant_member6263403};
var $type_DASH_id_DASH_brands34003401 = {"$brand-type-id3399":true};
$type_DASH_id_DASH_brands34003401[CompileTypeBindingT5733323._brand] = true
var $type_DASH_module_DASH_bindings_DASH_base34053406 = {"_match":anf_variant_member6393410,
"_torepr":anf_variant_member6493411};
var $type_DASH_module_DASH_bindings_DASH_brands34083409 = {"$brand-type-module-bindings3407":true};
$type_DASH_module_DASH_bindings_DASH_brands34083409[CompileTypeBindingT5733323._brand] = true
return R.makeObject({"CompileTypeBinding":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[167],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CompileTypeBindingT5733323._brand));
}),
"is-type-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[54],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-type-id3399"));
}),
"type-id":R.makeFunction(function(id1813404) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[168],1,arguments);
}
return R.checkAnnArgs([$type$String19],[id1813404],[L[169]],function() {
var dict = R.create($type_DASH_id_DASH_base33973398);
dict["id"] = id1813404
return R.makeBrandedObject(dict,$type_DASH_id_DASH_brands34003401);
});
}),
"is-type-module-bindings":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[53],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-type-module-bindings3407"));
}),
"type-module-bindings":R.makeFunction(function(name1823412,bindings1833413) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[170],2,arguments);
}
return R.checkAnnArgs([$type$String19,List1555],[name1823412,bindings1833413],[L[171],L[172]],function() {
var dict = R.create($type_DASH_module_DASH_bindings_DASH_base34053406);
dict["name"] = name1823412
dict["bindings"] = bindings1833413
return R.makeBrandedObject(dict,$type_DASH_module_DASH_bindings_DASH_brands34083409);
});
})});
})();
CompileTypeBinding111273378.$var = anf_assign6503379;
var anf_assign6513380 = G(CompileTypeBinding111273378.$var,"CompileTypeBinding",L[167]);
CompileTypeBinding12853.$var = anf_assign6513380;
var anf_assign6523381 = G(CompileTypeBinding111273378.$var,"CompileTypeBinding",L[167]);
is_DASH_CompileTypeBinding12969.$var = anf_assign6523381;
var anf_assign6533382 = G(CompileTypeBinding111273378.$var,"is-type-id",L[54]);
is_DASH_type_DASH_id13082.$var = anf_assign6533382;
var anf_assign6543383 = G(CompileTypeBinding111273378.$var,"type-id",L[54]);
type_DASH_id13198.$var = anf_assign6543383;
var anf_assign6553384 = G(CompileTypeBinding111273378.$var,"is-type-module-bindings",L[53]);
is_DASH_type_DASH_module_DASH_bindings13283.$var = anf_assign6553384;
var anf_assign6563385 = G(CompileTypeBinding111273378.$var,"type-module-bindings",L[53]);
type_DASH_module_DASH_bindings13399.$var = anf_assign6563385;
var anf_fun65760 = G(lists723,"map",L[166]);
var anf_fun6583396 = G(list2391,"make",L[165]);
var $z33883389 = D;
var $f33943395 = function(_) {
return R.isFunction(anf_fun6583396)?anf_fun6583396.app([("Number"),("String"),("Function"),("Boolean"),("Object"),("Method"),("Nothing"),("RawArray")]):R.ffi.throwNonFunApp(L[165],anf_fun6583396,[[("Number"),("String"),("Function"),("Boolean"),("Object"),("Method"),("Nothing"),("RawArray")]]);
};
try {
if(--R.GAS > 0) {
$z33883389 = $f33943395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33943395,
"from":L[165]});
}
} catch($e33863387) {
if(R.isCont($e33863387)) {
var $ss33903391 = {"from":L[165],
"go":function(anf_arg65943) {
return $Hanf_arg107242(anf_arg65943,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun65760,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
}};
$e33863387.stack[R.EXN_STACKHEIGHT++] = $ss33903391;
}
if(R.isPyretException($e33863387)) {
$e33863387.pyretStack.push(L[165]);
}
throw $e33863387;
}
var $ret33923393 = $Hanf_arg107242($z33883389,Bootstrap8344,CompileBinding7445,CompileBindingT67546,CompileEnvironment6647,CompileEnvironment8548,CompileError7049,CompileError9750,CompileResult6851,CompileResult9052,CompileTypeBinding12853,CompileTypeBinding7254,List1555,Loc7656,Pyret8157,PyretDialect6458,PyretDialect7859,anf_fun65760,bad_DASH_assignment12061,compile_DASH_env8862,duplicate_DASH_id12663,err9564,is_DASH_Bootstrap8265,is_DASH_CompileEnvironment8666,is_DASH_CompileError9867,is_DASH_CompileResult9168,is_DASH_CompileTypeBinding12969,is_DASH_Pyret8070,is_DASH_PyretDialect7971,is_DASH_bad_DASH_assignment11972,is_DASH_compile_DASH_env8773,is_DASH_duplicate_DASH_id12574,is_DASH_err9475,is_DASH_mixed_DASH_id_DASH_var12176,is_DASH_ok9277,is_DASH_pointless_DASH_shadow11778,is_DASH_pointless_DASH_var11579,is_DASH_reserved_DASH_name10380,is_DASH_shadow_DASH_id12381,is_DASH_type_DASH_id13082,is_DASH_type_DASH_module_DASH_bindings13283,is_DASH_unbound_DASH_id10784,is_DASH_unbound_DASH_type_DASH_id11185,is_DASH_unbound_DASH_var10986,is_DASH_unexpected_DASH_type_DASH_var11387,is_DASH_wf_DASH_err_DASH_split10188,is_DASH_wf_DASH_err9989,is_DASH_zero_DASH_fraction10590,list2391,lists723,mixed_DASH_id_DASH_var12292,ok9393,pointless_DASH_shadow11894,pointless_DASH_var11695,reserved_DASH_name10496,shadow_DASH_id12497,type_DASH_id13198,type_DASH_module_DASH_bindings13399,unbound_DASH_id108100,unbound_DASH_type_DASH_id112101,unbound_DASH_var110102,unexpected_DASH_type_DASH_var114103,wf_DASH_err_DASH_split102104,wf_DASH_err100105,zero_DASH_fraction106106,_plus13,builtins14,nothing16,torepr17,$type$String19);
++R.GAS;
return $ret33923393;
},function(moduleVal) {
R.modules["$src/arr/compiler/compile-structs.arr34"] = moduleVal
return moduleVal;
});
});
}
};
});
define('js/bootstrap-tokenizer',["../../../lib/jglr/jglr"], function(E) {
  const Grammar = E.Grammar
  const Nonterm = E.Nonterm
  const Token = E.Token
  const SrcLoc = E.SrcLoc
  const GenTokenizer = E.Tokenizer;
  const STICKY_REGEXP = E.STICKY_REGEXP;

  const escapes = new RegExp("^(.*?)\\\\([\\\\\"\'nrt]|u[0-9A-Fa-f]{1,4}|x[0-9A-Fa-f]{1,2}|[0-7]{1,3}|[\r\n]{1,2})");
  function fixEscapes(s) {
    var ret = "";
    var match = escapes.exec(s);
    while (match !== null) {
      var esc = match[2];
      ret += match[1];
      s = s.slice(match[0].length);
      if (esc === "\n") {}
      else if (esc === "\r") {}
      else if (esc === "\n\r") {}
      else if (esc === "\r\n") {}
      else if (esc === "n") { ret += "\n"; }
      else if (esc === "r") { ret += "\r"; }
      else if (esc === "t") { ret += "\t"; }
      else if (esc === "\"") { ret += "\""; }
      else if (esc === "'") { ret += "'"; }
      else if (esc === "\\") { ret += "\\"; }
      else if (esc[0] === 'u') { ret += String.fromCharCode(parseInt(esc.slice(1), 16)); }
      else if (esc[0] === 'x') { ret += String.fromCharCode(parseInt(esc.slice(1), 16)); }
      else { ret += String.fromCharCode(parseInt(esc.slice(2), 8)); }
      match = escapes.exec(s);
    }
    ret += s;
    return ret;
  }

  function Tokenizer(ignore_ws, Tokens) {
    GenTokenizer.call(this, ignore_ws, Tokens);
    this.parenIsForExp = true; // initialize this at the beginning of file to true
  }
  Tokenizer.prototype = Object.create(GenTokenizer.prototype);
  Tokenizer.prototype.tokenizeFrom = function(str) {
    GenTokenizer.prototype.tokenizeFrom.call(this, str);
    this.parenIsForExp = true;
  }
  Tokenizer.prototype.makeToken = function (tok_type, s, pos) { 
    if (tok_type === "STRING") s = fixEscapes(s);
    else if (tok_type === "LONG_STRING") tok_type = "STRING";
    return GenTokenizer.prototype.makeToken(tok_type, s, pos);
  }
  Tokenizer.prototype.postProcessMatch = function(tok, match) {
    var tok_type = tok.name;
    if (tok_type === "PAREN?") {
      for (var j = 0; j < this.Tokens.length; j++) {
        if (STICKY_REGEXP !== '') {
          var oldIndex = this.Tokens[j].val.lastIndex;
          this.Tokens[j].val.lastIndex = 0;
        }
        var op = this.Tokens[j].val.exec(match[0]);
        if (STICKY_REGEXP !== '') {
          this.Tokens[j].val.lastIndex = oldIndex;
        }
        if (op !== null) {
          tok_type = this.Tokens[j].name;
          if (tok_type == "LPAREN?")
            tok_type = this.parenIsForExp ? "PARENSPACE" : "PARENNOSPACE";
          break;
        }
      }
    } else if (tok_type == "LPAREN?") {
      tok_type = this.parenIsForExp ? "PARENSPACE" : "PARENNOSPACE";
    }
    this.parenIsForExp = !!tok.parenIsForExp;
    return tok_type;
  }



  function kw(str) { return "^(?:" + str + ")(?![-_a-zA-Z0-9])"; }
  function anyOf(strs) { return "(?:" + strs.join("|") + ")(?![-_a-zA-Z0-9])"; }
  const operator_regex_str = anyOf(["\\+", "-", "\\*", "/", "<=", ">=", "==", "<>", "%",
                                    "<", ">", "and", "or", "is", "raises"]);
  const name = new RegExp("^[_a-zA-Z][-_a-zA-Z0-9]*", STICKY_REGEXP);
  const number = new RegExp("^-?[0-9]+(?:\\.[0-9]+)?", STICKY_REGEXP);
  const rational = new RegExp("^-?[0-9]+/[0-9]+", STICKY_REGEXP);
  const parenparen = new RegExp("^\\((?=\\()", STICKY_REGEXP); // NOTE: Don't include the following paren
  const opparen = new RegExp("^" + operator_regex_str + "(?=\\()", STICKY_REGEXP); // NOTE: likewise
  const spaceparen = new RegExp("^\\s+\\(", STICKY_REGEXP);
  const ws = new RegExp("^\\s+", STICKY_REGEXP);
  const comment = new RegExp("^#.*(?:\\n|\\r|\\r\\n|\\n\\r|$)", STICKY_REGEXP)
  const bar = new RegExp("^\\|", STICKY_REGEXP);
  const langle = new RegExp("^<", STICKY_REGEXP);
  const rangle = new RegExp("^>", STICKY_REGEXP);
  const lbrack = new RegExp("^\\[", STICKY_REGEXP);
  const rbrack = new RegExp("^\\]", STICKY_REGEXP);
  const lbrace = new RegExp("^\\{", STICKY_REGEXP);
  const rbrace = new RegExp("^\\}", STICKY_REGEXP);
  const lparen = new RegExp("^\\(", STICKY_REGEXP);
  const rparen = new RegExp("^\\)", STICKY_REGEXP);
  const period = new RegExp("^\\.", STICKY_REGEXP);
  const bang = new RegExp("^!", STICKY_REGEXP);
  const percent = new RegExp("^%", STICKY_REGEXP);
  const comma = new RegExp("^,", STICKY_REGEXP);
  const thinarrow = new RegExp("^->", STICKY_REGEXP);
  const thickarrow = new RegExp("^=>", STICKY_REGEXP);
  const coloncolon = new RegExp("^::", STICKY_REGEXP);
  const colon = new RegExp("^:", STICKY_REGEXP);
  const caret = new RegExp("^\\^", STICKY_REGEXP);
  const equals = new RegExp("^=", STICKY_REGEXP);
  const colonequals = new RegExp("^:=", STICKY_REGEXP);
  const semi = new RegExp("^;", STICKY_REGEXP);
  const backslash = new RegExp("^\\\\", STICKY_REGEXP);
  const opplus = new RegExp("^\\s+\\+\\s+", STICKY_REGEXP);
  const opminus = new RegExp("^\\s+-\\s+", STICKY_REGEXP);
  const optimes = new RegExp("^\\s+\\*\\s+", STICKY_REGEXP);
  const opdiv = new RegExp("^\\s+/\\s+", STICKY_REGEXP);
  const opleq = new RegExp("^\\s+<=\\s+", STICKY_REGEXP);
  const opgeq = new RegExp("^\\s+>=\\s+", STICKY_REGEXP);
  const opeq = new RegExp("^\\s+==\\s+", STICKY_REGEXP);
  const opneq = new RegExp("^\\s+<>\\s+", STICKY_REGEXP);
  const oplt = new RegExp("^\\s*<\\s*", STICKY_REGEXP);
  const opgt = new RegExp("^\\s*>\\s*", STICKY_REGEXP);
  const opand = new RegExp("^and(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opor = new RegExp("^or(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opis = new RegExp("^is(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opsatisfies = new RegExp("^satisfies(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opraises = new RegExp("^raises(?![-_a-zA-Z0-9])", STICKY_REGEXP);

  const slashable = "[\\\\nrt\"\']"
  const tquot_str =
    new RegExp("^```(?:" +
               "\\\\[01234567]{1,3}" +
               "|\\\\x[0-9a-fA-F]{1,2}" + 
               "|\\\\u[0-9a-fA-f]{1,4}" + 
               "|\\\\[\\\\nrt\"\']" + 
               "|[^`])*```", STICKY_REGEXP); // NOTE: Allow unescaped newlines
  const dquot_str = 
    new RegExp("^\"(?:" +
               "\\\\[01234567]{1,3}" +
               "|\\\\x[0-9a-fA-F]{1,2}" + 
               "|\\\\u[0-9a-fA-f]{1,4}" + 
               "|\\\\[\\\\nrt\"\']" + 
               "|[^\\\\\"\n\r])*\"", STICKY_REGEXP);
  const squot_str = 
    new RegExp("^\'(?:" +
               "\\\\[01234567]{1,3}" +
               "|\\\\x[0-9a-fA-F]{1,2}" + 
               "|\\\\u[0-9a-fA-f]{1,4}" + 
               "|\\\\[\\\\nrt\"\']" + 
               "|[^\\\\\'\n\r])*\'", STICKY_REGEXP);

  const unterminated_string = new RegExp("^[\"\'].*", STICKY_REGEXP);

  const anychar = new RegExp("^[^]", STICKY_REGEXP);
  const Tokens = [
    {name: "PAREN?", val: parenparen, parenIsForExp: true},
    {name: "PAREN?", val: opparen, parenIsForExp: true},
    {name: "PARENSPACE", val: spaceparen, parenIsForExp: true},
    {name: "LPAREN?", val: lparen, parenIsForExp: true},


    {name: "IMPORT", val: new RegExp(kw("import"), STICKY_REGEXP)},
    {name: "PROVIDE", val: new RegExp(kw("provide"), STICKY_REGEXP)},
    {name: "AS", val: new RegExp(kw("as"), STICKY_REGEXP)},
    {name: "VAR", val: new RegExp(kw("var"), STICKY_REGEXP)},
    {name: "VAL", val: new RegExp(kw("val"), STICKY_REGEXP)},
    {name: "LETREC", val: new RegExp(kw("letrec"), STICKY_REGEXP)},
    {name: "LET", val: new RegExp(kw("let"), STICKY_REGEXP)},
    {name: "FUN", val: new RegExp(kw("fun"), STICKY_REGEXP)},
    {name: "LAM", val: new RegExp(kw("lam"), STICKY_REGEXP)},
    {name: "TRUE", val: new RegExp(kw("true"), STICKY_REGEXP)},
    {name: "FALSE", val: new RegExp(kw("false"), STICKY_REGEXP)},
    {name: "METHOD", val: new RegExp(kw("method"), STICKY_REGEXP)},
    {name: "DOC", val: new RegExp(kw("doc:"), STICKY_REGEXP)},
    {name: "WHERE", val: new RegExp(kw("where:"), STICKY_REGEXP)},
    {name: "EXAMPLESCOLON", val: new RegExp(kw("examples:"), STICKY_REGEXP)},
    {name: "CHECKCOLON", val: new RegExp(kw("check:"), STICKY_REGEXP)},
    {name: "EXAMPLES", val: new RegExp(kw("examples"), STICKY_REGEXP)},
    {name: "CHECK", val: new RegExp(kw("check"), STICKY_REGEXP)},
    {name: "TRY", val: new RegExp(kw("try:"), STICKY_REGEXP)},
    {name: "EXCEPT", val: new RegExp(kw("except"), STICKY_REGEXP)},
    {name: "CASES", val: new RegExp(kw("cases"), STICKY_REGEXP)},
    {name: "WHEN", val: new RegExp(kw("when"), STICKY_REGEXP)},
    {name: "ASKCOLON", val: new RegExp(kw("ask:"), STICKY_REGEXP)},
    {name: "OTHERWISECOLON", val: new RegExp(kw("otherwise:"), STICKY_REGEXP)},
    {name: "IF", val: new RegExp(kw("if"), STICKY_REGEXP)},
    {name: "THENCOLON", val: new RegExp(kw("then:"), STICKY_REGEXP)},
    {name: "ELSECOLON", val: new RegExp(kw("else:"), STICKY_REGEXP)},
    {name: "ELSEIF", val: new RegExp(kw("else if"), STICKY_REGEXP)},
    {name: "ELSE", val: new RegExp(kw("else"), STICKY_REGEXP)},
    {name: "DATA", val: new RegExp(kw("data"), STICKY_REGEXP)},
    {name: "WITH", val: new RegExp(kw("with:"), STICKY_REGEXP)},
    {name: "SHARING", val: new RegExp(kw("sharing:"), STICKY_REGEXP)},
    {name: "SHADOW", val: new RegExp(kw("shadow"), STICKY_REGEXP)},
    {name: "MUTABLE", val: new RegExp(kw("mutable"), STICKY_REGEXP)},
    {name: "CYCLIC", val: new RegExp(kw("cyclic"), STICKY_REGEXP)},
    {name: "DATATYPE", val: new RegExp(kw("datatype"), STICKY_REGEXP)},
    {name: "WITHCONSTRUCTOR", val: new RegExp(kw("with constructor"), STICKY_REGEXP)},
    {name: "GRAPH", val: new RegExp(kw("graph:"), STICKY_REGEXP)},
    {name: "BLOCK", val: new RegExp(kw("block:"), STICKY_REGEXP)},
    {name: "FOR", val: new RegExp(kw("for"), STICKY_REGEXP)},
    {name: "FROM", val: new RegExp(kw("from"), STICKY_REGEXP)},
    {name: "END", val: new RegExp(kw("end"), STICKY_REGEXP)},
    {name: "LAZY", val: new RegExp(kw("lazy"), STICKY_REGEXP)},
    
    {name: "DOT", val: period},
    {name: "BANG", val: bang},
    {name: "PERCENT", val: percent},
    {name: "COMMA", val: comma},
    {name: "THINARROW", val: thinarrow},
    {name: "THICKARROW", val: thickarrow},
    {name: "COLONEQUALS", val: colonequals},
    {name: "COLONCOLON", val: coloncolon},
    {name: "COLON", val: colon},
    {name: "CARET", val: caret},
    {name: "BAR", val: bar},

    {name: "RATIONAL", val: rational},
    {name: "NUMBER", val: number},
    {name: "LONG_STRING", val: tquot_str}, 
    {name: "STRING", val: dquot_str}, 
    {name: "STRING", val: squot_str},

    {name: "PLUS", val: opplus, parenIsForExp: true},
    {name: "DASH", val: opminus, parenIsForExp: true},
    {name: "STAR", val: optimes, parenIsForExp: true},
    {name: "SLASH", val: opdiv, parenIsForExp: true},
    {name: "LEQ", val: opleq, parenIsForExp: true},
    {name: "GEQ", val: opgeq, parenIsForExp: true},
    {name: "EQUALEQUAL", val: opeq, parenIsForExp: true},
    {name: "NEQ", val: opneq, parenIsForExp: true},
    {name: "LT", val: oplt, parenIsForExp: true},
    {name: "GT", val: opgt, parenIsForExp: true},
    {name: "AND", val: opand},
    {name: "OR", val: opor},
    {name: "IS", val: opis},
    {name: "SATISFIES", val: opsatisfies},
    {name: "RAISES", val: opraises},
    {name: "LBRACK", val: lbrack}, 
    {name: "RBRACK", val: rbrack}, 
    {name: "LBRACE", val: lbrace}, 
    {name: "RBRACE", val: rbrace}, 
    {name: "RPAREN", val: rparen}, 
    {name: "LANGLE", val: langle, parenIsForExp: true},
    {name: "RANGLE", val: rangle, parenIsForExp: true},

    {name: "EQUALS", val: equals},

    {name: "COMMENT", val: comment}, 
    {name: "WS", val: ws, parenIsForExp: true},

    {name: "SEMI", val: semi},
    {name: "BACKSLASH", val: backslash},

    {name: "NAME", val: name},

    {name: "UNTERMINATED-STRING", val: unterminated_string},
    {name: "UNKNOWN", val: anychar},
  ];


  return {
    'Tokenizer': new Tokenizer(true, Tokens)
  };
});

define('js/bootstrap-parser',['../../../lib/jglr/jglr'],
/** @param {{Grammar : {fromSerializable : !Function}, Nonterm : !Object, Token : !Object, Rule : !Object}} E */
function(E) {
  const Grammar = E.Grammar;
  const Nonterm = E.Nonterm;
  const Token = E.Token;
  const Rule = E.Rule;

  var g_json = {
    "start": "START",
    "name": "BootstrapGrammar",
    "acceptStates": [
      1
    ],
    "mode": "RNGLR",
    "derivable": {
      "program": [
        "prelude",
        "prelude_I0_opt",
        "prelude_I1_star",
        "ε",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "import-stmt",
        "block",
        "stmt",
        "block_I0_star",
        "block_I0",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "prelude": [
        "prelude_I0_opt",
        "prelude_I1_star",
        "ε",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "import-stmt"
      ],
      "block": [
        "block_I0_star",
        "ε",
        "block_I0",
        "stmt",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "end": [],
      "prelude_I0_opt": [
        "ε",
        "prelude_I0",
        "provide-stmt"
      ],
      "prelude_I1_star": [
        "ε",
        "prelude_I1",
        "import-stmt"
      ],
      "prelude_I0": [
        "provide-stmt"
      ],
      "provide-stmt": [],
      "prelude_I1": [
        "import-stmt"
      ],
      "import-stmt": [],
      "import-stmt_I1": [
        "import-name",
        "import-string"
      ],
      "import-name": [],
      "import-string": [],
      "import-stmt_I2_star": [
        "ε",
        "import-stmt_I2"
      ],
      "import-stmt_I4": [
        "import-name",
        "import-string"
      ],
      "import-stmt_I2": [],
      "stmt": [
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "block_I0_star": [
        "ε",
        "block_I0",
        "stmt",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "block_I0": [
        "stmt",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "let-expr": [],
      "fun-expr": [],
      "data-expr": [],
      "datatype-expr": [],
      "when-expr": [],
      "var-expr": [],
      "assign-expr": [],
      "check-test": [
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "check-expr": [],
      "graph-expr": [],
      "contract-stmt": [],
      "toplevel-binding": [
        "binding"
      ],
      "binop-expr": [
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "binding": [],
      "binding_I0_opt": [
        "ε",
        "binding_I0"
      ],
      "binding_I2_opt": [
        "ε",
        "binding_I2"
      ],
      "binding_I0": [],
      "binding_I2": [],
      "ann": [
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "toplevel-binding_A1_I0_opt": [
        "ε",
        "toplevel-binding_A1_I0"
      ],
      "noparen-arrow-ann": [],
      "toplevel-binding_A1_I0": [],
      "multi-let-expr": [],
      "multi-let-expr_I1_star": [
        "ε",
        "multi-let-expr_I1",
        "let-binding-elt"
      ],
      "let-binding": [
        "let-expr",
        "var-expr"
      ],
      "multi-let-expr_I1": [
        "let-binding-elt"
      ],
      "let-binding-elt": [],
      "letrec-expr": [],
      "letrec-expr_I1_star": [
        "ε",
        "letrec-expr_I1",
        "letrec-binding"
      ],
      "letrec-expr_I1": [
        "letrec-binding"
      ],
      "letrec-binding": [],
      "contract-stmt_I2": [
        "ann",
        "noparen-arrow-ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "fun-header": [],
      "doc-string": [
        "doc-string_I0_opt",
        "ε",
        "doc-string_I0"
      ],
      "where-clause": [
        "where-clause_I0_opt",
        "ε",
        "where-clause_I0"
      ],
      "ty-params": [
        "ty-params_I0_opt",
        "ε",
        "ty-params_I0"
      ],
      "args": [],
      "return-ann": [
        "return-ann_I0_opt",
        "ε",
        "return-ann_I0"
      ],
      "ty-params_I0_opt": [
        "ε",
        "ty-params_I0"
      ],
      "ty-params_I0": [],
      "ty-params_I0_I0": [],
      "ty-params_I0_I1_star": [
        "ε",
        "ty-params_I0_I1",
        "list-ty-param"
      ],
      "ty-params_I0_I3": [],
      "ty-params_I0_I1": [
        "list-ty-param"
      ],
      "list-ty-param": [],
      "args_I0": [],
      "args_I1_opt": [
        "ε",
        "args_I1",
        "binding"
      ],
      "args_I1": [
        "binding"
      ],
      "args_I1_I0_star": [
        "ε",
        "args_I1_I0",
        "list-arg-elt"
      ],
      "args_I1_I0": [
        "list-arg-elt"
      ],
      "list-arg-elt": [],
      "return-ann_I0_opt": [
        "ε",
        "return-ann_I0"
      ],
      "return-ann_I0": [],
      "doc-string_I0_opt": [
        "ε",
        "doc-string_I0"
      ],
      "doc-string_I0": [],
      "where-clause_I0_opt": [
        "ε",
        "where-clause_I0"
      ],
      "where-clause_I0": [],
      "check-op": [],
      "data-mixins": [
        "data-mixins_I0_opt",
        "ε",
        "data-mixins_I0"
      ],
      "data-expr_I5_opt": [
        "ε",
        "data-expr_I5",
        "first-data-variant",
        "variant-constructor"
      ],
      "data-expr_I6_star": [
        "ε",
        "data-expr_I6",
        "data-variant"
      ],
      "data-sharing": [
        "data-sharing_I0_opt",
        "ε",
        "data-sharing_I0"
      ],
      "data-expr_I5": [
        "first-data-variant",
        "variant-constructor"
      ],
      "first-data-variant": [
        "variant-constructor"
      ],
      "data-expr_I6": [
        "data-variant"
      ],
      "data-variant": [],
      "data-mixins_I0_opt": [
        "ε",
        "data-mixins_I0"
      ],
      "data-mixins_I0": [],
      "mixins": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "variant-constructor": [],
      "variant-members": [],
      "data-with": [
        "data-with_I0_opt",
        "ε",
        "data-with_I0"
      ],
      "variant-members_I0": [],
      "variant-members_I1_opt": [
        "ε",
        "variant-members_I1",
        "variant-member",
        "binding"
      ],
      "variant-members_I1": [
        "variant-member",
        "binding"
      ],
      "variant-members_I1_I0_star": [
        "ε",
        "variant-members_I1_I0",
        "list-variant-member"
      ],
      "variant-member": [
        "binding"
      ],
      "variant-members_I1_I0": [
        "list-variant-member"
      ],
      "list-variant-member": [],
      "variant-member_I0_opt": [
        "ε",
        "variant-member_I0"
      ],
      "variant-member_I0": [],
      "data-with_I0_opt": [
        "ε",
        "data-with_I0"
      ],
      "data-with_I0": [],
      "fields": [
        "field"
      ],
      "data-sharing_I0_opt": [
        "ε",
        "data-sharing_I0"
      ],
      "data-sharing_I0": [],
      "mixins_I0_star": [
        "ε",
        "mixins_I0",
        "list-mixin"
      ],
      "mixins_I0": [
        "list-mixin"
      ],
      "list-mixin": [],
      "datatype-expr_I4_opt": [
        "ε",
        "datatype-expr_I4",
        "first-datatype-variant"
      ],
      "datatype-expr_I5_star": [
        "ε",
        "datatype-expr_I5",
        "datatype-variant"
      ],
      "datatype-expr_I4": [
        "first-datatype-variant"
      ],
      "first-datatype-variant": [],
      "datatype-expr_I5": [
        "datatype-variant"
      ],
      "datatype-variant": [],
      "constructor-clause": [],
      "constructor-clause_I1": [],
      "graph-expr_I1_star": [
        "ε",
        "graph-expr_I1",
        "let-expr"
      ],
      "graph-expr_I1": [
        "let-expr"
      ],
      "expr": [
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "multi-let-expr",
        "letrec-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "binop-expr_I1_star": [
        "ε",
        "binop-expr_I1"
      ],
      "binop-expr_I1": [],
      "binop": [],
      "paren-expr": [],
      "id-expr": [],
      "prim-expr": [
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "lambda-expr": [],
      "method-expr": [],
      "app-expr": [],
      "obj-expr": [],
      "dot-expr": [],
      "bracket-expr": [],
      "get-bang-expr": [],
      "update-expr": [],
      "extend-expr": [],
      "if-expr": [],
      "if-pipe-expr": [],
      "cases-expr": [],
      "for-expr": [],
      "try-expr": [],
      "user-block-expr": [],
      "inst-expr": [],
      "construct-expr": [],
      "bad-expr": [],
      "num-expr": [],
      "frac-expr": [],
      "bool-expr": [],
      "string-expr": [],
      "app-args": [],
      "app-args_I1_opt": [
        "ε",
        "app-args_I1",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-args_I1": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-args_I1_I0_star": [
        "ε",
        "app-args_I1_I0",
        "app-arg-elt"
      ],
      "app-args_I1_I0": [
        "app-arg-elt"
      ],
      "app-arg-elt": [],
      "inst-expr_I1": [],
      "inst-expr_I2_star": [
        "ε",
        "inst-expr_I2",
        "inst-elt"
      ],
      "inst-expr_I4": [],
      "inst-expr_I2": [
        "inst-elt"
      ],
      "inst-elt": [],
      "obj-fields": [
        "obj-field"
      ],
      "obj-fields_I0_star": [
        "ε",
        "obj-fields_I0",
        "list-obj-field"
      ],
      "obj-field": [],
      "obj-fields_I2_opt": [
        "ε",
        "obj-fields_I2"
      ],
      "obj-fields_I0": [
        "list-obj-field"
      ],
      "list-obj-field": [],
      "obj-fields_I2": [],
      "key": [],
      "obj-field_A1_I2_opt": [
        "ε",
        "obj-field_A1_I2"
      ],
      "obj-field_A1_I2": [],
      "fields_I0_star": [
        "ε",
        "fields_I0",
        "list-field"
      ],
      "field": [],
      "fields_I2_opt": [
        "ε",
        "fields_I2"
      ],
      "fields_I0": [
        "list-field"
      ],
      "list-field": [],
      "fields_I2": [],
      "construct-modifier": [
        "ε"
      ],
      "construct-expr_I4_opt": [
        "ε",
        "construct-expr_I4",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "construct-expr_I4": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "construct-expr_I4_I0_star": [
        "ε",
        "construct-expr_I4_I0",
        "list-elt"
      ],
      "construct-expr_I4_I0": [
        "list-elt"
      ],
      "list-elt": [],
      "if-expr_I4_star": [
        "ε",
        "if-expr_I4",
        "else-if"
      ],
      "if-expr_I5_opt": [
        "ε",
        "if-expr_I5"
      ],
      "if-expr_I4": [
        "else-if"
      ],
      "else-if": [],
      "if-expr_I5": [],
      "if-pipe-expr_I1_star": [
        "ε",
        "if-pipe-expr_I1",
        "if-pipe-branch"
      ],
      "if-pipe-expr_I2_opt": [
        "ε",
        "if-pipe-expr_I2"
      ],
      "if-pipe-expr_I1": [
        "if-pipe-branch"
      ],
      "if-pipe-branch": [],
      "if-pipe-expr_I2": [],
      "cases-expr_I1": [],
      "cases-expr_I6_star": [
        "ε",
        "cases-expr_I6",
        "cases-branch"
      ],
      "cases-expr_I7_opt": [
        "ε",
        "cases-expr_I7"
      ],
      "cases-expr_I6": [
        "cases-branch"
      ],
      "cases-branch": [],
      "cases-expr_I7": [],
      "cases-branch_I2_opt": [
        "ε",
        "cases-branch_I2",
        "args"
      ],
      "cases-branch_I2": [
        "args"
      ],
      "for-bind": [],
      "for-bind-elt": [],
      "for-expr_I3_opt": [
        "ε",
        "for-expr_I3",
        "for-bind"
      ],
      "for-expr_I3": [
        "for-bind"
      ],
      "for-expr_I3_I0_star": [
        "ε",
        "for-expr_I3_I0",
        "for-bind-elt"
      ],
      "for-expr_I3_I0": [
        "for-bind-elt"
      ],
      "try-expr_I3": [],
      "name-ann": [],
      "record-ann": [],
      "arrow-ann": [],
      "app-ann": [],
      "pred-ann": [],
      "dot-ann": [],
      "record-ann_A0_I1_opt": [
        "ε",
        "record-ann_A0_I1",
        "ann-field"
      ],
      "record-ann_A0_I1": [
        "ann-field"
      ],
      "record-ann_A0_I1_I0_star": [
        "ε",
        "record-ann_A0_I1_I0",
        "list-ann-field"
      ],
      "ann-field": [],
      "record-ann_A0_I1_I0": [
        "list-ann-field"
      ],
      "list-ann-field": [],
      "noparen-arrow-ann_I0_opt": [
        "ε",
        "noparen-arrow-ann_I0",
        "ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "noparen-arrow-ann_I0": [
        "ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "noparen-arrow-ann_I0_I0_star": [
        "ε",
        "noparen-arrow-ann_I0_I0",
        "arrow-ann-elt"
      ],
      "noparen-arrow-ann_I0_I0": [
        "arrow-ann-elt"
      ],
      "arrow-ann-elt": [],
      "arrow-ann_I0": [],
      "arrow-ann_I1_opt": [
        "ε",
        "arrow-ann_I1",
        "ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "arrow-ann_I1": [
        "ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "arrow-ann_I1_I0_star": [
        "ε",
        "arrow-ann_I1_I0",
        "arrow-ann-elt"
      ],
      "arrow-ann_I1_I0": [
        "arrow-ann-elt"
      ],
      "app-ann_I0": [
        "name-ann",
        "dot-ann"
      ],
      "app-ann_I1": [],
      "app-ann_I2_star": [
        "ε",
        "app-ann_I2",
        "app-ann-elt"
      ],
      "app-ann_I4": [],
      "app-ann_I2": [
        "app-ann-elt"
      ],
      "app-ann-elt": [],
      "pred-ann_I2": [],
      "START": [
        "program",
        "ε",
        "prelude",
        "prelude_I0_opt",
        "prelude_I1_star",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "import-stmt",
        "block",
        "stmt",
        "block_I0_star",
        "block_I0",
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "obj-expr",
        "dot-expr",
        "bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "construct-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ]
    },
    "rulesByOldId": {
      "0": {
        "name": "program",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "1": {
        "name": "end",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "END"
          }
        ]
      },
      "2": {
        "name": "end",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SEMI"
          }
        ]
      },
      "3": {
        "name": "prelude",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "4": {
        "name": "prelude_I0_opt",
        "position": 0,
        "symbols": []
      },
      "5": {
        "name": "prelude_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0"
          }
        ]
      },
      "6": {
        "name": "prelude_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "provide-stmt"
          }
        ]
      },
      "7": {
        "name": "prelude_I1_star",
        "position": 0,
        "symbols": []
      },
      "8": {
        "name": "prelude_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I1"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "9": {
        "name": "prelude_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt"
          }
        ]
      },
      "10": {
        "name": "import-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I1"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "11": {
        "name": "import-stmt_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "12": {
        "name": "import-stmt_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "13": {
        "name": "import-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I4"
          }
        ]
      },
      "14": {
        "name": "import-stmt_I2_star",
        "position": 0,
        "symbols": []
      },
      "15": {
        "name": "import-stmt_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt_I2"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          }
        ]
      },
      "16": {
        "name": "import-stmt_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "17": {
        "name": "import-stmt_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "18": {
        "name": "import-stmt_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "19": {
        "name": "import-name",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "20": {
        "name": "import-string",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "21": {
        "name": "provide-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "22": {
        "name": "provide-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "23": {
        "name": "block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "24": {
        "name": "block_I0_star",
        "position": 0,
        "symbols": []
      },
      "25": {
        "name": "block_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0"
          },
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "26": {
        "name": "block_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "27": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "28": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fun-expr"
          }
        ]
      },
      "29": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr"
          }
        ]
      },
      "30": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr"
          }
        ]
      },
      "31": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "when-expr"
          }
        ]
      },
      "32": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "33": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "assign-expr"
          }
        ]
      },
      "34": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-test"
          }
        ]
      },
      "35": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr"
          }
        ]
      },
      "36": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr"
          }
        ]
      },
      "37": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "contract-stmt"
          }
        ]
      },
      "38": {
        "name": "let-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "39": {
        "name": "let-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "VAL"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "40": {
        "name": "binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "41": {
        "name": "binding_I0_opt",
        "position": 0,
        "symbols": []
      },
      "42": {
        "name": "binding_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0"
          }
        ]
      },
      "43": {
        "name": "binding_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "44": {
        "name": "binding_I2_opt",
        "position": 0,
        "symbols": []
      },
      "45": {
        "name": "binding_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I2"
          }
        ]
      },
      "46": {
        "name": "binding_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "47": {
        "name": "toplevel-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "48": {
        "name": "toplevel-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "49": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 0,
        "symbols": []
      },
      "50": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0"
          }
        ]
      },
      "51": {
        "name": "toplevel-binding_A1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "52": {
        "name": "multi-let-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LET"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "53": {
        "name": "multi-let-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "54": {
        "name": "multi-let-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "55": {
        "name": "multi-let-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding-elt"
          }
        ]
      },
      "56": {
        "name": "let-binding-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "57": {
        "name": "let-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "58": {
        "name": "let-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "59": {
        "name": "letrec-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LETREC"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "60": {
        "name": "letrec-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "61": {
        "name": "letrec-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "62": {
        "name": "letrec-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-binding"
          }
        ]
      },
      "63": {
        "name": "letrec-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "64": {
        "name": "contract-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "contract-stmt_I2"
          }
        ]
      },
      "65": {
        "name": "contract-stmt_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "66": {
        "name": "contract-stmt_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "67": {
        "name": "fun-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "fun-header"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "68": {
        "name": "fun-header",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "69": {
        "name": "ty-params",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_opt"
          }
        ]
      },
      "70": {
        "name": "ty-params_I0_opt",
        "position": 0,
        "symbols": []
      },
      "71": {
        "name": "ty-params_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0"
          }
        ]
      },
      "72": {
        "name": "ty-params_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I3"
          }
        ]
      },
      "73": {
        "name": "ty-params_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "74": {
        "name": "ty-params_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "75": {
        "name": "ty-params_I0_I1_star",
        "position": 0,
        "symbols": []
      },
      "76": {
        "name": "ty-params_I0_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "77": {
        "name": "ty-params_I0_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ty-param"
          }
        ]
      },
      "78": {
        "name": "ty-params_I0_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "79": {
        "name": "ty-params_I0_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "80": {
        "name": "list-ty-param",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "81": {
        "name": "args",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "82": {
        "name": "args_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "83": {
        "name": "args_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "84": {
        "name": "args_I1_opt",
        "position": 0,
        "symbols": []
      },
      "85": {
        "name": "args_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1"
          }
        ]
      },
      "86": {
        "name": "args_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "87": {
        "name": "args_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "88": {
        "name": "args_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "89": {
        "name": "args_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-arg-elt"
          }
        ]
      },
      "90": {
        "name": "list-arg-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "91": {
        "name": "return-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0_opt"
          }
        ]
      },
      "92": {
        "name": "return-ann_I0_opt",
        "position": 0,
        "symbols": []
      },
      "93": {
        "name": "return-ann_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0"
          }
        ]
      },
      "94": {
        "name": "return-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "95": {
        "name": "doc-string",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0_opt"
          }
        ]
      },
      "96": {
        "name": "doc-string_I0_opt",
        "position": 0,
        "symbols": []
      },
      "97": {
        "name": "doc-string_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0"
          }
        ]
      },
      "98": {
        "name": "doc-string_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DOC"
          },
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "99": {
        "name": "where-clause",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0_opt"
          }
        ]
      },
      "100": {
        "name": "where-clause_I0_opt",
        "position": 0,
        "symbols": []
      },
      "101": {
        "name": "where-clause_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0"
          }
        ]
      },
      "102": {
        "name": "where-clause_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WHERE"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "103": {
        "name": "where-clause",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "104": {
        "name": "check-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECK"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "105": {
        "name": "check-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECKCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "106": {
        "name": "check-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLES"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "107": {
        "name": "check-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "108": {
        "name": "check-test",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "check-op"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "109": {
        "name": "check-test",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "110": {
        "name": "data-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "111": {
        "name": "data-expr_I5_opt",
        "position": 0,
        "symbols": []
      },
      "112": {
        "name": "data-expr_I5_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I5"
          }
        ]
      },
      "113": {
        "name": "data-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-data-variant"
          }
        ]
      },
      "114": {
        "name": "data-expr_I6_star",
        "position": 0,
        "symbols": []
      },
      "115": {
        "name": "data-expr_I6_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "116": {
        "name": "data-expr_I6",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-variant"
          }
        ]
      },
      "117": {
        "name": "data-mixins",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0_opt"
          }
        ]
      },
      "118": {
        "name": "data-mixins_I0_opt",
        "position": 0,
        "symbols": []
      },
      "119": {
        "name": "data-mixins_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0"
          }
        ]
      },
      "120": {
        "name": "data-mixins_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DERIVING"
          },
          {
            "type": "Nonterm",
            "name": "mixins"
          }
        ]
      },
      "121": {
        "name": "variant-constructor",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          }
        ]
      },
      "122": {
        "name": "first-data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "123": {
        "name": "first-data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "124": {
        "name": "data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "125": {
        "name": "data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "126": {
        "name": "variant-members",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "127": {
        "name": "variant-members_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "128": {
        "name": "variant-members_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "129": {
        "name": "variant-members_I1_opt",
        "position": 0,
        "symbols": []
      },
      "130": {
        "name": "variant-members_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1"
          }
        ]
      },
      "131": {
        "name": "variant-members_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "variant-member"
          }
        ]
      },
      "132": {
        "name": "variant-members_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "133": {
        "name": "variant-members_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "134": {
        "name": "variant-members_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-variant-member"
          }
        ]
      },
      "135": {
        "name": "list-variant-member",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "136": {
        "name": "variant-member",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "137": {
        "name": "variant-member_I0_opt",
        "position": 0,
        "symbols": []
      },
      "138": {
        "name": "variant-member_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0"
          }
        ]
      },
      "139": {
        "name": "variant-member_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          }
        ]
      },
      "140": {
        "name": "variant-member_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CYCLIC"
          }
        ]
      },
      "141": {
        "name": "data-with",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0_opt"
          }
        ]
      },
      "142": {
        "name": "data-with_I0_opt",
        "position": 0,
        "symbols": []
      },
      "143": {
        "name": "data-with_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0"
          }
        ]
      },
      "144": {
        "name": "data-with_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WITH"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "145": {
        "name": "data-sharing",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0_opt"
          }
        ]
      },
      "146": {
        "name": "data-sharing_I0_opt",
        "position": 0,
        "symbols": []
      },
      "147": {
        "name": "data-sharing_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0"
          }
        ]
      },
      "148": {
        "name": "data-sharing_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHARING"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "149": {
        "name": "mixins",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "150": {
        "name": "mixins_I0_star",
        "position": 0,
        "symbols": []
      },
      "151": {
        "name": "mixins_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "152": {
        "name": "mixins_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-mixin"
          }
        ]
      },
      "153": {
        "name": "list-mixin",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "154": {
        "name": "datatype-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "155": {
        "name": "datatype-expr_I4_opt",
        "position": 0,
        "symbols": []
      },
      "156": {
        "name": "datatype-expr_I4_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4"
          }
        ]
      },
      "157": {
        "name": "datatype-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-datatype-variant"
          }
        ]
      },
      "158": {
        "name": "datatype-expr_I5_star",
        "position": 0,
        "symbols": []
      },
      "159": {
        "name": "datatype-expr_I5_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "160": {
        "name": "datatype-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-variant"
          }
        ]
      },
      "161": {
        "name": "first-datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "162": {
        "name": "first-datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "163": {
        "name": "datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "164": {
        "name": "datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "165": {
        "name": "constructor-clause",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WITHCONSTRUCTOR"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause_I1"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "166": {
        "name": "constructor-clause_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "167": {
        "name": "constructor-clause_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "168": {
        "name": "var-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "VAR"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "169": {
        "name": "assign-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONEQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "170": {
        "name": "graph-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GRAPH"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "171": {
        "name": "graph-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "172": {
        "name": "graph-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "173": {
        "name": "graph-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "174": {
        "name": "when-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WHEN"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "175": {
        "name": "binop-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "176": {
        "name": "binop-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "177": {
        "name": "binop-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "178": {
        "name": "binop-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          }
        ]
      },
      "179": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PLUS"
          }
        ]
      },
      "180": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DASH"
          }
        ]
      },
      "181": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "182": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SLASH"
          }
        ]
      },
      "183": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LEQ"
          }
        ]
      },
      "184": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GEQ"
          }
        ]
      },
      "185": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "EQUALEQUAL"
          }
        ]
      },
      "186": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NEQ"
          }
        ]
      },
      "187": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "188": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "189": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "AND"
          }
        ]
      },
      "190": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "OR"
          }
        ]
      },
      "191": {
        "name": "binop",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CARET"
          }
        ]
      },
      "192": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IS"
          }
        ]
      },
      "193": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RAISES"
          }
        ]
      },
      "194": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SATISFIES"
          }
        ]
      },
      "195": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "paren-expr"
          }
        ]
      },
      "196": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          }
        ]
      },
      "197": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prim-expr"
          }
        ]
      },
      "198": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "lambda-expr"
          }
        ]
      },
      "199": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "method-expr"
          }
        ]
      },
      "200": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-expr"
          }
        ]
      },
      "201": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-expr"
          }
        ]
      },
      "202": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-expr"
          }
        ]
      },
      "203": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bracket-expr"
          }
        ]
      },
      "204": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "get-bang-expr"
          }
        ]
      },
      "205": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "update-expr"
          }
        ]
      },
      "206": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "extend-expr"
          }
        ]
      },
      "207": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr"
          }
        ]
      },
      "208": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr"
          }
        ]
      },
      "209": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr"
          }
        ]
      },
      "210": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr"
          }
        ]
      },
      "211": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "try-expr"
          }
        ]
      },
      "212": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "user-block-expr"
          }
        ]
      },
      "213": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr"
          }
        ]
      },
      "214": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr"
          }
        ]
      },
      "215": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr"
          }
        ]
      },
      "216": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr"
          }
        ]
      },
      "217": {
        "name": "bad-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "UNTERMINATED-STRING"
          }
        ]
      },
      "218": {
        "name": "bad-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "UNKNOWN"
          }
        ]
      },
      "219": {
        "name": "paren-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "220": {
        "name": "id-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "221": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "num-expr"
          }
        ]
      },
      "222": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "frac-expr"
          }
        ]
      },
      "223": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bool-expr"
          }
        ]
      },
      "224": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "string-expr"
          }
        ]
      },
      "225": {
        "name": "num-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NUMBER"
          }
        ]
      },
      "226": {
        "name": "frac-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RATIONAL"
          }
        ]
      },
      "227": {
        "name": "bool-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "TRUE"
          }
        ]
      },
      "228": {
        "name": "bool-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FALSE"
          }
        ]
      },
      "229": {
        "name": "string-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "230": {
        "name": "lambda-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LAM"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "231": {
        "name": "method-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "METHOD"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "232": {
        "name": "app-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "app-args"
          }
        ]
      },
      "233": {
        "name": "app-args",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "234": {
        "name": "app-args_I1_opt",
        "position": 0,
        "symbols": []
      },
      "235": {
        "name": "app-args_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1"
          }
        ]
      },
      "236": {
        "name": "app-args_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "237": {
        "name": "app-args_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "238": {
        "name": "app-args_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "239": {
        "name": "app-args_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-arg-elt"
          }
        ]
      },
      "240": {
        "name": "app-arg-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "241": {
        "name": "inst-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I4"
          }
        ]
      },
      "242": {
        "name": "inst-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "243": {
        "name": "inst-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "244": {
        "name": "inst-expr_I2_star",
        "position": 0,
        "symbols": []
      },
      "245": {
        "name": "inst-expr_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "246": {
        "name": "inst-expr_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-elt"
          }
        ]
      },
      "247": {
        "name": "inst-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "248": {
        "name": "inst-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "249": {
        "name": "inst-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "250": {
        "name": "obj-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "251": {
        "name": "obj-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "252": {
        "name": "obj-fields",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "253": {
        "name": "obj-fields_I0_star",
        "position": 0,
        "symbols": []
      },
      "254": {
        "name": "obj-fields_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "255": {
        "name": "obj-fields_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-obj-field"
          }
        ]
      },
      "256": {
        "name": "obj-fields_I2_opt",
        "position": 0,
        "symbols": []
      },
      "257": {
        "name": "obj-fields_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I2"
          }
        ]
      },
      "258": {
        "name": "obj-fields_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "259": {
        "name": "list-obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "260": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "261": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          },
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2_opt"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "262": {
        "name": "obj-field_A1_I2_opt",
        "position": 0,
        "symbols": []
      },
      "263": {
        "name": "obj-field_A1_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2"
          }
        ]
      },
      "264": {
        "name": "obj-field_A1_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "265": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "266": {
        "name": "fields",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "267": {
        "name": "fields_I0_star",
        "position": 0,
        "symbols": []
      },
      "268": {
        "name": "fields_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "269": {
        "name": "fields_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-field"
          }
        ]
      },
      "270": {
        "name": "fields_I2_opt",
        "position": 0,
        "symbols": []
      },
      "271": {
        "name": "fields_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I2"
          }
        ]
      },
      "272": {
        "name": "fields_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "273": {
        "name": "list-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "274": {
        "name": "field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "275": {
        "name": "field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "276": {
        "name": "key",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "277": {
        "name": "key",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "278": {
        "name": "construct-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "construct-modifier"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_opt"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "279": {
        "name": "construct-expr_I4_opt",
        "position": 0,
        "symbols": []
      },
      "280": {
        "name": "construct-expr_I4_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4"
          }
        ]
      },
      "281": {
        "name": "construct-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "282": {
        "name": "construct-expr_I4_I0_star",
        "position": 0,
        "symbols": []
      },
      "283": {
        "name": "construct-expr_I4_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          }
        ]
      },
      "284": {
        "name": "construct-expr_I4_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-elt"
          }
        ]
      },
      "285": {
        "name": "construct-modifier",
        "position": 0,
        "symbols": []
      },
      "286": {
        "name": "construct-modifier",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LAZY"
          }
        ]
      },
      "287": {
        "name": "list-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "288": {
        "name": "dot-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "289": {
        "name": "bracket-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "290": {
        "name": "get-bang-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "291": {
        "name": "extend-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "292": {
        "name": "update-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "293": {
        "name": "if-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "294": {
        "name": "if-expr_I4_star",
        "position": 0,
        "symbols": []
      },
      "295": {
        "name": "if-expr_I4_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "296": {
        "name": "if-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "else-if"
          }
        ]
      },
      "297": {
        "name": "if-expr_I5_opt",
        "position": 0,
        "symbols": []
      },
      "298": {
        "name": "if-expr_I5_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I5"
          }
        ]
      },
      "299": {
        "name": "if-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "300": {
        "name": "else-if",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSEIF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "301": {
        "name": "if-pipe-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "ASKCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "302": {
        "name": "if-pipe-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "303": {
        "name": "if-pipe-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "304": {
        "name": "if-pipe-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-branch"
          }
        ]
      },
      "305": {
        "name": "if-pipe-expr_I2_opt",
        "position": 0,
        "symbols": []
      },
      "306": {
        "name": "if-pipe-expr_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2"
          }
        ]
      },
      "307": {
        "name": "if-pipe-expr_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "OTHERWISECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "308": {
        "name": "if-pipe-branch",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "THENCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "309": {
        "name": "cases-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "310": {
        "name": "cases-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "311": {
        "name": "cases-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "312": {
        "name": "cases-expr_I6_star",
        "position": 0,
        "symbols": []
      },
      "313": {
        "name": "cases-expr_I6_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "314": {
        "name": "cases-expr_I6",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch"
          }
        ]
      },
      "315": {
        "name": "cases-expr_I7_opt",
        "position": 0,
        "symbols": []
      },
      "316": {
        "name": "cases-expr_I7_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I7"
          }
        ]
      },
      "317": {
        "name": "cases-expr_I7",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSE"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "318": {
        "name": "cases-branch",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "cases-branch_I2_opt"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "319": {
        "name": "cases-branch_I2_opt",
        "position": 0,
        "symbols": []
      },
      "320": {
        "name": "cases-branch_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch_I2"
          }
        ]
      },
      "321": {
        "name": "cases-branch_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args"
          }
        ]
      },
      "322": {
        "name": "for-bind",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "323": {
        "name": "for-bind-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "324": {
        "name": "for-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FOR"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "325": {
        "name": "for-expr_I3_opt",
        "position": 0,
        "symbols": []
      },
      "326": {
        "name": "for-expr_I3_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3"
          }
        ]
      },
      "327": {
        "name": "for-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "for-bind"
          }
        ]
      },
      "328": {
        "name": "for-expr_I3_I0_star",
        "position": 0,
        "symbols": []
      },
      "329": {
        "name": "for-expr_I3_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "330": {
        "name": "for-expr_I3_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind-elt"
          }
        ]
      },
      "331": {
        "name": "try-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "TRY"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Token",
            "name": "EXCEPT"
          },
          {
            "type": "Nonterm",
            "name": "try-expr_I3"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "332": {
        "name": "try-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "333": {
        "name": "try-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "334": {
        "name": "user-block-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BLOCK"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "335": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "336": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann"
          }
        ]
      },
      "337": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann"
          }
        ]
      },
      "338": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann"
          }
        ]
      },
      "339": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "pred-ann"
          }
        ]
      },
      "340": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "341": {
        "name": "name-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "342": {
        "name": "record-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_opt"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "343": {
        "name": "record-ann_A0_I1_opt",
        "position": 0,
        "symbols": []
      },
      "344": {
        "name": "record-ann_A0_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1"
          }
        ]
      },
      "345": {
        "name": "record-ann_A0_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann-field"
          }
        ]
      },
      "346": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "347": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "348": {
        "name": "record-ann_A0_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ann-field"
          }
        ]
      },
      "349": {
        "name": "record-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "350": {
        "name": "list-ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "351": {
        "name": "ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "352": {
        "name": "ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "353": {
        "name": "noparen-arrow-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "354": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 0,
        "symbols": []
      },
      "355": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0"
          }
        ]
      },
      "356": {
        "name": "noparen-arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "357": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 0,
        "symbols": []
      },
      "358": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "359": {
        "name": "noparen-arrow-ann_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "360": {
        "name": "arrow-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "361": {
        "name": "arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "362": {
        "name": "arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "363": {
        "name": "arrow-ann_I1_opt",
        "position": 0,
        "symbols": []
      },
      "364": {
        "name": "arrow-ann_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1"
          }
        ]
      },
      "365": {
        "name": "arrow-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "366": {
        "name": "arrow-ann_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "367": {
        "name": "arrow-ann_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "368": {
        "name": "arrow-ann_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "369": {
        "name": "arrow-ann-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "370": {
        "name": "app-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I1"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I4"
          }
        ]
      },
      "371": {
        "name": "app-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "372": {
        "name": "app-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "373": {
        "name": "app-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "374": {
        "name": "app-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "375": {
        "name": "app-ann_I2_star",
        "position": 0,
        "symbols": []
      },
      "376": {
        "name": "app-ann_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "377": {
        "name": "app-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann-elt"
          }
        ]
      },
      "378": {
        "name": "app-ann_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "379": {
        "name": "app-ann_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "380": {
        "name": "app-ann-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "381": {
        "name": "pred-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "PERCENT"
          },
          {
            "type": "Nonterm",
            "name": "pred-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "382": {
        "name": "pred-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "383": {
        "name": "pred-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "384": {
        "name": "dot-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "385": {
        "name": "START",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "program"
          }
        ]
      },
      "587": {
        "name": "program",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "4288": {
        "name": "prelude",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "4484": {
        "name": "prelude_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0"
          }
        ]
      },
      "4518": {
        "name": "prelude_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "provide-stmt"
          }
        ]
      },
      "4782": {
        "name": "program",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "4786": {
        "name": "id-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "4903": {
        "name": "string-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "4956": {
        "name": "block_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "4989": {
        "name": "block",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "4991": {
        "name": "block_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0"
          },
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "4993": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "5026": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fun-expr"
          }
        ]
      },
      "5059": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr"
          }
        ]
      },
      "5092": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr"
          }
        ]
      },
      "5125": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "when-expr"
          }
        ]
      },
      "5158": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "5191": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "assign-expr"
          }
        ]
      },
      "5224": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-test"
          }
        ]
      },
      "5257": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr"
          }
        ]
      },
      "5290": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr"
          }
        ]
      },
      "5323": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "contract-stmt"
          }
        ]
      },
      "5390": {
        "name": "check-test",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "5545": {
        "name": "toplevel-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "5549": {
        "name": "binding_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0"
          }
        ]
      },
      "5551": {
        "name": "toplevel-binding_A1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "5552": {
        "name": "binding_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "5557": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0"
          }
        ]
      },
      "5559": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr"
          }
        ]
      },
      "5686": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr"
          }
        ]
      },
      "6319": {
        "name": "binop-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "7151": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "paren-expr"
          }
        ]
      },
      "7204": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          }
        ]
      },
      "7257": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prim-expr"
          }
        ]
      },
      "7310": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "lambda-expr"
          }
        ]
      },
      "7363": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "method-expr"
          }
        ]
      },
      "7416": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-expr"
          }
        ]
      },
      "7469": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-expr"
          }
        ]
      },
      "7522": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-expr"
          }
        ]
      },
      "7575": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bracket-expr"
          }
        ]
      },
      "7628": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "get-bang-expr"
          }
        ]
      },
      "7681": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "update-expr"
          }
        ]
      },
      "7734": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "extend-expr"
          }
        ]
      },
      "7787": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr"
          }
        ]
      },
      "7840": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr"
          }
        ]
      },
      "7893": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr"
          }
        ]
      },
      "7946": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr"
          }
        ]
      },
      "7999": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "try-expr"
          }
        ]
      },
      "8052": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "user-block-expr"
          }
        ]
      },
      "8105": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr"
          }
        ]
      },
      "8158": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr"
          }
        ]
      },
      "8211": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "num-expr"
          }
        ]
      },
      "8264": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "frac-expr"
          }
        ]
      },
      "8317": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bool-expr"
          }
        ]
      },
      "8370": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "string-expr"
          }
        ]
      },
      "8423": {
        "name": "num-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NUMBER"
          }
        ]
      },
      "8476": {
        "name": "frac-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RATIONAL"
          }
        ]
      },
      "8529": {
        "name": "bool-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "TRUE"
          }
        ]
      },
      "8582": {
        "name": "bool-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "FALSE"
          }
        ]
      },
      "9399": {
        "name": "prelude",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "9432": {
        "name": "prelude_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I1"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "9465": {
        "name": "prelude_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt"
          }
        ]
      },
      "9679": {
        "name": "provide-stmt",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "10516": {
        "name": "block_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block_I0"
          },
          {
            "type": "Nonterm",
            "name": "block_I0_star"
          }
        ]
      },
      "10584": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "IS"
          }
        ]
      },
      "10604": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RAISES"
          }
        ]
      },
      "10624": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SATISFIES"
          }
        ]
      },
      "10677": {
        "name": "binding",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "10684": {
        "name": "let-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "10686": {
        "name": "let-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "10753": {
        "name": "multi-let-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "10758": {
        "name": "multi-let-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding-elt"
          }
        ]
      },
      "10821": {
        "name": "letrec-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "10825": {
        "name": "letrec-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-binding"
          }
        ]
      },
      "10864": {
        "name": "ty-params",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_opt"
          }
        ]
      },
      "10866": {
        "name": "ty-params_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0"
          }
        ]
      },
      "10874": {
        "name": "ty-params_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "10876": {
        "name": "ty-params_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "11234": {
        "name": "graph-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "11273": {
        "name": "graph-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "11367": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "11387": {
        "name": "inst-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "11392": {
        "name": "inst-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "11393": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "11417": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "11623": {
        "name": "binop-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "11659": {
        "name": "binop-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "11744": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PLUS"
          }
        ]
      },
      "11764": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "DASH"
          }
        ]
      },
      "11784": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SLASH"
          }
        ]
      },
      "11804": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LEQ"
          }
        ]
      },
      "11824": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GEQ"
          }
        ]
      },
      "11844": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "EQUALEQUAL"
          }
        ]
      },
      "11864": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NEQ"
          }
        ]
      },
      "11884": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "AND"
          }
        ]
      },
      "11904": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "OR"
          }
        ]
      },
      "11924": {
        "name": "binop",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "CARET"
          }
        ]
      },
      "11944": {
        "name": "app-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "app-args"
          }
        ]
      },
      "12462": {
        "name": "args_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "12466": {
        "name": "args_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "12470": {
        "name": "key",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "12531": {
        "name": "obj-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "12593": {
        "name": "obj-fields_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "12597": {
        "name": "obj-fields_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-obj-field"
          }
        ]
      },
      "12716": {
        "name": "construct-modifier",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LAZY"
          }
        ]
      },
      "12906": {
        "name": "if-pipe-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "12910": {
        "name": "if-pipe-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-branch"
          }
        ]
      },
      "12914": {
        "name": "cases-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "12919": {
        "name": "cases-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "13277": {
        "name": "prelude_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I1"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "13345": {
        "name": "import-name",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "13384": {
        "name": "import-stmt_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "13386": {
        "name": "import-stmt_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "13388": {
        "name": "import-string",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "13390": {
        "name": "provide-stmt",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "13424": {
        "name": "end",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "END"
          }
        ]
      },
      "13458": {
        "name": "end",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SEMI"
          }
        ]
      },
      "13492": {
        "name": "name-ann",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "13566": {
        "name": "contract-stmt_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "13639": {
        "name": "contract-stmt_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "13672": {
        "name": "contract-stmt",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "contract-stmt_I2"
          }
        ]
      },
      "13705": {
        "name": "arrow-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "13711": {
        "name": "arrow-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "13796": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "13797": {
        "name": "app-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "13834": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann"
          }
        ]
      },
      "13869": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann"
          }
        ]
      },
      "13904": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann"
          }
        ]
      },
      "13939": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "pred-ann"
          }
        ]
      },
      "13974": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "13975": {
        "name": "app-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "14045": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0"
          }
        ]
      },
      "14062": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "14067": {
        "name": "noparen-arrow-ann_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "14165": {
        "name": "assign-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONEQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "14198": {
        "name": "let-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "14231": {
        "name": "check-test",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "check-op"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "14297": {
        "name": "binding",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "14299": {
        "name": "binding_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I2"
          }
        ]
      },
      "14377": {
        "name": "let-binding-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "14382": {
        "name": "multi-let-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "14387": {
        "name": "letrec-binding",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "14444": {
        "name": "letrec-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "14623": {
        "name": "ty-params_I0_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "14625": {
        "name": "ty-params_I0_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ty-param"
          }
        ]
      },
      "14627": {
        "name": "paren-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "14680": {
        "name": "check-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "14746": {
        "name": "check-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECKCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "14921": {
        "name": "graph-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "GRAPH"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "14954": {
        "name": "graph-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "15112": {
        "name": "app-args_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1"
          }
        ]
      },
      "15116": {
        "name": "app-args_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "15136": {
        "name": "app-args_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-arg-elt"
          }
        ]
      },
      "15165": {
        "name": "binop-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr_I1_star"
          }
        ]
      },
      "15201": {
        "name": "binop-expr_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          }
        ]
      },
      "15334": {
        "name": "inst-expr_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "15339": {
        "name": "inst-expr_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-elt"
          }
        ]
      },
      "15344": {
        "name": "dot-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "15514": {
        "name": "get-bang-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "15726": {
        "name": "return-ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0_opt"
          }
        ]
      },
      "15728": {
        "name": "return-ann_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0"
          }
        ]
      },
      "15752": {
        "name": "args_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1"
          }
        ]
      },
      "15757": {
        "name": "args_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "15760": {
        "name": "args_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-arg-elt"
          }
        ]
      },
      "15770": {
        "name": "obj-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "15824": {
        "name": "obj-fields",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "15831": {
        "name": "list-obj-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "15835": {
        "name": "obj-fields_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "16299": {
        "name": "if-pipe-expr_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2"
          }
        ]
      },
      "16302": {
        "name": "if-pipe-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "16495": {
        "name": "user-block-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BLOCK"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "16656": {
        "name": "import-stmt_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt_I2"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          }
        ]
      },
      "16698": {
        "name": "arrow-ann-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "16780": {
        "name": "record-ann",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "16850": {
        "name": "record-ann_A0_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1"
          }
        ]
      },
      "16858": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "16860": {
        "name": "record-ann_A0_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ann-field"
          }
        ]
      },
      "16897": {
        "name": "noparen-arrow-ann_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "16910": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "16915": {
        "name": "arrow-ann_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "16955": {
        "name": "arrow-ann_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1"
          }
        ]
      },
      "16959": {
        "name": "arrow-ann_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "16964": {
        "name": "app-ann_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "16969": {
        "name": "app-ann_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "17025": {
        "name": "let-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "VAL"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "17060": {
        "name": "binding_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "17073": {
        "name": "toplevel-binding",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "17303": {
        "name": "doc-string",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0_opt"
          }
        ]
      },
      "17338": {
        "name": "doc-string_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0"
          }
        ]
      },
      "17408": {
        "name": "fun-header",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "17410": {
        "name": "list-ty-param",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "17416": {
        "name": "ty-params_I0_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "17517": {
        "name": "data-mixins",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0_opt"
          }
        ]
      },
      "17519": {
        "name": "data-mixins_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0"
          }
        ]
      },
      "17659": {
        "name": "var-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "VAR"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "17725": {
        "name": "app-arg-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "17745": {
        "name": "app-args",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "17798": {
        "name": "app-args_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "17800": {
        "name": "app-args_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "17820": {
        "name": "inst-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "18008": {
        "name": "inst-expr_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "18077": {
        "name": "fields_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "18080": {
        "name": "fields_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-field"
          }
        ]
      },
      "18297": {
        "name": "return-ann_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "18310": {
        "name": "list-arg-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "18313": {
        "name": "args",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "18316": {
        "name": "args_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "18319": {
        "name": "args_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "18326": {
        "name": "obj-field_A1_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2"
          }
        ]
      },
      "18328": {
        "name": "obj-fields_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "18330": {
        "name": "obj-fields",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "18332": {
        "name": "obj-fields_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I2"
          }
        ]
      },
      "18334": {
        "name": "obj-field",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "18338": {
        "name": "key",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "18717": {
        "name": "if-pipe-branch",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "THENCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "18806": {
        "name": "if-pipe-expr_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "OTHERWISECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "18809": {
        "name": "if-pipe-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "ASKCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "18922": {
        "name": "for-expr_I3_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind-elt"
          }
        ]
      },
      "18978": {
        "name": "for-expr_I3_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3"
          }
        ]
      },
      "18983": {
        "name": "for-expr_I3_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "18986": {
        "name": "try-expr_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "18989": {
        "name": "try-expr_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "19045": {
        "name": "import-stmt",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I1"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "19245": {
        "name": "import-stmt_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt_I2"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          }
        ]
      },
      "19247": {
        "name": "import-stmt_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "19250": {
        "name": "dot-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "19287": {
        "name": "pred-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "19307": {
        "name": "pred-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "19366": {
        "name": "record-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_opt"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "19403": {
        "name": "record-ann_A0_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann-field"
          }
        ]
      },
      "19405": {
        "name": "list-ann-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "19407": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "19409": {
        "name": "noparen-arrow-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "19478": {
        "name": "arrow-ann_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "19480": {
        "name": "arrow-ann_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "19525": {
        "name": "app-ann_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "19530": {
        "name": "app-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann-elt"
          }
        ]
      },
      "19775": {
        "name": "doc-string_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "DOC"
          },
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "19810": {
        "name": "fun-header",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "19812": {
        "name": "ty-params_I0",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I3"
          }
        ]
      },
      "19814": {
        "name": "ty-params_I0_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "19816": {
        "name": "ty-params_I0_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "19818": {
        "name": "check-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECK"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "19851": {
        "name": "check-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLES"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "19974": {
        "name": "data-mixins_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "DERIVING"
          },
          {
            "type": "Nonterm",
            "name": "mixins"
          }
        ]
      },
      "19978": {
        "name": "mixins_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "19998": {
        "name": "mixins_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-mixin"
          }
        ]
      },
      "20104": {
        "name": "datatype-expr_I4_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4"
          }
        ]
      },
      "20110": {
        "name": "datatype-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-datatype-variant"
          }
        ]
      },
      "20116": {
        "name": "when-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "WHEN"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "20149": {
        "name": "inst-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "20202": {
        "name": "inst-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "20255": {
        "name": "inst-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I4"
          }
        ]
      },
      "20310": {
        "name": "extend-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "20369": {
        "name": "fields",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "20374": {
        "name": "list-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "20377": {
        "name": "fields_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "20380": {
        "name": "bracket-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "20433": {
        "name": "update-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "20593": {
        "name": "obj-field_A1_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "20672": {
        "name": "construct-expr_I4_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4"
          }
        ]
      },
      "20676": {
        "name": "construct-expr_I4_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          }
        ]
      },
      "20696": {
        "name": "construct-expr_I4_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-elt"
          }
        ]
      },
      "20775": {
        "name": "if-expr_I4_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "20779": {
        "name": "if-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "else-if"
          }
        ]
      },
      "20789": {
        "name": "if-pipe-branch",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "THENCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "20881": {
        "name": "if-pipe-expr_I2",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "OTHERWISECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "20939": {
        "name": "for-bind-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "20996": {
        "name": "for-expr_I3",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "for-bind"
          }
        ]
      },
      "20998": {
        "name": "for-expr_I3_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "21087": {
        "name": "import-stmt_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "21121": {
        "name": "import-stmt_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "21155": {
        "name": "import-stmt",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I2_star"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I4"
          }
        ]
      },
      "21257": {
        "name": "ann-field",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "21259": {
        "name": "ann-field",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "21296": {
        "name": "app-ann-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "21404": {
        "name": "app-ann_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "21409": {
        "name": "multi-let-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "LET"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "21462": {
        "name": "letrec-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "LETREC"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "21548": {
        "name": "where-clause",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0_opt"
          }
        ]
      },
      "21551": {
        "name": "where-clause_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0"
          }
        ]
      },
      "21554": {
        "name": "where-clause_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "WHERE"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "21557": {
        "name": "where-clause",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "21560": {
        "name": "first-data-variant",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "21666": {
        "name": "data-expr_I5_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I5"
          }
        ]
      },
      "21673": {
        "name": "data-expr_I5",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-data-variant"
          }
        ]
      },
      "21680": {
        "name": "first-data-variant",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "21687": {
        "name": "list-mixin",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "21707": {
        "name": "mixins",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "21709": {
        "name": "mixins_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "21729": {
        "name": "variant-members_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "21735": {
        "name": "variant-members_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "21741": {
        "name": "variant-constructor",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          }
        ]
      },
      "21773": {
        "name": "first-datatype-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "21787": {
        "name": "first-datatype-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "21838": {
        "name": "datatype-expr_I5_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "21843": {
        "name": "datatype-expr_I5",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-variant"
          }
        ]
      },
      "21849": {
        "name": "field",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "21853": {
        "name": "fields_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "21855": {
        "name": "fields",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "21857": {
        "name": "fields_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I2"
          }
        ]
      },
      "21965": {
        "name": "obj-field",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          },
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2_opt"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "21969": {
        "name": "list-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "21989": {
        "name": "construct-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "construct-modifier"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_opt"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "22042": {
        "name": "construct-expr_I4",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "22044": {
        "name": "construct-expr_I4_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0"
          },
          {
            "type": "Nonterm",
            "name": "construct-expr_I4_I0_star"
          }
        ]
      },
      "22117": {
        "name": "if-expr_I5_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I5"
          }
        ]
      },
      "22120": {
        "name": "if-expr_I5",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "22123": {
        "name": "if-expr_I4_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "22205": {
        "name": "for-bind",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "22313": {
        "name": "pred-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "PERCENT"
          },
          {
            "type": "Nonterm",
            "name": "pred-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "22348": {
        "name": "arrow-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "22383": {
        "name": "app-ann_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "22418": {
        "name": "app-ann_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "22453": {
        "name": "app-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I1"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I4"
          }
        ]
      },
      "22488": {
        "name": "fun-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "fun-header"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "22521": {
        "name": "where-clause_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "WHERE"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "22524": {
        "name": "where-clause",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "22534": {
        "name": "first-data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "22548": {
        "name": "data-with",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0_opt"
          }
        ]
      },
      "22555": {
        "name": "data-with_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0"
          }
        ]
      },
      "22624": {
        "name": "data-expr_I6_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "22630": {
        "name": "data-expr_I6",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-variant"
          }
        ]
      },
      "22651": {
        "name": "first-data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "22660": {
        "name": "variant-members_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1"
          }
        ]
      },
      "22670": {
        "name": "variant-members_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "22675": {
        "name": "variant-members_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-variant-member"
          }
        ]
      },
      "22682": {
        "name": "variant-member_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0"
          }
        ]
      },
      "22685": {
        "name": "variant-member_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          }
        ]
      },
      "22688": {
        "name": "variant-member_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "CYCLIC"
          }
        ]
      },
      "22691": {
        "name": "constructor-clause_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "22693": {
        "name": "constructor-clause_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "22746": {
        "name": "datatype-expr_I5_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "22861": {
        "name": "if-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "22914": {
        "name": "if-expr_I5",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "22917": {
        "name": "else-if",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSEIF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "22985": {
        "name": "cases-expr_I6_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "22989": {
        "name": "cases-expr_I6",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch"
          }
        ]
      },
      "23099": {
        "name": "data-with_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "WITH"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "23157": {
        "name": "data-sharing",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0_opt"
          }
        ]
      },
      "23162": {
        "name": "data-sharing_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0"
          }
        ]
      },
      "23172": {
        "name": "data-expr_I6_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "23178": {
        "name": "data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "23185": {
        "name": "data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "23192": {
        "name": "variant-members",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "23194": {
        "name": "variant-members_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "variant-member"
          }
        ]
      },
      "23197": {
        "name": "list-variant-member",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "23202": {
        "name": "variant-members_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "23207": {
        "name": "variant-member",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "23215": {
        "name": "datatype-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "23221": {
        "name": "datatype-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "23227": {
        "name": "datatype-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23315": {
        "name": "method-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "METHOD"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23372": {
        "name": "else-if",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSEIF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "23441": {
        "name": "cases-expr_I7_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I7"
          }
        ]
      },
      "23444": {
        "name": "cases-expr_I6_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "23587": {
        "name": "data-sharing_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "SHARING"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "23592": {
        "name": "data-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "23599": {
        "name": "data-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "variant-constructor"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "23614": {
        "name": "lambda-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "LAM"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23667": {
        "name": "obj-field",
        "position": 8,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23671": {
        "name": "cases-branch_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args"
          }
        ]
      },
      "23678": {
        "name": "cases-branch_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch_I2"
          }
        ]
      },
      "23683": {
        "name": "cases-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23736": {
        "name": "for-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "FOR"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23789": {
        "name": "try-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "TRY"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Token",
            "name": "EXCEPT"
          },
          {
            "type": "Nonterm",
            "name": "try-expr_I3"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23842": {
        "name": "data-expr",
        "position": 10,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23883": {
        "name": "cases-branch",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "cases-branch_I2_opt"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "23887": {
        "name": "cases-expr_I7",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSE"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "23904": {
        "name": "field",
        "position": 8,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23906": {
        "name": "cases-branch",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "cases-branch_I2_opt"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "23910": {
        "name": "cases-expr_I7",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSE"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "23913": {
        "name": "constructor-clause",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "WITHCONSTRUCTOR"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause_I1"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      }
    },
    "actionsByOldId": {
      "0": "Rule.defaultAction",
      "1": "Rule.defaultAction",
      "2": "Rule.defaultAction",
      "3": "Rule.defaultAction",
      "4": "Rule.Inline",
      "5": "Rule.Inline",
      "6": "Rule.Inline",
      "7": "Rule.Inline",
      "8": "Rule.ListCons(\"prelude_I1\", \"prelude_I1_star\", true)",
      "9": "Rule.Inline",
      "10": "Rule.defaultAction",
      "11": "Rule.Inline",
      "12": "Rule.Inline",
      "13": "Rule.defaultAction",
      "14": "Rule.Inline",
      "15": "Rule.ListCons(\"import-stmt_I2\", \"import-stmt_I2_star\", true)",
      "16": "Rule.Inline",
      "17": "Rule.Inline",
      "18": "Rule.Inline",
      "19": "Rule.defaultAction",
      "20": "Rule.defaultAction",
      "21": "Rule.defaultAction",
      "22": "Rule.defaultAction",
      "23": "Rule.defaultAction",
      "24": "Rule.Inline",
      "25": "Rule.ListCons(\"block_I0\", \"block_I0_star\", true)",
      "26": "Rule.Inline",
      "27": "Rule.defaultAction",
      "28": "Rule.defaultAction",
      "29": "Rule.defaultAction",
      "30": "Rule.defaultAction",
      "31": "Rule.defaultAction",
      "32": "Rule.defaultAction",
      "33": "Rule.defaultAction",
      "34": "Rule.defaultAction",
      "35": "Rule.defaultAction",
      "36": "Rule.defaultAction",
      "37": "Rule.defaultAction",
      "38": "Rule.defaultAction",
      "39": "Rule.defaultAction",
      "40": "Rule.defaultAction",
      "41": "Rule.Inline",
      "42": "Rule.Inline",
      "43": "Rule.Inline",
      "44": "Rule.Inline",
      "45": "Rule.Inline",
      "46": "Rule.Inline",
      "47": "Rule.defaultAction",
      "48": "Rule.defaultAction",
      "49": "Rule.Inline",
      "50": "Rule.Inline",
      "51": "Rule.Inline",
      "52": "Rule.defaultAction",
      "53": "Rule.Inline",
      "54": "Rule.ListCons(\"multi-let-expr_I1\", \"multi-let-expr_I1_star\", true)",
      "55": "Rule.Inline",
      "56": "Rule.defaultAction",
      "57": "Rule.defaultAction",
      "58": "Rule.defaultAction",
      "59": "Rule.defaultAction",
      "60": "Rule.Inline",
      "61": "Rule.ListCons(\"letrec-expr_I1\", \"letrec-expr_I1_star\", true)",
      "62": "Rule.Inline",
      "63": "Rule.defaultAction",
      "64": "Rule.defaultAction",
      "65": "Rule.Inline",
      "66": "Rule.Inline",
      "67": "Rule.defaultAction",
      "68": "Rule.defaultAction",
      "69": "Rule.defaultAction",
      "70": "Rule.Inline",
      "71": "Rule.Inline",
      "72": "Rule.Inline",
      "73": "Rule.Inline",
      "74": "Rule.Inline",
      "75": "Rule.Inline",
      "76": "Rule.ListCons(\"ty-params_I0_I1\", \"ty-params_I0_I1_star\", true)",
      "77": "Rule.Inline",
      "78": "Rule.Inline",
      "79": "Rule.Inline",
      "80": "Rule.defaultAction",
      "81": "Rule.defaultAction",
      "82": "Rule.Inline",
      "83": "Rule.Inline",
      "84": "Rule.Inline",
      "85": "Rule.Inline",
      "86": "Rule.Inline",
      "87": "Rule.Inline",
      "88": "Rule.ListCons(\"args_I1_I0\", \"args_I1_I0_star\", true)",
      "89": "Rule.Inline",
      "90": "Rule.defaultAction",
      "91": "Rule.defaultAction",
      "92": "Rule.Inline",
      "93": "Rule.Inline",
      "94": "Rule.Inline",
      "95": "Rule.defaultAction",
      "96": "Rule.Inline",
      "97": "Rule.Inline",
      "98": "Rule.Inline",
      "99": "Rule.defaultAction",
      "100": "Rule.Inline",
      "101": "Rule.Inline",
      "102": "Rule.Inline",
      "103": "Rule.defaultAction",
      "104": "Rule.defaultAction",
      "105": "Rule.defaultAction",
      "106": "Rule.defaultAction",
      "107": "Rule.defaultAction",
      "108": "Rule.defaultAction",
      "109": "Rule.defaultAction",
      "110": "Rule.defaultAction",
      "111": "Rule.Inline",
      "112": "Rule.Inline",
      "113": "Rule.Inline",
      "114": "Rule.Inline",
      "115": "Rule.ListCons(\"data-expr_I6\", \"data-expr_I6_star\", true)",
      "116": "Rule.Inline",
      "117": "Rule.defaultAction",
      "118": "Rule.Inline",
      "119": "Rule.Inline",
      "120": "Rule.Inline",
      "121": "Rule.defaultAction",
      "122": "Rule.defaultAction",
      "123": "Rule.defaultAction",
      "124": "Rule.defaultAction",
      "125": "Rule.defaultAction",
      "126": "Rule.defaultAction",
      "127": "Rule.Inline",
      "128": "Rule.Inline",
      "129": "Rule.Inline",
      "130": "Rule.Inline",
      "131": "Rule.Inline",
      "132": "Rule.Inline",
      "133": "Rule.ListCons(\"variant-members_I1_I0\", \"variant-members_I1_I0_star\", true)",
      "134": "Rule.Inline",
      "135": "Rule.defaultAction",
      "136": "Rule.defaultAction",
      "137": "Rule.Inline",
      "138": "Rule.Inline",
      "139": "Rule.Inline",
      "140": "Rule.Inline",
      "141": "Rule.defaultAction",
      "142": "Rule.Inline",
      "143": "Rule.Inline",
      "144": "Rule.Inline",
      "145": "Rule.defaultAction",
      "146": "Rule.Inline",
      "147": "Rule.Inline",
      "148": "Rule.Inline",
      "149": "Rule.defaultAction",
      "150": "Rule.Inline",
      "151": "Rule.ListCons(\"mixins_I0\", \"mixins_I0_star\", true)",
      "152": "Rule.Inline",
      "153": "Rule.defaultAction",
      "154": "Rule.defaultAction",
      "155": "Rule.Inline",
      "156": "Rule.Inline",
      "157": "Rule.Inline",
      "158": "Rule.Inline",
      "159": "Rule.ListCons(\"datatype-expr_I5\", \"datatype-expr_I5_star\", true)",
      "160": "Rule.Inline",
      "161": "Rule.defaultAction",
      "162": "Rule.defaultAction",
      "163": "Rule.defaultAction",
      "164": "Rule.defaultAction",
      "165": "Rule.defaultAction",
      "166": "Rule.Inline",
      "167": "Rule.Inline",
      "168": "Rule.defaultAction",
      "169": "Rule.defaultAction",
      "170": "Rule.defaultAction",
      "171": "Rule.Inline",
      "172": "Rule.ListCons(\"graph-expr_I1\", \"graph-expr_I1_star\", true)",
      "173": "Rule.Inline",
      "174": "Rule.defaultAction",
      "175": "Rule.defaultAction",
      "176": "Rule.Inline",
      "177": "Rule.ListCons(\"binop-expr_I1\", \"binop-expr_I1_star\", true)",
      "178": "Rule.Inline",
      "179": "Rule.defaultAction",
      "180": "Rule.defaultAction",
      "181": "Rule.defaultAction",
      "182": "Rule.defaultAction",
      "183": "Rule.defaultAction",
      "184": "Rule.defaultAction",
      "185": "Rule.defaultAction",
      "186": "Rule.defaultAction",
      "187": "Rule.defaultAction",
      "188": "Rule.defaultAction",
      "189": "Rule.defaultAction",
      "190": "Rule.defaultAction",
      "191": "Rule.defaultAction",
      "192": "Rule.defaultAction",
      "193": "Rule.defaultAction",
      "194": "Rule.defaultAction",
      "195": "Rule.defaultAction",
      "196": "Rule.defaultAction",
      "197": "Rule.defaultAction",
      "198": "Rule.defaultAction",
      "199": "Rule.defaultAction",
      "200": "Rule.defaultAction",
      "201": "Rule.defaultAction",
      "202": "Rule.defaultAction",
      "203": "Rule.defaultAction",
      "204": "Rule.defaultAction",
      "205": "Rule.defaultAction",
      "206": "Rule.defaultAction",
      "207": "Rule.defaultAction",
      "208": "Rule.defaultAction",
      "209": "Rule.defaultAction",
      "210": "Rule.defaultAction",
      "211": "Rule.defaultAction",
      "212": "Rule.defaultAction",
      "213": "Rule.defaultAction",
      "214": "Rule.defaultAction",
      "215": "Rule.defaultAction",
      "216": "Rule.defaultAction",
      "217": "Rule.defaultAction",
      "218": "Rule.defaultAction",
      "219": "Rule.defaultAction",
      "220": "Rule.defaultAction",
      "221": "Rule.defaultAction",
      "222": "Rule.defaultAction",
      "223": "Rule.defaultAction",
      "224": "Rule.defaultAction",
      "225": "Rule.defaultAction",
      "226": "Rule.defaultAction",
      "227": "Rule.defaultAction",
      "228": "Rule.defaultAction",
      "229": "Rule.defaultAction",
      "230": "Rule.defaultAction",
      "231": "Rule.defaultAction",
      "232": "Rule.defaultAction",
      "233": "Rule.defaultAction",
      "234": "Rule.Inline",
      "235": "Rule.Inline",
      "236": "Rule.Inline",
      "237": "Rule.Inline",
      "238": "Rule.ListCons(\"app-args_I1_I0\", \"app-args_I1_I0_star\", true)",
      "239": "Rule.Inline",
      "240": "Rule.defaultAction",
      "241": "Rule.defaultAction",
      "242": "Rule.Inline",
      "243": "Rule.Inline",
      "244": "Rule.Inline",
      "245": "Rule.ListCons(\"inst-expr_I2\", \"inst-expr_I2_star\", true)",
      "246": "Rule.Inline",
      "247": "Rule.Inline",
      "248": "Rule.Inline",
      "249": "Rule.defaultAction",
      "250": "Rule.defaultAction",
      "251": "Rule.defaultAction",
      "252": "Rule.defaultAction",
      "253": "Rule.Inline",
      "254": "Rule.ListCons(\"obj-fields_I0\", \"obj-fields_I0_star\", true)",
      "255": "Rule.Inline",
      "256": "Rule.Inline",
      "257": "Rule.Inline",
      "258": "Rule.Inline",
      "259": "Rule.defaultAction",
      "260": "Rule.defaultAction",
      "261": "Rule.defaultAction",
      "262": "Rule.Inline",
      "263": "Rule.Inline",
      "264": "Rule.Inline",
      "265": "Rule.defaultAction",
      "266": "Rule.defaultAction",
      "267": "Rule.Inline",
      "268": "Rule.ListCons(\"fields_I0\", \"fields_I0_star\", true)",
      "269": "Rule.Inline",
      "270": "Rule.Inline",
      "271": "Rule.Inline",
      "272": "Rule.Inline",
      "273": "Rule.defaultAction",
      "274": "Rule.defaultAction",
      "275": "Rule.defaultAction",
      "276": "Rule.defaultAction",
      "277": "Rule.defaultAction",
      "278": "Rule.defaultAction",
      "279": "Rule.Inline",
      "280": "Rule.Inline",
      "281": "Rule.Inline",
      "282": "Rule.Inline",
      "283": "Rule.ListCons(\"construct-expr_I4_I0\", \"construct-expr_I4_I0_star\", true)",
      "284": "Rule.Inline",
      "285": "Rule.defaultAction",
      "286": "Rule.defaultAction",
      "287": "Rule.defaultAction",
      "288": "Rule.defaultAction",
      "289": "Rule.defaultAction",
      "290": "Rule.defaultAction",
      "291": "Rule.defaultAction",
      "292": "Rule.defaultAction",
      "293": "Rule.defaultAction",
      "294": "Rule.Inline",
      "295": "Rule.ListCons(\"if-expr_I4\", \"if-expr_I4_star\", true)",
      "296": "Rule.Inline",
      "297": "Rule.Inline",
      "298": "Rule.Inline",
      "299": "Rule.Inline",
      "300": "Rule.defaultAction",
      "301": "Rule.defaultAction",
      "302": "Rule.Inline",
      "303": "Rule.ListCons(\"if-pipe-expr_I1\", \"if-pipe-expr_I1_star\", true)",
      "304": "Rule.Inline",
      "305": "Rule.Inline",
      "306": "Rule.Inline",
      "307": "Rule.Inline",
      "308": "Rule.defaultAction",
      "309": "Rule.defaultAction",
      "310": "Rule.Inline",
      "311": "Rule.Inline",
      "312": "Rule.Inline",
      "313": "Rule.ListCons(\"cases-expr_I6\", \"cases-expr_I6_star\", true)",
      "314": "Rule.Inline",
      "315": "Rule.Inline",
      "316": "Rule.Inline",
      "317": "Rule.Inline",
      "318": "Rule.defaultAction",
      "319": "Rule.Inline",
      "320": "Rule.Inline",
      "321": "Rule.Inline",
      "322": "Rule.defaultAction",
      "323": "Rule.defaultAction",
      "324": "Rule.defaultAction",
      "325": "Rule.Inline",
      "326": "Rule.Inline",
      "327": "Rule.Inline",
      "328": "Rule.Inline",
      "329": "Rule.ListCons(\"for-expr_I3_I0\", \"for-expr_I3_I0_star\", true)",
      "330": "Rule.Inline",
      "331": "Rule.defaultAction",
      "332": "Rule.Inline",
      "333": "Rule.Inline",
      "334": "Rule.defaultAction",
      "335": "Rule.defaultAction",
      "336": "Rule.defaultAction",
      "337": "Rule.defaultAction",
      "338": "Rule.defaultAction",
      "339": "Rule.defaultAction",
      "340": "Rule.defaultAction",
      "341": "Rule.defaultAction",
      "342": "Rule.defaultAction",
      "343": "Rule.Inline",
      "344": "Rule.Inline",
      "345": "Rule.Inline",
      "346": "Rule.Inline",
      "347": "Rule.ListCons(\"record-ann_A0_I1_I0\", \"record-ann_A0_I1_I0_star\", true)",
      "348": "Rule.Inline",
      "349": "Rule.defaultAction",
      "350": "Rule.defaultAction",
      "351": "Rule.defaultAction",
      "352": "Rule.defaultAction",
      "353": "Rule.defaultAction",
      "354": "Rule.Inline",
      "355": "Rule.Inline",
      "356": "Rule.Inline",
      "357": "Rule.Inline",
      "358": "Rule.ListCons(\"noparen-arrow-ann_I0_I0\", \"noparen-arrow-ann_I0_I0_star\", true)",
      "359": "Rule.Inline",
      "360": "Rule.defaultAction",
      "361": "Rule.Inline",
      "362": "Rule.Inline",
      "363": "Rule.Inline",
      "364": "Rule.Inline",
      "365": "Rule.Inline",
      "366": "Rule.Inline",
      "367": "Rule.ListCons(\"arrow-ann_I1_I0\", \"arrow-ann_I1_I0_star\", true)",
      "368": "Rule.Inline",
      "369": "Rule.defaultAction",
      "370": "Rule.defaultAction",
      "371": "Rule.Inline",
      "372": "Rule.Inline",
      "373": "Rule.Inline",
      "374": "Rule.Inline",
      "375": "Rule.Inline",
      "376": "Rule.ListCons(\"app-ann_I2\", \"app-ann_I2_star\", true)",
      "377": "Rule.Inline",
      "378": "Rule.Inline",
      "379": "Rule.Inline",
      "380": "Rule.defaultAction",
      "381": "Rule.defaultAction",
      "382": "Rule.Inline",
      "383": "Rule.Inline",
      "384": "Rule.defaultAction",
      "385": "Rule.defaultAction"
    },
    "flagsByOldId": {},
    "rules": [
      0,
      1,
      2,
      3,
      4,
      5,
      6,
      7,
      8,
      9,
      10,
      13,
      11,
      12,
      14,
      15,
      16,
      17,
      18,
      19,
      20,
      21,
      22,
      23,
      24,
      25,
      26,
      27,
      28,
      29,
      30,
      31,
      32,
      33,
      34,
      35,
      36,
      37,
      38,
      39,
      40,
      41,
      42,
      43,
      44,
      45,
      46,
      47,
      48,
      49,
      50,
      51,
      52,
      53,
      54,
      55,
      56,
      57,
      58,
      59,
      60,
      61,
      62,
      63,
      64,
      65,
      66,
      67,
      68,
      69,
      70,
      71,
      72,
      73,
      74,
      75,
      76,
      77,
      78,
      79,
      80,
      81,
      82,
      83,
      84,
      85,
      86,
      87,
      88,
      89,
      90,
      91,
      92,
      93,
      94,
      95,
      96,
      97,
      98,
      99,
      103,
      100,
      101,
      102,
      104,
      105,
      106,
      107,
      108,
      109,
      110,
      111,
      112,
      113,
      114,
      115,
      116,
      117,
      118,
      119,
      120,
      121,
      122,
      123,
      124,
      125,
      126,
      127,
      128,
      129,
      130,
      131,
      132,
      133,
      134,
      135,
      136,
      137,
      138,
      139,
      140,
      141,
      142,
      143,
      144,
      145,
      146,
      147,
      148,
      149,
      150,
      151,
      152,
      153,
      154,
      155,
      156,
      157,
      158,
      159,
      160,
      161,
      162,
      163,
      164,
      165,
      166,
      167,
      168,
      169,
      170,
      171,
      172,
      173,
      174,
      175,
      176,
      177,
      178,
      179,
      180,
      181,
      182,
      183,
      184,
      185,
      186,
      187,
      188,
      189,
      190,
      191,
      192,
      193,
      194,
      195,
      196,
      197,
      198,
      199,
      200,
      201,
      202,
      203,
      204,
      205,
      206,
      207,
      208,
      209,
      210,
      211,
      212,
      213,
      214,
      215,
      216,
      217,
      218,
      219,
      220,
      221,
      222,
      223,
      224,
      225,
      226,
      227,
      228,
      229,
      230,
      231,
      232,
      233,
      234,
      235,
      236,
      237,
      238,
      239,
      240,
      241,
      242,
      243,
      244,
      245,
      246,
      247,
      248,
      249,
      250,
      251,
      252,
      253,
      254,
      255,
      256,
      257,
      258,
      259,
      260,
      261,
      265,
      262,
      263,
      264,
      266,
      267,
      268,
      269,
      270,
      271,
      272,
      273,
      274,
      275,
      276,
      277,
      278,
      279,
      280,
      281,
      282,
      283,
      284,
      285,
      286,
      287,
      288,
      289,
      290,
      291,
      292,
      293,
      294,
      295,
      296,
      297,
      298,
      299,
      300,
      301,
      302,
      303,
      304,
      305,
      306,
      307,
      308,
      309,
      310,
      311,
      312,
      313,
      314,
      315,
      316,
      317,
      318,
      319,
      320,
      321,
      322,
      323,
      324,
      325,
      326,
      327,
      328,
      329,
      330,
      331,
      332,
      333,
      334,
      335,
      336,
      337,
      338,
      339,
      340,
      341,
      342,
      349,
      343,
      344,
      345,
      346,
      347,
      348,
      350,
      351,
      352,
      353,
      354,
      355,
      356,
      357,
      358,
      359,
      360,
      361,
      362,
      363,
      364,
      365,
      366,
      367,
      368,
      369,
      370,
      371,
      372,
      373,
      374,
      375,
      376,
      377,
      378,
      379,
      380,
      381,
      382,
      383,
      384,
      385
    ],
    "rnTable": [
      {
        "program": {
          "push": 1
        },
        "prelude": {
          "push": 2
        },
        "prelude_I0_opt": {
          "push": 3
        },
        "prelude_I0": {
          "push": 4
        },
        "provide-stmt": {
          "push": 5
        },
        "'PROVIDE": {
          "push": 6
        },
        "$": {
          "reductions": [
            [
              0,
              1
            ],
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4,
              3
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              3,
              2
            ],
            [
              4,
              3
            ]
          ]
        }
      },
      {
        "$": {
          "accept": true
        }
      },
      {
        "block": {
          "push": 7
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "$": {
          "reductions": [
            [
              587,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "prelude_I1_star": {
          "push": 87
        },
        "prelude_I1": {
          "push": 88
        },
        "import-stmt": {
          "push": 89
        },
        "'IMPORT": {
          "push": 90
        },
        "$": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4288,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4518,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 91
        },
        "'STAR": {
          "push": 92
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "$": {
          "reductions": [
            [
              4782,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 93
        },
        "'COLONEQUALS": {
          "push": 94
        },
        "$": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4903,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4956,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4989,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 95
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39,
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "$": {
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4991,
              7
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4993,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5026,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5059,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5092,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5125,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5158,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5191,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5224,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5257,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5290,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5323,
              0
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "push": 96
        }
      },
      {
        "check-op": {
          "push": 97
        },
        "'IS": {
          "push": 98
        },
        "'RAISES": {
          "push": 99
        },
        "'SATISFIES": {
          "push": 100
        },
        "$": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5390,
              0
            ]
          ]
        }
      },
      {
        "toplevel-binding": {
          "push": 101
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "'NAME": {
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "reductions": [
            [
              5545,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 102
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              5549,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              5551,
              0
            ],
            [
              5552,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 103
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              5557,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5559,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 104
        },
        "var-expr": {
          "push": 105
        },
        "toplevel-binding": {
          "push": 24
        },
        "'VAL": {
          "push": 26,
          "reductions": [
            [
              53,
              11
            ]
          ]
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30,
          "reductions": [
            [
              53,
              11
            ]
          ]
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr_I1_star": {
          "push": 106
        },
        "let-binding": {
          "push": 107
        },
        "multi-let-expr_I1": {
          "push": 108
        },
        "let-binding-elt": {
          "push": 109
        },
        "'VAR": {
          "push": 45,
          "reductions": [
            [
              53,
              11
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              53,
              11
            ],
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5686,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 110
        },
        "toplevel-binding": {
          "push": 24
        },
        "'VAL": {
          "push": 26,
          "reductions": [
            [
              60,
              12
            ]
          ]
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30,
          "reductions": [
            [
              60,
              12
            ]
          ]
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "letrec-expr_I1_star": {
          "push": 111
        },
        "letrec-expr_I1": {
          "push": 112
        },
        "letrec-binding": {
          "push": 113
        },
        "'NAME": {
          "reductions": [
            [
              60,
              12
            ],
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "fun-header": {
          "push": 114
        },
        "ty-params": {
          "push": 115
        },
        "ty-params_I0_opt": {
          "push": 116
        },
        "ty-params_I0": {
          "push": 117
        },
        "ty-params_I0_I0": {
          "push": 118
        },
        "'LANGLE": {
          "push": 119
        },
        "'LT": {
          "push": 120
        },
        "'NAME": {
          "reductions": [
            [
              69,
              13
            ],
            [
              70,
              14
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 122
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "block": {
          "push": 123
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'STRING": {
          "push": 124
        }
      },
      {
        "block": {
          "push": 125
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'STRING": {
          "push": 126
        }
      },
      {
        "'NAME": {
          "push": 127
        }
      },
      {
        "'NAME": {
          "push": 128
        }
      },
      {
        "toplevel-binding": {
          "push": 129
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "'NAME": {
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 130
        },
        "toplevel-binding": {
          "push": 24
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "graph-expr_I1_star": {
          "push": 131
        },
        "graph-expr_I1": {
          "push": 132
        },
        "'END": {
          "reductions": [
            [
              171,
              38
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              171,
              38
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 133
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'STAR": {
          "push": 134
        },
        "'LANGLE": {
          "push": 135
        },
        "'LT": {
          "push": 136
        },
        "'GT": {
          "push": 137
        },
        "'PARENNOSPACE": {
          "push": 138
        },
        "binop-expr_I1_star": {
          "push": 139
        },
        "binop-expr_I1": {
          "push": 140
        },
        "binop": {
          "push": 141
        },
        "'PLUS": {
          "push": 142
        },
        "'DASH": {
          "push": 143
        },
        "'SLASH": {
          "push": 144
        },
        "'LEQ": {
          "push": 145
        },
        "'GEQ": {
          "push": 146
        },
        "'EQUALEQUAL": {
          "push": 147
        },
        "'NEQ": {
          "push": 148
        },
        "'AND": {
          "push": 149
        },
        "'OR": {
          "push": 150
        },
        "'CARET": {
          "push": 151
        },
        "app-args": {
          "push": 152
        },
        "inst-expr_I1": {
          "push": 153
        },
        "'DOT": {
          "push": 154
        },
        "'BANG": {
          "push": 155
        },
        "$": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6319,
              39
            ],
            [
              176,
              39
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7151,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7204,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7257,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7310,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7363,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7416,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7469,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7522,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7575,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7628,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7681,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7734,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7787,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7840,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7893,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7946,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7999,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8052,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8105,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8158,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8211,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8264,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8317,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8370,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8423,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8476,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8529,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8582,
              0
            ]
          ]
        }
      },
      {
        "ty-params": {
          "push": 156
        },
        "ty-params_I0_opt": {
          "push": 116
        },
        "ty-params_I0": {
          "push": 117
        },
        "ty-params_I0_I0": {
          "push": 118
        },
        "'LANGLE": {
          "push": 119
        },
        "'LT": {
          "push": 120
        },
        "'PARENSPACE": {
          "reductions": [
            [
              69,
              13
            ],
            [
              70,
              14
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              69,
              13
            ],
            [
              70,
              14
            ]
          ]
        }
      },
      {
        "args": {
          "push": 157
        },
        "args_I0": {
          "push": 158
        },
        "'PARENSPACE": {
          "push": 159
        },
        "'PARENNOSPACE": {
          "push": 160
        }
      },
      {
        "'NAME": {
          "push": 161,
          "reductions": [
            [
              253,
              43
            ]
          ]
        },
        "'MUTABLE": {
          "push": 162,
          "reductions": [
            [
              253,
              43
            ]
          ]
        },
        "obj-fields": {
          "push": 163
        },
        "'RBRACE": {
          "push": 164
        },
        "obj-fields_I0_star": {
          "push": 165
        },
        "obj-field": {
          "push": 166
        },
        "obj-fields_I0": {
          "push": 167
        },
        "list-obj-field": {
          "push": 168
        },
        "key": {
          "push": 169
        },
        "'LBRACK": {
          "push": 170,
          "reductions": [
            [
              253,
              43
            ]
          ]
        }
      },
      {
        "construct-modifier": {
          "push": 171
        },
        "'LAZY": {
          "push": 172
        },
        "'NAME": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              285,
              50
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 173
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'BAR": {
          "push": 174,
          "reductions": [
            [
              302,
              53
            ]
          ]
        },
        "if-pipe-expr_I1_star": {
          "push": 175
        },
        "if-pipe-expr_I1": {
          "push": 176
        },
        "if-pipe-branch": {
          "push": 177
        },
        "'END": {
          "reductions": [
            [
              302,
              53
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              302,
              53
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 178
        },
        "'PARENNOSPACE": {
          "push": 179
        },
        "cases-expr_I1": {
          "push": 180
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 181
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "block": {
          "push": 182
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'EXCEPT": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "block": {
          "push": 183
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9399,
              0
            ]
          ]
        }
      },
      {
        "prelude_I1_star": {
          "push": 184
        },
        "prelude_I1": {
          "push": 88
        },
        "import-stmt": {
          "push": 89
        },
        "'IMPORT": {
          "push": 90
        },
        "$": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9432,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9465,
              0
            ]
          ]
        }
      },
      {
        "import-stmt_I1": {
          "push": 185
        },
        "'NAME": {
          "push": 186
        },
        "import-name": {
          "push": 187
        },
        "import-string": {
          "push": 188
        },
        "'STRING": {
          "push": 189
        }
      },
      {
        "end": {
          "push": 190
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "$": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9679,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              357,
              63
            ]
          ]
        },
        "ann": {
          "push": 194
        },
        "noparen-arrow-ann": {
          "push": 195
        },
        "contract-stmt_I2": {
          "push": 196
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              357,
              63
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              357,
              63
            ]
          ]
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              357,
              63
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "noparen-arrow-ann_I0_opt": {
          "push": 206
        },
        "noparen-arrow-ann_I0": {
          "push": 207
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 208
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 209
        },
        "arrow-ann-elt": {
          "push": 210
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        },
        "'THINARROW": {
          "reductions": [
            [
              354,
              62
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 213
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "$": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              10516,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 214
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 215
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10584,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10604,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10624,
              0
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "push": 216
        }
      },
      {
        "binding_I2_opt": {
          "push": 217
        },
        "binding_I2": {
          "push": 218
        },
        "'COLONCOLON": {
          "push": 219
        },
        "'FROM": {
          "reductions": [
            [
              10677,
              9
            ],
            [
              44,
              9
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              10677,
              9
            ],
            [
              44,
              9
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              10677,
              9
            ],
            [
              44,
              9
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              10677,
              9
            ],
            [
              44,
              9
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 220
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              10684,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10684,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              10686,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10686,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 104
        },
        "var-expr": {
          "push": 105
        },
        "toplevel-binding": {
          "push": 24
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "let-binding": {
          "push": 221
        },
        "'VAR": {
          "push": 45
        },
        "'NAME": {
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 222
        }
      },
      {
        "let-expr": {
          "push": 104
        },
        "var-expr": {
          "push": 105
        },
        "toplevel-binding": {
          "push": 24
        },
        "'VAL": {
          "push": 26,
          "reductions": [
            [
              10753,
              11
            ],
            [
              53,
              11
            ]
          ]
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30,
          "reductions": [
            [
              10753,
              11
            ],
            [
              53,
              11
            ]
          ]
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr_I1_star": {
          "push": 223
        },
        "let-binding": {
          "push": 107
        },
        "multi-let-expr_I1": {
          "push": 108
        },
        "let-binding-elt": {
          "push": 109
        },
        "'VAR": {
          "push": 45,
          "reductions": [
            [
              10753,
              11
            ],
            [
              53,
              11
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              10753,
              11
            ],
            [
              53,
              11
            ],
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10758,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              10758,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10758,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              10758,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 224
        }
      },
      {
        "let-expr": {
          "push": 225
        },
        "toplevel-binding": {
          "push": 24
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "'NAME": {
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 110
        },
        "toplevel-binding": {
          "push": 24
        },
        "'VAL": {
          "push": 26,
          "reductions": [
            [
              10821,
              12
            ],
            [
              60,
              12
            ]
          ]
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30,
          "reductions": [
            [
              10821,
              12
            ],
            [
              60,
              12
            ]
          ]
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "letrec-expr_I1_star": {
          "push": 226
        },
        "letrec-expr_I1": {
          "push": 112
        },
        "letrec-binding": {
          "push": 113
        },
        "'NAME": {
          "reductions": [
            [
              10821,
              12
            ],
            [
              60,
              12
            ],
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10825,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              10825,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10825,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 227
        }
      },
      {
        "'NAME": {
          "push": 228
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10864,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10864,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10864,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              10864,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              10864,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10866,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10866,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10866,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              10866,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              10866,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 229,
          "reductions": [
            [
              75,
              15
            ]
          ]
        },
        "ty-params_I0_I1_star": {
          "push": 230
        },
        "ty-params_I0_I1": {
          "push": 231
        },
        "list-ty-param": {
          "push": 232
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10874,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10876,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4786,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 233
        }
      },
      {
        "end": {
          "push": 234
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'COLON": {
          "push": 235
        }
      },
      {
        "end": {
          "push": 236
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'COLON": {
          "push": 237
        }
      },
      {
        "ty-params": {
          "push": 238
        },
        "ty-params_I0_opt": {
          "push": 116
        },
        "ty-params_I0": {
          "push": 117
        },
        "ty-params_I0_I0": {
          "push": 118
        },
        "'LANGLE": {
          "push": 119
        },
        "'LT": {
          "push": 120
        },
        "'COLON": {
          "reductions": [
            [
              69,
              13
            ],
            [
              70,
              14
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              69,
              13
            ],
            [
              70,
              14
            ]
          ]
        }
      },
      {
        "ty-params": {
          "push": 239
        },
        "ty-params_I0_opt": {
          "push": 116
        },
        "ty-params_I0": {
          "push": 117
        },
        "ty-params_I0_I0": {
          "push": 118
        },
        "'LANGLE": {
          "push": 119
        },
        "'LT": {
          "push": 120
        },
        "'COLON": {
          "reductions": [
            [
              69,
              13
            ],
            [
              70,
              14
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "push": 240
        }
      },
      {
        "'END": {
          "reductions": [
            [
              11234,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11234,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11234,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11234,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11234,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 241
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "let-expr": {
          "push": 130
        },
        "toplevel-binding": {
          "push": 24
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "graph-expr_I1_star": {
          "push": 242
        },
        "graph-expr_I1": {
          "push": 132
        },
        "'END": {
          "reductions": [
            [
              11273,
              38
            ],
            [
              171,
              38
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11273,
              38
            ],
            [
              171,
              38
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 243
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11367,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11387,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11387,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11387,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11387,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11392,
              0
            ],
            [
              11393,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11392,
              0
            ],
            [
              11393,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11392,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11392,
              0
            ],
            [
              11393,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11417,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "binop-expr": {
          "push": 244
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 38,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'LAM": {
          "push": 77,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'METHOD": {
          "push": 78,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "app-args_I1_opt": {
          "push": 245
        },
        "app-args_I1": {
          "push": 246
        },
        "app-args_I1_I0_star": {
          "push": 247
        },
        "app-args_I1_I0": {
          "push": 248
        },
        "app-arg-elt": {
          "push": 249
        },
        "'LBRACE": {
          "push": 79,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'LBRACK": {
          "push": 80,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'IF": {
          "push": 81,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 82,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'CASES": {
          "push": 83,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'FOR": {
          "push": 84,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'TRY": {
          "push": 85,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'BLOCK": {
          "push": 86,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              234,
              40
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11623,
              0
            ]
          ]
        }
      },
      {
        "'STAR": {
          "push": 134
        },
        "'LT": {
          "push": 250
        },
        "'GT": {
          "push": 137
        },
        "binop-expr_I1_star": {
          "push": 251
        },
        "binop-expr_I1": {
          "push": 140
        },
        "binop": {
          "push": 141
        },
        "'PLUS": {
          "push": 142
        },
        "'DASH": {
          "push": 143
        },
        "'SLASH": {
          "push": 144
        },
        "'LEQ": {
          "push": 145
        },
        "'GEQ": {
          "push": 146
        },
        "'EQUALEQUAL": {
          "push": 147
        },
        "'NEQ": {
          "push": 148
        },
        "'AND": {
          "push": 149
        },
        "'OR": {
          "push": 150
        },
        "'CARET": {
          "push": 151
        },
        "$": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11659,
              39
            ],
            [
              176,
              39
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 252
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11744,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11764,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11784,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11804,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11824,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11844,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11864,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11884,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11904,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11924,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11944,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              244,
              42
            ]
          ]
        },
        "ann": {
          "push": 253
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              244,
              42
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              244,
              42
            ]
          ]
        },
        "inst-expr_I2_star": {
          "push": 254
        },
        "inst-expr_I2": {
          "push": 255
        },
        "inst-elt": {
          "push": 256
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              244,
              42
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "push": 257
        },
        "'LBRACE": {
          "push": 258
        },
        "'LBRACK": {
          "push": 259
        }
      },
      {
        "'NAME": {
          "push": 260
        },
        "'LBRACE": {
          "push": 261
        }
      },
      {
        "args": {
          "push": 262
        },
        "args_I0": {
          "push": 158
        },
        "'PARENSPACE": {
          "push": 159
        },
        "'PARENNOSPACE": {
          "push": 160
        }
      },
      {
        "return-ann": {
          "push": 263
        },
        "return-ann_I0_opt": {
          "push": 264
        },
        "return-ann_I0": {
          "push": 265
        },
        "'THINARROW": {
          "push": 266
        },
        "'COLON": {
          "reductions": [
            [
              91,
              18
            ],
            [
              92,
              19
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 267
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 268,
          "reductions": [
            [
              87,
              17
            ]
          ]
        },
        "args_I1_opt": {
          "push": 269
        },
        "args_I1": {
          "push": 270
        },
        "args_I1_I0_star": {
          "push": 271
        },
        "args_I1_I0": {
          "push": 272
        },
        "list-arg-elt": {
          "push": 273
        },
        "'NAME": {
          "reductions": [
            [
              87,
              17
            ],
            [
              41,
              8
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              84,
              16
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12462,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12462,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12462,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12466,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12466,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12466,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "reductions": [
            [
              12470,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12470,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12470,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12470,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 161
        },
        "key": {
          "push": 274
        },
        "'LBRACK": {
          "push": 170
        }
      },
      {
        "'RBRACE": {
          "push": 275
        }
      },
      {
        "$": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12531,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 161
        },
        "'MUTABLE": {
          "push": 162
        },
        "obj-field": {
          "push": 276
        },
        "key": {
          "push": 169
        },
        "'LBRACK": {
          "push": 170
        }
      },
      {
        "'COMMA": {
          "push": 277
        }
      },
      {
        "'NAME": {
          "push": 161,
          "reductions": [
            [
              12593,
              43
            ],
            [
              253,
              43
            ]
          ]
        },
        "'MUTABLE": {
          "push": 162,
          "reductions": [
            [
              12593,
              43
            ],
            [
              253,
              43
            ]
          ]
        },
        "obj-fields_I0_star": {
          "push": 278
        },
        "obj-field": {
          "push": 166
        },
        "obj-fields_I0": {
          "push": 167
        },
        "list-obj-field": {
          "push": 168
        },
        "key": {
          "push": 169
        },
        "'LBRACK": {
          "push": 170,
          "reductions": [
            [
              12593,
              43
            ],
            [
              253,
              43
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12597,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              12597,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12597,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 279
        },
        "args": {
          "push": 280
        },
        "args_I0": {
          "push": 158
        },
        "'PARENSPACE": {
          "push": 159
        },
        "'PARENNOSPACE": {
          "push": 160
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 281
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 282
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12716,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 283
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 284
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'BAR": {
          "push": 285
        },
        "if-pipe-expr_I2_opt": {
          "push": 286
        },
        "if-pipe-expr_I2": {
          "push": 287
        },
        "'END": {
          "reductions": [
            [
              305,
              54
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              305,
              54
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 174,
          "reductions": [
            [
              12906,
              53
            ],
            [
              302,
              53
            ]
          ]
        },
        "if-pipe-expr_I1_star": {
          "push": 288
        },
        "if-pipe-expr_I1": {
          "push": 176
        },
        "if-pipe-branch": {
          "push": 177
        },
        "'END": {
          "reductions": [
            [
              12906,
              53
            ],
            [
              302,
              53
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12906,
              53
            ],
            [
              302,
              53
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              12910,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12910,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              12910,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12914,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12914,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12914,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12914,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12919,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12919,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12919,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12919,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 289
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'LANGLE": {
          "push": 135
        },
        "'LT": {
          "push": 290
        },
        "'PARENNOSPACE": {
          "push": 291
        },
        "app-args": {
          "push": 152
        },
        "inst-expr_I1": {
          "push": 153
        },
        "'DOT": {
          "push": 154
        },
        "'BANG": {
          "push": 155
        }
      },
      {
        "'EXCEPT": {
          "push": 292
        }
      },
      {
        "end": {
          "push": 293
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "$": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13277,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "push": 294
        }
      },
      {
        "import-stmt_I2_star": {
          "push": 295
        },
        "import-stmt_I2": {
          "push": 296
        },
        "'COMMA": {
          "push": 297
        },
        "'AS": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14,
              5
            ]
          ]
        }
      },
      {
        "'AS": {
          "reductions": [
            [
              13384,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "reductions": [
            [
              13386,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'AS": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13388,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13390,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13424,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13458,
              0
            ]
          ]
        }
      },
      {
        "'DOT": {
          "push": 298
        },
        "$": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              13492,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 299
        },
        "'PERCENT": {
          "push": 300
        },
        "$": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13566,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13639,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13672,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13705,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13705,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13705,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13705,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13705,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13711,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13711,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13711,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13711,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13711,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 301,
          "reductions": [
            [
              346,
              61
            ]
          ]
        },
        "'RBRACE": {
          "push": 302,
          "reductions": [
            [
              343,
              60
            ]
          ]
        },
        "record-ann_A0_I1_opt": {
          "push": 303
        },
        "record-ann_A0_I1": {
          "push": 304
        },
        "record-ann_A0_I1_I0_star": {
          "push": 305
        },
        "ann-field": {
          "push": 306
        },
        "record-ann_A0_I1_I0": {
          "push": 307
        },
        "list-ann-field": {
          "push": 308
        }
      },
      {
        "$": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13797,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13797,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              13796,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              13834,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              13869,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              13904,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              13939,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13975,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13975,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        }
      },
      {
        "'THINARROW": {
          "push": 309
        }
      },
      {
        "'THINARROW": {
          "reductions": [
            [
              14045,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 310
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              14062,
              63
            ],
            [
              357,
              63
            ]
          ]
        },
        "ann": {
          "push": 311
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              14062,
              63
            ],
            [
              357,
              63
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              14062,
              63
            ],
            [
              357,
              63
            ]
          ]
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              14062,
              63
            ],
            [
              357,
              63
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 312
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 209
        },
        "arrow-ann-elt": {
          "push": 210
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14067,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14067,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14067,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14067,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              366,
              65
            ]
          ]
        },
        "ann": {
          "push": 311
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              366,
              65
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              366,
              65
            ]
          ]
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              366,
              65
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann-elt": {
          "push": 313
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "arrow-ann_I1_opt": {
          "push": 314
        },
        "arrow-ann_I1": {
          "push": 315
        },
        "arrow-ann_I1_I0_star": {
          "push": 316
        },
        "arrow-ann_I1_I0": {
          "push": 317
        },
        "app-ann_I0": {
          "push": 212
        },
        "'THINARROW": {
          "reductions": [
            [
              363,
              64
            ]
          ]
        }
      },
      {
        "'LANGLE": {
          "push": 318
        },
        "'LT": {
          "push": 319
        },
        "app-ann_I1": {
          "push": 320
        }
      },
      {
        "$": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14165,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14198,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14231,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 321
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'FROM": {
          "reductions": [
            [
              14297,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14297,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14297,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14297,
              0
            ]
          ]
        }
      },
      {
        "'FROM": {
          "reductions": [
            [
              14299,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14299,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14299,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14299,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 322
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              357,
              63
            ]
          ]
        },
        "ann": {
          "push": 311
        },
        "noparen-arrow-ann": {
          "push": 323
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              357,
              63
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              357,
              63
            ]
          ]
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              357,
              63
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "noparen-arrow-ann_I0_opt": {
          "push": 206
        },
        "noparen-arrow-ann_I0": {
          "push": 207
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 208
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 209
        },
        "arrow-ann-elt": {
          "push": 210
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        },
        "'THINARROW": {
          "reductions": [
            [
              354,
              62
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 324
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14377,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14377,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14377,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14377,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14382,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14382,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14382,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14382,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14387,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14387,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14387,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 325
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14444,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14444,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14444,
              0
            ]
          ]
        }
      },
      {
        "doc-string": {
          "push": 326
        },
        "doc-string_I0_opt": {
          "push": 327
        },
        "doc-string_I0": {
          "push": 328
        },
        "'DOC": {
          "push": 329
        },
        "'END": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        }
      },
      {
        "args": {
          "push": 330
        },
        "args_I0": {
          "push": 158
        },
        "'PARENSPACE": {
          "push": 159
        },
        "'PARENNOSPACE": {
          "push": 160
        }
      },
      {
        "'COMMA": {
          "push": 331
        }
      },
      {
        "'NAME": {
          "push": 332
        }
      },
      {
        "'NAME": {
          "push": 229,
          "reductions": [
            [
              14623,
              15
            ],
            [
              75,
              15
            ]
          ]
        },
        "ty-params_I0_I1_star": {
          "push": 333
        },
        "ty-params_I0_I1": {
          "push": 231
        },
        "list-ty-param": {
          "push": 232
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14625,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14627,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14680,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 334
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14746,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 335
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "data-mixins": {
          "push": 336
        },
        "data-mixins_I0_opt": {
          "push": 337
        },
        "data-mixins_I0": {
          "push": 338
        },
        "'DERIVING": {
          "push": 339
        },
        "'COLON": {
          "reductions": [
            [
              117,
              26
            ],
            [
              118,
              27
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 340
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 341
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "$": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14921,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              14954,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14954,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 342
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 343
        }
      },
      {
        "'RPAREN": {
          "push": 344
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              15112,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 345
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "push": 121,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "binop-expr": {
          "push": 244
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 38,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'LAM": {
          "push": 77,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'METHOD": {
          "push": 78,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "app-args_I1_I0_star": {
          "push": 346
        },
        "app-args_I1_I0": {
          "push": 248
        },
        "app-arg-elt": {
          "push": 249
        },
        "'LBRACE": {
          "push": 79,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'LBRACK": {
          "push": 80,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'IF": {
          "push": 81,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 82,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'CASES": {
          "push": 83,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'FOR": {
          "push": 84,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'TRY": {
          "push": 85,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        },
        "'BLOCK": {
          "push": 86,
          "reductions": [
            [
              15116,
              41
            ],
            [
              237,
              41
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15136,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11393,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15165,
              0
            ]
          ]
        }
      },
      {
        "'LANGLE": {
          "push": 135
        },
        "'LT": {
          "push": 290,
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 138
        },
        "app-args": {
          "push": 152
        },
        "inst-expr_I1": {
          "push": 153
        },
        "'DOT": {
          "push": 154
        },
        "'BANG": {
          "push": 155
        },
        "$": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15201,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 347
        },
        "'PERCENT": {
          "push": 300
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 348
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              15334,
              42
            ],
            [
              244,
              42
            ]
          ]
        },
        "ann": {
          "push": 253
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              15334,
              42
            ],
            [
              244,
              42
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              15334,
              42
            ],
            [
              244,
              42
            ]
          ]
        },
        "inst-expr_I2_star": {
          "push": 349
        },
        "inst-expr_I2": {
          "push": 255
        },
        "inst-elt": {
          "push": 256
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              15334,
              42
            ],
            [
              244,
              42
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15339,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15339,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15339,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15339,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15344,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 161,
          "reductions": [
            [
              267,
              46
            ]
          ]
        },
        "fields": {
          "push": 350
        },
        "key": {
          "push": 351
        },
        "fields_I0_star": {
          "push": 352
        },
        "field": {
          "push": 353
        },
        "fields_I0": {
          "push": 354
        },
        "list-field": {
          "push": 355
        },
        "'LBRACK": {
          "push": 170,
          "reductions": [
            [
              267,
              46
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 356
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "$": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15514,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 161,
          "reductions": [
            [
              267,
              46
            ]
          ]
        },
        "fields": {
          "push": 357
        },
        "key": {
          "push": 351
        },
        "fields_I0_star": {
          "push": 352
        },
        "field": {
          "push": 353
        },
        "fields_I0": {
          "push": 354
        },
        "list-field": {
          "push": 355
        },
        "'LBRACK": {
          "push": 170,
          "reductions": [
            [
              267,
              46
            ]
          ]
        }
      },
      {
        "return-ann": {
          "push": 358
        },
        "return-ann_I0_opt": {
          "push": 264
        },
        "return-ann_I0": {
          "push": 265
        },
        "'THINARROW": {
          "push": 266
        },
        "'COLON": {
          "reductions": [
            [
              91,
              18
            ],
            [
              92,
              19
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 359
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              15726,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              15728,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 360
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'COMMA": {
          "push": 361
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              5552,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 362
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              15752,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 363
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 268
        },
        "'NAME": {
          "reductions": [
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 267
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 268,
          "reductions": [
            [
              15757,
              17
            ],
            [
              87,
              17
            ]
          ]
        },
        "args_I1_I0_star": {
          "push": 364
        },
        "args_I1_I0": {
          "push": 272
        },
        "list-arg-elt": {
          "push": 273
        },
        "'NAME": {
          "reductions": [
            [
              15757,
              17
            ],
            [
              87,
              17
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15760,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15760,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 365
        },
        "obj-field_A1_I2_opt": {
          "push": 366
        },
        "obj-field_A1_I2": {
          "push": 367
        },
        "'COLON": {
          "reductions": [
            [
              262,
              45
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15770,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 368
        },
        "obj-fields_I2_opt": {
          "push": 369
        },
        "obj-fields_I2": {
          "push": 370
        },
        "'RBRACE": {
          "reductions": [
            [
              15824,
              44
            ],
            [
              256,
              44
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15831,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              15831,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15831,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15835,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              15835,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15835,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 371
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "return-ann": {
          "push": 372
        },
        "return-ann_I0_opt": {
          "push": 264
        },
        "return-ann_I0": {
          "push": 265
        },
        "'THINARROW": {
          "push": 266
        },
        "'COLON": {
          "reductions": [
            [
              91,
              18
            ],
            [
              92,
              19
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "push": 373
        }
      },
      {
        "'COLON": {
          "push": 374
        }
      },
      {
        "block": {
          "push": 375
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'THENCOLON": {
          "push": 376
        }
      },
      {
        "'OTHERWISECOLON": {
          "push": 377
        }
      },
      {
        "end": {
          "push": 378
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'END": {
          "reductions": [
            [
              16299,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16299,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              16302,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16302,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16302,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 379
        },
        "'PERCENT": {
          "push": 300
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11392,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11392,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11392,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11392,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121,
          "reductions": [
            [
              328,
              59
            ],
            [
              237,
              41
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "binop-expr": {
          "push": 244
        },
        "binding": {
          "push": 380
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 268,
          "reductions": [
            [
              328,
              59
            ]
          ]
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 38,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'LAM": {
          "push": 77,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'METHOD": {
          "push": 78,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "app-args_I1_opt": {
          "push": 245
        },
        "app-args_I1": {
          "push": 246
        },
        "app-args_I1_I0_star": {
          "push": 247
        },
        "app-args_I1_I0": {
          "push": 248
        },
        "app-arg-elt": {
          "push": 249
        },
        "'LBRACE": {
          "push": 79,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'LBRACK": {
          "push": 80,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'IF": {
          "push": 81,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 82,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'CASES": {
          "push": 83,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "for-bind": {
          "push": 381
        },
        "for-bind-elt": {
          "push": 382
        },
        "'FOR": {
          "push": 84,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "for-expr_I3_opt": {
          "push": 383
        },
        "for-expr_I3": {
          "push": 384
        },
        "for-expr_I3_I0_star": {
          "push": 385
        },
        "for-expr_I3_I0": {
          "push": 386
        },
        "'TRY": {
          "push": 85,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'BLOCK": {
          "push": 86,
          "reductions": [
            [
              237,
              41
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              325,
              58
            ],
            [
              234,
              40
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 387
        },
        "'PARENNOSPACE": {
          "push": 388
        },
        "try-expr_I3": {
          "push": 389
        }
      },
      {
        "$": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16495,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 390
        }
      },
      {
        "'FROM": {
          "push": 391
        }
      },
      {
        "import-stmt_I2_star": {
          "push": 392
        },
        "import-stmt_I2": {
          "push": 296
        },
        "'COMMA": {
          "push": 297
        },
        "'FROM": {
          "reductions": [
            [
              16656,
              5
            ],
            [
              14,
              5
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 393
        }
      },
      {
        "'NAME": {
          "push": 394
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16698,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16698,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16698,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16698,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 395
        },
        "'PARENNOSPACE": {
          "push": 396
        },
        "pred-ann_I2": {
          "push": 397
        }
      },
      {
        "'COLONCOLON": {
          "push": 398
        },
        "'COLON": {
          "push": 399
        }
      },
      {
        "$": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              16780,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "push": 400
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              16850,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 301
        },
        "ann-field": {
          "push": 401
        }
      },
      {
        "'COMMA": {
          "push": 402
        }
      },
      {
        "'NAME": {
          "push": 301,
          "reductions": [
            [
              16858,
              61
            ],
            [
              346,
              61
            ]
          ]
        },
        "record-ann_A0_I1_I0_star": {
          "push": 403
        },
        "ann-field": {
          "push": 306
        },
        "record-ann_A0_I1_I0": {
          "push": 307
        },
        "list-ann-field": {
          "push": 308
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16860,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 404
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'PERCENT": {
          "push": 300
        },
        "'THINARROW": {
          "reductions": [
            [
              16897,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 299
        },
        "'PERCENT": {
          "push": 300
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16910,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16910,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16910,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16910,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16915,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16915,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16915,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16915,
              0
            ]
          ]
        }
      },
      {
        "'THINARROW": {
          "push": 405
        }
      },
      {
        "'THINARROW": {
          "reductions": [
            [
              16955,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 406
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              16959,
              65
            ],
            [
              366,
              65
            ]
          ]
        },
        "ann": {
          "push": 311
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              16959,
              65
            ],
            [
              366,
              65
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              16959,
              65
            ],
            [
              366,
              65
            ]
          ]
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              16959,
              65
            ],
            [
              366,
              65
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann-elt": {
          "push": 313
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "arrow-ann_I1_I0_star": {
          "push": 407
        },
        "arrow-ann_I1_I0": {
          "push": 317
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16964,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16964,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16964,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16964,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16969,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16969,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16969,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16969,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              375,
              66
            ]
          ]
        },
        "ann": {
          "push": 408
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              375,
              66
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              375,
              66
            ]
          ]
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              375,
              66
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        },
        "app-ann_I2_star": {
          "push": 409
        },
        "app-ann_I2": {
          "push": 410
        },
        "app-ann-elt": {
          "push": 411
        }
      },
      {
        "$": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17025,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 300
        },
        "'FROM": {
          "reductions": [
            [
              17060,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17060,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              17060,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17060,
              0
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "reductions": [
            [
              17073,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 412
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "block": {
          "push": 413
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "block": {
          "push": 414
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39,
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17303,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        }
      },
      {
        "'STRING": {
          "push": 415
        }
      },
      {
        "return-ann": {
          "push": 416
        },
        "return-ann_I0_opt": {
          "push": 264
        },
        "return-ann_I0": {
          "push": 265
        },
        "'THINARROW": {
          "push": 266
        },
        "'COLON": {
          "reductions": [
            [
              17408,
              18
            ],
            [
              91,
              18
            ],
            [
              92,
              19
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17410,
              0
            ]
          ]
        }
      },
      {
        "ty-params_I0_I3": {
          "push": 417
        },
        "'RANGLE": {
          "push": 418
        },
        "'GT": {
          "push": 419
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17416,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 420
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "end": {
          "push": 421
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'COLON": {
          "push": 422
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              17517,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              17519,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "binop-expr": {
          "push": 423
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 38,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "mixins": {
          "push": 424
        },
        "mixins_I0_star": {
          "push": 425
        },
        "mixins_I0": {
          "push": 426
        },
        "list-mixin": {
          "push": 427
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'LAM": {
          "push": 77,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'METHOD": {
          "push": 78,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'LBRACE": {
          "push": 79,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'LBRACK": {
          "push": 80,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'IF": {
          "push": 81,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 82,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'CASES": {
          "push": 83,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'FOR": {
          "push": 84,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'TRY": {
          "push": 85,
          "reductions": [
            [
              150,
              35
            ]
          ]
        },
        "'BLOCK": {
          "push": 86,
          "reductions": [
            [
              150,
              35
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 428
        },
        "variant-constructor": {
          "push": 429
        },
        "datatype-expr_I4_opt": {
          "push": 430
        },
        "datatype-expr_I4": {
          "push": 431
        },
        "first-datatype-variant": {
          "push": 432
        },
        "'END": {
          "reductions": [
            [
              155,
              36
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              155,
              36
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              155,
              36
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              155,
              36
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              155,
              36
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17659,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 433
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17725,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17745,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              17798,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17800,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17820,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17820,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17820,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17820,
              0
            ]
          ]
        }
      },
      {
        "'RANGLE": {
          "push": 434
        },
        "'GT": {
          "push": 435
        },
        "inst-expr_I4": {
          "push": 436
        },
        "'PERCENT": {
          "push": 300
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18008,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18008,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18008,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18008,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "push": 437
        }
      },
      {
        "'COLON": {
          "push": 438
        },
        "args": {
          "push": 439
        },
        "args_I0": {
          "push": 158
        },
        "'PARENSPACE": {
          "push": 159
        },
        "'PARENNOSPACE": {
          "push": 160
        }
      },
      {
        "'NAME": {
          "push": 161
        },
        "key": {
          "push": 351
        },
        "field": {
          "push": 440
        },
        "'LBRACK": {
          "push": 170
        }
      },
      {
        "'COMMA": {
          "push": 441
        }
      },
      {
        "'NAME": {
          "push": 161,
          "reductions": [
            [
              18077,
              46
            ],
            [
              267,
              46
            ]
          ]
        },
        "key": {
          "push": 351
        },
        "fields_I0_star": {
          "push": 442
        },
        "field": {
          "push": 353
        },
        "fields_I0": {
          "push": 354
        },
        "list-field": {
          "push": 355
        },
        "'LBRACK": {
          "push": 170,
          "reductions": [
            [
              18077,
              46
            ],
            [
              267,
              46
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18080,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18080,
              0
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "push": 443
        }
      },
      {
        "'RBRACE": {
          "push": 444
        }
      },
      {
        "'COLON": {
          "push": 445
        }
      },
      {
        "doc-string": {
          "push": 446
        },
        "doc-string_I0_opt": {
          "push": 327
        },
        "doc-string_I0": {
          "push": 328
        },
        "'DOC": {
          "push": 329
        },
        "'END": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 300
        },
        "'COLON": {
          "reductions": [
            [
              18297,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18310,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18310,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              18313,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              18313,
              0
            ]
          ]
        },
        "'THICKARROW": {
          "reductions": [
            [
              18313,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              18316,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18319,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18319,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 447
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'COLON": {
          "push": 448
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              18326,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              18328,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              18330,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              18332,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              18334,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18334,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 449
        }
      },
      {
        "'COLONCOLON": {
          "reductions": [
            [
              18338,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18338,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18338,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18338,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "binop-expr": {
          "push": 450
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 38,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'LAM": {
          "push": 77,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'METHOD": {
          "push": 78,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'LBRACE": {
          "push": 79,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'LBRACK": {
          "push": 80,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "construct-expr_I4_opt": {
          "push": 451
        },
        "construct-expr_I4": {
          "push": 452
        },
        "construct-expr_I4_I0_star": {
          "push": 453
        },
        "construct-expr_I4_I0": {
          "push": 454
        },
        "list-elt": {
          "push": 455
        },
        "'IF": {
          "push": 81,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 82,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'CASES": {
          "push": 83,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'FOR": {
          "push": 84,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'TRY": {
          "push": 85,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'BLOCK": {
          "push": 86,
          "reductions": [
            [
              282,
              49
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              279,
              48
            ]
          ]
        }
      },
      {
        "if-expr_I4_star": {
          "push": 456
        },
        "if-expr_I4": {
          "push": 457
        },
        "else-if": {
          "push": 458
        },
        "'ELSEIF": {
          "push": 459
        },
        "'END": {
          "reductions": [
            [
              294,
              51
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              294,
              51
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              294,
              51
            ]
          ]
        }
      },
      {
        "block": {
          "push": 460
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              18717,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18717,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18717,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "block": {
          "push": 461
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              18806,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18806,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18809,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 462
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'FROM": {
          "push": 463
        }
      },
      {
        "'COMMA": {
          "push": 464
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18922,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18922,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 465
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              18978,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 380
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 268
        },
        "for-bind": {
          "push": 466
        },
        "'NAME": {
          "reductions": [
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 380
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 268,
          "reductions": [
            [
              18983,
              59
            ],
            [
              328,
              59
            ]
          ]
        },
        "for-bind": {
          "push": 381
        },
        "for-bind-elt": {
          "push": 382
        },
        "for-expr_I3_I0_star": {
          "push": 467
        },
        "for-expr_I3_I0": {
          "push": 386
        },
        "'NAME": {
          "reductions": [
            [
              18983,
              59
            ],
            [
              328,
              59
            ],
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18986,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18986,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18989,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18989,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 468
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 268
        },
        "'NAME": {
          "reductions": [
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19045,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 469
        },
        "import-name": {
          "push": 470
        },
        "import-string": {
          "push": 471
        },
        "import-stmt_I4": {
          "push": 472
        },
        "'STRING": {
          "push": 189
        }
      },
      {
        "'FROM": {
          "reductions": [
            [
              19245,
              0
            ]
          ]
        }
      },
      {
        "'FROM": {
          "reductions": [
            [
              19247,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19247,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              19250,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19287,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19307,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 473
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 474
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 475
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "$": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              19366,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              19403,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19405,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19407,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 300
        },
        "$": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19409,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 476
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'PERCENT": {
          "push": 300
        },
        "'THINARROW": {
          "reductions": [
            [
              19478,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19480,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19480,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19480,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19480,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 477
        },
        "'PERCENT": {
          "push": 300
        }
      },
      {
        "'NAME": {
          "push": 193
        },
        "ann": {
          "push": 478
        },
        "'PARENSPACE": {
          "push": 197
        },
        "'PARENNOSPACE": {
          "push": 198
        },
        "'LBRACE": {
          "push": 199
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        }
      },
      {
        "'NAME": {
          "push": 193,
          "reductions": [
            [
              19525,
              66
            ],
            [
              375,
              66
            ]
          ]
        },
        "ann": {
          "push": 408
        },
        "'PARENSPACE": {
          "push": 197,
          "reductions": [
            [
              19525,
              66
            ],
            [
              375,
              66
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 198,
          "reductions": [
            [
              19525,
              66
            ],
            [
              375,
              66
            ]
          ]
        },
        "'LBRACE": {
          "push": 199,
          "reductions": [
            [
              19525,
              66
            ],
            [
              375,
              66
            ]
          ]
        },
        "name-ann": {
          "push": 200
        },
        "record-ann": {
          "push": 201
        },
        "arrow-ann": {
          "push": 202
        },
        "app-ann": {
          "push": 203
        },
        "pred-ann": {
          "push": 204
        },
        "dot-ann": {
          "push": 205
        },
        "arrow-ann_I0": {
          "push": 211
        },
        "app-ann_I0": {
          "push": 212
        },
        "app-ann_I2_star": {
          "push": 479
        },
        "app-ann_I2": {
          "push": 410
        },
        "app-ann-elt": {
          "push": 411
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19530,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19530,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19530,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19530,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 480
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "end": {
          "push": 481
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "where-clause": {
          "push": 482
        },
        "where-clause_I0_opt": {
          "push": 483
        },
        "where-clause_I0": {
          "push": 484
        },
        "'WHERE": {
          "push": 485
        },
        "'EXAMPLESCOLON": {
          "push": 486
        },
        "'END": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19775,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              19810,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19812,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19812,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19812,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19812,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              19812,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19814,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19814,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19814,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19814,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              19814,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19816,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19816,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19816,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19816,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              19816,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19818,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19851,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 487
        },
        "data-expr_I5_opt": {
          "push": 488
        },
        "data-expr_I5": {
          "push": 489
        },
        "first-data-variant": {
          "push": 490
        },
        "variant-constructor": {
          "push": 491
        },
        "'END": {
          "reductions": [
            [
              111,
              24
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              111,
              24
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              111,
              24
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              111,
              24
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              111,
              24
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              111,
              24
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 492
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              19974,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 493
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "push": 121,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "binop-expr": {
          "push": 423
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 38,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "mixins_I0_star": {
          "push": 494
        },
        "mixins_I0": {
          "push": 426
        },
        "list-mixin": {
          "push": 427
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'LAM": {
          "push": 77,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'METHOD": {
          "push": 78,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'LBRACE": {
          "push": 79,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'LBRACK": {
          "push": 80,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'IF": {
          "push": 81,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 82,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'CASES": {
          "push": 83,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'FOR": {
          "push": 84,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'TRY": {
          "push": 85,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        },
        "'BLOCK": {
          "push": 86,
          "reductions": [
            [
              19978,
              35
            ],
            [
              150,
              35
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19998,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 495
        },
        "'PARENNOSPACE": {
          "push": 496
        },
        "variant-members": {
          "push": 497
        },
        "variant-members_I0": {
          "push": 498
        },
        "constructor-clause": {
          "push": 499
        },
        "'WITHCONSTRUCTOR": {
          "push": 500
        }
      },
      {
        "constructor-clause": {
          "push": 501
        },
        "'WITHCONSTRUCTOR": {
          "push": 500
        }
      },
      {
        "'BAR": {
          "push": 502
        },
        "datatype-expr_I5_star": {
          "push": 503
        },
        "datatype-expr_I5": {
          "push": 504
        },
        "datatype-variant": {
          "push": 505
        },
        "'END": {
          "reductions": [
            [
              158,
              37
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              158,
              37
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              158,
              37
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              158,
              37
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              20104,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20104,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20104,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20104,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20104,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              20110,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20110,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20110,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20110,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20110,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20116,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20149,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20202,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20255,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20310,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 506
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "return-ann": {
          "push": 507
        },
        "return-ann_I0_opt": {
          "push": 264
        },
        "return-ann_I0": {
          "push": 265
        },
        "'THINARROW": {
          "push": 266
        },
        "'COLON": {
          "reductions": [
            [
              91,
              18
            ],
            [
              92,
              19
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 508
        },
        "fields_I2_opt": {
          "push": 509
        },
        "fields_I2": {
          "push": 510
        },
        "'END": {
          "reductions": [
            [
              20369,
              47
            ],
            [
              270,
              47
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20369,
              47
            ],
            [
              270,
              47
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20369,
              47
            ],
            [
              270,
              47
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20369,
              47
            ],
            [
              270,
              47
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20369,
              47
            ],
            [
              270,
              47
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20369,
              47
            ],
            [
              270,
              47
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20369,
              47
            ],
            [
              270,
              47
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20374,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20374,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20377,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20377,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20433,
              0
            ]
          ]
        }
      },
      {
        "doc-string": {
          "push": 511
        },
        "doc-string_I0_opt": {
          "push": 327
        },
        "doc-string_I0": {
          "push": 328
        },
        "'DOC": {
          "push": 329
        },
        "'END": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        }
      },
      {
        "block": {
          "push": 512
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39,
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 300
        },
        "'COLON": {
          "reductions": [
            [
              20593,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 513
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "doc-string": {
          "push": 514
        },
        "doc-string_I0_opt": {
          "push": 327
        },
        "doc-string_I0": {
          "push": 328
        },
        "'DOC": {
          "push": 329
        },
        "'END": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 515
        }
      },
      {
        "'RBRACK": {
          "push": 516
        }
      },
      {
        "'RBRACK": {
          "reductions": [
            [
              20672,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 517
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "push": 121,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'STRING": {
          "push": 9,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "binop-expr": {
          "push": 450
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 38,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'LAM": {
          "push": 77,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'METHOD": {
          "push": 78,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'LBRACE": {
          "push": 79,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'LBRACK": {
          "push": 80,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "construct-expr_I4_I0_star": {
          "push": 518
        },
        "construct-expr_I4_I0": {
          "push": 454
        },
        "list-elt": {
          "push": 455
        },
        "'IF": {
          "push": 81,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'ASKCOLON": {
          "push": 82,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'CASES": {
          "push": 83,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'FOR": {
          "push": 84,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'TRY": {
          "push": 85,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        },
        "'BLOCK": {
          "push": 86,
          "reductions": [
            [
              20676,
              49
            ],
            [
              282,
              49
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20696,
              0
            ]
          ]
        }
      },
      {
        "if-expr_I5_opt": {
          "push": 519
        },
        "if-expr_I5": {
          "push": 520
        },
        "'ELSECOLON": {
          "push": 521
        },
        "'END": {
          "reductions": [
            [
              297,
              52
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              297,
              52
            ]
          ]
        }
      },
      {
        "if-expr_I4_star": {
          "push": 522
        },
        "if-expr_I4": {
          "push": 457
        },
        "else-if": {
          "push": 458
        },
        "'ELSEIF": {
          "push": 459
        },
        "'END": {
          "reductions": [
            [
              20775,
              51
            ],
            [
              294,
              51
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20775,
              51
            ],
            [
              294,
              51
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20775,
              51
            ],
            [
              294,
              51
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              20779,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20779,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20779,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20779,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 523
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'END": {
          "reductions": [
            [
              20789,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20789,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20789,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              20881,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20881,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 524
        },
        "'LANGLE": {
          "push": 135
        },
        "'LT": {
          "push": 290
        },
        "'PARENNOSPACE": {
          "push": 138
        },
        "app-args": {
          "push": 152
        },
        "inst-expr_I1": {
          "push": 153
        },
        "'DOT": {
          "push": 154
        },
        "'BANG": {
          "push": 155
        }
      },
      {
        "'NAME": {
          "push": 121
        },
        "'STRING": {
          "push": 9
        },
        "binop-expr": {
          "push": 525
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'PARENSPACE": {
          "push": 38
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20939,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20939,
              0
            ]
          ]
        }
      },
      {
        "return-ann": {
          "push": 526
        },
        "return-ann_I0_opt": {
          "push": 264
        },
        "return-ann_I0": {
          "push": 265
        },
        "'THINARROW": {
          "push": 266
        },
        "'COLON": {
          "reductions": [
            [
              91,
              18
            ],
            [
              92,
              19
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              20996,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20998,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20998,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 527
        }
      },
      {
        "$": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13345,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21087,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21121,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21155,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 528
        }
      },
      {
        "'PERCENT": {
          "push": 300
        },
        "'COMMA": {
          "reductions": [
            [
              21257,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21257,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 300
        },
        "'COMMA": {
          "reductions": [
            [
              21259,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21259,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 529
        },
        "'PERCENT": {
          "push": 300
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21296,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21296,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21296,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21296,
              0
            ]
          ]
        }
      },
      {
        "'RANGLE": {
          "push": 530
        },
        "'GT": {
          "push": 531
        },
        "app-ann_I4": {
          "push": 532
        },
        "'PERCENT": {
          "push": 300
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21404,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21404,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21404,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21404,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21409,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21462,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 533
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21548,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21548,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21551,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21551,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 534
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              21554,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21554,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "block": {
          "push": 535
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              21557,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21557,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 495
        },
        "'PARENNOSPACE": {
          "push": 496
        },
        "variant-members": {
          "push": 497
        },
        "data-with": {
          "push": 536
        },
        "variant-members_I0": {
          "push": 498
        },
        "data-with_I0_opt": {
          "push": 537
        },
        "data-with_I0": {
          "push": 538
        },
        "'WITH": {
          "push": 539
        },
        "'END": {
          "reductions": [
            [
              21560,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21560,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21560,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21560,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21560,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21560,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        }
      },
      {
        "data-expr_I6_star": {
          "push": 540
        },
        "data-expr_I6": {
          "push": 541
        },
        "data-variant": {
          "push": 542
        },
        "'BAR": {
          "push": 543
        },
        "'END": {
          "reductions": [
            [
              114,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              114,
              25
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              114,
              25
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              114,
              25
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              114,
              25
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21666,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21666,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21666,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21666,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21666,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21666,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21673,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21673,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21673,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21673,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21673,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21673,
              0
            ]
          ]
        }
      },
      {
        "data-with": {
          "push": 544
        },
        "data-with_I0_opt": {
          "push": 537
        },
        "data-with_I0": {
          "push": 538
        },
        "'WITH": {
          "push": 539
        },
        "'END": {
          "reductions": [
            [
              21680,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21680,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21680,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21680,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21680,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21680,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21687,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              21707,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21709,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21729,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21729,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21729,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              21729,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              21729,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21735,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21735,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21735,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              21735,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              21735,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21741,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21741,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21741,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21741,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21741,
              0
            ]
          ]
        },
        "'WITH": {
          "reductions": [
            [
              21741,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21741,
              0
            ]
          ]
        },
        "'WITHCONSTRUCTOR": {
          "reductions": [
            [
              21741,
              0
            ]
          ]
        }
      },
      {
        "variant-members_I1_opt": {
          "push": 545
        },
        "variant-members_I1": {
          "push": 546
        },
        "variant-members_I1_I0_star": {
          "push": 547
        },
        "variant-member": {
          "push": 548
        },
        "variant-members_I1_I0": {
          "push": 549
        },
        "list-variant-member": {
          "push": 550
        },
        "variant-member_I0_opt": {
          "push": 551
        },
        "variant-member_I0": {
          "push": 552
        },
        "'MUTABLE": {
          "push": 553,
          "reductions": [
            [
              132,
              29
            ]
          ]
        },
        "'CYCLIC": {
          "push": 554,
          "reductions": [
            [
              132,
              29
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              132,
              29
            ],
            [
              137,
              30
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              132,
              29
            ],
            [
              137,
              30
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              129,
              28
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21773,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21773,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21773,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21773,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21773,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 555
        },
        "'PARENNOSPACE": {
          "push": 556
        },
        "constructor-clause_I1": {
          "push": 557
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21787,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21787,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21787,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21787,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21787,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 558
        },
        "variant-constructor": {
          "push": 559
        }
      },
      {
        "where-clause": {
          "push": 560
        },
        "where-clause_I0_opt": {
          "push": 483
        },
        "where-clause_I0": {
          "push": 484
        },
        "'WHERE": {
          "push": 485
        },
        "'EXAMPLESCOLON": {
          "push": 486
        },
        "'END": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 502
        },
        "datatype-expr_I5_star": {
          "push": 561
        },
        "datatype-expr_I5": {
          "push": 504
        },
        "datatype-variant": {
          "push": 505
        },
        "'END": {
          "reductions": [
            [
              21838,
              37
            ],
            [
              158,
              37
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21838,
              37
            ],
            [
              158,
              37
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21838,
              37
            ],
            [
              158,
              37
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21838,
              37
            ],
            [
              158,
              37
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21843,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21843,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21843,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21843,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21843,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21849,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21849,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21849,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21849,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21849,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21849,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21849,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21849,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 562
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21853,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21853,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21853,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21853,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21853,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21853,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21853,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21855,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21855,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21855,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21855,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21855,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21855,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21855,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              21857,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21857,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21857,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21857,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21857,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21857,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21857,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 563
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39,
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 564
        },
        "where-clause_I0_opt": {
          "push": 483
        },
        "where-clause_I0": {
          "push": 484
        },
        "'WHERE": {
          "push": 485
        },
        "'EXAMPLESCOLON": {
          "push": 486
        },
        "'END": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              21965,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21965,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 565
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39,
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21969,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21989,
              0
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "reductions": [
            [
              22042,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22044,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 566
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22117,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22117,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 567
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              22120,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22120,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22123,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22123,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22123,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 568
        }
      },
      {
        "'BAR": {
          "push": 569,
          "reductions": [
            [
              312,
              55
            ]
          ]
        },
        "cases-expr_I6_star": {
          "push": 570
        },
        "cases-expr_I6": {
          "push": 571
        },
        "cases-branch": {
          "push": 572
        },
        "'END": {
          "reductions": [
            [
              312,
              55
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              312,
              55
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              22205,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22205,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 573
        }
      },
      {
        "'COLON": {
          "push": 574
        }
      },
      {
        "$": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              22313,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              22348,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              22383,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              22418,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              22453,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22488,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22521,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22521,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22524,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22524,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22534,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22534,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22534,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22534,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22534,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22534,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22548,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22548,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22548,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22548,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22548,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22548,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22555,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22555,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22555,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22555,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22555,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22555,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 161,
          "reductions": [
            [
              267,
              46
            ]
          ]
        },
        "fields": {
          "push": 575
        },
        "key": {
          "push": 351
        },
        "fields_I0_star": {
          "push": 352
        },
        "field": {
          "push": 353
        },
        "fields_I0": {
          "push": 354
        },
        "list-field": {
          "push": 355
        },
        "'LBRACK": {
          "push": 170,
          "reductions": [
            [
              267,
              46
            ]
          ]
        }
      },
      {
        "data-sharing": {
          "push": 576
        },
        "data-sharing_I0_opt": {
          "push": 577
        },
        "data-sharing_I0": {
          "push": 578
        },
        "'SHARING": {
          "push": 579
        },
        "'END": {
          "reductions": [
            [
              145,
              33
            ],
            [
              146,
              34
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              145,
              33
            ],
            [
              146,
              34
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              145,
              33
            ],
            [
              146,
              34
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              145,
              33
            ],
            [
              146,
              34
            ]
          ]
        }
      },
      {
        "data-expr_I6_star": {
          "push": 580
        },
        "data-expr_I6": {
          "push": 541
        },
        "data-variant": {
          "push": 542
        },
        "'BAR": {
          "push": 543
        },
        "'END": {
          "reductions": [
            [
              22624,
              25
            ],
            [
              114,
              25
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22624,
              25
            ],
            [
              114,
              25
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22624,
              25
            ],
            [
              114,
              25
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22624,
              25
            ],
            [
              114,
              25
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22624,
              25
            ],
            [
              114,
              25
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22630,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22630,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22630,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22630,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22630,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22630,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 581
        },
        "variant-constructor": {
          "push": 582
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22651,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22651,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22651,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22651,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22651,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22651,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 583
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              22660,
              0
            ]
          ]
        }
      },
      {
        "variant-member": {
          "push": 584
        },
        "variant-member_I0_opt": {
          "push": 551
        },
        "variant-member_I0": {
          "push": 552
        },
        "'MUTABLE": {
          "push": 553
        },
        "'CYCLIC": {
          "push": 554
        },
        "'NAME": {
          "reductions": [
            [
              137,
              30
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              137,
              30
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 585
        }
      },
      {
        "variant-members_I1_I0_star": {
          "push": 586
        },
        "variant-member": {
          "push": 548
        },
        "variant-members_I1_I0": {
          "push": 549
        },
        "list-variant-member": {
          "push": 550
        },
        "variant-member_I0_opt": {
          "push": 551
        },
        "variant-member_I0": {
          "push": 552
        },
        "'MUTABLE": {
          "push": 553,
          "reductions": [
            [
              22670,
              29
            ],
            [
              132,
              29
            ]
          ]
        },
        "'CYCLIC": {
          "push": 554,
          "reductions": [
            [
              22670,
              29
            ],
            [
              132,
              29
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22670,
              29
            ],
            [
              132,
              29
            ],
            [
              137,
              30
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22670,
              29
            ],
            [
              132,
              29
            ],
            [
              137,
              30
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22675,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22675,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              22675,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              22675,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 587
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 268
        },
        "'NAME": {
          "reductions": [
            [
              41,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22682,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22682,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22685,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22685,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22688,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22688,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22691,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22693,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 588
        }
      },
      {
        "'PARENSPACE": {
          "push": 495
        },
        "'PARENNOSPACE": {
          "push": 496
        },
        "variant-members": {
          "push": 497
        },
        "variant-members_I0": {
          "push": 498
        },
        "constructor-clause": {
          "push": 589
        },
        "'WITHCONSTRUCTOR": {
          "push": 500
        }
      },
      {
        "constructor-clause": {
          "push": 590
        },
        "'WITHCONSTRUCTOR": {
          "push": 500
        }
      },
      {
        "end": {
          "push": 591
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22746,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22746,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22746,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22746,
              0
            ]
          ]
        }
      },
      {
        "doc-string": {
          "push": 592
        },
        "doc-string_I0_opt": {
          "push": 327
        },
        "doc-string_I0": {
          "push": 328
        },
        "'DOC": {
          "push": 329
        },
        "'END": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              95,
              20
            ],
            [
              96,
              21
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 593
        },
        "where-clause_I0_opt": {
          "push": 483
        },
        "where-clause_I0": {
          "push": 484
        },
        "'WHERE": {
          "push": 485
        },
        "'EXAMPLESCOLON": {
          "push": 486
        },
        "'END": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        }
      },
      {
        "end": {
          "push": 594
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "where-clause": {
          "push": 595
        },
        "where-clause_I0_opt": {
          "push": 483
        },
        "where-clause_I0": {
          "push": 484
        },
        "'WHERE": {
          "push": 485
        },
        "'EXAMPLESCOLON": {
          "push": 486
        },
        "'END": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22861,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22914,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22914,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 596
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              22917,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22917,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22917,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22917,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 597
        }
      },
      {
        "'BAR": {
          "push": 598
        },
        "cases-expr_I7_opt": {
          "push": 599
        },
        "cases-expr_I7": {
          "push": 600
        },
        "'END": {
          "reductions": [
            [
              315,
              56
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              315,
              56
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 569,
          "reductions": [
            [
              22985,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "cases-expr_I6_star": {
          "push": 601
        },
        "cases-expr_I6": {
          "push": 571
        },
        "cases-branch": {
          "push": 572
        },
        "'END": {
          "reductions": [
            [
              22985,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22985,
              55
            ],
            [
              312,
              55
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              22989,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22989,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22989,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 602
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "block": {
          "push": 603
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23099,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23099,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23099,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23099,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23099,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23099,
              0
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 604
        },
        "where-clause_I0_opt": {
          "push": 483
        },
        "where-clause_I0": {
          "push": 484
        },
        "'WHERE": {
          "push": 485
        },
        "'EXAMPLESCOLON": {
          "push": 486
        },
        "'END": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23157,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23157,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23157,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23157,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23162,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23162,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23162,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23162,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 161,
          "reductions": [
            [
              267,
              46
            ]
          ]
        },
        "fields": {
          "push": 605
        },
        "key": {
          "push": 351
        },
        "fields_I0_star": {
          "push": 352
        },
        "field": {
          "push": 353
        },
        "fields_I0": {
          "push": 354
        },
        "list-field": {
          "push": 355
        },
        "'LBRACK": {
          "push": 170,
          "reductions": [
            [
              267,
              46
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23172,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23172,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23172,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23172,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23172,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 495
        },
        "'PARENNOSPACE": {
          "push": 496
        },
        "variant-members": {
          "push": 497
        },
        "data-with": {
          "push": 606
        },
        "variant-members_I0": {
          "push": 498
        },
        "data-with_I0_opt": {
          "push": 537
        },
        "data-with_I0": {
          "push": 538
        },
        "'WITH": {
          "push": 539
        },
        "'END": {
          "reductions": [
            [
              23178,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23178,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23178,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23178,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23178,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23178,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        }
      },
      {
        "data-with": {
          "push": 607
        },
        "data-with_I0_opt": {
          "push": 537
        },
        "data-with_I0": {
          "push": 538
        },
        "'WITH": {
          "push": 539
        },
        "'END": {
          "reductions": [
            [
              23185,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23185,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23185,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23185,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23185,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23185,
              31
            ],
            [
              141,
              31
            ],
            [
              142,
              32
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23192,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23192,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23192,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23192,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23192,
              0
            ]
          ]
        },
        "'WITH": {
          "reductions": [
            [
              23192,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23192,
              0
            ]
          ]
        },
        "'WITHCONSTRUCTOR": {
          "reductions": [
            [
              23192,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              23194,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23197,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23197,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              23197,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              23197,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23202,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23202,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              23202,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              23202,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              23207,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23207,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 608
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23215,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23215,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23215,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23215,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23215,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23221,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23221,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23221,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23221,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23221,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23227,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 609
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39,
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "end": {
          "push": 610
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "$": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23315,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 611
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23372,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23372,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23372,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23372,
              0
            ]
          ]
        }
      },
      {
        "args": {
          "push": 612
        },
        "args_I0": {
          "push": 158
        },
        "'PARENSPACE": {
          "push": 159
        },
        "'PARENNOSPACE": {
          "push": 160
        },
        "cases-branch_I2_opt": {
          "push": 613
        },
        "cases-branch_I2": {
          "push": 614
        },
        "'THICKARROW": {
          "reductions": [
            [
              319,
              57
            ]
          ]
        }
      },
      {
        "'ELSE": {
          "push": 615
        }
      },
      {
        "end": {
          "push": 616
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23441,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23441,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23444,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23444,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23444,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 617
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "end": {
          "push": 618
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "end": {
          "push": 619
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23587,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23587,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23587,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23587,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23592,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23592,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23592,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23592,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23592,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23592,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23599,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23599,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23599,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23599,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23599,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23599,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 620
        }
      },
      {
        "where-clause": {
          "push": 621
        },
        "where-clause_I0_opt": {
          "push": 483
        },
        "where-clause_I0": {
          "push": 484
        },
        "'WHERE": {
          "push": 485
        },
        "'EXAMPLESCOLON": {
          "push": 486
        },
        "'END": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              99,
              22
            ],
            [
              100,
              23
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23614,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              23667,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23667,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "reductions": [
            [
              23671,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "push": 622
        }
      },
      {
        "'THICKARROW": {
          "reductions": [
            [
              23678,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "push": 623
        }
      },
      {
        "$": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23683,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23736,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'STAR": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'PLUS": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'DASH": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'SLASH": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'LEQ": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'GEQ": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'EQUALEQUAL": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'NEQ": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'AND": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'OR": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23789,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'LAM": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'ASKCOLON": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23842,
              0
            ]
          ]
        }
      },
      {
        "block": {
          "push": 624
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "end": {
          "push": 625
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "block": {
          "push": 626
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23883,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23883,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23883,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "block": {
          "push": 627
        },
        "'NAME": {
          "push": 8,
          "reductions": [
            [
              49,
              10
            ],
            [
              41,
              8
            ]
          ]
        },
        "'STRING": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "block_I0_star": {
          "push": 11
        },
        "block_I0": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "fun-expr": {
          "push": 14
        },
        "data-expr": {
          "push": 15
        },
        "datatype-expr": {
          "push": 16
        },
        "when-expr": {
          "push": 17
        },
        "var-expr": {
          "push": 18
        },
        "assign-expr": {
          "push": 19
        },
        "check-test": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "toplevel-binding": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "'VAL": {
          "push": 26
        },
        "binding": {
          "push": 27
        },
        "binding_I0_opt": {
          "push": 28
        },
        "binding_I0": {
          "push": 29
        },
        "'SHADOW": {
          "push": 30
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 31
        },
        "toplevel-binding_A1_I0": {
          "push": 32
        },
        "multi-let-expr": {
          "push": 33
        },
        "'LET": {
          "push": 34
        },
        "letrec-expr": {
          "push": 35
        },
        "'LETREC": {
          "push": 36
        },
        "'FUN": {
          "push": 37
        },
        "'PARENSPACE": {
          "push": 38
        },
        "'EXAMPLESCOLON": {
          "push": 39
        },
        "'CHECK": {
          "push": 40
        },
        "'CHECKCOLON": {
          "push": 41
        },
        "'EXAMPLES": {
          "push": 42
        },
        "'DATA": {
          "push": 43
        },
        "'DATATYPE": {
          "push": 44
        },
        "'VAR": {
          "push": 45
        },
        "'GRAPH": {
          "push": 46
        },
        "'WHEN": {
          "push": 47
        },
        "expr": {
          "push": 48
        },
        "paren-expr": {
          "push": 49
        },
        "id-expr": {
          "push": 50
        },
        "prim-expr": {
          "push": 51
        },
        "lambda-expr": {
          "push": 52
        },
        "method-expr": {
          "push": 53
        },
        "app-expr": {
          "push": 54
        },
        "obj-expr": {
          "push": 55
        },
        "dot-expr": {
          "push": 56
        },
        "bracket-expr": {
          "push": 57
        },
        "get-bang-expr": {
          "push": 58
        },
        "update-expr": {
          "push": 59
        },
        "extend-expr": {
          "push": 60
        },
        "if-expr": {
          "push": 61
        },
        "if-pipe-expr": {
          "push": 62
        },
        "cases-expr": {
          "push": 63
        },
        "for-expr": {
          "push": 64
        },
        "try-expr": {
          "push": 65
        },
        "user-block-expr": {
          "push": 66
        },
        "inst-expr": {
          "push": 67
        },
        "construct-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'LAM": {
          "push": 77
        },
        "'METHOD": {
          "push": 78
        },
        "'LBRACE": {
          "push": 79
        },
        "'LBRACK": {
          "push": 80
        },
        "'IF": {
          "push": 81
        },
        "'ASKCOLON": {
          "push": 82
        },
        "'CASES": {
          "push": 83
        },
        "'FOR": {
          "push": 84
        },
        "'TRY": {
          "push": 85
        },
        "'BLOCK": {
          "push": 86
        },
        "'END": {
          "reductions": [
            [
              23887,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23887,
              6
            ],
            [
              23,
              6
            ],
            [
              24,
              7
            ]
          ]
        }
      },
      {
        "end": {
          "push": 628
        },
        "'END": {
          "push": 191
        },
        "'SEMI": {
          "push": 192
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23904,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23904,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23904,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23904,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23904,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23904,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23904,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23904,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23906,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23906,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23906,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23910,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23910,
              0
            ]
          ]
        }
      },
      {
        "'END": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23913,
              0
            ]
          ]
        }
      }
    ],
    "I": {
      "ε": 0,
      "program": 1,
      "prelude": 2,
      "prelude_I0_opt": 3,
      "prelude_I1_star": 4,
      "import-stmt_I2_star": 5,
      "block": 6,
      "block_I0_star": 7,
      "binding_I0_opt": 8,
      "binding_I2_opt": 9,
      "toplevel-binding_A1_I0_opt": 10,
      "multi-let-expr_I1_star": 11,
      "letrec-expr_I1_star": 12,
      "ty-params": 13,
      "ty-params_I0_opt": 14,
      "ty-params_I0_I1_star": 15,
      "args_I1_opt": 16,
      "args_I1_I0_star": 17,
      "return-ann": 18,
      "return-ann_I0_opt": 19,
      "doc-string": 20,
      "doc-string_I0_opt": 21,
      "where-clause": 22,
      "where-clause_I0_opt": 23,
      "data-expr_I5_opt": 24,
      "data-expr_I6_star": 25,
      "data-mixins": 26,
      "data-mixins_I0_opt": 27,
      "variant-members_I1_opt": 28,
      "variant-members_I1_I0_star": 29,
      "variant-member_I0_opt": 30,
      "data-with": 31,
      "data-with_I0_opt": 32,
      "data-sharing": 33,
      "data-sharing_I0_opt": 34,
      "mixins_I0_star": 35,
      "datatype-expr_I4_opt": 36,
      "datatype-expr_I5_star": 37,
      "graph-expr_I1_star": 38,
      "binop-expr_I1_star": 39,
      "app-args_I1_opt": 40,
      "app-args_I1_I0_star": 41,
      "inst-expr_I2_star": 42,
      "obj-fields_I0_star": 43,
      "obj-fields_I2_opt": 44,
      "obj-field_A1_I2_opt": 45,
      "fields_I0_star": 46,
      "fields_I2_opt": 47,
      "construct-expr_I4_opt": 48,
      "construct-expr_I4_I0_star": 49,
      "construct-modifier": 50,
      "if-expr_I4_star": 51,
      "if-expr_I5_opt": 52,
      "if-pipe-expr_I1_star": 53,
      "if-pipe-expr_I2_opt": 54,
      "cases-expr_I6_star": 55,
      "cases-expr_I7_opt": 56,
      "cases-branch_I2_opt": 57,
      "for-expr_I3_opt": 58,
      "for-expr_I3_I0_star": 59,
      "record-ann_A0_I1_opt": 60,
      "record-ann_A0_I1_I0_star": 61,
      "noparen-arrow-ann_I0_opt": 62,
      "noparen-arrow-ann_I0_I0_star": 63,
      "arrow-ann_I1_opt": 64,
      "arrow-ann_I1_I0_star": 65,
      "app-ann_I2_star": 66,
      "START": 67
    },
    "eSPPFs": [
      {
        "label": "EPSILON"
      },
      {
        "label": "program",
        "kids": [
          2,
          6
        ],
        "rule": 0
      },
      {
        "label": "prelude",
        "kids": [
          3,
          4
        ],
        "rule": 3
      },
      {
        "label": "prelude_I0_opt",
        "kids": [],
        "rule": 4
      },
      {
        "label": "prelude_I1_star",
        "kids": [],
        "rule": 7
      },
      {
        "label": "import-stmt_I2_star",
        "kids": [],
        "rule": 14
      },
      {
        "label": "block",
        "kids": [
          7
        ],
        "rule": 23
      },
      {
        "label": "block_I0_star",
        "kids": [],
        "rule": 24
      },
      {
        "label": "binding_I0_opt",
        "kids": [],
        "rule": 41
      },
      {
        "label": "binding_I2_opt",
        "kids": [],
        "rule": 44
      },
      {
        "label": "toplevel-binding_A1_I0_opt",
        "kids": [],
        "rule": 49
      },
      {
        "label": "multi-let-expr_I1_star",
        "kids": [],
        "rule": 53
      },
      {
        "label": "letrec-expr_I1_star",
        "kids": [],
        "rule": 60
      },
      {
        "label": "ty-params",
        "kids": [
          14
        ],
        "rule": 69
      },
      {
        "label": "ty-params_I0_opt",
        "kids": [],
        "rule": 70
      },
      {
        "label": "ty-params_I0_I1_star",
        "kids": [],
        "rule": 75
      },
      {
        "label": "args_I1_opt",
        "kids": [],
        "rule": 84
      },
      {
        "label": "args_I1_I0_star",
        "kids": [],
        "rule": 87
      },
      {
        "label": "return-ann",
        "kids": [
          19
        ],
        "rule": 91
      },
      {
        "label": "return-ann_I0_opt",
        "kids": [],
        "rule": 92
      },
      {
        "label": "doc-string",
        "kids": [
          21
        ],
        "rule": 95
      },
      {
        "label": "doc-string_I0_opt",
        "kids": [],
        "rule": 96
      },
      {
        "label": "where-clause",
        "kids": [
          23
        ],
        "rule": 99
      },
      {
        "label": "where-clause_I0_opt",
        "kids": [],
        "rule": 100
      },
      {
        "label": "data-expr_I5_opt",
        "kids": [],
        "rule": 111
      },
      {
        "label": "data-expr_I6_star",
        "kids": [],
        "rule": 114
      },
      {
        "label": "data-mixins",
        "kids": [
          27
        ],
        "rule": 117
      },
      {
        "label": "data-mixins_I0_opt",
        "kids": [],
        "rule": 118
      },
      {
        "label": "variant-members_I1_opt",
        "kids": [],
        "rule": 129
      },
      {
        "label": "variant-members_I1_I0_star",
        "kids": [],
        "rule": 132
      },
      {
        "label": "variant-member_I0_opt",
        "kids": [],
        "rule": 137
      },
      {
        "label": "data-with",
        "kids": [
          32
        ],
        "rule": 141
      },
      {
        "label": "data-with_I0_opt",
        "kids": [],
        "rule": 142
      },
      {
        "label": "data-sharing",
        "kids": [
          34
        ],
        "rule": 145
      },
      {
        "label": "data-sharing_I0_opt",
        "kids": [],
        "rule": 146
      },
      {
        "label": "mixins_I0_star",
        "kids": [],
        "rule": 150
      },
      {
        "label": "datatype-expr_I4_opt",
        "kids": [],
        "rule": 155
      },
      {
        "label": "datatype-expr_I5_star",
        "kids": [],
        "rule": 158
      },
      {
        "label": "graph-expr_I1_star",
        "kids": [],
        "rule": 171
      },
      {
        "label": "binop-expr_I1_star",
        "kids": [],
        "rule": 176
      },
      {
        "label": "app-args_I1_opt",
        "kids": [],
        "rule": 234
      },
      {
        "label": "app-args_I1_I0_star",
        "kids": [],
        "rule": 237
      },
      {
        "label": "inst-expr_I2_star",
        "kids": [],
        "rule": 244
      },
      {
        "label": "obj-fields_I0_star",
        "kids": [],
        "rule": 253
      },
      {
        "label": "obj-fields_I2_opt",
        "kids": [],
        "rule": 256
      },
      {
        "label": "obj-field_A1_I2_opt",
        "kids": [],
        "rule": 262
      },
      {
        "label": "fields_I0_star",
        "kids": [],
        "rule": 267
      },
      {
        "label": "fields_I2_opt",
        "kids": [],
        "rule": 270
      },
      {
        "label": "construct-expr_I4_opt",
        "kids": [],
        "rule": 279
      },
      {
        "label": "construct-expr_I4_I0_star",
        "kids": [],
        "rule": 282
      },
      {
        "label": "construct-modifier",
        "kids": [],
        "rule": 285
      },
      {
        "label": "if-expr_I4_star",
        "kids": [],
        "rule": 294
      },
      {
        "label": "if-expr_I5_opt",
        "kids": [],
        "rule": 297
      },
      {
        "label": "if-pipe-expr_I1_star",
        "kids": [],
        "rule": 302
      },
      {
        "label": "if-pipe-expr_I2_opt",
        "kids": [],
        "rule": 305
      },
      {
        "label": "cases-expr_I6_star",
        "kids": [],
        "rule": 312
      },
      {
        "label": "cases-expr_I7_opt",
        "kids": [],
        "rule": 315
      },
      {
        "label": "cases-branch_I2_opt",
        "kids": [],
        "rule": 319
      },
      {
        "label": "for-expr_I3_opt",
        "kids": [],
        "rule": 325
      },
      {
        "label": "for-expr_I3_I0_star",
        "kids": [],
        "rule": 328
      },
      {
        "label": "record-ann_A0_I1_opt",
        "kids": [],
        "rule": 343
      },
      {
        "label": "record-ann_A0_I1_I0_star",
        "kids": [],
        "rule": 346
      },
      {
        "label": "noparen-arrow-ann_I0_opt",
        "kids": [],
        "rule": 354
      },
      {
        "label": "noparen-arrow-ann_I0_I0_star",
        "kids": [],
        "rule": 357
      },
      {
        "label": "arrow-ann_I1_opt",
        "kids": [],
        "rule": 363
      },
      {
        "label": "arrow-ann_I1_I0_star",
        "kids": [],
        "rule": 366
      },
      {
        "label": "app-ann_I2_star",
        "kids": [],
        "rule": 375
      },
      {
        "label": "START",
        "kids": [
          1
        ],
        "rule": 385
      }
    ]
  };
  return { BootstrapGrammar: Grammar.fromSerializable(g_json) };
});

define('js/bootstrap-un-tokenizer',["../../../lib/jglr/jglr"], function(E) {
  const Grammar = E.Grammar
  const Nonterm = E.Nonterm
  const Token = E.Token
  const SrcLoc = E.SrcLoc
  const GenTokenizer = E.Tokenizer;
  const STICKY_REGEXP = E.STICKY_REGEXP;

  const escapes = new RegExp("^(.*?)\\\\([\\\\\"\'nrt]|u[0-9A-Fa-f]{1,4}|x[0-9A-Fa-f]{1,2}|[0-7]{1,3}|[\r\n]{1,2})");
  function fixEscapes(s) {
    var ret = "";
    var match = escapes.exec(s);
    while (match !== null) {
      var esc = match[2];
      ret += match[1];
      s = s.slice(match[0].length);
      if (esc === "\n") {}
      else if (esc === "\r") {}
      else if (esc === "\n\r") {}
      else if (esc === "\r\n") {}
      else if (esc === "n") { ret += "\n"; }
      else if (esc === "r") { ret += "\r"; }
      else if (esc === "t") { ret += "\t"; }
      else if (esc === "\"") { ret += "\""; }
      else if (esc === "'") { ret += "'"; }
      else if (esc === "\\") { ret += "\\"; }
      else if (esc[0] === 'u') { ret += String.fromCharCode(parseInt(esc.slice(1), 16)); }
      else if (esc[0] === 'x') { ret += String.fromCharCode(parseInt(esc.slice(1), 16)); }
      else { ret += String.fromCharCode(parseInt(esc.slice(2), 8)); }
      match = escapes.exec(s);
    }
    ret += s;
    return ret;
  }

  function Tokenizer(ignore_ws, Tokens) {
    GenTokenizer.call(this, ignore_ws, Tokens);
    this.parenIsForExp = true; // initialize this at the beginning of file to true
  }
  Tokenizer.prototype = Object.create(GenTokenizer.prototype);
  Tokenizer.prototype.tokenizeFrom = function(str) {
    GenTokenizer.prototype.tokenizeFrom.call(this, str);
    this.parenIsForExp = true;
  }
  Tokenizer.prototype.makeToken = function (tok_type, s, pos) { 
    if (tok_type === "STRING") s = fixEscapes(s);
    return GenTokenizer.prototype.makeToken(tok_type, s, pos);
  }
  Tokenizer.prototype.postProcessMatch = function(tok, match) {
    var tok_type = tok.name;
    if (tok_type === "PAREN?") {
      for (var j = 0; j < this.Tokens.length; j++) {
        if (STICKY_REGEXP !== '') {
          var oldIndex = this.Tokens[j].val.lastIndex;
          this.Tokens[j].val.lastIndex = 0;
        }
        var op = this.Tokens[j].val.exec(match[0]);
        if (STICKY_REGEXP !== '') {
          this.Tokens[j].val.lastIndex = oldIndex;
        }
        if (op !== null) {
          tok_type = this.Tokens[j].name;
          if (tok_type == "LPAREN?")
            tok_type = this.parenIsForExp ? "PARENSPACE" : "PARENNOSPACE";
          break;
        }
      }
    } else if (tok_type == "LPAREN?") {
      tok_type = this.parenIsForExp ? "PARENSPACE" : "PARENNOSPACE";
    }
    this.parenIsForExp = !!tok.parenIsForExp;
    return tok_type;
  }



  function kw(str) { return "^(?:" + str + ")(?![-_a-zA-Z0-9])"; }
  function anyOf(strs) { return "(?:" + strs.join("|") + ")(?![-_a-zA-Z0-9])"; }
  const operator_regex_str = anyOf(["\\+", "-", "\\*", "/", "<=", ">=", "==", "<>", "%",
                                    "<", ">", "is", "raises"]);
  const name = new RegExp("^[_a-zA-Z][-_a-zA-Z0-9]*", STICKY_REGEXP);
  const number = new RegExp("^-?[0-9]+(?:\\.[0-9]+)?", STICKY_REGEXP);
  const rational = new RegExp("^-?[0-9]+/[0-9]+", STICKY_REGEXP);
  const parenparen = new RegExp("^\\((?=\\()", STICKY_REGEXP); // NOTE: Don't include the following paren
  const opparen = new RegExp("^" + operator_regex_str + "(?=\\()", STICKY_REGEXP); // NOTE: likewise
  const spaceparen = new RegExp("^\\s+\\(", STICKY_REGEXP);
  const ws = new RegExp("^\\s+", STICKY_REGEXP);
  const comment = new RegExp("^#.*(?:\\n|\\r|\\r\\n|\\n\\r)", STICKY_REGEXP)
  const bar = new RegExp("^\\|", STICKY_REGEXP);
  const langle = new RegExp("^<", STICKY_REGEXP);
  const rangle = new RegExp("^>", STICKY_REGEXP);
  const lbrack = new RegExp("^\\[", STICKY_REGEXP);
  const rbrack = new RegExp("^\\]", STICKY_REGEXP);
  const lbrace = new RegExp("^\\{", STICKY_REGEXP);
  const rbrace = new RegExp("^\\}", STICKY_REGEXP);
  const lparen = new RegExp("^\\(", STICKY_REGEXP);
  const rparen = new RegExp("^\\)", STICKY_REGEXP);
  const period = new RegExp("^\\.", STICKY_REGEXP);
  const bang = new RegExp("^!", STICKY_REGEXP);
  const percent = new RegExp("^%", STICKY_REGEXP);
  const comma = new RegExp("^,", STICKY_REGEXP);
  const thinarrow = new RegExp("^->", STICKY_REGEXP);
  const thickarrow = new RegExp("^=>", STICKY_REGEXP);
  const coloncolon = new RegExp("^::", STICKY_REGEXP);
  const colon = new RegExp("^:", STICKY_REGEXP);
  const caret = new RegExp("^\\^", STICKY_REGEXP);
  const equals = new RegExp("^=", STICKY_REGEXP);
  const colonequals = new RegExp("^:=", STICKY_REGEXP);
  const semi = new RegExp("^;", STICKY_REGEXP);
  const backslash = new RegExp("^\\\\", STICKY_REGEXP);
  const opplus = new RegExp("^\\s+\\+\\s+", STICKY_REGEXP);
  const opminus = new RegExp("^\\s+-\\s+", STICKY_REGEXP);
  const optimes = new RegExp("^\\s+\\*\\s+", STICKY_REGEXP);
  const opdiv = new RegExp("^\\s+/\\s+", STICKY_REGEXP);
  const opleq = new RegExp("^\\s+<=\\s+", STICKY_REGEXP);
  const opgeq = new RegExp("^\\s+>=\\s+", STICKY_REGEXP);
  const opeq = new RegExp("^\\s+==\\s+", STICKY_REGEXP);
  const opneq = new RegExp("^\\s+<>\\s+", STICKY_REGEXP);
  const oplt = new RegExp("^\\s*<\\s*", STICKY_REGEXP);
  const opgt = new RegExp("^\\s*>\\s*", STICKY_REGEXP);
  const opis = new RegExp("^is(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opsatisfies = new RegExp("^satisfies(?![-_a-zA-Z0-9])", STICKY_REGEXP);
  const opraises = new RegExp("^raises(?![-_a-zA-Z0-9])", STICKY_REGEXP);

  const slashable = "[\\\\nrt\"\']"
  const dquot_str = 
    new RegExp("^\"(?:" +
               "\\\\[01234567]{1,3}" +
               "|\\\\x[0-9a-fA-F]{1,2}" + 
               "|\\\\u[0-9a-fA-f]{1,4}" + 
               "|\\\\[\r\n]{1,2}" + 
               "|\\\\[\\\\nrt\"\']" + 
               "|[^\"])*\"", STICKY_REGEXP);
  const squot_str = 
    new RegExp("^\'(?:" +
               "\\\\[01234567]{1,3}" +
               "|\\\\x[0-9a-fA-F]{1,2}" + 
               "|\\\\u[0-9a-fA-f]{1,4}" + 
               "|\\\\[\r\n]{1,2}" + 
               "|\\\\[\\\\nrt\"\']" + 
               "|[^\'])*\'", STICKY_REGEXP);

  const anychar = new RegExp("^[^]", STICKY_REGEXP);
  const Tokens = [
    {name: "PAREN?", val: parenparen, parenIsForExp: true},
    {name: "PAREN?", val: opparen, parenIsForExp: true},
    {name: "PARENSPACE", val: spaceparen, parenIsForExp: true},
    {name: "LPAREN?", val: lparen, parenIsForExp: true},


    {name: "IMPORT", val: new RegExp(kw("import"), STICKY_REGEXP)},
    {name: "PROVIDE", val: new RegExp(kw("provide"), STICKY_REGEXP)},
    {name: "AS", val: new RegExp(kw("as"), STICKY_REGEXP)},
    {name: "VAR", val: new RegExp(kw("var"), STICKY_REGEXP)},
    {name: "VAL", val: new RegExp(kw("val"), STICKY_REGEXP)},
    {name: "LETREC", val: new RegExp(kw("letrec"), STICKY_REGEXP)},
    {name: "LET", val: new RegExp(kw("let"), STICKY_REGEXP)},
    {name: "FUN", val: new RegExp(kw("fun"), STICKY_REGEXP)},
    {name: "TRUE", val: new RegExp(kw("true"), STICKY_REGEXP)},
    {name: "FALSE", val: new RegExp(kw("false"), STICKY_REGEXP)},
    {name: "METHOD", val: new RegExp(kw("method"), STICKY_REGEXP)},
    {name: "DOC", val: new RegExp(kw("doc:"), STICKY_REGEXP)},
    {name: "WHERE", val: new RegExp(kw("where:"), STICKY_REGEXP)},
    {name: "EXAMPLESCOLON", val: new RegExp(kw("examples:"), STICKY_REGEXP)},
    {name: "CHECKCOLON", val: new RegExp(kw("check:"), STICKY_REGEXP)},
    {name: "EXAMPLES", val: new RegExp(kw("examples"), STICKY_REGEXP)},
    {name: "CHECK", val: new RegExp(kw("check"), STICKY_REGEXP)},
    {name: "TRY", val: new RegExp(kw("try:"), STICKY_REGEXP)},
    {name: "EXCEPT", val: new RegExp(kw("except"), STICKY_REGEXP)},
    {name: "CASES", val: new RegExp(kw("cases"), STICKY_REGEXP)},
    {name: "WHEN", val: new RegExp(kw("when"), STICKY_REGEXP)},
    {name: "IFCOLON", val: new RegExp(kw("ask:"), STICKY_REGEXP)},
    {name: "IF", val: new RegExp(kw("if"), STICKY_REGEXP)},
    {name: "THENCOLON", val: new RegExp(kw("then:"), STICKY_REGEXP)},
    {name: "THEN", val: new RegExp(kw("then"), STICKY_REGEXP)},
    {name: "ELSECOLON", val: new RegExp(kw("otherwise:"), STICKY_REGEXP)},
    {name: "ELSEIF", val: new RegExp(kw("else if"), STICKY_REGEXP)},
    {name: "ELSE", val: new RegExp(kw("else"), STICKY_REGEXP)},
    {name: "DATA", val: new RegExp(kw("data"), STICKY_REGEXP)},
    {name: "WITH", val: new RegExp(kw("with:"), STICKY_REGEXP)},
    {name: "SHARING", val: new RegExp(kw("sharing:"), STICKY_REGEXP)},
    {name: "SHADOW", val: new RegExp(kw("shadow"), STICKY_REGEXP)},
    {name: "MUTABLE", val: new RegExp(kw("mutable"), STICKY_REGEXP)},
    {name: "CYCLIC", val: new RegExp(kw("cyclic"), STICKY_REGEXP)},
    {name: "DATATYPE", val: new RegExp(kw("datatype"), STICKY_REGEXP)},
    {name: "WITHCONSTRUCTOR", val: new RegExp(kw("with constructor"), STICKY_REGEXP)},
    {name: "GRAPH", val: new RegExp(kw("graph:"), STICKY_REGEXP)},
    {name: "BLOCK", val: new RegExp(kw("block:"), STICKY_REGEXP)},
    {name: "FOR", val: new RegExp(kw("for"), STICKY_REGEXP)},
    {name: "FROM", val: new RegExp(kw("from"), STICKY_REGEXP)},
    {name: "END", val: new RegExp(kw("end"), STICKY_REGEXP)},
    
    {name: "DOT", val: period},
    {name: "BANG", val: bang},
    {name: "PERCENT", val: percent},
    {name: "COMMA", val: comma},
    {name: "THINARROW", val: thinarrow},
    {name: "THICKARROW", val: thickarrow},
    {name: "COLONEQUALS", val: colonequals},
    {name: "COLONCOLON", val: coloncolon},
    {name: "COLON", val: colon},
    {name: "CARET", val: caret},
    {name: "BAR", val: bar},

    {name: "RATIONAL", val: rational},
    {name: "NUMBER", val: number},
    {name: "STRING", val: dquot_str}, 
    {name: "STRING", val: squot_str},

    {name: "PLUS", val: opplus, parenIsForExp: true},
    {name: "DASH", val: opminus, parenIsForExp: true},
    {name: "STAR", val: optimes, parenIsForExp: true},
    {name: "SLASH", val: opdiv, parenIsForExp: true},
    {name: "LEQ", val: opleq, parenIsForExp: true},
    {name: "GEQ", val: opgeq, parenIsForExp: true},
    {name: "EQUALEQUAL", val: opeq, parenIsForExp: true},
    {name: "NEQ", val: opneq, parenIsForExp: true},
    {name: "LT", val: oplt, parenIsForExp: true},
    {name: "GT", val: opgt, parenIsForExp: true},
    {name: "IS", val: opis},
    {name: "SATISFIES", val: opsatisfies},
    {name: "RAISES", val: opraises},
    {name: "LBRACK", val: lbrack}, 
    {name: "RBRACK", val: rbrack}, 
    {name: "LBRACE", val: lbrace}, 
    {name: "RBRACE", val: rbrace}, 
    {name: "RPAREN", val: rparen}, 
    {name: "LANGLE", val: langle, parenIsForExp: true},
    {name: "RANGLE", val: rangle, parenIsForExp: true},

    {name: "EQUALS", val: equals},

    {name: "COMMENT", val: comment}, 
    {name: "WS", val: ws, parenIsForExp: true},

    {name: "SEMI", val: semi},
    {name: "BACKSLASH", val: backslash},

    {name: "NAME", val: name},

    {name: "UNKNOWN", val: anychar},
  ];


  return {
    'Tokenizer': new Tokenizer(true, Tokens)
  };
});

define('js/bootstrap-un-parser',['../../../lib/jglr/jglr'],
/** @param {{Grammar : {fromSerializable : !Function}, Nonterm : !Object, Token : !Object, Rule : !Object}} E */
function(E) {
  const Grammar = E.Grammar;
  const Nonterm = E.Nonterm;
  const Token = E.Token;
  const Rule = E.Rule;

  var g_json = {
    "start": "START",
    "name": "BootstrapGrammar",
    "acceptStates": [
      1
    ],
    "ambiguitySortingFlag": "errorPriority",
    "mode": "RNGLR",
    "derivable": {
      "program": [
        "prelude",
        "prelude_I0_opt",
        "prelude_I1_star",
        "ε",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "import-stmt",
        "toplevel-block",
        "toplevel-block_I0_star",
        "toplevel-block_I0",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "prelude": [
        "prelude_I0_opt",
        "prelude_I1_star",
        "ε",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "import-stmt"
      ],
      "toplevel-block": [
        "toplevel-block_I0_star",
        "ε",
        "toplevel-block_I0",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "toplevel-block_I0_star": [
        "ε",
        "toplevel-block_I0",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "toplevel-block_I0": [
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "stmt": [
        "let-expr",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-test",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "end": [
        "ε"
      ],
      "prelude_I0_opt": [
        "ε",
        "prelude_I0",
        "provide-stmt"
      ],
      "prelude_I1_star": [
        "ε",
        "prelude_I1",
        "import-stmt"
      ],
      "prelude_I0": [
        "provide-stmt"
      ],
      "provide-stmt": [],
      "prelude_I1": [
        "import-stmt"
      ],
      "import-stmt": [],
      "import-stmt_I1": [
        "import-name",
        "import-string"
      ],
      "import-name": [],
      "import-string": [],
      "block": [
        "good-block",
        "bad-block",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "good-block": [
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "bad-block": [],
      "good-block_I0_star": [
        "ε",
        "good-block_I0",
        "block-prelude",
        "let-expr"
      ],
      "good-block_I0": [
        "block-prelude",
        "let-expr"
      ],
      "block-prelude": [
        "let-expr"
      ],
      "bad-block_I1_plus": [
        "bad-block_I1",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "bad-block_I1": [
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "check-block": [
        "good-check-block",
        "bad-check-block",
        "bad-check-block_I0_plus",
        "bad-check-block_I0",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr",
        "good-check-block_I1_plus",
        "good-check-block_I1"
      ],
      "good-check-block": [
        "good-check-block_I1_plus",
        "good-check-block_I1",
        "check-test",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "bad-check-block": [
        "bad-check-block_I0_plus",
        "bad-check-block_I0",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "good-check-block_I0_star": [
        "ε",
        "good-check-block_I0",
        "let-expr"
      ],
      "good-check-block_I1_plus": [
        "good-check-block_I1",
        "check-test",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "good-check-block_I0": [
        "let-expr"
      ],
      "let-expr": [],
      "good-check-block_I1": [
        "check-test",
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "check-test": [
        "binop-expr",
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "bad-check-block_I0_plus": [
        "bad-check-block_I0",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "bad-check-block_I0": [
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "fun-expr": [],
      "data-expr": [],
      "datatype-expr": [],
      "when-expr": [],
      "var-expr": [],
      "assign-expr": [],
      "check-expr": [],
      "graph-expr": [],
      "contract-stmt": [],
      "let-expr_I0_opt": [
        "ε",
        "let-expr_I0"
      ],
      "toplevel-binding": [
        "binding"
      ],
      "binop-expr": [
        "expr",
        "multi-let-expr",
        "letrec-expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "let-expr_I0": [],
      "binding": [],
      "binding_I0_opt": [
        "ε",
        "binding_I0"
      ],
      "binding_I2_opt": [
        "ε",
        "binding_I2"
      ],
      "binding_I0": [],
      "binding_I2": [],
      "ann": [
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "toplevel-binding_A1_I0_opt": [
        "ε",
        "toplevel-binding_A1_I0"
      ],
      "noparen-arrow-ann": [],
      "toplevel-binding_A1_I0": [],
      "multi-let-expr": [],
      "multi-let-expr_I1_star": [
        "ε",
        "multi-let-expr_I1",
        "let-binding-elt"
      ],
      "let-binding": [
        "let-expr",
        "var-expr"
      ],
      "multi-let-expr_I1": [
        "let-binding-elt"
      ],
      "let-binding-elt": [],
      "letrec-expr": [],
      "letrec-expr_I1_star": [
        "ε",
        "letrec-expr_I1",
        "letrec-binding"
      ],
      "letrec-expr_I1": [
        "letrec-binding"
      ],
      "letrec-binding": [],
      "contract-stmt_I2": [
        "ann",
        "noparen-arrow-ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "fun-header": [],
      "maybe-colon": [
        "ε"
      ],
      "doc-string": [
        "doc-string_I0_opt",
        "ε",
        "doc-string_I0"
      ],
      "where-clause": [
        "where-clause_I0_opt",
        "ε",
        "where-clause_I0"
      ],
      "ty-params": [
        "ty-params_I0_opt",
        "ε",
        "ty-params_I0"
      ],
      "args": [],
      "return-ann": [
        "return-ann_I0_opt",
        "ε",
        "return-ann_I0"
      ],
      "ty-params_I0_opt": [
        "ε",
        "ty-params_I0"
      ],
      "ty-params_I0": [],
      "ty-params_I0_I0": [],
      "ty-params_I0_I1_star": [
        "ε",
        "ty-params_I0_I1",
        "list-ty-param"
      ],
      "ty-params_I0_I3": [],
      "ty-params_I0_I1": [
        "list-ty-param"
      ],
      "list-ty-param": [],
      "args_I0": [],
      "args_I1_opt": [
        "ε",
        "args_I1",
        "binding"
      ],
      "args_I1": [
        "binding"
      ],
      "args_I1_I0_star": [
        "ε",
        "args_I1_I0",
        "list-arg-elt",
        "binding"
      ],
      "args_I1_I0": [
        "list-arg-elt",
        "binding"
      ],
      "list-arg-elt": [
        "binding"
      ],
      "list-arg-elt_I1_opt": [
        "ε",
        "list-arg-elt_I1"
      ],
      "list-arg-elt_I1": [],
      "return-ann_I0_opt": [
        "ε",
        "return-ann_I0"
      ],
      "return-ann_I0": [],
      "doc-string_I0_opt": [
        "ε",
        "doc-string_I0"
      ],
      "doc-string_I0": [],
      "where-clause_I0_opt": [
        "ε",
        "where-clause_I0"
      ],
      "where-clause_I0": [],
      "check-expr_A0_I0": [],
      "check-expr_A1_I0": [],
      "check-op": [],
      "data-mixins": [
        "data-mixins_I0_opt",
        "ε",
        "data-mixins_I0"
      ],
      "data-expr_I5_opt": [
        "ε",
        "data-expr_I5",
        "first-data-variant"
      ],
      "data-expr_I6_star": [
        "ε",
        "data-expr_I6",
        "data-variant"
      ],
      "data-sharing": [
        "data-sharing_I0_opt",
        "ε",
        "data-sharing_I0"
      ],
      "data-expr_I5": [
        "first-data-variant"
      ],
      "first-data-variant": [],
      "data-expr_I6": [
        "data-variant"
      ],
      "data-variant": [],
      "data-mixins_I0_opt": [
        "ε",
        "data-mixins_I0"
      ],
      "data-mixins_I0": [],
      "mixins": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "variant-members": [],
      "data-with": [
        "data-with_I0_opt",
        "ε",
        "data-with_I0"
      ],
      "variant-members_I0": [],
      "variant-members_I1_opt": [
        "ε",
        "variant-members_I1",
        "variant-member",
        "binding"
      ],
      "variant-members_I1": [
        "variant-member",
        "binding"
      ],
      "variant-members_I1_I0_star": [
        "ε",
        "variant-members_I1_I0",
        "list-variant-member"
      ],
      "variant-member": [
        "binding"
      ],
      "variant-members_I1_I0": [
        "list-variant-member"
      ],
      "list-variant-member": [],
      "variant-member_I0_opt": [
        "ε",
        "variant-member_I0"
      ],
      "variant-member_I0": [],
      "data-with_I0_opt": [
        "ε",
        "data-with_I0"
      ],
      "data-with_I0": [],
      "fields": [
        "field"
      ],
      "data-sharing_I0_opt": [
        "ε",
        "data-sharing_I0"
      ],
      "data-sharing_I0": [],
      "mixins_I0_star": [
        "ε",
        "mixins_I0",
        "list-mixin"
      ],
      "mixins_I0": [
        "list-mixin"
      ],
      "list-mixin": [],
      "datatype-expr_I4_opt": [
        "ε",
        "datatype-expr_I4",
        "first-datatype-variant"
      ],
      "datatype-expr_I5_star": [
        "ε",
        "datatype-expr_I5",
        "datatype-variant"
      ],
      "datatype-expr_I4": [
        "first-datatype-variant"
      ],
      "first-datatype-variant": [],
      "datatype-expr_I5": [
        "datatype-variant"
      ],
      "datatype-variant": [],
      "constructor-clause": [],
      "constructor-clause_I1": [],
      "graph-expr_I1_star": [
        "ε",
        "graph-expr_I1",
        "let-expr"
      ],
      "graph-expr_I1": [
        "let-expr"
      ],
      "expr": [
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "multi-let-expr",
        "letrec-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "paren-expr": [],
      "id-expr": [],
      "prim-expr": [
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "lambda-expr": [],
      "method-expr": [],
      "app-expr": [],
      "left-app-expr": [],
      "obj-expr": [],
      "list-expr": [],
      "dot-expr": [],
      "bracket-expr": [],
      "colon-expr": [],
      "colon-bracket-expr": [],
      "get-bang-expr": [],
      "update-expr": [],
      "extend-expr": [],
      "if-expr": [],
      "if-pipe-expr": [],
      "cases-expr": [],
      "for-expr": [],
      "try-expr": [],
      "user-block-expr": [],
      "inst-expr": [],
      "num-expr": [],
      "frac-expr": [],
      "bool-expr": [],
      "string-expr": [],
      "app-args": [],
      "app-args_I1_opt": [
        "ε",
        "app-args_I1",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-args_I1": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-args_I1_I0_star": [
        "ε",
        "app-args_I1_I0",
        "app-arg-elt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-args_I1_I0": [
        "app-arg-elt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-arg-elt": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "app-arg-elt_I1_opt": [
        "ε",
        "app-arg-elt_I1"
      ],
      "app-arg-elt_I1": [],
      "left-app-fun-expr": [
        "id-expr"
      ],
      "inst-expr_I1": [],
      "inst-expr_I2_star": [
        "ε",
        "inst-expr_I2",
        "inst-elt"
      ],
      "inst-expr_I4": [],
      "inst-expr_I2": [
        "inst-elt"
      ],
      "inst-elt": [],
      "obj-fields": [
        "obj-field"
      ],
      "obj-fields_I0_star": [
        "ε",
        "obj-fields_I0",
        "list-obj-field"
      ],
      "obj-field": [],
      "obj-fields_I2_opt": [
        "ε",
        "obj-fields_I2"
      ],
      "obj-fields_I0": [
        "list-obj-field"
      ],
      "list-obj-field": [],
      "obj-fields_I2": [],
      "key": [],
      "obj-field_A1_I2_opt": [
        "ε",
        "obj-field_A1_I2"
      ],
      "obj-field_A1_I2": [],
      "fields_I0_star": [
        "ε",
        "fields_I0",
        "list-field"
      ],
      "field": [],
      "fields_I2_opt": [
        "ε",
        "fields_I2"
      ],
      "fields_I0": [
        "list-field"
      ],
      "list-field": [],
      "fields_I2": [],
      "list-elt": [],
      "list-expr_I1_opt": [
        "ε",
        "list-expr_I1",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "list-expr_I1": [
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ],
      "list-expr_I1_I0_star": [
        "ε",
        "list-expr_I1_I0",
        "list-elt"
      ],
      "list-expr_I1_I0": [
        "list-elt"
      ],
      "if-expr_I4_star": [
        "ε",
        "if-expr_I4",
        "else-if"
      ],
      "if-expr_I5_opt": [
        "ε",
        "if-expr_I5"
      ],
      "if-expr_I4": [
        "else-if"
      ],
      "else-if": [],
      "if-expr_I5": [],
      "if-pipe-expr_I1_star": [
        "ε",
        "if-pipe-expr_I1",
        "if-pipe-branch"
      ],
      "if-pipe-expr_I2_opt": [
        "ε",
        "if-pipe-expr_I2"
      ],
      "if-pipe-expr_I1": [
        "if-pipe-branch"
      ],
      "if-pipe-branch": [],
      "if-pipe-expr_I2": [],
      "if-pipe-branch_I2": [],
      "cases-expr_I1": [],
      "cases-expr_I6_star": [
        "ε",
        "cases-expr_I6",
        "cases-branch"
      ],
      "cases-expr_I7_opt": [
        "ε",
        "cases-expr_I7"
      ],
      "cases-expr_I6": [
        "cases-branch"
      ],
      "cases-branch": [],
      "cases-expr_I7": [],
      "cases-branch_I2_opt": [
        "ε",
        "cases-branch_I2",
        "args"
      ],
      "cases-branch_I2": [
        "args"
      ],
      "for-bind": [],
      "for-bind-elt": [],
      "for-expr_I3_opt": [
        "ε",
        "for-expr_I3",
        "for-bind"
      ],
      "for-expr_I3": [
        "for-bind"
      ],
      "for-expr_I3_I0_star": [
        "ε",
        "for-expr_I3_I0",
        "for-bind-elt"
      ],
      "for-expr_I3_I0": [
        "for-bind-elt"
      ],
      "try-expr_I3": [],
      "name-ann": [],
      "record-ann": [],
      "arrow-ann": [],
      "app-ann": [],
      "pred-ann": [],
      "dot-ann": [],
      "record-ann_A0_I1_opt": [
        "ε",
        "record-ann_A0_I1",
        "ann-field"
      ],
      "record-ann_A0_I1": [
        "ann-field"
      ],
      "record-ann_A0_I1_I0_star": [
        "ε",
        "record-ann_A0_I1_I0",
        "list-ann-field"
      ],
      "ann-field": [],
      "record-ann_A0_I1_I0": [
        "list-ann-field"
      ],
      "list-ann-field": [],
      "noparen-arrow-ann_I0_opt": [
        "ε",
        "noparen-arrow-ann_I0",
        "ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "noparen-arrow-ann_I0": [
        "ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "noparen-arrow-ann_I0_I0_star": [
        "ε",
        "noparen-arrow-ann_I0_I0",
        "arrow-ann-elt"
      ],
      "noparen-arrow-ann_I0_I0": [
        "arrow-ann-elt"
      ],
      "arrow-ann-elt": [],
      "arrow-ann_I0": [],
      "arrow-ann_I1_opt": [
        "ε",
        "arrow-ann_I1",
        "ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "arrow-ann_I1": [
        "ann",
        "name-ann",
        "record-ann",
        "arrow-ann",
        "app-ann",
        "pred-ann",
        "dot-ann"
      ],
      "arrow-ann_I1_I0_star": [
        "ε",
        "arrow-ann_I1_I0",
        "arrow-ann-elt"
      ],
      "arrow-ann_I1_I0": [
        "arrow-ann-elt"
      ],
      "app-ann_I0": [
        "name-ann",
        "dot-ann"
      ],
      "app-ann_I1": [],
      "app-ann_I2_star": [
        "ε",
        "app-ann_I2",
        "app-ann-elt"
      ],
      "app-ann_I4": [],
      "app-ann_I2": [
        "app-ann-elt"
      ],
      "app-ann-elt": [],
      "pred-ann_I2": [],
      "START": [
        "program",
        "ε",
        "prelude",
        "prelude_I0_opt",
        "prelude_I1_star",
        "prelude_I0",
        "provide-stmt",
        "prelude_I1",
        "import-stmt",
        "toplevel-block",
        "toplevel-block_I0_star",
        "toplevel-block_I0",
        "stmt",
        "let-expr",
        "check-test",
        "fun-expr",
        "data-expr",
        "datatype-expr",
        "when-expr",
        "var-expr",
        "assign-expr",
        "check-expr",
        "graph-expr",
        "contract-stmt",
        "binop-expr",
        "multi-let-expr",
        "letrec-expr",
        "expr",
        "paren-expr",
        "id-expr",
        "prim-expr",
        "lambda-expr",
        "method-expr",
        "app-expr",
        "left-app-expr",
        "obj-expr",
        "list-expr",
        "dot-expr",
        "bracket-expr",
        "colon-expr",
        "colon-bracket-expr",
        "get-bang-expr",
        "update-expr",
        "extend-expr",
        "if-expr",
        "if-pipe-expr",
        "cases-expr",
        "for-expr",
        "try-expr",
        "user-block-expr",
        "inst-expr",
        "num-expr",
        "frac-expr",
        "bool-expr",
        "string-expr"
      ]
    },
    "rulesByOldId": {
      "0": {
        "name": "program",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-block"
          }
        ]
      },
      "1": {
        "name": "toplevel-block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-block_I0_star"
          }
        ]
      },
      "2": {
        "name": "toplevel-block_I0_star",
        "position": 0,
        "symbols": []
      },
      "3": {
        "name": "toplevel-block_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-block_I0_star"
          }
        ]
      },
      "4": {
        "name": "toplevel-block_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "5": {
        "name": "end",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "END"
          }
        ]
      },
      "6": {
        "name": "end",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SEMI"
          }
        ]
      },
      "7": {
        "name": "end",
        "position": 0,
        "symbols": []
      },
      "8": {
        "name": "prelude",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "9": {
        "name": "prelude_I0_opt",
        "position": 0,
        "symbols": []
      },
      "10": {
        "name": "prelude_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0"
          }
        ]
      },
      "11": {
        "name": "prelude_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "provide-stmt"
          }
        ]
      },
      "12": {
        "name": "prelude_I1_star",
        "position": 0,
        "symbols": []
      },
      "13": {
        "name": "prelude_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I1"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "14": {
        "name": "prelude_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt"
          }
        ]
      },
      "15": {
        "name": "import-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I1"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "16": {
        "name": "import-stmt_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "17": {
        "name": "import-stmt_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "18": {
        "name": "import-name",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "19": {
        "name": "import-string",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "20": {
        "name": "provide-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "21": {
        "name": "provide-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "22": {
        "name": "block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-block"
          }
        ]
      },
      "23": {
        "name": "block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-block"
          }
        ]
      },
      "24": {
        "name": "good-block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-block_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "25": {
        "name": "good-block_I0_star",
        "position": 0,
        "symbols": []
      },
      "26": {
        "name": "good-block_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "good-block_I0_star"
          }
        ]
      },
      "27": {
        "name": "good-block_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block-prelude"
          }
        ]
      },
      "28": {
        "name": "bad-block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "bad-block_I1_plus"
          }
        ]
      },
      "29": {
        "name": "bad-block_I1_plus",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-block_I1"
          }
        ]
      },
      "30": {
        "name": "bad-block_I1_plus",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-block_I1"
          },
          {
            "type": "Nonterm",
            "name": "bad-block_I1_plus"
          }
        ]
      },
      "31": {
        "name": "bad-block_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "32": {
        "name": "check-block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block"
          }
        ]
      },
      "33": {
        "name": "check-block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-check-block"
          }
        ]
      },
      "34": {
        "name": "good-check-block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "good-check-block_I1_plus"
          }
        ]
      },
      "35": {
        "name": "good-check-block_I0_star",
        "position": 0,
        "symbols": []
      },
      "36": {
        "name": "good-check-block_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "good-check-block_I0_star"
          }
        ]
      },
      "37": {
        "name": "good-check-block_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "38": {
        "name": "good-check-block_I1_plus",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I1"
          }
        ]
      },
      "39": {
        "name": "good-check-block_I1_plus",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I1"
          },
          {
            "type": "Nonterm",
            "name": "good-check-block_I1_plus"
          }
        ]
      },
      "40": {
        "name": "good-check-block_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-test"
          }
        ]
      },
      "41": {
        "name": "bad-check-block",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-check-block_I0_plus"
          }
        ]
      },
      "42": {
        "name": "bad-check-block_I0_plus",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-check-block_I0"
          }
        ]
      },
      "43": {
        "name": "bad-check-block_I0_plus",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-check-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "bad-check-block_I0_plus"
          }
        ]
      },
      "44": {
        "name": "bad-check-block_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "45": {
        "name": "block-prelude",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "46": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "47": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fun-expr"
          }
        ]
      },
      "48": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr"
          }
        ]
      },
      "49": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr"
          }
        ]
      },
      "50": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "when-expr"
          }
        ]
      },
      "51": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "52": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "assign-expr"
          }
        ]
      },
      "53": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-test"
          }
        ]
      },
      "54": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr"
          }
        ]
      },
      "55": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr"
          }
        ]
      },
      "56": {
        "name": "stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "contract-stmt"
          }
        ]
      },
      "57": {
        "name": "let-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "58": {
        "name": "let-expr_I0_opt",
        "position": 0,
        "symbols": []
      },
      "59": {
        "name": "let-expr_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr_I0"
          }
        ]
      },
      "60": {
        "name": "let-expr_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "VAL"
          }
        ]
      },
      "61": {
        "name": "binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "62": {
        "name": "binding_I0_opt",
        "position": 0,
        "symbols": []
      },
      "63": {
        "name": "binding_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0"
          }
        ]
      },
      "64": {
        "name": "binding_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "65": {
        "name": "binding_I2_opt",
        "position": 0,
        "symbols": []
      },
      "66": {
        "name": "binding_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I2"
          }
        ]
      },
      "67": {
        "name": "binding_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "68": {
        "name": "toplevel-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "69": {
        "name": "toplevel-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "70": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 0,
        "symbols": []
      },
      "71": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0"
          }
        ]
      },
      "72": {
        "name": "toplevel-binding_A1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "73": {
        "name": "multi-let-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LET"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "74": {
        "name": "multi-let-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "75": {
        "name": "multi-let-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "76": {
        "name": "multi-let-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding-elt"
          }
        ]
      },
      "77": {
        "name": "let-binding-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "78": {
        "name": "let-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "79": {
        "name": "let-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "80": {
        "name": "letrec-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LETREC"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "81": {
        "name": "letrec-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "82": {
        "name": "letrec-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "83": {
        "name": "letrec-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-binding"
          }
        ]
      },
      "84": {
        "name": "letrec-binding",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "85": {
        "name": "contract-stmt",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "contract-stmt_I2"
          }
        ]
      },
      "86": {
        "name": "contract-stmt_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "87": {
        "name": "contract-stmt_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "88": {
        "name": "fun-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "fun-header"
          },
          {
            "type": "Nonterm",
            "name": "maybe-colon"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "89": {
        "name": "maybe-colon",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COLON"
          }
        ]
      },
      "90": {
        "name": "maybe-colon",
        "position": 0,
        "symbols": []
      },
      "91": {
        "name": "fun-header",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "92": {
        "name": "ty-params",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_opt"
          }
        ]
      },
      "93": {
        "name": "ty-params_I0_opt",
        "position": 0,
        "symbols": []
      },
      "94": {
        "name": "ty-params_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0"
          }
        ]
      },
      "95": {
        "name": "ty-params_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I3"
          }
        ]
      },
      "96": {
        "name": "ty-params_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "97": {
        "name": "ty-params_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "98": {
        "name": "ty-params_I0_I1_star",
        "position": 0,
        "symbols": []
      },
      "99": {
        "name": "ty-params_I0_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "100": {
        "name": "ty-params_I0_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ty-param"
          }
        ]
      },
      "101": {
        "name": "ty-params_I0_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "102": {
        "name": "ty-params_I0_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "103": {
        "name": "list-ty-param",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "104": {
        "name": "args",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "105": {
        "name": "args_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "106": {
        "name": "args_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "107": {
        "name": "args_I1_opt",
        "position": 0,
        "symbols": []
      },
      "108": {
        "name": "args_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1"
          }
        ]
      },
      "109": {
        "name": "args_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "110": {
        "name": "args_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "111": {
        "name": "args_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "112": {
        "name": "args_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-arg-elt"
          }
        ]
      },
      "113": {
        "name": "list-arg-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Nonterm",
            "name": "list-arg-elt_I1_opt"
          }
        ]
      },
      "114": {
        "name": "list-arg-elt_I1_opt",
        "position": 0,
        "symbols": []
      },
      "115": {
        "name": "list-arg-elt_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-arg-elt_I1"
          }
        ]
      },
      "116": {
        "name": "list-arg-elt_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "117": {
        "name": "return-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0_opt"
          }
        ]
      },
      "118": {
        "name": "return-ann_I0_opt",
        "position": 0,
        "symbols": []
      },
      "119": {
        "name": "return-ann_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0"
          }
        ]
      },
      "120": {
        "name": "return-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "121": {
        "name": "doc-string",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0_opt"
          }
        ]
      },
      "122": {
        "name": "doc-string_I0_opt",
        "position": 0,
        "symbols": []
      },
      "123": {
        "name": "doc-string_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0"
          }
        ]
      },
      "124": {
        "name": "doc-string_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DOC"
          },
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "125": {
        "name": "where-clause",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0_opt"
          }
        ]
      },
      "126": {
        "name": "where-clause_I0_opt",
        "position": 0,
        "symbols": []
      },
      "127": {
        "name": "where-clause_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0"
          }
        ]
      },
      "128": {
        "name": "where-clause_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WHERE"
          }
        ]
      },
      "129": {
        "name": "where-clause_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          },
          {
            "type": "Nonterm",
            "name": "check-block"
          }
        ]
      },
      "130": {
        "name": "check-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr_A0_I0"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "check-block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "131": {
        "name": "check-expr_A0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECK"
          }
        ]
      },
      "132": {
        "name": "check-expr_A0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLES"
          }
        ]
      },
      "133": {
        "name": "check-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr_A1_I0"
          },
          {
            "type": "Nonterm",
            "name": "check-block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "134": {
        "name": "check-expr_A1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECKCOLON"
          }
        ]
      },
      "135": {
        "name": "check-expr_A1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          }
        ]
      },
      "136": {
        "name": "check-test",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "check-op"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "137": {
        "name": "check-test",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "138": {
        "name": "data-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "139": {
        "name": "data-expr_I5_opt",
        "position": 0,
        "symbols": []
      },
      "140": {
        "name": "data-expr_I5_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I5"
          }
        ]
      },
      "141": {
        "name": "data-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-data-variant"
          }
        ]
      },
      "142": {
        "name": "data-expr_I6_star",
        "position": 0,
        "symbols": []
      },
      "143": {
        "name": "data-expr_I6_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "144": {
        "name": "data-expr_I6",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-variant"
          }
        ]
      },
      "145": {
        "name": "data-mixins",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0_opt"
          }
        ]
      },
      "146": {
        "name": "data-mixins_I0_opt",
        "position": 0,
        "symbols": []
      },
      "147": {
        "name": "data-mixins_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0"
          }
        ]
      },
      "148": {
        "name": "data-mixins_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DERIVING"
          },
          {
            "type": "Nonterm",
            "name": "mixins"
          }
        ]
      },
      "149": {
        "name": "first-data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "150": {
        "name": "first-data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "151": {
        "name": "data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "152": {
        "name": "data-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "153": {
        "name": "variant-members",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "154": {
        "name": "variant-members_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "155": {
        "name": "variant-members_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "156": {
        "name": "variant-members_I1_opt",
        "position": 0,
        "symbols": []
      },
      "157": {
        "name": "variant-members_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1"
          }
        ]
      },
      "158": {
        "name": "variant-members_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "variant-member"
          }
        ]
      },
      "159": {
        "name": "variant-members_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "160": {
        "name": "variant-members_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "161": {
        "name": "variant-members_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-variant-member"
          }
        ]
      },
      "162": {
        "name": "list-variant-member",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "163": {
        "name": "variant-member",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "164": {
        "name": "variant-member_I0_opt",
        "position": 0,
        "symbols": []
      },
      "165": {
        "name": "variant-member_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0"
          }
        ]
      },
      "166": {
        "name": "variant-member_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          }
        ]
      },
      "167": {
        "name": "variant-member_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CYCLIC"
          }
        ]
      },
      "168": {
        "name": "data-with",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0_opt"
          }
        ]
      },
      "169": {
        "name": "data-with_I0_opt",
        "position": 0,
        "symbols": []
      },
      "170": {
        "name": "data-with_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0"
          }
        ]
      },
      "171": {
        "name": "data-with_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WITH"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "172": {
        "name": "data-sharing",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0_opt"
          }
        ]
      },
      "173": {
        "name": "data-sharing_I0_opt",
        "position": 0,
        "symbols": []
      },
      "174": {
        "name": "data-sharing_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0"
          }
        ]
      },
      "175": {
        "name": "data-sharing_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SHARING"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "176": {
        "name": "mixins",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "177": {
        "name": "mixins_I0_star",
        "position": 0,
        "symbols": []
      },
      "178": {
        "name": "mixins_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "179": {
        "name": "mixins_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-mixin"
          }
        ]
      },
      "180": {
        "name": "list-mixin",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "181": {
        "name": "datatype-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "182": {
        "name": "datatype-expr_I4_opt",
        "position": 0,
        "symbols": []
      },
      "183": {
        "name": "datatype-expr_I4_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4"
          }
        ]
      },
      "184": {
        "name": "datatype-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-datatype-variant"
          }
        ]
      },
      "185": {
        "name": "datatype-expr_I5_star",
        "position": 0,
        "symbols": []
      },
      "186": {
        "name": "datatype-expr_I5_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "187": {
        "name": "datatype-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-variant"
          }
        ]
      },
      "188": {
        "name": "first-datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "189": {
        "name": "first-datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "190": {
        "name": "datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "191": {
        "name": "datatype-variant",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "192": {
        "name": "constructor-clause",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WITHCONSTRUCTOR"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause_I1"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "193": {
        "name": "constructor-clause_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "194": {
        "name": "constructor-clause_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "195": {
        "name": "var-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "VAR"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "196": {
        "name": "assign-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONEQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "197": {
        "name": "graph-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GRAPH"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "198": {
        "name": "graph-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "199": {
        "name": "graph-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "200": {
        "name": "graph-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "201": {
        "name": "when-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "WHEN"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "202": {
        "name": "binop-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          }
        ]
      },
      "203": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IS"
          }
        ]
      },
      "204": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RAISES"
          }
        ]
      },
      "205": {
        "name": "check-op",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "SATISFIES"
          }
        ]
      },
      "206": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "paren-expr"
          }
        ]
      },
      "207": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          }
        ]
      },
      "208": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prim-expr"
          }
        ]
      },
      "209": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "lambda-expr"
          }
        ]
      },
      "210": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "method-expr"
          }
        ]
      },
      "211": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-expr"
          }
        ]
      },
      "212": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "left-app-expr"
          }
        ]
      },
      "213": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-expr"
          }
        ]
      },
      "214": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr"
          }
        ]
      },
      "215": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-expr"
          }
        ]
      },
      "216": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bracket-expr"
          }
        ]
      },
      "217": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "colon-expr"
          }
        ]
      },
      "218": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "colon-bracket-expr"
          }
        ]
      },
      "219": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "get-bang-expr"
          }
        ]
      },
      "220": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "update-expr"
          }
        ]
      },
      "221": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "extend-expr"
          }
        ]
      },
      "222": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr"
          }
        ]
      },
      "223": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr"
          }
        ]
      },
      "224": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr"
          }
        ]
      },
      "225": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr"
          }
        ]
      },
      "226": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "try-expr"
          }
        ]
      },
      "227": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "user-block-expr"
          }
        ]
      },
      "228": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr"
          }
        ]
      },
      "229": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr"
          }
        ]
      },
      "230": {
        "name": "expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr"
          }
        ]
      },
      "231": {
        "name": "paren-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "232": {
        "name": "id-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "233": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "num-expr"
          }
        ]
      },
      "234": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "frac-expr"
          }
        ]
      },
      "235": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bool-expr"
          }
        ]
      },
      "236": {
        "name": "prim-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "string-expr"
          }
        ]
      },
      "237": {
        "name": "num-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NUMBER"
          }
        ]
      },
      "238": {
        "name": "frac-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RATIONAL"
          }
        ]
      },
      "239": {
        "name": "bool-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "TRUE"
          }
        ]
      },
      "240": {
        "name": "bool-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FALSE"
          }
        ]
      },
      "241": {
        "name": "string-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "242": {
        "name": "lambda-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "243": {
        "name": "method-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "METHOD"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "244": {
        "name": "app-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "app-args"
          }
        ]
      },
      "245": {
        "name": "app-args",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "246": {
        "name": "app-args_I1_opt",
        "position": 0,
        "symbols": []
      },
      "247": {
        "name": "app-args_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1"
          }
        ]
      },
      "248": {
        "name": "app-args_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "249": {
        "name": "app-args_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "250": {
        "name": "app-args_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "251": {
        "name": "app-args_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-arg-elt"
          }
        ]
      },
      "252": {
        "name": "app-arg-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "app-arg-elt_I1_opt"
          }
        ]
      },
      "253": {
        "name": "app-arg-elt_I1_opt",
        "position": 0,
        "symbols": []
      },
      "254": {
        "name": "app-arg-elt_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-arg-elt_I1"
          }
        ]
      },
      "255": {
        "name": "app-arg-elt_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "256": {
        "name": "left-app-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "CARET"
          },
          {
            "type": "Nonterm",
            "name": "left-app-fun-expr"
          },
          {
            "type": "Nonterm",
            "name": "app-args"
          }
        ]
      },
      "257": {
        "name": "left-app-fun-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          }
        ]
      },
      "258": {
        "name": "left-app-fun-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "259": {
        "name": "inst-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I4"
          }
        ]
      },
      "260": {
        "name": "inst-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "261": {
        "name": "inst-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "262": {
        "name": "inst-expr_I2_star",
        "position": 0,
        "symbols": []
      },
      "263": {
        "name": "inst-expr_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "264": {
        "name": "inst-expr_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-elt"
          }
        ]
      },
      "265": {
        "name": "inst-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "266": {
        "name": "inst-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "267": {
        "name": "inst-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "268": {
        "name": "obj-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "269": {
        "name": "obj-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "270": {
        "name": "obj-fields",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "271": {
        "name": "obj-fields_I0_star",
        "position": 0,
        "symbols": []
      },
      "272": {
        "name": "obj-fields_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "273": {
        "name": "obj-fields_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-obj-field"
          }
        ]
      },
      "274": {
        "name": "obj-fields_I2_opt",
        "position": 0,
        "symbols": []
      },
      "275": {
        "name": "obj-fields_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I2"
          }
        ]
      },
      "276": {
        "name": "obj-fields_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "277": {
        "name": "list-obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "278": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "279": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          },
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2_opt"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "280": {
        "name": "obj-field_A1_I2_opt",
        "position": 0,
        "symbols": []
      },
      "281": {
        "name": "obj-field_A1_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2"
          }
        ]
      },
      "282": {
        "name": "obj-field_A1_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "283": {
        "name": "obj-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "284": {
        "name": "fields",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "285": {
        "name": "fields_I0_star",
        "position": 0,
        "symbols": []
      },
      "286": {
        "name": "fields_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "287": {
        "name": "fields_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-field"
          }
        ]
      },
      "288": {
        "name": "fields_I2_opt",
        "position": 0,
        "symbols": []
      },
      "289": {
        "name": "fields_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I2"
          }
        ]
      },
      "290": {
        "name": "fields_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "291": {
        "name": "list-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "292": {
        "name": "field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "293": {
        "name": "field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "294": {
        "name": "key",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "295": {
        "name": "key",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "296": {
        "name": "list-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "297": {
        "name": "list-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "list-expr_I1_opt"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "298": {
        "name": "list-expr_I1_opt",
        "position": 0,
        "symbols": []
      },
      "299": {
        "name": "list-expr_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr_I1"
          }
        ]
      },
      "300": {
        "name": "list-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "301": {
        "name": "list-expr_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "302": {
        "name": "list-expr_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "list-expr_I1_I0_star"
          }
        ]
      },
      "303": {
        "name": "list-expr_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-elt"
          }
        ]
      },
      "304": {
        "name": "dot-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "305": {
        "name": "bracket-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "306": {
        "name": "get-bang-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "307": {
        "name": "colon-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "308": {
        "name": "colon-bracket-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "309": {
        "name": "extend-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "310": {
        "name": "update-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "311": {
        "name": "if-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "312": {
        "name": "if-expr_I4_star",
        "position": 0,
        "symbols": []
      },
      "313": {
        "name": "if-expr_I4_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "314": {
        "name": "if-expr_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "else-if"
          }
        ]
      },
      "315": {
        "name": "if-expr_I5_opt",
        "position": 0,
        "symbols": []
      },
      "316": {
        "name": "if-expr_I5_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I5"
          }
        ]
      },
      "317": {
        "name": "if-expr_I5",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "318": {
        "name": "else-if",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSEIF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "319": {
        "name": "if-pipe-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "IFCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "320": {
        "name": "if-pipe-expr_I1_star",
        "position": 0,
        "symbols": []
      },
      "321": {
        "name": "if-pipe-expr_I1_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "322": {
        "name": "if-pipe-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-branch"
          }
        ]
      },
      "323": {
        "name": "if-pipe-expr_I2_opt",
        "position": 0,
        "symbols": []
      },
      "324": {
        "name": "if-pipe-expr_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2"
          }
        ]
      },
      "325": {
        "name": "if-pipe-expr_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "326": {
        "name": "if-pipe-branch",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-branch_I2"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "327": {
        "name": "if-pipe-branch_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "THENCOLON"
          }
        ]
      },
      "328": {
        "name": "if-pipe-branch_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "THEN"
          }
        ]
      },
      "329": {
        "name": "cases-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "330": {
        "name": "cases-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "331": {
        "name": "cases-expr_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "332": {
        "name": "cases-expr_I6_star",
        "position": 0,
        "symbols": []
      },
      "333": {
        "name": "cases-expr_I6_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "334": {
        "name": "cases-expr_I6",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch"
          }
        ]
      },
      "335": {
        "name": "cases-expr_I7_opt",
        "position": 0,
        "symbols": []
      },
      "336": {
        "name": "cases-expr_I7_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I7"
          }
        ]
      },
      "337": {
        "name": "cases-expr_I7",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSE"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "338": {
        "name": "cases-branch",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "cases-branch_I2_opt"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "339": {
        "name": "cases-branch_I2_opt",
        "position": 0,
        "symbols": []
      },
      "340": {
        "name": "cases-branch_I2_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch_I2"
          }
        ]
      },
      "341": {
        "name": "cases-branch_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args"
          }
        ]
      },
      "342": {
        "name": "for-bind",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "343": {
        "name": "for-bind-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "344": {
        "name": "for-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "FOR"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "345": {
        "name": "for-expr_I3_opt",
        "position": 0,
        "symbols": []
      },
      "346": {
        "name": "for-expr_I3_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3"
          }
        ]
      },
      "347": {
        "name": "for-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "for-bind"
          }
        ]
      },
      "348": {
        "name": "for-expr_I3_I0_star",
        "position": 0,
        "symbols": []
      },
      "349": {
        "name": "for-expr_I3_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "350": {
        "name": "for-expr_I3_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind-elt"
          }
        ]
      },
      "351": {
        "name": "try-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "TRY"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Token",
            "name": "EXCEPT"
          },
          {
            "type": "Nonterm",
            "name": "try-expr_I3"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "352": {
        "name": "try-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "353": {
        "name": "try-expr_I3",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "354": {
        "name": "user-block-expr",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "BLOCK"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "355": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "356": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann"
          }
        ]
      },
      "357": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann"
          }
        ]
      },
      "358": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann"
          }
        ]
      },
      "359": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "pred-ann"
          }
        ]
      },
      "360": {
        "name": "ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "361": {
        "name": "name-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "362": {
        "name": "record-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_opt"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "363": {
        "name": "record-ann_A0_I1_opt",
        "position": 0,
        "symbols": []
      },
      "364": {
        "name": "record-ann_A0_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1"
          }
        ]
      },
      "365": {
        "name": "record-ann_A0_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann-field"
          }
        ]
      },
      "366": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "367": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "368": {
        "name": "record-ann_A0_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ann-field"
          }
        ]
      },
      "369": {
        "name": "record-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "370": {
        "name": "list-ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "371": {
        "name": "ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "372": {
        "name": "ann-field",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "373": {
        "name": "noparen-arrow-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "374": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 0,
        "symbols": []
      },
      "375": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0"
          }
        ]
      },
      "376": {
        "name": "noparen-arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "377": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 0,
        "symbols": []
      },
      "378": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "379": {
        "name": "noparen-arrow-ann_I0_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "380": {
        "name": "arrow-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "381": {
        "name": "arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "382": {
        "name": "arrow-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "383": {
        "name": "arrow-ann_I1_opt",
        "position": 0,
        "symbols": []
      },
      "384": {
        "name": "arrow-ann_I1_opt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1"
          }
        ]
      },
      "385": {
        "name": "arrow-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "386": {
        "name": "arrow-ann_I1_I0_star",
        "position": 0,
        "symbols": []
      },
      "387": {
        "name": "arrow-ann_I1_I0_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "388": {
        "name": "arrow-ann_I1_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "389": {
        "name": "arrow-ann-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "390": {
        "name": "app-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I1"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I4"
          }
        ]
      },
      "391": {
        "name": "app-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "392": {
        "name": "app-ann_I0",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "393": {
        "name": "app-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "394": {
        "name": "app-ann_I1",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "395": {
        "name": "app-ann_I2_star",
        "position": 0,
        "symbols": []
      },
      "396": {
        "name": "app-ann_I2_star",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "397": {
        "name": "app-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann-elt"
          }
        ]
      },
      "398": {
        "name": "app-ann_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "399": {
        "name": "app-ann_I4",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "400": {
        "name": "app-ann-elt",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "401": {
        "name": "pred-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "PERCENT"
          },
          {
            "type": "Nonterm",
            "name": "pred-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "402": {
        "name": "pred-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "403": {
        "name": "pred-ann_I2",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "404": {
        "name": "dot-ann",
        "position": 0,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "405": {
        "name": "START",
        "position": 0,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "program"
          }
        ]
      },
      "601": {
        "name": "program",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-block"
          }
        ]
      },
      "3902": {
        "name": "prelude",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "4060": {
        "name": "prelude_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0"
          }
        ]
      },
      "4093": {
        "name": "prelude_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "provide-stmt"
          }
        ]
      },
      "4444": {
        "name": "program",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-block"
          }
        ]
      },
      "4446": {
        "name": "toplevel-block",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-block_I0_star"
          }
        ]
      },
      "4448": {
        "name": "toplevel-block_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-block_I0_star"
          }
        ]
      },
      "4450": {
        "name": "toplevel-block_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "4484": {
        "name": "id-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "4588": {
        "name": "string-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "4630": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "4662": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-test"
          }
        ]
      },
      "4694": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fun-expr"
          }
        ]
      },
      "4726": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr"
          }
        ]
      },
      "4758": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr"
          }
        ]
      },
      "4790": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "when-expr"
          }
        ]
      },
      "4822": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "4854": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "assign-expr"
          }
        ]
      },
      "4886": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr"
          }
        ]
      },
      "4918": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr"
          }
        ]
      },
      "4950": {
        "name": "stmt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "contract-stmt"
          }
        ]
      },
      "5024": {
        "name": "check-test",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "5144": {
        "name": "let-expr_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr_I0"
          }
        ]
      },
      "5147": {
        "name": "let-expr_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "VAL"
          }
        ]
      },
      "5150": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr"
          }
        ]
      },
      "5254": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr"
          }
        ]
      },
      "5572": {
        "name": "check-expr_A1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          }
        ]
      },
      "5635": {
        "name": "check-expr_A0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECK"
          }
        ]
      },
      "5637": {
        "name": "check-expr_A0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLES"
          }
        ]
      },
      "5961": {
        "name": "check-expr_A1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "CHECKCOLON"
          }
        ]
      },
      "6088": {
        "name": "graph-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GRAPH"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "6252": {
        "name": "binop-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          }
        ]
      },
      "6756": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "paren-expr"
          }
        ]
      },
      "6798": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          }
        ]
      },
      "6840": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prim-expr"
          }
        ]
      },
      "6882": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "lambda-expr"
          }
        ]
      },
      "6924": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "method-expr"
          }
        ]
      },
      "6966": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-expr"
          }
        ]
      },
      "7008": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "left-app-expr"
          }
        ]
      },
      "7050": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-expr"
          }
        ]
      },
      "7092": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr"
          }
        ]
      },
      "7134": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-expr"
          }
        ]
      },
      "7176": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bracket-expr"
          }
        ]
      },
      "7218": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "colon-expr"
          }
        ]
      },
      "7260": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "colon-bracket-expr"
          }
        ]
      },
      "7302": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "get-bang-expr"
          }
        ]
      },
      "7344": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "update-expr"
          }
        ]
      },
      "7386": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "extend-expr"
          }
        ]
      },
      "7428": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr"
          }
        ]
      },
      "7470": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr"
          }
        ]
      },
      "7512": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr"
          }
        ]
      },
      "7554": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr"
          }
        ]
      },
      "7596": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "try-expr"
          }
        ]
      },
      "7638": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "user-block-expr"
          }
        ]
      },
      "7680": {
        "name": "expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr"
          }
        ]
      },
      "7722": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "num-expr"
          }
        ]
      },
      "7764": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "frac-expr"
          }
        ]
      },
      "7806": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bool-expr"
          }
        ]
      },
      "7848": {
        "name": "prim-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "string-expr"
          }
        ]
      },
      "7890": {
        "name": "num-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NUMBER"
          }
        ]
      },
      "7932": {
        "name": "frac-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RATIONAL"
          }
        ]
      },
      "7974": {
        "name": "bool-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "TRUE"
          }
        ]
      },
      "8016": {
        "name": "bool-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "FALSE"
          }
        ]
      },
      "8437": {
        "name": "if-pipe-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "IFCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "9127": {
        "name": "prelude",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "9159": {
        "name": "prelude_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I1"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "9191": {
        "name": "prelude_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-stmt"
          }
        ]
      },
      "9261": {
        "name": "provide-stmt",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "9402": {
        "name": "provide-stmt",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Token",
            "name": "STAR"
          }
        ]
      },
      "9696": {
        "name": "toplevel-block_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-block_I0_star"
          }
        ]
      },
      "10353": {
        "name": "toplevel-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "10357": {
        "name": "binding_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0"
          }
        ]
      },
      "10359": {
        "name": "toplevel-binding_A1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "10360": {
        "name": "binding_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SHADOW"
          }
        ]
      },
      "10365": {
        "name": "toplevel-binding_A1_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0"
          }
        ]
      },
      "10399": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "IS"
          }
        ]
      },
      "10419": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RAISES"
          }
        ]
      },
      "10439": {
        "name": "check-op",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SATISFIES"
          }
        ]
      },
      "10459": {
        "name": "let-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "10461": {
        "name": "let-binding",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "var-expr"
          }
        ]
      },
      "10515": {
        "name": "multi-let-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "10520": {
        "name": "multi-let-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding-elt"
          }
        ]
      },
      "10572": {
        "name": "letrec-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "10576": {
        "name": "letrec-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-binding"
          }
        ]
      },
      "10749": {
        "name": "ty-params",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_opt"
          }
        ]
      },
      "10753": {
        "name": "ty-params_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0"
          }
        ]
      },
      "10765": {
        "name": "ty-params_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "10767": {
        "name": "ty-params_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "10912": {
        "name": "bad-check-block_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "10946": {
        "name": "check-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr_A1_I0"
          },
          {
            "type": "Nonterm",
            "name": "check-block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "10978": {
        "name": "check-block",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block"
          }
        ]
      },
      "11012": {
        "name": "check-block",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-check-block"
          }
        ]
      },
      "11179": {
        "name": "good-check-block_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "good-check-block_I0_star"
          }
        ]
      },
      "11199": {
        "name": "good-check-block_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "11221": {
        "name": "bad-check-block",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-check-block_I0_plus"
          }
        ]
      },
      "11255": {
        "name": "bad-check-block_I0_plus",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-check-block_I0"
          }
        ]
      },
      "11427": {
        "name": "graph-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "11461": {
        "name": "graph-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "GRAPH"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "11493": {
        "name": "graph-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "11644": {
        "name": "inst-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "11649": {
        "name": "inst-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "11775": {
        "name": "app-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "app-args"
          }
        ]
      },
      "12192": {
        "name": "args_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "12196": {
        "name": "args_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "12200": {
        "name": "key",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "12250": {
        "name": "obj-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "12301": {
        "name": "obj-fields_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "12305": {
        "name": "obj-fields_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-obj-field"
          }
        ]
      },
      "12452": {
        "name": "list-expr_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-elt"
          }
        ]
      },
      "12514": {
        "name": "list-expr_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr_I1"
          }
        ]
      },
      "12518": {
        "name": "list-expr_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "list-expr_I1_I0_star"
          }
        ]
      },
      "12759": {
        "name": "if-pipe-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "IFCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "12930": {
        "name": "if-pipe-expr_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "12975": {
        "name": "if-pipe-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-branch"
          }
        ]
      },
      "13020": {
        "name": "cases-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "13025": {
        "name": "cases-expr_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "13288": {
        "name": "block",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-block"
          }
        ]
      },
      "13290": {
        "name": "block",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-block"
          }
        ]
      },
      "13294": {
        "name": "good-block_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "good-block_I0_star"
          }
        ]
      },
      "13325": {
        "name": "good-block_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "block-prelude"
          }
        ]
      },
      "13356": {
        "name": "block-prelude",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          }
        ]
      },
      "13773": {
        "name": "user-block-expr",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "BLOCK"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "13974": {
        "name": "prelude_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "prelude_I1"
          },
          {
            "type": "Nonterm",
            "name": "prelude_I1_star"
          }
        ]
      },
      "14039": {
        "name": "import-name",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "14041": {
        "name": "import-stmt_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-name"
          }
        ]
      },
      "14043": {
        "name": "import-stmt_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "import-string"
          }
        ]
      },
      "14045": {
        "name": "import-string",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "14047": {
        "name": "provide-stmt",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PROVIDE"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "14080": {
        "name": "end",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "END"
          }
        ]
      },
      "14113": {
        "name": "end",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "SEMI"
          }
        ]
      },
      "14146": {
        "name": "name-ann",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "14218": {
        "name": "contract-stmt_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "14289": {
        "name": "contract-stmt_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "14321": {
        "name": "contract-stmt",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "contract-stmt_I2"
          }
        ]
      },
      "14353": {
        "name": "arrow-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "14359": {
        "name": "arrow-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "14442": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "14443": {
        "name": "app-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "name-ann"
          }
        ]
      },
      "14479": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann"
          }
        ]
      },
      "14513": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann"
          }
        ]
      },
      "14547": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann"
          }
        ]
      },
      "14581": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "pred-ann"
          }
        ]
      },
      "14615": {
        "name": "ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "14616": {
        "name": "app-ann_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "dot-ann"
          }
        ]
      },
      "14684": {
        "name": "noparen-arrow-ann_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0"
          }
        ]
      },
      "14701": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "14706": {
        "name": "noparen-arrow-ann_I0_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "14802": {
        "name": "assign-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONEQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "14866": {
        "name": "binding",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "14873": {
        "name": "check-test",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "check-op"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "14951": {
        "name": "let-binding-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "14956": {
        "name": "multi-let-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          }
        ]
      },
      "14961": {
        "name": "letrec-binding",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "15007": {
        "name": "letrec-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          }
        ]
      },
      "15011": {
        "name": "maybe-colon",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COLON"
          }
        ]
      },
      "15307": {
        "name": "ty-params_I0_I1_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "15309": {
        "name": "ty-params_I0_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ty-param"
          }
        ]
      },
      "15311": {
        "name": "paren-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "15386": {
        "name": "check-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr_A1_I0"
          },
          {
            "type": "Nonterm",
            "name": "check-block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "15418": {
        "name": "good-check-block",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "good-check-block_I1_plus"
          }
        ]
      },
      "15452": {
        "name": "good-check-block_I1_plus",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I1"
          }
        ]
      },
      "15520": {
        "name": "good-check-block_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-test"
          }
        ]
      },
      "15554": {
        "name": "good-check-block_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "good-check-block_I0_star"
          }
        ]
      },
      "15574": {
        "name": "bad-check-block_I0_plus",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-check-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "bad-check-block_I0_plus"
          }
        ]
      },
      "15714": {
        "name": "graph-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "GRAPH"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "15746": {
        "name": "graph-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "graph-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "graph-expr_I1_star"
          }
        ]
      },
      "15812": {
        "name": "colon-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "15896": {
        "name": "app-arg-elt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "app-arg-elt_I1_opt"
          }
        ]
      },
      "16015": {
        "name": "app-args_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1"
          }
        ]
      },
      "16019": {
        "name": "app-args_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "16039": {
        "name": "app-args_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-arg-elt"
          }
        ]
      },
      "16059": {
        "name": "left-app-fun-expr",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          }
        ]
      },
      "16105": {
        "name": "dot-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "16315": {
        "name": "inst-expr_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "16320": {
        "name": "inst-expr_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-elt"
          }
        ]
      },
      "16325": {
        "name": "get-bang-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "16451": {
        "name": "return-ann",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0_opt"
          }
        ]
      },
      "16453": {
        "name": "return-ann_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "return-ann_I0"
          }
        ]
      },
      "16470": {
        "name": "list-arg-elt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Nonterm",
            "name": "list-arg-elt_I1_opt"
          }
        ]
      },
      "16485": {
        "name": "args_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1"
          }
        ]
      },
      "16490": {
        "name": "args_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "16493": {
        "name": "args_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-arg-elt"
          }
        ]
      },
      "16503": {
        "name": "obj-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "16546": {
        "name": "obj-fields",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "16553": {
        "name": "list-obj-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "16557": {
        "name": "obj-fields_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          }
        ]
      },
      "16638": {
        "name": "list-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "16658": {
        "name": "list-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "list-expr_I1_opt"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "16700": {
        "name": "list-expr_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "16702": {
        "name": "list-expr_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-expr_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "list-expr_I1_I0_star"
          }
        ]
      },
      "17059": {
        "name": "if-pipe-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "IFCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "17101": {
        "name": "if-pipe-expr_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2"
          }
        ]
      },
      "17145": {
        "name": "if-pipe-expr_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          }
        ]
      },
      "17300": {
        "name": "bad-block_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "17336": {
        "name": "bad-block",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "stmt"
          },
          {
            "type": "Nonterm",
            "name": "bad-block_I1_plus"
          }
        ]
      },
      "17338": {
        "name": "bad-block_I1_plus",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-block_I1"
          }
        ]
      },
      "17483": {
        "name": "good-block",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-block_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "stmt"
          }
        ]
      },
      "17485": {
        "name": "good-block_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-block_I0"
          },
          {
            "type": "Nonterm",
            "name": "good-block_I0_star"
          }
        ]
      },
      "17516": {
        "name": "user-block-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BLOCK"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "17647": {
        "name": "arrow-ann-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "17728": {
        "name": "record-ann",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "17796": {
        "name": "record-ann_A0_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1"
          }
        ]
      },
      "17804": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "17806": {
        "name": "record-ann_A0_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-ann-field"
          }
        ]
      },
      "17842": {
        "name": "noparen-arrow-ann_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "17855": {
        "name": "noparen-arrow-ann_I0_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_I0_star"
          }
        ]
      },
      "17860": {
        "name": "arrow-ann_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann-elt"
          }
        ]
      },
      "17899": {
        "name": "arrow-ann_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1"
          }
        ]
      },
      "17903": {
        "name": "arrow-ann_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "17908": {
        "name": "app-ann_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LANGLE"
          }
        ]
      },
      "17913": {
        "name": "app-ann_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "LT"
          }
        ]
      },
      "17968": {
        "name": "let-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "let-expr_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "18000": {
        "name": "binding",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "binding_I2_opt"
          }
        ]
      },
      "18002": {
        "name": "binding_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding_I2"
          }
        ]
      },
      "18142": {
        "name": "doc-string",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0_opt"
          }
        ]
      },
      "18173": {
        "name": "doc-string_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "doc-string_I0"
          }
        ]
      },
      "18235": {
        "name": "fun-header",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "18465": {
        "name": "list-ty-param",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "18477": {
        "name": "ty-params_I0_I1_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          }
        ]
      },
      "18480": {
        "name": "check-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr_A0_I0"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "check-block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "18512": {
        "name": "good-check-block_I1_plus",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "good-check-block_I1"
          },
          {
            "type": "Nonterm",
            "name": "good-check-block_I1_plus"
          }
        ]
      },
      "18578": {
        "name": "data-mixins",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0_opt"
          }
        ]
      },
      "18580": {
        "name": "data-mixins_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-mixins_I0"
          }
        ]
      },
      "18661": {
        "name": "datatype-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "18868": {
        "name": "var-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "VAR"
          },
          {
            "type": "Nonterm",
            "name": "toplevel-binding"
          },
          {
            "type": "Token",
            "name": "EQUALS"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "18900": {
        "name": "when-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "WHEN"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "18974": {
        "name": "app-arg-elt_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "18994": {
        "name": "app-arg-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "app-arg-elt_I1_opt"
          }
        ]
      },
      "19014": {
        "name": "app-arg-elt_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-arg-elt_I1"
          }
        ]
      },
      "19034": {
        "name": "app-args",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "19076": {
        "name": "app-args_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "19078": {
        "name": "app-args_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-args_I1_I0_star"
          }
        ]
      },
      "19100": {
        "name": "left-app-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "CARET"
          },
          {
            "type": "Nonterm",
            "name": "left-app-fun-expr"
          },
          {
            "type": "Nonterm",
            "name": "app-args"
          }
        ]
      },
      "19195": {
        "name": "fields_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "19198": {
        "name": "fields_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-field"
          }
        ]
      },
      "19243": {
        "name": "inst-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "19398": {
        "name": "inst-expr_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "inst-expr_I2"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          }
        ]
      },
      "19489": {
        "name": "return-ann_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "19502": {
        "name": "list-arg-elt_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "19505": {
        "name": "list-arg-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Nonterm",
            "name": "list-arg-elt_I1_opt"
          }
        ]
      },
      "19508": {
        "name": "list-arg-elt_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-arg-elt_I1"
          }
        ]
      },
      "19511": {
        "name": "args",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "19514": {
        "name": "args_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "19517": {
        "name": "args_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "args_I1_I0_star"
          }
        ]
      },
      "19524": {
        "name": "obj-field_A1_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2"
          }
        ]
      },
      "19526": {
        "name": "obj-fields_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "19528": {
        "name": "obj-fields",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "obj-field"
          },
          {
            "type": "Nonterm",
            "name": "obj-fields_I2_opt"
          }
        ]
      },
      "19530": {
        "name": "obj-fields_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "obj-fields_I2"
          }
        ]
      },
      "19532": {
        "name": "obj-field",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "19536": {
        "name": "key",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "19716": {
        "name": "if-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "19991": {
        "name": "if-pipe-branch_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "THENCOLON"
          }
        ]
      },
      "20022": {
        "name": "if-pipe-branch_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "THEN"
          }
        ]
      },
      "20097": {
        "name": "if-pipe-expr",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "IFCOLON"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-expr_I2_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "20188": {
        "name": "for-expr_I3_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind-elt"
          }
        ]
      },
      "20233": {
        "name": "for-expr_I3_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3"
          }
        ]
      },
      "20238": {
        "name": "for-expr_I3_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "20241": {
        "name": "bad-block_I1_plus",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "bad-block_I1"
          },
          {
            "type": "Nonterm",
            "name": "bad-block_I1_plus"
          }
        ]
      },
      "20243": {
        "name": "try-expr_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "20246": {
        "name": "try-expr_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "20291": {
        "name": "import-stmt",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "IMPORT"
          },
          {
            "type": "Nonterm",
            "name": "import-stmt_I1"
          },
          {
            "type": "Token",
            "name": "AS"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "20324": {
        "name": "dot-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "20360": {
        "name": "pred-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "20380": {
        "name": "pred-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "20438": {
        "name": "record-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_opt"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "20474": {
        "name": "record-ann_A0_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann-field"
          }
        ]
      },
      "20476": {
        "name": "list-ann-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann-field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "20478": {
        "name": "record-ann_A0_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "record-ann_A0_I1_I0_star"
          }
        ]
      },
      "20480": {
        "name": "noparen-arrow-ann",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann_I0_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "20547": {
        "name": "arrow-ann_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "20549": {
        "name": "arrow-ann_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_I0_star"
          }
        ]
      },
      "20593": {
        "name": "app-ann_I2_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "20598": {
        "name": "app-ann_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann-elt"
          }
        ]
      },
      "20605": {
        "name": "binding_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "20618": {
        "name": "toplevel-binding",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "toplevel-binding_A1_I0_opt"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "noparen-arrow-ann"
          }
        ]
      },
      "20621": {
        "name": "multi-let-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "LET"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "20663": {
        "name": "letrec-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "LETREC"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "20793": {
        "name": "fun-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "fun-header"
          },
          {
            "type": "Nonterm",
            "name": "maybe-colon"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "20993": {
        "name": "doc-string_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "DOC"
          },
          {
            "type": "Token",
            "name": "STRING"
          }
        ]
      },
      "21024": {
        "name": "fun-header",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          }
        ]
      },
      "21205": {
        "name": "ty-params_I0",
        "position": 4,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I0"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I1_star"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params_I0_I3"
          }
        ]
      },
      "21209": {
        "name": "ty-params_I0_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "21213": {
        "name": "ty-params_I0_I3",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "21217": {
        "name": "check-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "check-expr_A0_I0"
          },
          {
            "type": "Token",
            "name": "STRING"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "check-block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "21249": {
        "name": "data-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "21481": {
        "name": "data-mixins_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "DERIVING"
          },
          {
            "type": "Nonterm",
            "name": "mixins"
          }
        ]
      },
      "21485": {
        "name": "mixins_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "21505": {
        "name": "mixins_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-mixin"
          }
        ]
      },
      "21643": {
        "name": "datatype-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "21848": {
        "name": "datatype-expr_I4_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4"
          }
        ]
      },
      "21884": {
        "name": "datatype-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-datatype-variant"
          }
        ]
      },
      "21920": {
        "name": "when-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "WHEN"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "21952": {
        "name": "colon-bracket-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "21994": {
        "name": "left-app-fun-expr",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "id-expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "NAME"
          }
        ]
      },
      "21996": {
        "name": "extend-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "22044": {
        "name": "fields",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "22049": {
        "name": "list-field",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "22052": {
        "name": "fields_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0"
          },
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          }
        ]
      },
      "22055": {
        "name": "bracket-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "DOT"
          },
          {
            "type": "Token",
            "name": "LBRACK"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RBRACK"
          }
        ]
      },
      "22097": {
        "name": "inst-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "22139": {
        "name": "inst-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "22181": {
        "name": "inst-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "inst-expr_I4"
          }
        ]
      },
      "22225": {
        "name": "update-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "BANG"
          },
          {
            "type": "Token",
            "name": "LBRACE"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          },
          {
            "type": "Token",
            "name": "RBRACE"
          }
        ]
      },
      "22310": {
        "name": "obj-field_A1_I2",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "22316": {
        "name": "if-expr",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "22487": {
        "name": "if-expr_I4_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "22532": {
        "name": "if-expr_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "else-if"
          }
        ]
      },
      "22712": {
        "name": "if-pipe-branch",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Nonterm",
            "name": "if-pipe-branch_I2"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "22760": {
        "name": "if-pipe-expr_I2",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "22848": {
        "name": "for-bind-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-bind"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "22894": {
        "name": "for-expr_I3",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "for-bind"
          }
        ]
      },
      "22896": {
        "name": "for-expr_I3_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_I0_star"
          }
        ]
      },
      "22975": {
        "name": "ann-field",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLONCOLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "22977": {
        "name": "ann-field",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          }
        ]
      },
      "23013": {
        "name": "app-ann-elt",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "23118": {
        "name": "app-ann_I2_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          }
        ]
      },
      "23124": {
        "name": "multi-let-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "LET"
          },
          {
            "type": "Nonterm",
            "name": "multi-let-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-binding"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23166": {
        "name": "letrec-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "LETREC"
          },
          {
            "type": "Nonterm",
            "name": "letrec-expr_I1_star"
          },
          {
            "type": "Nonterm",
            "name": "let-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23208": {
        "name": "fun-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "fun-header"
          },
          {
            "type": "Nonterm",
            "name": "maybe-colon"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23240": {
        "name": "where-clause",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0_opt"
          }
        ]
      },
      "23274": {
        "name": "where-clause_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "where-clause_I0"
          }
        ]
      },
      "23308": {
        "name": "where-clause_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "WHERE"
          }
        ]
      },
      "23419": {
        "name": "first-data-variant",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "23673": {
        "name": "data-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "23883": {
        "name": "data-expr_I5_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I5"
          }
        ]
      },
      "23920": {
        "name": "data-expr_I5",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "first-data-variant"
          }
        ]
      },
      "23957": {
        "name": "list-mixin",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "23977": {
        "name": "mixins",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "23979": {
        "name": "mixins_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "mixins_I0"
          },
          {
            "type": "Nonterm",
            "name": "mixins_I0_star"
          }
        ]
      },
      "23999": {
        "name": "variant-members_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "24005": {
        "name": "variant-members_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "24077": {
        "name": "first-datatype-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "24223": {
        "name": "datatype-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "24255": {
        "name": "datatype-expr_I5_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "24290": {
        "name": "datatype-expr_I5",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-variant"
          }
        ]
      },
      "24326": {
        "name": "field",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "24330": {
        "name": "fields_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "24332": {
        "name": "fields",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "field"
          },
          {
            "type": "Nonterm",
            "name": "fields_I2_opt"
          }
        ]
      },
      "24334": {
        "name": "fields_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "fields_I2"
          }
        ]
      },
      "24336": {
        "name": "method-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "METHOD"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "24428": {
        "name": "obj-field",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          },
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "obj-field_A1_I2_opt"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "24432": {
        "name": "if-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "24474": {
        "name": "if-expr_I5_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I5"
          }
        ]
      },
      "24562": {
        "name": "if-expr_I4_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "if-expr_I4"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          }
        ]
      },
      "24653": {
        "name": "cases-expr",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "24871": {
        "name": "for-bind",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "FROM"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          }
        ]
      },
      "24957": {
        "name": "pred-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "PERCENT"
          },
          {
            "type": "Nonterm",
            "name": "pred-ann_I2"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "24991": {
        "name": "arrow-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "arrow-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "arrow-ann_I1_opt"
          },
          {
            "type": "Token",
            "name": "THINARROW"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "25025": {
        "name": "app-ann_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "RANGLE"
          }
        ]
      },
      "25059": {
        "name": "app-ann_I4",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "GT"
          }
        ]
      },
      "25093": {
        "name": "app-ann",
        "position": 5,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "app-ann_I0"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I1"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I2_star"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Nonterm",
            "name": "app-ann_I4"
          }
        ]
      },
      "25127": {
        "name": "fun-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "fun-header"
          },
          {
            "type": "Nonterm",
            "name": "maybe-colon"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "25159": {
        "name": "where-clause_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "EXAMPLESCOLON"
          },
          {
            "type": "Nonterm",
            "name": "check-block"
          }
        ]
      },
      "25193": {
        "name": "lambda-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "25235": {
        "name": "first-data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "25272": {
        "name": "first-data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "25346": {
        "name": "data-with",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0_opt"
          }
        ]
      },
      "25383": {
        "name": "data-with_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-with_I0"
          }
        ]
      },
      "25493": {
        "name": "data-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "25661": {
        "name": "data-expr_I6_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "25697": {
        "name": "data-expr_I6",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-variant"
          }
        ]
      },
      "25808": {
        "name": "first-datatype-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "25846": {
        "name": "variant-members_I1_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1"
          }
        ]
      },
      "25856": {
        "name": "variant-members_I1_I0_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "25861": {
        "name": "variant-members_I1_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "list-variant-member"
          }
        ]
      },
      "25868": {
        "name": "variant-member_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0"
          }
        ]
      },
      "25871": {
        "name": "variant-member_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "MUTABLE"
          }
        ]
      },
      "25874": {
        "name": "variant-member_I0",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "CYCLIC"
          }
        ]
      },
      "25877": {
        "name": "constructor-clause_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENSPACE"
          }
        ]
      },
      "25879": {
        "name": "constructor-clause_I1",
        "position": 1,
        "symbols": [
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          }
        ]
      },
      "25989": {
        "name": "datatype-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26021": {
        "name": "datatype-expr_I5_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          }
        ]
      },
      "26058": {
        "name": "method-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "METHOD"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26236": {
        "name": "obj-field",
        "position": 6,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26246": {
        "name": "if-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "IF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I4_star"
          },
          {
            "type": "Nonterm",
            "name": "if-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26288": {
        "name": "if-expr_I5",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSECOLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "26423": {
        "name": "cases-expr",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26594": {
        "name": "cases-expr_I6_star",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "26639": {
        "name": "cases-expr_I6",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch"
          }
        ]
      },
      "26768": {
        "name": "lambda-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "26810": {
        "name": "first-data-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "26847": {
        "name": "data-with_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "WITH"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "26992": {
        "name": "data-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27024": {
        "name": "data-sharing",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0_opt"
          }
        ]
      },
      "27059": {
        "name": "data-sharing_I0_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-sharing_I0"
          }
        ]
      },
      "27129": {
        "name": "data-expr_I6_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "data-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          }
        ]
      },
      "27166": {
        "name": "data-variant",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "27239": {
        "name": "variant-members",
        "position": 3,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          }
        ]
      },
      "27241": {
        "name": "variant-members_I1",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          },
          {
            "type": "Nonterm",
            "name": "variant-member"
          }
        ]
      },
      "27244": {
        "name": "list-variant-member",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member"
          },
          {
            "type": "Token",
            "name": "COMMA"
          }
        ]
      },
      "27249": {
        "name": "variant-members_I1_I0_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0"
          },
          {
            "type": "Nonterm",
            "name": "variant-members_I1_I0_star"
          }
        ]
      },
      "27254": {
        "name": "variant-member",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "variant-member_I0_opt"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          }
        ]
      },
      "27328": {
        "name": "datatype-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "27364": {
        "name": "datatype-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "DATATYPE"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I4_opt"
          },
          {
            "type": "Nonterm",
            "name": "datatype-expr_I5_star"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27398": {
        "name": "method-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "METHOD"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27440": {
        "name": "obj-field",
        "position": 7,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27456": {
        "name": "else-if",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "ELSEIF"
          },
          {
            "type": "Nonterm",
            "name": "binop-expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "27595": {
        "name": "cases-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27637": {
        "name": "cases-expr_I7_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I7"
          }
        ]
      },
      "27681": {
        "name": "cases-expr_I6_star",
        "position": 2,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-expr_I6"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          }
        ]
      },
      "27726": {
        "name": "for-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "FOR"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27768": {
        "name": "try-expr",
        "position": 8,
        "symbols": [
          {
            "type": "Token",
            "name": "TRY"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Token",
            "name": "EXCEPT"
          },
          {
            "type": "Nonterm",
            "name": "try-expr_I3"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27810": {
        "name": "lambda-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "FUN"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27852": {
        "name": "data-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "27884": {
        "name": "data-sharing_I0",
        "position": 2,
        "symbols": [
          {
            "type": "Token",
            "name": "SHARING"
          },
          {
            "type": "Nonterm",
            "name": "fields"
          }
        ]
      },
      "27919": {
        "name": "data-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "27956": {
        "name": "data-variant",
        "position": 3,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "28029": {
        "name": "datatype-variant",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause"
          }
        ]
      },
      "28065": {
        "name": "field",
        "position": 6,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28067": {
        "name": "obj-field",
        "position": 8,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28071": {
        "name": "cases-branch_I2",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "args"
          }
        ]
      },
      "28119": {
        "name": "cases-branch_I2_opt",
        "position": 1,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "cases-branch_I2"
          }
        ]
      },
      "28165": {
        "name": "cases-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "CASES"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I1"
          },
          {
            "type": "Nonterm",
            "name": "ann"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "cases-expr_I7_opt"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28207": {
        "name": "for-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "FOR"
          },
          {
            "type": "Nonterm",
            "name": "expr"
          },
          {
            "type": "Token",
            "name": "PARENNOSPACE"
          },
          {
            "type": "Nonterm",
            "name": "for-expr_I3_opt"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28249": {
        "name": "try-expr",
        "position": 9,
        "symbols": [
          {
            "type": "Token",
            "name": "TRY"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Token",
            "name": "EXCEPT"
          },
          {
            "type": "Nonterm",
            "name": "try-expr_I3"
          },
          {
            "type": "Nonterm",
            "name": "binding"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28291": {
        "name": "data-expr",
        "position": 10,
        "symbols": [
          {
            "type": "Token",
            "name": "DATA"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "ty-params"
          },
          {
            "type": "Nonterm",
            "name": "data-mixins"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I5_opt"
          },
          {
            "type": "Nonterm",
            "name": "data-expr_I6_star"
          },
          {
            "type": "Nonterm",
            "name": "data-sharing"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28323": {
        "name": "data-variant",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "variant-members"
          },
          {
            "type": "Nonterm",
            "name": "data-with"
          }
        ]
      },
      "28396": {
        "name": "field",
        "position": 7,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28487": {
        "name": "constructor-clause",
        "position": 6,
        "symbols": [
          {
            "type": "Token",
            "name": "WITHCONSTRUCTOR"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause_I1"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28535": {
        "name": "field",
        "position": 8,
        "symbols": [
          {
            "type": "Nonterm",
            "name": "key"
          },
          {
            "type": "Nonterm",
            "name": "args"
          },
          {
            "type": "Nonterm",
            "name": "return-ann"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "doc-string"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "where-clause"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      },
      "28537": {
        "name": "cases-branch",
        "position": 5,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Nonterm",
            "name": "cases-branch_I2_opt"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "28582": {
        "name": "cases-expr_I7",
        "position": 4,
        "symbols": [
          {
            "type": "Token",
            "name": "BAR"
          },
          {
            "type": "Token",
            "name": "ELSE"
          },
          {
            "type": "Token",
            "name": "THICKARROW"
          },
          {
            "type": "Nonterm",
            "name": "block"
          }
        ]
      },
      "28626": {
        "name": "constructor-clause",
        "position": 7,
        "symbols": [
          {
            "type": "Token",
            "name": "WITHCONSTRUCTOR"
          },
          {
            "type": "Nonterm",
            "name": "constructor-clause_I1"
          },
          {
            "type": "Token",
            "name": "NAME"
          },
          {
            "type": "Token",
            "name": "RPAREN"
          },
          {
            "type": "Token",
            "name": "COLON"
          },
          {
            "type": "Nonterm",
            "name": "block"
          },
          {
            "type": "Nonterm",
            "name": "end"
          }
        ]
      }
    },
    "actionsByOldId": {
      "0": "Rule.defaultAction",
      "1": "Rule.defaultAction",
      "2": "Rule.Inline",
      "3": "Rule.ListCons(\"toplevel-block_I0\", \"toplevel-block_I0_star\", true)",
      "4": "Rule.Inline",
      "5": "Rule.defaultAction",
      "6": "Rule.defaultAction",
      "7": "Rule.defaultAction",
      "8": "Rule.defaultAction",
      "9": "Rule.Inline",
      "10": "Rule.Inline",
      "11": "Rule.Inline",
      "12": "Rule.Inline",
      "13": "Rule.ListCons(\"prelude_I1\", \"prelude_I1_star\", true)",
      "14": "Rule.Inline",
      "15": "Rule.defaultAction",
      "16": "Rule.Inline",
      "17": "Rule.Inline",
      "18": "Rule.defaultAction",
      "19": "Rule.defaultAction",
      "20": "Rule.defaultAction",
      "21": "Rule.defaultAction",
      "22": "Rule.defaultAction",
      "23": "Rule.defaultAction",
      "24": "Rule.defaultAction",
      "25": "Rule.Inline",
      "26": "Rule.ListCons(\"good-block_I0\", \"good-block_I0_star\", true)",
      "27": "Rule.Inline",
      "28": "Rule.defaultAction",
      "29": "Rule.Inline",
      "30": "Rule.ListCons(\"bad-block_I1\", \"bad-block_I1_plus\", true)",
      "31": "Rule.Inline",
      "32": "Rule.defaultAction",
      "33": "Rule.defaultAction",
      "34": "Rule.defaultAction",
      "35": "Rule.Inline",
      "36": "Rule.ListCons(\"good-check-block_I0\", \"good-check-block_I0_star\", true)",
      "37": "Rule.Inline",
      "38": "Rule.Inline",
      "39": "Rule.ListCons(\"good-check-block_I1\", \"good-check-block_I1_plus\", true)",
      "40": "Rule.Inline",
      "41": "Rule.defaultAction",
      "42": "Rule.Inline",
      "43": "Rule.ListCons(\"bad-check-block_I0\", \"bad-check-block_I0_plus\", true)",
      "44": "Rule.Inline",
      "45": "Rule.defaultAction",
      "46": "Rule.defaultAction",
      "47": "Rule.defaultAction",
      "48": "Rule.defaultAction",
      "49": "Rule.defaultAction",
      "50": "Rule.defaultAction",
      "51": "Rule.defaultAction",
      "52": "Rule.defaultAction",
      "53": "Rule.defaultAction",
      "54": "Rule.defaultAction",
      "55": "Rule.defaultAction",
      "56": "Rule.defaultAction",
      "57": "Rule.defaultAction",
      "58": "Rule.Inline",
      "59": "Rule.Inline",
      "60": "Rule.Inline",
      "61": "Rule.defaultAction",
      "62": "Rule.Inline",
      "63": "Rule.Inline",
      "64": "Rule.Inline",
      "65": "Rule.Inline",
      "66": "Rule.Inline",
      "67": "Rule.Inline",
      "68": "Rule.defaultAction",
      "69": "Rule.defaultAction",
      "70": "Rule.Inline",
      "71": "Rule.Inline",
      "72": "Rule.Inline",
      "73": "Rule.defaultAction",
      "74": "Rule.Inline",
      "75": "Rule.ListCons(\"multi-let-expr_I1\", \"multi-let-expr_I1_star\", true)",
      "76": "Rule.Inline",
      "77": "Rule.defaultAction",
      "78": "Rule.defaultAction",
      "79": "Rule.defaultAction",
      "80": "Rule.defaultAction",
      "81": "Rule.Inline",
      "82": "Rule.ListCons(\"letrec-expr_I1\", \"letrec-expr_I1_star\", true)",
      "83": "Rule.Inline",
      "84": "Rule.defaultAction",
      "85": "Rule.defaultAction",
      "86": "Rule.Inline",
      "87": "Rule.Inline",
      "88": "Rule.defaultAction",
      "89": "Rule.defaultAction",
      "90": "Rule.defaultAction",
      "91": "Rule.defaultAction",
      "92": "Rule.defaultAction",
      "93": "Rule.Inline",
      "94": "Rule.Inline",
      "95": "Rule.Inline",
      "96": "Rule.Inline",
      "97": "Rule.Inline",
      "98": "Rule.Inline",
      "99": "Rule.ListCons(\"ty-params_I0_I1\", \"ty-params_I0_I1_star\", true)",
      "100": "Rule.Inline",
      "101": "Rule.Inline",
      "102": "Rule.Inline",
      "103": "Rule.defaultAction",
      "104": "Rule.defaultAction",
      "105": "Rule.Inline",
      "106": "Rule.Inline",
      "107": "Rule.Inline",
      "108": "Rule.Inline",
      "109": "Rule.Inline",
      "110": "Rule.Inline",
      "111": "Rule.ListCons(\"args_I1_I0\", \"args_I1_I0_star\", true)",
      "112": "Rule.Inline",
      "113": "Rule.defaultAction",
      "114": "Rule.Inline",
      "115": "Rule.Inline",
      "116": "Rule.Inline",
      "117": "Rule.defaultAction",
      "118": "Rule.Inline",
      "119": "Rule.Inline",
      "120": "Rule.Inline",
      "121": "Rule.defaultAction",
      "122": "Rule.Inline",
      "123": "Rule.Inline",
      "124": "Rule.Inline",
      "125": "Rule.defaultAction",
      "126": "Rule.Inline",
      "127": "Rule.Inline",
      "128": "Rule.Inline",
      "129": "Rule.Inline",
      "130": "Rule.defaultAction",
      "131": "Rule.Inline",
      "132": "Rule.Inline",
      "133": "Rule.defaultAction",
      "134": "Rule.Inline",
      "135": "Rule.Inline",
      "136": "Rule.defaultAction",
      "137": "Rule.defaultAction",
      "138": "Rule.defaultAction",
      "139": "Rule.Inline",
      "140": "Rule.Inline",
      "141": "Rule.Inline",
      "142": "Rule.Inline",
      "143": "Rule.ListCons(\"data-expr_I6\", \"data-expr_I6_star\", true)",
      "144": "Rule.Inline",
      "145": "Rule.defaultAction",
      "146": "Rule.Inline",
      "147": "Rule.Inline",
      "148": "Rule.Inline",
      "149": "Rule.defaultAction",
      "150": "Rule.defaultAction",
      "151": "Rule.defaultAction",
      "152": "Rule.defaultAction",
      "153": "Rule.defaultAction",
      "154": "Rule.Inline",
      "155": "Rule.Inline",
      "156": "Rule.Inline",
      "157": "Rule.Inline",
      "158": "Rule.Inline",
      "159": "Rule.Inline",
      "160": "Rule.ListCons(\"variant-members_I1_I0\", \"variant-members_I1_I0_star\", true)",
      "161": "Rule.Inline",
      "162": "Rule.defaultAction",
      "163": "Rule.defaultAction",
      "164": "Rule.Inline",
      "165": "Rule.Inline",
      "166": "Rule.Inline",
      "167": "Rule.Inline",
      "168": "Rule.defaultAction",
      "169": "Rule.Inline",
      "170": "Rule.Inline",
      "171": "Rule.Inline",
      "172": "Rule.defaultAction",
      "173": "Rule.Inline",
      "174": "Rule.Inline",
      "175": "Rule.Inline",
      "176": "Rule.defaultAction",
      "177": "Rule.Inline",
      "178": "Rule.ListCons(\"mixins_I0\", \"mixins_I0_star\", true)",
      "179": "Rule.Inline",
      "180": "Rule.defaultAction",
      "181": "Rule.defaultAction",
      "182": "Rule.Inline",
      "183": "Rule.Inline",
      "184": "Rule.Inline",
      "185": "Rule.Inline",
      "186": "Rule.ListCons(\"datatype-expr_I5\", \"datatype-expr_I5_star\", true)",
      "187": "Rule.Inline",
      "188": "Rule.defaultAction",
      "189": "Rule.defaultAction",
      "190": "Rule.defaultAction",
      "191": "Rule.defaultAction",
      "192": "Rule.defaultAction",
      "193": "Rule.Inline",
      "194": "Rule.Inline",
      "195": "Rule.defaultAction",
      "196": "Rule.defaultAction",
      "197": "Rule.defaultAction",
      "198": "Rule.Inline",
      "199": "Rule.ListCons(\"graph-expr_I1\", \"graph-expr_I1_star\", true)",
      "200": "Rule.Inline",
      "201": "Rule.defaultAction",
      "202": "Rule.defaultAction",
      "203": "Rule.defaultAction",
      "204": "Rule.defaultAction",
      "205": "Rule.defaultAction",
      "206": "Rule.defaultAction",
      "207": "Rule.defaultAction",
      "208": "Rule.defaultAction",
      "209": "Rule.defaultAction",
      "210": "Rule.defaultAction",
      "211": "Rule.defaultAction",
      "212": "Rule.defaultAction",
      "213": "Rule.defaultAction",
      "214": "Rule.defaultAction",
      "215": "Rule.defaultAction",
      "216": "Rule.defaultAction",
      "217": "Rule.defaultAction",
      "218": "Rule.defaultAction",
      "219": "Rule.defaultAction",
      "220": "Rule.defaultAction",
      "221": "Rule.defaultAction",
      "222": "Rule.defaultAction",
      "223": "Rule.defaultAction",
      "224": "Rule.defaultAction",
      "225": "Rule.defaultAction",
      "226": "Rule.defaultAction",
      "227": "Rule.defaultAction",
      "228": "Rule.defaultAction",
      "229": "Rule.defaultAction",
      "230": "Rule.defaultAction",
      "231": "Rule.defaultAction",
      "232": "Rule.defaultAction",
      "233": "Rule.defaultAction",
      "234": "Rule.defaultAction",
      "235": "Rule.defaultAction",
      "236": "Rule.defaultAction",
      "237": "Rule.defaultAction",
      "238": "Rule.defaultAction",
      "239": "Rule.defaultAction",
      "240": "Rule.defaultAction",
      "241": "Rule.defaultAction",
      "242": "Rule.defaultAction",
      "243": "Rule.defaultAction",
      "244": "Rule.defaultAction",
      "245": "Rule.defaultAction",
      "246": "Rule.Inline",
      "247": "Rule.Inline",
      "248": "Rule.Inline",
      "249": "Rule.Inline",
      "250": "Rule.ListCons(\"app-args_I1_I0\", \"app-args_I1_I0_star\", true)",
      "251": "Rule.Inline",
      "252": "Rule.defaultAction",
      "253": "Rule.Inline",
      "254": "Rule.Inline",
      "255": "Rule.Inline",
      "256": "Rule.defaultAction",
      "257": "Rule.defaultAction",
      "258": "Rule.defaultAction",
      "259": "Rule.defaultAction",
      "260": "Rule.Inline",
      "261": "Rule.Inline",
      "262": "Rule.Inline",
      "263": "Rule.ListCons(\"inst-expr_I2\", \"inst-expr_I2_star\", true)",
      "264": "Rule.Inline",
      "265": "Rule.Inline",
      "266": "Rule.Inline",
      "267": "Rule.defaultAction",
      "268": "Rule.defaultAction",
      "269": "Rule.defaultAction",
      "270": "Rule.defaultAction",
      "271": "Rule.Inline",
      "272": "Rule.ListCons(\"obj-fields_I0\", \"obj-fields_I0_star\", true)",
      "273": "Rule.Inline",
      "274": "Rule.Inline",
      "275": "Rule.Inline",
      "276": "Rule.Inline",
      "277": "Rule.defaultAction",
      "278": "Rule.defaultAction",
      "279": "Rule.defaultAction",
      "280": "Rule.Inline",
      "281": "Rule.Inline",
      "282": "Rule.Inline",
      "283": "Rule.defaultAction",
      "284": "Rule.defaultAction",
      "285": "Rule.Inline",
      "286": "Rule.ListCons(\"fields_I0\", \"fields_I0_star\", true)",
      "287": "Rule.Inline",
      "288": "Rule.Inline",
      "289": "Rule.Inline",
      "290": "Rule.Inline",
      "291": "Rule.defaultAction",
      "292": "Rule.defaultAction",
      "293": "Rule.defaultAction",
      "294": "Rule.defaultAction",
      "295": "Rule.defaultAction",
      "296": "Rule.defaultAction",
      "297": "Rule.defaultAction",
      "298": "Rule.Inline",
      "299": "Rule.Inline",
      "300": "Rule.Inline",
      "301": "Rule.Inline",
      "302": "Rule.ListCons(\"list-expr_I1_I0\", \"list-expr_I1_I0_star\", true)",
      "303": "Rule.Inline",
      "304": "Rule.defaultAction",
      "305": "Rule.defaultAction",
      "306": "Rule.defaultAction",
      "307": "Rule.defaultAction",
      "308": "Rule.defaultAction",
      "309": "Rule.defaultAction",
      "310": "Rule.defaultAction",
      "311": "Rule.defaultAction",
      "312": "Rule.Inline",
      "313": "Rule.ListCons(\"if-expr_I4\", \"if-expr_I4_star\", true)",
      "314": "Rule.Inline",
      "315": "Rule.Inline",
      "316": "Rule.Inline",
      "317": "Rule.Inline",
      "318": "Rule.defaultAction",
      "319": "Rule.defaultAction",
      "320": "Rule.Inline",
      "321": "Rule.ListCons(\"if-pipe-expr_I1\", \"if-pipe-expr_I1_star\", true)",
      "322": "Rule.Inline",
      "323": "Rule.Inline",
      "324": "Rule.Inline",
      "325": "Rule.Inline",
      "326": "Rule.defaultAction",
      "327": "Rule.Inline",
      "328": "Rule.Inline",
      "329": "Rule.defaultAction",
      "330": "Rule.Inline",
      "331": "Rule.Inline",
      "332": "Rule.Inline",
      "333": "Rule.ListCons(\"cases-expr_I6\", \"cases-expr_I6_star\", true)",
      "334": "Rule.Inline",
      "335": "Rule.Inline",
      "336": "Rule.Inline",
      "337": "Rule.Inline",
      "338": "Rule.defaultAction",
      "339": "Rule.Inline",
      "340": "Rule.Inline",
      "341": "Rule.Inline",
      "342": "Rule.defaultAction",
      "343": "Rule.defaultAction",
      "344": "Rule.defaultAction",
      "345": "Rule.Inline",
      "346": "Rule.Inline",
      "347": "Rule.Inline",
      "348": "Rule.Inline",
      "349": "Rule.ListCons(\"for-expr_I3_I0\", \"for-expr_I3_I0_star\", true)",
      "350": "Rule.Inline",
      "351": "Rule.defaultAction",
      "352": "Rule.Inline",
      "353": "Rule.Inline",
      "354": "Rule.defaultAction",
      "355": "Rule.defaultAction",
      "356": "Rule.defaultAction",
      "357": "Rule.defaultAction",
      "358": "Rule.defaultAction",
      "359": "Rule.defaultAction",
      "360": "Rule.defaultAction",
      "361": "Rule.defaultAction",
      "362": "Rule.defaultAction",
      "363": "Rule.Inline",
      "364": "Rule.Inline",
      "365": "Rule.Inline",
      "366": "Rule.Inline",
      "367": "Rule.ListCons(\"record-ann_A0_I1_I0\", \"record-ann_A0_I1_I0_star\", true)",
      "368": "Rule.Inline",
      "369": "Rule.defaultAction",
      "370": "Rule.defaultAction",
      "371": "Rule.defaultAction",
      "372": "Rule.defaultAction",
      "373": "Rule.defaultAction",
      "374": "Rule.Inline",
      "375": "Rule.Inline",
      "376": "Rule.Inline",
      "377": "Rule.Inline",
      "378": "Rule.ListCons(\"noparen-arrow-ann_I0_I0\", \"noparen-arrow-ann_I0_I0_star\", true)",
      "379": "Rule.Inline",
      "380": "Rule.defaultAction",
      "381": "Rule.Inline",
      "382": "Rule.Inline",
      "383": "Rule.Inline",
      "384": "Rule.Inline",
      "385": "Rule.Inline",
      "386": "Rule.Inline",
      "387": "Rule.ListCons(\"arrow-ann_I1_I0\", \"arrow-ann_I1_I0_star\", true)",
      "388": "Rule.Inline",
      "389": "Rule.defaultAction",
      "390": "Rule.defaultAction",
      "391": "Rule.Inline",
      "392": "Rule.Inline",
      "393": "Rule.Inline",
      "394": "Rule.Inline",
      "395": "Rule.Inline",
      "396": "Rule.ListCons(\"app-ann_I2\", \"app-ann_I2_star\", true)",
      "397": "Rule.Inline",
      "398": "Rule.Inline",
      "399": "Rule.Inline",
      "400": "Rule.defaultAction",
      "401": "Rule.defaultAction",
      "402": "Rule.Inline",
      "403": "Rule.Inline",
      "404": "Rule.defaultAction",
      "405": "Rule.defaultAction"
    },
    "flagsByOldId": {
      "7": {
        "errorPriority": 1
      },
      "23": {
        "errorPriority": 1
      },
      "33": {
        "errorPriority": 1
      },
      "90": {
        "errorPriority": 1
      }
    },
    "rules": [
      0,
      1,
      2,
      3,
      4,
      5,
      6,
      7,
      8,
      9,
      10,
      11,
      12,
      13,
      14,
      15,
      16,
      17,
      18,
      19,
      20,
      21,
      22,
      23,
      24,
      25,
      26,
      27,
      28,
      29,
      30,
      31,
      32,
      33,
      34,
      35,
      36,
      37,
      38,
      39,
      40,
      41,
      42,
      43,
      44,
      45,
      46,
      47,
      48,
      49,
      50,
      51,
      52,
      53,
      54,
      55,
      56,
      57,
      58,
      59,
      60,
      61,
      62,
      63,
      64,
      65,
      66,
      67,
      68,
      69,
      70,
      71,
      72,
      73,
      74,
      75,
      76,
      77,
      78,
      79,
      80,
      81,
      82,
      83,
      84,
      85,
      86,
      87,
      88,
      89,
      90,
      91,
      92,
      93,
      94,
      95,
      96,
      97,
      98,
      99,
      100,
      101,
      102,
      103,
      104,
      105,
      106,
      107,
      108,
      109,
      110,
      111,
      112,
      113,
      114,
      115,
      116,
      117,
      118,
      119,
      120,
      121,
      122,
      123,
      124,
      125,
      126,
      127,
      128,
      129,
      130,
      133,
      131,
      132,
      134,
      135,
      136,
      137,
      138,
      139,
      140,
      141,
      142,
      143,
      144,
      145,
      146,
      147,
      148,
      149,
      150,
      151,
      152,
      153,
      154,
      155,
      156,
      157,
      158,
      159,
      160,
      161,
      162,
      163,
      164,
      165,
      166,
      167,
      168,
      169,
      170,
      171,
      172,
      173,
      174,
      175,
      176,
      177,
      178,
      179,
      180,
      181,
      182,
      183,
      184,
      185,
      186,
      187,
      188,
      189,
      190,
      191,
      192,
      193,
      194,
      195,
      196,
      197,
      198,
      199,
      200,
      201,
      202,
      203,
      204,
      205,
      206,
      207,
      208,
      209,
      210,
      211,
      212,
      213,
      214,
      215,
      216,
      217,
      218,
      219,
      220,
      221,
      222,
      223,
      224,
      225,
      226,
      227,
      228,
      229,
      230,
      231,
      232,
      233,
      234,
      235,
      236,
      237,
      238,
      239,
      240,
      241,
      242,
      243,
      244,
      245,
      246,
      247,
      248,
      249,
      250,
      251,
      252,
      253,
      254,
      255,
      256,
      257,
      258,
      259,
      260,
      261,
      262,
      263,
      264,
      265,
      266,
      267,
      268,
      269,
      270,
      271,
      272,
      273,
      274,
      275,
      276,
      277,
      278,
      279,
      283,
      280,
      281,
      282,
      284,
      285,
      286,
      287,
      288,
      289,
      290,
      291,
      292,
      293,
      294,
      295,
      296,
      297,
      298,
      299,
      300,
      301,
      302,
      303,
      304,
      305,
      306,
      307,
      308,
      309,
      310,
      311,
      312,
      313,
      314,
      315,
      316,
      317,
      318,
      319,
      320,
      321,
      322,
      323,
      324,
      325,
      326,
      327,
      328,
      329,
      330,
      331,
      332,
      333,
      334,
      335,
      336,
      337,
      338,
      339,
      340,
      341,
      342,
      343,
      344,
      345,
      346,
      347,
      348,
      349,
      350,
      351,
      352,
      353,
      354,
      355,
      356,
      357,
      358,
      359,
      360,
      361,
      362,
      369,
      363,
      364,
      365,
      366,
      367,
      368,
      370,
      371,
      372,
      373,
      374,
      375,
      376,
      377,
      378,
      379,
      380,
      381,
      382,
      383,
      384,
      385,
      386,
      387,
      388,
      389,
      390,
      391,
      392,
      393,
      394,
      395,
      396,
      397,
      398,
      399,
      400,
      401,
      402,
      403,
      404,
      405
    ],
    "rnTable": [
      {
        "program": {
          "push": 1
        },
        "prelude": {
          "push": 2
        },
        "prelude_I0_opt": {
          "push": 3
        },
        "prelude_I0": {
          "push": 4
        },
        "provide-stmt": {
          "push": 5
        },
        "'PROVIDE": {
          "push": 6
        },
        "$": {
          "reductions": [
            [
              0,
              1
            ],
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              9,
              6
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8,
              5
            ],
            [
              9,
              6
            ]
          ]
        }
      },
      {
        "$": {
          "accept": true
        }
      },
      {
        "toplevel-block": {
          "push": 7
        },
        "toplevel-block_I0_star": {
          "push": 8
        },
        "toplevel-block_I0": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 32
        },
        "'PARENSPACE": {
          "push": 33
        },
        "'EXAMPLESCOLON": {
          "push": 34
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36
        },
        "'EXAMPLES": {
          "push": 37
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39
        },
        "'DATA": {
          "push": 40
        },
        "'DATATYPE": {
          "push": 41
        },
        "'VAR": {
          "push": 42
        },
        "'GRAPH": {
          "push": 43
        },
        "'WHEN": {
          "push": 44
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        },
        "$": {
          "reductions": [
            [
              601,
              2
            ],
            [
              1,
              2
            ],
            [
              2,
              3
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "prelude_I1_star": {
          "push": 86
        },
        "prelude_I1": {
          "push": 87
        },
        "import-stmt": {
          "push": 88
        },
        "'IMPORT": {
          "push": 89
        },
        "$": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              3902,
              7
            ],
            [
              12,
              7
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4060,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4093,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 90
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12
        },
        "'STAR": {
          "push": 91
        },
        "let-expr": {
          "push": 13
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 32
        },
        "'PARENSPACE": {
          "push": 33
        },
        "'EXAMPLESCOLON": {
          "push": 34
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36
        },
        "'EXAMPLES": {
          "push": 37
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39
        },
        "'DATA": {
          "push": 40
        },
        "'DATATYPE": {
          "push": 41
        },
        "'VAR": {
          "push": 42
        },
        "'GRAPH": {
          "push": 43
        },
        "'WHEN": {
          "push": 44
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4444,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4446,
              0
            ]
          ]
        }
      },
      {
        "toplevel-block_I0_star": {
          "push": 92
        },
        "toplevel-block_I0": {
          "push": 9
        },
        "stmt": {
          "push": 10
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 32
        },
        "'PARENSPACE": {
          "push": 33
        },
        "'EXAMPLESCOLON": {
          "push": 34
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36
        },
        "'EXAMPLES": {
          "push": 37
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39
        },
        "'DATA": {
          "push": 40
        },
        "'DATATYPE": {
          "push": 41
        },
        "'VAR": {
          "push": 42
        },
        "'GRAPH": {
          "push": 43
        },
        "'WHEN": {
          "push": 44
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        },
        "$": {
          "reductions": [
            [
              4448,
              3
            ],
            [
              2,
              3
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4450,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 93
        },
        "'COLONEQUALS": {
          "push": 94
        },
        "$": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4588,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4662,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4694,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4726,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4758,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4790,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4822,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4854,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4886,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4918,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4950,
              0
            ]
          ]
        }
      },
      {
        "toplevel-binding": {
          "push": 95
        },
        "binding": {
          "push": 96
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 99
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 100
        },
        "toplevel-binding_A1_I0": {
          "push": 101
        },
        "'NAME": {
          "reductions": [
            [
              70,
              13
            ],
            [
              62,
              11
            ]
          ]
        }
      },
      {
        "check-op": {
          "push": 102
        },
        "'IS": {
          "push": 103,
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'RAISES": {
          "push": 104,
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "push": 105,
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5024,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              5144,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5144,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              5147,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5147,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5150,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 106
        },
        "var-expr": {
          "push": 107
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              74,
              14
            ]
          ]
        },
        "multi-let-expr_I1_star": {
          "push": 108
        },
        "let-binding": {
          "push": 109
        },
        "multi-let-expr_I1": {
          "push": 110
        },
        "let-binding-elt": {
          "push": 111
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              74,
              14
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              74,
              14
            ],
            [
              58,
              10
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              74,
              14
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5254,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 112
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              81,
              15
            ]
          ]
        },
        "letrec-expr_I1_star": {
          "push": 113
        },
        "letrec-expr_I1": {
          "push": 114
        },
        "letrec-binding": {
          "push": 115
        },
        "'NAME": {
          "reductions": [
            [
              81,
              15
            ],
            [
              58,
              10
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              81,
              15
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "fun-header": {
          "push": 116
        },
        "ty-params": {
          "push": 117
        },
        "ty-params_I0_opt": {
          "push": 118
        },
        "ty-params_I0": {
          "push": 119
        },
        "ty-params_I0_I0": {
          "push": 120
        },
        "'LANGLE": {
          "push": 121
        },
        "'LT": {
          "push": 122
        },
        "'NAME": {
          "reductions": [
            [
              92,
              17
            ],
            [
              93,
              18
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              92,
              17
            ],
            [
              93,
              18
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              92,
              17
            ],
            [
              93,
              18
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 124
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5572,
              0
            ]
          ]
        }
      },
      {
        "'STRING": {
          "push": 126
        }
      },
      {
        "'STRING": {
          "reductions": [
            [
              5635,
              0
            ]
          ]
        }
      },
      {
        "'STRING": {
          "reductions": [
            [
              5637,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 127
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              35,
              9
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "check-block": {
          "push": 128
        },
        "good-check-block": {
          "push": 129
        },
        "bad-check-block": {
          "push": 130
        },
        "good-check-block_I0_star": {
          "push": 131
        },
        "good-check-block_I0": {
          "push": 132
        },
        "let-expr": {
          "push": 133
        },
        "check-test": {
          "push": 14
        },
        "bad-check-block_I0_plus": {
          "push": 134
        },
        "bad-check-block_I0": {
          "push": 135
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36
        },
        "'EXAMPLES": {
          "push": 37
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39
        },
        "'DATA": {
          "push": 40
        },
        "'DATATYPE": {
          "push": 41
        },
        "'VAR": {
          "push": 42
        },
        "'GRAPH": {
          "push": 43
        },
        "'WHEN": {
          "push": 44
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              5961,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 136
        }
      },
      {
        "'NAME": {
          "push": 137
        }
      },
      {
        "toplevel-binding": {
          "push": 138
        },
        "binding": {
          "push": 96
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 99
        },
        "toplevel-binding_A1_I0_opt": {
          "push": 100
        },
        "toplevel-binding_A1_I0": {
          "push": 101
        },
        "'NAME": {
          "reductions": [
            [
              70,
              13
            ],
            [
              62,
              11
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 139
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "graph-expr_I1_star": {
          "push": 140
        },
        "graph-expr_I1": {
          "push": 141
        },
        "$": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ],
            [
              58,
              10
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6088,
              78
            ],
            [
              198,
              43
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 142
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'COLON": {
          "push": 143,
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'LANGLE": {
          "push": 144,
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'LT": {
          "push": 145,
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 146,
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "app-args": {
          "push": 147
        },
        "'CARET": {
          "push": 148,
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'DOT": {
          "push": 149,
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "inst-expr_I1": {
          "push": 150
        },
        "'BANG": {
          "push": 151,
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6252,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6756,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6798,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6840,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6882,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6924,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              6966,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7008,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7050,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7092,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7134,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7176,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7218,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7260,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7302,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7344,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7386,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7428,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7470,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7512,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7554,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7596,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7638,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7680,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7722,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7764,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7806,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7848,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7890,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7932,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              7974,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8016,
              0
            ]
          ]
        }
      },
      {
        "args": {
          "push": 152
        },
        "args_I0": {
          "push": 153
        },
        "'PARENSPACE": {
          "push": 154
        },
        "'PARENNOSPACE": {
          "push": 155
        }
      },
      {
        "'NAME": {
          "push": 156,
          "reductions": [
            [
              271,
              48
            ]
          ]
        },
        "'MUTABLE": {
          "push": 157,
          "reductions": [
            [
              271,
              48
            ]
          ]
        },
        "obj-fields": {
          "push": 158
        },
        "'RBRACE": {
          "push": 159
        },
        "obj-fields_I0_star": {
          "push": 160
        },
        "obj-field": {
          "push": 161
        },
        "obj-fields_I0": {
          "push": 162
        },
        "list-obj-field": {
          "push": 163
        },
        "key": {
          "push": 164
        },
        "'LBRACK": {
          "push": 165,
          "reductions": [
            [
              271,
              48
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "binop-expr": {
          "push": 166
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'FUN": {
          "push": 125,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "list-elt": {
          "push": 167
        },
        "list-expr_I1_opt": {
          "push": 168
        },
        "list-expr_I1": {
          "push": 169
        },
        "list-expr_I1_I0_star": {
          "push": 170
        },
        "list-expr_I1_I0": {
          "push": 171
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              301,
              54
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              298,
              53
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 172
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'BAR": {
          "push": 173,
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "if-pipe-expr_I1_star": {
          "push": 174
        },
        "if-pipe-expr_I1": {
          "push": 175
        },
        "if-pipe-branch": {
          "push": 176
        },
        "$": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              8437,
              81
            ],
            [
              320,
              57
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 177
        },
        "'PARENNOSPACE": {
          "push": 178
        },
        "cases-expr_I1": {
          "push": 179
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 180
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 182
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 189
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9127,
              0
            ]
          ]
        }
      },
      {
        "prelude_I1_star": {
          "push": 190
        },
        "prelude_I1": {
          "push": 87
        },
        "import-stmt": {
          "push": 88
        },
        "'IMPORT": {
          "push": 89
        },
        "$": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9159,
              7
            ],
            [
              12,
              7
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9191,
              0
            ]
          ]
        }
      },
      {
        "import-stmt_I1": {
          "push": 191
        },
        "'NAME": {
          "push": 192
        },
        "import-name": {
          "push": 193
        },
        "import-string": {
          "push": 194
        },
        "'STRING": {
          "push": 195
        }
      },
      {
        "end": {
          "push": 196
        },
        "'END": {
          "push": 197
        },
        "'SEMI": {
          "push": 198
        },
        "$": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9261,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              9402,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              9696,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              377,
              67
            ]
          ]
        },
        "ann": {
          "push": 200
        },
        "noparen-arrow-ann": {
          "push": 201
        },
        "contract-stmt_I2": {
          "push": 202
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              377,
              67
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              377,
              67
            ]
          ]
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              377,
              67
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "noparen-arrow-ann_I0_opt": {
          "push": 212
        },
        "noparen-arrow-ann_I0": {
          "push": 213
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 214
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 215
        },
        "arrow-ann-elt": {
          "push": 216
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        },
        "'THINARROW": {
          "reductions": [
            [
              374,
              66
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 219
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'EQUALS": {
          "push": 220
        }
      },
      {
        "'EQUALS": {
          "reductions": [
            [
              10353,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 221
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10357,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10359,
              0
            ],
            [
              10360,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 222
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10365,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 223
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10399,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10419,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10439,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              10459,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              10459,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              10461,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              10461,
              0
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 106
        },
        "var-expr": {
          "push": 107
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "let-binding": {
          "push": 224
        },
        "'VAR": {
          "push": 42
        },
        "'NAME": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 225
        }
      },
      {
        "let-expr": {
          "push": 106
        },
        "var-expr": {
          "push": 107
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              10515,
              14
            ],
            [
              74,
              14
            ]
          ]
        },
        "multi-let-expr_I1_star": {
          "push": 226
        },
        "let-binding": {
          "push": 109
        },
        "multi-let-expr_I1": {
          "push": 110
        },
        "let-binding-elt": {
          "push": 111
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              10515,
              14
            ],
            [
              74,
              14
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              10515,
              14
            ],
            [
              74,
              14
            ],
            [
              58,
              10
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10515,
              14
            ],
            [
              74,
              14
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10520,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              10520,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10520,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              10520,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 227
        }
      },
      {
        "let-expr": {
          "push": 228
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "'NAME": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 112
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              10572,
              15
            ],
            [
              81,
              15
            ]
          ]
        },
        "letrec-expr_I1_star": {
          "push": 229
        },
        "letrec-expr_I1": {
          "push": 114
        },
        "letrec-binding": {
          "push": 115
        },
        "'NAME": {
          "reductions": [
            [
              10572,
              15
            ],
            [
              81,
              15
            ],
            [
              58,
              10
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10572,
              15
            ],
            [
              81,
              15
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10576,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              10576,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10576,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 230
        },
        "maybe-colon": {
          "push": 231
        },
        "'NAME": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              90,
              16
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 232
        },
        "args": {
          "push": 233
        },
        "args_I0": {
          "push": 153
        },
        "'PARENSPACE": {
          "push": 154
        },
        "'PARENNOSPACE": {
          "push": 155
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10749,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10749,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10749,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              10749,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              10749,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10753,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10753,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10753,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              10753,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              10753,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 234,
          "reductions": [
            [
              98,
              19
            ]
          ]
        },
        "ty-params_I0_I1_star": {
          "push": 235
        },
        "ty-params_I0_I1": {
          "push": 236
        },
        "list-ty-param": {
          "push": 237
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10765,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10767,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4484,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 238
        }
      },
      {
        "ty-params": {
          "push": 239
        },
        "ty-params_I0_opt": {
          "push": 118
        },
        "ty-params_I0": {
          "push": 119
        },
        "ty-params_I0_I0": {
          "push": 120
        },
        "'LANGLE": {
          "push": 121
        },
        "'LT": {
          "push": 122
        },
        "'PARENSPACE": {
          "reductions": [
            [
              92,
              17
            ],
            [
              93,
              18
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              92,
              17
            ],
            [
              93,
              18
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 240
        }
      },
      {
        "$": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10912,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 241
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10946,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              10978,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11012,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "good-check-block_I1_plus": {
          "push": 242
        },
        "good-check-block_I1": {
          "push": 243
        },
        "check-test": {
          "push": 244
        },
        "binop-expr": {
          "push": 25
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "good-check-block_I0_star": {
          "push": 245
        },
        "good-check-block_I0": {
          "push": 132
        },
        "let-expr": {
          "push": 246
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "'NAME": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11179,
              9
            ],
            [
              35,
              9
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              4630,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11199,
              0
            ],
            [
              4630,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11221,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 127
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              11255,
              0
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "let-expr": {
          "push": 13
        },
        "check-test": {
          "push": 14
        },
        "bad-check-block_I0_plus": {
          "push": 247
        },
        "bad-check-block_I0": {
          "push": 135
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11255,
              0
            ],
            [
              58,
              10
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11255,
              0
            ]
          ]
        }
      },
      {
        "ty-params": {
          "push": 248
        },
        "ty-params_I0_opt": {
          "push": 118
        },
        "ty-params_I0": {
          "push": 119
        },
        "ty-params_I0_I0": {
          "push": 120
        },
        "'LANGLE": {
          "push": 121
        },
        "'LT": {
          "push": 122
        },
        "'COLON": {
          "reductions": [
            [
              92,
              17
            ],
            [
              93,
              18
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              92,
              17
            ],
            [
              93,
              18
            ]
          ]
        }
      },
      {
        "ty-params": {
          "push": 249
        },
        "ty-params_I0_opt": {
          "push": 118
        },
        "ty-params_I0": {
          "push": 119
        },
        "ty-params_I0_I0": {
          "push": 120
        },
        "'LANGLE": {
          "push": 121
        },
        "'LT": {
          "push": 122
        },
        "'COLON": {
          "reductions": [
            [
              92,
              17
            ],
            [
              93,
              18
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "push": 250
        }
      },
      {
        "$": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11427,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 251
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11461,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "let-expr": {
          "push": 139
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "graph-expr_I1_star": {
          "push": 252
        },
        "graph-expr_I1": {
          "push": 141
        },
        "$": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ],
            [
              58,
              10
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11493,
              43
            ],
            [
              198,
              43
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 253
        }
      },
      {
        "'NAME": {
          "push": 254
        },
        "'LBRACK": {
          "push": 255
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11644,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11644,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11644,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11644,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11649,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11649,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11649,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11649,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "binop-expr": {
          "push": 256
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'FUN": {
          "push": 125,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "app-args_I1_opt": {
          "push": 257
        },
        "app-args_I1": {
          "push": 258
        },
        "app-args_I1_I0_star": {
          "push": 259
        },
        "app-args_I1_I0": {
          "push": 260
        },
        "app-arg-elt": {
          "push": 261
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              246,
              44
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11775,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "id-expr": {
          "push": 262
        },
        "left-app-fun-expr": {
          "push": 263
        }
      },
      {
        "'NAME": {
          "push": 264
        },
        "'LBRACE": {
          "push": 265
        },
        "'LBRACK": {
          "push": 266
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              262,
              47
            ]
          ]
        },
        "ann": {
          "push": 267
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              262,
              47
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              262,
              47
            ]
          ]
        },
        "inst-expr_I2_star": {
          "push": 268
        },
        "inst-expr_I2": {
          "push": 269
        },
        "inst-elt": {
          "push": 270
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              262,
              47
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "push": 271
        },
        "'LBRACE": {
          "push": 272
        }
      },
      {
        "return-ann": {
          "push": 273
        },
        "return-ann_I0_opt": {
          "push": 274
        },
        "return-ann_I0": {
          "push": 275
        },
        "'THINARROW": {
          "push": 276
        },
        "'COLON": {
          "reductions": [
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 277
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 278,
          "reductions": [
            [
              110,
              21
            ]
          ]
        },
        "args_I1_opt": {
          "push": 279
        },
        "args_I1": {
          "push": 280
        },
        "args_I1_I0_star": {
          "push": 281
        },
        "args_I1_I0": {
          "push": 282
        },
        "list-arg-elt": {
          "push": 283
        },
        "'NAME": {
          "reductions": [
            [
              110,
              21
            ],
            [
              62,
              11
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              107,
              20
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12192,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12192,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12192,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12196,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12196,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12196,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "reductions": [
            [
              12200,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12200,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12200,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12200,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 156
        },
        "key": {
          "push": 284
        },
        "'LBRACK": {
          "push": 165
        }
      },
      {
        "'RBRACE": {
          "push": 285
        }
      },
      {
        "$": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12250,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 156
        },
        "'MUTABLE": {
          "push": 157
        },
        "obj-field": {
          "push": 286
        },
        "key": {
          "push": 164
        },
        "'LBRACK": {
          "push": 165
        }
      },
      {
        "'COMMA": {
          "push": 287
        }
      },
      {
        "'NAME": {
          "push": 156,
          "reductions": [
            [
              12301,
              48
            ],
            [
              271,
              48
            ]
          ]
        },
        "'MUTABLE": {
          "push": 157,
          "reductions": [
            [
              12301,
              48
            ],
            [
              271,
              48
            ]
          ]
        },
        "obj-fields_I0_star": {
          "push": 288
        },
        "obj-field": {
          "push": 161
        },
        "obj-fields_I0": {
          "push": 162
        },
        "list-obj-field": {
          "push": 163
        },
        "key": {
          "push": 164
        },
        "'LBRACK": {
          "push": 165,
          "reductions": [
            [
              12301,
              48
            ],
            [
              271,
              48
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12305,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              12305,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12305,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 289
        },
        "args": {
          "push": 290
        },
        "args_I0": {
          "push": 153
        },
        "'PARENSPACE": {
          "push": 154
        },
        "'PARENNOSPACE": {
          "push": 155
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 291
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'COMMA": {
          "push": 292
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12452,
              0
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "push": 293
        }
      },
      {
        "'RBRACK": {
          "reductions": [
            [
              12514,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 294
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'NAME": {
          "push": 123,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "binop-expr": {
          "push": 166
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'FUN": {
          "push": 125,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "list-elt": {
          "push": 167
        },
        "list-expr_I1_I0_star": {
          "push": 295
        },
        "list-expr_I1_I0": {
          "push": 171
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              12518,
              54
            ],
            [
              301,
              54
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 296
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 297
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'BAR": {
          "push": 298,
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "if-pipe-expr_I2_opt": {
          "push": 299
        },
        "if-pipe-expr_I2": {
          "push": 300
        },
        "$": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12759,
              82
            ],
            [
              323,
              58
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 173,
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "if-pipe-expr_I1_star": {
          "push": 301
        },
        "if-pipe-expr_I1": {
          "push": 175
        },
        "if-pipe-branch": {
          "push": 176
        },
        "$": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12930,
              57
            ],
            [
              320,
              57
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              12975,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13020,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13020,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13020,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13020,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13025,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13025,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13025,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13025,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 302
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'COLON": {
          "push": 143
        },
        "'LANGLE": {
          "push": 144
        },
        "'LT": {
          "push": 145
        },
        "'PARENNOSPACE": {
          "push": 303
        },
        "app-args": {
          "push": 147
        },
        "'CARET": {
          "push": 148
        },
        "'DOT": {
          "push": 149
        },
        "inst-expr_I1": {
          "push": 150
        },
        "'BANG": {
          "push": 151
        }
      },
      {
        "stmt": {
          "push": 304
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12
        },
        "bad-block_I1_plus": {
          "push": 305
        },
        "bad-block_I1": {
          "push": 306
        },
        "let-expr": {
          "push": 13
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 32
        },
        "'PARENSPACE": {
          "push": 33
        },
        "'EXAMPLESCOLON": {
          "push": 34
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36
        },
        "'EXAMPLES": {
          "push": 37
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39
        },
        "'DATA": {
          "push": 40
        },
        "'DATATYPE": {
          "push": 41
        },
        "'VAR": {
          "push": 42
        },
        "'GRAPH": {
          "push": 43
        },
        "'WHEN": {
          "push": 44
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'EXCEPT": {
          "push": 307
        }
      },
      {
        "$": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13288,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13290,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 308
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12
        },
        "let-expr": {
          "push": 13
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 32
        },
        "'PARENSPACE": {
          "push": 33
        },
        "'EXAMPLESCOLON": {
          "push": 34
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36
        },
        "'EXAMPLES": {
          "push": 37
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39
        },
        "'DATA": {
          "push": 40
        },
        "'DATATYPE": {
          "push": 41
        },
        "'VAR": {
          "push": 42
        },
        "'GRAPH": {
          "push": 43
        },
        "'WHEN": {
          "push": 44
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "good-block_I0_star": {
          "push": 309
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 310
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13294,
              8
            ],
            [
              25,
              8
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13325,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              4630,
              0
            ],
            [
              13356,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 311
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13773,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13974,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "push": 312
        }
      },
      {
        "'AS": {
          "reductions": [
            [
              14039,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "reductions": [
            [
              14041,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "reductions": [
            [
              14043,
              0
            ]
          ]
        }
      },
      {
        "'AS": {
          "reductions": [
            [
              14045,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14047,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14080,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14113,
              0
            ]
          ]
        }
      },
      {
        "'DOT": {
          "push": 313,
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              14146,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 314,
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'PERCENT": {
          "push": 315
        },
        "$": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14218,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14289,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14321,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14353,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14353,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14353,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14353,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14353,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14359,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14359,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14359,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14359,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14359,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 316,
          "reductions": [
            [
              366,
              65
            ]
          ]
        },
        "'RBRACE": {
          "push": 317,
          "reductions": [
            [
              363,
              64
            ]
          ]
        },
        "record-ann_A0_I1_opt": {
          "push": 318
        },
        "record-ann_A0_I1": {
          "push": 319
        },
        "record-ann_A0_I1_I0_star": {
          "push": 320
        },
        "ann-field": {
          "push": 321
        },
        "record-ann_A0_I1_I0": {
          "push": 322
        },
        "list-ann-field": {
          "push": 323
        }
      },
      {
        "$": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14442,
              0
            ],
            [
              14443,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14442,
              0
            ],
            [
              14443,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              14442,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              14479,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              14513,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              14547,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              14581,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14615,
              0
            ],
            [
              14616,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14615,
              0
            ],
            [
              14616,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              14615,
              0
            ]
          ]
        }
      },
      {
        "'THINARROW": {
          "push": 324
        }
      },
      {
        "'THINARROW": {
          "reductions": [
            [
              14684,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 325
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              14701,
              67
            ],
            [
              377,
              67
            ]
          ]
        },
        "ann": {
          "push": 326
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              14701,
              67
            ],
            [
              377,
              67
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              14701,
              67
            ],
            [
              377,
              67
            ]
          ]
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              14701,
              67
            ],
            [
              377,
              67
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 327
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 215
        },
        "arrow-ann-elt": {
          "push": 216
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14706,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14706,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14706,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14706,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              386,
              69
            ]
          ]
        },
        "ann": {
          "push": 326
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              386,
              69
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              386,
              69
            ]
          ]
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              386,
              69
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann-elt": {
          "push": 328
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "arrow-ann_I1_opt": {
          "push": 329
        },
        "arrow-ann_I1": {
          "push": 330
        },
        "arrow-ann_I1_I0_star": {
          "push": 331
        },
        "arrow-ann_I1_I0": {
          "push": 332
        },
        "app-ann_I0": {
          "push": 218
        },
        "'THINARROW": {
          "reductions": [
            [
              383,
              68
            ]
          ]
        }
      },
      {
        "'LANGLE": {
          "push": 333
        },
        "'LT": {
          "push": 334
        },
        "app-ann_I1": {
          "push": 335
        }
      },
      {
        "$": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14802,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 336
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "binding_I2_opt": {
          "push": 337
        },
        "binding_I2": {
          "push": 338
        },
        "'COLONCOLON": {
          "push": 339
        },
        "'NAME": {
          "reductions": [
            [
              14866,
              12
            ],
            [
              65,
              12
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              14866,
              12
            ],
            [
              65,
              12
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14866,
              12
            ],
            [
              65,
              12
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14866,
              12
            ],
            [
              65,
              12
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14866,
              12
            ],
            [
              65,
              12
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              14866,
              12
            ],
            [
              65,
              12
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 340
        }
      },
      {
        "$": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              14873,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 341
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14951,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14951,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14951,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14951,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14956,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14956,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14956,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              14956,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              14961,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              14961,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              14961,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 342
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15007,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15007,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15007,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15011,
              0
            ]
          ]
        }
      },
      {
        "doc-string": {
          "push": 343
        },
        "doc-string_I0_opt": {
          "push": 344
        },
        "doc-string_I0": {
          "push": 345
        },
        "'DOC": {
          "push": 346
        },
        "'NAME": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        }
      },
      {
        "args": {
          "push": 347
        },
        "args_I0": {
          "push": 153
        },
        "'PARENSPACE": {
          "push": 154
        },
        "'PARENNOSPACE": {
          "push": 155
        }
      },
      {
        "return-ann": {
          "push": 348
        },
        "return-ann_I0_opt": {
          "push": 274
        },
        "return-ann_I0": {
          "push": 275
        },
        "'THINARROW": {
          "push": 276
        },
        "'COLON": {
          "reductions": [
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 349
        }
      },
      {
        "'NAME": {
          "push": 350
        }
      },
      {
        "'NAME": {
          "push": 234,
          "reductions": [
            [
              15307,
              19
            ],
            [
              98,
              19
            ]
          ]
        },
        "ty-params_I0_I1_star": {
          "push": 351
        },
        "ty-params_I0_I1": {
          "push": 236
        },
        "list-ty-param": {
          "push": 237
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15309,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15311,
              0
            ]
          ]
        }
      },
      {
        "args": {
          "push": 233
        },
        "args_I0": {
          "push": 153
        },
        "'PARENSPACE": {
          "push": 154
        },
        "'PARENNOSPACE": {
          "push": 155
        }
      },
      {
        "stmt": {
          "push": 127
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              35,
              9
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "check-block": {
          "push": 352
        },
        "good-check-block": {
          "push": 129
        },
        "bad-check-block": {
          "push": 130
        },
        "good-check-block_I0_star": {
          "push": 131
        },
        "good-check-block_I0": {
          "push": 132
        },
        "let-expr": {
          "push": 133
        },
        "check-test": {
          "push": 14
        },
        "bad-check-block_I0_plus": {
          "push": 134
        },
        "bad-check-block_I0": {
          "push": 135
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36
        },
        "'EXAMPLES": {
          "push": 37
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39
        },
        "'DATA": {
          "push": 40
        },
        "'DATATYPE": {
          "push": 41
        },
        "'VAR": {
          "push": 42
        },
        "'GRAPH": {
          "push": 43
        },
        "'WHEN": {
          "push": 44
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15386,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15418,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "good-check-block_I1_plus": {
          "push": 353
        },
        "good-check-block_I1": {
          "push": 243
        },
        "check-test": {
          "push": 244
        },
        "binop-expr": {
          "push": 25
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'FUN": {
          "push": 125,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15452,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15520,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15554,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              11199,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15574,
              0
            ]
          ]
        }
      },
      {
        "data-mixins": {
          "push": 354
        },
        "data-mixins_I0_opt": {
          "push": 355
        },
        "data-mixins_I0": {
          "push": 356
        },
        "'DERIVING": {
          "push": 357
        },
        "'COLON": {
          "reductions": [
            [
              145,
              31
            ],
            [
              146,
              32
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 358
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 359
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "$": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15714,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15746,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 360
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15812,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 361
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'COMMA": {
          "push": 362
        },
        "app-arg-elt_I1_opt": {
          "push": 363
        },
        "app-arg-elt_I1": {
          "push": 364
        },
        "'NAME": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              15896,
              46
            ],
            [
              253,
              46
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 365
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              16015,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 366
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'NAME": {
          "push": 123,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "binop-expr": {
          "push": 256
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'FUN": {
          "push": 125,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "app-args_I1_I0_star": {
          "push": 367
        },
        "app-args_I1_I0": {
          "push": 260
        },
        "app-arg-elt": {
          "push": 261
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              16019,
              45
            ],
            [
              249,
              45
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16039,
              0
            ]
          ]
        }
      },
      {
        "'DOT": {
          "push": 368
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16059,
              0
            ]
          ]
        }
      },
      {
        "'PARENNOSPACE": {
          "push": 146
        },
        "app-args": {
          "push": 369
        }
      },
      {
        "$": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16105,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 156,
          "reductions": [
            [
              285,
              51
            ]
          ]
        },
        "fields": {
          "push": 370
        },
        "key": {
          "push": 371
        },
        "fields_I0_star": {
          "push": 372
        },
        "field": {
          "push": 373
        },
        "fields_I0": {
          "push": 374
        },
        "list-field": {
          "push": 375
        },
        "'LBRACK": {
          "push": 165,
          "reductions": [
            [
              285,
              51
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 376
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'COMMA": {
          "push": 377
        },
        "'PERCENT": {
          "push": 315
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 378
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              16315,
              47
            ],
            [
              262,
              47
            ]
          ]
        },
        "ann": {
          "push": 267
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              16315,
              47
            ],
            [
              262,
              47
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              16315,
              47
            ],
            [
              262,
              47
            ]
          ]
        },
        "inst-expr_I2_star": {
          "push": 379
        },
        "inst-expr_I2": {
          "push": 269
        },
        "inst-elt": {
          "push": 270
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              16315,
              47
            ],
            [
              262,
              47
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16320,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16320,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16320,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16320,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16325,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 156,
          "reductions": [
            [
              285,
              51
            ]
          ]
        },
        "fields": {
          "push": 380
        },
        "key": {
          "push": 371
        },
        "fields_I0_star": {
          "push": 372
        },
        "field": {
          "push": 373
        },
        "fields_I0": {
          "push": 374
        },
        "list-field": {
          "push": 375
        },
        "'LBRACK": {
          "push": 165,
          "reductions": [
            [
              285,
              51
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 381
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16451,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16453,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 382
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'COMMA": {
          "push": 383
        },
        "list-arg-elt_I1_opt": {
          "push": 384
        },
        "list-arg-elt_I1": {
          "push": 385
        },
        "'NAME": {
          "reductions": [
            [
              16470,
              22
            ],
            [
              114,
              22
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16470,
              22
            ],
            [
              114,
              22
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              10360,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 386
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              16485,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 387
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 278
        },
        "'NAME": {
          "reductions": [
            [
              62,
              11
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 277
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 278,
          "reductions": [
            [
              16490,
              21
            ],
            [
              110,
              21
            ]
          ]
        },
        "args_I1_I0_star": {
          "push": 388
        },
        "args_I1_I0": {
          "push": 282
        },
        "list-arg-elt": {
          "push": 283
        },
        "'NAME": {
          "reductions": [
            [
              16490,
              21
            ],
            [
              110,
              21
            ],
            [
              62,
              11
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16493,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16493,
              0
            ]
          ]
        }
      },
      {
        "'COLONCOLON": {
          "push": 389
        },
        "obj-field_A1_I2_opt": {
          "push": 390
        },
        "obj-field_A1_I2": {
          "push": 391
        },
        "'COLON": {
          "reductions": [
            [
              280,
              50
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16503,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 392
        },
        "obj-fields_I2_opt": {
          "push": 393
        },
        "obj-fields_I2": {
          "push": 394
        },
        "'RBRACE": {
          "reductions": [
            [
              16546,
              49
            ],
            [
              274,
              49
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16553,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              16553,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16553,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16557,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              16557,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16557,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 395
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "return-ann": {
          "push": 396
        },
        "return-ann_I0_opt": {
          "push": 274
        },
        "return-ann_I0": {
          "push": 275
        },
        "'THINARROW": {
          "push": 276
        },
        "'COLON": {
          "reductions": [
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "push": 397
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16638,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16658,
              0
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "reductions": [
            [
              16700,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              16702,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 398
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "if-pipe-branch_I2": {
          "push": 399
        },
        "'THENCOLON": {
          "push": 400
        },
        "'THEN": {
          "push": 401
        }
      },
      {
        "'ELSECOLON": {
          "push": 402
        }
      },
      {
        "end": {
          "push": 403
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17059,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17101,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17145,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 404
        },
        "'PERCENT": {
          "push": 315
        }
      },
      {
        "'NAME": {
          "push": 123,
          "reductions": [
            [
              348,
              63
            ],
            [
              249,
              45
            ],
            [
              62,
              11
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "binop-expr": {
          "push": 256
        },
        "binding": {
          "push": 405
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 278,
          "reductions": [
            [
              348,
              63
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'FUN": {
          "push": 125,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "app-args_I1_opt": {
          "push": 257
        },
        "app-args_I1": {
          "push": 258
        },
        "app-args_I1_I0_star": {
          "push": 259
        },
        "app-args_I1_I0": {
          "push": 260
        },
        "app-arg-elt": {
          "push": 261
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "for-bind": {
          "push": 406
        },
        "for-bind-elt": {
          "push": 407
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "for-expr_I3_opt": {
          "push": 408
        },
        "for-expr_I3": {
          "push": 409
        },
        "for-expr_I3_I0_star": {
          "push": 410
        },
        "for-expr_I3_I0": {
          "push": 411
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              249,
              45
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              345,
              62
            ],
            [
              246,
              44
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17300,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17336,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 304
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              17338,
              0
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "bad-block_I1_plus": {
          "push": 412
        },
        "bad-block_I1": {
          "push": 306
        },
        "let-expr": {
          "push": 13
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17338,
              0
            ],
            [
              58,
              10
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17338,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 413
        },
        "'PARENNOSPACE": {
          "push": 414
        },
        "try-expr_I3": {
          "push": 415
        }
      },
      {
        "$": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17483,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17485,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              13356,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17516,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 416
        }
      },
      {
        "'NAME": {
          "push": 417
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17647,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17647,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17647,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17647,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 418
        },
        "'PARENNOSPACE": {
          "push": 419
        },
        "pred-ann_I2": {
          "push": 420
        }
      },
      {
        "'COLONCOLON": {
          "push": 421
        },
        "'COLON": {
          "push": 422
        }
      },
      {
        "$": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              17728,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "push": 423
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              17796,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 316
        },
        "ann-field": {
          "push": 424
        }
      },
      {
        "'COMMA": {
          "push": 425
        }
      },
      {
        "'NAME": {
          "push": 316,
          "reductions": [
            [
              17804,
              65
            ],
            [
              366,
              65
            ]
          ]
        },
        "record-ann_A0_I1_I0_star": {
          "push": 426
        },
        "ann-field": {
          "push": 321
        },
        "record-ann_A0_I1_I0": {
          "push": 322
        },
        "list-ann-field": {
          "push": 323
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17806,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 427
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'PERCENT": {
          "push": 315
        },
        "'THINARROW": {
          "reductions": [
            [
              17842,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 314
        },
        "'PERCENT": {
          "push": 315
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17855,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17855,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17855,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17855,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17860,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17860,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17860,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17860,
              0
            ]
          ]
        }
      },
      {
        "'THINARROW": {
          "push": 428
        }
      },
      {
        "'THINARROW": {
          "reductions": [
            [
              17899,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 429
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              17903,
              69
            ],
            [
              386,
              69
            ]
          ]
        },
        "ann": {
          "push": 326
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              17903,
              69
            ],
            [
              386,
              69
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              17903,
              69
            ],
            [
              386,
              69
            ]
          ]
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              17903,
              69
            ],
            [
              386,
              69
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann-elt": {
          "push": 328
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "arrow-ann_I1_I0_star": {
          "push": 430
        },
        "arrow-ann_I1_I0": {
          "push": 332
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17908,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17908,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17908,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17908,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              17913,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17913,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17913,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17913,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              395,
              70
            ]
          ]
        },
        "ann": {
          "push": 431
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              395,
              70
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              395,
              70
            ]
          ]
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              395,
              70
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        },
        "app-ann_I2_star": {
          "push": 432
        },
        "app-ann_I2": {
          "push": 433
        },
        "app-ann-elt": {
          "push": 434
        }
      },
      {
        "$": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              17968,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18000,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              18000,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18000,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18000,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18000,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              18000,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18002,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              18002,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18002,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18002,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18002,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              18002,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 435
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              377,
              67
            ]
          ]
        },
        "ann": {
          "push": 326
        },
        "noparen-arrow-ann": {
          "push": 436
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              377,
              67
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              377,
              67
            ]
          ]
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              377,
              67
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "noparen-arrow-ann_I0_opt": {
          "push": 212
        },
        "noparen-arrow-ann_I0": {
          "push": 213
        },
        "noparen-arrow-ann_I0_I0_star": {
          "push": 214
        },
        "noparen-arrow-ann_I0_I0": {
          "push": 215
        },
        "arrow-ann-elt": {
          "push": 216
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        },
        "'THINARROW": {
          "reductions": [
            [
              374,
              66
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 437
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 438
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 439
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18142,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18173,
              0
            ]
          ]
        }
      },
      {
        "'STRING": {
          "push": 440
        }
      },
      {
        "return-ann": {
          "push": 441
        },
        "return-ann_I0_opt": {
          "push": 274
        },
        "return-ann_I0": {
          "push": 275
        },
        "'THINARROW": {
          "push": 276
        },
        "'NAME": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18235,
              23
            ],
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 442
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18465,
              0
            ]
          ]
        }
      },
      {
        "ty-params_I0_I3": {
          "push": 443
        },
        "'RANGLE": {
          "push": 444
        },
        "'GT": {
          "push": 445
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18477,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 446
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18480,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18512,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 447
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              18578,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              18580,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "binop-expr": {
          "push": 448
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'FUN": {
          "push": 125,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "mixins": {
          "push": 449
        },
        "mixins_I0_star": {
          "push": 450
        },
        "mixins_I0": {
          "push": 451
        },
        "list-mixin": {
          "push": 452
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              177,
              40
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              177,
              40
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 453,
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "datatype-expr_I4_opt": {
          "push": 454
        },
        "datatype-expr_I4": {
          "push": 455
        },
        "first-datatype-variant": {
          "push": 456
        },
        "$": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18661,
              76
            ],
            [
              182,
              41
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18868,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 457
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18900,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "push": 458
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18974,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              18994,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19014,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19034,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              19076,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19078,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 459
        }
      },
      {
        "$": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19100,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "push": 460
        }
      },
      {
        "'COLON": {
          "push": 461
        },
        "args": {
          "push": 462
        },
        "args_I0": {
          "push": 153
        },
        "'PARENSPACE": {
          "push": 154
        },
        "'PARENNOSPACE": {
          "push": 155
        }
      },
      {
        "'NAME": {
          "push": 156
        },
        "key": {
          "push": 371
        },
        "field": {
          "push": 463
        },
        "'LBRACK": {
          "push": 165
        }
      },
      {
        "'COMMA": {
          "push": 464
        }
      },
      {
        "'NAME": {
          "push": 156,
          "reductions": [
            [
              19195,
              51
            ],
            [
              285,
              51
            ]
          ]
        },
        "key": {
          "push": 371
        },
        "fields_I0_star": {
          "push": 465
        },
        "field": {
          "push": 373
        },
        "fields_I0": {
          "push": 374
        },
        "list-field": {
          "push": 375
        },
        "'LBRACK": {
          "push": 165,
          "reductions": [
            [
              19195,
              51
            ],
            [
              285,
              51
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19198,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19198,
              0
            ]
          ]
        }
      },
      {
        "'RBRACK": {
          "push": 466
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19243,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19243,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19243,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19243,
              0
            ]
          ]
        }
      },
      {
        "'RANGLE": {
          "push": 467
        },
        "'GT": {
          "push": 468
        },
        "inst-expr_I4": {
          "push": 469
        },
        "'PERCENT": {
          "push": 315
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19398,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19398,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19398,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19398,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "push": 470
        }
      },
      {
        "doc-string": {
          "push": 471
        },
        "doc-string_I0_opt": {
          "push": 344
        },
        "doc-string_I0": {
          "push": 345
        },
        "'DOC": {
          "push": 346
        },
        "'NAME": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 315
        },
        "'NAME": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19489,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19502,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19502,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19505,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19505,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19508,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19508,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'THICKARROW": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19511,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              19514,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19517,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19517,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 472
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'COLON": {
          "push": 473
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              19524,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              19526,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              19528,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              19530,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              19532,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19532,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 474
        }
      },
      {
        "'COLONCOLON": {
          "reductions": [
            [
              19536,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19536,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19536,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19536,
              0
            ]
          ]
        }
      },
      {
        "if-expr_I4_star": {
          "push": 475
        },
        "if-expr_I4": {
          "push": 476
        },
        "else-if": {
          "push": 477
        },
        "'ELSEIF": {
          "push": 478,
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19716,
              79
            ],
            [
              312,
              55
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 479
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              19991,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20022,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 480
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20097,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 481
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'FROM": {
          "push": 482
        }
      },
      {
        "'COMMA": {
          "push": 483
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20188,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20188,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 484
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              20233,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 405
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 278
        },
        "for-bind": {
          "push": 485
        },
        "'NAME": {
          "reductions": [
            [
              62,
              11
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 405
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 278,
          "reductions": [
            [
              20238,
              63
            ],
            [
              348,
              63
            ]
          ]
        },
        "for-bind": {
          "push": 406
        },
        "for-bind-elt": {
          "push": 407
        },
        "for-expr_I3_I0_star": {
          "push": 486
        },
        "for-expr_I3_I0": {
          "push": 411
        },
        "'NAME": {
          "reductions": [
            [
              20238,
              63
            ],
            [
              348,
              63
            ],
            [
              62,
              11
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20241,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20243,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20243,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20246,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20246,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 487
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 278
        },
        "'NAME": {
          "reductions": [
            [
              62,
              11
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20291,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              20324,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20360,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20380,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 488
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 489
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 490
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "$": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              20438,
              0
            ]
          ]
        }
      },
      {
        "'RBRACE": {
          "reductions": [
            [
              20474,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20476,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20478,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 315
        },
        "$": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20480,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 491
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'PERCENT": {
          "push": 315
        },
        "'THINARROW": {
          "reductions": [
            [
              20547,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20549,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20549,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20549,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20549,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 492
        },
        "'PERCENT": {
          "push": 315
        }
      },
      {
        "'NAME": {
          "push": 199
        },
        "ann": {
          "push": 493
        },
        "'PARENSPACE": {
          "push": 203
        },
        "'PARENNOSPACE": {
          "push": 204
        },
        "'LBRACE": {
          "push": 205
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        }
      },
      {
        "'NAME": {
          "push": 199,
          "reductions": [
            [
              20593,
              70
            ],
            [
              395,
              70
            ]
          ]
        },
        "ann": {
          "push": 431
        },
        "'PARENSPACE": {
          "push": 203,
          "reductions": [
            [
              20593,
              70
            ],
            [
              395,
              70
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 204,
          "reductions": [
            [
              20593,
              70
            ],
            [
              395,
              70
            ]
          ]
        },
        "'LBRACE": {
          "push": 205,
          "reductions": [
            [
              20593,
              70
            ],
            [
              395,
              70
            ]
          ]
        },
        "name-ann": {
          "push": 206
        },
        "record-ann": {
          "push": 207
        },
        "arrow-ann": {
          "push": 208
        },
        "app-ann": {
          "push": 209
        },
        "pred-ann": {
          "push": 210
        },
        "dot-ann": {
          "push": 211
        },
        "arrow-ann_I0": {
          "push": 217
        },
        "app-ann_I0": {
          "push": 218
        },
        "app-ann_I2_star": {
          "push": 494
        },
        "app-ann_I2": {
          "push": 433
        },
        "app-ann-elt": {
          "push": 434
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20598,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20598,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20598,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20598,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 315
        },
        "'NAME": {
          "reductions": [
            [
              20605,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              20605,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20605,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20605,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20605,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              20605,
              0
            ]
          ]
        }
      },
      {
        "'EQUALS": {
          "reductions": [
            [
              20618,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 495
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20621,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "end": {
          "push": 496
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20663,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 497
        },
        "where-clause_I0_opt": {
          "push": 498
        },
        "where-clause_I0": {
          "push": 499
        },
        "'WHERE": {
          "push": 500,
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 501,
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20793,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              20993,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21024,
              0
            ]
          ]
        }
      },
      {
        "doc-string": {
          "push": 502
        },
        "doc-string_I0_opt": {
          "push": 344
        },
        "doc-string_I0": {
          "push": 345
        },
        "'DOC": {
          "push": 346
        },
        "'NAME": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21205,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21205,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21205,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21205,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              21205,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21209,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21209,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21209,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21209,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              21209,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21213,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21213,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21213,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21213,
              0
            ]
          ]
        },
        "'DERIVING": {
          "reductions": [
            [
              21213,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21217,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 503,
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "data-expr_I5_opt": {
          "push": 504
        },
        "data-expr_I5": {
          "push": 505
        },
        "first-data-variant": {
          "push": 506
        },
        "$": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21249,
              73
            ],
            [
              139,
              29
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 507
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              21481,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 508
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'NAME": {
          "push": 123,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "binop-expr": {
          "push": 448
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'FUN": {
          "push": 125,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "mixins_I0_star": {
          "push": 509
        },
        "mixins_I0": {
          "push": 451
        },
        "list-mixin": {
          "push": 452
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              21485,
              40
            ],
            [
              177,
              40
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21505,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 510
        },
        "'PARENNOSPACE": {
          "push": 511
        },
        "variant-members": {
          "push": 512
        },
        "variant-members_I0": {
          "push": 513
        },
        "constructor-clause": {
          "push": 514
        },
        "'WITHCONSTRUCTOR": {
          "push": 515
        }
      },
      {
        "'BAR": {
          "push": 516,
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "datatype-expr_I5_star": {
          "push": 517
        },
        "datatype-expr_I5": {
          "push": 518
        },
        "datatype-variant": {
          "push": 519
        },
        "$": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21643,
              77
            ],
            [
              185,
              42
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21848,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21884,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21920,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21952,
              0
            ]
          ]
        }
      },
      {
        "'PARENNOSPACE": {
          "reductions": [
            [
              21994,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              21996,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 520
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "return-ann": {
          "push": 521
        },
        "return-ann_I0_opt": {
          "push": 274
        },
        "return-ann_I0": {
          "push": 275
        },
        "'THINARROW": {
          "push": 276
        },
        "'COLON": {
          "reductions": [
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 522,
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "fields_I2_opt": {
          "push": 523
        },
        "fields_I2": {
          "push": 524
        },
        "$": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22044,
              52
            ],
            [
              288,
              52
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22049,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22049,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22052,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22052,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22055,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22097,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22139,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22181,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22225,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 525
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 315
        },
        "'COLON": {
          "reductions": [
            [
              22310,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 526
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "doc-string": {
          "push": 527
        },
        "doc-string_I0_opt": {
          "push": 344
        },
        "doc-string_I0": {
          "push": 345
        },
        "'DOC": {
          "push": 346
        },
        "'NAME": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        }
      },
      {
        "if-expr_I5_opt": {
          "push": 528
        },
        "if-expr_I5": {
          "push": 529
        },
        "'ELSECOLON": {
          "push": 530,
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22316,
              80
            ],
            [
              315,
              56
            ]
          ]
        }
      },
      {
        "if-expr_I4_star": {
          "push": 531
        },
        "if-expr_I4": {
          "push": 476
        },
        "else-if": {
          "push": 477
        },
        "'ELSEIF": {
          "push": 478,
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22487,
              55
            ],
            [
              312,
              55
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22532,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 532
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "$": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22712,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              22760,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 533
        },
        "'LANGLE": {
          "push": 144
        },
        "'LT": {
          "push": 145
        },
        "'PARENNOSPACE": {
          "push": 146
        },
        "app-args": {
          "push": 147
        },
        "'CARET": {
          "push": 148
        },
        "'DOT": {
          "push": 149
        },
        "inst-expr_I1": {
          "push": 150
        },
        "'BANG": {
          "push": 151
        }
      },
      {
        "'NAME": {
          "push": 123
        },
        "'STRING": {
          "push": 12
        },
        "binop-expr": {
          "push": 534
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31
        },
        "'FUN": {
          "push": 125
        },
        "'PARENSPACE": {
          "push": 33
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73
        },
        "'RATIONAL": {
          "push": 74
        },
        "'TRUE": {
          "push": 75
        },
        "'FALSE": {
          "push": 76
        },
        "'METHOD": {
          "push": 77
        },
        "'LBRACE": {
          "push": 78
        },
        "'LBRACK": {
          "push": 79
        },
        "'IF": {
          "push": 80
        },
        "'IFCOLON": {
          "push": 81
        },
        "'CASES": {
          "push": 82
        },
        "'FOR": {
          "push": 83
        },
        "'TRY": {
          "push": 84
        },
        "'BLOCK": {
          "push": 85
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22848,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22848,
              0
            ]
          ]
        }
      },
      {
        "return-ann": {
          "push": 535
        },
        "return-ann_I0_opt": {
          "push": 274
        },
        "return-ann_I0": {
          "push": 275
        },
        "'THINARROW": {
          "push": 276
        },
        "'COLON": {
          "reductions": [
            [
              117,
              23
            ],
            [
              118,
              24
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              22894,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              22896,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              22896,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 536
        }
      },
      {
        "'RPAREN": {
          "push": 537
        }
      },
      {
        "'PERCENT": {
          "push": 315
        },
        "'COMMA": {
          "reductions": [
            [
              22975,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22975,
              0
            ]
          ]
        }
      },
      {
        "'PERCENT": {
          "push": 315
        },
        "'COMMA": {
          "reductions": [
            [
              22977,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              22977,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 538
        },
        "'PERCENT": {
          "push": 315
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23013,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23013,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23013,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23013,
              0
            ]
          ]
        }
      },
      {
        "'RANGLE": {
          "push": 539
        },
        "'GT": {
          "push": 540
        },
        "app-ann_I4": {
          "push": 541
        },
        "'PERCENT": {
          "push": 315
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23118,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23118,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23118,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23118,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23124,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23166,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 542
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23208,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23240,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23274,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23308,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 127
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              35,
              9
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "check-block": {
          "push": 543
        },
        "good-check-block": {
          "push": 129
        },
        "bad-check-block": {
          "push": 130
        },
        "good-check-block_I0_star": {
          "push": 131
        },
        "good-check-block_I0": {
          "push": 132
        },
        "let-expr": {
          "push": 133
        },
        "check-test": {
          "push": 14
        },
        "bad-check-block_I0_plus": {
          "push": 134
        },
        "bad-check-block_I0": {
          "push": 135
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36
        },
        "'EXAMPLES": {
          "push": 37
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39
        },
        "'DATA": {
          "push": 40
        },
        "'DATATYPE": {
          "push": 41
        },
        "'VAR": {
          "push": 42
        },
        "'GRAPH": {
          "push": 43
        },
        "'WHEN": {
          "push": 44
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              35,
              9
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 544
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 510,
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 511,
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "variant-members": {
          "push": 545
        },
        "data-with": {
          "push": 546
        },
        "variant-members_I0": {
          "push": 513
        },
        "data-with_I0_opt": {
          "push": 547
        },
        "data-with_I0": {
          "push": 548
        },
        "'WITH": {
          "push": 549
        },
        "$": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23419,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        }
      },
      {
        "data-expr_I6_star": {
          "push": 550
        },
        "data-expr_I6": {
          "push": 551
        },
        "data-variant": {
          "push": 552
        },
        "'BAR": {
          "push": 553,
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23673,
              74
            ],
            [
              142,
              30
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23883,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23920,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23957,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "reductions": [
            [
              23977,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              23979,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              23999,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              23999,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              23999,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              23999,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              23999,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              24005,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24005,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24005,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              24005,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              24005,
              0
            ]
          ]
        }
      },
      {
        "constructor-clause": {
          "push": 554
        },
        "'WITHCONSTRUCTOR": {
          "push": 515
        }
      },
      {
        "variant-members_I1_opt": {
          "push": 555
        },
        "variant-members_I1": {
          "push": 556
        },
        "variant-members_I1_I0_star": {
          "push": 557
        },
        "variant-member": {
          "push": 558
        },
        "variant-members_I1_I0": {
          "push": 559
        },
        "list-variant-member": {
          "push": 560
        },
        "variant-member_I0_opt": {
          "push": 561
        },
        "variant-member_I0": {
          "push": 562
        },
        "'MUTABLE": {
          "push": 563,
          "reductions": [
            [
              159,
              34
            ]
          ]
        },
        "'CYCLIC": {
          "push": 564,
          "reductions": [
            [
              159,
              34
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              159,
              34
            ],
            [
              164,
              35
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              159,
              34
            ],
            [
              164,
              35
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              156,
              33
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24077,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 565
        },
        "'PARENNOSPACE": {
          "push": 566
        },
        "constructor-clause_I1": {
          "push": 567
        }
      },
      {
        "'NAME": {
          "push": 568
        }
      },
      {
        "where-clause": {
          "push": 569
        },
        "where-clause_I0_opt": {
          "push": 498
        },
        "where-clause_I0": {
          "push": 499
        },
        "'WHERE": {
          "push": 500,
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 501,
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24223,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 516,
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "datatype-expr_I5_star": {
          "push": 570
        },
        "datatype-expr_I5": {
          "push": 518
        },
        "datatype-variant": {
          "push": 519
        },
        "$": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24255,
              42
            ],
            [
              185,
              42
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24290,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24326,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 571
        }
      },
      {
        "$": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24330,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24332,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24334,
              0
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 572
        },
        "where-clause_I0_opt": {
          "push": 498
        },
        "where-clause_I0": {
          "push": 499
        },
        "'WHERE": {
          "push": 500,
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 501,
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24336,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              24428,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24428,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 573
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "end": {
          "push": 574
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24432,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24474,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 575
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24562,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 576
        }
      },
      {
        "'NAME": {
          "push": 254,
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'BAR": {
          "push": 577,
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LBRACK": {
          "push": 255,
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "cases-expr_I6_star": {
          "push": 578
        },
        "cases-expr_I6": {
          "push": 579
        },
        "cases-branch": {
          "push": 580
        },
        "$": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24653,
              83
            ],
            [
              332,
              59
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              24871,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24871,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 581
        }
      },
      {
        "'COLON": {
          "push": 582
        }
      },
      {
        "$": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              24957,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              24991,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              25025,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              25059,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'EQUALS": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'RANGLE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'GT": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'THINARROW": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'DOC": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'FROM": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        },
        "'PERCENT": {
          "reductions": [
            [
              25093,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25127,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25159,
              0
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 583
        },
        "where-clause_I0_opt": {
          "push": 498
        },
        "where-clause_I0": {
          "push": 499
        },
        "'WHERE": {
          "push": 500,
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 501,
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25193,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        }
      },
      {
        "data-with": {
          "push": 584
        },
        "data-with_I0_opt": {
          "push": 547
        },
        "data-with_I0": {
          "push": 548
        },
        "'WITH": {
          "push": 549
        },
        "$": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25235,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25272,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25346,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25383,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 156,
          "reductions": [
            [
              285,
              51
            ]
          ]
        },
        "fields": {
          "push": 585
        },
        "key": {
          "push": 371
        },
        "fields_I0_star": {
          "push": 372
        },
        "field": {
          "push": 373
        },
        "fields_I0": {
          "push": 374
        },
        "list-field": {
          "push": 375
        },
        "'LBRACK": {
          "push": 165,
          "reductions": [
            [
              285,
              51
            ]
          ]
        }
      },
      {
        "data-sharing": {
          "push": 586
        },
        "data-sharing_I0_opt": {
          "push": 587
        },
        "data-sharing_I0": {
          "push": 588
        },
        "'SHARING": {
          "push": 589,
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25493,
              75
            ],
            [
              172,
              38
            ],
            [
              173,
              39
            ]
          ]
        }
      },
      {
        "data-expr_I6_star": {
          "push": 590
        },
        "data-expr_I6": {
          "push": 551
        },
        "data-variant": {
          "push": 552
        },
        "'BAR": {
          "push": 553,
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25661,
              30
            ],
            [
              142,
              30
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25697,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 591
        }
      },
      {
        "$": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25808,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 592
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              25846,
              0
            ]
          ]
        }
      },
      {
        "variant-member": {
          "push": 593
        },
        "variant-member_I0_opt": {
          "push": 561
        },
        "variant-member_I0": {
          "push": 562
        },
        "'MUTABLE": {
          "push": 563
        },
        "'CYCLIC": {
          "push": 564
        },
        "'NAME": {
          "reductions": [
            [
              164,
              35
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              164,
              35
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "push": 594
        }
      },
      {
        "variant-members_I1_I0_star": {
          "push": 595
        },
        "variant-member": {
          "push": 558
        },
        "variant-members_I1_I0": {
          "push": 559
        },
        "list-variant-member": {
          "push": 560
        },
        "variant-member_I0_opt": {
          "push": 561
        },
        "variant-member_I0": {
          "push": 562
        },
        "'MUTABLE": {
          "push": 563,
          "reductions": [
            [
              25856,
              34
            ],
            [
              159,
              34
            ]
          ]
        },
        "'CYCLIC": {
          "push": 564,
          "reductions": [
            [
              25856,
              34
            ],
            [
              159,
              34
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25856,
              34
            ],
            [
              159,
              34
            ],
            [
              164,
              35
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25856,
              34
            ],
            [
              159,
              34
            ],
            [
              164,
              35
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25861,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25861,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              25861,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              25861,
              0
            ]
          ]
        }
      },
      {
        "binding": {
          "push": 596
        },
        "binding_I0_opt": {
          "push": 97
        },
        "binding_I0": {
          "push": 98
        },
        "'SHADOW": {
          "push": 278
        },
        "'NAME": {
          "reductions": [
            [
              62,
              11
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25868,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25868,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25871,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25871,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25874,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25874,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25877,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              25879,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 597
        }
      },
      {
        "'PARENSPACE": {
          "push": 510
        },
        "'PARENNOSPACE": {
          "push": 511
        },
        "variant-members": {
          "push": 598
        },
        "variant-members_I0": {
          "push": 513
        },
        "constructor-clause": {
          "push": 599
        },
        "'WITHCONSTRUCTOR": {
          "push": 515
        }
      },
      {
        "end": {
          "push": 600
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              25989,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26021,
              0
            ]
          ]
        }
      },
      {
        "doc-string": {
          "push": 601
        },
        "doc-string_I0_opt": {
          "push": 344
        },
        "doc-string_I0": {
          "push": 345
        },
        "'DOC": {
          "push": 346
        },
        "'NAME": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              121,
              25
            ],
            [
              122,
              26
            ]
          ]
        }
      },
      {
        "end": {
          "push": 602
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26058,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 603
        },
        "where-clause_I0_opt": {
          "push": 498
        },
        "where-clause_I0": {
          "push": 499
        },
        "'WHERE": {
          "push": 500
        },
        "'EXAMPLESCOLON": {
          "push": 501
        },
        "'END": {
          "reductions": [
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26236,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26236,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26246,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26288,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 604
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 605
        }
      },
      {
        "'BAR": {
          "push": 606,
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "cases-expr_I7_opt": {
          "push": 607
        },
        "cases-expr_I7": {
          "push": 608
        },
        "$": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26423,
              84
            ],
            [
              335,
              60
            ]
          ]
        }
      },
      {
        "'BAR": {
          "push": 577,
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "cases-expr_I6_star": {
          "push": 609
        },
        "cases-expr_I6": {
          "push": 579
        },
        "cases-branch": {
          "push": 580
        },
        "$": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26594,
              59
            ],
            [
              332,
              59
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26639,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 610
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 611
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "end": {
          "push": 612
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26768,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26810,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26847,
              0
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 613
        },
        "where-clause_I0_opt": {
          "push": 498
        },
        "where-clause_I0": {
          "push": 499
        },
        "'WHERE": {
          "push": 500,
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 501,
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              26992,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27024,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27059,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "push": 156,
          "reductions": [
            [
              285,
              51
            ]
          ]
        },
        "fields": {
          "push": 614
        },
        "key": {
          "push": 371
        },
        "fields_I0_star": {
          "push": 372
        },
        "field": {
          "push": 373
        },
        "fields_I0": {
          "push": 374
        },
        "list-field": {
          "push": 375
        },
        "'LBRACK": {
          "push": 165,
          "reductions": [
            [
              285,
              51
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27129,
              0
            ]
          ]
        }
      },
      {
        "'PARENSPACE": {
          "push": 510,
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'PARENNOSPACE": {
          "push": 511,
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "variant-members": {
          "push": 615
        },
        "data-with": {
          "push": 616
        },
        "variant-members_I0": {
          "push": 513
        },
        "data-with_I0_opt": {
          "push": 547
        },
        "data-with_I0": {
          "push": 548
        },
        "'WITH": {
          "push": 549
        },
        "$": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27166,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'WITH": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'WITHCONSTRUCTOR": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27239,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "reductions": [
            [
              27241,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              27244,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27244,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              27244,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              27244,
              0
            ]
          ]
        }
      },
      {
        "'NAME": {
          "reductions": [
            [
              27249,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27249,
              0
            ]
          ]
        },
        "'MUTABLE": {
          "reductions": [
            [
              27249,
              0
            ]
          ]
        },
        "'CYCLIC": {
          "reductions": [
            [
              27249,
              0
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              27254,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27254,
              0
            ]
          ]
        }
      },
      {
        "'RPAREN": {
          "push": 617
        }
      },
      {
        "constructor-clause": {
          "push": 618
        },
        "'WITHCONSTRUCTOR": {
          "push": 515
        }
      },
      {
        "$": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27328,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27364,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 619
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27398,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 620
        },
        "'END": {
          "push": 197
        },
        "'SEMI": {
          "push": 198
        },
        "'COMMA": {
          "reductions": [
            [
              27440,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27440,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27456,
              0
            ]
          ]
        }
      },
      {
        "args": {
          "push": 621
        },
        "args_I0": {
          "push": 153
        },
        "'PARENSPACE": {
          "push": 154
        },
        "'PARENNOSPACE": {
          "push": 155
        },
        "cases-branch_I2_opt": {
          "push": 622
        },
        "cases-branch_I2": {
          "push": 623
        },
        "'THICKARROW": {
          "reductions": [
            [
              339,
              61
            ]
          ]
        }
      },
      {
        "'ELSE": {
          "push": 624
        }
      },
      {
        "end": {
          "push": 625
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27595,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27637,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27681,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 626
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27726,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "end": {
          "push": 627
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27768,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27810,
              0
            ]
          ]
        }
      },
      {
        "end": {
          "push": 628
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27852,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27884,
              0
            ]
          ]
        }
      },
      {
        "data-with": {
          "push": 629
        },
        "data-with_I0_opt": {
          "push": 547
        },
        "data-with_I0": {
          "push": 548
        },
        "'WITH": {
          "push": 549
        },
        "$": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27919,
              36
            ],
            [
              168,
              36
            ],
            [
              169,
              37
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              27956,
              0
            ]
          ]
        }
      },
      {
        "'COLON": {
          "push": 630
        }
      },
      {
        "$": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28029,
              0
            ]
          ]
        }
      },
      {
        "where-clause": {
          "push": 631
        },
        "where-clause_I0_opt": {
          "push": 498
        },
        "where-clause_I0": {
          "push": 499
        },
        "'WHERE": {
          "push": 500,
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 501,
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28065,
              72
            ],
            [
              125,
              27
            ],
            [
              126,
              28
            ]
          ]
        }
      },
      {
        "'COMMA": {
          "reductions": [
            [
              28067,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28067,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "reductions": [
            [
              28071,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "push": 632
        }
      },
      {
        "'THICKARROW": {
          "reductions": [
            [
              28119,
              0
            ]
          ]
        }
      },
      {
        "'THICKARROW": {
          "push": 633
        }
      },
      {
        "$": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28165,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28207,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28249,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28291,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28323,
              0
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 634
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "end": {
          "push": 635
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28396,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 636
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "stmt": {
          "push": 181
        },
        "'NAME": {
          "push": 11,
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        },
        "'STRING": {
          "push": 12,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "block": {
          "push": 637
        },
        "good-block": {
          "push": 183
        },
        "bad-block": {
          "push": 184
        },
        "good-block_I0_star": {
          "push": 185
        },
        "good-block_I0": {
          "push": 186
        },
        "block-prelude": {
          "push": 187
        },
        "let-expr": {
          "push": 188
        },
        "check-test": {
          "push": 14
        },
        "fun-expr": {
          "push": 15
        },
        "data-expr": {
          "push": 16
        },
        "datatype-expr": {
          "push": 17
        },
        "when-expr": {
          "push": 18
        },
        "var-expr": {
          "push": 19
        },
        "assign-expr": {
          "push": 20
        },
        "check-expr": {
          "push": 21
        },
        "graph-expr": {
          "push": 22
        },
        "contract-stmt": {
          "push": 23
        },
        "let-expr_I0_opt": {
          "push": 24
        },
        "binop-expr": {
          "push": 25
        },
        "let-expr_I0": {
          "push": 26
        },
        "'VAL": {
          "push": 27,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "multi-let-expr": {
          "push": 28
        },
        "'LET": {
          "push": 29,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "letrec-expr": {
          "push": 30
        },
        "'LETREC": {
          "push": 31,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FUN": {
          "push": 32,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'PARENSPACE": {
          "push": 33,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "push": 34,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A0_I0": {
          "push": 35
        },
        "'CHECK": {
          "push": 36,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'EXAMPLES": {
          "push": 37,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "check-expr_A1_I0": {
          "push": 38
        },
        "'CHECKCOLON": {
          "push": 39,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATA": {
          "push": 40,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'DATATYPE": {
          "push": 41,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'VAR": {
          "push": 42,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'GRAPH": {
          "push": 43,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'WHEN": {
          "push": 44,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "expr": {
          "push": 45
        },
        "paren-expr": {
          "push": 46
        },
        "id-expr": {
          "push": 47
        },
        "prim-expr": {
          "push": 48
        },
        "lambda-expr": {
          "push": 49
        },
        "method-expr": {
          "push": 50
        },
        "app-expr": {
          "push": 51
        },
        "left-app-expr": {
          "push": 52
        },
        "obj-expr": {
          "push": 53
        },
        "list-expr": {
          "push": 54
        },
        "dot-expr": {
          "push": 55
        },
        "bracket-expr": {
          "push": 56
        },
        "colon-expr": {
          "push": 57
        },
        "colon-bracket-expr": {
          "push": 58
        },
        "get-bang-expr": {
          "push": 59
        },
        "update-expr": {
          "push": 60
        },
        "extend-expr": {
          "push": 61
        },
        "if-expr": {
          "push": 62
        },
        "if-pipe-expr": {
          "push": 63
        },
        "cases-expr": {
          "push": 64
        },
        "for-expr": {
          "push": 65
        },
        "try-expr": {
          "push": 66
        },
        "user-block-expr": {
          "push": 67
        },
        "inst-expr": {
          "push": 68
        },
        "num-expr": {
          "push": 69
        },
        "frac-expr": {
          "push": 70
        },
        "bool-expr": {
          "push": 71
        },
        "string-expr": {
          "push": 72
        },
        "'NUMBER": {
          "push": 73,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'RATIONAL": {
          "push": 74,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRUE": {
          "push": 75,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FALSE": {
          "push": 76,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'METHOD": {
          "push": 77,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACE": {
          "push": 78,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'LBRACK": {
          "push": 79,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IF": {
          "push": 80,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'IFCOLON": {
          "push": 81,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'CASES": {
          "push": 82,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'FOR": {
          "push": 83,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'TRY": {
          "push": 84,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'BLOCK": {
          "push": 85,
          "reductions": [
            [
              25,
              8
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              25,
              8
            ],
            [
              58,
              10
            ]
          ]
        }
      },
      {
        "end": {
          "push": 638
        },
        "'END": {
          "push": 197,
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SEMI": {
          "push": 198,
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "$": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28487,
              4
            ],
            [
              7,
              4
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28535,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28537,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28582,
              0
            ]
          ]
        }
      },
      {
        "$": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'END": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'SEMI": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'IMPORT": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'NAME": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'STRING": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'VAL": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'SHADOW": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'LET": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'COLON": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'COMMA": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'LETREC": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'FUN": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'LANGLE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'LT": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'RPAREN": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'PARENSPACE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'PARENNOSPACE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'WHERE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'EXAMPLESCOLON": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'CHECK": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'EXAMPLES": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'CHECKCOLON": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'DATA": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'BAR": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'SHARING": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'DATATYPE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'VAR": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'GRAPH": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'WHEN": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'IS": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'RAISES": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'SATISFIES": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'NUMBER": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'RATIONAL": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'TRUE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'FALSE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'METHOD": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'CARET": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'DOT": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'LBRACE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'RBRACE": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'LBRACK": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'RBRACK": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'BANG": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'IF": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'ELSECOLON": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'ELSEIF": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'IFCOLON": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'THENCOLON": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'THEN": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'CASES": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'FOR": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'TRY": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'EXCEPT": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        },
        "'BLOCK": {
          "reductions": [
            [
              28626,
              0
            ]
          ]
        }
      }
    ],
    "I": {
      "ε": 0,
      "program": 1,
      "toplevel-block": 2,
      "toplevel-block_I0_star": 3,
      "end": 4,
      "prelude": 5,
      "prelude_I0_opt": 6,
      "prelude_I1_star": 7,
      "good-block_I0_star": 8,
      "good-check-block_I0_star": 9,
      "let-expr_I0_opt": 10,
      "binding_I0_opt": 11,
      "binding_I2_opt": 12,
      "toplevel-binding_A1_I0_opt": 13,
      "multi-let-expr_I1_star": 14,
      "letrec-expr_I1_star": 15,
      "maybe-colon": 16,
      "ty-params": 17,
      "ty-params_I0_opt": 18,
      "ty-params_I0_I1_star": 19,
      "args_I1_opt": 20,
      "args_I1_I0_star": 21,
      "list-arg-elt_I1_opt": 22,
      "return-ann": 23,
      "return-ann_I0_opt": 24,
      "doc-string": 25,
      "doc-string_I0_opt": 26,
      "where-clause": 27,
      "where-clause_I0_opt": 28,
      "data-expr_I5_opt": 29,
      "data-expr_I6_star": 30,
      "data-mixins": 31,
      "data-mixins_I0_opt": 32,
      "variant-members_I1_opt": 33,
      "variant-members_I1_I0_star": 34,
      "variant-member_I0_opt": 35,
      "data-with": 36,
      "data-with_I0_opt": 37,
      "data-sharing": 38,
      "data-sharing_I0_opt": 39,
      "mixins_I0_star": 40,
      "datatype-expr_I4_opt": 41,
      "datatype-expr_I5_star": 42,
      "graph-expr_I1_star": 43,
      "app-args_I1_opt": 44,
      "app-args_I1_I0_star": 45,
      "app-arg-elt_I1_opt": 46,
      "inst-expr_I2_star": 47,
      "obj-fields_I0_star": 48,
      "obj-fields_I2_opt": 49,
      "obj-field_A1_I2_opt": 50,
      "fields_I0_star": 51,
      "fields_I2_opt": 52,
      "list-expr_I1_opt": 53,
      "list-expr_I1_I0_star": 54,
      "if-expr_I4_star": 55,
      "if-expr_I5_opt": 56,
      "if-pipe-expr_I1_star": 57,
      "if-pipe-expr_I2_opt": 58,
      "cases-expr_I6_star": 59,
      "cases-expr_I7_opt": 60,
      "cases-branch_I2_opt": 61,
      "for-expr_I3_opt": 62,
      "for-expr_I3_I0_star": 63,
      "record-ann_A0_I1_opt": 64,
      "record-ann_A0_I1_I0_star": 65,
      "noparen-arrow-ann_I0_opt": 66,
      "noparen-arrow-ann_I0_I0_star": 67,
      "arrow-ann_I1_opt": 68,
      "arrow-ann_I1_I0_star": 69,
      "app-ann_I2_star": 70,
      "START": 71,
      "where-clause,end": 72,
      "data-expr_I5_opt,data-expr_I6_star,data-sharing,where-clause,end": 73,
      "data-expr_I6_star,data-sharing,where-clause,end": 74,
      "data-sharing,where-clause,end": 75,
      "datatype-expr_I4_opt,datatype-expr_I5_star,where-clause,end": 76,
      "datatype-expr_I5_star,where-clause,end": 77,
      "graph-expr_I1_star,end": 78,
      "if-expr_I4_star,if-expr_I5_opt,end": 79,
      "if-expr_I5_opt,end": 80,
      "if-pipe-expr_I1_star,if-pipe-expr_I2_opt,end": 81,
      "if-pipe-expr_I2_opt,end": 82,
      "cases-expr_I6_star,cases-expr_I7_opt,end": 83,
      "cases-expr_I7_opt,end": 84
    },
    "eSPPFs": [
      {
        "label": "EPSILON"
      },
      {
        "label": "program",
        "kids": [
          5,
          2
        ],
        "rule": 0
      },
      {
        "label": "toplevel-block",
        "kids": [
          3
        ],
        "rule": 1
      },
      {
        "label": "toplevel-block_I0_star",
        "kids": [],
        "rule": 2
      },
      {
        "label": "end",
        "kids": [],
        "rule": 7
      },
      {
        "label": "prelude",
        "kids": [
          6,
          7
        ],
        "rule": 8
      },
      {
        "label": "prelude_I0_opt",
        "kids": [],
        "rule": 9
      },
      {
        "label": "prelude_I1_star",
        "kids": [],
        "rule": 12
      },
      {
        "label": "good-block_I0_star",
        "kids": [],
        "rule": 25
      },
      {
        "label": "good-check-block_I0_star",
        "kids": [],
        "rule": 35
      },
      {
        "label": "let-expr_I0_opt",
        "kids": [],
        "rule": 58
      },
      {
        "label": "binding_I0_opt",
        "kids": [],
        "rule": 62
      },
      {
        "label": "binding_I2_opt",
        "kids": [],
        "rule": 65
      },
      {
        "label": "toplevel-binding_A1_I0_opt",
        "kids": [],
        "rule": 70
      },
      {
        "label": "multi-let-expr_I1_star",
        "kids": [],
        "rule": 74
      },
      {
        "label": "letrec-expr_I1_star",
        "kids": [],
        "rule": 81
      },
      {
        "label": "maybe-colon",
        "kids": [],
        "rule": 90
      },
      {
        "label": "ty-params",
        "kids": [
          18
        ],
        "rule": 92
      },
      {
        "label": "ty-params_I0_opt",
        "kids": [],
        "rule": 93
      },
      {
        "label": "ty-params_I0_I1_star",
        "kids": [],
        "rule": 98
      },
      {
        "label": "args_I1_opt",
        "kids": [],
        "rule": 107
      },
      {
        "label": "args_I1_I0_star",
        "kids": [],
        "rule": 110
      },
      {
        "label": "list-arg-elt_I1_opt",
        "kids": [],
        "rule": 114
      },
      {
        "label": "return-ann",
        "kids": [
          24
        ],
        "rule": 117
      },
      {
        "label": "return-ann_I0_opt",
        "kids": [],
        "rule": 118
      },
      {
        "label": "doc-string",
        "kids": [
          26
        ],
        "rule": 121
      },
      {
        "label": "doc-string_I0_opt",
        "kids": [],
        "rule": 122
      },
      {
        "label": "where-clause",
        "kids": [
          28
        ],
        "rule": 125
      },
      {
        "label": "where-clause_I0_opt",
        "kids": [],
        "rule": 126
      },
      {
        "label": "data-expr_I5_opt",
        "kids": [],
        "rule": 139
      },
      {
        "label": "data-expr_I6_star",
        "kids": [],
        "rule": 142
      },
      {
        "label": "data-mixins",
        "kids": [
          32
        ],
        "rule": 145
      },
      {
        "label": "data-mixins_I0_opt",
        "kids": [],
        "rule": 146
      },
      {
        "label": "variant-members_I1_opt",
        "kids": [],
        "rule": 156
      },
      {
        "label": "variant-members_I1_I0_star",
        "kids": [],
        "rule": 159
      },
      {
        "label": "variant-member_I0_opt",
        "kids": [],
        "rule": 164
      },
      {
        "label": "data-with",
        "kids": [
          37
        ],
        "rule": 168
      },
      {
        "label": "data-with_I0_opt",
        "kids": [],
        "rule": 169
      },
      {
        "label": "data-sharing",
        "kids": [
          39
        ],
        "rule": 172
      },
      {
        "label": "data-sharing_I0_opt",
        "kids": [],
        "rule": 173
      },
      {
        "label": "mixins_I0_star",
        "kids": [],
        "rule": 177
      },
      {
        "label": "datatype-expr_I4_opt",
        "kids": [],
        "rule": 182
      },
      {
        "label": "datatype-expr_I5_star",
        "kids": [],
        "rule": 185
      },
      {
        "label": "graph-expr_I1_star",
        "kids": [],
        "rule": 198
      },
      {
        "label": "app-args_I1_opt",
        "kids": [],
        "rule": 246
      },
      {
        "label": "app-args_I1_I0_star",
        "kids": [],
        "rule": 249
      },
      {
        "label": "app-arg-elt_I1_opt",
        "kids": [],
        "rule": 253
      },
      {
        "label": "inst-expr_I2_star",
        "kids": [],
        "rule": 262
      },
      {
        "label": "obj-fields_I0_star",
        "kids": [],
        "rule": 271
      },
      {
        "label": "obj-fields_I2_opt",
        "kids": [],
        "rule": 274
      },
      {
        "label": "obj-field_A1_I2_opt",
        "kids": [],
        "rule": 280
      },
      {
        "label": "fields_I0_star",
        "kids": [],
        "rule": 285
      },
      {
        "label": "fields_I2_opt",
        "kids": [],
        "rule": 288
      },
      {
        "label": "list-expr_I1_opt",
        "kids": [],
        "rule": 298
      },
      {
        "label": "list-expr_I1_I0_star",
        "kids": [],
        "rule": 301
      },
      {
        "label": "if-expr_I4_star",
        "kids": [],
        "rule": 312
      },
      {
        "label": "if-expr_I5_opt",
        "kids": [],
        "rule": 315
      },
      {
        "label": "if-pipe-expr_I1_star",
        "kids": [],
        "rule": 320
      },
      {
        "label": "if-pipe-expr_I2_opt",
        "kids": [],
        "rule": 323
      },
      {
        "label": "cases-expr_I6_star",
        "kids": [],
        "rule": 332
      },
      {
        "label": "cases-expr_I7_opt",
        "kids": [],
        "rule": 335
      },
      {
        "label": "cases-branch_I2_opt",
        "kids": [],
        "rule": 339
      },
      {
        "label": "for-expr_I3_opt",
        "kids": [],
        "rule": 345
      },
      {
        "label": "for-expr_I3_I0_star",
        "kids": [],
        "rule": 348
      },
      {
        "label": "record-ann_A0_I1_opt",
        "kids": [],
        "rule": 363
      },
      {
        "label": "record-ann_A0_I1_I0_star",
        "kids": [],
        "rule": 366
      },
      {
        "label": "noparen-arrow-ann_I0_opt",
        "kids": [],
        "rule": 374
      },
      {
        "label": "noparen-arrow-ann_I0_I0_star",
        "kids": [],
        "rule": 377
      },
      {
        "label": "arrow-ann_I1_opt",
        "kids": [],
        "rule": 383
      },
      {
        "label": "arrow-ann_I1_I0_star",
        "kids": [],
        "rule": 386
      },
      {
        "label": "app-ann_I2_star",
        "kids": [],
        "rule": 395
      },
      {
        "label": "START",
        "kids": [
          1
        ],
        "rule": 405
      },
      {
        "label": "where-clause,end",
        "kids": [
          27,
          4
        ]
      },
      {
        "label": "data-expr_I5_opt,data-expr_I6_star,data-sharing,where-clause,end",
        "kids": [
          29,
          30,
          38,
          27,
          4
        ]
      },
      {
        "label": "data-expr_I6_star,data-sharing,where-clause,end",
        "kids": [
          30,
          38,
          27,
          4
        ]
      },
      {
        "label": "data-sharing,where-clause,end",
        "kids": [
          38,
          27,
          4
        ]
      },
      {
        "label": "datatype-expr_I4_opt,datatype-expr_I5_star,where-clause,end",
        "kids": [
          41,
          42,
          27,
          4
        ]
      },
      {
        "label": "datatype-expr_I5_star,where-clause,end",
        "kids": [
          42,
          27,
          4
        ]
      },
      {
        "label": "graph-expr_I1_star,end",
        "kids": [
          43,
          4
        ]
      },
      {
        "label": "if-expr_I4_star,if-expr_I5_opt,end",
        "kids": [
          55,
          56,
          4
        ]
      },
      {
        "label": "if-expr_I5_opt,end",
        "kids": [
          56,
          4
        ]
      },
      {
        "label": "if-pipe-expr_I1_star,if-pipe-expr_I2_opt,end",
        "kids": [
          57,
          58,
          4
        ]
      },
      {
        "label": "if-pipe-expr_I2_opt,end",
        "kids": [
          58,
          4
        ]
      },
      {
        "label": "cases-expr_I6_star,cases-expr_I7_opt,end",
        "kids": [
          59,
          60,
          4
        ]
      },
      {
        "label": "cases-expr_I7_opt,end",
        "kids": [
          60,
          4
        ]
      }
    ]
  };
  return { BootstrapGrammar: Grammar.fromSerializable(g_json) };
});

define('trove/image-structs',["trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($arrays1819,$lists3920,$option51021,$error71122,$sets91223) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/trove/image-structs.arr18"]) {
return R.modules["$src/arr/trove/image-structs.arr18"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/trove/image-structs.arr";
var D = R.undefined;
var L = [[M,6,0,40,12,3,155],
[M,7,2,54,11,22,151],
[M,3,0,13,12,3,155],
[M,7,4,56,11,22,151],
[M,8,13,76,8,19,82],
[M,9,15,99,9,21,105],
[M,10,14,121,10,20,127],
[M,11,15,144,11,21,150],
[M,11,6,135,11,21,150],
[M,10,6,113,10,20,127],
[M,9,6,90,9,21,105],
[M,8,6,69,8,19,82]];
var _plus3 = NAMESPACE.get("_plus");
var builtins4 = NAMESPACE.get("builtins");
var nothing5 = NAMESPACE.get("nothing");
var torepr6 = NAMESPACE.get("torepr");
var $type$Number7 = NAMESPACE.get("$type$Number");
var $Hanf_bracket6024 = function(anf_bracket4125,Color6026,provides3927,nothing5) {
var anf_fun4238 = G(anf_bracket4125,"results",L[0]);
var $z3031 = D;
var $f3637 = function(_) {
return R.isFunction(anf_fun4238)?anf_fun4238.app():R.ffi.throwNonFunApp(L[0],anf_fun4238,[]);
};
try {
if(--R.GAS > 0) {
$z3031 = $f3637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3637,
"from":L[0]});
}
} catch($e2829) {
if(R.isCont($e2829)) {
var $ss3233 = {"from":L[0],
"go":function(checks4339) {
return $Hchecks5940(checks4339,Color6026,provides3927,nothing5);
}};
$e2829.stack[R.EXN_STACKHEIGHT++] = $ss3233;
}
if(R.isPyretException($e2829)) {
$e2829.pyretStack.push(L[0]);
}
throw $e2829;
}
var $ret3435 = $Hchecks5940($z3031,Color6026,provides3927,nothing5);
++R.GAS;
return $ret3435;
};
var $Hchecks5940 = function(checks4339,Color6026,provides3927,nothing5) {
return R.makeObject({"answer":nothing5,
"provide-plus-types":R.makeObject({"values":provides3927,
"types":{"Color":Color6026}}),
"checks":checks4339});
};
var $Hanf_arg5841 = function(anf_arg1842,self543,_plus3,torepr6) {
var anf_arg1954 = G(self543,"green",L[1]);
var $z4647 = D;
var $f5253 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg1954):R.ffi.throwNonFunApp(L[1],torepr6,[anf_arg1954]);
};
try {
if(--R.GAS > 0) {
$z4647 = $f5253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5253,
"from":L[1]});
}
} catch($e4445) {
if(R.isCont($e4445)) {
var $ss4849 = {"from":L[1],
"go":function(anf_arg2055) {
return $Hanf_arg5756(anf_arg2055,anf_arg1842,self543,_plus3,torepr6);
}};
$e4445.stack[R.EXN_STACKHEIGHT++] = $ss4849;
}
if(R.isPyretException($e4445)) {
$e4445.pyretStack.push(L[1]);
}
throw $e4445;
}
var $ret5051 = $Hanf_arg5756($z4647,anf_arg1842,self543,_plus3,torepr6);
++R.GAS;
return $ret5051;
};
var $Hanf_arg5756 = function(anf_arg2055,anf_arg1842,self543,_plus3,torepr6) {
var $z5960 = D;
var $f6566 = function(_) {
return R.isFunction(_plus3)?_plus3.app((", "),anf_arg2055):R.ffi.throwNonFunApp(L[1],_plus3,[(", "),anf_arg2055]);
};
try {
if(--R.GAS > 0) {
$z5960 = $f6566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6566,
"from":L[1]});
}
} catch($e5758) {
if(R.isCont($e5758)) {
var $ss6162 = {"from":L[1],
"go":function(anf_arg2167) {
return $Hanf_arg5668(anf_arg2167,anf_arg1842,self543,_plus3,torepr6);
}};
$e5758.stack[R.EXN_STACKHEIGHT++] = $ss6162;
}
if(R.isPyretException($e5758)) {
$e5758.pyretStack.push(L[1]);
}
throw $e5758;
}
var $ret6364 = $Hanf_arg5668($z5960,anf_arg1842,self543,_plus3,torepr6);
++R.GAS;
return $ret6364;
};
var $Hanf_arg5668 = function(anf_arg2167,anf_arg1842,self543,_plus3,torepr6) {
var $z7172 = D;
var $f7778 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg1842,anf_arg2167):R.ffi.throwNonFunApp(L[1],_plus3,[anf_arg1842,anf_arg2167]);
};
try {
if(--R.GAS > 0) {
$z7172 = $f7778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7778,
"from":L[1]});
}
} catch($e6970) {
if(R.isCont($e6970)) {
var $ss7374 = {"from":L[1],
"go":function(anf_arg2279) {
return $Hanf_arg5580(anf_arg2279,self543,_plus3,torepr6);
}};
$e6970.stack[R.EXN_STACKHEIGHT++] = $ss7374;
}
if(R.isPyretException($e6970)) {
$e6970.pyretStack.push(L[1]);
}
throw $e6970;
}
var $ret7576 = $Hanf_arg5580($z7172,self543,_plus3,torepr6);
++R.GAS;
return $ret7576;
};
var $Hanf_arg5580 = function(anf_arg2279,self543,_plus3,torepr6) {
var anf_arg2391 = G(self543,"blue",L[1]);
var $z8384 = D;
var $f8990 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg2391):R.ffi.throwNonFunApp(L[1],torepr6,[anf_arg2391]);
};
try {
if(--R.GAS > 0) {
$z8384 = $f8990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8990,
"from":L[1]});
}
} catch($e8182) {
if(R.isCont($e8182)) {
var $ss8586 = {"from":L[1],
"go":function(anf_arg2492) {
return $Hanf_arg5493(anf_arg2492,anf_arg2279,self543,_plus3,torepr6);
}};
$e8182.stack[R.EXN_STACKHEIGHT++] = $ss8586;
}
if(R.isPyretException($e8182)) {
$e8182.pyretStack.push(L[1]);
}
throw $e8182;
}
var $ret8788 = $Hanf_arg5493($z8384,anf_arg2279,self543,_plus3,torepr6);
++R.GAS;
return $ret8788;
};
var $Hanf_arg5493 = function(anf_arg2492,anf_arg2279,self543,_plus3,torepr6) {
var $z9697 = D;
var $f102103 = function(_) {
return R.isFunction(_plus3)?_plus3.app((", "),anf_arg2492):R.ffi.throwNonFunApp(L[1],_plus3,[(", "),anf_arg2492]);
};
try {
if(--R.GAS > 0) {
$z9697 = $f102103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f102103,
"from":L[1]});
}
} catch($e9495) {
if(R.isCont($e9495)) {
var $ss9899 = {"from":L[1],
"go":function(anf_arg25104) {
return $Hanf_arg53105(anf_arg25104,anf_arg2279,self543,_plus3,torepr6);
}};
$e9495.stack[R.EXN_STACKHEIGHT++] = $ss9899;
}
if(R.isPyretException($e9495)) {
$e9495.pyretStack.push(L[1]);
}
throw $e9495;
}
var $ret100101 = $Hanf_arg53105($z9697,anf_arg2279,self543,_plus3,torepr6);
++R.GAS;
return $ret100101;
};
var $Hanf_arg53105 = function(anf_arg25104,anf_arg2279,self543,_plus3,torepr6) {
var $z108109 = D;
var $f114115 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg2279,anf_arg25104):R.ffi.throwNonFunApp(L[1],_plus3,[anf_arg2279,anf_arg25104]);
};
try {
if(--R.GAS > 0) {
$z108109 = $f114115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f114115,
"from":L[1]});
}
} catch($e106107) {
if(R.isCont($e106107)) {
var $ss110111 = {"from":L[1],
"go":function(anf_arg26116) {
return $Hanf_arg52117(anf_arg26116,self543,_plus3,torepr6);
}};
$e106107.stack[R.EXN_STACKHEIGHT++] = $ss110111;
}
if(R.isPyretException($e106107)) {
$e106107.pyretStack.push(L[1]);
}
throw $e106107;
}
var $ret112113 = $Hanf_arg52117($z108109,self543,_plus3,torepr6);
++R.GAS;
return $ret112113;
};
var $Hanf_arg52117 = function(anf_arg26116,self543,_plus3,torepr6) {
var anf_arg27128 = G(self543,"alpha",L[1]);
var $z120121 = D;
var $f126127 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg27128):R.ffi.throwNonFunApp(L[1],torepr6,[anf_arg27128]);
};
try {
if(--R.GAS > 0) {
$z120121 = $f126127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f126127,
"from":L[1]});
}
} catch($e118119) {
if(R.isCont($e118119)) {
var $ss122123 = {"from":L[1],
"go":function(anf_arg28129) {
return $Hanf_arg51130(anf_arg28129,anf_arg26116,_plus3);
}};
$e118119.stack[R.EXN_STACKHEIGHT++] = $ss122123;
}
if(R.isPyretException($e118119)) {
$e118119.pyretStack.push(L[1]);
}
throw $e118119;
}
var $ret124125 = $Hanf_arg51130($z120121,anf_arg26116,_plus3);
++R.GAS;
return $ret124125;
};
var $Hanf_arg51130 = function(anf_arg28129,anf_arg26116,_plus3) {
var $z133134 = D;
var $f139140 = function(_) {
return R.isFunction(_plus3)?_plus3.app((", "),anf_arg28129):R.ffi.throwNonFunApp(L[1],_plus3,[(", "),anf_arg28129]);
};
try {
if(--R.GAS > 0) {
$z133134 = $f139140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f139140,
"from":L[1]});
}
} catch($e131132) {
if(R.isCont($e131132)) {
var $ss135136 = {"from":L[1],
"go":function(anf_arg29141) {
return $Hanf_arg50142(anf_arg29141,anf_arg26116,_plus3);
}};
$e131132.stack[R.EXN_STACKHEIGHT++] = $ss135136;
}
if(R.isPyretException($e131132)) {
$e131132.pyretStack.push(L[1]);
}
throw $e131132;
}
var $ret137138 = $Hanf_arg50142($z133134,anf_arg26116,_plus3);
++R.GAS;
return $ret137138;
};
var $Hanf_arg50142 = function(anf_arg29141,anf_arg26116,_plus3) {
var $z145146 = D;
var $f151152 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg26116,anf_arg29141):R.ffi.throwNonFunApp(L[1],_plus3,[anf_arg26116,anf_arg29141]);
};
try {
if(--R.GAS > 0) {
$z145146 = $f151152();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f151152,
"from":L[1]});
}
} catch($e143144) {
if(R.isCont($e143144)) {
var $ss147148 = {"from":L[1],
"go":function(anf_arg30153) {
return $Hanf_arg49154(anf_arg30153,_plus3);
}};
$e143144.stack[R.EXN_STACKHEIGHT++] = $ss147148;
}
if(R.isPyretException($e143144)) {
$e143144.pyretStack.push(L[1]);
}
throw $e143144;
}
var $ret149150 = $Hanf_arg49154($z145146,_plus3);
++R.GAS;
return $ret149150;
};
var $Hanf_arg49154 = function(anf_arg30153,_plus3) {
var $z157158 = D;
var $f163164 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg30153,(")")):R.ffi.throwNonFunApp(L[1],_plus3,[anf_arg30153,(")")]);
};
try {
if(--R.GAS > 0) {
$z157158 = $f163164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f163164,
"from":L[1]});
}
} catch($e155156) {
if(R.isCont($e155156)) {
var $ss159160 = {"from":L[1],
"go":function(anf_arg31165) {
return $Hanf_arg48166(anf_arg31165,_plus3);
}};
$e155156.stack[R.EXN_STACKHEIGHT++] = $ss159160;
}
if(R.isPyretException($e155156)) {
$e155156.pyretStack.push(L[1]);
}
throw $e155156;
}
var $ret161162 = $Hanf_arg48166($z157158,_plus3);
++R.GAS;
return $ret161162;
};
var $Hanf_arg48166 = function(anf_arg31165,_plus3) {
var $z169170 = D;
var $f175176 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("("),anf_arg31165):R.ffi.throwNonFunApp(L[1],_plus3,[("("),anf_arg31165]);
};
try {
if(--R.GAS > 0) {
$z169170 = $f175176();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f175176,
"from":L[1]});
}
} catch($e167168) {
if(R.isCont($e167168)) {
var $ss171172 = {"from":L[1],
"go":function(anf_arg32177) {
return $Hanf_arg47178(anf_arg32177,_plus3);
}};
$e167168.stack[R.EXN_STACKHEIGHT++] = $ss171172;
}
if(R.isPyretException($e167168)) {
$e167168.pyretStack.push(L[1]);
}
throw $e167168;
}
var $ret173174 = $Hanf_arg47178($z169170,_plus3);
++R.GAS;
return $ret173174;
};
var $Hanf_arg47178 = function(anf_arg32177,_plus3) {
var $z181182 = D;
var $f187188 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("color"),anf_arg32177):R.ffi.throwNonFunApp(L[1],_plus3,[("color"),anf_arg32177]);
};
try {
if(--R.GAS > 0) {
$z181182 = $f187188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f187188,
"from":L[1]});
}
} catch($e179180) {
if(R.isCont($e179180)) {
var $ss183184 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp16189) {
return $Hann_DASH_check_DASH_temp46190(ann_DASH_check_DASH_temp16189);
}};
$e179180.stack[R.EXN_STACKHEIGHT++] = $ss183184;
}
if(R.isPyretException($e179180)) {
$e179180.pyretStack.push(L[1]);
}
throw $e179180;
}
var $ret185186 = $Hann_DASH_check_DASH_temp46190($z181182);
++R.GAS;
return $ret185186;
};
var $Hann_DASH_check_DASH_temp46190 = function(ann_DASH_check_DASH_temp16189) {
return ann_DASH_check_DASH_temp16189;
};
var $Hcont_tail_arg44191 = function(cont_tail_arg13192,if_helper2193) {
if(--R.GAS > 0) {
$z194195 = R.isFunction(if_helper2193)?if_helper2193.app(cont_tail_arg13192):R.ffi.throwNonFunApp(L[1],if_helper2193,[cont_tail_arg13192]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored196) {
return R.isFunction(if_helper2193)?if_helper2193.app(cont_tail_arg13192):R.ffi.throwNonFunApp(L[1],if_helper2193,[cont_tail_arg13192]);
},
"from":L[1]});
}
++R.GAS;
return $z194195;
};
var $Hcont_tail_arg45197 = function(cont_tail_arg7198,if_helper2193) {
if(--R.GAS > 0) {
$z199200 = R.isFunction(if_helper2193)?if_helper2193.app(cont_tail_arg7198):R.ffi.throwNonFunApp(L[1],if_helper2193,[cont_tail_arg7198]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored196) {
return R.isFunction(if_helper2193)?if_helper2193.app(cont_tail_arg7198):R.ffi.throwNonFunApp(L[1],if_helper2193,[cont_tail_arg7198]);
},
"from":L[1]});
}
++R.GAS;
return $z199200;
};
return R.loadModulesNew(NAMESPACE,[$arrays1819,$lists3920,$option51021,$error71122,$sets91223],function($arrays1819,$lists3920,$option51021,$error71122,$sets91223) {
var arrays18 = R.getField($arrays1819,"values");
var lists39 = R.getField($lists3920,"values");
var option510 = R.getField($option51021,"values");
var error711 = R.getField($error71122,"values");
var sets912 = R.getField($sets91223,"values");
var arrays213 = R.getField($arrays1819,"types");
var lists414 = R.getField($lists3920,"types");
var option615 = R.getField($option51021,"types");
var error816 = R.getField($error71122,"types");
var sets1017 = R.getField($sets91223,"types");
return R.safeCall(function() {
var List11201 = R.getDotAnn(L[2],"lists",lists414,"List");
var Option12202 = R.getDotAnn(L[2],"option",option615,"Option");
var Array13203 = R.getDotAnn(L[2],"arrays",arrays213,"Array");
var Set14204 = R.getDotAnn(L[2],"sets",sets1017,"Set");
var array15328 = G(arrays18,"array",L[2]);
var build_DASH_array16327 = G(arrays18,"build-array",L[2]);
var array_DASH_from_DASH_list17326 = G(arrays18,"array-from-list",L[2]);
var is_DASH_array18325 = G(arrays18,"is-array",L[2]);
var list19324 = G(lists39,"list",L[2]);
var is_DASH_empty20323 = G(lists39,"is-empty",L[2]);
var is_DASH_link21322 = G(lists39,"is-link",L[2]);
var empty22321 = G(lists39,"empty",L[2]);
var link23320 = G(lists39,"link",L[2]);
var range24319 = G(lists39,"range",L[2]);
var repeat25318 = G(lists39,"repeat",L[2]);
var filter26317 = G(lists39,"filter",L[2]);
var partition27316 = G(lists39,"partition",L[2]);
var split_DASH_at28315 = G(lists39,"split-at",L[2]);
var any29314 = G(lists39,"any",L[2]);
var find30313 = G(lists39,"find",L[2]);
var map31312 = G(lists39,"map",L[2]);
var map232311 = G(lists39,"map2",L[2]);
var map333310 = G(lists39,"map3",L[2]);
var map434309 = G(lists39,"map4",L[2]);
var map_n35308 = G(lists39,"map_n",L[2]);
var map2_n36307 = G(lists39,"map2_n",L[2]);
var map3_n37306 = G(lists39,"map3_n",L[2]);
var map4_n38305 = G(lists39,"map4_n",L[2]);
var each39304 = G(lists39,"each",L[2]);
var each240303 = G(lists39,"each2",L[2]);
var each341302 = G(lists39,"each3",L[2]);
var each442301 = G(lists39,"each4",L[2]);
var each_n43300 = G(lists39,"each_n",L[2]);
var each2_n44299 = G(lists39,"each2_n",L[2]);
var each3_n45298 = G(lists39,"each3_n",L[2]);
var each4_n46297 = G(lists39,"each4_n",L[2]);
var fold47296 = G(lists39,"fold",L[2]);
var fold248295 = G(lists39,"fold2",L[2]);
var fold349294 = G(lists39,"fold3",L[2]);
var fold450293 = G(lists39,"fold4",L[2]);
var index51292 = G(lists39,"index",L[2]);
var Option52291 = G(option510,"Option",L[2]);
var is_DASH_none53290 = G(option510,"is-none",L[2]);
var is_DASH_some54289 = G(option510,"is-some",L[2]);
var none55288 = G(option510,"none",L[2]);
var some56287 = G(option510,"some",L[2]);
var set57286 = G(sets912,"set",L[2]);
var tree_DASH_set58285 = G(sets912,"tree-set",L[2]);
var list_DASH_set59284 = G(sets912,"list-set",L[2]);
var ColorT161205 = R.namedBrander("Color");
var Color6026 = R.makeBranderAnn(ColorT161205,"Color");
var Color262206 = {"$var":D,
"$name":"Color2"};
var Color63208 = {"$var":D,
"$name":"Color"};
var is_DASH_Color64210 = {"$var":D,
"$name":"is-Color"};
var is_DASH_color65212 = {"$var":D,
"$name":"is-color"};
var color66214 = {"$var":D,
"$name":"color"};
var anf_variant_member15232 = R.makeMethod(function(self2264) {
return function(cases_DASH_funs3265,else_DASH_clause4276) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
var if_DASH_6277 = R.hasField(cases_DASH_funs3265,("color"));
var if_helper2193 = R.makeFunction(function(if_helper_arg3282) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
var ann_DASH_check_DASH_temp1283 = if_helper_arg3282;
return ann_DASH_check_DASH_temp1283;
});
var anf_if6281 = R.isBoolean(if_DASH_6277);
if(R.isPyretTrue(anf_if6281)) {
if(R.isPyretTrue(if_DASH_6277)) {
var call_DASH_color1259 = G(cases_DASH_funs3265,"color",L[1]);
var anf_arg9260 = G(self2264,"red",L[11]);
var anf_arg10261 = G(self2264,"green",L[10]);
var anf_arg11262 = G(self2264,"blue",L[9]);
var anf_arg12263 = G(self2264,"alpha",L[8]);
var $z251252 = D;
var $f257258 = function(_) {
return R.isFunction(call_DASH_color1259)?call_DASH_color1259.app(anf_arg9260,anf_arg10261,anf_arg11262,anf_arg12263):R.ffi.throwNonFunApp(L[1],call_DASH_color1259,[anf_arg9260,anf_arg10261,anf_arg11262,anf_arg12263]);
};
try {
if(--R.GAS > 0) {
$z251252 = $f257258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f257258,
"from":L[1]});
}
} catch($e249250) {
if(R.isCont($e249250)) {
var $ss253254 = {"from":L[1],
"go":function(cont_tail_arg13192) {
return $Hcont_tail_arg44191(cont_tail_arg13192,if_helper2193);
}};
$e249250.stack[R.EXN_STACKHEIGHT++] = $ss253254;
}
if(R.isPyretException($e249250)) {
$e249250.pyretStack.push(L[1]);
}
throw $e249250;
}
var $ret255256 = $Hcont_tail_arg44191($z251252,if_helper2193);
++R.GAS;
return $ret255256;
} else {
var $z268269 = D;
var $f274275 = function(_) {
return R.isFunction(else_DASH_clause4276)?else_DASH_clause4276.app():R.ffi.throwNonFunApp(L[1],else_DASH_clause4276,[]);
};
try {
if(--R.GAS > 0) {
$z268269 = $f274275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f274275,
"from":L[1]});
}
} catch($e266267) {
if(R.isCont($e266267)) {
var $ss270271 = {"from":L[1],
"go":function(cont_tail_arg7198) {
return $Hcont_tail_arg45197(cont_tail_arg7198,if_helper2193);
}};
$e266267.stack[R.EXN_STACKHEIGHT++] = $ss270271;
}
if(R.isPyretException($e266267)) {
$e266267.pyretStack.push(L[1]);
}
throw $e266267;
}
var $ret272273 = $Hcont_tail_arg45197($z268269,if_helper2193);
++R.GAS;
return $ret272273;
}
} else {
var cont_tail_arg4280 = R.throwNonBooleanCondition(L[1],("if"),if_DASH_6277);
if(--R.GAS > 0) {
$z278279 = R.isFunction(if_helper2193)?if_helper2193.app(cont_tail_arg4280):R.ffi.throwNonFunApp(L[1],if_helper2193,[cont_tail_arg4280]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored196) {
return R.isFunction(if_helper2193)?if_helper2193.app(cont_tail_arg4280):R.ffi.throwNonFunApp(L[1],if_helper2193,[cont_tail_arg4280]);
},
"from":L[1]});
}
++R.GAS;
return $z278279;
}
};
},{"length":3});
var anf_variant_member33233 = R.makeMethod(function(self543) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1],0,arguments);
}
var anf_arg17248 = G(self543,"red",L[1]);
var $z240241 = D;
var $f246247 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg17248):R.ffi.throwNonFunApp(L[1],torepr6,[anf_arg17248]);
};
try {
if(--R.GAS > 0) {
$z240241 = $f246247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f246247,
"from":L[1]});
}
} catch($e238239) {
if(R.isCont($e238239)) {
var $ss242243 = {"from":L[1],
"go":function(anf_arg1842) {
return $Hanf_arg5841(anf_arg1842,self543,_plus3,torepr6);
}};
$e238239.stack[R.EXN_STACKHEIGHT++] = $ss242243;
}
if(R.isPyretException($e238239)) {
$e238239.pyretStack.push(L[1]);
}
throw $e238239;
}
var $ret244245 = $Hanf_arg5841($z240241,self543,_plus3,torepr6);
++R.GAS;
return $ret244245;
};
},{"length":1});
var anf_assign34207 = (function() {
var $color_DASH_base227228 = {"_match":anf_variant_member15232,
"_torepr":anf_variant_member33233};
var $color_DASH_brands230231 = {"$brand-color229":true};
$color_DASH_brands230231[ColorT161205._brand] = true
return R.makeObject({"Color":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ColorT161205._brand));
}),
"is-color":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-color229"));
}),
"color":R.makeFunction(function(red67234,green68235,blue69236,alpha70237) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[3],4,arguments);
}
return R.checkAnnArgs([$type$Number7,$type$Number7,$type$Number7,$type$Number7],[red67234,green68235,blue69236,alpha70237],[L[4],L[5],L[6],L[7]],function() {
var dict = R.create($color_DASH_base227228);
dict["red"] = red67234
dict["green"] = green68235
dict["blue"] = blue69236
dict["alpha"] = alpha70237
return R.makeBrandedObject(dict,$color_DASH_brands230231);
});
})});
})();
Color262206.$var = anf_assign34207;
var anf_assign35209 = G(Color262206.$var,"Color",L[0]);
Color63208.$var = anf_assign35209;
var anf_assign36211 = G(Color262206.$var,"Color",L[0]);
is_DASH_Color64210.$var = anf_assign36211;
var anf_assign37213 = G(Color262206.$var,"is-color",L[1]);
is_DASH_color65212.$var = anf_assign37213;
var anf_assign38215 = G(Color262206.$var,"color",L[1]);
color66214.$var = anf_assign38215;
var provides3927 = R.makeObject({"Color":Color63208.$var,
"is-Color":is_DASH_Color64210.$var,
"color":color66214.$var,
"is-color":is_DASH_color65212.$var});
var anf_fun40226 = G(builtins4,"current-checker",L[0]);
var $z218219 = D;
var $f224225 = function(_) {
return R.isFunction(anf_fun40226)?anf_fun40226.app():R.ffi.throwNonFunApp(L[0],anf_fun40226,[]);
};
try {
if(--R.GAS > 0) {
$z218219 = $f224225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f224225,
"from":L[0]});
}
} catch($e216217) {
if(R.isCont($e216217)) {
var $ss220221 = {"from":L[0],
"go":function(anf_bracket4125) {
return $Hanf_bracket6024(anf_bracket4125,Color6026,provides3927,nothing5);
}};
$e216217.stack[R.EXN_STACKHEIGHT++] = $ss220221;
}
if(R.isPyretException($e216217)) {
$e216217.pyretStack.push(L[0]);
}
throw $e216217;
}
var $ret222223 = $Hanf_bracket6024($z218219,Color6026,provides3927,nothing5);
++R.GAS;
return $ret222223;
},function(moduleVal) {
R.modules["$src/arr/trove/image-structs.arr18"] = moduleVal
return moduleVal;
});
});
}
};
});
define('trove/image-lib',[
    "trove/image-structs",
    "js/ffi-helpers",
    "js/js-numbers"
  ], function(
      imageLib,
      ffiLib,
      jsnums
    ) {
  // Basic implementation of the image library.
  //
  // This should mimic the implementation of 2htdp/image.

  return function(runtime, namespace) {
    var gf = runtime.getField;
    return runtime.loadJSModules(namespace, [ffiLib], function(ffi) {
      return runtime.loadModulesNew(namespace, [imageLib], function(imageImp) {
        var image = gf(imageImp, "values");
        var color = gf(image, "color");
        var colorPred = gf(image, "Color");
        var isNum = function(n) { return typeof n === "number"; }
        var unwrap = runtime.unwrap;

        var hasOwnProperty = {}.hasOwnProperty;

        // clone: object -> object
        // Copies an object.  The new object should respond like the old
        // object, including to things like instanceof.

        // NOTE(joe): There are much better ways to do this.  This is from
        // whalesong/whalesong/js-assembler/runtime-src/baselib.js
        // and we're keeping it for now (March 31, 2014) to avoid changing
        // potentially fragile prototype semantics
        var clone = function (obj) {
            var property;
            var C = function () {};
            C.prototype = obj;
            var c = new C();
            for (property in obj) {
                if (hasOwnProperty.call(obj, property)) {
                    c[property] = obj[property];
                }
            }
            return c;
        };

        //////////////////////////////////////////////////////////////////////
        var makeColor = function(r,g,b,a) {
          if (a === undefined) { a = 255; }
          if ([r,g,b,a].filter(isNum).length !== 4) {
            throw new Error("Internal error: non-number in makeColor argList ", [r, g, b, a]);
          }
          return color.app(
              runtime.wrap(r),
              runtime.wrap(g),
              runtime.wrap(b),
              runtime.wrap(a)
            );
        };
        var isColor = function(c) { return unwrap(colorPred.app(c)); };
        var colorRed = function(c) { return unwrap(gf(c, "red")); }
        var colorGreen = function(c) { return unwrap(gf(c, "green")); };
        var colorBlue = function(c) { return unwrap(gf(c, "blue")); };
        var colorAlpha = function(c) { return unwrap(gf(c, "alpha")); };
        var equals = runtime.same;

        var imageEquals = function(left, right) {
          if (!isImage(left) || !isImage(right)) { return false; }
          return left.equals(right);
        }
        //////////////////////////////////////////////////////////////////////

        var heir = Object.create;

        var isAngle = function(x) {
            return jsnums.isReal(x) &&
                jsnums.greaterThanOrEqual(x, 0) &&
                jsnums.lessThan(x, 360);
        };


        // Produces true if the value is a color or a color string.
        // On the Racket side of things, this is exposed as image-color?.
        var isColorOrColorString = function(thing) {
            return (isColor(thing) ||
                    ((runtime.isString(thing) &&
                      typeof(colorDb.get(thing)) != 'undefined')));
        };




        //////////////////////////////////////////////////////////////////////
        // colorString : hexColor Style -> rgba
        // Style can be "solid" (1.0), "outline" (1.0), a number (0-1.0) or null (1.0)
        var colorString = function(aColor, aStyle) {
          var alpha = isNaN(aStyle)? 1.0 : aStyle/255;
          return "rgba(" + colorRed(aColor) + "," +
                          colorGreen(aColor) + ", " +
                          colorBlue(aColor) + ", " +
                          alpha + ")";
        };




        var isSideCount = function(x) {
            return jsnums.isInteger(x) && jsnums.greaterThanOrEqual(x, 3);
        };

        var isStepCount = function(x) {
            return jsnums.isInteger(x) && jsnums.greaterThanOrEqual(x, 1);
        };


        var isPointsCount = function(x) {
            return jsnums.isExactInteger(x) && jsnums.greaterThanOrEqual(x, 2); 
        };





        // Produces true if thing is an image-like object.
        var isImage = function(thing) {
            if (typeof(thing.getHeight) !== 'function')
                return false;
            if (typeof(thing.getWidth) !== 'function')
                return false;
            if (typeof(thing.getBaseline) !== 'function')
                return false;
            if (typeof(thing.updatePinhole) !== 'function')
                return false;
            if (typeof(thing.render) !== 'function')
                return false;
            return true;
        };

        // given two arrays of {x,y} structs, determine their equivalence
        var verticesEqual = function(v1, v2){
          if(v1.length !== v2.length){ return false; }
          for(var i=0; i< v1.length; i++){
            if(v1[i].x !== v2[i].x || v1[i].y !== v2[i].y){ return false; }
          }
          return true;
        };
        // given two arrays of xs and ys, zip them into a vertex array
        var zipVertices = function(xs, ys){
          if(xs.length !== ys.length){throw new Error('failure in zipVertices');}
          var vertices = [];
          for(var i=0; i<xs.length;i++){
            vertices.push({x: xs[i], y: ys[i]});
          }
          return vertices;
        };


        // Base class for all images.
        var BaseImage = function() {};



        BaseImage.prototype.updatePinhole = function(x, y) {
            var aCopy = clone(this);
            aCopy.pinholeX = x;
            aCopy.pinholeY = y;
            return aCopy;
        };

        BaseImage.prototype.getHeight = function(){
            return this.height;
        };

        BaseImage.prototype.getWidth = function(){
            return this.width;
        };

        BaseImage.prototype.getBaseline = function(){
            return this.height;
        };

        // return the vertex array if it exists, otherwise make one using height and width
        BaseImage.prototype.getVertices = function(){
          if(this.vertices){ return this.vertices; }
          else{ return [{x:0 , y: 0},
                        {x: this.width, y: 0},
                        {x: 0, y: this.height},
                        {x: this.width, y: this.height}]; }
        };

        // render: context fixnum fixnum: -> void
        // Render the image, where the upper-left corner of the image is drawn at
        // (x, y).
        // If the image isn't vertex-based, throw an error
        // Otherwise, stroke and fill the vertices.
        BaseImage.prototype.render = function(ctx, x, y) {
          if(!this.vertices){
            throw new Error('BaseImage.render is not implemented for this type!');
          }
          ctx.save();
          ctx.beginPath();
          ctx.moveTo(x+this.vertices[0].x, y+this.vertices[0].y);
          for(var i=1; i < this.vertices.length; i++){
            ctx.lineTo(x+this.vertices[i].x, y+this.vertices[i].y);
          }
          ctx.closePath();

          if (this.style.toString().toLowerCase() === "outline") {
            ctx.strokeStyle = colorString(this.color);
            ctx.stroke();
          } else {
            ctx.fillStyle = colorString(this.color, this.style);
            ctx.fill();
          }
          ctx.restore();
        };


        // makeCanvas: number number -> canvas
        // Constructs a canvas object of a particular width and height.
        var makeCanvas = function(width, height) {
            var canvas = document.createElement("canvas");
            canvas.width = width;
            canvas.height = height;

            jQuery(canvas).css('width', canvas.width + "px");
            jQuery(canvas).css('height', canvas.height + "px");
            jQuery(canvas).css('padding', '0px');

            // KLUDGE: IE compatibility uses /js/excanvas.js, and dynamic
            // elements must be marked this way.
            if (window.G_vmlCanvasManager) {
          canvas = window.G_vmlCanvasManager.initElement(canvas);
            }
            return canvas;
        };



        var withIeHack = function(canvas, f) {
            // 	canvas.style.display = 'none';
            // 	document.body.appendChild(canvas);
            // 	try {
            var result = f(canvas);
            // 	} catch(e) {
            // 	    document.body.removeChild(canvas);
            // 	    canvas.style.display = '';
            // 	    throw e;
            // 	}
            // 	document.body.removeChild(canvas);
            // 	canvas.style.display = '';
            return result;
        };



        // Images are expected to define a render() method, which is used
        // here to draw to the canvas.
        BaseImage.prototype.toDomNode = function(params) {
            var that = this;
            var width = that.getWidth();
            var height = that.getHeight();
            var canvas = makeCanvas(width, height);
            var ctx;

            // // Try best effort to render to screen at this point.
            // try {
            //     ctx = canvas.getContext("2d");
            //     that.render(ctx, 0, 0);
            // } catch (e) {
            // }
            // KLUDGE: on IE, the canvas rendering functions depend on a
            // context where the canvas is attached to the DOM tree.
            // We initialize an afterAttach hook; the client's responsible
            // for calling this after the dom node is attached to the
            // document.
            var onAfterAttach = function(event) {
                // jQuery(canvas).unbind('afterAttach', onAfterAttach);
                var ctx = this.getContext("2d");
              that.render(ctx, 0, 0);
            };
            jQuery(canvas).bind('afterAttach', onAfterAttach);

            // Canvases lose their drawn content on cloning.  data may help us to preserve it.
            jQuery(canvas).data('toRender', onAfterAttach);

            return canvas;
        };




        BaseImage.prototype.toWrittenString = function(cache) { return "<image>"; }
        BaseImage.prototype.toDisplayedString = function(cache) { return "<image>"; }

        // Best-Guess equivalence for images. If they're vertex-based we're in luck,
        // otherwise we go pixel-by-pixel. It's up to exotic image types to provide
        // more efficient ways of comparing one another
        BaseImage.prototype.equals = function(other, aUnionFind) {
          if(this.width    !== other.getWidth()    ||
             this.height   !== other.getHeight()){ return false; }
          // if they're both vertex-based images, all we need to compare are
          // their styles, vertices and color
          if(this.vertices && other.vertices){
            return (this.style    === other.style &&
                    verticesEqual(this.vertices, other.vertices) &&
                    equals(this.color, other.color, aUnionFind));
          }
          // if it's something more sophisticated, render both images to canvases
          // First check canvas dimensions, then go pixel-by-pixel
          var c1 = this.toDomNode(), c2 = other.toDomNode();
          if(c1.width !== c2.width || c1.height !== c2.height){ return false;}
          try{
            var ctx1 = c1.getContext('2d'), ctx2 = c2.getContext('2d'),
            data1 = ctx1.getImageData(0, 0, c1.width, c1.height),
            data2 = ctx2.getImageData(0, 0, c2.width, c2.height);
            var pixels1 = data1.data,
            pixels2 = data2.data;
            for(var i = 0; i < pixels1.length; i++){
              if(pixels1[i] !== pixels2[i]){ return false; }
            }
          } catch(e){
            // if we violate CORS, just bail
            return false;
          }
          // if, after all this, we're still good...then they're equal!
          return true;
        };




        // isScene: any -> boolean
        // Produces true when x is a scene.
        var isScene = function(x) {
            return ((x != undefined) && (x != null) && (x instanceof SceneImage));
        };


        //////////////////////////////////////////////////////////////////////
        // SceneImage: primitive-number primitive-number (listof image) -> Scene
        var SceneImage = function(width, height, children, withBorder) {
          BaseImage.call(this);
          this.width    = width;
          this.height   = height;
          this.children = children; // arrayof [image, number, number]
          this.withBorder = withBorder;
        };
        SceneImage.prototype = heir(BaseImage.prototype);

        // add: image primitive-number primitive-number -> Scene
        SceneImage.prototype.add = function(anImage, x, y) {
          return new SceneImage(this.width,
                                this.height,
                                this.children.concat([[anImage,
                                                       x - anImage.getWidth()/2,
                                                       y - anImage.getHeight()/2]]),
                                this.withBorder);
        };

        // render: 2d-context primitive-number primitive-number -> void
        SceneImage.prototype.render = function(ctx, x, y) {
          var i;
          var childImage, childX, childY;
          // create a clipping region around the boundaries of the Scene
          ctx.save();
          ctx.fillStyle = "rgba(0,0,0,0)";
          ctx.fillRect(x, y, this.width, this.height);
          ctx.restore();
          // save the context, reset the path, and clip to the path around the scene edge
          ctx.save();
          ctx.beginPath();
          ctx.rect(x, y, this.width, this.height);
          ctx.clip();
          ctx.clearRect(x, y, this.width, this.height);
          // Ask every object to render itself inside the region
          for(i = 0; i < this.children.length; i++) {
            // then, render the child images
            childImage = this.children[i][0];
            childX = this.children[i][1];
            childY = this.children[i][2];
            childImage.render(ctx, childX + x, childY + y);
          }
          // unclip
          ctx.restore();
          
          if (this.withBorder) {
            ctx.strokeStyle = 'black';
            ctx.strokeRect(x, y, this.width, this.height);
          }
        };

        SceneImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof SceneImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          if (this.width    !== other.width ||
              this.height   !== other.height ||
              this.children.length !== other.children.length) {
            return false;
          }
          
          for (var i = 0; i < this.children.length; i++) {
            var rec1 = this.children[i];
            var rec2 = other.children[i];
            if (rec1[1] !== rec2[1] ||
                rec1[2] !== rec2[2] ||
                !equals(rec1[0], rec2[0], aUnionFind)) {
              return false;
            }
          }
          return true;
        };

        //////////////////////////////////////////////////////////////////////
        // FileImage: string node -> Image
        var FileImage = function(src, rawImage) {
          BaseImage.call(this);
          var self = this;
          this.src = src;
          this.isLoaded = false;
          
          // animationHack: see installHackToSupportAnimatedGifs() for details.
          this.animationHackImg = undefined;
          
          if (rawImage && rawImage.complete) {
            this.img = rawImage;
            this.isLoaded = true;
            self.width = self.img.width;
            self.height = self.img.height;
          } else {
            // fixme: we may want to do something blocking here for
            // onload, since we don't know at this time what the file size
            // should be, nor will drawImage do the right thing until the
            // file is loaded.
            this.img = new Image();
            this.img.onload = function() {
              self.isLoaded = true;
              self.width = self.img.width;
              self.height = self.img.height;
            };
            this.img.onerror = function(e) {
              self.img.onerror = "";
              self.img.src = "http://www.wescheme.org/images/broken.png";
            }
            this.img.src = src;
          }
        }
        FileImage.prototype = heir(BaseImage.prototype);


        var imageCache = {};
        FileImage.makeInstance = function(path, rawImage) {
          if (! (path in imageCache)) {
            imageCache[path] = new FileImage(path, rawImage);
          }
          return imageCache[path];
        };

        FileImage.installInstance = function(path, rawImage) {
          imageCache[path] = new FileImage(path, rawImage);
        };

        FileImage.installBrokenImage = function(path) {
          imageCache[path] = new TextImage("Unable to load " + path, 10, colorDb.get("red"),
                                           "normal", "Optimer","","",false);
        };



        FileImage.prototype.render = function(ctx, x, y) {
          this.installHackToSupportAnimatedGifs();
          ctx.drawImage(this.animationHackImg, x, y);
        };


        // The following is a hack that we use to allow animated gifs to show
        // as animating on the canvas.
        FileImage.prototype.installHackToSupportAnimatedGifs = function() {
          if (this.animationHackImg) { return; }
          this.animationHackImg = this.img.cloneNode(true);
          document.body.appendChild(this.animationHackImg);
          this.animationHackImg.style.position = 'absolute';
          this.animationHackImg.style.top = '-2000px';
        };


        FileImage.prototype.getWidth = function() {
          return this.img.width;
        };


        FileImage.prototype.getHeight = function() {
          return this.img.height;
        };

        // Override toDomNode: we don't need a full-fledged canvas here.
        FileImage.prototype.toDomNode = function(params) {
          return this.img.cloneNode(true);
        };

        FileImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof FileImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return (this.src === other.src);
        };

        //////////////////////////////////////////////////////////////////////
        // FileVideoe: String Node -> Video
        var FileVideo = function(src, rawVideo) {
            BaseImage.call(this);
            var self = this;
            this.src = src;
            if (rawVideo) {
          this.video			= rawVideo;
          this.width			= self.video.videoWidth;
          this.height			= self.video.videoHeight;
          this.video.volume	= 1;
          this.video.poster	= "http://www.wescheme.org/images/broken.png";
          this.video.autoplay	= true;
          this.video.autobuffer=true;
          this.video.loop		= true;
          this.video.play();
            } else {
          // fixme: we may want to do something blocking here for
          // onload, since we don't know at this time what the file size
          // should be, nor will drawImage do the right thing until the
          // file is loaded.
          this.video = document.createElement('video');
          this.video.src = src;
          this.video.addEventListener('canplay', function() {
              this.width			= self.video.videoWidth;
              this.height			= self.video.videoHeight;
              this.video.poster	= "http://www.wescheme.org/images/broken.png";
              this.video.autoplay	= true;
              this.video.autobuffer=true;
              this.video.loop		= true;
              this.video.play();
          });
          this.video.addEventListener('error', function(e) {
              self.video.onerror = "";
              self.video.poster = "http://www.wescheme.org/images/broken.png";
          });
            }
        }
        FileVideo.prototype = heir(BaseImage.prototype);

        var videos = {};
        FileVideo.makeInstance = function(path, rawVideo) {
            if (! (path in FileVideo)) {
          videos[path] = new FileVideo(path, rawVideo);
            } 
            return videos[path];
        };

        FileVideo.prototype.render = function(ctx, x, y) {
            ctx.drawImage(this.video, x, y);
        };
        FileVideo.prototype.equals = function(other, aUnionFind) {
          return (other instanceof FileVideo) && (this.src === other.src);
        };

        //////////////////////////////////////////////////////////////////////
        // ImageDataImage: imageData -> image
        // Given an array of pixel data, create an image
        var ImageDataImage = function(imageData) {
          BaseImage.call(this);
          this.imageData= imageData;
          this.width    = imageData.width;
          this.height   = imageData.height;
        };

        ImageDataImage.prototype = heir(BaseImage.prototype);

        ImageDataImage.prototype.render = function(ctx, x, y) {
          ctx.putImageData(this.imageData, x, y);
        };


        //////////////////////////////////////////////////////////////////////
        // OverlayImage: image image placeX placeY -> image
        // Creates an image that overlays img1 on top of the
        // other image img2.
        var OverlayImage = function(img1, img2, placeX, placeY) {
          BaseImage.call(this);
          
          // An overlay image consists of width, height, x1, y1, x2, and
          // y2.  We need to compute these based on the inputs img1,
          // img2, placex, and placey.
          
          // placeX and placeY may be non-numbers, in which case their values
          // depend on the img1 and img2 geometry.

          var x1, y1, x2, y2;
          
          if (placeX === "left") {
            x1 = 0;
            x2 = 0;
          } else if (placeX === "right") {
            x1 = Math.max(img1.getWidth(), img2.getWidth()) - img1.getWidth();
            x2 = Math.max(img1.getWidth(), img2.getWidth()) - img2.getWidth();
          } else if (placeX === "beside") {
            x1 = 0;
            x2 = img1.getWidth();
          } else if (placeX === "middle" || placeX === "center") {
            x1 = Math.max(img1.getWidth(), img2.getWidth())/2 - img1.getWidth()/2;
            x2 = Math.max(img1.getWidth(), img2.getWidth())/2 - img2.getWidth()/2;
          } else {
            x1 = Math.max(placeX, 0) - placeX;
            x2 = Math.max(placeX, 0);
          }
          
          if (placeY === "top") {
            y1 = 0;
            y2 = 0;
          } else if (placeY === "bottom") {
            y1 = Math.max(img1.getHeight(), img2.getHeight()) - img1.getHeight();
            y2 = Math.max(img1.getHeight(), img2.getHeight()) - img2.getHeight();
          } else if (placeY === "above") {
            y1 = 0;
            y2 = img1.getHeight();
          } else if (placeY === "baseline") {
            y1 = Math.max(img1.getBaseline(), img2.getBaseline()) - img1.getBaseline();
            y2 = Math.max(img1.getBaseline(), img2.getBaseline()) - img2.getBaseline();
          } else if (placeY === "middle" || placeY === "center") {
            y1 = Math.max(img1.getHeight(), img2.getHeight())/2 - img1.getHeight()/2;
            y2 = Math.max(img1.getHeight(), img2.getHeight())/2 - img2.getHeight()/2;
          } else {
            y1 = Math.max(placeY, 0) - placeY;
            y2 = Math.max(placeY, 0);
          }
          
          // calculate the vertices of this image by translating the verticies of the sub-images
          var i, v1 = img1.getVertices(), v2 = img2.getVertices(), xs = [], ys = [];

          for(i=0; i<v1.length; i++){
            xs.push(Math.round(v1[i].x + x1));
            ys.push(Math.round(v1[i].y + y1));
          }
          for(i=0; i<v2.length; i++){
            xs.push(Math.round(v2[i].x + x2));
            ys.push(Math.round(v2[i].y + y2));
          }
          
          // store the vertices as something private, so this.getVertices() will still return undefined
          this._vertices = zipVertices(xs, ys);
          this.width  = Math.max.apply(Math, xs) - Math.min.apply(Math, xs);
          this.height = Math.max.apply(Math, ys) - Math.min.apply(Math, ys);
          
          // store the offsets for rendering
          this.x1 = Math.floor(x1);
          this.y1 = Math.floor(y1);
          this.x2 = Math.floor(x2);
          this.y2 = Math.floor(y2);
          this.img1 = img1;
          this.img2 = img2;
        };

        OverlayImage.prototype = heir(BaseImage.prototype);

        OverlayImage.prototype.getVertices = function() { return this._vertices; };

        OverlayImage.prototype.render = function(ctx, x, y) {
          ctx.save();
          this.img2.render(ctx, x + this.x2, y + this.y2);
          this.img1.render(ctx, x + this.x1, y + this.y1);
          ctx.restore();
        };

        OverlayImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof OverlayImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return (this.width     === other.width &&
                  this.height    === other.height &&
                  this.x1        === other.x1 &&
                  this.y1        === other.y1 &&
                  this.x2        === other.x2 &&
                  this.y2        === other.y2 &&
                  equals(this.img1, other.img1, aUnionFind) &&
                  equals(this.img2, other.img2, aUnionFind) );
        };


        //////////////////////////////////////////////////////////////////////
        // rotate: angle image -> image
        // Rotates image by angle degrees in a counter-clockwise direction.
        // TODO: special case for ellipse?
        var RotateImage = function(angle, img) {
          BaseImage.call(this);
          var sin   = Math.sin(angle * Math.PI / 180);
          var cos   = Math.cos(angle * Math.PI / 180);
          var width = img.getWidth();
          var height= img.getHeight();
          
          // rotate each point as if it were rotated about (0,0)
          var vertices = img.getVertices(), xs = [], ys = [];
          for(var i=0; i<vertices.length; i++){
            xs[i] = Math.round(vertices[i].x*cos - vertices[i].y*sin);
            ys[i] = Math.round(vertices[i].x*sin + vertices[i].y*cos);
          }
          // figure out what translation is necessary to shift the vertices back to 0,0
          var translateX = Math.floor(-Math.min.apply( Math, xs ));
          var translateY = Math.floor(-Math.min.apply( Math, ys ));
          for(var i=0; i<vertices.length; i++){
            xs[i] += translateX;
            ys[i] += translateY;
          }
          
          // store the vertices as something private, so this.getVertices() will still return undefined
          this._vertices = zipVertices(xs,ys);
          var rotatedWidth  = Math.max.apply( Math, xs ) - Math.min.apply( Math, xs );
          var rotatedHeight = Math.max.apply( Math, ys ) - Math.min.apply( Math, ys );
          
          this.img        = img;
          this.width      = Math.floor(rotatedWidth);
          this.height     = Math.floor(rotatedHeight);
          this.angle      = angle;
          this.translateX = translateX;
          this.translateY  = translateY;
        };

        RotateImage.prototype = heir(BaseImage.prototype);

        RotateImage.prototype.getVertices = function() { return this._vertices; };

        // translate the canvas using the calculated values, then draw at the rotated (x,y) offset.
        RotateImage.prototype.render = function(ctx, x, y) {
          ctx.save();
          ctx.translate(x+this.translateX, y + this.translateY);
          ctx.rotate(this.angle * Math.PI / 180);
          this.img.render(ctx, 0, 0);
          ctx.restore();
        };

        RotateImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof RotateImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return (this.width     === other.width &&
                  this.height    === other.height &&
                  this.angle     === other.angle &&
                  this.translateX=== other.translateX &&
                  this.translateY=== other.translateY &&
                  equals(this.img, other.img, aUnionFind) );
        };

        //////////////////////////////////////////////////////////////////////
        // ScaleImage: factor factor image -> image
        // Scale an image
        var ScaleImage = function(xFactor, yFactor, img) {
          BaseImage.call(this);
          var vertices = img.getVertices();
          var xs = [], ys = [];
          for(var i=0; i<vertices.length; i++){
            xs[i] = Math.round(vertices[i].x*xFactor);
            ys[i] = Math.round(vertices[i].y*yFactor);
          }
          // store the vertices as something private, so this.getVertices() will still return undefined
          this._vertices = zipVertices(xs,ys);
          
          this.img      = img;
          this.width    = Math.floor(img.getWidth() * xFactor);
          this.height   = Math.floor(img.getHeight() * yFactor);
          this.xFactor  = xFactor;
          this.yFactor  = yFactor;
        };

        ScaleImage.prototype = heir(BaseImage.prototype);

        ScaleImage.prototype.getVertices = function() { return this._vertices; };

        // scale the context, and pass it to the image's render function
        ScaleImage.prototype.render = function(ctx, x, y) {
          ctx.save();
          ctx.scale(this.xFactor, this.yFactor);
          this.img.render(ctx, x / this.xFactor, y / this.yFactor);
          ctx.restore();
        };

        ScaleImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof ScaleImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return (this.width     === other.width &&
                  this.height    === other.height &&
                  this.xFactor   === other.xFactor &&
                  this.yFactor   === other.yFactor &&
                  equals(this.img, other.img, aUnionFind) );
        };

        //////////////////////////////////////////////////////////////////////
        // CropImage: startX startY width height image -> image
        // Crop an image
        var CropImage = function(x, y, width, height, img) {
          BaseImage.call(this);
          this.x          = x;
          this.y          = y;
          this.width      = width;
          this.height     = height;
          this.img        = img;
        };

        CropImage.prototype = heir(BaseImage.prototype);

        CropImage.prototype.render = function(ctx, x, y) {
          ctx.save();
          ctx.beginPath();
          ctx.rect(x, y, this.width, this.height);
          ctx.clip();
          ctx.translate(-this.x, -this.y);
          this.img.render(ctx, x, y);
          ctx.restore();
        };

        CropImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof CropImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return (this.width     === other.width &&
                  this.height    === other.height &&
                  this.x         === other.x &&
                  this.y         === other.y &&
                  equals(this.img, other.img, aUnionFind) );
        };

        //////////////////////////////////////////////////////////////////////
        // FrameImage: factor factor image -> image
        // Stick a frame around the image
        var FrameImage = function(img) {
          BaseImage.call(this);
          this.img        = img;
          this.width      = img.getWidth();
          this.height     = img.getHeight();
        };

        FrameImage.prototype = heir(BaseImage.prototype);

        // scale the context, and pass it to the image's render function
        FrameImage.prototype.render = function(ctx, x, y) {
          ctx.save();
          this.img.render(ctx, x, y);
          ctx.beginPath();
          ctx.strokeStyle = "black";
          ctx.strokeRect(x, y, this.width, this.height);
          ctx.closePath();
          ctx.restore();
        };

        FrameImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof FrameImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return equals(this.img, other.img, aUnionFind);
        };

        //////////////////////////////////////////////////////////////////////
        // FlipImage: image string -> image
        // Flip an image either horizontally or vertically
        var FlipImage = function(img, direction) {
          BaseImage.call(this);
          this.img        = img;
          this.width      = img.getWidth();
          this.height     = img.getHeight();
          this.direction  = direction;
        };

        FlipImage.prototype = heir(BaseImage.prototype);

        FlipImage.prototype.render = function(ctx, x, y) {
          // when flipping an image of dimension M and offset by N across an axis,
          // we need to translate the canvas by M+2N in the opposite direction
          ctx.save();
          if(this.direction === "horizontal"){
            ctx.scale(-1, 1);
            ctx.translate(-(this.width+2*x), 0);
            this.img.render(ctx, x, y);
          }
          if (this.direction === "vertical"){
            ctx.scale(1, -1);
            ctx.translate(0, -(this.height+2*y));
            this.img.render(ctx, x, y);
          }
          ctx.restore();
        };

        FlipImage.prototype.getWidth = function() {
          return this.width;
        };

        FlipImage.prototype.getHeight = function() {
          return this.height;
        };

        FlipImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof FlipImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return (this.width     === other.width &&
                  this.height    === other.height &&
                  this.direction === other.direction &&
                  equals(this.img, other.img, aUnionFind) );
        };




        //////////////////////////////////////////////////////////////////////
        // RectangleImage: Number Number Mode Color -> Image
        var RectangleImage = function(width, height, style, color) {
          BaseImage.call(this);
          this.width  = width;
          this.height = height;
          this.style  = style;
          this.color  = color;
          this.vertices = [{x:0,y:height},{x:0,y:0},{x:width,y:0},{x:width,y:height}];
        };
        RectangleImage.prototype = heir(BaseImage.prototype);

        RectangleImage.prototype.getWidth = function() {
          return this.width;
        };

        RectangleImage.prototype.getHeight = function() {
          return this.height;
        };

        //////////////////////////////////////////////////////////////////////
        // RhombusImage: Number Number Mode Color -> Image
        var RhombusImage = function(side, angle, style, color) {
          BaseImage.call(this);
          // sin(angle/2-in-radians) * side = half of base
          // cos(angle/2-in-radians) * side = half of height
          this.width  = Math.sin(angle/2 * Math.PI / 180) * side * 2;
          this.height = Math.abs(Math.cos(angle/2 * Math.PI / 180)) * side * 2;
          this.side   = side;
          this.angle  = angle;
          this.style  = style;
          this.color  = color;
          this.vertices = [{x:this.width/2, y:0},
                           {x:this.width,   y:this.height/2},
                           {x:this.width/2, y:this.height},
                           {x:0,            y:this.height/2}];
          
        };
        RhombusImage.prototype = heir(BaseImage.prototype);

        RhombusImage.prototype.getWidth = function() {
          return this.width;
        };

        RhombusImage.prototype.getHeight = function() {
          return this.height;
        };


        //////////////////////////////////////////////////////////////////////
        // PolygonImage: Number Count Step Mode Color -> Image
        //
        // See http://www.algebra.com/algebra/homework/Polygons/Inscribed-and-circumscribed-polygons.lesson
        // the polygon is inscribed in a circle, whose radius is length/2sin(pi/count)
        // another circle is inscribed in the polygon, whose radius is length/2tan(pi/count)
        // rotate a 3/4 quarter turn plus half the angle length to keep bottom base level
        var PolygonImage = function(length, count, step, style, color) {
          BaseImage.call(this);
          this.outerRadius = Math.floor(length/(2*Math.sin(Math.PI/count)));
          this.innerRadius = Math.floor(length/(2*Math.tan(Math.PI/count)));
          var adjust = (3*Math.PI/2)+Math.PI/count;
          
          // rotate around outer circle, storing x and y coordinates
          var radians = 0, xs = [], ys = [];
          for(var i = 0; i < count; i++) {
            radians = radians + (step*2*Math.PI/count);
            xs.push(Math.round(this.outerRadius*Math.cos(radians-adjust)));
            ys.push(Math.round(this.outerRadius*Math.sin(radians-adjust)));
          }
          var vertices = zipVertices(xs, ys);
          
          this.width      = Math.max.apply(Math, xs) - Math.min.apply(Math, xs);
          this.height     = Math.max.apply(Math, ys) - Math.min.apply(Math, ys);
          this.length     = length;
          this.count      = count;
          this.step       = step;
          this.style      = style;
          this.color      = color;
          
          // shift the vertices by the calculated offsets, now that we know the width
          var xOffset = Math.round(this.width/2);
          var yOffset = ((this.count % 2)? this.outerRadius : this.innerRadius);
          for(i=0; i<vertices.length; i++){
            vertices[i].x += xOffset; vertices[i].y += yOffset;
          }
          this.vertices   = vertices;
        };

        PolygonImage.prototype = heir(BaseImage.prototype);

        var maybeQuote = function(s) {
          if (/ /.test(s)) {
            return "\"" + s + "\"";
          }
          return s;
        };


        //////////////////////////////////////////////////////////////////////
        // TextImage: String Number Color String String String String any/c -> Image
        var TextImage = function(msg, size, color, face, family, style, weight, underline) {
          BaseImage.call(this);
          var metrics;
          this.msg        = msg;
          this.size       = size;   // 18
          this.color      = color;  // red
          this.face       = face;   // Gill Sans
          this.family     = family; // 'swiss
          this.style      = (style === "slant")? "oblique" : style;  // Racket's "slant" -> CSS's "oblique"
          this.weight     = (weight=== "light")? "lighter" : weight; // Racket's "light" -> CSS's "lighter"
          this.underline  = underline;
          // example: "bold italic 20px 'Times', sans-serif".
          // Default weight is "normal", face is "Arial"
          
          // NOTE: we *ignore* font-family, as it causes a number of font bugs due the browser inconsistencies
          var canvas  = makeCanvas(0, 0),
              ctx     = canvas.getContext("2d");
          
          this.font = (this.style + " " +
                       this.weight + " " +
                       this.size + "px " +
                       '"'+this.face+'", '+
                       this.family);
          
          try {
            ctx.font    = this.font;
          } catch (e) {
            this.fallbackOnFont();
            ctx.font    = this.font;
          }
          
          // Defensive: on IE, this can break.
          try {
            metrics     = ctx.measureText(msg);
            this.width  = metrics.width;
            this.height = Number(this.size);
          } catch(e) {
            this.fallbackOnFont();
          }
        };


        TextImage.prototype = heir(BaseImage.prototype);

        TextImage.prototype.fallbackOnFont = function() {
          // Defensive: if the browser doesn't support certain features, we
          // reduce to a smaller feature set and try again.
          this.font       = this.size + "px " + maybeQuote(this.family);
          var canvas      = makeCanvas(0, 0);
          var ctx         = canvas.getContext("2d");
          ctx.font        = this.font;
          var metrics     = ctx.measureText(this.msg);
          this.width      = metrics.width;
          // KLUDGE: I don't know how to get at the height.
          this.height     = Number(this.size);//ctx.measureText("m").width + 20;
        };


        TextImage.prototype.render = function(ctx, x, y) {
          ctx.save();
          ctx.textAlign   = 'left';
          ctx.textBaseline= 'top';
          ctx.fillStyle   = colorString(this.color);
          ctx.font        = this.font;
          try {
            ctx.fillText(this.msg, x, y);
          } catch (e) {
            this.fallbackOnFont();
            ctx.font = this.font;
            ctx.fillText(this.msg, x, y);
          }
          if(this.underline){
            ctx.beginPath();
            ctx.moveTo(x, y+this.size);
            // we use this.size, as it is more accurate for underlining than this.height
            ctx.lineTo(x+this.width, y+this.size);
            ctx.closePath();
            ctx.strokeStyle = colorString(this.color);
            ctx.stroke();
          }
          ctx.restore();
        };

        TextImage.prototype.getBaseline = function() {
          return this.size;
        };

        TextImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof TextImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return (this.msg      === other.msg &&
                  this.size     === other.size &&
                  this.face     === other.face &&
                  this.family   === other.family &&
                  this.style    === other.style &&
                  this.weight   === other.weight &&
                  this.underline === other.underline &&
                  equals(this.color, other.color, aUnionFind) &&
                  this.font === other.font);
        };


        //////////////////////////////////////////////////////////////////////
        // StarImage: fixnum fixnum fixnum color -> image
        // Most of this code here adapted from the Canvas tutorial at:
        // http://developer.apple.com/safari/articles/makinggraphicswithcanvas.html
        var StarImage = function(points, outer, inner, style, color) {
          BaseImage.call(this);
          this.points     = points;
          this.outer      = outer;
          this.inner      = inner;
          this.style      = style;
          this.color      = color;
          this.radius     = Math.max(this.inner, this.outer);
          this.width      = this.radius*2;
          this.height     = this.radius*2;
          var vertices   = [];
          
          var oneDegreeAsRadian = Math.PI / 180;
          for(var pt = 0; pt < (this.points * 2) + 1; pt++ ) {
            var rads = ( ( 360 / (2 * this.points) ) * pt ) * oneDegreeAsRadian - 0.5;
            var radius = ( pt % 2 === 1 ) ? this.outer : this.inner;
            vertices.push({x:this.radius + ( Math.sin( rads ) * radius ),
                          y:this.radius + ( Math.cos( rads ) * radius )} );
          }
          this.vertices = vertices;
        };

        StarImage.prototype = heir(BaseImage.prototype);

        /////////////////////////////////////////////////////////////////////
        //TriangleImage: Number Number Number Mode Color -> Image
        // Draws a triangle with the base = sideC, and the angle between sideC
        // and sideB being angleA
        // See http://docs.racket-lang.org/teachpack/2htdpimage.html#(def._((lib._2htdp/image..rkt)._triangle))
        var TriangleImage = function(sideC, angleA, sideB, style, color) {
          BaseImage.call(this);
          var thirdX = sideB * Math.cos(angleA * Math.PI/180);
          var thirdY = sideB * Math.sin(angleA * Math.PI/180);

          var offsetX = 0 - Math.min(0, thirdX); // angleA could be obtuse

          this.width = Math.max(sideC, thirdX) + offsetX;
          this.height = Math.abs(thirdY);
          
          var vertices = [];
          // if angle < 180 start at the top of the canvas, otherwise start at the bottom
          if(thirdY > 0){
            vertices.push({x: offsetX + 0, y: 0});
            vertices.push({x: offsetX + sideC, y: 0});
            vertices.push({x: offsetX + thirdX, y: thirdY});
          } else {
            vertices.push({x: offsetX + 0, y: -thirdY});
            vertices.push({x: offsetX + sideC, y: -thirdY});
            vertices.push({x: offsetX + thirdX, y: 0});
          }
            console.log(vertices);
          this.vertices = vertices;
          
          this.style = style;
          this.color = color;
        };
        TriangleImage.prototype = heir(BaseImage.prototype);

        //////////////////////////////////////////////////////////////////////
        //Ellipse : Number Number Mode Color -> Image
        var EllipseImage = function(width, height, style, color) {
          BaseImage.call(this);
          this.width = width;
          this.height = height;
          this.style = style;
          this.color = color;
        };

        EllipseImage.prototype = heir(BaseImage.prototype);

        EllipseImage.prototype.render = function(ctx, aX, aY) {
          ctx.save();
          ctx.beginPath();
          
          // Most of this code is taken from:
          // http://webreflection.blogspot.com/2009/01/ellipse-and-circle-for-canvas-2d.html
          var hB = (this.width / 2) * 0.5522848,
          vB = (this.height / 2) * 0.5522848,
          eX = aX + this.width,
          eY = aY + this.height,
          mX = aX + this.width / 2,
          mY = aY + this.height / 2;
          ctx.moveTo(aX, mY);
          ctx.bezierCurveTo(aX, mY - vB, mX - hB, aY, mX, aY);
          ctx.bezierCurveTo(mX + hB, aY, eX, mY - vB, eX, mY);
          ctx.bezierCurveTo(eX, mY + vB, mX + hB, eY, mX, eY);
          ctx.bezierCurveTo(mX - hB, eY, aX, mY + vB, aX, mY);
          ctx.closePath();
          if (this.style.toString().toLowerCase() === "outline") {
            ctx.strokeStyle = colorString(this.color);
            ctx.stroke();
          }
          else {
            ctx.fillStyle = colorString(this.color, this.style);
            ctx.fill();
          }
          
          ctx.restore();
        };

        EllipseImage.prototype.equals = function(other, aUnionFind) {
          if (!(other instanceof EllipseImage)) {
            return BaseImage.prototype.equals.call(this, other, aUnionFind);
          }
          return (this.width    === other.width &&
                  this.height   === other.height &&
                  this.style    === other.style &&
                  equals(this.color, other.color, aUnionFind));
        };


        //////////////////////////////////////////////////////////////////////
        // Line: Number Number Color Boolean -> Image
        var LineImage = function(x, y, color) {
          BaseImage.call(this);
          var vertices;
          if (x >= 0) {
            if (y >= 0) { vertices = [{x:  0, y:  0}, {x: x, y: y}]; }
            else        { vertices = [{x:  0, y: -y}, {x: x, y: 0}]; }
          } else {
            if (y >= 0) { vertices = [{x: -x, y:  0}, {x: 0, y: y}]; }
            else        { vertices = [{x: -x, y: -y}, {x: 0, y: 0}]; }
          }
          // preserve the invariant that all vertex-based images have a style
          this.style  = "outline";
          this.color  = color;
          this.width  = Math.abs(x);
          this.height = Math.abs(y);
          this.vertices = vertices;
        };

        LineImage.prototype = heir(BaseImage.prototype);




        var imageToColorList = function(img) {
            var width = img.getWidth(),
            height = img.getHeight(),
            canvas = makeCanvas(width, height),
            ctx = canvas.getContext("2d"),
            imageData,
            data,
            i,
            r, g, b, a;
            img.render(ctx, 0, 0);
            imageData = ctx.getImageData(0, 0, width, height);
            data = imageData.data;
            var colors = [];
            for (i = 0 ; i < data.length; i += 4) {
              r = data[i];
              g = data[i+1];
              b = data[i+2];
              a = data[i+3];
              colors.push(makeColor(r, g, b, a));
            }
            return ffi.makeList(colors);
        }


        var colorListToImage = function(listOfColors,
                                        width,
                                        height,
                                        pinholeX,
                                        pinholeY) {
            var canvas = makeCanvas(jsnums.toFixnum(width),
                  jsnums.toFixnum(height)),
            ctx = canvas.getContext("2d"),
            imageData = ctx.createImageData(jsnums.toFixnum(width),
                    jsnums.toFixnum(height)),
            aColor,
            data = imageData.data,
            jsLOC = ffi.toArray(listOfColors);
            for(var i = 0; i < jsLOC.length * 4; i += 4) {
              aColor = jsLOC[i / 4];
              data[i] = jsnums.toFixnum(colorRed(aColor));
              data[i+1] = jsnums.toFixnum(colorGreen(aColor));
              data[i+2] = jsnums.toFixnum(colorBlue(aColor));
              data[i+3] = jsnums.toFixnum(colorAlpha(aColor));
            }

            return makeImageDataImage(imageData);
        };













        var makeSceneImage = function(width, height, children, withBorder) {
            return new SceneImage(width, height, children, withBorder);
        };
        var makeCircleImage = function(radius, style, color) {
            return new EllipseImage(2*radius, 2*radius, style, color);
        };
        var makeStarImage = function(points, outer, inner, style, color) {
            return new StarImage(points, outer, inner, style, color);
        };
        var makeRectangleImage = function(width, height, style, color) {
            return new RectangleImage(width, height, style, color);
        };
        var makeRhombusImage = function(side, angle, style, color) {
            return new RhombusImage(side, angle, style, color);
        };
        var makePolygonImage = function(length, count, step, style, color) {
            return new PolygonImage(length, count, step, style, color);
        };
        var makeSquareImage = function(length, style, color) {
            return new RectangleImage(length, length, style, color);
        };
        var makeTriangleImage = function(sideA, angleC, sideB, style, color) {
            return new TriangleImage(sideA, angleC, sideB, style, color);
        };
        var makeEllipseImage = function(width, height, style, color) {
            return new EllipseImage(width, height, style, color);
        };
        var makeLineImage = function(x, y, color, normalPinhole) {
            return new LineImage(x, y, color, normalPinhole);
        };
        var makeOverlayImage = function(img1, img2, X, Y) {
            return new OverlayImage(img1, img2, X, Y);
        };
        var makeRotateImage = function(angle, img) {
            return new RotateImage(angle, img);
        };
        var makeScaleImage = function(xFactor, yFactor, img) {
            return new ScaleImage(xFactor, yFactor, img);
        };
        var makeCropImage = function(x, y, width, height, img) {
            return new CropImage(x, y, width, height, img);
        };
        var makeFrameImage = function(img) {
            return new FrameImage(img);
        };
        var makeFlipImage = function(img, direction) {
            return new FlipImage(img, direction);
        };
        var makeTextImage = function(msg, size, color, face, family, style, weight, underline) {
            return new TextImage(msg, size, color, face, family, style, weight, underline);
        };
        var makeImageDataImage = function(imageData) {
            return new ImageDataImage(imageData);
        };
        var makeFileImage = function(path, rawImage) {
            return FileImage.makeInstance(path, rawImage);
        };
        var makeFileVideo = function(path, rawVideo) {
            return FileVideo.makeInstance(path, rawVideo);
        };


        var isSceneImage = function(x) { return x instanceof SceneImage; };
        var isCircleImage = function(x) { return x instanceof EllipseImage && 
                                          x.width === x.height; };
        var isStarImage	= function(x) { return x instanceof StarImage; };
        var isRectangleImage=function(x) { return x instanceof RectangleImage; };
        var isPolygonImage = function(x) { return x instanceof PolygonImage; };
        var isRhombusImage = function(x) { return x instanceof RhombusImage; };
        var isSquareImage	= function(x) { return x instanceof SquareImage; };
        var isTriangleImage= function(x) { return x instanceof TriangleImage; };
        var isEllipseImage = function(x) { return x instanceof EllipseImage; };
        var isLineImage	= function(x) { return x instanceof LineImage; };
        var isOverlayImage = function(x) { return x instanceof OverlayImage; };
        var isRotateImage	= function(x) { return x instanceof RotateImage; };
        var isScaleImage	= function(x) { return x instanceof ScaleImage; };
        var isCropImage	= function(x) { return x instanceof CropImage; };
        var isFrameImage	= function(x) { return x instanceof FrameImage; };
        var isFlipImage	= function(x) { return x instanceof FlipImage; };
        var isTextImage	= function(x) { return x instanceof TextImage; };
        var isFileImage	= function(x) { return x instanceof FileImage; };
        var isFileVideo	= function(x) { return x instanceof FileVideo; };

        // Color database
        var ColorDb = function() {
            this.colors = {};
        };


        ColorDb.prototype.put = function(name, color) {
            this.colors[name] = color;
        };

        ColorDb.prototype.get = function(name) {
            return this.colors[name.toString().toUpperCase()];
        };


        // FIXME: update toString to handle the primitive field values.

        var colorDb = new ColorDb();
        colorDb.put("ORANGE", makeColor(255, 165, 0));
        colorDb.put("RED", makeColor(255, 0, 0));
        colorDb.put("ORANGERED", makeColor(255, 69, 0));
        colorDb.put("TOMATO", makeColor(255, 99, 71));
        colorDb.put("DARKRED", makeColor(139, 0, 0));
        colorDb.put("RED", makeColor(255, 0, 0));
        colorDb.put("FIREBRICK", makeColor(178, 34, 34));
        colorDb.put("CRIMSON", makeColor(220, 20, 60));
        colorDb.put("DEEPPINK", makeColor(255, 20, 147));
        colorDb.put("MAROON", makeColor(176, 48, 96));
        colorDb.put("INDIAN RED", makeColor(205, 92, 92));
        colorDb.put("INDIANRED", makeColor(205, 92, 92));
        colorDb.put("MEDIUM VIOLET RED", makeColor(199, 21, 133));
        colorDb.put("MEDIUMVIOLETRED", makeColor(199, 21, 133));
        colorDb.put("VIOLET RED", makeColor(208, 32, 144));
        colorDb.put("VIOLETRED", makeColor(208, 32, 144));
        colorDb.put("LIGHTCORAL", makeColor(240, 128, 128));
        colorDb.put("HOTPINK", makeColor(255, 105, 180));
        colorDb.put("PALEVIOLETRED", makeColor(219, 112, 147));
        colorDb.put("LIGHTPINK", makeColor(255, 182, 193));
        colorDb.put("ROSYBROWN", makeColor(188, 143, 143));
        colorDb.put("PINK", makeColor(255, 192, 203));
        colorDb.put("ORCHID", makeColor(218, 112, 214));
        colorDb.put("LAVENDERBLUSH", makeColor(255, 240, 245));
        colorDb.put("SNOW", makeColor(255, 250, 250));
        colorDb.put("CHOCOLATE", makeColor(210, 105, 30));
        colorDb.put("SADDLEBROWN", makeColor(139, 69, 19));
        colorDb.put("BROWN", makeColor(132, 60, 36));
        colorDb.put("DARKORANGE", makeColor(255, 140, 0));
        colorDb.put("CORAL", makeColor(255, 127, 80));
        colorDb.put("SIENNA", makeColor(160, 82, 45));
        colorDb.put("ORANGE", makeColor(255, 165, 0));
        colorDb.put("SALMON", makeColor(250, 128, 114));
        colorDb.put("PERU", makeColor(205, 133, 63));
        colorDb.put("DARKGOLDENROD", makeColor(184, 134, 11));
        colorDb.put("GOLDENROD", makeColor(218, 165, 32));
        colorDb.put("SANDYBROWN", makeColor(244, 164, 96));
        colorDb.put("LIGHTSALMON", makeColor(255, 160, 122));
        colorDb.put("DARKSALMON", makeColor(233, 150, 122));
        colorDb.put("GOLD", makeColor(255, 215, 0));
        colorDb.put("YELLOW", makeColor(255, 255, 0));
        colorDb.put("OLIVE", makeColor(128, 128, 0));
        colorDb.put("BURLYWOOD", makeColor(222, 184, 135));
        colorDb.put("TAN", makeColor(210, 180, 140));
        colorDb.put("NAVAJOWHITE", makeColor(255, 222, 173));
        colorDb.put("PEACHPUFF", makeColor(255, 218, 185));
        colorDb.put("KHAKI", makeColor(240, 230, 140));
        colorDb.put("DARKKHAKI", makeColor(189, 183, 107));
        colorDb.put("MOCCASIN", makeColor(255, 228, 181));
        colorDb.put("WHEAT", makeColor(245, 222, 179));
        colorDb.put("BISQUE", makeColor(255, 228, 196));
        colorDb.put("PALEGOLDENROD", makeColor(238, 232, 170));
        colorDb.put("BLANCHEDALMOND", makeColor(255, 235, 205));
        colorDb.put("MEDIUM GOLDENROD", makeColor(234, 234, 173));
        colorDb.put("MEDIUMGOLDENROD", makeColor(234, 234, 173));
        colorDb.put("PAPAYAWHIP", makeColor(255, 239, 213));
        colorDb.put("MISTYROSE", makeColor(255, 228, 225));
        colorDb.put("LEMONCHIFFON", makeColor(255, 250, 205));
        colorDb.put("ANTIQUEWHITE", makeColor(250, 235, 215));
        colorDb.put("CORNSILK", makeColor(255, 248, 220));
        colorDb.put("LIGHTGOLDENRODYELLOW", makeColor(250, 250, 210));
        colorDb.put("OLDLACE", makeColor(253, 245, 230));
        colorDb.put("LINEN", makeColor(250, 240, 230));
        colorDb.put("LIGHTYELLOW", makeColor(255, 255, 224));
        colorDb.put("SEASHELL", makeColor(255, 245, 238));
        colorDb.put("BEIGE", makeColor(245, 245, 220));
        colorDb.put("FLORALWHITE", makeColor(255, 250, 240));
        colorDb.put("IVORY", makeColor(255, 255, 240));
        colorDb.put("GREEN", makeColor(0, 255, 0));
        colorDb.put("LAWNGREEN", makeColor(124, 252, 0));
        colorDb.put("CHARTREUSE", makeColor(127, 255, 0));
        colorDb.put("GREEN YELLOW", makeColor(173, 255, 47));
        colorDb.put("GREENYELLOW", makeColor(173, 255, 47));
        colorDb.put("YELLOW GREEN", makeColor(154, 205, 50));
        colorDb.put("YELLOWGREEN", makeColor(154, 205, 50));
        colorDb.put("MEDIUM FOREST GREEN", makeColor(107, 142, 35));
        colorDb.put("OLIVEDRAB", makeColor(107, 142, 35));
        colorDb.put("MEDIUMFORESTGREEN", makeColor(107, 142, 35));
        colorDb.put("DARK OLIVE GREEN", makeColor(85, 107, 47));
        colorDb.put("DARKOLIVEGREEN", makeColor(85, 107, 47));
        colorDb.put("DARKSEAGREEN", makeColor(143, 188, 139));
        colorDb.put("LIME", makeColor(0, 255, 0));
        colorDb.put("DARK GREEN", makeColor(0, 100, 0));
        colorDb.put("DARKGREEN", makeColor(0, 100, 0));
        colorDb.put("LIME GREEN", makeColor(50, 205, 50));
        colorDb.put("LIMEGREEN", makeColor(50, 205, 50));
        colorDb.put("FOREST GREEN", makeColor(34, 139, 34));
        colorDb.put("FORESTGREEN", makeColor(34, 139, 34));
        colorDb.put("SPRING GREEN", makeColor(0, 255, 127));
        colorDb.put("SPRINGGREEN", makeColor(0, 255, 127));
        colorDb.put("MEDIUM SPRING GREEN", makeColor(0, 250, 154));
        colorDb.put("MEDIUMSPRINGGREEN", makeColor(0, 250, 154));
        colorDb.put("SEA GREEN", makeColor(46, 139, 87));
        colorDb.put("SEAGREEN", makeColor(46, 139, 87));
        colorDb.put("MEDIUM SEA GREEN", makeColor(60, 179, 113));
        colorDb.put("MEDIUMSEAGREEN", makeColor(60, 179, 113));
        colorDb.put("AQUAMARINE", makeColor(112, 216, 144));
        colorDb.put("LIGHTGREEN", makeColor(144, 238, 144));
        colorDb.put("PALE GREEN", makeColor(152, 251, 152));
        colorDb.put("PALEGREEN", makeColor(152, 251, 152));
        colorDb.put("MEDIUM AQUAMARINE", makeColor(102, 205, 170));
        colorDb.put("MEDIUMAQUAMARINE", makeColor(102, 205, 170));
        colorDb.put("TURQUOISE", makeColor(64, 224, 208));
        colorDb.put("LIGHTSEAGREEN", makeColor(32, 178, 170));
        colorDb.put("MEDIUM TURQUOISE", makeColor(72, 209, 204));
        colorDb.put("MEDIUMTURQUOISE", makeColor(72, 209, 204));
        colorDb.put("HONEYDEW", makeColor(240, 255, 240));
        colorDb.put("MINTCREAM", makeColor(245, 255, 250));
        colorDb.put("ROYALBLUE", makeColor(65, 105, 225));
        colorDb.put("DODGERBLUE", makeColor(30, 144, 255));
        colorDb.put("DEEPSKYBLUE", makeColor(0, 191, 255));
        colorDb.put("CORNFLOWERBLUE", makeColor(100, 149, 237));
        colorDb.put("STEEL BLUE", makeColor(70, 130, 180));
        colorDb.put("STEELBLUE", makeColor(70, 130, 180));
        colorDb.put("LIGHTSKYBLUE", makeColor(135, 206, 250));
        colorDb.put("DARK TURQUOISE", makeColor(0, 206, 209));
        colorDb.put("DARKTURQUOISE", makeColor(0, 206, 209));
        colorDb.put("CYAN", makeColor(0, 255, 255));
        colorDb.put("AQUA", makeColor(0, 255, 255));
        colorDb.put("DARKCYAN", makeColor(0, 139, 139));
        colorDb.put("TEAL", makeColor(0, 128, 128));
        colorDb.put("SKY BLUE", makeColor(135, 206, 235));
        colorDb.put("SKYBLUE", makeColor(135, 206, 235));
        colorDb.put("CADET BLUE", makeColor(96, 160, 160));
        colorDb.put("CADETBLUE", makeColor(95, 158, 160));
        colorDb.put("DARK SLATE GRAY", makeColor(47, 79, 79));
        colorDb.put("DARKSLATEGRAY", makeColor(47, 79, 79));
        colorDb.put("LIGHTSLATEGRAY", makeColor(119, 136, 153));
        colorDb.put("SLATEGRAY", makeColor(112, 128, 144));
        colorDb.put("LIGHT STEEL BLUE", makeColor(176, 196, 222));
        colorDb.put("LIGHTSTEELBLUE", makeColor(176, 196, 222));
        colorDb.put("LIGHT BLUE", makeColor(173, 216, 230));
        colorDb.put("LIGHTBLUE", makeColor(173, 216, 230));
        colorDb.put("POWDERBLUE", makeColor(176, 224, 230));
        colorDb.put("PALETURQUOISE", makeColor(175, 238, 238));
        colorDb.put("LIGHTCYAN", makeColor(224, 255, 255));
        colorDb.put("ALICEBLUE", makeColor(240, 248, 255));
        colorDb.put("AZURE", makeColor(240, 255, 255));
        colorDb.put("MEDIUM BLUE", makeColor(0, 0, 205));
        colorDb.put("MEDIUMBLUE", makeColor(0, 0, 205));
        colorDb.put("DARKBLUE", makeColor(0, 0, 139));
        colorDb.put("MIDNIGHT BLUE", makeColor(25, 25, 112));
        colorDb.put("MIDNIGHTBLUE", makeColor(25, 25, 112));
        colorDb.put("NAVY", makeColor(36, 36, 140));
        colorDb.put("BLUE", makeColor(0, 0, 255));
        colorDb.put("INDIGO", makeColor(75, 0, 130));
        colorDb.put("BLUE VIOLET", makeColor(138, 43, 226));
        colorDb.put("BLUEVIOLET", makeColor(138, 43, 226));
        colorDb.put("MEDIUM SLATE BLUE", makeColor(123, 104, 238));
        colorDb.put("MEDIUMSLATEBLUE", makeColor(123, 104, 238));
        colorDb.put("SLATE BLUE", makeColor(106, 90, 205));
        colorDb.put("SLATEBLUE", makeColor(106, 90, 205));
        colorDb.put("PURPLE", makeColor(160, 32, 240));
        colorDb.put("DARK SLATE BLUE", makeColor(72, 61, 139));
        colorDb.put("DARKSLATEBLUE", makeColor(72, 61, 139));
        colorDb.put("DARKVIOLET", makeColor(148, 0, 211));
        colorDb.put("DARK ORCHID", makeColor(153, 50, 204));
        colorDb.put("DARKORCHID", makeColor(153, 50, 204));
        colorDb.put("MEDIUMPURPLE", makeColor(147, 112, 219));
        colorDb.put("CORNFLOWER BLUE", makeColor(68, 64, 108));
        colorDb.put("MEDIUM ORCHID", makeColor(186, 85, 211));
        colorDb.put("MEDIUMORCHID", makeColor(186, 85, 211));
        colorDb.put("MAGENTA", makeColor(255, 0, 255));
        colorDb.put("FUCHSIA", makeColor(255, 0, 255));
        colorDb.put("DARKMAGENTA", makeColor(139, 0, 139));
        colorDb.put("VIOLET", makeColor(238, 130, 238));
        colorDb.put("PLUM", makeColor(221, 160, 221));
        colorDb.put("LAVENDER", makeColor(230, 230, 250));
        colorDb.put("THISTLE", makeColor(216, 191, 216));
        colorDb.put("GHOSTWHITE", makeColor(248, 248, 255));
        colorDb.put("WHITE", makeColor(255, 255, 255));
        colorDb.put("WHITESMOKE", makeColor(245, 245, 245));
        colorDb.put("GAINSBORO", makeColor(220, 220, 220));
        colorDb.put("LIGHT GRAY", makeColor(211, 211, 211));
        colorDb.put("LIGHTGRAY", makeColor(211, 211, 211));
        colorDb.put("SILVER", makeColor(192, 192, 192));
        colorDb.put("GRAY", makeColor(190, 190, 190));
        colorDb.put("DARK GRAY", makeColor(169, 169, 169));
        colorDb.put("DARKGRAY", makeColor(169, 169, 169));
        colorDb.put("DIM GRAY", makeColor(105, 105, 105));
        colorDb.put("DIMGRAY", makeColor(105, 105, 105));
        colorDb.put("BLACK", makeColor(0, 0, 0));



        ///////////////////////////////////////////////////////////////
        // Exports

        // These functions are available for direct access without the typechecks
        // of the Racket-exposed functions.
        return {
          makeCanvas: makeCanvas,



          BaseImage: BaseImage,
          SceneImage: SceneImage,
          FileImage: FileImage,
          VideoImage: FileVideo,
          OverlayImage: OverlayImage,
          RotateImage: RotateImage,
          ScaleImage: ScaleImage,
          CropImage: CropImage,
          FrameImage: FrameImage,
          FlipImage: FlipImage,
          RectangleImage: RectangleImage,
          RhombusImage: RhombusImage,
          ImageDataImage: ImageDataImage,
          PolygonImage: PolygonImage,
          TextImage: TextImage,
          StarImage: StarImage,
          TriangleImage: TriangleImage,
          EllipseImage: EllipseImage,
          LineImage: LineImage,
          StarImage: StarImage,


          imageEquals: imageEquals,

          colorDb: colorDb,

          makeSceneImage: makeSceneImage,
          makeCircleImage: makeCircleImage,
          makeStarImage: makeStarImage,
          makeRectangleImage: makeRectangleImage,
          makeRhombusImage: makeRhombusImage,
          makePolygonImage: makePolygonImage,
          makeSquareImage: makeSquareImage,
          makeTriangleImage: makeTriangleImage,
          makeEllipseImage: makeEllipseImage,
          makeLineImage: makeLineImage,
          makeOverlayImage: makeOverlayImage,
          makeRotateImage: makeRotateImage,
          makeScaleImage: makeScaleImage,
          makeCropImage: makeCropImage,
          makeFrameImage: makeFrameImage,
          makeFlipImage: makeFlipImage,
          makeTextImage: makeTextImage,
          makeImageDataImage: makeImageDataImage,
          makeFileImage: makeFileImage,
          makeVideoImage: makeFileVideo,

          imageToColorList: imageToColorList,
          colorListToImage: colorListToImage,


          isImage: isImage,
          isScene: isScene,
          isColorOrColorString: isColorOrColorString,
          isAngle: isAngle,
          isSideCount: isSideCount,
          isStepCount: isStepCount,
          isPointsCount: isPointsCount,


          isSceneImage: isSceneImage,
          isCircleImage: isCircleImage,
          isStarImage: isStarImage,
          isRectangleImage: isRectangleImage,
          isPolygonImage: isPolygonImage,
          isRhombusImage: isRhombusImage,
          isSquareImage: isSquareImage,
          isTriangleImage: isTriangleImage,
          isEllipseImage: isEllipseImage,
          isLineImage: isLineImage,
          isOverlayImage: isOverlayImage,
          isRotateImage: isRotateImage,
          isScaleImage: isScaleImage,
          isCropImage: isCropImage,
          isFrameImage: isFrameImage,
          isFlipImage: isFlipImage,
          isTextImage: isTextImage,
          isFileImage: isFileImage,
          isFileVideo: isFileVideo,



          makeColor: makeColor,
          isColor: isColor,
          colorRed: colorRed,
          colorGreen: colorGreen,
          colorBlue: colorBlue,
          colorAlpha: colorAlpha
        }
      });
    });
  };
});

define('trove/image',[
    "./image-lib",
    "js/js-numbers",
    "js/ffi-helpers"
  ], function(imageLib, jsnums, ffiLib) {

  return function(runtime, namespace) {
    return runtime.loadJSModules(namespace, [imageLib, ffiLib], function(image, ffi) {
      var colorDb = image.colorDb;

      var isString = runtime.isString;

      var isFontFamily = function(x){
          return (isString(x) &&
            (x.toString().toLowerCase() == "default" ||
             x.toString().toLowerCase() == "decorative" ||
             x.toString().toLowerCase() == "roman" ||
             x.toString().toLowerCase() == "script" ||
             x.toString().toLowerCase() == "swiss" ||
             x.toString().toLowerCase() == "modern" ||
             x.toString().toLowerCase() == "symbol" ||
             x.toString().toLowerCase() == "system"))
        || (x === false);		// false is also acceptable
      };
      var isFontStyle = function(x){
          return (isString(x) &&
            (x.toString().toLowerCase() == "normal" ||
             x.toString().toLowerCase() == "italic" ||
             x.toString().toLowerCase() == "slant"))
        || (x === false);		// false is also acceptable
      };
      var isFontWeight = function(x){
          return (isString(x) &&
            (x.toString().toLowerCase() == "normal" ||
             x.toString().toLowerCase() == "bold" ||
             x.toString().toLowerCase() == "light"))
        || (x === false);		// false is also acceptable
      };
      var isMode = function(x) {
        return (isString(x) &&
                (x.toString().toLowerCase() == "solid" ||
                 x.toString().toLowerCase() == "outline")) ||
        ((jsnums.isReal(x)) &&
         (jsnums.greaterThanOrEqual(x, 0) &&
          jsnums.lessThanOrEqual(x, 255)));
      };

      var isPlaceX = function(x) {
          return (isString(x) &&
            (x.toString().toLowerCase() == "left"  ||
             x.toString().toLowerCase() == "right" ||
             x.toString().toLowerCase() == "center" ||
             x.toString().toLowerCase() == "middle"));
      };

      var isPlaceY = function(x) {
          return (isString(x) &&
            (x.toString().toLowerCase() == "top"	  ||
             x.toString().toLowerCase() == "bottom"   ||
             x.toString().toLowerCase() == "baseline" ||
             x.toString().toLowerCase() == "center"   ||
             x.toString().toLowerCase() == "middle"));
      };

      var isStyle = function(x) {
          return (isString(x) &&
            (x.toString().toLowerCase() == "solid" ||
             x.toString().toLowerCase() == "outline"));
      };


      var less = function(lhs, rhs) {
        return (rhs - lhs) > 0.00001;
      }



      var p = function(pred, name) {
        return function(val) { runtime.makeCheckType(pred, name)(val); return val; }
      }

      var checkString = p(runtime.isString, "String");
      var checkStringOrFalse = p(function(val) { return runtime.isString(val) || runtime.isPyretFalse; }, "String or false");

      var checkByte = p(function(val) {
          return runtime.isNumber(val) && jsnums.greaterThanOrEqual(val, 0) && jsnums.greaterThanOrEqual(255, val);
        }, "Number between 0 and 255");
      var checkReal = p(function(val) {
          return runtime.isNumber(val) && jsnums.isReal(val);
        }, "Real Number");
      var checkBoolean = p(runtime.isBoolean, "Boolean");

      var checkNatural = p(function(val) {
          return runtime.isNumber(val) && jsnums.isExactInteger(val) && jsnums.greaterThanOrEqual(val, 0);
        }, "Natural Number");

      var checkPositiveInteger = p(function(val) {
          return runtime.isNumber(val) && jsnums.isExactInteger(val) && jsnums.greaterThanOrEqual(val, 0);
        }, "Positive Integer");

      var checkNonNegativeReal = p(function(val) {
          return runtime.isNumber(val) && jsnums.isReal(val) && jsnums.greaterThanOrEqual(val, 0);
        }, "Non-negative Real Number");

      var _checkColor = p(image.isColorOrColorString, "Color");

      var checkColor = function(val) {
          var aColor = _checkColor(val);
          if (colorDb.get(aColor)) {
            aColor = colorDb.get(aColor);
          }
          return aColor;
      };

      var checkImage = function(val) {
        runtime.makeCheckType(function(v) { return runtime.isOpaque(v) && image.isImage(v.val); }, "Image")(val);
        return val.val;
      }
      var checkImageOrScene = function(val) {
        runtime.makeCheckType(function(v) { return runtime.isOpaque(v) && (image.isImage(val.val) || image.isScene(val.val)); }, "Image")(val);
        return val.val;
      }

      var checkFontFamily = p(isFontFamily, "Font Family");

      var checkFontStyle = p(isFontStyle, "Font Style");

      var checkFontWeight = p(isFontWeight, "Font Weight");

      var checkPlaceX = p(isPlaceX, "X Place");

      var checkPlaceY = p(isPlaceY, "Y Place");


      var checkAngle = p(image.isAngle, "Angle");


      var checkMode = p(isMode, "Mode");

      var checkSideCount = p(image.isSideCount, "Side Count");

      var checkStepCount = p(image.isStepCount, "Step Count");

      var checkPointsCount = p(image.isPointsCount, "Points Count");

      var checkArity = ffi.checkArity;

      var checkListofColor = p(function(val) {
        return ffi.makeList(ffi.toArray(val).map(checkColor));
      }, "List<Color>");

      var throwMessage = ffi.throwMessageException;

      function makeImage(i) {
        return runtime.makeOpaque(i, image.imageEquals);
      }

      // Useful trigonometric functions based on htdp teachpack

      // excess : compute the Euclidean excess
      //  Note: If the excess is 0, then C is 90 deg.
      //        If the excess is negative, then C is obtuse.
      //        If the excess is positive, then C is acuse.
      function excess(sideA, sideB, sideC) {
         return sideA*sideA + sideB*sideB - sideC*sideC;
      }

      // return c^2 = a^2 + b^2 - 2ab cos(C)
      function cosRel(sideA, sideB, angleC) {
          return (sideA*sideA) + (sideB*sideB) - (2*sideA*sideB*Math.cos(angleC * Math.PI/180));
      }

      //////////////////////////////////////////////////////////////////////
      var f = runtime.makeFunction;
      var bitmapURL = f(function(maybeUrl) {
        checkArity(1, arguments, "bitmapURL");
        var url = checkString(maybeUrl);
        runtime.pauseStack(function(restarter) {
          var rawImage = new Image();
          rawImage.onload = function() {
            restarter.resume(makeImage(image.makeFileImage(String(url), rawImage)));
          };
          rawImage.onerror = function(e) {
            restarter.error(runtime.ffi.makeMessageException("unable to load " + url + ": " + e.message));
          };
          rawImage.src = String(url);
        });
      });
      return runtime.makeObject({
        "provide-plus-types": runtime.makeObject({
          types: {
            "Image": runtime.makePrimitiveAnn("Image", image.isImage),
            "Scene": runtime.makePrimitiveAnn("Scene", image.isScene)
          },
          values: runtime.makeObject({
            "circle": f(function(maybeRadius, maybeMode, maybeColor) {
              checkArity(3, arguments, "circle");
              var radius = checkNonNegativeReal(maybeRadius);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(image.makeCircleImage(jsnums.toFixnum(radius), String(mode), color));
            }),
            "is-image-color": f(function(maybeImage) {
              checkArity(1, arguments, "is-image-color");
              return runtime.wrap(image.isColorOrColorString(maybeImage));
            }),
            "is-mode": f(function(maybeMode) {
              checkArity(1, arguments, "is-mode");
              return runtime.wrap(isMode(maybeMode));
            }),
            "is-x-place": f(function(maybeXPlace) {
              checkArity(1, arguments, "is-x-place");
              return runtime.wrap(isPlaceX(maybeXPlace));
            }),
            "is-y-place": f(function(maybeYPlace) {
              checkArity(1, arguments, "is-y-place");
              return runtime.wrap(isPlaceY(maybeYPlace));
            }),
            "is-angle": f(function(maybeAngle) {
              checkArity(1, arguments, "is-angle");
              return runtime.wrap(image.isAngle(maybeAngle));
            }),
            "is-side-count": f(function(maybeSideCount) {
              checkArity(1, arguments, "is-side-count");
              return runtime.wrap(image.isSideCount(maybeSideCount));
            }),
            "is-step-count": f(function(maybeStepCount) {
              checkArity(1, arguments, "is-step-count");
              return runtime.wrap(image.isStepCount(maybeStepCount));
            }),        
            "is-image": f(function(maybeImage) {
              checkArity(1, arguments, "is-image");
              runtime.confirm(maybeImage, runtime.isOpaque);
              return runtime.wrap(image.isImage(maybeImage.val));
            }),
            "bitmap-url": bitmapURL,
            "open-image-url": bitmapURL,
            "image-url": bitmapURL,
            "images-equal": f(function(maybeImage1, maybeImage2) {
              checkArity(2, arguments, "images-equal");
              // TODO: The original version of the image library's equals function passes a union-find datastructure
              // for some reason.  Our runtime.same method doesn't.  Could be a problem...
              var img1 = checkImage(maybeImage1);
              var img2 = checkImage(maybeImage2);
              return runtime.wrap(image.imageEquals(img1, img2));
            }),
            "text": f(function(maybeString, maybeSize, maybeColor) {
              checkArity(3, arguments, "text");
              var string = checkString(maybeString);
              var size = checkPositiveInteger(maybeSize);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeTextImage(String(string), jsnums.toFixnum(size), color,
                                    "normal", "Optimer", "", "", false));
            }),
            "text-font": f(function(maybeString, maybeSize, maybeColor, maybeFace, 
                                    maybeFamily, maybeStyle, maybeWeight, maybeUnderline) {
              checkArity(8, arguments);
              var string = checkString(maybeString);
              var size = checkByte(maybeSize);
              var color = checkColor(maybeColor);
              var face = checkStringOrFalse(maybeFace);
              var family = checkFontFamily(maybeFamily);
              var style = checkFontStyle(maybeStyle);
              var weight = checkFontWeight(maybeWeight);
              var underline = checkBoolean(maybeUnderline);
              return makeImage(
                image.makeTextImage(String(string), jsnums.toFixnum(size), color,
                                    String(face), String(family), String(style),
                                    String(weight), underline));
            }),

            "overlay": f(function(maybeImg1, maybeImg2) {
              checkArity(2, arguments, "overlay");
              var img1 = checkImage(maybeImg1);
              var img2 = checkImage(maybeImg2);
              return makeImage(image.makeOverlayImage(img1, img2, "middle", "middle"));
            }),

            "overlay-xy": f(function(maybeImg1, maybeDx, maybeDy, maybeImg2) {
              checkArity(4, arguments, "overlay-xy");
              var img1 = checkImage(maybeImg1);
              var dx = checkReal(maybeDx);
              var dy = checkReal(maybeDy);
              var img2 = checkImage(maybeImg2);
              return makeImage(
                image.makeOverlayImage(img1, img2, jsnums.toFixnum(dx), jsnums.toFixnum(dy)));
            }),

            "overlay-align": f(function(maybePlaceX, maybePlaceY, maybeImg1, maybeImg2) {
              checkArity(4, arguments, "overlay-align");
              var placeX = checkPlaceX(maybePlaceX);
              var placeY = checkPlaceY(maybePlaceY);
              var img1 = checkImage(maybeImg1);
              var img2 = checkImage(maybeImg2);
              return makeImage(image.makeOverlayImage(img1, img2, String(placeX), String(placeY)));
            }),

            "underlay": f(function(maybeImg1, maybeImg2) {
              checkArity(2, arguments, "underlay");
              var img1 = checkImage(maybeImg1);
              var img2 = checkImage(maybeImg2);
              return makeImage(image.makeOverlayImage(img2, img1, "middle", "middle"));
            }),

            "underlay-xy": f(function(maybeImg1, maybeDx, maybeDy, maybeImg2) {
              checkArity(4, arguments, "underlay-xy");
              var img1 = checkImage(maybeImg1);
              var dx = checkReal(maybeDx);
              var dy = checkReal(maybeDy);
              var img2 = checkImage(maybeImg2);
              return makeImage(
                image.makeOverlayImage(img2, img1, -jsnums.toFixnum(dx), -jsnums.toFixnum(dy)));
            }),

            "underlay-align": f(function(maybePlaceX, maybePlaceY, maybeImg1, maybeImg2) {
              checkArity(4, arguments, "underlay-align");
              var placeX = checkPlaceX(maybePlaceX);
              var placeY = checkPlaceY(maybePlaceY);
              var img1 = checkImage(maybeImg1);
              var img2 = checkImage(maybeImg2);
              return makeImage(image.makeOverlayImage(img2, img1, String(placeX), String(placeY)));
            }),

            "beside": f(function(maybeImg1, maybeImg2) {
              checkArity(2, arguments, "beside");
              var img1 = checkImage(maybeImg1);
              var img2 = checkImage(maybeImg2);
              return makeImage(image.makeOverlayImage(img1, img2, "beside", "middle"));
            }),

            "beside-align": f(function(maybePlaceY, maybeImg1, maybeImg2) {
              checkArity(3, arguments, "beside-align");
              var placeY = checkPlaceY(maybePlaceY);
              var img1 = checkImage(maybeImg1);
              var img2 = checkImage(maybeImg2);
              return makeImage(image.makeOverlayImage(img1, img2, "beside", String(placeY)));
            }),

            "above": f(function(maybeImg1, maybeImg2) {
              checkArity(2, arguments, "above");
              var img1 = checkImage(maybeImg1);
              var img2 = checkImage(maybeImg2);
              return makeImage(image.makeOverlayImage(img1, img2, "middle", "above"));
            }),

            "above-align": f(function(maybePlaceX, maybeImg1, maybeImg2) {
              checkArity(3, arguments, "above-align");
              var placeX = checkPlaceX(maybePlaceX);
              var img1 = checkImage(maybeImg1);
              var img2 = checkImage(maybeImg2);
              return makeImage(image.makeOverlayImage(img1, img2, String(placeX), "above"));
            }),

            "empty-scene": f(function(maybeWidth, maybeHeight) {
              checkArity(2, arguments, "empty-scene");
              var width = checkNonNegativeReal(maybeWidth);
              var height = checkNonNegativeReal(maybeHeight);
              return makeImage(
                image.makeSceneImage(jsnums.toFixnum(width), jsnums.toFixnum(height), [], true));
            }),
            "put-image": f(function(maybePicture, maybeX, maybeY, maybeBackground) {
              checkArity(4, arguments, "put-image");
              var picture = checkImage(maybePicture);
              var x = checkReal(maybeX);
              var y = checkReal(maybeY);
              var background = checkImageOrScene(maybeBackground);
              if (image.isScene(background)) {
                return makeImage(background.add(picture, jsnums.toFixnum(x), background.getHeight() - jsnums.toFixnum(y)));
              } else {
                var newScene = image.makeSceneImage(background.getWidth(), background.getHeight(), [], false);
                newScene = newScene.add(background, background.getWidth()/2, background.getHeight()/2);
                newScene = newScene.add(picture, jsnums.toFixnum(x), background.getHeight() - jsnums.toFixnum(y));
                return makeImage(newScene);
              }
            }),
            "place-image": f(function(maybePicture, maybeX, maybeY, maybeBackground) {
              checkArity(4, arguments, "place-image");
              var picture = checkImage(maybePicture);
              var x = checkReal(maybeX);
              var y = checkReal(maybeY);
              var background = checkImageOrScene(maybeBackground);
              if (image.isScene(background)) {
                return makeImage(background.add(picture, jsnums.toFixnum(x), jsnums.toFixnum(y)));
              } else {
                var newScene = image.makeSceneImage(background.getWidth(), background.getHeight(), [], false);
                newScene = newScene.add(background, background.getWidth()/2, background.getHeight()/2);
                newScene = newScene.add(picture, jsnums.toFixnum(x), jsnums.toFixnum(y));
                return makeImage(newScene);
              }
            }),
            "place-image-align": f(function(maybeImg, maybeX, maybeY, maybePlaceX, maybePlaceY, maybeBackground) {
              checkArity(6, arguments, "place-image-align");
              var img = checkImage(maybeImg);
              var x = checkReal(maybeX);
              var y = checkReal(maybeY);
              var placeX = checkPlaceX(maybePlaceX);
              var placeY = checkPlaceY(maybePlaceY);
              var background = checkImageOrScene(maybeBackground);
              if      (placeX == "left"  ) { x = x + img.getWidth()/2; }
              else if (placeX == "right" ) { x = x - img.getWidth()/2; }
              if      (placeY == "top"   ) { y = y + img.getHeight()/2; }
              else if (placeY == "bottom") { y = y - img.getHeight()/2; }

              if (image.isScene(background)) {
                return makeImage(background.add(img, jsnums.toFixnum(x), jsnums.toFixnum(y)));
              } else {
                var newScene = image.makeSceneImage(background.getWidth(),
                                              background.getHeight(),
                                              [], 
                                              false);
                newScene = newScene.add(background, background.getWidth()/2, background.getHeight()/2);
                newScene = newScene.add(img, jsnums.toFixnum(x), jsnums.toFixnum(y));
                return makeImage(newScene);
              }
            }),

            "rotate": f(function(maybeAngle, maybeImg) {
              checkArity(2, arguments, "rotate");
              var angle = checkAngle(maybeAngle);
              var img = checkImage(maybeImg);
              return makeImage(image.makeRotateImage(jsnums.toFixnum(-angle), img));
            }),

            "scale": f(function(maybeFactor, maybeImg) {
              checkArity(2, arguments, "scale");
              var factor = checkReal(maybeFactor);
              var img = checkImage(maybeImg);
              return makeImage(image.makeScaleImage(jsnums.toFixnum(factor), jsnums.toFixnum(factor), img));
            }),
              
            "scale-xy": f(function(maybeXFactor, maybeYFactor, maybeImg) {
              checkArity(3, arguments, "scale-xy");
              var xFactor = checkReal(maybeXFactor);
              var yFactor = checkReal(maybeYFactor);
              var img = checkImage(maybeImg);
              return makeImage(image.makeScaleImage(jsnums.toFixnum(xFactor), jsnums.toFixnum(yFactor), img));
            }),

            "flip-horizontal": f(function(maybeImg) {
              checkArity(1, arguments, "flip-horizontal");
              var img = checkImage(maybeImg);
              return makeImage(image.makeFlipImage(img, "horizontal"));
            }),

            "flip-vertical": f(function(maybeImg) {
              checkArity(1, arguments, "flip-vertical");
              var img = checkImage(maybeImg);
              return makeImage(image.makeFlipImage(img, "vertical"));
            }),

            "frame": f(function(maybeImg) {
              checkArity(1, arguments, "frame");
              var img = checkImage(maybeImg);
              return makeImage(image.makeFrameImage(img));
            }),
            
            "crop": f(function(maybeX, maybeY, maybeWidth, maybeHeight, maybeImg) {
              checkArity(5, arguments, "crop");
              var x = checkReal(maybeX);
              var y = checkReal(maybeY);
              var width = checkNonNegativeReal(maybeWidth);
              var height = checkNonNegativeReal(maybeHeight);
              var img = checkImage(maybeImg);
              return makeImage(image.makeCropImage(jsnums.toFixnum(x), jsnums.toFixnum(y),
                                                            jsnums.toFixnum(width), jsnums.toFixnum(height), img));
            }),

            "line": f(function(maybeX, maybeY, maybeC) {
              checkArity(3, arguments, "line");
              var x = checkReal(maybeX);
              var y = checkReal(maybeY);
              var c = checkColor(maybeC);
              return makeImage(
                image.makeLineImage(jsnums.toFixnum(x), jsnums.toFixnum(y), c, true));
            }),

            "add-line": f(function(maybeImg, maybeX1, maybeY1, maybeX2, maybeY2, maybeC) {
              checkArity(6, arguments, "add-line");
              var x1 = checkReal(maybeX1);
              var y1 = checkReal(maybeY1);
              var x2 = checkReal(maybeX2);
              var y2 = checkReal(maybeY2);
              var c = checkColor(maybeC);
              var img = checkImage(maybeImg);
              var line = image.makeLineImage(jsnums.toFixnum(x2 - x1), jsnums.toFixnum(y2 - y1), c, true);
              var leftmost = Math.min(x1, x2);
              var topmost = Math.min(y1, y2);
              return makeImage(image.makeOverlayImage(line, img, -leftmost, -topmost));
            }),

            "scene-line": f(function(maybeImg, maybeX1, maybeY1, maybeX2, maybeY2, maybeC) {
              checkArity(6, arguments, "scene-line");
              var x1 = checkReal(maybeX1);
              var y1 = checkReal(maybeY1);
              var x2 = checkReal(maybeX2);
              var y2 = checkReal(maybeY2);
              var c = checkColor(maybeC);
              var img = checkImage(maybeImg);
              var line = image.makeLineImage(jsnums.toFixnum(x2 - x1), jsnums.toFixnum(y2 - y1), c, true);

              var newScene = image.makeSceneImage(jsnums.toFixnum(img.getWidth()), 
                                                  jsnums.toFixnum(img.getHeight()),
                                                  [],
                                                  true);
              newScene = newScene.add(img, img.getWidth()/2, img.getHeight()/2);
              // make an image containing the line
              var line = image.makeLineImage(jsnums.toFixnum(x2-x1),
                                             jsnums.toFixnum(y2-y1),
                                             c,
                                             false),
              leftMost = Math.min(x1,x2),
              topMost = Math.min(y1,y2);
              return makeImage(newScene.add(line, line.getWidth()/2+leftMost, line.getHeight()/2+topMost));
            }),

            "square": f(function(maybeSide, maybeMode, maybeColor) {
              checkArity(3, arguments, "square");
              var side = checkNonNegativeReal(maybeSide);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(image.makeSquareImage(jsnums.toFixnum(side), String(mode), color));
            }),

            "rectangle": f(function(maybeWidth, maybeHeight, maybeMode, maybeColor) {
              checkArity(4, arguments, "rectangle");
              var width = checkNonNegativeReal(maybeWidth);
              var height = checkNonNegativeReal(maybeHeight);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeRectangleImage(jsnums.toFixnum(width), jsnums.toFixnum(height), String(mode), color));
            }),

            "regular-polygon": f(function(maybeLength, maybeCount, maybeMode, maybeColor) {
              checkArity(4, arguments, "regular-polygon");
              var length = checkNonNegativeReal(maybeLength);
              var count = checkNonNegativeReal(maybeCount);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makePolygonImage(jsnums.toFixnum(length), jsnums.toFixnum(count), jsnums.toFixnum(1), String(mode), color));
            }),

            "ellipse": f(function(maybeWidth, maybeHeight, maybeMode, maybeColor) {
              checkArity(4, arguments, "ellipse");
              var width = checkNonNegativeReal(maybeWidth);
              var height = checkNonNegativeReal(maybeHeight);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeEllipseImage(jsnums.toFixnum(width), jsnums.toFixnum(height), String(mode), color));
            }),

            "triangle": f(function(maybeSide, maybeMode, maybeColor) {
              checkArity(3, arguments, "triangle");
              var side = checkNonNegativeReal(maybeSide);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                // Angle makes triangle point up
                image.makeTriangleImage(jsnums.toFixnum(side), jsnums.toFixnum(360-60), jsnums.toFixnum(side),
                                        String(mode), color));
            }),

            "triangle-sas": f(function(maybeSideA, maybeAngleB, maybeSideC, maybeMode, maybeColor) {
              checkArity(5, arguments, "triangle-sas");
              var sideA = checkNonNegativeReal(maybeSideA);
              var angleB = checkAngle(maybeAngleB);
              var sideC = checkNonNegativeReal(maybeSideC);
              
              var sideB2 = cosRel(sideA, sideC, angleB);
              var sideB  = Math.sqrt(sideB2);
              
              if (sideB2 <= 0) {
                throwMessage("The given side, angle and side will not form a triangle: " 
                             + sideA + ", " + angleB + ", " + sideC);
              } else {
                if (less(sideA + sideC, sideB) ||
                    less(sideB + sideC, sideA) ||
                    less(sideA + sideB, sideC)) {
                  throwMessage("The given side, angle and side will not form a triangle: " 
                               + sideA + ", " + angleB + ", " + sideC);
                }
              }

              var angleA = Math.acos(excess(sideB, sideC, sideA) / (2 * sideB * sideC)) * (180 / Math.PI);

              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeTriangleImage(jsnums.toFixnum(sideC), jsnums.toFixnum(angleA), jsnums.toFixnum(sideB), 
                                        String(mode), color));
            }),

            "triangle-sss": f(function(maybeSideA, maybeSideB, maybeSideC, maybeMode, maybeColor) {
              checkArity(5, arguments, "triangle-sss");
              var sideA = checkNonNegativeReal(maybeSideA);
              var sideB = checkNonNegativeReal(maybeSideB);
              var sideC = checkNonNegativeReal(maybeSideC);
              if (less(sideA + sideB, sideC) ||
                  less(sideC + sideB, sideA) ||
                  less(sideA + sideC, sideB)) {
                throwMessage("The given sides will not form a triangle: " 
                             + sideA + ", " + sideB + ", " + sideC);
              }

              var angleA = Math.acos(excess(sideB, sideC, sideA) / (2 * sideB * sideC)) * (180 / Math.PI);

              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeTriangleImage(jsnums.toFixnum(sideC), jsnums.toFixnum(angleA), jsnums.toFixnum(sideB), 
                                        String(mode), color));
            }),

            "triangle-ass": f(function(maybeAngleA, maybeSideB, maybeSideC, maybeMode, maybeColor) {
              checkArity(5, arguments, "triangle-ass");
              var angleA = checkAngle(maybeAngleA);
              var sideB = checkNonNegativeReal(maybeSideB);
              var sideC = checkNonNegativeReal(maybeSideC);
              if (less(180, angleA)) {
                throwMessage("The given angle, side and side will not form a triangle: " 
                             + angleA + ", " + sideB + ", " + sideC);
              }
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeTriangleImage(jsnums.toFixnum(sideC), jsnums.toFixnum(angleA), jsnums.toFixnum(sideB), 
                                        String(mode), color));
            }),

            "triangle-ssa": f(function(maybeSideA, maybeSideB, maybeAngleC, maybeMode, maybeColor) {
              checkArity(5, arguments, "triangle-ssa");
              var sideA  = checkNonNegativeReal(maybeSideA);
              var sideB  = checkNonNegativeReal(maybeSideB);
              var angleC = checkAngle(maybeAngleC);
              if (less(180, angleC)) {
                throwMessage("The given side, side and angle will not form a triangle: " 
                             + sideA + ", " + sideB + ", " + angleC);
              }
              var sideC2 = cosRel(sideA, sideB, angleC);
              var sideC  = Math.sqrt(sideC2);
              
              if (sideC2 <= 0) {
                throwMessage("The given side, side and angle will not form a triangle: " 
                             + sideA + ", " + sideB + ", " + angleC);
              } else {
                if (less(sideA + sideB, sideC) ||
                    less(sideC + sideB, sideA) ||
                    less(sideA + sideC, sideB)) {
                  throwMessage("The given side, side and angle will not form a triangle: " 
                               + sideA + ", " + sideB + ", " + angleC);
                }
              }

              var angleA = Math.acos(excess(sideB, sideC, sideA) / (2 * sideB * sideC)) * (180 / Math.PI);

              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeTriangleImage(jsnums.toFixnum(sideC), jsnums.toFixnum(angleA), jsnums.toFixnum(sideB), 
                                        String(mode), color));
            }),

            "triangle-aas": f(function(maybeAngleA, maybeAngleB, maybeSideC, maybeMode, maybeColor) {
              checkArity(5, arguments, "triangle-aas");
              var angleA = checkAngle(maybeAngleA);
              var angleB = checkAngle(maybeAngleB);
              var sideC = checkNonNegativeReal(maybeSideC);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              var angleC = (180 - angleA - angleB);
              if (less(angleC, 0)) {
                throwMessage("The given angle, angle and side will not form a triangle: " 
                             + angleA + ", " + angleB + ", " + sideC);
              }
              var hypotenuse = sideC / (Math.sin(angleC*Math.PI/180))
              var sideB = hypotenuse * Math.sin(angleB*Math.PI/180);
              return makeImage(
                image.makeTriangleImage(jsnums.toFixnum(sideC), jsnums.toFixnum(angleA), jsnums.toFixnum(sideB), 
                                        String(mode), color));
            }),

            "triangle-asa": f(function(maybeAngleA, maybeSideB, maybeAngleC, maybeMode, maybeColor) {
              checkArity(5, arguments, "triangle-asa");
              var angleA = checkAngle(maybeAngleA);
              var sideB = checkNonNegativeReal(maybeSideB);
              var angleC = checkAngle(maybeAngleC);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              var angleB = (180 - angleA - angleC);
              if (less(angleB, 0)) {
                throwMessage("The given angle, side and angle will not form a triangle: " 
                             + angleA + ", " + sideB + ", " + angleC);
              }
              var base = (sideB * Math.sin(angleA*Math.PI/180)) / (Math.sin(angleB*Math.PI/180));
              var sideC = (sideB * Math.sin(angleC*Math.PI/180)) / (Math.sin(angleB*Math.PI/180));
              return makeImage(
                image.makeTriangleImage(jsnums.toFixnum(sideC), jsnums.toFixnum(angleA), jsnums.toFixnum(sideB), 
                                        String(mode), color));
            }),

            "triangle-saa": f(function(maybeSideA, maybeAngleB, maybeAngleC, maybeMode, maybeColor) {
              checkArity(5, arguments, "triangle-saa");
              var sideA = checkNonNegativeReal(maybeSideA);
              var angleB = checkAngle(maybeAngleB);
              var angleC = checkAngle(maybeAngleC);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              var angleA = (180 - angleC - angleB);
              var hypotenuse = sideA / (Math.sin(angleA*Math.PI/180));
              var sideC = hypotenuse * Math.sin(angleC*Math.PI/180);
              var sideB = hypotenuse * Math.sin(angleB*Math.PI/180);
              return makeImage(
                image.makeTriangleImage(jsnums.toFixnum(sideC), jsnums.toFixnum(angleA), jsnums.toFixnum(sideB), 
                                        String(mode), color));
            }),

            "right-triangle": f(function(maybeSide1, maybeSide2, maybeMode, maybeColor) {
              checkArity(4, arguments, "right-triangle");
              var side1 = checkNonNegativeReal(maybeSide1);
              var side2 = checkNonNegativeReal(maybeSide2);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                // add 180 to make the triangle point up
                image.makeTriangleImage(jsnums.toFixnum(side1), jsnums.toFixnum(360-90), jsnums.toFixnum(side2),
                                       String(mode), color));
            }),

            "isosceles-triangle": f(function(maybeSide, maybeAngleC, maybeMode, maybeColor) {
              checkArity(4, arguments, "isosceles-triangle");
              var side = checkNonNegativeReal(maybeSide);
              var angleC = checkAngle(maybeAngleC);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              var angleAB = (180-angleC)/2;
              var base = 2*side*Math.sin((angleC*Math.PI/180)/2);
              return makeImage(
                // add 180 to make the triangle point up
                image.makeTriangleImage(jsnums.toFixnum(base), jsnums.toFixnum(360-angleAB), jsnums.toFixnum(side), 
                                        String(mode), color));
            }),

            "star": f(function(maybeSide, maybeMode, maybeColor) {
              checkArity(3, arguments, "star");
              var side = checkNonNegativeReal(maybeSide);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makePolygonImage(jsnums.toFixnum(side), jsnums.toFixnum(5), jsnums.toFixnum(2),
                                    String(mode), color));
            }),
            // TODO: This was split from the variable-arity case in the original whalesong "star" function
            "star-sized": f(function(maybeSideCount, maybeOuter, maybeInner, maybeMode, maybeColor) {
              checkArity(5, arguments, "star-sized");
              var sideCount = checkSideCount(maybeSideCount);
              var outer = checkNonNegativeReal(maybeOuter);
              var inner = checkNonNegativeReal(maybeInner);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeStarImage(jsnums.toFixnum(sideCount), jsnums.toFixnum(inner), jsnums.toFixnum(outer),
                                    String(mode), color));
            }),
            // TODO: Same as star-sized?
            "radial-star": f(function(maybePoints, maybeOuter, maybeInner, maybeMode, maybeColor) {
              checkArity(5, arguments, "radial-star");
              var points = checkPointsCount(maybePoints);
              var outer = checkNonNegativeReal(maybeOuter);
              var inner = checkNonNegativeReal(maybeInner);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeStarImage(jsnums.toFixnum(points), jsnums.toFixnum(inner), jsnums.toFixnum(outer),
                                    String(mode), color));
            }),

            "star-polygon": f(function(maybeLength, maybeCount, maybeStep, maybeMode, maybeColor) {
              checkArity(5, arguments, "star-polygon");
              var length = checkNonNegativeReal(maybeLength);
              var count = checkNonNegativeReal(maybeCount);
              var step = checkStepCount(maybeStep);
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makePolygonImage(jsnums.toFixnum(length), jsnums.toFixnum(count), jsnums.toFixnum(step),
                                    String(mode), color));
            }),

            "rhombus": f(function(maybeLength, maybeAngle, maybeMode, maybeColor) {
              checkArity(4, arguments, "rhombus");
              var length = checkNonNegativeReal(maybeLength);
              var angle = checkAngle(maybeAngle); // TODO: This was originally checkNonNegativeReal, seemed like a bug
              var mode = checkMode(maybeMode);
              var color = checkColor(maybeColor);
              return makeImage(
                image.makeRhombusImage(jsnums.toFixnum(length), jsnums.toFixnum(angle), String(mode), color));
            }),

            "image-to-color-list": f(function(maybeImage) {
              checkArity(1, arguments, "image-to-color-list");
              var img = checkImage(maybeImage);
              return image.imageToColorList(img);
            }),

            "color-list-to-image": f(function(maybeList, maybeWidth, maybeHeight, maybePinholeX, maybePinholeY) {
              checkArity(5, arguments, "color-list-to-image");
              var loc = checkListofColor(maybeList);
              var width = checkNatural(maybeWidth);
              var height = checkNatural(maybeHeight);
              var pinholeX = checkNatural(maybePinholeX);
              var pinholeY = checkNatural(maybePinholeY);
              // TODO: why no jsnums.toFixnum here?
              return makeImage(image.colorListToImage(loc, width, height, pinholeX, pinholeY));
            }),

            "color-list-to-bitmap": f(function(maybeList, maybeWidth, maybeHeight) {
              checkArity(3, arguments, "color-list-to-bitmap");
              var loc = checkListofColor(maybeList);
              var width = checkNatural(maybeWidth);
              var height = checkNatural(maybeHeight);
              return makeImage(image.colorListToImage(loc, width, height, 0, 0));
            }),
            
            "image-width": f(function(maybeImg) {
              checkArity(1, arguments, "image-width");
              var img = checkImage(maybeImg);
              return runtime.wrap(img.getWidth());
            }),

            "image-height": f(function(maybeImg) {
              checkArity(1, arguments, "image-height");
              var img = checkImage(maybeImg);
              return runtime.wrap(img.getHeight());
            }),

            "image-baseline": f(function(maybeImg) {
              checkArity(1, arguments, "image-baseline");
              var img = checkImage(maybeImg);
              return runtime.wrap(img.getBaseline());
            }),

            "name-to-color": f(function(maybeName) {
              checkArity(1, arguments, "name-to-color");
              var name = checkString(maybeName);
              return runtime.wrap(colorDb.get(String(name)) || false);
            })
          }),
        }),
        answer: runtime.namespace.get("nothing")
      });
    });
  } // end rt/ns fun
});


define('trove/world-lib',["js/runtime-util"], function(util) {

  return util.memoModule("world-lib", function(runtime, namespace) {
    var rawJsworld = {};

    // Stuff here is copy-and-pasted from Chris King's JSWorld.
    //
    // dyoo: as I remember, most of this code had been revised from
    // Chris's original code by Ethan Cechetti, who rewrote it to
    // continuation passing style during summer 2010.

    

    /* Type signature notation
     * CPS(a b ... -> c) is used to denote
     *    a b ... (c -> void) -> void
     */

    var Jsworld = rawJsworld;

    var currentFocusedNode = false;

    var doNothing = function() {};

    // forEachK: CPS( array CPS(array -> void) (error -> void) -> void )
    // Iterates through an array and applies f to each element using CPS
    // If an error is thrown, it catches the error and calls f_error on it
    var forEachK = function(a, f, f_error, k) {
        var forEachHelp = function(i) {
            if( i >= a.length ) {
                if (k) {
                    return k();
                } else {
                    return;
                }
            }
            try {
                return f(a[i], function() { return forEachHelp(i+1); });
            } catch (e) {
                return Jsworld.shutdown({errorShutdown: e});
            }
        };
        return forEachHelp(0);
    };







    //
    // WORLD STUFFS
    //

    function InitialWorld() {}

    var world = new InitialWorld();
    var worldListeners = [];
    var eventDetachers = [];
    var runningBigBangs = [];

    var changingWorld = false;



    function clear_running_state() {
        var i;
        world = new InitialWorld();
        worldListeners = [];

        for (i = 0; i < eventDetachers.length; i++) {
                eventDetachers[i]();
        }
        eventDetachers = [];
        changingWorld = false;
    }



    // Close all world computations.
    Jsworld.shutdown = function(options) {
        while(runningBigBangs.length > 0) {
            var currentRecord = runningBigBangs.pop();
            if (currentRecord) { currentRecord.pause(); }
            if (options.cleanShutdown) {
                currentRecord.success(world);
            }
            if (options.errorShutdown) {
                currentRecord.fail(options.errorShutdown);
            }
        }
        clear_running_state();
    };



    function add_world_listener(listener) {
        worldListeners.push(listener);
    }


    function remove_world_listener(listener) {
        var i, index = -1;
        for (i = 0; i < worldListeners.length; i++) {
            if (worldListeners[i] === listener) {
                index = i;
                break;
            }
        }
        if (index !== -1) {
            worldListeners.splice(index, 1);
        }
    }


    // If we're in the middle of a change_world, delay.
    var DELAY_BEFORE_RETRY = 10;


    // change_world: CPS( CPS(world -> world) -> void )
    // Adjust the world, and notify all listeners.
    var change_world = function(updater, k) {

        // Check to see if we're in the middle of changing
        // the world already.  If so, put on the queue
        // and exit quickly.
        if (changingWorld) {
            setTimeout(
                function() {
                    change_world(updater, k);
                },
                DELAY_BEFORE_RETRY);
            return;
        }


        changingWorld = true;
        var originalWorld = world;

        var changeWorldHelp;
        changeWorldHelp = function() {
            forEachK(worldListeners,
                     function(listener, k2) {
                         listener(world, originalWorld, k2);
                     },
                     function(e) {
                         changingWorld = false;
                         world = originalWorld;
                         throw e; 
                     },
                     function() {
                         changingWorld = false;
                         k();
                     });
        };

        try {
            updater(world, function(newWorld) {
                world = newWorld;
                changeWorldHelp();
            });
        } catch(e) {
            changingWorld = false;
            world = originalWorld;
            return Jsworld.shutdown({errorShutdown: e});
        }
    };
    Jsworld.change_world = change_world;



    var map = function(a1, f) {
        var b = new Array(a1.length), i;
        for (i = 0; i < a1.length; i++) {
                b[i] = f(a1[i]);
        }
        return b;
    };

    var concat_map = function(a, f) {
        var b = [], i;
        for (i = 0; i < a.length; i++) {
                b = b.concat(f(a[i]));
        }
        return b;
    };


    function member(a, x) {
        var i;
        for (i = 0; i < a.length; i++) {
            if (a[i] === x) {
                return true;
            }
        }
        return false;
    }


    //
    // DOM UPDATING STUFFS
    //

    // tree(N): { node: N, children: [tree(N)] }
    // relation(N): { relation: 'parent', parent: N, child: N } | { relation: 'neighbor', left: N, right: N }
    // relations(N): [relation(N)]
    // nodes(N): [N]
    // css(N): [css_node(N)]
    // css_node(N): { node: N, attribs: attribs } | { className: string, attribs: attribs }
    // attrib: { attrib: string, values: [string] }
    // attribs: [attrib]

    // treeable(nodes(N), relations(N)) = bool
    /*function treeable(nodes, relations) {
    // for all neighbor relations between x and y
    for (var i = 0; i < relations.length; i++)
    if (relations[i].relation == 'neighbor') {
    var x = relations[i].left, y = relations[i].right;

    // there does not exist a neighbor relation between x and z!=y or z!=x and y
    for (var j = 0; j < relations.length; j++)
    if (relations[j].relation === 'neighbor')
    if (relations[j].left === x && relations[j].right !== y ||
    relations[j].left !== x && relations[j].right === y)
    return false;
    }

    // for all parent relations between x and y
    for (var i = 0; i < relations.length; i++)
    if (relations[i].relation == 'parent') {
    var x = relations[i].parent, y = relations[i].child;

    // there does not exist a parent relation between z!=x and y
    for (var j = 0; j < relations.length; j++)
    if (relations[j].relation == 'parent')
    if (relations[j].parent !== x && relations[j].child === y)
    return false;
    }

    // for all neighbor relations between x and y
    for (var i = 0; i < relations.length; i++)
    if (relations[i].relation == 'neighbor') {
    var x = relations[i].left, y = relations[i].right;

    // all parent relations between z and x or y share the same z
    for (var j = 0; j < relations.length; j++)
    if (relations[j].relation == 'parent')
    for (var k = 0; k < relations.length; k++)
    if (relations[k].relation == 'parent')
    if (relations[j].child === x && relations[k].child === y &&
    relations[j].parent !== relations[k].parent)
    return false;
    }

    return true;
    }*/


    // node_to_tree: dom -> dom-tree
    // Given a native dom node, produces the appropriate tree.
    function node_to_tree(domNode) {
        var result = [domNode], c;
        for (c = domNode.firstChild; c !== null; c = c.nextSibling) {
            result.push(node_to_tree(c));
        }
        return result;
    }
    Jsworld.node_to_tree = node_to_tree;



    // nodes(tree(N)) = nodes(N)
    function nodes(tree) {
        var ret, i;
        if (tree.node.jsworldOpaque === true) {
            return [tree.node];
        }

        ret = [tree.node];
        for (i = 0; i < tree.children.length; i++) {
            ret = ret.concat(nodes(tree.children[i]));
        }
        return ret;
    }


    // relations(tree(N)) = relations(N)
    function relations(tree) {
        var ret = [];
        var i;
        for (i = 0; i < tree.children.length; i++) {
            ret.push({ relation: 'parent',
                       parent: tree.node,
                       child: tree.children[i].node });
        }

        for (i = 0; i < tree.children.length - 1; i++) {
            ret.push({ relation: 'neighbor',
                       left: tree.children[i].node,
                       right: tree.children[i + 1].node });
        }

        if (! tree.node.jsworldOpaque) {
            for (i = 0; i < tree.children.length; i++) {
                ret = ret.concat(relations(tree.children[i]));
            }
        }

        return ret;
    }





    // Preorder traversal.
    var preorder = function(node, f) {
        f(node, function() {
            var child = node.firstChild;
            var nextSibling;
            while (child) {
                nextSibling = child.nextSibling;
                preorder(child, f);
                child = nextSibling;
            }
        });
    };


    // nodeEq: node node -> boolean
    // Returns true if the two nodes should be the same.
    var nodeEq = function(node1, node2) {
        return (node1 && node2 && node1 === node2);
    };


    // isMemq: X (arrayof X) -> boolean
    // Produces true if any of the elements of L are nodeEq to x.
    var isMemq = function(x, L) {
        var i;
        for (i = 0 ; i < L.length; i++) {
            if (nodeEq(x, L[i])) {
                return true;
            }
        }
        return false;
    };



    // If any node cares about the world, send it in.
    function refresh_node_values(nodes) {
        var i;
        for (i = 0; i < nodes.length; i++) {
            if (nodes[i].onWorldChange) {
                nodes[i].onWorldChange(world);
            }
        }
    }



    // update_dom(nodes(Node), relations(Node)) = void
    function update_dom(toplevelNode, nodes, relations) {
        var i, parent, child;
        // TODO: rewrite this to move stuff all in one go... possible? necessary?

        // move all children to their proper parents
        for (i = 0; i < relations.length; i++) {
            if (relations[i].relation === 'parent') {
                parent = relations[i].parent;
                child = relations[i].child;
                if (child.parentNode !== parent) {
                    parent.appendChild(child);
                }
            }
        }

        // arrange siblings in proper order
        // truly terrible... BUBBLE SORT
        var unsorted = true;
        while (unsorted) {
            unsorted = false;
            for (i = 0; i < relations.length; i++) {
                if (relations[i].relation === 'neighbor') {
                    var left = relations[i].left, right = relations[i].right;

                    if (! nodeEq(left.nextSibling, right)) {
                        left.parentNode.insertBefore(left, right);
                        unsorted = true;
                    }
                }
            }
        }

        // Finally, remove nodes that shouldn't be attached anymore.
        var nodesPlus = nodes.concat([toplevelNode]);
        preorder(toplevelNode, function(aNode, continueTraversalDown) {
            if (aNode.jsworldOpaque) {
                if (! isMemq(aNode, nodesPlus)) {
                    aNode.parentNode.removeChild(aNode);
                }
            } else {
                if (! isMemq(aNode, nodesPlus)) {
                    aNode.parentNode.removeChild(aNode);
                } else {
                    continueTraversalDown();
                }
            }
        });

        refresh_node_values(nodes);
    }



    // camelCase: string -> string
    function camelCase(name) {
        return name.replace(/\-(.)/g, function(m, l){return l.toUpperCase();});
    }


    function set_css_attribs(node, attribs) {
        var j;
        for (j = 0; j < attribs.length; j++){
            node.style[camelCase(attribs[j].attrib)] = attribs[j].values.join(" ");
        }
    }


    // isMatchingCssSelector: node css -> boolean
    // Returns true if the CSS selector matches.
    function isMatchingCssSelector(node, css) {
        if (css.id.match(/^\./)) {
            // Check to see if we match the class
            return (node.className && member(node.className.split(/\s+/),
                                             css.id.substring(1)));
        } else {
            return (node.id && node.id === css.id);
        }
    }


    var clearCss = function(node) {
        // FIXME: we should not be clearing the css
  //      if ('style' in node)
  //          node.style.cssText = "";
    };



    function update_css(nodes, css) {
        // clear CSS
        var i, j;
        for (i = 0; i < nodes.length; i++) {
            if ( !nodes[i].jsworldOpaque ) {
                    clearCss(nodes[i]);
            }
        }

        // set CSS
        for (i = 0; i < css.length; i++) {
            if (css[i].id) {
                for (j = 0; j < nodes.length; j++) {
                    if (isMatchingCssSelector(nodes[j], css[i])) {
                        set_css_attribs(nodes[j], css[i].attribs);
                    }
                }
            } else {
                set_css_attribs(css[i].node, css[i].attribs);
            }
        }
    }



    var sexp2tree;
    var sexp2css;
    var maintainingSelection;



    function do_redraw(world, oldWorld, toplevelNode, redraw_func, redraw_css_func, k) {
        if (oldWorld instanceof InitialWorld) {
            // Simple path
            redraw_func(world,
                function(drawn) {
                        var t = sexp2tree(drawn);
                        var ns = nodes(t);
                        // HACK: css before dom, due to excanvas hack.
                        redraw_css_func(world,
                                function(css) {
                                        update_css(ns, sexp2css(css));
                                        update_dom(toplevelNode, ns, relations(t));
                                        k();
                                });
                });
        } else {
            maintainingSelection(
                function(k2) {
                    redraw_func(
                        world,
                        function(newRedraw) {

                            redraw_css_func(
                                world,
                                function(newRedrawCss) {
                                    var t = sexp2tree(newRedraw);
                                    var ns = nodes(t);
                                    // Try to save the current selection and preserve it across
                                    // dom updates.

                                    // Kludge: update the CSS styles first.
                                    // This is a workaround an issue with excanvas: any style change
                                    // clears the content of the canvas, so we do this first before
                                    // attaching the dom element.
                                    update_css(ns, sexp2css(newRedrawCss));
                                    update_dom(toplevelNode, ns, relations(t));

                                    k2();
                                });
                        });
                }, k);
        }
    }



    var FocusedSelection;

    function hasCurrentFocusedSelection() {
        return currentFocusedNode !== undefined;
    }

    function getCurrentFocusedSelection() {
        return new FocusedSelection();
    }


    // maintainingSelection: (-> void) -> void
    // Calls the thunk f while trying to maintain the current focused selection.
    maintainingSelection = function(f, k) {
        var currentFocusedSelection;
        if (hasCurrentFocusedSelection()) {
            currentFocusedSelection = getCurrentFocusedSelection();
            f(function() {
                currentFocusedSelection.restore();
                k();
            });
        } else {
            f(function() { k(); });
        }
    };



    FocusedSelection = function() {
        this.focused = currentFocusedNode;
        this.selectionStart = currentFocusedNode.selectionStart;
        this.selectionEnd = currentFocusedNode.selectionEnd;
    };

    // Try to restore the focus.
    FocusedSelection.prototype.restore = function() {
        // FIXME: if we're scrolling through, what's visible
        // isn't restored yet.
        if (this.focused.parentNode) {
            this.focused.selectionStart = this.selectionStart;
            this.focused.selectionEnd = this.selectionEnd;
            this.focused.focus();
        } else if (this.focused.id) {
            var matching = document.getElementById(this.focused.id);
            if (matching) {
                matching.selectionStart = this.selectionStart;
                matching.selectionEnd = this.selectionEnd;
                matching.focus();
            }
        }
    };





    //////////////////////////////////////////////////////////////////////

    var bigBang, StopWhenHandler;

    function BigBangRecord(top, world, handlerCreators, handlers, attribs,
                           success, fail) {
        this.top = top;
        this.world = world;
        this.handlers = handlers;
        this.handlerCreators = handlerCreators;
        this.attribs = attribs;
        this.success = success;
        this.fail = fail;
    }

    BigBangRecord.prototype.restart = function() {
        bigBang(this.top, this.world, this.handlerCreators, this.attribs);
    };

    BigBangRecord.prototype.pause = function() {
        var i;
        for(i = 0 ; i < this.handlers.length; i++) {
            if (! (this.handlers[i] instanceof StopWhenHandler)) {
                this.handlers[i].onUnregister(this.top);
            }
        }
    };
    //////////////////////////////////////////////////////////////////////


    var copy_attribs;


    // Notes: bigBang maintains a stack of activation records; it should be possible
    // to call bigBang re-entrantly.
    // top: dom
    // init_world: any
    // handlerCreators: (Arrayof (-> handler))
    // k: any -> void
    bigBang = function(top, init_world, handlerCreators, attribs, succ, fail) {
        var i;
        // clear_running_state();

        // Construct a fresh set of the handlers.
        var handlers = map(handlerCreators, function(x) { return x();} );
        if (runningBigBangs.length > 0) {
            runningBigBangs[runningBigBangs.length - 1].pause();
        }

        // Create an activation record for this big-bang.
        var activationRecord =
            new BigBangRecord(top, init_world, handlerCreators, handlers, attribs, 
                              succ, fail);
        runningBigBangs.push(activationRecord);
        function keepRecordUpToDate(w, oldW, k2) {
            activationRecord.world = w;
            k2();
        }
        add_world_listener(keepRecordUpToDate);



        // Monitor for termination and register the other handlers.
        var stopWhen = new StopWhenHandler(function(w, k2) { k2(false); },
                                           function(w, k2) { k2(w); });
        for(i = 0 ; i < handlers.length; i++) {
            if (handlers[i] instanceof StopWhenHandler) {
                stopWhen = handlers[i];
            } else {
                handlers[i].onRegister(top);
            }
        }
        var watchForTermination = function(w, oldW, k2) {
            stopWhen.test(w,
                          function(stop) {
                              if (stop) {
                                  Jsworld.shutdown({cleanShutdown: true});
                              }
                              else { k2(); }
                          });
        };
        add_world_listener(watchForTermination);


        // Finally, begin the big-bang.
        copy_attribs(top, attribs);
        change_world(function(w, k2) { k2(init_world); }, doNothing);
    };
    Jsworld.bigBang = bigBang;





    // on_tick: number CPS(world -> world) -> handler
    var on_tick = function(delay, tick) {
        return function() {
            var scheduleTick, ticker;
            scheduleTick = function(t) {
                ticker.watchId = setTimeout(
                    function() {
                        ticker.watchId = undefined;
                        var startTime = (new Date()).valueOf();
                        change_world(tick,
                                     function() {
                                         var endTime = (new Date()).valueOf();
                                         scheduleTick(Math.max(delay - (endTime - startTime),
                                                               0));
                                     });
                    },
                    t);
            };

            ticker = {
                watchId: -1,
                onRegister: function (top) {
                    scheduleTick(delay);
                },

                onUnregister: function (top) {
                    if (ticker.watchId) {
                        clearTimeout(ticker.watchId);
                    }
                }
            };
            return ticker;
        };
    };
    Jsworld.on_tick = on_tick;

    var preventDefault, stopPropagation;
    var attachEvent, detachEvent;


    function on_key(press) {
        return function() {
            var wrappedPress = function(e) {
                if(e.keyCode === 27) { return; } // Escape events are not for world; the environment handles them
                stopPropagation(e);
                preventDefault(e);
                change_world(function(w, k) { press(w, e, k); }, doNothing);
            };
            return {
                onRegister: function(top) {
                    //http://www.w3.org/TR/html5/editing.html#sequential-focus-navigation-and-the-tabindex-attribue
                    jQuery(top).attr('tabindex', 1);
                    jQuery(top).focus();
                    attachEvent(top, 'keydown', wrappedPress);
                },
                onUnregister: function(top) {
                    detachEvent(top, 'keydown', wrappedPress);
                }
            };
        };
    }
    Jsworld.on_key = on_key;




    // http://www.quirksmode.org/js/events_mouse.html
    // http://stackoverflow.com/questions/55677/how-do-i-get-the-coordinates-of-a-mouse-click-on-a-canvas-element
    function on_mouse(mouse) {
        return function() {
            var isButtonDown = false;
            var makeWrapped = function(type) {
                return function(e) {
                    preventDefault(e);
                    stopPropagation(e);
                    var x = e.pageX, y = e.pageY;
                    var currentElement = e.target;
                    do {
                        x -= currentElement.offsetLeft;
                        y -= currentElement.offsetTop;
                        currentElement = currentElement.offsetParent;
                    } while(currentElement);

                    if (type === 'button-down') {
                        isButtonDown = true;
                    } else if (type === 'button-up') {
                        isButtonDown = false;
                    }
                    if (type === 'move' && isButtonDown) {
                        change_world(function(w, k) {
                            mouse(w, x, y, 'drag', k);
                        }, doNothing);
                    } else {
                        change_world(function(w, k) {
                            mouse(w, x, y, type, k);
                        }, doNothing);
                    }
                };
            };
            var wrappedDown = makeWrapped('button-down');
            var wrappedUp = makeWrapped('button-up');
            // How do we do drag?
            var wrappedMove = makeWrapped('move');
            var wrappedEnter = makeWrapped('enter');
            var wrappedLeave = makeWrapped('leave');
            return {
                onRegister: function(top) {
                    attachEvent(top, 'mousedown', wrappedDown);
                    attachEvent(top, 'mouseup', wrappedUp);
                    attachEvent(top, 'mousemove', wrappedMove);
                    attachEvent(top, 'mouseenter', wrappedEnter);
                    attachEvent(top, 'mouseleave', wrappedLeave);
                },
                onUnregister: function(top) {
                    detachEvent(top, 'mousedown', wrappedDown);
                    detachEvent(top, 'mouseup', wrappedUp);
                    detachEvent(top, 'mousemove', wrappedMove);
                    detachEvent(top, 'mouseenter', wrappedEnter);
                    detachEvent(top, 'mouseleave', wrappedLeave);
                }
            };
        };
    }
    Jsworld.on_mouse = on_mouse;





    var checkDomSexp;


    //  on_draw: CPS(world -> (sexpof node)) CPS(world -> (sexpof css-style)) -> handler
    function on_draw(redraw, redraw_css) {
        var wrappedRedraw = function(w, k) {
            redraw(w, function(newDomTree) {
                checkDomSexp(newDomTree, newDomTree);
                k(newDomTree);
            });
        };

        return function() {
            var drawer = {
                _top: null,
                _listener: function(w, oldW, k2) {
                    do_redraw(w, oldW, drawer._top, wrappedRedraw, redraw_css, k2);
                },
                onRegister: function (top) {
                    drawer._top = top;
                    add_world_listener(drawer._listener);
                },

                onUnregister: function (top) {
                    remove_world_listener(drawer._listener);
                }
            };
            return drawer;
        };
    }
    Jsworld.on_draw = on_draw;



    StopWhenHandler = function(test, receiver) {
        this.test = test;
        this.receiver = receiver;
    };
    // stop_when: CPS(world -> boolean) CPS(world -> boolean) -> handler
    function stop_when(test, receiver) {
        return function() {
            if (receiver === undefined) {
                receiver = function(w, k) { k(w); };
            }
            return new StopWhenHandler(test, receiver);
        };
    }
    Jsworld.stop_when = stop_when;



    function on_world_change(f) {
        var listener = function(world, oldW, k) { f(world, k); };
        return function() {
            return {
                onRegister: function (top) {
                    add_world_listener(listener); },
                onUnregister: function (top) {
                    remove_world_listener(listener); }
            };
        };
    }
    Jsworld.on_world_change = on_world_change;





    // Compatibility for attaching events to nodes.
    attachEvent = function(node, eventName, fn) {
        if (node.addEventListener) {
            // Mozilla
            node.addEventListener(eventName, fn, false);
        } else {
            // IE
            node.attachEvent('on' + eventName, fn, false);
        }
    };

    detachEvent = function(node, eventName, fn) {
        if (node.addEventListener) {
            // Mozilla
            node.removeEventListener(eventName, fn, false);
        } else {
            // IE
            node.detachEvent('on' + eventName, fn, false);
        }
    };

    //
    // DOM CREATION STUFFS
    //

    // add_ev: node string CPS(world event -> world) -> void
    // Attaches a world-updating handler when the world is changed.
    function add_ev(node, event, f) {
        var eventHandler = function(e) { change_world(function(w, k) { f(w, e, k); },
                                                       doNothing); };
        attachEvent(node, event, eventHandler);
        eventDetachers.push(function() { detachEvent(node, event, eventHandler); });
    }

    // add_ev_after: node string CPS(world event -> world) -> void
    // Attaches a world-updating handler when the world is changed, but only
    // after the fired event has finished.
    function add_ev_after(node, event, f) {
        var eventHandler = function(e) {
                setTimeout(function() { change_world(function(w, k) { f(w, e, k); },
                                                     doNothing); },
                           0);
        };

        attachEvent(node, event, eventHandler);
        eventDetachers.push(function() { detachEvent(node, event, eventHandler); });
    }


    function addFocusTracking(node) {
        attachEvent(node, "focus", function(e) {
            currentFocusedNode = node; });
        attachEvent(node, "blur", function(e) {
            currentFocusedNode = undefined;
        });
        return node;
    }





    //
    // WORLD STUFFS
    //


    sexp2tree = function(sexp) {
        if(sexp.length === undefined) { return { node: sexp, children: [] }; }
        else { return { node: sexp[0], children: map(sexp.slice(1), sexp2tree) }; }
    };

    function sexp2attrib(sexp) {
        return { attrib: sexp[0], values: sexp.slice(1) };
    }

    function sexp2css_node(sexp) {
        var attribs = map(sexp.slice(1), sexp2attrib);
        if (typeof sexp[0] === 'string'){
            return [{ id: sexp[0], attribs: attribs }];
        } else if (sexp[0].length !== undefined){
            return map(sexp[0], function (id) { return { id: id, attribs: attribs }; });
        } else {
            return [{ node: sexp[0], attribs: attribs }];
        }
    }

    sexp2css = function(sexp) {
        return concat_map(sexp, sexp2css_node);
    };



    function isTextNode(n) {
        return (n.nodeType === 3);
    }


    function isElementNode(n) {
        return (n.nodeType === 1);
    }

    var JsworldDomError;

    var throwDomError = function(thing, topThing) {
        throw new JsworldDomError(
            "Expected a non-empty array, received " +  thing + " within " + topThing,
            thing);
    };

    // checkDomSexp: X X -> boolean
    // Checks to see if thing is a DOM-sexp.  If not,
    // throws an object that explains why not.
    checkDomSexp = function(thing, topThing) {
        var i;
        if (! thing instanceof Array) {
            throwDomError(thing, topThing);
        }
        if (thing.length === 0) {
            throwDomError(thing, topThing);
        }


        // Check that the first element is a Text or an element.
        if (isTextNode(thing[0])) {
            if (thing.length > 1) {
                throw new JsworldDomError("Text node " + thing + " can not have children",
                                          thing);
            }
        } else if (isElementNode(thing[0])) {
            for (i = 1; i < thing.length; i++) {
                checkDomSexp(thing[i], thing);
            }
        } else {
            if (window.console && window.console.log) { window.console.log(thing[0]); }

            throw new JsworldDomError(
                "expected a Text or an Element, received " + thing + " within " + topThing,
                thing[0]);
        }
    };

    JsworldDomError = function(msg, elt) {
        this.msg = msg;
        this.elt = elt;
    };
    JsworldDomError.prototype.toString = function() {
        return "JsworldDomError: " + this.msg;
    };





    //
    // DOM CREATION STUFFS
    //


    copy_attribs = function(node, attribs) {
        var a;
        if (attribs) {
            for (a in attribs) {
                if (hasOwnProperty.call(attribs, a)) {
                    if (typeof attribs[a] === 'function') {
                        add_ev(node, a, attribs[a]);
                    } else {
                        node[a] = attribs[a];
                    }
                }
            }
        }
        return node;
    };


    //
    // NODE TYPES
    //

    function p(attribs) {
        return addFocusTracking(copy_attribs(document.createElement('p'), attribs));
    }
    Jsworld.p = p;

    function div(attribs) {
        return addFocusTracking(copy_attribs(document.createElement('div'), attribs));
    }
    Jsworld.div = div;

    // Used To Be: (world event -> world) (hashof X Y) -> domElement
    // Now: CPS(world event -> world) (hashof X Y) -> domElement
    function button(f, attribs) {
        var n = document.createElement('button');
        n.onclick = function(e) {return false;};
        add_ev(n, 'click', f);
        return addFocusTracking(copy_attribs(n, attribs));
    }
    Jsworld.button = button;




    preventDefault = function(event) {
        if (event.preventDefault) {
            event.preventDefault();
        } else {
            event.returnValue = false;
        }
    };

    stopPropagation = function(event) {
        if (event.stopPropagation) {
            event.stopPropagation();
        } else {
            event.cancelBubble = true;
        }
    };


    var stopClickPropagation = function(node) {
        attachEvent(node, "click",
                    function(e) {
                        stopPropagation(e);
                    });
        return node;
    };


    var text_input, checkbox_input;

    // input: string CPS(world -> world) 
    function input(aType, updateF, attribs) {
        aType = aType.toLowerCase();
        var dispatchTable = { text : text_input,
                              password: text_input,
                              checkbox: checkbox_input
                              //button: button_input,
                              //radio: radio_input 
        };

        if (dispatchTable[aType]) {
            return (dispatchTable[aType])(aType, updateF, attribs);
        }
        else {
            throw new Error("js-input: does not currently support type " + aType);
        }
    }
    Jsworld.input = input;




    text_input = function(type, updateF, attribs) {
        var n = document.createElement('input');
        n.type = type;

        var lastVal = n.value;
        var onEvent = function() {
            if (! n.parentNode) { return; }
            setTimeout(
                function() {
                    if (lastVal !== n.value) {
                        lastVal = n.value;
                        change_world(function (w, k) {
                            updateF(w, n.value, k);
                        }, doNothing);
                    }
                },
                0);
        };

        attachEvent(n, "keydown", onEvent);
        eventDetachers.push(function() {
            detachEvent(n, "keydown", onEvent); });

        attachEvent(n, "change", onEvent);
        eventDetachers.push(function() {
            detachEvent(n, "change", onEvent); });

        return stopClickPropagation(
            addFocusTracking(copy_attribs(n, attribs)));
    };


    checkbox_input = function(type, updateF, attribs) {
        var n = document.createElement('input');
        n.type = type;
        var onCheck = function(w, e, k) {
            updateF(w, n.checked, k);
        };
        // This established the widget->world direction
        add_ev_after(n, 'change', onCheck);

        attachEvent(n, 'click', function(e) {
            stopPropagation(e);
        });

        return copy_attribs(n, attribs);
    };


    // var button_input = function(type, updateF, attribs) {
    //     var n = document.createElement('button');
    //     add_ev(n, 'click', function(w, e, k) { updateF(w, n.value, k); });
    //     return addFocusTracking(copy_attribs(n, attribs));
    // };




    function text(s, attribs) {
        var result = document.createElement("div");
        result.appendChild(document.createTextNode(String(s)));
        result.jsworldOpaque = true;
        return result;
    }
    Jsworld.text = text;

    var option;

    function select(attribs, opts, f){
        var n = document.createElement('select'), i;
        for(i = 0; i < opts.length; i++) {
            n.add(option({value: opts[i]}), null);
        }
        n.jsworldOpaque = true;
        add_ev(n, 'change', f);
        var result = addFocusTracking(copy_attribs(n, attribs));
        return result;
    }
    Jsworld.select = select;

    option = function(attribs){
        var node = document.createElement("option");
        node.text = attribs.value;
        node.value = attribs.value;
        return node;
    };



    function textarea(attribs){
        return addFocusTracking(copy_attribs(document.createElement('textarea'), attribs));
    }
    Jsworld.textarea = textarea;

    function h1(attribs){
        return addFocusTracking(copy_attribs(document.createElement('h1'), attribs));
    }
    Jsworld.h1 = h1;

    function canvas(attribs){
        return addFocusTracking(copy_attribs(document.createElement('canvas'), attribs));
    }
    Jsworld.canvas = canvas;


    function img(src, attribs) {
        var n = document.createElement('img');
        n.src = src;
        return addFocusTracking(copy_attribs(n, attribs));
    }
    Jsworld.img = img;



    function raw_node(node, attribs) {
        return addFocusTracking(copy_attribs(node, attribs));
    }
    Jsworld.raw_node = raw_node;

    return Jsworld;
  });
});

define('trove/world',["js/runtime-util", "trove/image-lib", "trove/world-lib", "js/ffi-helpers"], function(util, imageLib, worldLib, ffiLib) {

  return util.memoModule("world", function(runtime, namespace) {
    return runtime.loadJSModules(namespace, [imageLib, worldLib, ffiLib], function(imageLibrary, rawJsworld, ffi) {
      var isImage = imageLibrary.isImage;

      //////////////////////////////////////////////////////////////////////

      // An Opaque is a Pyret concept for a value wrapping a hidden
      // implementation.  Check that a value is one of these, and internally is
      // a WorldConfigOption
      var isOpaqueWorldConfigOption = function(v) {
        return runtime.isOpaque(v) && isWorldConfigOption(v.val);
      }

      var bigBang = function(initW, handlers) {
          var outerToplevelNode = jQuery('<span/>').css('padding', '0px').get(0);
          // TODO(joe): This obviously can't stay
          if(!runtime.hasParam("current-animation-port")) {
            document.body.appendChild(outerToplevelNode);
          } else {
            runtime.getParam("current-animation-port")(outerToplevelNode);
          }

          var toplevelNode = jQuery('<span/>').css('padding', '0px').appendTo(outerToplevelNode).get(0);

          var configs = [];
          var isOutputConfigSeen = false;

          for (var i = 0 ; i < handlers.length; i++) {
              if (isOpaqueWorldConfigOption(handlers[i])) {
                  configs.push(handlers[i].val.toRawHandler(toplevelNode));
              }
              else {
                  configs.push(handlers[i]);
              }
              if (isOpaqueOutputConfig(handlers[i])) { isOutputConfigSeen = true; }
          }
          
          // If we haven't seen an onDraw function, use the default one.
          if (! isOutputConfigSeen) { 
              configs.push(new DefaultDrawingOutput().toRawHandler(toplevelNode));
          }


          runtime.pauseStack(function(restarter) {
            rawJsworld.bigBang(
              toplevelNode,
              initW,
              configs,
              {},
              function(finalWorldValue) {
                restarter.resume(finalWorldValue);
              },
              function(err) {
                restarter.error(err);
              });
          });
      };





      //////////////////////////////////////////////////////////////////////

      // Every world configuration function (on-tick, stop-when, ...)
      // produces a WorldConfigOption instance.
      var WorldConfigOption = function(name) {
          this.name = name;	    
      };

      WorldConfigOption.prototype.configure = function(config) {
          throw new Error('unimplemented WorldConfigOption');
      };


      WorldConfigOption.prototype.toDomNode = function(params) {  
          var span = document.createElement('span');
          span.appendChild(document.createTextNode("(" + this.name + " ...)"));
          return span;
      };

      WorldConfigOption.prototype.toWrittenString = function(cache) {
          return "(" + this.name + " ...)";
      };

      WorldConfigOption.prototype.toDisplayedString = function(cache) {
          return "(" + this.name + " ...)";
      };

      var isWorldConfigOption = function(v) { return v instanceof WorldConfigOption; };

      //////////////////////////////////////////////////////////////////////




      // adaptWorldFunction: Racket-function -> World-CPS
      // Takes a racket function and converts it to the CPS-style function
      // that our world implementation expects.
      // NOTE(joe):  This expects there to be no active run for runtime
      // (it should be paused).  The run gets paused by pauseStack() in the
      // call to bigBang, so these runs will all be fresh
      var adaptWorldFunction = function(worldFunction) {
          return function() {
              // Consumes any number of arguments.
              var success = arguments[arguments.length - 1];
              // NOTE(joe): don't move this line down, it's *these* args, not
              // any other nested function's args
              var pyretArgs = [].slice.call(arguments, 0, arguments.length - 1);
              runtime.run(function(_, _) {
                  return worldFunction.app.apply(null, pyretArgs);
                }, runtime.namespace,
                { sync: false },
                function(result) {
                  if(runtime.isSuccessResult(result)) {
                    success(result.result);
                  }
                  else {
                    return rawJsworld.shutdown({errorShutdown: result.exn});
                  }
                });
          };
      };

      //////////////////////////////////////////////////////////////////////

      // OnTick: racket-function javascript-float -> handler
      var OnTick = function(handler, aDelay) {
          WorldConfigOption.call(this, 'on-tick');
          this.handler = handler;
          this.delay = aDelay;
      };

      OnTick.prototype = Object.create(WorldConfigOption.prototype);
       
      OnTick.prototype.toRawHandler = function(toplevelNode) {
          var that = this;
          var worldFunction = adaptWorldFunction(that.handler);
          return rawJsworld.on_tick(this.delay, worldFunction);
      };


      //////////////////////////////////////////////////////////////////////
      var OnKey = function(handler) {
          WorldConfigOption.call(this, 'on-key');
          this.handler = handler;
      }

      OnKey.prototype = Object.create(WorldConfigOption.prototype);
       
      OnKey.prototype.toRawHandler = function(toplevelNode) {
          var that = this;
          var worldFunction = adaptWorldFunction(that.handler);
          return rawJsworld.on_key(
              function(w, e, success) {
                  worldFunction(w, getKeyCodeName(e), success);
              });
      };


      var getKeyCodeName = function(e) {
          var code = e.charCode || e.keyCode;
          var keyname;
          switch(code) {
          case 16: keyname = "shift"; break;
          case 17: keyname = "control"; break;
          case 19: keyname = "pause"; break;
          case 27: keyname = "escape"; break;
          case 33: keyname = "prior"; break;
          case 34: keyname = "next"; break;
          case 35: keyname = "end"; break;
          case 36: keyname = "home"; break;
          case 37: keyname = "left"; break;
          case 38: keyname = "up"; break;
          case 39: keyname = "right"; break;
          case 40: keyname = "down"; break;
          case 42: keyname = "print"; break;
          case 45: keyname = "insert"; break;
          case 46: keyname = String.fromCharCode(127); break;
          case 106: keyname = "*"; break;
          case 107: keyname = "+"; break;
          case 109: keyname = "-"; break;
          case 110: keyname = "."; break;
          case 111: keyname = "/"; break;
          case 144: keyname = "numlock"; break;
          case 145: keyname = "scroll"; break;
          case 186: keyname = ";"; break;
          case 187: keyname = "="; break;
          case 188: keyname = ","; break;
          case 189: keyname = "-"; break;
          case 190: keyname = "."; break;
          case 191: keyname = "/"; break;
          case 192: keyname = "`"; break;
          case 219: keyname = "["; break;
          case 220: keyname = "\\"; break;
          case 221: keyname = "]"; break;
          case 222: keyname = "'"; break;
          default: 
              if (code >= 96 && code <= 105) {
            keyname = (code - 96).toString();
              } else if (code >= 112 && code <= 123) {
            keyname = "f" + (code - 111);
        } else {
            keyname = String.fromCharCode(code).toLowerCase();
        }
        break;
          }
          return keyname;
      }
      //////////////////////////////////////////////////////////////////////





      var OnMouse = function(handler) {
          WorldConfigOption.call(this, 'on-mouse');
          this.handler = handler;
      }

      OnMouse.prototype = Object.create(WorldConfigOption.prototype);
       
      OnMouse.prototype.toRawHandler = function(toplevelNode) {
          var that = this;
          var worldFunction = adaptWorldFunction(that.handler);
          return rawJsworld.on_mouse(
              function(w, x, y, type, success) {
                  worldFunction(w, x, y, type, success);
              });
      };








      var OutputConfig = function() {}
      OutputConfig.prototype = Object.create(WorldConfigOption.prototype);
      var isOutputConfig = function(v) { return v instanceof OutputConfig; };
      var isOpaqueOutputConfig = function(v) {
        return runtime.isOpaque(v) && isOutputConfig(v.val);
      }





      // // ToDraw

      var ToDraw = function(handler) {
          WorldConfigOption.call(this, 'to-draw');
          this.handler = handler;
      };

      ToDraw.prototype = Object.create(OutputConfig.prototype);
       
      ToDraw.prototype.toRawHandler = function(toplevelNode) {
          var that = this;
          var reusableCanvas;
          var reusableCanvasNode;
          var adaptedWorldFunction = adaptWorldFunction(this.handler);

          var worldFunction = function(world, success) {

              adaptedWorldFunction(
                  world,
                  function(v) {
                      // fixme: once jsworld supports fail continuations, use them
                      // to check the status of the scene object and make sure it's an
                      // image.

                      
                      if (runtime.isOpaque(v) && isImage(v.val) ) {
              var theImage = v.val;
              var width = theImage.getWidth();
              var height = theImage.getHeight();

              if (! reusableCanvas) {
            reusableCanvas = imageLibrary.makeCanvas(width, height);
            // Note: the canvas object may itself manage objects,
            // as in the case of an excanvas.  In that case, we must make
            // sure jsworld doesn't try to disrupt its contents!
            reusableCanvas.jsworldOpaque = true;
            reusableCanvasNode = rawJsworld.node_to_tree(reusableCanvas);
              }
              if (reusableCanvas.width !== width) { 
                              reusableCanvas.width = width; 
                          }
              if (reusableCanvas.height !== height) { 
                              reusableCanvas.height = height;
                          }
              var ctx = reusableCanvas.getContext("2d");
              theImage.render(ctx, 0, 0);
              success([toplevelNode, reusableCanvasNode]);
          } else {
              // TODO(joe): Maybe torepr below
              success([toplevelNode, rawJsworld.node_to_tree(String(v))]);
          }
                  });
          };

          var cssFunction = function(w, k) { 
              if (reusableCanvas) {
            k([[reusableCanvas, 
                      ["padding", "0px"],
          ["width", reusableCanvas.width + "px"],
          ["height", reusableCanvas.height + "px"]]]);
              } else {
                  k([]); 
              }
          }

          return rawJsworld.on_draw(worldFunction, cssFunction);
      };







      var DefaultDrawingOutput = function() {
          WorldConfigOption.call(this, 'to-draw');
      };

      DefaultDrawingOutput.prototype = Object.create(WorldConfigOption.prototype);
       
      DefaultDrawingOutput.prototype.toRawHandler = function(toplevelNode) {
          var that = this;
          var worldFunction = function(world, success) {
              success([toplevelNode,
                       rawJsworld.node_to_tree(String(world))]);
          };
          var cssFunction = function(w, success) { success([]); }
          return rawJsworld.on_draw(worldFunction, cssFunction);
      };




      //////////////////////////////////////////////////////////////////////



      var StopWhen = function(handler) {
          WorldConfigOption.call(this, 'stop-when');
          this.handler = handler;
      };

      StopWhen.prototype = Object.create(WorldConfigOption.prototype);

      StopWhen.prototype.toRawHandler = function(toplevelNode) {
          var that = this;
          var worldFunction = adaptWorldFunction(that.handler);
          return rawJsworld.stop_when(worldFunction);
      };

      var checkHandler = runtime.makeCheckType(isOpaqueWorldConfigOption, "WorldConfigOption");



      // The default tick delay is 28 times a second.
      var DEFAULT_TICK_DELAY = 1/28;

      var makeObject = runtime.makeObject;
      var makeFunction = runtime.makeFunction;

      return makeObject({
        "provide": makeObject({
          "big-bang": makeFunction(function(init, handlers) {
            ffi.checkArity(2, arguments, "big-bang");
            var arr = ffi.toArray(handlers);
            var initialWorldValue = init;
            arr.map(function(h) { checkHandler(h); });
            bigBang(initialWorldValue, arr);
            ffi.throwMessageException("Internal error in bigBang: stack not properly paused and stored.");
          }),
          "on-tick": makeFunction(function(handler) {
            ffi.checkArity(1, arguments, "on-tick");
            runtime.checkFunction(handler);
            return runtime.makeOpaque(new OnTick(handler, Math.floor(DEFAULT_TICK_DELAY * 1000)));
          }),
          "on-tick-n": makeFunction(function(handler, n) {
            ffi.checkArity(2, arguments, "on-tick-n");
            runtime.checkFunction(handler);
            runtime.checkNumber(n);
            var fixN = typeof n === "number" ? fixN : n.toFixnum();
            return runtime.makeOpaque(new OnTick(handler, fixN * 1000));
          }),
          "to-draw": makeFunction(function(drawer) {
            ffi.checkArity(1, arguments, "to-draw");
            runtime.checkFunction(drawer);
            return runtime.makeOpaque(new ToDraw(drawer));
          }),
          "stop-when": makeFunction(function(stopper) {
            ffi.checkArity(1, arguments, "stop-when");
            runtime.checkFunction(stopper);
            return runtime.makeOpaque(new StopWhen(stopper));
          }),
          "on-key": makeFunction(function(onKey) {
            ffi.checkArity(1, arguments, "on-key");
            runtime.checkFunction(onKey);
            return runtime.makeOpaque(new OnKey(onKey));
          }),
          "on-mouse": makeFunction(function(onMouse) {
            ffi.checkArity(1, arguments, "on-mouse");
            runtime.checkFunction(onMouse);
            return runtime.makeOpaque(new OnMouse(onMouse));
          }),
          "is-world-config": makeFunction(function(v) {
            ffi.checkArity(1, arguments, "is-world-config");
            if(!runtime.isOpaque(v)) { return runtime.pyretFalse; }
            return runtime.makeBoolean(isWorldConfigOption(v.val));
          }),
          "is-key-equal": makeFunction(function(key1, key2) {
            ffi.checkArity(2, arguments, "is-key-equal");
            runtime.checkString(key1);
            runtime.checkString(key2);
            return key1.toString().toLowerCase() === key2.toString().toLowerCase();
          })
        })
      });
    });
  });
});

define('js/bootstrap-namespace',["js/namespace", "trove/image", "trove/world", "js/js-numbers"], function(Namespace, imageLib, worldLib, jsnums) {

  function makeBootstrapNamespace(rt) {
    return rt.loadModules(rt.namespace, [imageLib, worldLib], function(image, world) {
      var get = rt.getField;

      var makeFunction = rt.makeFunction;

      /* Most of what Bootstrap uses is just friendly names for the identifiers
       * we are used to (e.g. add, sub, max, instead of num-add, num-sub,
       * num-max).  A few, like the boolean functions and, or, and not, are
       * special to Bootstrap and we define them here. */

      var bool_and = function(l, r) {
        rt.ffi.checkArity(2, arguments, "both");
        rt.checkBoolean(l);
        rt.checkBoolean(r);
        return rt.makeBoolean(l && r);
      }
      var bool_or = function(l, r) {
        rt.ffi.checkArity(2, arguments, "either");
        rt.checkBoolean(l);
        rt.checkBoolean(r);
        return rt.makeBoolean(l || r);
      }

      var add = function(l, r) {
        rt.ffi.checkArity(2, arguments, "add");
        rt.checkNumber(l);
        rt.checkNumber(r);
        return jsnums.add(l, r);
      }
      var sub = function(l, r) {
        rt.ffi.checkArity(2, arguments, "sub");
        rt.checkNumber(l);
        rt.checkNumber(r);
        return jsnums.subtract(l, r);
      }
      var mul = function(l, r) {
        rt.ffi.checkArity(2, arguments, "mul");
        rt.checkNumber(l);
        rt.checkNumber(r);
        return jsnums.multiply(l, r);
      }
      var div = function(l, r) {
        rt.ffi.checkArity(2, arguments, "div");
        rt.checkNumber(l);
        rt.checkNumber(r);
        return jsnums.divide(l, r);
      }
      var n = Namespace.namespace({
        '_empty': rt.namespace.get("_empty"),
        '_plus': rt.namespace.get("_plus"),
        '_minus': rt.namespace.get("_minus"),
        '_times': rt.namespace.get("_times"),
        '_divide': rt.namespace.get("_divide"),
        '_lessthan': rt.namespace.get("_lessthan"),
        '_greaterthan': rt.namespace.get("_greaterthan"),
        '_greaterequal': rt.namespace.get("_greaterequal"),
        '_lessequal': rt.namespace.get("_lessequal"),

        'torepr': rt.namespace.get("torepr"),
        'tostring': rt.namespace.get("tostring"),
        'print': rt.namespace.get("print"),
        'display': rt.namespace.get("display"),
        'print-error': rt.namespace.get("print-error"),
        'display-error': rt.namespace.get("display-error"),
        'raise': rt.namespace.get("raise"),
        'builtins': rt.namespace.get("builtins"),
        'nothing': rt.namespace.get("nothing"),
        'is-nothing': rt.namespace.get("is-nothing"),
        'is-number': rt.namespace.get("is-number"),
        'is-boolean': rt.namespace.get("is-boolean"),
        'is-string': rt.namespace.get("is-string"),
        'is-function': rt.namespace.get("is-function"),
        'is-object': rt.namespace.get("is-object"),

        'add': rt.makeFunction(add),
        'sub': rt.makeFunction(sub),
        'mul': rt.makeFunction(mul),
        'div': rt.makeFunction(div),
        'less': rt.namespace.get("_lessthan"),
        'greater': rt.namespace.get("_greaterthan"),
        'greaterequal': rt.namespace.get("_greaterequal"),
        'lessequal': rt.namespace.get("_lessequal"),

        'both': makeFunction(bool_and),
        'either': makeFunction(bool_or),
        'not': rt.namespace.get("not"),

        'max': rt.namespace.get("num-max"),
        'min': rt.namespace.get("num-min"),

        'random': rt.namespace.get("random"),

        'num-max': rt.namespace.get("num-max"),
        'num-min': rt.namespace.get("num-min"),
        'nums-equal': rt.namespace.get("nums-equal"),
        'num-abs': rt.namespace.get("num-abs"),
        'num-sin': rt.namespace.get("num-sin"),
        'num-cos': rt.namespace.get("num-cos"),
        'num-tan': rt.namespace.get("num-tan"),
        'num-asin': rt.namespace.get("num-asin"),
        'num-acos': rt.namespace.get("num-acos"),
        'num-atan': rt.namespace.get("num-atan"),
        'num-modulo': rt.namespace.get("num-modulo"),
        'num-truncate': rt.namespace.get("num-truncate"),
        'num-sqrt': rt.namespace.get("num-sqrt"),
        'num-sqr': rt.namespace.get("num-sqr"),
        'num-ceiling': rt.namespace.get("num-ceiling"),
        'num-floor': rt.namespace.get("num-floor"),
        'num-log': rt.namespace.get("num-log"),
        'num-exp': rt.namespace.get("num-exp"),
        'num-exact': rt.namespace.get("num-exact"),
        'num-is-integer': rt.namespace.get("num-is-integer"),
        'num-expt': rt.namespace.get("num-expt"),
        'num-tostring': rt.namespace.get("num-tostring"),
        'max': rt.namespace.get("num-max"),
        'min': rt.namespace.get("num-min"),
        'abs': rt.namespace.get("num-abs"),
        'sin': rt.namespace.get("num-sin"),
        'cos': rt.namespace.get("num-cos"),
        'tan': rt.namespace.get("num-tan"),
        'asin': rt.namespace.get("num-asin"),
        'acos': rt.namespace.get("num-acos"),
        'atan': rt.namespace.get("num-atan"),
        'modulo': rt.namespace.get("num-modulo"),
        'truncate': rt.namespace.get("num-truncate"),
        'sqrt': rt.namespace.get("num-sqrt"),
        'sqr': rt.namespace.get("num-sqr"),
        'ceiling': rt.namespace.get("num-ceiling"),
        'floor': rt.namespace.get("num-floor"),
        'log': rt.namespace.get("num-log"),
        'exp': rt.namespace.get("num-exp"),
        'exact': rt.namespace.get("num-exact"),
        'is-integer': rt.namespace.get("num-is-integer"),
        'is-fixnum': rt.namespace.get("num-is-fixnum"),
        'expt': rt.namespace.get("num-expt"),

        'strings-equal': rt.namespace.get("strings-equal"),
        'string-contains': rt.namespace.get("string-contains"),
        'string-append': rt.namespace.get("string-append"),
        'string-length': rt.namespace.get("string-length"),
        'string-tonumber': rt.namespace.get("string-tonumber"),
        'string-repeat': rt.namespace.get("string-repeat"),
        'string-substring': rt.namespace.get("string-substring"),
        'string-replace': rt.namespace.get("string-replace"),
        'string-split': rt.namespace.get("string-split"),
        'string-char-at': rt.namespace.get("string-char-at"),
        'string-toupper': rt.namespace.get("string-toupper"),
        'string-tolower': rt.namespace.get("string-tolower"),
        'string-explode': rt.namespace.get("string-explode"),
        'string-index-of': rt.namespace.get("string-index-of"),

        'Number': rt.namespace.get("Number"),
        'String': rt.namespace.get("String"),
        'Function': rt.namespace.get("Function"),
        'Boolean': rt.namespace.get("Boolean"),
        'Object': rt.namespace.get("Object"),
        'Method': rt.namespace.get("Method"),
        'Nothing': rt.namespace.get("Nothing"),
        'RawArray': rt.namespace.get("RawArray")

      });
      var imageFields = {};
      rt.getFields(image).forEach(function(f) {
        imageFields[f] = get(image, f);
      });
      var worldFields = {};
      rt.getFields(world).forEach(function(f) {
        worldFields[f] = get(world, f);
      });
      return n.merge(Namespace.namespace(imageFields)).merge(Namespace.namespace(worldFields));
    });
  }

  return {
    create: makeBootstrapNamespace
  };
});

define('js/dialects-lib',["js/runtime-util", 
        "js/pyret-tokenizer", "js/pyret-parser", "compiler/compile-structs.arr",
        "js/bootstrap-tokenizer", "js/bootstrap-parser", "js/bootstrap-un-tokenizer", "js/bootstrap-un-parser", "js/bootstrap-namespace"], 
function(util, 
         PT, PG, PCS,
         BT, BG, BUT, BUG, BN) {
  return util.memoModule("dialects-lib", function(RUNTIME, NAMESPACE) {
    function get(obj, fld) { return RUNTIME.getField(obj, fld); }
    return RUNTIME.loadModulesNew(NAMESPACE, [PCS], function(PCSLib) {
      var pcs = get(PCSLib, "values");
      var dialects = {
        "Pyret": { 
          Tokenizer: PT.Tokenizer, 
          Grammar: PG.PyretGrammar,
          UnTokenizer: PT.Tokenizer, 
          UnGrammar: PG.PyretGrammar,
          makeNamespace: function(rt) { return rt.namespace; },
          compileEnv: get(pcs, "standard-builtins")
        },
        "Bootstrap": { 
          Tokenizer: BT.Tokenizer, 
          UnTokenizer: BUT.Tokenizer,
          Grammar: BG.BootstrapGrammar, 
          UnGrammar: BUG.BootstrapGrammar,
          makeNamespace: BN.create,
          compileEnv: get(pcs, "bootstrap-builtins")
        }
      }

      return {
        dialects: dialects,
        defaultDialect: "Pyret"
      };
    });
  });
});




define('trove/exec',["js/secure-loader", "js/ffi-helpers", "js/runtime-anf", "trove/checker", "js/dialects-lib"], function(loader, ffi, runtimeLib, checkerLib, dialectsLib) {

  if(requirejs.isBrowser) {
    var rjs = requirejs;
    var define = window.define;
  }
  else {
    var rjs = require("requirejs");
    var define = rjs.define;
  }

  return function(RUNTIME, NAMESPACE) {
    var F = ffi(RUNTIME, NAMESPACE);

    function execWithDir(jsStr, modnameP, loaddirP, checkAllP, dialectP, params) {
      F.checkArity(6, arguments, "exec");
      RUNTIME.checkString(jsStr);
      RUNTIME.checkString(modnameP);
      RUNTIME.checkString(loaddirP);
      RUNTIME.checkBoolean(checkAllP);
      RUNTIME.checkString(dialectP);
      var str = RUNTIME.unwrap(jsStr);
      var modname = RUNTIME.unwrap(modnameP);
      var loaddir = RUNTIME.unwrap(loaddirP);
      var checkAll = RUNTIME.unwrap(checkAllP);
      var dialect = RUNTIME.unwrap(dialectP);
      var argsArray = F.toArray(params).map(RUNTIME.unwrap);
      return exec(str, modname, loaddir, checkAll, dialect, argsArray);
    }

    function exec(str, modname, loaddir, checkAll, dialect, args) {
      var name = RUNTIME.unwrap(NAMESPACE.get("gensym").app(RUNTIME.makeString("module")));
      rjs.config({ baseUrl: loaddir });

      var newRuntime = runtimeLib.makeRuntime({ 
        stdout: function(str) { process.stdout.write(str); },
        stderr: function(str) { process.stderr.write(str); }
      });

      RUNTIME.pauseStack(function(restarter) {
        newRuntime.runThunk(function() {
          newRuntime.safeCall(function() {
            return dialectsLib(newRuntime, newRuntime.namespace);
          }, function(dialects) {
            dialect = dialects.dialects[dialect];
            return newRuntime.safeCall(function() {
              return dialect.makeNamespace(newRuntime);
            }, function(newNamespace) {
              newRuntime.setParam("command-line-arguments", args);

              return newRuntime.loadModulesNew(newNamespace, [checkerLib], function(checkerLib) {
                var checker = newRuntime.getField(checkerLib, "values");
                var currentChecker = newRuntime.getField(checker, "make-check-context").app(newRuntime.makeString(modname), newRuntime.makeBoolean(checkAll));
                newRuntime.setParam("current-checker", currentChecker);

                function makeResult(execRt, callingRt, r) {
                  if(execRt.isSuccessResult(r)) {
                    var pyretResult = r.result;
                    return callingRt.makeObject({
                        "success": callingRt.makeBoolean(true),
                        "render-check-results": callingRt.makeFunction(function() {
                          var toCall = execRt.getField(checker, "render-check-results");
                          var checks = execRt.getField(pyretResult, "checks");
                          callingRt.pauseStack(function(restarter) {
                              execRt.run(function(rt, ns) {
                                  return toCall.app(checks);
                                }, execRt.namespace, {sync: true},
                                function(printedCheckResult) {
                                  if(execRt.isSuccessResult(printedCheckResult)) {
                                    if(execRt.isString(printedCheckResult.result)) {
                                      restarter.resume(callingRt.makeString(execRt.unwrap(printedCheckResult.result)));
                                    }
                                  }
                                  else if(execRt.isFailureResult(printedCheckResult)) {
                                    console.error(printedCheckResult);
                                    console.error(printedCheckResult.exn);
                                    restarter.resume(callingRt.makeString("There was an exception while formatting the check results"));
                                  }
                                });
                            });
                        })
                      });
                  }
                  else if(execRt.isFailureResult(r)) {
                    return callingRt.makeObject({
                        "success": callingRt.makeBoolean(false),
                        "failure": r.exn.exn,
                        "render-error-message": callingRt.makeFunction(function() {
                          callingRt.pauseStack(function(restarter) {
                            execRt.runThunk(function() {
                              if(execRt.isPyretVal(r.exn.exn)) {
                                return execRt.string_append(
                                  execRt.toReprJS(r.exn.exn, "tostring"),
                                  execRt.makeString("\n" +
                                                    execRt.printPyretStack(r.exn.pyretStack)));
                              } else {
                                return String(r.exn, r.exn.stack);
                              }
                            }, function(v) {
                              if(execRt.isSuccessResult(v)) {
                                return restarter.resume(v.result)
                              } else {
                                console.error("There was an exception while rendering the exception: ", r.exn, v.exn);
                              }
                            })
                          });
                        })
                      });
                  }
                }

                var loaded = loader.goodIdea(RUNTIME, name, str);
                loaded.fail(function(err) {
                  restarter.resume(makeResult(newRuntime, RUNTIME, newRuntime.makeFailureResult(err)));
                });

                loaded.then(function(moduleVal) {

                  /* run() starts the anonymous module's evaluation on a new stack
                     (created by newRuntime).  Once the evaluated program finishes
                     (if it ever does), the continuation is called with r as either
                     a Success or Failure Result from newRuntime. */

                  newRuntime.run(moduleVal, newNamespace, {sync: true}, function(r) {

                      /* makeResult handles turning values from the new runtime into values that
                         the calling runtime understands (since they don't share
                         the same instantiation of all the Pyret constructors like PObject, or the
                         same brands) */

                      var wrappedResult = makeResult(newRuntime, RUNTIME, r);

                      /* This restarts the calling stack with the new value, which
                         used constructors from the calling runtime.  From the point of view of the
                         caller, wrappedResult is the return value of the call to exec() */
                      restarter.resume(wrappedResult);
                  });
                });
              });
            });
          });
        }, function(r) {
        })
      });

    };
    return RUNTIME.makeObject({
      provide: RUNTIME.makeObject({
        exec: RUNTIME.makeFunction(execWithDir)
      }),
      answer: NAMESPACE.get("nothing")
    });
  };
});


define('trove/parse-pyret',["js/runtime-util", "js/ffi-helpers", "trove/ast", "trove/srcloc", "js/dialects-lib"], function(util, ffi, astLib, srclocLib, dialectsLib) {
  return util.memoModule("parse-pyret", function(RUNTIME, NAMESPACE) {
    var F = ffi(RUNTIME, NAMESPACE);
    return RUNTIME.loadModulesNew(NAMESPACE, [srclocLib, astLib], function(srclocLib, astLib) {
      var srcloc = RUNTIME.getField(srclocLib, "values");
      var ast = RUNTIME.getField(astLib, "values");

      return RUNTIME.safeCall(function() {
        return dialectsLib(RUNTIME, NAMESPACE);
      }, function(dialects) {
        //var data = "#lang pyret\n\nif (f(x) and g(y) and h(z) and i(w) and j(u)): true else: false end";
        function makePyretPos(fileName, p) {
          var n = RUNTIME.makeNumber;
          return RUNTIME.getField(srcloc, "srcloc").app(
              RUNTIME.makeString(fileName),
              n(p.startRow),
              n(p.startCol),
              n(p.startChar),
              n(p.endRow),
              n(p.endCol),
              n(p.endChar)
            );
        }
        function translate(node, fileName) {
          // NOTE: This translation could blow the stack for very deep ASTs
          // We might have to rewrite the whole algorithm
          // One possibility is to reuse a stack of {todo: [...], done: [...], doing: fn} nodes
          // where each AST kid that needs to be recursively processed pushes a new frame on the stack
          // (it can eagerly process any primitive values, and defer the rest),
          // and returns a function to be called when all the new todos are done (which gets put into doing)
          // if a todo item is a Pyret value, it just gets pushed across to done
          // if a todo item is an array, then doing = RUNTIME.makeList and it creates a stack frame
          function tr(node) {
            return translators[node.name](node);
          }
          var pos = function(p) { return makePyretPos(fileName, p); };
          var makeList = F.makeList;
          function name(tok) {
            if (tok.value === "_")
              return RUNTIME.getField(ast, 's-underscore').app(pos(tok.pos));
            else
              return RUNTIME.getField(ast, 's-name').app(pos(tok.pos), RUNTIME.makeString(tok.value));
          }
          function symbol(tok) {
            return RUNTIME.makeString(tok.value);
          }
          function string(tok) { 
            if (tok.value.substring(0, 3) === "```")
              return RUNTIME.makeString(tok.value.slice(3, -3).trim());
            else
              return RUNTIME.makeString(tok.value.slice(1, -1));
          }
          function number(tok) { return RUNTIME.makeNumberFromString(tok.value); }
          const translators = {
            'program': function(node) {
              var prelude = tr(node.kids[0]);
              var body = tr(node.kids[1]);
              return RUNTIME.getField(ast, 's-program')
                .app(pos(node.pos), prelude.provide, prelude.provideTypes, prelude.imports, body);
            },
            'prelude': function(node) {
              var provide;
              var provideTypes;
              var kids = node.kids.slice(0);
              if (kids.length > 0 && kids[0].name === "provide-stmt") {
                provide = tr(kids.shift());
              } else {
                provide = RUNTIME.getField(ast, 's-provide-none').app(pos(node.pos));
              }
              if (kids.length > 0 && kids[0].name === "provide-types-stmt") {
                provideTypes = tr(kids.shift());
              } else {
                provideTypes = RUNTIME.getField(ast, 's-provide-types-none').app(pos(node.pos));
              }
              return {
                provide : provide,
                provideTypes : provideTypes,
                imports : makeList(kids.map(tr))
              };
            },
            'provide-stmt': function(node) {
              if (node.kids.length === 2) {
                // (provide-stmt PROVIDE STAR)
                return RUNTIME.getField(ast, 's-provide-all')
                  .app(pos(node.pos));
              } else {
                // (provide-stmt PROVIDE stmt END)
                return RUNTIME.getField(ast, 's-provide')
                  .app(pos(node.pos), tr(node.kids[1]))
              }
            },
            'provide-types-stmt': function(node) {
              if (node.kids[1].name === "STAR") {
                return RUNTIME.getField(ast, 's-provide-types-all').app(pos(node.pos));
              } else {
                // will produce record-ann
                var rec = tr(node.kids[1]);
                // Get the fields out of it
                return RUNTIME.getField(ast, 's-provide-types')
                  .app(pos(node.pos), RUNTIME.getField(rec, 'fields'));
              }
            },
            'import-stmt': function(node) {
              if (node.kids[node.kids.length - 2].name === "AS") {
                if (node.kids.length == 4) {
                  // (import-stmt IMPORT mod AS NAME)
                  return RUNTIME.getField(ast, 's-import')
                    .app(pos(node.pos), tr(node.kids[1]), name(node.kids[3]));
                } else {
                  // (import-stmt IMPORT mod AS NAME, TYPES)
                  return RUNTIME.getField(ast, 's-import-types')
                    .app(pos(node.pos), tr(node.kids[1]), name(node.kids[3]), name(node.kids[5]));
                }
              } else {
                // (import-stmt IMPORT NAME (COMMA NAME)* FROM mod)
                var names = [];
                for (var i = 1; i < node.kids.length - 2; i += 2) {
                  names.push(name(node.kids[i]));
                }
                return RUNTIME.getField(ast, 's-import-fields')
                  .app(pos(node.pos), makeList(names), tr(node.kids[node.kids.length - 1]));
              }
            },
            'import-name': function(node) {
              // (import-name NAME)
              return RUNTIME.getField(ast, 's-const-import')
                .app(pos(node.pos), symbol(node.kids[0]))
            },
            'import-string': function(node) {
              // (import-string STRING)
              return RUNTIME.getField(ast, 's-file-import')
                .app(pos(node.pos), string(node.kids[0]))
            },
            'block': function(node) {
              // (block stmts ...)
              return RUNTIME.getField(ast, 's-block')
                .app(pos(node.pos), makeList(node.kids.map(tr)));
            },
            'stmt': function(node) {
              // (stmt s)
              return tr(node.kids[0]);
            },
            'data-with': function(node) {
              if (node.kids.length === 0) {
                // (data-with)
                return makeList([]);
              } else {
                // (data-with WITH fields)
                return tr(node.kids[1]);
              }
            },
            'variant-constructor': function(node) {
              // (variant-constructor NAME variant-members)
              return {
                pos: pos(node.pos),
                name: symbol(node.kids[0]),
                args: tr(node.kids[1])
              }
            },
            'data-variant': function(node) {
              if (node.kids[1].value !== undefined) {
                // (data-variant PIPE NAME with)
                return RUNTIME.getField(ast, 's-singleton-variant')
                  .app(pos(node.pos), symbol(node.kids[1]), tr(node.kids[2]));
              } else {
                // (data-variant PIPE variant-constructor with)
                var constr = tr(node.kids[1])
                return RUNTIME.getField(ast, 's-variant')
                  .app(pos(node.pos), constr.pos, constr.name, constr.args, tr(node.kids[2]));
              }
            },
            'first-data-variant': function(node) {
              if (node.kids[0].value !== undefined) {
                // (first-data-variant NAME with)
                return RUNTIME.getField(ast, 's-singleton-variant')
                  .app(pos(node.pos), symbol(node.kids[0]), tr(node.kids[1]));
              } else {
                // (first-data-variant variant-constructor with)
                var constr = tr(node.kids[0])
                return RUNTIME.getField(ast, 's-variant')
                  .app(pos(node.pos), constr.pos, constr.name, constr.args, tr(node.kids[1]));
              }
            },
            'datatype-variant': function(node) {
              if (node.kids[1].value !== undefined) {
                // (datatype-variant PIPE NAME constructor)
                return RUNTIME.getField(ast, 's-datatype-singleton-variant')
                  .app(pos(node.pos), symbol(node.kids[1]), tr(node.kids[2]));
              } else {
                // (datatype-variant PIPE variant-constructor constructor)
                var constr = tr(node.kids[1])
                return RUNTIME.getField(ast, 's-datatype-variant')
                  .app(pos(node.pos), constr.pos, constr.name, constr.args, tr(node.kids[2]));
              }
            },
            'first-datatype-variant': function(node) {
              if (node.kids[0].value !== undefined) {
                // (datatype-variant NAME constructor)
                return RUNTIME.getField(ast, 's-datatype-singleton-variant')
                  .app(pos(node.pos), symbol(node.kids[0]), tr(node.kids[1]));
              } else {
                // (datatype-variant variant-constructor constructor)
                var constr = tr(node.kids[0])
                return RUNTIME.getField(ast, 's-datatype-variant')
                  .app(pos(node.pos), constr.pos, constr.name, constr.args, tr(node.kids[1]));
              }
            },
            'data-sharing': function(node) {
              if (node.kids.length === 2) {
                // (data-sharing SHARING fields)
                return tr(node.kids[1]);
              } else {
                // (data-sharing)
                return makeList([]);
              }
            },
            'constructor-clause': function(node) {
              // (constructor-clause WITHCONSTRUCTOR LPAREN NAME RPAREN COLON block END)
              return RUNTIME.getField(ast, 's-datatype-constructor')
                .app(pos(node.pos), symbol(node.kids[2]), tr(node.kids[5]));
            },
            'type-expr': function(node) {
              return RUNTIME.getField(ast, 's-type')
                .app(pos(node.pos), name(node.kids[1]), tr(node.kids[3]));
            },
            'newtype-expr': function(node) {
              return RUNTIME.getField(ast, 's-newtype')
                .app(pos(node.pos), name(node.kids[1]), name(node.kids[3]));
            },
            'var-expr': function(node) {
              // (var-expr VAR bind EQUALS e)
              return RUNTIME.getField(ast, 's-var')
                .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[3]));
            },
            'let-expr': function(node) {
              if (node.kids.length === 3) {
                // (let-expr bind EQUALS e)
                return RUNTIME.getField(ast, 's-let')
                  .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[2]), RUNTIME.makeBoolean(false));
              } else {
                // (let-expr VAL bind EQUALS e)
                return RUNTIME.getField(ast, 's-let')
                  .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[3]), RUNTIME.makeBoolean(true));
              }
            },
            'newtype-bind': function(node) {
              return RUNTIME.getField(ast, 's-newtype-bind')
                .app(pos(node.pos), name(node.kids[1]), name(node.kids[3]));
            },
            'type-bind': function(node) {
              return RUNTIME.getField(ast, 's-type-bind')
                .app(pos(node.pos), name(node.kids[0]), tr(node.kids[2]));
            },
            'type-let-bind': function(node) {
              return tr(node.kids[0]);
            },
            'type-let-bind-elt': function(node) {
              return tr(node.kids[0]);
            },
            'type-let-expr': function(node) {
              return RUNTIME.getField(ast, 's-type-let-expr')
                .app(pos(node.pos),
                     makeList(node.kids.slice(1, -3).map(tr)),
                     tr(node.kids[node.kids.length - 2]));
            },
            'multi-let-expr': function(node) {
              // (multi-let-expr LET let-binding-elt* let-binding COLON block END)
              // Note that we override the normal name dispatch here, because we don't want
              // to create the default let-expr or var-expr constructions
              return RUNTIME.getField(ast, 's-let-expr')
                .app(pos(node.pos), 
                     makeList(node.kids.slice(1, -3).map(translators["let-binding"])),
                     tr(node.kids[node.kids.length - 2]));
            },
            'letrec-expr': function(node) {
              // (letrec-expr LETREC letrec-binding* let-expr COLON block END)
              // Note that we override the normal name dispatch here, because we don't want
              // to create the default let-expr constructions
              return RUNTIME.getField(ast, 's-letrec')
                .app(pos(node.pos), 
                     makeList(node.kids.slice(1, -3).map(translators["letrec-binding"])), 
                     tr(node.kids[node.kids.length - 2]));
            },
            'let-binding': function(node) {
              if (node.name === "let-binding-elt") {
                // (let-binding-elt let-binding COMMA)
                node = node.kids[0];
              }
              if (node.name === "let-binding") {
                // (let-binding let-expr) or (let-binding var-expr)
                node = node.kids[0]
              }
              if (node.name === "let-expr") {
                // (let-expr binding EQUALS binop-expr)
                return RUNTIME.getField(ast, 's-let-bind')
                  .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[2]));
              } else if (node.name === "var-expr") {
                // (var-expr VAR binding EQUALS binop-expr)
                return RUNTIME.getField(ast, 's-var-bind')
                  .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[3]));
              }
            },
            'letrec-binding': function(node) {
              if (node.name === "letrec-binding") {
                node = node.kids[0];
              }
              // (let-expr binding EQUALS binop-expr)
              return RUNTIME.getField(ast, 's-letrec-bind')
                .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[2]));
            },
            'contract-stmt': function(node) {
              // (contract-stmt NAME COLONCOLON ann)
              return RUNTIME.getField(ast, 's-contract')
                .app(pos(node.pos), name(node.kids[0]), tr(node.kids[2]));
            },
            'graph-expr': function(node) {
              // (graph-expr GRAPH bind ... END)
              return RUNTIME.getField(ast, 's-graph')
                .app(pos(node.pos), makeList(node.kids.slice(1, -1).map(tr)));
            },
            'fun-expr': function(node) {
              // (fun-expr FUN (fun-header params fun-name args return) COLON doc body check END)
              return RUNTIME.getField(ast, 's-fun')
                .app(pos(node.pos), symbol(node.kids[1].kids[1]),
                     tr(node.kids[1].kids[0]),
                     tr(node.kids[1].kids[2]),
                     tr(node.kids[1].kids[3]),
                     tr(node.kids[3]),
                     tr(node.kids[4]),
                     tr(node.kids[5]));
            },
            'data-expr': function(node) {
              // (data-expr DATA NAME params mixins COLON variant ... sharing-part check END)
              return RUNTIME.getField(ast, 's-data')
                .app(pos(node.pos), symbol(node.kids[1]), tr(node.kids[2]), tr(node.kids[3]),
                     makeList(node.kids.slice(5, -3).map(tr)), 
                     tr(node.kids[node.kids.length - 3]),
                     tr(node.kids[node.kids.length - 2]));
            },
            'datatype-expr': function(node) {
              // (datatype-expr DATATYPE NAME params COLON variant ... check END)
              return RUNTIME.getField(ast, 's-datatype')
                .app(pos(node.pos), symbol(node.kids[1]), tr(node.kids[2]),
                     makeList(node.kids.slice(4, -2).map(tr)),
                     tr(node.kids[node.kids.length - 2]));
            },
            'assign-expr': function(node) {
              // (assign-expr id COLONEQUAL e)
              return RUNTIME.getField(ast, 's-assign')
                .app(pos(node.pos), name(node.kids[0]), tr(node.kids[2]));
            },
            'when-expr': function(node) {
              // (when-expr WHEN test COLON body END)
              return RUNTIME.getField(ast, 's-when')
                .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[3]));
            },
            'check-expr': function(node) {
              if (node.kids.length === 3) {
                // (check-expr CHECKCOLON body END)
                return RUNTIME.getField(ast, 's-check')
                  .app(pos(node.pos), F.makeNone(), tr(node.kids[1]), 
                       RUNTIME.makeBoolean(node.kids[0].name === "CHECKCOLON"));
              } else {
                // (check-expr CHECK STRING COLON body END)
                return RUNTIME.getField(ast, 's-check')
                  .app(pos(node.pos), F.makeSome(string(node.kids[1])), tr(node.kids[3]), 
                       RUNTIME.makeBoolean(node.kids[0].name === "CHECK"));
              }
            },
            'check-test': function(node) {
              if (node.kids.length === 1) {
                // (check-test e)
                return tr(node.kids[0]);
              } else {
                // (check-test left op right)
                return RUNTIME.getField(ast, 's-check-test')
                  .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[0]), tr(node.kids[2])); // Op comes first
              }
            },
            'binop-expr': function(node) {
              if (node.kids.length === 1) {
                // (binop-expr e)
                return tr(node.kids[0]);
              } else {
                var mkOp = RUNTIME.getField(ast, 's-op').app;
                var expr = mkOp(pos(node.pos), tr(node.kids[1]), tr(node.kids[0]), tr(node.kids[2]));
                for(var i = 4; i < node.kids.length; i += 2) {
                  expr = mkOp(pos(node.pos), tr(node.kids[i - 1]), expr, tr(node.kids[i]));
                }
                return expr;
              }
            },
            'doc-string': function(node) {
              if (node.kids.length === 0) {
                // (doc-string)
                return RUNTIME.makeString("");
              } else {
                // (doc-string DOC str)
                return string(node.kids[1]);
              }
            },
            'where-clause': function(node) {
              if (node.kids.length === 0) {
                // (where-clause)
                return F.makeNone();
              } else {
                // (where-clause WHERE block)
                return F.makeSome(tr(node.kids[1]));
              }
            },
            'check-op': function(node) {
              // (check-op str)
              var opname = String(node.kids[0].value).trim();
              if(opLookup[opname]) {
                return opLookup[opname];
              }
              else {
                throw "Unknown operator: " + opname;
              }
            },
            'expr': function(node) {
              // (expr e)
              return tr(node.kids[0]);
            },
            'binop-expr-paren': function(node) {
              if (node.kids[0].name === "paren-nospace-expr") {
                // (binop-expr-paren (paren-nospace-expr _ e _))
                return RUNTIME.getField(ast, 's-paren')
                  .app(pos(node.pos), tr(node.kids[0].kids[1]));
              } else {
                // (binop-expr-paren e)
                return tr(node.kids[0]);
              }
            },
            'binop': function(node) {
              // (binop str)
              var opname = String(node.kids[0].value).trim();
              if(opLookup[opname]) {
                return opLookup[opname];
              }
              else {
                throw "Unknown operator: " + opname;
              }
            },
            'return-ann': function(node) {
              if (node.kids.length === 0) {
                // (return-ann)
                return RUNTIME.getField(ast, 'a-blank');
              } else {
                // (return-ann THINARROW ann)
                return tr(node.kids[1]);
              }
            },
            'binding': function(node) {
              if (node.kids.length === 1) {
                // (binding name)
                return RUNTIME.getField(ast, 's-bind')
                  .app(pos(node.pos), RUNTIME.pyretFalse, name(node.kids[0]), 
                       RUNTIME.getField(ast, 'a-blank'));
              } else if (node.kids.length === 3) {
                // (binding name COLONCOLON ann)
                return RUNTIME.getField(ast, 's-bind')
                  .app(pos(node.pos), RUNTIME.pyretFalse, name(node.kids[0]), tr(node.kids[2]));
              } else if (node.kids.length === 2) {
                // (binding SHADOW name)
                return RUNTIME.getField(ast, 's-bind')
                  .app(pos(node.pos), RUNTIME.pyretTrue, name(node.kids[1]), 
                       RUNTIME.getField(ast, 'a-blank'));
              } else {
                // (binding SHADOW name COLONCOLON ann)
                return RUNTIME.getField(ast, 's-bind')
                  .app(pos(node.pos), RUNTIME.pyretTrue, name(node.kids[1]), tr(node.kids[3]));
              }
            },
            'toplevel-binding': function(node) {
              if (node.kids.length === 1) {
                // is actually a binding
                return tr(node.kids[0]);
              } else if (node.kids.length === 4) {
                // (toplevel-binding SHADOW NAME COLONCOLON noparen-arrow-ann)
                return RUNTIME.getField(ast, 's-bind')
                  .app(pos(node.pos), RUNTIME.pyretTrue, name(node.kids[1]), tr(node.kids[3]));
              } else {
                // (toplevel-binding NAME COLONCOLON noparen-arrow-ann)
                return RUNTIME.getField(ast, 's-bind')
                  .app(pos(node.pos), RUNTIME.pyretFalse, name(node.kids[0]), tr(node.kids[2]));
              }
            },
            'args': function(node) {
              if (node.kids.length === 2) {
                // (args LPAREN RPAREN)
                return makeList([]);
              } else {
                // (args LPAREN (list-arg-elt arg COMMA) ... lastarg RPAREN)
                return makeList(node.kids.slice(1, -1).map(tr));
              }
            },
            'list-arg-elt': function(node) {
              // (list-arg-elt arg COMMA)
              return tr(node.kids[0]);
            },
            'variant-member': function(node) {
              if (node.kids.length === 1) {
                // (variant-member b)
                return RUNTIME.getField(ast, 's-variant-member')
                  .app(pos(node.pos), RUNTIME.getField(ast, "s-normal"), tr(node.kids[0]));
              } else {
                if (node.kids[0].name === "MUTABLE") {
                  return RUNTIME.getField(ast, 's-variant-member')
                    .app(pos(node.pos), RUNTIME.getField(ast, "s-mutable"), tr(node.kids[1]));
                } else {
                  return RUNTIME.getField(ast, 's-variant-member')
                    .app(pos(node.pos), RUNTIME.getField(ast, "s-cyclic"), tr(node.kids[1]));
                }
              }
            },
            'variant-members': function(node) {
              if (node.kids.length === 2) {
                // (variant-members LPAREN RPAREN)
                return makeList([]);
              } else {
                // (variant-members LPAREN (list-variant-member mem COMMA) ... lastmem RPAREN)
                return makeList(node.kids.slice(1, -1).map(tr));
              }          
            },
            'list-variant-member': function(node) {
              // (list-variant-member mem COMMA)
              return tr(node.kids[0]);
            },
            'key': function(node) {
              if (node.kids.length === 3) {
                // (key LBRACK e RBRACK)
                return tr(node.kids[1]);
              } else {
                // (key name)
                return RUNTIME.getField(ast, 's-str')
                  .app(pos(node.pos), symbol(node.kids[0]));
              }
            },
            'obj-field': function(node) {
              if (node.kids.length === 4) {
                // (obj-field MUTABLE key COLON value)
                return RUNTIME.getField(ast, 's-mutable-field')
                  .app(pos(node.pos), tr(node.kids[1]), RUNTIME.getField(ast, 'a-blank'), tr(node.kids[3]));
              } else if (node.kids.length === 6) {
                // (obj-field MUTABLE key COLONCOLON ann COLON value)
                return RUNTIME.getField(ast, 's-mutable-field')
                  .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[2]), tr(node.kids[3]));
              } else if (node.kids.length === 3) {
                // (obj-field key COLON value)
                return RUNTIME.getField(ast, 's-data-field')
                  .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[2]));
              } else {
                // (obj-field key args ret COLON doc body check END)
                return RUNTIME.getField(ast, 's-method-field')
                  .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[1]), tr(node.kids[2]),
                       tr(node.kids[4]), tr(node.kids[5]), tr(node.kids[6]));
              }
            },
            'obj-fields': function(node) {
              if (node.kids[node.kids.length - 1].name !== "obj-field") {
                // (obj-fields (list-obj-field f1 COMMA) ... lastField COMMA)
                return makeList(node.kids.slice(0, -1).map(tr));
              } else {
                // (fields (list-obj-field f1 COMMA) ... lastField)
                return makeList(node.kids.map(tr));
              }
            },
            'list-obj-field': function(node) {
              // (list-obj-field f COMMA)
              return tr(node.kids[0]);
            },
            'field': function(node) {
              if (node.kids.length === 3) {
                // (field key COLON value)
                return RUNTIME.getField(ast, "s-data-field")
                  .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[2]));
              } else {
                // (field key args ret COLON doc body check END)
                return RUNTIME.getField(ast, "s-method-field")
                  .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[1]), tr(node.kids[2]),
                       tr(node.kids[4]), tr(node.kids[5]), tr(node.kids[6]));
              }
            },
            'fields': function(node) {
              if (node.kids[node.kids.length - 1].name !== "field") {
                // (fields (list-field f1 COMMA) ... lastField COMMA)
                return makeList(node.kids.slice(0, -1).map(tr));
              } else {
                // (fields (list-field f1 COMMA) ... lastField)
                return makeList(node.kids.map(tr));
              }
            },
            'list-field': function(node) {
              // (list-field f COMMA)
              return tr(node.kids[0]);
            },
            'data-mixins': function(node) {
              if (node.kids.length === 0) {
                // (data-mixins)
                return makeList([]);
              } else {
                // (data-mixins DERIVING mixins)
                return tr(node.kids[1]);
              }
            },
            'mixins': function(node) {
              // (mixins (list-mixin m COMMA) ... lastmixin)
              return makeList(node.kids.map(tr));
            },
            'list-mixin': function(node) {
              // (list-mixin m COMMA)
              return tr(node.kids[0]);
            },
            'app-args': function(node) {
              if (node.kids.length === 2) {
                // (app-args LPAREN RPAREN)
                return makeList([]);
              } else {
                // (app-args LPAREN (app-arg-elt e COMMA) ... elast RPAREN)
                return makeList(node.kids.slice(1, -1).map(tr));
              }
            },
            'app-arg-elt': function(node) {
              // (app-arg-elt e COMMA)
              return tr(node.kids[0]);
            },
            'cases-branch': function(node) {
              if (node.kids.length === 4) {
                // (cases-branch PIPE NAME THICKARROW body)
                return RUNTIME.getField(ast, 's-cases-branch')
                  .app(pos(node.pos), symbol(node.kids[1]), makeList([]), tr(node.kids[3]));
              } else {
                // (cases-branch PIPE NAME args THICKARROW body)
                return RUNTIME.getField(ast, 's-cases-branch')
                  .app(pos(node.pos), symbol(node.kids[1]), tr(node.kids[2]), tr(node.kids[4]));
              }
            },
            'if-pipe-branch': function(node) {
              // (if-pipe-branch BAR binop-expr THENCOLON block)
              return RUNTIME.getField(ast, 's-if-pipe-branch')
                .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[3]));
            },
            'else-if': function(node) {
              // (else-if ELSEIF test COLON body)
              return RUNTIME.getField(ast, 's-if-branch')
                .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[3]));
            },
            'else': function(node) {
              // (else ELSECOLON body)
              return RUNTIME.getField(ast, 's-else')
                .app(pos(node.pos), tr(node.kids[1]));
            },
            'ty-params': function(node) {
              if (node.kids.length === 0) {
                // (ty-params)
                return makeList([]);
              } else {
                // (ty-params LANGLE (list-ty-param p COMMA) ... last RANGLE)
                return makeList(node.kids.slice(1, -2).map(tr).concat([name(node.kids[node.kids.length - 2])]));
              }
            },
            'list-ty-param': function(node) {
              // (list-ty-param NAME COMMA)
              return name(node.kids[0]);
            },
            'for-bind': function(node) {
              // (for-bind name FROM e)
              return RUNTIME.getField(ast, 's-for-bind')
                .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[2]));
            },
            'prim-expr': function(node) {
              // (prim-expr e)
              return tr(node.kids[0]);
            },
            'obj-expr': function(node) {
              if (node.kids.length === 2) {
                // (obj-expr LBRACE RBRACE)
                return RUNTIME.getField(ast, 's-obj')
                  .app(pos(node.pos), makeList([]));
              } else {
                // (obj-expr LBRACE obj-fields RBRACE)
                return RUNTIME.getField(ast, 's-obj')
                  .app(pos(node.pos), tr(node.kids[1]));
              }
            },
            'list-elt': function(node) {
              return tr(node.kids[0]);
            },
            'bless-expr': function(node) {
              return RUNTIME.getField(ast, 's-bless')
                .app(pos(node.pos), tr(node.kids[1]), name(node.kids[3]));
            },
            'confirm-expr': function(node) {
              return RUNTIME.getField(ast, 's-confirm')
                .app(pos(node.pos), tr(node.kids[1]), name(node.kids[3]));
            },
            'construct-expr': function(node) {
              return RUNTIME.getField(ast, 's-construct')
                .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[2]), makeList(node.kids.slice(4, -1).map(tr)))
            },
            'construct-modifier': function(node) {
              if (node.kids.length === 0) {
                return RUNTIME.getField(ast, 's-construct-normal');
              } else if (node.kids.length === 1) {
                if (node.kids[0].name === "LAZY") {
                  return RUNTIME.getField(ast, 's-construct-lazy');
                }
              }
            },
            'app-expr': function(node) {
              // (app-expr f args)
              return RUNTIME.getField(ast, 's-app')
                .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[1]));
            },
            'id-expr': function(node) {
              // (id-expr x)
              return RUNTIME.getField(ast, 's-id')
                .app(pos(node.pos), name(node.kids[0]));
            },
            'dot-expr': function(node) {
              // (dot-expr obj PERIOD field)
              return RUNTIME.getField(ast, 's-dot')
                .app(pos(node.pos), tr(node.kids[0]), symbol(node.kids[2]));
            },
            'get-bang-expr': function(node) {
              // (get-bang-expr obj BANG field)
              return RUNTIME.getField(ast, 's-get-bang')
                .app(pos(node.pos), tr(node.kids[0]), symbol(node.kids[2]));
            },
            'bracket-expr': function(node) {
              // (bracket-expr obj PERIOD LBRACK field RBRACK)
              return RUNTIME.getField(ast, 's-bracket')
                .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[3]));
            },
            'cases-expr': function(node) {
              if (node.kids[node.kids.length - 4].name === "ELSE") {
                // (cases-expr CASES LPAREN type RPAREN val COLON branch ... PIPE ELSE THICKARROW elseblock END)
                return RUNTIME.getField(ast, 's-cases-else')
                  .app(pos(node.pos), tr(node.kids[2]), tr(node.kids[4]),
                       makeList(node.kids.slice(6, -5).map(tr)), tr(node.kids[node.kids.length - 2]));
              } else {
                // (cases-expr CASES LPAREN type RPAREN val COLON branch ... END)
                return RUNTIME.getField(ast, 's-cases')
                  .app(pos(node.pos), tr(node.kids[2]), tr(node.kids[4]),
                       makeList(node.kids.slice(6, -1).map(tr)));
              }
            },
            'if-pipe-expr': function(node) {
              if (node.kids[node.kids.length - 3].name === "OTHERWISECOLON") {
                // (if-pipe-expr IFCOLON branch ... BAR OTHERWISECOLON else END)
                return RUNTIME.getField(ast, 's-if-pipe-else')
                  .app(pos(node.pos), makeList(node.kids.slice(1, -4).map(tr)),
                       tr(node.kids[node.kids.length - 2]));
              } else {
                // (if-expr IFCOLON branch ... END)
                return RUNTIME.getField(ast, 's-if-pipe')
                  .app(pos(node.pos), makeList(node.kids.slice(1, -1).map(tr)));
              }
            },
            'if-expr': function(node) {
              if (node.kids[node.kids.length - 3].name === "ELSECOLON") {
                // (if-expr IF test COLON body branch ... ELSECOLON else END)
                return RUNTIME.getField(ast, 's-if-else')
                  .app(pos(node.pos), makeList(
                    [RUNTIME.getField(ast, 's-if-branch')
                     .app(pos(node.kids[1].pos), tr(node.kids[1]), tr(node.kids[3]))]
                      .concat(node.kids.slice(4, -3).map(tr))),
                       tr(node.kids[node.kids.length - 2]));
              } else {
                // (if-expr IF test COLON body branch ... END)
                return RUNTIME.getField(ast, 's-if')
                  .app(pos(node.pos), makeList(
                    [RUNTIME.getField(ast, 's-if-branch')
                     .app(pos(node.kids[1].pos), tr(node.kids[1]), tr(node.kids[3]))]
                      .concat(node.kids.slice(4, -1).map(tr))));
              }
            },
            'for-expr': function(node) {
              // (for-expr FOR iter LPAREN binds ... RPAREN return COLON body END)
              return RUNTIME.getField(ast, 's-for')
                .app(pos(node.pos), tr(node.kids[1]), makeList(node.kids.slice(3, -5).map(tr)),
                     tr(node.kids[node.kids.length - 4]), tr(node.kids[node.kids.length - 2]));
            },
            'for-bind-elt': function(node) {
              // (for-bind-elt b COMMA)
              return tr(node.kids[0]);
            },
            'try-expr': function(node) {
              // (try-expr TRY body EXCEPT LPAREN arg RPAREN COLON except END)
              return RUNTIME.getField(ast, 's-try')
                .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[4]), tr(node.kids[7]));
            },
            'user-block-expr': function(node) {
              // (user-block-expr BLOCK body END)
              return RUNTIME.getField(ast, 's-user-block')
                .app(pos(node.pos), tr(node.kids[1]));
            },
            'lambda-expr': function(node) {
              // (lambda-expr LAM ty-params args return-ann COLON doc body check END)
              return RUNTIME.getField(ast, 's-lam')
                .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[2]), tr(node.kids[3]),
                     tr(node.kids[5]), tr(node.kids[6]), tr(node.kids[7]));
            },
            'method-expr': function(node) {
              // (method-expr METHOD args return-ann COLON doc body check END)
              return RUNTIME.getField(ast, 's-method')
                .app(pos(node.pos), tr(node.kids[1]), tr(node.kids[2]),
                     tr(node.kids[4]), tr(node.kids[5]), tr(node.kids[6]));
            },
            'extend-expr': function(node) {
              // (extend-expr e PERIOD LBRACE fields RBRACE)
              return RUNTIME.getField(ast, 's-extend')
                .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[3]));
            },
            'update-expr': function(node) {
              // (update-expr e BANG LBRACE fields RBRACE)
              return RUNTIME.getField(ast, 's-update')
                .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[3]));
            },
            'paren-expr': function(node) {
              // (paren-expr LPAREN e RPAREN)
              return RUNTIME.getField(ast, 's-paren')
                .app(pos(node.pos), tr(node.kids[1]));
            },
            'paren-nospace-expr': function(node) {
              // (paren-nospace-expr LPAREN e RPAREN)
              return RUNTIME.getField(ast, 's-paren')
                .app(pos(node.pos), tr(node.kids[1]));
            },
            'inst-expr': function(node) {
              // (inst-expr e LANGLE (inst-elt a COMMA) ... alast RANGLE)
              return RUNTIME.getField(ast, 's-instantiate')
                .app(pos(node.pos), tr(node.kids[0]), makeList(node.kids.slice(2, -1).map(tr)));
            },
            'inst-elt': function(node) {
              // (inst-elt a COMMA)
              return tr(node.kids[0]);
            },
            'bool-expr': function(node) {
              if (node.kids[0].name === "TRUE") {
                return RUNTIME.getField(ast, 's-bool')
                  .app(pos(node.pos), RUNTIME.pyretTrue);
              } else {
                return RUNTIME.getField(ast, 's-bool')
                  .app(pos(node.pos), RUNTIME.pyretFalse);
              }
            },
            'num-expr': function(node) {
              // (num-expr n)
              return RUNTIME.getField(ast, 's-num')
                .app(pos(node.pos), number(node.kids[0]));
            },
            'frac-expr': function(node) {
              // (frac-expr n)
              var numden = node.kids[0].value.split("/");
              return RUNTIME.getField(ast, 's-frac')
                .app(pos(node.pos), RUNTIME.makeNumberFromString(numden[0]), RUNTIME.makeNumberFromString(numden[1]));
            },
            'string-expr': function(node) {
              return RUNTIME.getField(ast, 's-str')
                .app(pos(node.pos), string(node.kids[0]));
            },
            'ann-field': function(node) {
              // (ann-field n COLON ann) or (ann-field n COLONCOLON ann)
              return RUNTIME.getField(ast, 'a-field')
                .app(pos(node.pos), symbol(node.kids[0]), tr(node.kids[2]));
            },
            'name-ann': function(node) {
              if (node.kids[0].value === "Any") {
                return RUNTIME.getField(ast, 'a-any');
              } else {
                return RUNTIME.getField(ast, 'a-name')
                  .app(pos(node.pos), name(node.kids[0]));
              }
            },
            'record-ann': function(node) {
              // (record-ann LBRACE fields ... RBRACE)
              return RUNTIME.getField(ast, 'a-record')
                .app(pos(node.pos), makeList(node.kids.slice(1, -1).map(tr)));
            },
            'noparen-arrow-ann': function(node) {
              // (noparen-arrow-ann args ... THINARROW result)
              return RUNTIME.getField(ast, 'a-arrow')
                .app(pos(node.pos), makeList(node.kids.slice(0, -2).map(tr)), tr(node.kids[node.kids.length - 1]),
                    RUNTIME.pyretFalse);
            },
            'arrow-ann': function(node) {
              // (arrow-ann LPAREN args ... THINARROW result RPAREN)
              return RUNTIME.getField(ast, 'a-arrow')
                .app(pos(node.pos), makeList(node.kids.slice(1, -3).map(tr)), tr(node.kids[node.kids.length - 2]),
                    RUNTIME.pyretTrue);
            },
            'app-ann': function(node) {
              // (app-ann ann LANGLE args ... RANGLE)
              return RUNTIME.getField(ast, 'a-app')
                .app(pos(node.pos), tr(node.kids[0]), makeList(node.kids.slice(2, -1).map(tr)));
            },
            'pred-ann': function(node) {
              // (pred-ann ann PERCENT LPAREN exp RPAREN)
              return RUNTIME.getField(ast, 'a-pred')
                .app(pos(node.pos), tr(node.kids[0]), tr(node.kids[3]));
            },
            'dot-ann': function(node) {
              // (dot-ann n1 PERIOD n2)
              return RUNTIME.getField(ast, 'a-dot')
                .app(pos(node.pos), name(node.kids[0]), symbol(node.kids[2]));
            },
            'ann': function(node) {
              // (ann a)
              return tr(node.kids[0]);
            },
            'list-ann-field': function(node) {
              // (list-ann-field f COMMA)
              return tr(node.kids[0]);
            },
            'arrow-ann-elt': function(node) {
              // (arrow-ann-elt ann COMMA)
              return tr(node.kids[0]);
            },
            'app-ann-elt': function(node) {
              // (app-ann-elt ann COMMA)
              return tr(node.kids[0]);
            }
          };
          return tr(node);
        }

        const opLookup = {
          "+": RUNTIME.makeString("op+"),
          "-": RUNTIME.makeString("op-"),
          "*": RUNTIME.makeString("op*"),
          "/": RUNTIME.makeString("op/"),
          "$": RUNTIME.makeString("op^"),
          "^": RUNTIME.makeString("op^"),
          "<=": RUNTIME.makeString("op<="),
          "<": RUNTIME.makeString("op<"),
          ">=": RUNTIME.makeString("op>="),
          ">": RUNTIME.makeString("op>"),
          "==": RUNTIME.makeString("op=="),
          "<>": RUNTIME.makeString("op<>"),
          "and": RUNTIME.makeString("opand"),
          "or": RUNTIME.makeString("opor"),
          "is": RUNTIME.makeString("opis"),
          "raises": RUNTIME.makeString("opraises"),
          "satisfies": RUNTIME.makeString("opsatisfies"),
        }

        function parseDataRaw(dialect, data, fileName) {
          const toks = dialects.dialects[dialect].Tokenizer;
          const grammar = dialects.dialects[dialect].Grammar;
          toks.tokenizeFrom(data);
          // while (toks.hasNext())
          //   console.log(toks.next().toString(true));
          var parsed = grammar.parse(toks);
          //console.log("Result:");
          var countParses = grammar.countAllParses(parsed);
          if (countParses == 0) {
            var nextTok = toks.curTok; 
            console.error("There were " + countParses + " potential parses.\n" +
                          "Parse failed, next token is " + nextTok.toString(true) +
                          " at " + nextTok.pos.toString(true));
            console.log(nextTok);
            if (toks.isEOF(nextTok))
              RUNTIME.ffi.throwParseErrorEOF(makePyretPos(fileName, nextTok.pos));
            else
              RUNTIME.ffi.throwParseErrorNextToken(makePyretPos(fileName, nextTok.pos), nextTok.value || nextTok.toString(true));
          }
          //console.log("There were " + countParses + " potential parses");
          if (countParses === 1) {
            var ast = grammar.constructUniqueParse(parsed);
            //          console.log(ast.toString());
            return translate(ast, fileName);
          } else {
            var asts = grammar.constructAllParses(parsed);
            throw "Non-unique parse";
            for (var i = 0; i < asts.length; i++) {
              //console.log("Parse " + i + ": " + asts[i].toString());
              //            console.log(("" + asts[i]) === ("" + asts2[i]));
            }
            return translate(ast, fileName);
          }
        }
        
        function parseDataDialect(dialect, data, fileName) {
          F.checkArity(3, arguments, "parse-dialect");
          RUNTIME.checkString(dialect);
          RUNTIME.checkString(data);
          RUNTIME.checkString(fileName);
          return parseDataRaw(RUNTIME.unwrap(dialect), RUNTIME.unwrap(data), RUNTIME.unwrap(fileName));
        }
        function parsePyret(data, fileName) {
          F.checkArity(2, arguments, "surface-parse");
          RUNTIME.checkString(data);
          RUNTIME.checkString(fileName);
          return parseDataRaw("Pyret", RUNTIME.unwrap(data), RUNTIME.unwrap(fileName));
        }
        function parseBootstrap(data, fileName) {
          F.checkArity(2, arguments, "parse-bootstrap");
          RUNTIME.checkString(data);
          RUNTIME.checkString(fileName);
          return parseDataRaw("Bootstrap", RUNTIME.unwrap(data), RUNTIME.unwrap(fileName));
        }

        return RUNTIME.makeObject({
          provide: RUNTIME.makeObject({
            'parse-dialect': RUNTIME.makeFunction(parseDataDialect),
            'surface-parse': RUNTIME.makeFunction(parsePyret), // TODO: Rename this eventually
            'parse-bootstrap': RUNTIME.makeFunction(parseBootstrap)
          }),
          answer: NAMESPACE.get("nothing")
        });
      });
    });
  });
});




define('compiler/ast-anf.arr',["trove/ast",
"trove/pprint",
"trove/srcloc",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($A13653,$PP33754,$SL53855,$arrays73956,$lists94057,$option114158,$error134259,$sets154360) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/ast-anf.arr52"]) {
return R.modules["$src/arr/compiler/ast-anf.arr52"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/ast-anf.arr";
var D = R.undefined;
var L = [[M,14,0,155,14,30,185],
[M,14,13,168,14,19,174],
[M,15,0,186,15,30,216],
[M,15,13,199,15,19,205],
[M,16,0,217,16,24,241],
[M,16,13,230,16,19,236],
[M,17,0,242,17,22,264],
[M,17,11,253,17,17,259],
[M,18,0,265,18,27,292],
[M,18,15,280,18,21,286],
[M,19,0,293,19,23,316],
[M,19,12,305,19,18,311],
[M,20,0,317,20,29,346],
[M,20,17,334,20,23,340],
[M,21,0,347,21,28,375],
[M,21,17,364,21,23,370],
[M,22,0,376,22,23,399],
[M,22,10,386,22,16,392],
[M,23,0,400,23,34,434],
[M,23,15,415,23,21,421],
[M,24,0,435,24,24,459],
[M,24,10,445,24,16,451],
[M,25,0,460,25,24,484],
[M,25,10,470,25,16,476],
[M,26,0,485,26,22,507],
[M,26,9,494,26,15,500],
[M,27,0,508,27,31,539],
[M,27,16,524,27,22,530],
[M,28,0,540,28,24,564],
[M,28,10,550,28,16,556],
[M,29,0,565,29,29,594],
[M,29,13,578,29,19,584],
[M,30,0,595,30,35,630],
[M,30,22,617,30,28,623],
[M,31,0,631,31,29,660],
[M,31,17,648,31,23,654],
[M,32,0,661,32,29,690],
[M,32,13,674,32,19,680],
[M,33,0,691,33,31,722],
[M,33,14,705,33,20,711],
[M,34,0,723,34,21,744],
[M,34,9,732,34,15,738],
[M,35,0,745,35,32,777],
[M,35,14,759,35,20,765],
[M,37,0,779,37,40,819],
[M,37,12,791,37,22,801],
[M,9,0,96,791,3,27992],
[M,787,0,27859,791,3,27992],
[M,788,24,27929,788,43,27948],
[M,788,2,27907,790,5,27988],
[M,789,4,27966,789,17,27979],
[M,787,21,27880,787,33,27892],
[M,783,0,27771,785,3,27857],
[M,784,20,27833,784,39,27852],
[M,783,20,27791,783,24,27795],
[M,765,0,27176,781,3,27769],
[M,766,2,27252,780,5,27765],
[M,779,52,27749,779,61,27758],
[M,778,4,27665,778,35,27696],
[M,777,4,27631,777,33,27660],
[M,776,4,27598,776,32,27626],
[M,775,4,27565,775,32,27593],
[M,774,4,27529,774,35,27560],
[M,773,4,27478,773,50,27524],
[M,773,31,27505,773,46,27520],
[M,772,4,27433,772,44,27473],
[M,772,25,27454,772,40,27469],
[M,771,4,27392,771,40,27428],
[M,771,21,27409,771,36,27424],
[M,767,4,27271,770,9,27387],
[M,768,6,27297,770,9,27387],
[M,765,24,27200,765,28,27204],
[M,765,45,27221,765,56,27232],
[M,761,0,27083,763,3,27174],
[M,762,20,27150,762,39,27169],
[M,761,20,27103,761,29,27112],
[M,700,0,24665,759,3,27081],
[M,701,2,24746,758,5,27077],
[M,757,52,27061,757,61,27070],
[M,756,4,26964,756,48,27008],
[M,756,18,26978,756,32,26992],
[M,755,4,26900,755,63,26959],
[M,755,31,26927,755,45,26941],
[M,754,4,26839,754,60,26895],
[M,754,28,26863,754,42,26877],
[M,753,4,26780,753,58,26834],
[M,753,26,26802,753,40,26816],
[M,748,4,26595,752,9,26775],
[M,749,18,26644,749,32,26658],
[M,749,6,26632,749,51,26677],
[M,740,4,26280,747,28,26590],
[M,741,6,26334,743,9,26445],
[M,741,22,26350,743,9,26445],
[M,735,4,26095,739,9,26275],
[M,736,18,26144,736,32,26158],
[M,736,6,26132,736,51,26177],
[M,731,4,25969,734,9,26090],
[M,732,6,25997,734,9,26090],
[M,733,8,26052,733,22,26066],
[M,733,23,26067,733,30,26074],
[M,724,4,25648,730,38,25964],
[M,725,6,25688,725,51,25733],
[M,717,4,25330,723,38,25643],
[M,718,6,25367,718,51,25412],
[M,713,4,25202,716,9,25325],
[M,714,6,25236,716,9,25325],
[M,715,8,25291,715,22,25305],
[M,708,4,25038,712,9,25197],
[M,709,15,25076,709,29,25090],
[M,709,6,25067,709,45,25106],
[M,707,4,24971,707,66,25033],
[M,707,46,25013,707,65,25032],
[M,707,46,25013,707,61,25028],
[M,702,4,24770,706,50,24966],
[M,705,28,24898,705,44,24914],
[M,705,38,24908,705,43,24913],
[M,705,28,24898,705,37,24907],
[M,700,24,24689,700,33,24698],
[M,700,50,24715,700,61,24726],
[M,687,0,24241,698,3,24663],
[M,688,2,24327,694,5,24562],
[M,688,17,24342,694,5,24562],
[M,693,4,24511,693,49,24556],
[M,689,4,24365,692,9,24506],
[M,690,6,24407,692,9,24506],
[M,691,25,24480,691,35,24490],
[M,691,25,24480,691,31,24486],
[M,687,30,24271,687,38,24279],
[M,687,55,24296,687,66,24307],
[M,675,0,23929,685,3,24239],
[M,676,23,23998,676,42,24017],
[M,675,23,23952,675,28,23957],
[M,636,0,22414,673,3,23927],
[M,637,2,22494,672,5,23923],
[M,670,4,23821,671,74,23917],
[M,671,42,23885,671,56,23899],
[M,671,42,23885,671,72,23915],
[M,669,4,23767,669,53,23816],
[M,669,23,23786,669,37,23800],
[M,660,4,23407,668,35,23762],
[M,661,15,23473,661,29,23487],
[M,661,6,23464,661,45,23503],
[M,655,4,23238,659,9,23402],
[M,656,15,23281,656,29,23295],
[M,656,6,23272,656,45,23311],
[M,652,4,23130,654,33,23233],
[M,653,6,23158,653,47,23199],
[M,649,4,22975,651,72,23125],
[M,650,6,23007,650,51,23052],
[M,646,4,22820,648,72,22970],
[M,647,6,22852,647,51,22897],
[M,638,4,22517,645,9,22815],
[M,639,6,22551,639,50,22595],
[M,636,27,22441,636,32,22446],
[M,636,49,22463,636,60,22474],
[M,616,0,21708,634,3,22412],
[M,618,2,21833,633,5,22408],
[M,627,4,22225,632,48,22402],
[M,628,6,22255,631,9,22353],
[M,628,13,22262,631,9,22353],
[M,630,8,22316,630,35,22343],
[M,629,8,22290,629,25,22307],
[M,626,4,22177,626,47,22220],
[M,626,33,22206,626,46,22219],
[M,625,4,22123,625,53,22172],
[M,625,35,22154,625,52,22171],
[M,625,46,22165,625,51,22170],
[M,625,35,22154,625,45,22164],
[M,624,4,22068,624,54,22118],
[M,624,38,22102,624,53,22117],
[M,623,4,22011,623,56,22063],
[M,623,40,22047,623,55,22062],
[M,622,4,21958,622,52,22006],
[M,622,31,21985,622,46,22000],
[M,621,4,21911,621,46,21953],
[M,621,25,21932,621,40,21947],
[M,620,4,21884,620,26,21906],
[M,619,4,21855,619,28,21879],
[M,617,10,21797,617,43,21830],
[M,616,28,21736,616,33,21741],
[M,616,50,21758,616,61,21769],
[M,610,0,21564,614,3,21706],
[M,611,2,21623,613,5,21702],
[M,612,4,21672,612,20,21688],
[M,610,30,21594,610,41,21605],
[M,605,2,21466,607,5,21560],
[M,605,36,21500,605,42,21506],
[M,605,25,21489,605,28,21492],
[M,605,52,21516,605,59,21523],
[M,602,2,21397,604,5,21462],
[M,602,33,21428,602,39,21434],
[M,602,22,21417,602,25,21420],
[M,599,2,21336,601,5,21393],
[M,599,29,21363,599,35,21369],
[M,599,18,21352,599,21,21355],
[M,596,2,21279,598,5,21332],
[M,596,25,21302,596,28,21305],
[M,593,2,21215,595,5,21275],
[M,593,20,21233,593,23,21236],
[M,593,30,21243,593,37,21250],
[M,590,2,21154,592,5,21211],
[M,590,19,21171,590,22,21174],
[M,590,29,21181,590,35,21187],
[M,588,15,21120,588,38,21143],
[M,588,24,21129,588,37,21142],
[M,588,15,21120,588,23,21128],
[M,587,21,21079,587,24,21082],
[M,587,34,21092,587,44,21102],
[M,587,2,21060,589,5,21150],
[M,584,2,20999,586,5,21056],
[M,584,19,21016,584,22,21019],
[M,584,29,21026,584,35,21032],
[M,581,2,20945,583,5,20995],
[M,579,21,20917,579,38,20934],
[M,579,21,20917,579,32,20928],
[M,578,21,20859,578,24,20862],
[M,578,34,20872,578,40,20878],
[M,578,51,20889,578,55,20893],
[M,578,2,20840,580,5,20941],
[M,575,2,20756,577,5,20836],
[M,575,31,20785,575,37,20791],
[M,575,46,20800,575,51,20805],
[M,575,20,20774,575,23,20777],
[M,573,10,20732,573,23,20745],
[M,573,10,20732,573,17,20739],
[M,572,19,20715,572,23,20719],
[M,572,2,20698,574,5,20752],
[M,570,16,20641,570,39,20664],
[M,570,25,20650,570,38,20663],
[M,570,16,20641,570,24,20649],
[M,569,55,20602,569,60,20607],
[M,569,22,20569,569,25,20572],
[M,569,35,20582,569,46,20593],
[M,569,70,20617,569,75,20622],
[M,569,2,20549,571,5,20694],
[M,567,13,20492,567,36,20515],
[M,567,22,20501,567,35,20514],
[M,567,13,20492,567,21,20500],
[M,566,52,20456,566,57,20461],
[M,566,19,20423,566,22,20426],
[M,566,32,20436,566,43,20447],
[M,566,67,20471,566,72,20476],
[M,566,2,20406,568,5,20545],
[M,564,18,20373,564,33,20388],
[M,564,18,20373,564,27,20382],
[M,563,24,20319,563,27,20322],
[M,563,36,20331,563,40,20335],
[M,563,51,20346,563,57,20352],
[M,563,2,20297,565,5,20402],
[M,561,15,20264,561,30,20279],
[M,561,15,20264,561,24,20273],
[M,560,21,20213,560,24,20216],
[M,560,33,20225,560,37,20229],
[M,560,48,20240,560,54,20246],
[M,560,2,20194,562,5,20293],
[M,558,13,20161,558,28,20176],
[M,558,13,20161,558,22,20170],
[M,557,19,20112,557,22,20115],
[M,557,31,20124,557,35,20128],
[M,557,46,20139,557,52,20145],
[M,557,2,20095,559,5,20190],
[M,555,16,20041,555,32,20057],
[M,555,16,20041,555,26,20051],
[M,554,22,19981,554,25,19984],
[M,554,35,19994,554,39,19998],
[M,554,51,20010,554,63,20022],
[M,554,2,19961,556,5,20091],
[M,552,16,19907,552,32,19923],
[M,552,16,19907,552,26,19917],
[M,551,22,19847,551,25,19850],
[M,551,35,19860,551,39,19864],
[M,551,51,19876,551,63,19888],
[M,551,2,19827,553,5,19957],
[M,549,13,19791,549,38,19816],
[M,549,24,19802,549,37,19815],
[M,549,13,19791,549,23,19801],
[M,548,19,19748,548,22,19751],
[M,548,34,19763,548,46,19775],
[M,548,2,19731,550,5,19823],
[M,546,21,19697,546,44,19720],
[M,546,30,19706,546,43,19719],
[M,546,21,19697,546,29,19705],
[M,545,24,19637,545,27,19640],
[M,545,34,19647,545,40,19653],
[M,545,50,19663,545,60,19673],
[M,545,2,19615,547,5,19727],
[M,543,13,19563,543,29,19579],
[M,543,13,19563,543,23,19573],
[M,542,19,19510,542,22,19513],
[M,542,32,19523,542,36,19527],
[M,542,46,19537,542,56,19547],
[M,542,2,19493,544,5,19611],
[M,540,20,19465,540,37,19482],
[M,540,20,19465,540,31,19476],
[M,539,33,19421,539,39,19427],
[M,539,22,19410,539,25,19413],
[M,539,50,19438,539,54,19442],
[M,539,2,19390,541,5,19489],
[M,537,15,19366,537,28,19379],
[M,537,15,19366,537,22,19373],
[M,536,24,19339,536,33,19348],
[M,536,2,19317,538,5,19386],
[M,534,12,19263,534,25,19276],
[M,534,12,19263,534,19,19270],
[M,533,18,19210,533,21,19213],
[M,533,28,19220,533,32,19224],
[M,533,39,19231,533,44,19236],
[M,533,51,19243,533,56,19248],
[M,533,2,19194,535,5,19313],
[M,531,27,19105,531,40,19118],
[M,531,27,19105,531,34,19112],
[M,530,25,18977,530,28,18980],
[M,530,40,18992,530,47,18999],
[M,530,54,19006,530,58,19010],
[M,530,68,19020,530,78,19030],
[M,530,90,19042,530,96,19048],
[M,530,113,19065,530,123,19075],
[M,530,2,18954,532,5,19190],
[M,528,18,18902,528,34,18918],
[M,528,18,18902,528,28,18912],
[M,527,24,18844,527,27,18847],
[M,527,37,18857,527,41,18861],
[M,527,51,18871,527,61,18881],
[M,527,2,18822,529,5,18950],
[M,525,37,18795,525,53,18811],
[M,525,37,18795,525,47,18805],
[M,524,30,18709,524,33,18712],
[M,524,50,18729,524,61,18740],
[M,524,71,18750,524,76,18755],
[M,524,2,18681,526,5,18818],
[M,522,33,18639,522,64,18670],
[M,522,50,18656,522,63,18669],
[M,522,33,18639,522,49,18655],
[M,521,33,18554,521,36,18557],
[M,521,46,18567,521,52,18573],
[M,521,70,18591,521,82,18603],
[M,521,2,18523,523,5,18677],
[M,519,35,18453,519,61,18479],
[M,519,47,18465,519,60,18478],
[M,519,35,18453,519,46,18464],
[M,518,23,18314,518,26,18317],
[M,518,42,18333,518,45,18336],
[M,518,55,18346,518,61,18352],
[M,518,74,18365,518,94,18385],
[M,518,112,18403,518,124,18415],
[M,518,2,18293,520,5,18519],
[M,516,32,18228,516,59,18255],
[M,516,45,18241,516,58,18254],
[M,516,32,18228,516,44,18240],
[M,515,55,18135,515,61,18141],
[M,515,25,18105,515,28,18108],
[M,515,38,18118,515,44,18124],
[M,515,75,18155,515,89,18169],
[M,515,101,18181,515,113,18193],
[M,515,2,18082,517,5,18289],
[M,513,13,18041,513,27,18055],
[M,513,13,18041,513,21,18049],
[M,512,19,17992,512,22,17995],
[M,512,30,18003,512,39,18012],
[M,512,47,18020,512,52,18025],
[M,512,2,17975,514,5,18078],
[M,510,13,17915,510,29,17931],
[M,510,13,17915,510,23,17925],
[M,509,19,17850,509,22,17853],
[M,509,32,17863,509,37,17868],
[M,509,44,17875,509,53,17884],
[M,509,63,17894,509,68,17899],
[M,509,2,17833,511,5,17971],
[M,507,13,17773,507,29,17789],
[M,507,13,17773,507,23,17783],
[M,506,19,17708,506,22,17711],
[M,506,32,17721,506,37,17726],
[M,506,44,17733,506,53,17742],
[M,506,63,17752,506,68,17757],
[M,506,2,17691,508,5,17829],
[M,504,18,17646,504,34,17662],
[M,504,18,17646,504,28,17656],
[M,503,2,17595,505,5,17687],
[M,500,2,17513,502,5,17591],
[M,497,2,17441,499,5,17509],
[M,494,2,17332,496,5,17437],
[M,494,58,17388,494,64,17394],
[M,494,30,17360,494,33,17363],
[M,494,42,17372,494,48,17378],
[M,491,2,17227,493,5,17328],
[M,491,56,17281,491,62,17287],
[M,491,27,17252,491,30,17255],
[M,491,40,17265,491,46,17271],
[M,489,22,17156,489,45,17179],
[M,489,22,17156,489,39,17173],
[M,488,69,17108,488,75,17114],
[M,488,86,17125,488,92,17131],
[M,488,28,17067,488,31,17070],
[M,488,48,17087,488,59,17098],
[M,488,2,17041,490,5,17223],
[M,486,16,16989,486,39,17012],
[M,486,16,16989,486,33,17006],
[M,485,63,16964,485,69,16970],
[M,485,22,16923,485,25,16926],
[M,485,42,16943,485,53,16954],
[M,485,2,16903,487,5,17037],
[M,483,17,16848,483,43,16874],
[M,483,29,16860,483,42,16873],
[M,483,17,16848,483,28,16859],
[M,482,23,16784,482,26,16787],
[M,482,39,16800,482,52,16813],
[M,482,62,16823,482,67,16828],
[M,482,2,16763,484,5,16899],
[M,480,16,16685,480,34,16703],
[M,480,16,16685,480,28,16697],
[M,479,22,16588,479,25,16591],
[M,479,37,16603,479,41,16607],
[M,479,55,16621,479,59,16625],
[M,479,70,16636,479,84,16650],
[M,479,96,16662,479,100,16666],
[M,479,2,16568,481,5,16759],
[M,464,0,16057,476,3,16540],
[M,465,2,16091,475,5,16536],
[M,474,4,16468,474,66,16530],
[M,473,4,16419,473,48,16463],
[M,472,4,16378,472,40,16414],
[M,471,4,16331,471,46,16373],
[M,470,4,16284,470,46,16326],
[M,469,4,16241,469,42,16279],
[M,468,4,16200,468,40,16236],
[M,467,4,16159,467,40,16195],
[M,466,4,16112,466,46,16154],
[M,464,25,16082,464,29,16086],
[M,458,0,15905,462,3,16055],
[M,459,2,15945,461,5,16051],
[M,460,4,15970,460,79,16045],
[M,460,58,16024,460,71,16037],
[M,460,58,16024,460,78,16044],
[M,458,29,15934,458,35,15940],
[M,428,0,14591,456,3,15903],
[M,429,2,14640,455,5,15899],
[M,453,4,15850,454,29,15893],
[M,454,12,15876,454,25,15889],
[M,454,12,15876,454,28,15892],
[M,451,4,15753,452,58,15845],
[M,452,37,15824,452,57,15844],
[M,449,4,15662,450,55,15748],
[M,450,34,15727,450,54,15747],
[M,447,4,15572,448,54,15657],
[M,448,28,15631,448,41,15644],
[M,448,28,15631,448,46,15649],
[M,445,4,15488,446,51,15567],
[M,446,25,15541,446,38,15554],
[M,446,25,15541,446,43,15559],
[M,443,4,15408,444,49,15483],
[M,444,23,15457,444,36,15470],
[M,444,23,15457,444,41,15475],
[M,441,4,15305,442,67,15403],
[M,442,6,15342,442,67,15403],
[M,442,18,15354,442,31,15367],
[M,442,18,15354,442,37,15373],
[M,439,4,15202,440,67,15300],
[M,440,6,15239,440,67,15300],
[M,440,18,15251,440,31,15264],
[M,440,18,15251,440,37,15270],
[M,438,4,15130,438,71,15197],
[M,438,54,15180,438,69,15195],
[M,438,43,15169,438,70,15196],
[M,438,43,15169,438,53,15179],
[M,436,4,15042,437,55,15125],
[M,437,40,15110,437,53,15123],
[M,437,31,15101,437,54,15124],
[M,437,31,15101,437,39,15109],
[M,434,4,14949,435,65,15037],
[M,435,23,14995,435,36,15008],
[M,435,23,14995,435,39,15011],
[M,433,4,14871,433,77,14944],
[M,433,56,14923,433,69,14936],
[M,433,56,14923,433,76,14943],
[M,430,4,14671,432,71,14866],
[M,431,26,14747,431,39,14760],
[M,431,26,14747,431,47,14768],
[M,428,35,14626,428,44,14635],
[M,422,0,14442,426,3,14589],
[M,423,2,14479,425,5,14585],
[M,424,4,14502,424,81,14579],
[M,424,50,14548,424,80,14578],
[M,424,60,14558,424,79,14577],
[M,424,50,14548,424,59,14557],
[M,422,27,14469,422,32,14474],
[M,396,0,13534,420,3,14440],
[M,397,2,13571,419,5,14436],
[M,417,4,14372,418,39,14430],
[M,418,17,14408,418,35,14426],
[M,418,17,14408,418,38,14429],
[M,408,4,14120,416,9,14367],
[M,412,10,14246,412,23,14259],
[M,412,10,14246,412,26,14262],
[M,406,4,14016,407,77,14115],
[M,407,22,14060,407,35,14073],
[M,407,22,14060,407,38,14076],
[M,404,4,13923,405,66,14011],
[M,405,23,13968,405,41,13986],
[M,405,23,13968,405,45,13990],
[M,402,4,13796,403,91,13918],
[M,403,23,13850,403,37,13864],
[M,403,23,13850,403,43,13870],
[M,400,4,13669,401,91,13791],
[M,401,23,13723,401,37,13737],
[M,401,23,13723,401,43,13743],
[M,398,4,13594,399,39,13664],
[M,396,27,13561,396,32,13566],
[M,389,0,13303,394,3,13532],
[M,390,2,13350,393,5,13528],
[M,392,4,13453,392,73,13522],
[M,391,4,13376,391,76,13448],
[M,389,31,13334,389,42,13345],
[M,379,0,12905,387,3,13301],
[M,380,2,12943,386,5,13297],
[M,383,4,13100,385,74,13291],
[M,384,32,13181,384,53,13202],
[M,384,32,13181,384,66,13215],
[M,381,4,12965,382,94,13095],
[M,382,26,13027,382,47,13048],
[M,382,26,13027,382,60,13061],
[M,379,26,12931,379,33,12938],
[M,372,0,12726,377,3,12903],
[M,373,2,12760,376,5,12899],
[M,374,4,12780,375,80,12893],
[M,375,39,12852,375,55,12868],
[M,375,27,12840,375,56,12869],
[M,375,27,12840,375,38,12851],
[M,372,24,12750,372,29,12755],
[M,363,2,12445,365,56,12598],
[M,360,2,12312,362,56,12442],
[M,357,2,12193,359,50,12309],
[M,354,2,12081,356,43,12190],
[M,347,2,11799,354,0,12079],
[M,344,2,11678,346,48,11796],
[M,341,2,11559,343,49,11675],
[M,338,2,11448,340,41,11556],
[M,335,2,11325,337,48,11445],
[M,334,0,11312,370,3,12724],
[M,335,4,11327,335,34,11357],
[M,335,18,11341,335,21,11344],
[M,335,30,11353,335,33,11356],
[M,338,4,11450,338,32,11478],
[M,338,15,11461,338,18,11464],
[M,338,25,11471,338,31,11477],
[M,341,4,11561,341,32,11589],
[M,341,15,11572,341,18,11575],
[M,341,25,11582,341,31,11588],
[M,344,4,11680,344,34,11710],
[M,344,16,11692,344,19,11695],
[M,344,26,11702,344,33,11709],
[M,347,4,11801,347,43,11840],
[M,347,17,11814,347,20,11817],
[M,347,32,11829,347,42,11839],
[M,354,4,12083,354,25,12104],
[M,354,21,12100,354,24,12103],
[M,357,4,12195,357,32,12223],
[M,357,25,12216,357,31,12222],
[M,357,14,12205,357,17,12208],
[M,360,4,12314,360,36,12346],
[M,360,29,12339,360,35,12345],
[M,360,18,12328,360,21,12331],
[M,363,4,12447,363,56,12499],
[M,363,32,12475,363,38,12481],
[M,363,21,12464,363,24,12467],
[M,363,48,12491,363,55,12498],
[M,365,33,12575,365,51,12593],
[M,365,33,12575,365,49,12591],
[M,365,33,12575,365,40,12582],
[M,365,20,12562,365,26,12568],
[M,365,4,12546,365,56,12598],
[M,364,4,12510,364,34,12540],
[M,363,40,12483,363,55,12498],
[M,363,26,12469,363,38,12481],
[M,363,16,12459,363,24,12467],
[M,362,33,12419,362,51,12437],
[M,362,33,12419,362,49,12435],
[M,362,33,12419,362,40,12426],
[M,362,20,12406,362,26,12412],
[M,362,4,12390,362,56,12442],
[M,361,4,12357,361,31,12384],
[M,360,23,12333,360,35,12345],
[M,360,13,12323,360,21,12331],
[M,359,27,12286,359,45,12304],
[M,359,27,12286,359,43,12302],
[M,359,27,12286,359,34,12293],
[M,359,20,12279,359,26,12285],
[M,359,4,12263,359,50,12309],
[M,358,4,12234,358,27,12257],
[M,357,19,12210,357,31,12222],
[M,357,9,12200,357,17,12208],
[M,356,4,12151,356,43,12190],
[M,356,20,12167,356,26,12173],
[M,355,4,12115,355,34,12145],
[M,354,16,12095,354,24,12103],
[M,350,38,11937,350,61,11960],
[M,350,38,11937,350,44,11943],
[M,350,6,11905,350,26,11925],
[M,349,4,11883,352,7,12058],
[M,348,4,11851,348,30,11877],
[M,347,22,11819,347,42,11839],
[M,347,12,11809,347,20,11817],
[M,346,27,11775,346,43,11791],
[M,346,36,11784,346,42,11790],
[M,346,20,11768,346,26,11774],
[M,346,4,11752,346,48,11796],
[M,345,4,11721,345,29,11746],
[M,344,21,11697,344,33,11709],
[M,344,11,11687,344,19,11695],
[M,343,30,11656,343,44,11670],
[M,343,37,11663,343,43,11669],
[M,343,30,11656,343,36,11662],
[M,343,20,11646,343,29,11655],
[M,343,4,11630,343,49,11675],
[M,342,4,11600,342,28,11624],
[M,341,20,11577,341,31,11588],
[M,341,10,11567,341,18,11575],
[M,340,4,11519,340,41,11556],
[M,340,30,11545,340,36,11551],
[M,340,20,11535,340,29,11544],
[M,339,4,11489,339,28,11513],
[M,338,20,11466,338,31,11477],
[M,338,10,11456,338,18,11464],
[M,337,27,11424,337,43,11440],
[M,337,34,11431,337,42,11439],
[M,337,20,11417,337,26,11423],
[M,337,4,11401,337,48,11445],
[M,336,4,11368,336,31,11395],
[M,335,23,11346,335,33,11356],
[M,335,13,11336,335,21,11344],
[M,367,2,12610,369,5,12720],
[M,368,25,12657,368,81,12713],
[M,368,64,12696,368,76,12708],
[M,368,64,12696,368,74,12706],
[M,368,4,12636,368,15,12647],
[M,325,2,10995,327,100,11184],
[M,324,0,10980,332,3,11310],
[M,325,4,10997,325,52,11045],
[M,325,17,11010,325,20,11013],
[M,325,30,11023,325,36,11029],
[M,325,47,11040,325,51,11044],
[M,327,36,11120,327,53,11137],
[M,327,43,11127,327,52,11136],
[M,327,36,11120,327,42,11126],
[M,327,20,11104,327,27,11111],
[M,327,4,11088,327,99,11183],
[M,326,4,11056,326,30,11082],
[M,325,38,11031,325,51,11044],
[M,325,22,11015,325,36,11029],
[M,325,12,11005,325,20,11013],
[M,329,2,11196,331,5,11306],
[M,330,25,11243,330,81,11299],
[M,330,64,11282,330,76,11294],
[M,330,64,11282,330,74,11292],
[M,330,4,11222,330,15,11233],
[M,316,0,10660,322,3,10978],
[M,318,36,10765,318,58,10787],
[M,318,48,10777,318,57,10786],
[M,318,36,10765,318,45,10774],
[M,318,4,10733,318,24,10753],
[M,317,13,10713,317,20,10720],
[M,307,2,10436,309,41,10532],
[M,304,2,10242,306,81,10433],
[M,301,2,10057,303,78,10239],
[M,298,2,9866,300,94,10054],
[M,295,2,9680,297,95,9863],
[M,292,2,9497,294,96,9677],
[M,287,2,9346,291,7,9494],
[M,282,2,9195,286,7,9343],
[M,276,2,8938,281,7,9192],
[M,269,2,8660,275,7,8935],
[M,262,2,8385,268,7,8657],
[M,257,2,8156,261,7,8382],
[M,252,2,7949,256,7,8153],
[M,242,2,7307,251,7,7942],
[M,241,0,7289,314,3,10658],
[M,242,4,7309,242,79,7384],
[M,242,18,7323,242,21,7326],
[M,242,33,7338,242,37,7342],
[M,242,51,7356,242,55,7360],
[M,242,74,7379,242,78,7383],
[M,252,4,7951,252,110,8057],
[M,252,51,7998,252,57,8004],
[M,252,21,7968,252,24,7971],
[M,252,34,7981,252,40,7987],
[M,252,71,8018,252,85,8032],
[M,252,97,8044,252,109,8056],
[M,257,4,8158,257,51,8205],
[M,257,29,8183,257,35,8189],
[M,257,18,8172,257,21,8175],
[M,257,46,8200,257,50,8204],
[M,262,4,8387,262,53,8436],
[M,262,15,8398,262,18,8401],
[M,262,28,8411,262,32,8415],
[M,262,42,8425,262,52,8435],
[M,269,4,8662,269,57,8715],
[M,269,20,8678,269,23,8681],
[M,269,30,8688,269,36,8694],
[M,269,46,8704,269,56,8714],
[M,276,4,8940,276,43,8979],
[M,276,15,8951,276,18,8954],
[M,276,30,8966,276,42,8978],
[M,282,4,9197,282,60,9253],
[M,282,18,9211,282,21,9214],
[M,282,31,9224,282,35,9228],
[M,282,47,9240,282,59,9252],
[M,287,4,9348,287,60,9404],
[M,287,18,9362,287,21,9365],
[M,287,31,9375,287,35,9379],
[M,287,47,9391,287,59,9403],
[M,292,4,9499,292,49,9544],
[M,292,15,9510,292,18,9513],
[M,292,27,9522,292,31,9526],
[M,292,42,9537,292,48,9543],
[M,295,4,9682,295,51,9729],
[M,295,17,9695,295,20,9698],
[M,295,29,9707,295,33,9711],
[M,295,44,9722,295,50,9728],
[M,298,4,9868,298,54,9918],
[M,298,20,9884,298,23,9887],
[M,298,32,9896,298,36,9900],
[M,298,47,9911,298,53,9917],
[M,301,4,10059,301,69,10124],
[M,301,48,10103,301,53,10108],
[M,301,15,10070,301,18,10073],
[M,301,28,10083,301,39,10094],
[M,301,63,10118,301,68,10123],
[M,304,4,10244,304,72,10312],
[M,304,51,10291,304,56,10296],
[M,304,18,10258,304,21,10261],
[M,304,31,10271,304,42,10282],
[M,304,66,10306,304,71,10311],
[M,307,4,10438,307,20,10454],
[M,307,15,10449,307,19,10453],
[M,309,4,10495,309,41,10532],
[M,309,20,10511,309,35,10526],
[M,309,20,10511,309,26,10517],
[M,308,4,10465,308,28,10489],
[M,307,10,10444,307,19,10453],
[M,306,38,10390,306,54,10406],
[M,306,38,10390,306,44,10396],
[M,306,4,10356,306,81,10433],
[M,305,4,10323,305,31,10350],
[M,304,58,10298,304,71,10311],
[M,304,44,10284,304,56,10296],
[M,304,23,10263,304,42,10282],
[M,304,13,10253,304,21,10261],
[M,303,38,10199,303,51,10212],
[M,303,38,10199,303,44,10205],
[M,303,4,10165,303,78,10239],
[M,302,4,10135,302,28,10159],
[M,301,55,10110,301,68,10123],
[M,301,41,10096,301,53,10108],
[M,301,20,10075,301,39,10094],
[M,301,10,10065,301,18,10073],
[M,300,50,10010,300,69,10029],
[M,300,50,10010,300,67,10027],
[M,300,50,10010,300,58,10018],
[M,300,20,9980,300,28,9988],
[M,300,4,9964,300,94,10054],
[M,299,4,9929,299,33,9958],
[M,298,38,9902,298,53,9917],
[M,298,25,9889,298,36,9900],
[M,298,15,9879,298,23,9887],
[M,297,51,9819,297,70,9838],
[M,297,51,9819,297,68,9836],
[M,297,51,9819,297,59,9827],
[M,297,20,9788,297,28,9796],
[M,297,4,9772,297,95,9863],
[M,296,4,9740,296,30,9766],
[M,295,35,9713,295,50,9728],
[M,295,22,9700,295,33,9711],
[M,295,12,9690,295,20,9698],
[M,294,52,9633,294,71,9652],
[M,294,52,9633,294,69,9650],
[M,294,52,9633,294,60,9641],
[M,294,20,9601,294,28,9609],
[M,294,4,9585,294,96,9677],
[M,293,4,9555,293,28,9579],
[M,292,33,9528,292,48,9543],
[M,292,20,9515,292,31,9526],
[M,292,10,9505,292,18,9513],
[M,289,4,9448,291,7,9494],
[M,290,6,9470,290,12,9476],
[M,288,4,9415,288,31,9442],
[M,287,37,9381,287,59,9403],
[M,287,23,9367,287,35,9379],
[M,287,13,9357,287,21,9365],
[M,284,4,9297,286,7,9343],
[M,285,6,9319,285,12,9325],
[M,283,4,9264,283,31,9291],
[M,282,37,9230,282,59,9252],
[M,282,23,9216,282,35,9228],
[M,282,13,9206,282,21,9214],
[M,279,38,9074,279,60,9096],
[M,279,50,9086,279,59,9095],
[M,279,38,9074,279,47,9083],
[M,279,6,9042,279,26,9062],
[M,278,4,9020,281,7,9192],
[M,277,4,8990,277,28,9014],
[M,276,20,8956,276,42,8978],
[M,276,10,8946,276,18,8954],
[M,272,15,8792,272,29,8806],
[M,272,22,8799,272,28,8805],
[M,272,15,8792,272,21,8798],
[M,272,6,8783,272,14,8791],
[M,271,4,8761,275,7,8935],
[M,270,4,8726,270,33,8755],
[M,269,38,8696,269,56,8714],
[M,269,25,8683,269,36,8694],
[M,269,15,8673,269,23,8681],
[M,265,15,8508,265,35,8528],
[M,265,15,8508,265,33,8526],
[M,265,15,8508,265,24,8517],
[M,265,6,8499,265,14,8507],
[M,264,4,8477,268,7,8657],
[M,263,4,8447,263,28,8471],
[M,262,34,8417,262,52,8435],
[M,262,20,8403,262,32,8415],
[M,262,10,8393,262,18,8401],
[M,260,31,8296,260,49,8314],
[M,260,31,8296,260,47,8312],
[M,260,31,8296,260,38,8303],
[M,260,15,8280,260,22,8287],
[M,260,6,8271,260,14,8279],
[M,259,4,8249,261,7,8382],
[M,258,4,8216,258,31,8243],
[M,257,37,8191,257,50,8204],
[M,257,23,8177,257,35,8189],
[M,257,13,8167,257,21,8175],
[M,254,4,8104,256,7,8153],
[M,255,6,8126,255,12,8132],
[M,253,4,8068,253,34,8098],
[M,252,87,8034,252,109,8056],
[M,252,59,8006,252,85,8032],
[M,252,42,7989,252,57,8004],
[M,252,26,7973,252,40,7987],
[M,252,16,7963,252,24,7971],
[M,245,6,7450,245,22,7466],
[M,245,6,7450,245,12,7456],
[M,244,4,7428,251,7,7942],
[M,243,4,7395,243,31,7422],
[M,242,64,7369,242,78,7383],
[M,242,57,7362,242,62,7367],
[M,242,39,7344,242,55,7360],
[M,242,23,7328,242,37,7342],
[M,242,13,7318,242,21,7326],
[M,311,2,10544,313,5,10654],
[M,312,25,10591,312,81,10647],
[M,312,64,10630,312,76,10642],
[M,312,64,10630,312,74,10640],
[M,312,4,10570,312,15,10581],
[M,225,2,6933,233,7,7160],
[M,224,0,6910,238,3,7286],
[M,225,4,6935,229,5,7028],
[M,226,11,6964,226,14,6967],
[M,227,21,6990,227,32,7001],
[M,228,14,7017,228,19,7022],
[M,232,6,7102,232,33,7129],
[M,232,6,7102,232,31,7127],
[M,232,6,7102,232,22,7118],
[M,231,4,7080,233,7,7160],
[M,230,4,7039,230,39,7074],
[M,228,6,7009,228,19,7022],
[M,227,6,6975,227,32,7001],
[M,226,6,6959,226,14,6967],
[M,235,2,7172,237,5,7282],
[M,236,25,7219,236,81,7275],
[M,236,64,7258,236,76,7270],
[M,236,64,7258,236,74,7268],
[M,236,4,7198,236,15,7209],
[M,219,2,6810,221,42,6904],
[M,216,2,6716,218,41,6807],
[M,213,2,6629,215,34,6713],
[M,212,0,6609,222,3,6908],
[M,221,4,6866,221,42,6904],
[M,221,20,6882,221,26,6888],
[M,220,4,6832,220,32,6860],
[M,218,4,6770,218,41,6807],
[M,218,20,6786,218,26,6792],
[M,217,4,6737,217,31,6764],
[M,215,4,6683,215,34,6713],
[M,215,20,6699,215,26,6705],
[M,214,4,6650,214,31,6677],
[M,199,2,6296,205,43,6481],
[M,190,2,6054,198,43,6293],
[M,189,0,6037,210,3,6607],
[M,190,4,6056,196,5,6209],
[M,191,11,6078,191,14,6081],
[M,192,20,6103,192,23,6106],
[M,193,14,6122,193,20,6128],
[M,194,17,6147,194,37,6167],
[M,195,22,6191,196,4,6208],
[M,199,4,6298,203,5,6397],
[M,200,11,6330,200,14,6333],
[M,201,14,6349,201,20,6355],
[M,202,22,6379,203,4,6396],
[M,205,4,6442,205,43,6481],
[M,205,20,6458,205,26,6464],
[M,204,4,6408,204,32,6436],
[M,202,6,6363,203,4,6396],
[M,201,6,6341,201,20,6355],
[M,200,6,6325,200,14,6333],
[M,198,4,6254,198,43,6293],
[M,198,20,6270,198,26,6276],
[M,197,4,6220,197,32,6248],
[M,195,6,6175,196,4,6208],
[M,194,6,6136,194,37,6167],
[M,193,6,6114,193,20,6128],
[M,192,6,6089,192,23,6106],
[M,191,6,6073,191,14,6081],
[M,207,2,6493,209,5,6603],
[M,208,25,6540,208,81,6596],
[M,208,64,6579,208,76,6591],
[M,208,64,6579,208,74,6589],
[M,208,4,6519,208,15,6530],
[M,176,2,5647,182,7,5909],
[M,175,0,5633,187,3,6035],
[M,176,4,5649,176,48,5693],
[M,176,27,5672,176,33,5678],
[M,176,42,5687,176,47,5692],
[M,176,16,5661,176,19,5664],
[M,179,9,5760,179,31,5782],
[M,179,22,5773,179,30,5781],
[M,179,9,5760,179,21,5772],
[M,178,4,5735,182,7,5909],
[M,177,4,5704,177,29,5729],
[M,176,35,5680,176,47,5692],
[M,176,21,5666,176,33,5678],
[M,176,11,5656,176,19,5664],
[M,184,2,5921,186,5,6031],
[M,185,25,5968,185,81,6024],
[M,185,64,6007,185,76,6019],
[M,185,64,6007,185,74,6017],
[M,185,4,5947,185,15,5958],
[M,164,2,5384,168,7,5505],
[M,154,2,4994,163,7,5381],
[M,139,2,4232,153,7,4991],
[M,132,2,3953,138,7,4229],
[M,127,2,3779,131,7,3950],
[M,117,2,3420,126,7,3776],
[M,107,2,3061,116,7,3417],
[M,97,2,2748,106,7,3058],
[M,96,0,2734,173,3,5631],
[M,97,4,2750,97,58,2804],
[M,97,20,2766,97,23,2769],
[M,97,33,2779,97,42,2788],
[M,97,52,2798,97,57,2803],
[M,107,4,3063,107,65,3124],
[M,107,15,3074,107,18,3077],
[M,107,28,3087,107,33,3092],
[M,107,40,3099,107,49,3108],
[M,107,59,3118,107,64,3123],
[M,117,4,3422,117,65,3483],
[M,117,15,3433,117,18,3436],
[M,117,28,3446,117,33,3451],
[M,117,40,3458,117,49,3467],
[M,117,59,3477,117,64,3482],
[M,127,4,3781,127,49,3826],
[M,127,15,3792,127,18,3795],
[M,127,26,3803,127,35,3812],
[M,127,43,3820,127,48,3825],
[M,132,4,3955,132,55,4006],
[M,132,20,3971,132,23,3974],
[M,132,30,3981,132,34,3985],
[M,132,44,3995,132,54,4005],
[M,139,4,4234,139,120,4350],
[M,139,86,4316,139,92,4322],
[M,139,21,4251,139,24,4254],
[M,139,36,4266,139,43,4273],
[M,139,50,4280,139,54,4284],
[M,139,64,4294,139,74,4304],
[M,139,109,4339,139,119,4349],
[M,154,4,4996,154,53,5045],
[M,154,14,5006,154,17,5009],
[M,154,24,5016,154,28,5020],
[M,154,35,5027,154,40,5032],
[M,154,47,5039,154,52,5044],
[M,164,4,5386,164,30,5412],
[M,164,20,5402,164,29,5411],
[M,166,4,5458,168,7,5505],
[M,167,6,5480,167,21,5495],
[M,167,6,5480,167,12,5486],
[M,165,4,5423,165,33,5452],
[M,164,15,5397,164,29,5411],
[M,158,25,5142,158,36,5153],
[M,158,17,5134,158,24,5141],
[M,157,6,5107,157,14,5115],
[M,156,4,5085,163,7,5381],
[M,155,4,5056,155,27,5079],
[M,154,42,5034,154,52,5044],
[M,154,30,5022,154,40,5032],
[M,154,19,5011,154,28,5020],
[M,154,9,5001,154,17,5009],
[M,144,12,4474,144,28,4490],
[M,144,12,4474,144,18,4480],
[M,143,17,4446,143,24,4453],
[M,143,8,4437,143,16,4445],
[M,142,6,4419,142,14,4427],
[M,141,4,4397,153,7,4991],
[M,140,4,4361,140,34,4391],
[M,139,94,4324,139,119,4349],
[M,139,76,4306,139,92,4322],
[M,139,56,4286,139,74,4304],
[M,139,45,4275,139,54,4284],
[M,139,26,4256,139,43,4273],
[M,139,16,4246,139,24,4254],
[M,135,15,4083,135,32,4100],
[M,135,15,4083,135,30,4098],
[M,135,15,4083,135,21,4089],
[M,135,6,4074,135,14,4082],
[M,134,4,4052,138,7,4229],
[M,133,4,4017,133,33,4046],
[M,132,36,3987,132,54,4005],
[M,132,25,3976,132,34,3985],
[M,132,15,3966,132,23,3974],
[M,130,6,3889,130,24,3907],
[M,130,6,3889,130,22,3905],
[M,130,6,3889,130,13,3896],
[M,129,4,3867,131,7,3950],
[M,128,4,3837,128,28,3861],
[M,127,37,3814,127,48,3825],
[M,127,20,3797,127,35,3812],
[M,127,10,3787,127,18,3795],
[M,123,12,3637,123,32,3657],
[M,123,12,3637,123,30,3655],
[M,123,12,3637,123,21,3646],
[M,122,17,3609,122,24,3616],
[M,122,8,3600,122,16,3608],
[M,120,6,3546,120,22,3562],
[M,119,4,3524,126,7,3776],
[M,118,4,3494,118,28,3518],
[M,117,51,3469,117,64,3482],
[M,117,35,3453,117,49,3467],
[M,117,20,3438,117,33,3451],
[M,117,10,3428,117,18,3436],
[M,113,12,3278,113,32,3298],
[M,113,12,3278,113,30,3296],
[M,113,12,3278,113,21,3287],
[M,112,17,3250,112,24,3257],
[M,112,8,3241,112,16,3249],
[M,110,6,3187,110,22,3203],
[M,109,4,3165,116,7,3417],
[M,108,4,3135,108,28,3159],
[M,107,51,3110,107,64,3123],
[M,107,35,3094,107,49,3108],
[M,107,20,3079,107,33,3092],
[M,107,10,3069,107,18,3077],
[M,103,12,2968,103,32,2988],
[M,103,12,2968,103,30,2986],
[M,103,12,2968,103,21,2977],
[M,102,17,2940,102,24,2947],
[M,102,8,2931,102,16,2939],
[M,100,6,2872,100,22,2888],
[M,99,4,2850,106,7,3058],
[M,98,4,2815,98,33,2844],
[M,97,44,2790,97,57,2803],
[M,97,25,2771,97,42,2788],
[M,97,15,2761,97,23,2769],
[M,170,2,5517,172,5,5627],
[M,171,25,5564,171,81,5620],
[M,171,64,5603,171,76,5615],
[M,171,64,5603,171,74,5613],
[M,171,4,5543,171,15,5554],
[M,85,2,2366,89,7,2606],
[M,82,2,2165,84,102,2363],
[M,81,0,2147,94,3,2732],
[M,82,4,2167,82,55,2218],
[M,82,34,2197,82,40,2203],
[M,82,49,2212,82,54,2217],
[M,82,21,2184,82,24,2187],
[M,85,4,2368,85,61,2425],
[M,85,37,2401,85,43,2407],
[M,85,54,2418,85,60,2424],
[M,85,24,2388,85,27,2391],
[M,88,29,2520,88,49,2540],
[M,88,29,2520,88,47,2538],
[M,88,29,2520,88,38,2529],
[M,88,6,2497,88,14,2505],
[M,87,4,2475,89,7,2606],
[M,86,4,2436,86,37,2469],
[M,85,45,2409,85,60,2424],
[M,85,29,2393,85,43,2407],
[M,85,19,2383,85,27,2391],
[M,84,56,2317,84,76,2337],
[M,84,56,2317,84,74,2335],
[M,84,56,2317,84,65,2326],
[M,84,20,2281,84,28,2289],
[M,84,4,2265,84,102,2363],
[M,83,4,2229,83,34,2259],
[M,82,42,2205,82,54,2217],
[M,82,26,2189,82,40,2203],
[M,82,16,2179,82,24,2187],
[M,91,2,2618,93,5,2728],
[M,92,25,2665,92,81,2721],
[M,92,64,2704,92,76,2716],
[M,92,64,2704,92,74,2714],
[M,92,4,2644,92,15,2655],
[M,70,2,1728,74,7,2019],
[M,65,2,1501,69,7,1725],
[M,64,0,1485,79,3,2145],
[M,65,4,1503,65,66,1565],
[M,65,59,1558,65,65,1564],
[M,65,18,1517,65,21,1520],
[M,65,38,1537,65,49,1548],
[M,70,4,1730,70,89,1815],
[M,70,65,1791,70,71,1797],
[M,70,82,1808,70,88,1814],
[M,70,24,1750,70,27,1753],
[M,70,44,1770,70,55,1781],
[M,73,33,1914,73,60,1941],
[M,73,33,1914,73,58,1939],
[M,73,33,1914,73,49,1930],
[M,73,14,1895,73,129,2010],
[M,73,6,1887,73,13,1894],
[M,72,4,1865,74,7,2019],
[M,71,4,1826,71,37,1859],
[M,70,73,1799,70,88,1814],
[M,70,57,1783,70,71,1797],
[M,70,29,1755,70,55,1781],
[M,70,19,1745,70,27,1753],
[M,68,33,1658,68,60,1685],
[M,68,33,1658,68,58,1683],
[M,68,33,1658,68,49,1674],
[M,68,14,1639,68,91,1716],
[M,68,6,1631,68,13,1638],
[M,67,4,1609,69,7,1725],
[M,66,4,1576,66,31,1603],
[M,65,51,1550,65,65,1564],
[M,65,23,1522,65,49,1548],
[M,65,13,1512,65,21,1520],
[M,76,2,2031,78,5,2141],
[M,77,25,2078,77,81,2134],
[M,77,64,2117,77,76,2129],
[M,77,64,2117,77,74,2127],
[M,77,4,2057,77,15,2068],
[M,60,2,1379,61,52,1479],
[M,58,2,1286,59,40,1376],
[M,57,0,1266,62,3,1483],
[M,58,4,1288,58,45,1329],
[M,58,26,1310,58,29,1313],
[M,58,38,1322,58,44,1328],
[M,60,4,1381,60,43,1420],
[M,60,23,1400,60,26,1403],
[M,60,36,1413,60,42,1419],
[M,61,30,1457,61,47,1474],
[M,61,37,1464,61,46,1473],
[M,61,30,1457,61,36,1463],
[M,61,20,1447,61,29,1456],
[M,61,4,1431,61,52,1479],
[M,60,28,1405,60,42,1419],
[M,60,18,1395,60,26,1403],
[M,59,4,1340,59,40,1376],
[M,59,27,1363,59,35,1371],
[M,59,20,1356,59,26,1362],
[M,58,31,1315,58,44,1328],
[M,58,21,1305,58,29,1313],
[M,42,2,852,50,7,1138],
[M,41,0,838,55,3,1264],
[M,42,4,854,42,64,914],
[M,42,19,869,42,22,872],
[M,42,35,885,42,48,898],
[M,42,58,908,42,63,913],
[M,46,8,999,46,72,1063],
[M,46,59,1050,46,71,1062],
[M,46,33,1024,46,57,1048],
[M,46,41,1032,46,51,1042],
[M,46,20,1011,46,31,1022],
[M,46,8,999,46,19,1010],
[M,45,6,981,45,14,989],
[M,44,4,959,50,7,1138],
[M,43,4,925,43,32,953],
[M,42,50,900,42,63,913],
[M,42,24,874,42,48,898],
[M,42,14,864,42,22,872],
[M,52,2,1150,54,5,1260],
[M,53,25,1197,53,81,1253],
[M,53,64,1236,53,76,1248],
[M,53,64,1236,53,74,1246],
[M,53,4,1176,53,15,1187],
[M,39,6,827,39,15,836],
[M,680,2,24075,680,12,24085],
[M,679,6,24048,679,30,24072],
[M,679,6,24048,679,20,24062],
[M,681,2,24088,681,12,24098],
[M,682,2,24101,684,62,24235],
[M,683,15,24128,683,38,24151],
[M,683,28,24141,683,37,24150],
[M,683,46,24159,683,57,24170],
[M,683,40,24153,683,58,24171],
[M,684,25,24198,684,35,24208],
[M,684,19,24192,684,36,24209],
[M,684,8,24181,684,37,24210],
[M,683,6,24119,684,38,24211],
[M,682,2,24101,684,39,24212],
[M,682,2,24101,684,49,24222],
[M,682,2,24101,684,47,24220],
[M,684,53,24226,684,62,24235],
[M,779,20,27717,779,62,27759],
[M,757,20,27029,757,62,27071],
[M,750,6,26684,752,9,26775],
[M,751,8,26737,751,22,26751],
[M,751,23,26752,751,30,26759],
[M,744,6,26452,746,9,26561],
[M,744,20,26466,746,9,26561],
[M,745,8,26523,745,22,26537],
[M,745,23,26538,745,30,26545],
[M,747,6,26568,747,21,26583],
[M,737,6,26184,739,9,26275],
[M,738,8,26237,738,22,26251],
[M,738,23,26252,738,30,26259],
[M,726,64,25798,726,78,25812],
[M,726,73,25807,726,77,25811],
[M,726,64,25798,726,72,25806],
[M,726,42,25776,726,63,25797],
[M,726,21,25755,726,41,25775],
[M,726,42,25776,726,79,25813],
[M,726,6,25740,726,80,25814],
[M,727,6,25821,729,9,25925],
[M,727,18,25833,729,9,25925],
[M,728,25,25904,728,30,25909],
[M,719,64,25477,719,78,25491],
[M,719,73,25486,719,77,25490],
[M,719,64,25477,719,72,25485],
[M,719,42,25455,719,63,25476],
[M,719,21,25434,719,41,25454],
[M,719,42,25455,719,79,25492],
[M,719,6,25419,719,80,25493],
[M,720,6,25500,722,9,25604],
[M,720,18,25512,722,9,25604],
[M,721,25,25583,721,30,25588],
[M,710,6,25113,712,9,25197],
[M,711,8,25163,711,22,25177],
[M,707,28,24995,707,42,25009],
[M,706,12,24928,706,26,24942],
[M,706,12,24928,706,47,24963],
[M,705,10,24880,706,48,24964],
[M,704,8,24848,704,22,24862],
[M,704,8,24848,706,49,24965],
[M,703,6,24820,703,20,24834],
[M,695,41,24604,695,55,24618],
[M,695,2,24565,697,5,24659],
[M,696,4,24625,696,18,24639],
[M,696,19,24640,696,26,24647],
[M,671,24,23867,671,73,23916],
[M,662,6,23510,664,9,23606],
[M,662,18,23522,664,9,23606],
[M,663,8,23572,663,22,23586],
[M,665,6,23613,667,9,23726],
[M,665,25,23632,667,9,23726],
[M,666,8,23692,666,22,23706],
[M,668,6,23733,668,29,23756],
[M,657,6,23318,659,9,23402],
[M,658,8,23368,658,22,23382],
[M,654,6,23206,654,20,23220],
[M,651,48,23101,651,70,23123],
[M,651,65,23118,651,69,23122],
[M,651,48,23101,651,64,23117],
[M,651,23,23076,651,28,23081],
[M,651,30,23083,651,44,23097],
[M,651,30,23083,651,71,23124],
[M,648,48,22946,648,70,22968],
[M,648,65,22963,648,69,22967],
[M,648,48,22946,648,64,22962],
[M,648,23,22921,648,28,22926],
[M,648,30,22928,648,44,22942],
[M,648,30,22928,648,71,22969],
[M,640,6,22602,645,9,22815],
[M,643,8,22724,644,45,22805],
[M,644,10,22770,644,31,22791],
[M,644,10,22770,644,25,22785],
[M,641,8,22630,642,54,22715],
[M,642,32,22693,642,53,22714],
[M,642,32,22693,642,47,22708],
[M,644,10,22770,644,38,22798],
[M,632,26,22380,632,47,22401],
[M,632,26,22380,632,41,22395],
[M,570,46,20671,570,62,20687],
[M,570,46,20671,570,56,20681],
[M,567,43,20522,567,59,20538],
[M,567,43,20522,567,53,20532],
[M,555,34,20059,555,59,20084],
[M,555,45,20070,555,58,20083],
[M,555,34,20059,555,44,20069],
[M,552,34,19925,552,59,19950],
[M,552,45,19936,552,58,19949],
[M,552,34,19925,552,44,19935],
[M,543,31,19581,543,54,19604],
[M,543,40,19590,543,53,19603],
[M,543,31,19581,543,39,19589],
[M,534,27,19278,534,40,19291],
[M,534,27,19278,534,34,19285],
[M,534,42,19293,534,55,19306],
[M,534,42,19293,534,49,19300],
[M,531,42,19120,531,65,19143],
[M,531,51,19129,531,64,19142],
[M,531,42,19120,531,50,19128],
[M,531,75,19153,531,105,19183],
[M,531,91,19169,531,104,19182],
[M,531,75,19153,531,90,19168],
[M,528,36,18920,528,59,18943],
[M,528,45,18929,528,58,18942],
[M,528,36,18920,528,44,18928],
[M,519,63,18481,519,94,18512],
[M,519,80,18498,519,93,18511],
[M,519,63,18481,519,79,18497],
[M,516,61,18257,516,86,18282],
[M,516,72,18268,516,85,18281],
[M,516,61,18257,516,71,18267],
[M,513,29,18057,513,43,18071],
[M,513,29,18057,513,37,18065],
[M,510,31,17933,510,44,17946],
[M,510,31,17933,510,38,17940],
[M,510,46,17948,510,62,17964],
[M,510,46,17948,510,56,17958],
[M,507,31,17791,507,44,17804],
[M,507,31,17791,507,38,17798],
[M,507,46,17806,507,62,17822],
[M,507,46,17806,507,56,17816],
[M,504,36,17664,504,52,17680],
[M,504,36,17664,504,46,17674],
[M,489,47,17181,489,63,17197],
[M,489,47,17181,489,57,17191],
[M,489,65,17199,489,82,17216],
[M,489,65,17199,489,76,17210],
[M,486,41,17014,486,57,17030],
[M,486,41,17014,486,51,17024],
[M,483,45,16876,483,61,16892],
[M,483,45,16876,483,55,16886],
[M,480,36,16705,480,56,16725],
[M,480,36,16705,480,50,16719],
[M,480,65,16734,480,83,16752],
[M,480,65,16734,480,77,16746],
[M,442,50,15386,442,65,15401],
[M,442,39,15375,442,66,15402],
[M,442,39,15375,442,49,15385],
[M,440,50,15283,440,65,15298],
[M,440,39,15272,440,66,15299],
[M,440,39,15272,440,49,15282],
[M,435,50,15022,435,63,15035],
[M,435,41,15013,435,64,15036],
[M,435,41,15013,435,49,15021],
[M,431,49,14770,431,62,14783],
[M,431,49,14770,431,72,14793],
[M,432,8,14803,432,47,14842],
[M,432,18,14813,432,46,14841],
[M,432,26,14821,432,45,14840],
[M,432,8,14803,432,17,14812],
[M,432,49,14844,432,62,14857],
[M,432,49,14844,432,70,14865],
[M,413,19,14283,413,32,14296],
[M,413,10,14274,413,33,14297],
[M,413,10,14274,413,18,14282],
[M,415,26,14343,415,39,14356],
[M,415,10,14327,415,40,14357],
[M,415,10,14327,415,25,14342],
[M,407,40,14078,407,57,14095],
[M,407,59,14097,407,76,14114],
[M,405,47,13992,405,65,14010],
[M,403,45,13872,403,63,13890],
[M,403,45,13872,403,68,13895],
[M,403,70,13897,403,90,13917],
[M,401,45,13745,401,63,13763],
[M,401,45,13745,401,68,13768],
[M,401,70,13770,401,90,13790],
[M,385,8,13225,385,39,13256],
[M,385,19,13236,385,38,13255],
[M,385,8,13225,385,18,13235],
[M,385,41,13258,385,73,13290],
[M,385,53,13270,385,72,13289],
[M,385,41,13258,385,52,13269],
[M,382,62,13063,382,93,13094],
[M,382,73,13074,382,92,13093],
[M,382,62,13063,382,72,13073],
[M,375,65,12878,375,79,12892],
[M,365,27,12569,365,52,12594],
[M,362,27,12413,362,52,12438],
[M,350,63,11962,350,85,11984],
[M,350,63,11962,350,69,11968],
[M,351,8,12020,351,37,12049],
[M,351,24,12036,351,36,12048],
[M,351,8,12020,351,23,12035],
[M,351,8,12020,351,19,12031],
[M,350,102,12001,350,111,12010],
[M,350,87,11986,350,100,11999],
[M,368,38,12670,368,77,12709],
[M,327,36,11120,327,95,11179],
[M,327,73,11157,327,94,11178],
[M,327,73,11157,327,92,11176],
[M,327,73,11157,327,83,11167],
[M,330,38,11256,330,77,11295],
[M,319,6,10831,319,40,10865],
[M,319,15,10840,319,39,10864],
[M,319,23,10848,319,33,10858],
[M,319,6,10831,319,14,10839],
[M,318,85,10814,318,94,10823],
[M,318,70,10799,318,83,10812],
[M,318,59,10788,318,68,10797],
[M,318,4,10733,319,41,10866],
[M,317,2,10702,319,42,10867],
[M,320,20,10888,320,47,10915],
[M,320,11,10879,320,19,10887],
[M,320,2,10870,320,47,10915],
[M,321,33,10949,321,48,10964],
[M,321,33,10949,321,46,10962],
[M,321,2,10918,321,13,10929],
[M,306,20,10372,306,37,10389],
[M,306,67,10419,306,76,10428],
[M,306,56,10408,306,65,10417],
[M,303,20,10181,303,37,10198],
[M,303,64,10225,303,73,10234],
[M,303,53,10214,303,62,10223],
[M,300,71,10031,300,89,10049],
[M,300,78,10038,300,88,10048],
[M,300,71,10031,300,77,10037],
[M,297,72,9840,297,90,9858],
[M,297,79,9847,297,89,9857],
[M,297,72,9840,297,78,9846],
[M,294,73,9654,294,91,9672],
[M,294,80,9661,294,90,9671],
[M,294,73,9654,294,79,9660],
[M,280,45,9142,280,86,9183],
[M,280,61,9158,280,85,9182],
[M,280,69,9166,280,79,9176],
[M,280,45,9142,280,60,9157],
[M,280,45,9142,280,56,9153],
[M,280,34,9131,280,43,9140],
[M,280,19,9116,280,32,9129],
[M,280,8,9105,280,17,9114],
[M,274,39,8884,274,78,8923],
[M,274,53,8898,274,77,8922],
[M,274,61,8906,274,71,8916],
[M,274,39,8884,274,52,8897],
[M,274,39,8884,274,48,8893],
[M,274,24,8869,274,37,8882],
[M,274,12,8857,274,23,8868],
[M,273,20,8829,273,27,8836],
[M,273,10,8819,273,19,8828],
[M,274,12,8857,274,79,8924],
[M,273,20,8829,274,80,8925],
[M,273,10,8819,274,81,8926],
[M,272,15,8792,274,82,8927],
[M,267,39,8606,267,78,8645],
[M,267,53,8620,267,77,8644],
[M,267,61,8628,267,71,8638],
[M,267,39,8606,267,52,8619],
[M,267,39,8606,267,48,8615],
[M,267,24,8591,267,37,8604],
[M,267,12,8579,267,23,8590],
[M,266,22,8551,266,29,8558],
[M,266,12,8541,266,21,8550],
[M,267,12,8579,267,79,8646],
[M,266,22,8551,267,80,8647],
[M,266,12,8541,267,81,8648],
[M,265,15,8508,267,82,8649],
[M,260,31,8296,260,108,8373],
[M,260,86,8351,260,107,8372],
[M,260,86,8351,260,105,8370],
[M,260,86,8351,260,96,8361],
[M,260,15,8280,260,108,8373],
[M,246,43,7571,246,59,7587],
[M,246,43,7571,246,49,7577],
[M,246,12,7540,246,20,7548],
[M,245,77,7521,250,85,7932],
[M,245,62,7506,245,75,7519],
[M,245,47,7491,245,60,7504],
[M,245,35,7479,245,46,7490],
[M,245,25,7469,245,34,7478],
[M,246,61,7589,246,83,7611],
[M,246,61,7589,246,81,7609],
[M,246,61,7589,246,72,7600],
[M,246,12,7540,246,84,7612],
[M,247,43,7657,247,61,7675],
[M,247,43,7657,247,49,7663],
[M,247,12,7626,247,20,7634],
[M,247,63,7677,247,87,7701],
[M,247,63,7677,247,85,7699],
[M,247,63,7677,247,76,7690],
[M,247,12,7626,247,88,7702],
[M,248,43,7747,248,58,7762],
[M,248,43,7747,248,49,7753],
[M,248,12,7716,248,20,7724],
[M,249,26,7791,249,78,7843],
[M,249,67,7832,249,77,7842],
[M,249,53,7818,249,65,7830],
[M,249,38,7803,249,51,7816],
[M,249,26,7791,249,37,7802],
[M,249,14,7779,249,25,7790],
[M,249,14,7779,249,79,7844],
[M,248,12,7716,249,80,7845],
[M,250,43,7890,250,59,7906],
[M,250,43,7890,250,49,7896],
[M,250,12,7859,250,20,7867],
[M,250,61,7908,250,83,7930],
[M,250,61,7908,250,81,7928],
[M,250,61,7908,250,72,7919],
[M,250,12,7859,250,84,7931],
[M,245,35,7479,250,86,7933],
[M,245,25,7469,250,87,7934],
[M,312,38,10604,312,77,10643],
[M,232,36,7132,232,56,7152],
[M,232,36,7132,232,54,7150],
[M,232,36,7132,232,45,7141],
[M,236,38,7232,236,77,7271],
[M,208,38,6553,208,77,6592],
[M,179,33,5784,179,51,5802],
[M,179,33,5784,179,49,5800],
[M,179,33,5784,179,40,5791],
[M,180,48,5851,180,66,5869],
[M,180,48,5851,180,64,5867],
[M,180,48,5851,180,55,5858],
[M,180,12,5815,180,20,5823],
[M,180,68,5871,180,87,5890],
[M,180,68,5871,180,85,5888],
[M,180,68,5871,180,76,5879],
[M,180,12,5815,180,88,5891],
[M,185,38,5981,185,77,6020],
[M,158,37,5154,158,54,5171],
[M,158,37,5154,158,52,5169],
[M,158,37,5154,158,43,5160],
[M,158,37,5154,158,67,5184],
[M,158,17,5134,158,67,5184],
[M,158,8,5125,162,32,5373],
[M,159,40,5225,159,57,5242],
[M,159,40,5225,159,55,5240],
[M,159,40,5225,159,46,5231],
[M,159,12,5197,159,19,5204],
[M,159,28,5213,159,58,5243],
[M,159,12,5197,159,58,5243],
[M,161,40,5322,161,57,5339],
[M,161,40,5322,161,55,5337],
[M,161,40,5322,161,46,5328],
[M,161,12,5294,161,19,5301],
[M,161,28,5310,161,58,5340],
[M,161,12,5294,161,58,5340],
[M,145,25,4516,145,58,4549],
[M,145,25,4516,145,56,4547],
[M,145,25,4516,145,47,4538],
[M,145,25,4516,145,41,4532],
[M,145,16,4507,145,24,4515],
[M,145,61,4552,145,76,4567],
[M,145,61,4552,145,67,4558],
[M,145,25,4516,147,86,4718],
[M,145,79,4570,145,96,4587],
[M,145,79,4570,145,94,4585],
[M,145,79,4570,145,85,4576],
[M,147,43,4675,147,82,4714],
[M,147,57,4689,147,81,4713],
[M,147,65,4697,147,75,4707],
[M,147,43,4675,147,56,4688],
[M,147,43,4675,147,52,4684],
[M,147,28,4660,147,41,4673],
[M,147,16,4648,147,27,4659],
[M,146,28,4616,146,35,4623],
[M,146,18,4606,146,27,4615],
[M,147,16,4648,147,83,4715],
[M,146,28,4616,147,84,4716],
[M,146,18,4606,147,85,4717],
[M,145,16,4507,147,86,4718],
[M,144,12,4474,147,87,4719],
[M,143,17,4446,147,87,4719],
[M,143,8,4437,147,88,4720],
[M,143,8,4437,152,95,4983],
[M,149,33,4776,149,51,4794],
[M,149,33,4776,149,39,4782],
[M,149,17,4760,149,24,4767],
[M,149,8,4751,149,16,4759],
[M,149,33,4776,152,93,4981],
[M,150,16,4823,150,38,4845],
[M,150,16,4823,150,36,4843],
[M,150,16,4823,150,27,4834],
[M,152,43,4931,152,89,4977],
[M,152,64,4952,152,88,4976],
[M,152,72,4960,152,82,4970],
[M,152,43,4931,152,63,4951],
[M,152,43,4931,152,59,4947],
[M,152,28,4916,152,41,4929],
[M,152,16,4904,152,27,4915],
[M,151,26,4872,151,33,4879],
[M,151,16,4862,151,25,4871],
[M,152,16,4904,152,90,4978],
[M,151,26,4872,152,91,4979],
[M,151,16,4862,152,92,4980],
[M,149,17,4760,152,93,4981],
[M,149,8,4751,152,94,4982],
[M,137,39,4178,137,78,4217],
[M,137,53,4192,137,77,4216],
[M,137,61,4200,137,71,4210],
[M,137,39,4178,137,52,4191],
[M,137,39,4178,137,48,4187],
[M,137,24,4163,137,37,4176],
[M,137,12,4151,137,23,4162],
[M,136,22,4123,136,29,4130],
[M,136,12,4113,136,21,4122],
[M,137,12,4151,137,79,4218],
[M,136,22,4123,137,80,4219],
[M,136,12,4113,137,81,4220],
[M,135,15,4083,137,82,4221],
[M,130,6,3889,130,59,3942],
[M,130,27,3910,130,38,3921],
[M,130,41,3924,130,59,3942],
[M,130,41,3924,130,57,3940],
[M,130,41,3924,130,48,3931],
[M,123,12,3637,123,82,3707],
[M,123,64,3689,123,81,3706],
[M,123,64,3689,123,79,3704],
[M,123,64,3689,123,70,3695],
[M,122,17,3609,123,82,3707],
[M,122,8,3600,123,83,3708],
[M,121,8,3582,123,96,3721],
[M,124,8,3730,124,28,3750],
[M,124,8,3730,124,26,3748],
[M,124,8,3730,124,17,3739],
[M,113,12,3278,113,82,3348],
[M,113,64,3330,113,81,3347],
[M,113,64,3330,113,79,3345],
[M,113,64,3330,113,70,3336],
[M,112,17,3250,113,82,3348],
[M,112,8,3241,113,83,3349],
[M,111,8,3223,113,96,3362],
[M,114,8,3371,114,28,3391],
[M,114,8,3371,114,26,3389],
[M,114,8,3371,114,17,3380],
[M,102,17,2940,103,33,2989],
[M,102,8,2931,103,34,2990],
[M,101,8,2908,103,47,3003],
[M,104,8,3012,104,28,3032],
[M,104,8,3012,104,26,3030],
[M,104,8,3012,104,17,3021],
[M,171,38,5577,171,77,5616],
[M,88,15,2506,88,107,2598],
[M,88,85,2576,88,106,2597],
[M,88,85,2576,88,104,2595],
[M,88,85,2576,88,95,2586],
[M,84,78,2339,84,97,2358],
[M,84,78,2339,84,95,2356],
[M,84,78,2339,84,86,2347],
[M,92,38,2678,92,77,2717],
[M,73,70,1951,73,90,1971],
[M,73,70,1951,73,88,1969],
[M,73,70,1951,73,79,1960],
[M,73,107,1988,73,128,2009],
[M,73,107,1988,73,126,2007],
[M,73,107,1988,73,117,1998],
[M,73,92,1973,73,105,1986],
[M,68,70,1695,68,90,1715],
[M,68,70,1695,68,88,1713],
[M,68,70,1695,68,79,1704],
[M,77,38,2091,77,77,2130],
[M,46,8,999,48,32,1120],
[M,47,12,1076,47,23,1087],
[M,48,12,1100,48,32,1120],
[M,48,12,1100,48,30,1118],
[M,48,12,1100,48,21,1109],
[M,53,38,1210,53,77,1249],
[M,3,0,13,791,3,27992],
[M,9,11,107,9,20,116],
[M,13,0,130,13,24,154],
[M,13,12,142,13,21,151]];
var _plus26 = NAMESPACE.get("_plus");
var _times27 = NAMESPACE.get("_times");
var builtins28 = NAMESPACE.get("builtins");
var nothing29 = NAMESPACE.get("nothing");
var raise30 = NAMESPACE.get("raise");
var torepr31 = NAMESPACE.get("torepr");
var tostring32 = NAMESPACE.get("tostring");
var $type$Boolean33 = NAMESPACE.get("$type$Boolean");
var $type$Number34 = NAMESPACE.get("$type$Number");
var $type$String35 = NAMESPACE.get("$type$String");
var $Hbreak_DASH_one398461 = function(break_DASH_one9262,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,fold5391,link2992,list2593,sets1543,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun2104 = G(PP337,"str",L[1]);
var $z9697 = D;
var $f102103 = function(_) {
return R.isFunction(anf_fun2104)?anf_fun2104.app((" method")):R.ffi.throwNonFunApp(L[0],anf_fun2104,[(" method")]);
};
try {
if(--R.GAS > 0) {
$z9697 = $f102103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f102103,
"from":L[0]});
}
} catch($e9495) {
if(R.isCont($e9495)) {
var $ss9899 = {"from":L[0],
"go":function(str_DASH_method93105) {
return $Hstr_DASH_method3983106(str_DASH_method93105,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e9495.stack[R.EXN_STACKHEIGHT++] = $ss9899;
}
if(R.isPyretException($e9495)) {
$e9495.pyretStack.push(L[0]);
}
throw $e9495;
}
var $ret100101 = $Hstr_DASH_method3983106($z9697,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret100101;
};
var $Hstr_DASH_method3983106 = function(str_DASH_method93105,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun3117 = G(PP337,"str",L[3]);
var $z109110 = D;
var $f115116 = function(_) {
return R.isFunction(anf_fun3117)?anf_fun3117.app(("letrec ")):R.ffi.throwNonFunApp(L[2],anf_fun3117,[("letrec ")]);
};
try {
if(--R.GAS > 0) {
$z109110 = $f115116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f115116,
"from":L[2]});
}
} catch($e107108) {
if(R.isCont($e107108)) {
var $ss111112 = {"from":L[2],
"go":function(str_DASH_letrec94118) {
return $Hstr_DASH_letrec3982119(str_DASH_letrec94118,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_method93105,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e107108.stack[R.EXN_STACKHEIGHT++] = $ss111112;
}
if(R.isPyretException($e107108)) {
$e107108.pyretStack.push(L[2]);
}
throw $e107108;
}
var $ret113114 = $Hstr_DASH_letrec3982119($z109110,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_method93105,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret113114;
};
var $Hstr_DASH_letrec3982119 = function(str_DASH_letrec94118,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_method93105,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun4130 = G(PP337,"str",L[5]);
var $z122123 = D;
var $f128129 = function(_) {
return R.isFunction(anf_fun4130)?anf_fun4130.app((".")):R.ffi.throwNonFunApp(L[4],anf_fun4130,[(".")]);
};
try {
if(--R.GAS > 0) {
$z122123 = $f128129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f128129,
"from":L[4]});
}
} catch($e120121) {
if(R.isCont($e120121)) {
var $ss124125 = {"from":L[4],
"go":function(str_DASH_period95131) {
return $Hstr_DASH_period3981132(str_DASH_period95131,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_letrec94118,str_DASH_method93105,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e120121.stack[R.EXN_STACKHEIGHT++] = $ss124125;
}
if(R.isPyretException($e120121)) {
$e120121.pyretStack.push(L[4]);
}
throw $e120121;
}
var $ret126127 = $Hstr_DASH_period3981132($z122123,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_letrec94118,str_DASH_method93105,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret126127;
};
var $Hstr_DASH_period3981132 = function(str_DASH_period95131,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_letrec94118,str_DASH_method93105,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun5143 = G(PP337,"str",L[7]);
var $z135136 = D;
var $f141142 = function(_) {
return R.isFunction(anf_fun5143)?anf_fun5143.app(("!")):R.ffi.throwNonFunApp(L[6],anf_fun5143,[("!")]);
};
try {
if(--R.GAS > 0) {
$z135136 = $f141142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f141142,
"from":L[6]});
}
} catch($e133134) {
if(R.isCont($e133134)) {
var $ss137138 = {"from":L[6],
"go":function(str_DASH_bang96144) {
return $Hstr_DASH_bang3980145(str_DASH_bang96144,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e133134.stack[R.EXN_STACKHEIGHT++] = $ss137138;
}
if(R.isPyretException($e133134)) {
$e133134.pyretStack.push(L[6]);
}
throw $e133134;
}
var $ret139140 = $Hstr_DASH_bang3980145($z135136,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret139140;
};
var $Hstr_DASH_bang3980145 = function(str_DASH_bang96144,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun6156 = G(PP337,"str",L[9]);
var $z148149 = D;
var $f154155 = function(_) {
return R.isFunction(anf_fun6156)?anf_fun6156.app(("[]")):R.ffi.throwNonFunApp(L[8],anf_fun6156,[("[]")]);
};
try {
if(--R.GAS > 0) {
$z148149 = $f154155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f154155,
"from":L[8]});
}
} catch($e146147) {
if(R.isCont($e146147)) {
var $ss150151 = {"from":L[8],
"go":function(str_DASH_brackets97157) {
return $Hstr_DASH_brackets3979158(str_DASH_brackets97157,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e146147.stack[R.EXN_STACKHEIGHT++] = $ss150151;
}
if(R.isPyretException($e146147)) {
$e146147.pyretStack.push(L[8]);
}
throw $e146147;
}
var $ret152153 = $Hstr_DASH_brackets3979158($z148149,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret152153;
};
var $Hstr_DASH_brackets3979158 = function(str_DASH_brackets97157,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun7169 = G(PP337,"str",L[11]);
var $z161162 = D;
var $f167168 = function(_) {
return R.isFunction(anf_fun7169)?anf_fun7169.app((":")):R.ffi.throwNonFunApp(L[10],anf_fun7169,[(":")]);
};
try {
if(--R.GAS > 0) {
$z161162 = $f167168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f167168,
"from":L[10]});
}
} catch($e159160) {
if(R.isCont($e159160)) {
var $ss163164 = {"from":L[10],
"go":function(str_DASH_colon98170) {
return $Hstr_DASH_colon3978171(str_DASH_colon98170,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e159160.stack[R.EXN_STACKHEIGHT++] = $ss163164;
}
if(R.isPyretException($e159160)) {
$e159160.pyretStack.push(L[10]);
}
throw $e159160;
}
var $ret165166 = $Hstr_DASH_colon3978171($z161162,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret165166;
};
var $Hstr_DASH_colon3978171 = function(str_DASH_colon98170,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun8182 = G(PP337,"str",L[13]);
var $z174175 = D;
var $f180181 = function(_) {
return R.isFunction(anf_fun8182)?anf_fun8182.app(("::")):R.ffi.throwNonFunApp(L[12],anf_fun8182,[("::")]);
};
try {
if(--R.GAS > 0) {
$z174175 = $f180181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f180181,
"from":L[12]});
}
} catch($e172173) {
if(R.isCont($e172173)) {
var $ss176177 = {"from":L[12],
"go":function(str_DASH_coloncolon99183) {
return $Hstr_DASH_coloncolon3977184(str_DASH_coloncolon99183,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e172173.stack[R.EXN_STACKHEIGHT++] = $ss176177;
}
if(R.isPyretException($e172173)) {
$e172173.pyretStack.push(L[12]);
}
throw $e172173;
}
var $ret178179 = $Hstr_DASH_coloncolon3977184($z174175,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret178179;
};
var $Hstr_DASH_coloncolon3977184 = function(str_DASH_coloncolon99183,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun9195 = G(PP337,"str",L[15]);
var $z187188 = D;
var $f193194 = function(_) {
return R.isFunction(anf_fun9195)?anf_fun9195.app((":")):R.ffi.throwNonFunApp(L[14],anf_fun9195,[(":")]);
};
try {
if(--R.GAS > 0) {
$z187188 = $f193194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f193194,
"from":L[14]});
}
} catch($e185186) {
if(R.isCont($e185186)) {
var $ss189190 = {"from":L[14],
"go":function(str_DASH_colonspace100196) {
return $Hstr_DASH_colonspace3976197(str_DASH_colonspace100196,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e185186.stack[R.EXN_STACKHEIGHT++] = $ss189190;
}
if(R.isPyretException($e185186)) {
$e185186.pyretStack.push(L[14]);
}
throw $e185186;
}
var $ret191192 = $Hstr_DASH_colonspace3976197($z187188,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret191192;
};
var $Hstr_DASH_colonspace3976197 = function(str_DASH_colonspace100196,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun10208 = G(PP337,"str",L[17]);
var $z200201 = D;
var $f206207 = function(_) {
return R.isFunction(anf_fun10208)?anf_fun10208.app(("end")):R.ffi.throwNonFunApp(L[16],anf_fun10208,[("end")]);
};
try {
if(--R.GAS > 0) {
$z200201 = $f206207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f206207,
"from":L[16]});
}
} catch($e198199) {
if(R.isCont($e198199)) {
var $ss202203 = {"from":L[16],
"go":function(str_DASH_end101209) {
return $Hstr_DASH_end3975210(str_DASH_end101209,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e198199.stack[R.EXN_STACKHEIGHT++] = $ss202203;
}
if(R.isPyretException($e198199)) {
$e198199.pyretStack.push(L[16]);
}
throw $e198199;
}
var $ret204205 = $Hstr_DASH_end3975210($z200201,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret204205;
};
var $Hstr_DASH_end3975210 = function(str_DASH_end101209,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun11221 = G(PP337,"str",L[19]);
var $z213214 = D;
var $f219220 = function(_) {
return R.isFunction(anf_fun11221)?anf_fun11221.app(("type-let ")):R.ffi.throwNonFunApp(L[18],anf_fun11221,[("type-let ")]);
};
try {
if(--R.GAS > 0) {
$z213214 = $f219220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f219220,
"from":L[18]});
}
} catch($e211212) {
if(R.isCont($e211212)) {
var $ss215216 = {"from":L[18],
"go":function(str_DASH_type_DASH_let102222) {
return $Hstr_DASH_type_DASH_let3974223(str_DASH_type_DASH_let102222,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e211212.stack[R.EXN_STACKHEIGHT++] = $ss215216;
}
if(R.isPyretException($e211212)) {
$e211212.pyretStack.push(L[18]);
}
throw $e211212;
}
var $ret217218 = $Hstr_DASH_type_DASH_let3974223($z213214,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret217218;
};
var $Hstr_DASH_type_DASH_let3974223 = function(str_DASH_type_DASH_let102222,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun12234 = G(PP337,"str",L[21]);
var $z226227 = D;
var $f232233 = function(_) {
return R.isFunction(anf_fun12234)?anf_fun12234.app(("let ")):R.ffi.throwNonFunApp(L[20],anf_fun12234,[("let ")]);
};
try {
if(--R.GAS > 0) {
$z226227 = $f232233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f232233,
"from":L[20]});
}
} catch($e224225) {
if(R.isCont($e224225)) {
var $ss228229 = {"from":L[20],
"go":function(str_DASH_let103235) {
return $Hstr_DASH_let3973236(str_DASH_let103235,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e224225.stack[R.EXN_STACKHEIGHT++] = $ss228229;
}
if(R.isPyretException($e224225)) {
$e224225.pyretStack.push(L[20]);
}
throw $e224225;
}
var $ret230231 = $Hstr_DASH_let3973236($z226227,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret230231;
};
var $Hstr_DASH_let3973236 = function(str_DASH_let103235,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun13247 = G(PP337,"str",L[23]);
var $z239240 = D;
var $f245246 = function(_) {
return R.isFunction(anf_fun13247)?anf_fun13247.app(("var ")):R.ffi.throwNonFunApp(L[22],anf_fun13247,[("var ")]);
};
try {
if(--R.GAS > 0) {
$z239240 = $f245246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f245246,
"from":L[22]});
}
} catch($e237238) {
if(R.isCont($e237238)) {
var $ss241242 = {"from":L[22],
"go":function(str_DASH_var104248) {
return $Hstr_DASH_var3972249(str_DASH_var104248,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e237238.stack[R.EXN_STACKHEIGHT++] = $ss241242;
}
if(R.isPyretException($e237238)) {
$e237238.pyretStack.push(L[22]);
}
throw $e237238;
}
var $ret243244 = $Hstr_DASH_var3972249($z239240,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret243244;
};
var $Hstr_DASH_var3972249 = function(str_DASH_var104248,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun14260 = G(PP337,"str",L[25]);
var $z252253 = D;
var $f258259 = function(_) {
return R.isFunction(anf_fun14260)?anf_fun14260.app(("if ")):R.ffi.throwNonFunApp(L[24],anf_fun14260,[("if ")]);
};
try {
if(--R.GAS > 0) {
$z252253 = $f258259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f258259,
"from":L[24]});
}
} catch($e250251) {
if(R.isCont($e250251)) {
var $ss254255 = {"from":L[24],
"go":function(str_DASH_if105261) {
return $Hstr_DASH_if3971262(str_DASH_if105261,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e250251.stack[R.EXN_STACKHEIGHT++] = $ss254255;
}
if(R.isPyretException($e250251)) {
$e250251.pyretStack.push(L[24]);
}
throw $e250251;
}
var $ret256257 = $Hstr_DASH_if3971262($z252253,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret256257;
};
var $Hstr_DASH_if3971262 = function(str_DASH_if105261,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun15273 = G(PP337,"str",L[27]);
var $z265266 = D;
var $f271272 = function(_) {
return R.isFunction(anf_fun15273)?anf_fun15273.app(("else:")):R.ffi.throwNonFunApp(L[26],anf_fun15273,[("else:")]);
};
try {
if(--R.GAS > 0) {
$z265266 = $f271272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f271272,
"from":L[26]});
}
} catch($e263264) {
if(R.isCont($e263264)) {
var $ss267268 = {"from":L[26],
"go":function(str_DASH_elsecolon106274) {
return $Hstr_DASH_elsecolon3970275(str_DASH_elsecolon106274,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e263264.stack[R.EXN_STACKHEIGHT++] = $ss267268;
}
if(R.isPyretException($e263264)) {
$e263264.pyretStack.push(L[26]);
}
throw $e263264;
}
var $ret269270 = $Hstr_DASH_elsecolon3970275($z265266,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret269270;
};
var $Hstr_DASH_elsecolon3970275 = function(str_DASH_elsecolon106274,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun16286 = G(PP337,"str",L[29]);
var $z278279 = D;
var $f284285 = function(_) {
return R.isFunction(anf_fun16286)?anf_fun16286.app(("try:")):R.ffi.throwNonFunApp(L[28],anf_fun16286,[("try:")]);
};
try {
if(--R.GAS > 0) {
$z278279 = $f284285();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f284285,
"from":L[28]});
}
} catch($e276277) {
if(R.isCont($e276277)) {
var $ss280281 = {"from":L[28],
"go":function(str_DASH_try107287) {
return $Hstr_DASH_try3969288(str_DASH_try107287,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e276277.stack[R.EXN_STACKHEIGHT++] = $ss280281;
}
if(R.isPyretException($e276277)) {
$e276277.pyretStack.push(L[28]);
}
throw $e276277;
}
var $ret282283 = $Hstr_DASH_try3969288($z278279,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret282283;
};
var $Hstr_DASH_try3969288 = function(str_DASH_try107287,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun17299 = G(PP337,"str",L[31]);
var $z291292 = D;
var $f297298 = function(_) {
return R.isFunction(anf_fun17299)?anf_fun17299.app(("except")):R.ffi.throwNonFunApp(L[30],anf_fun17299,[("except")]);
};
try {
if(--R.GAS > 0) {
$z291292 = $f297298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f297298,
"from":L[30]});
}
} catch($e289290) {
if(R.isCont($e289290)) {
var $ss293294 = {"from":L[30],
"go":function(str_DASH_except108300) {
return $Hstr_DASH_except3968301(str_DASH_except108300,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e289290.stack[R.EXN_STACKHEIGHT++] = $ss293294;
}
if(R.isPyretException($e289290)) {
$e289290.pyretStack.push(L[30]);
}
throw $e289290;
}
var $ret295296 = $Hstr_DASH_except3968301($z291292,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret295296;
};
var $Hstr_DASH_except3968301 = function(str_DASH_except108300,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun18312 = G(PP337,"str",L[33]);
var $z304305 = D;
var $f310311 = function(_) {
return R.isFunction(anf_fun18312)?anf_fun18312.app((" :=")):R.ffi.throwNonFunApp(L[32],anf_fun18312,[(" :=")]);
};
try {
if(--R.GAS > 0) {
$z304305 = $f310311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f310311,
"from":L[32]});
}
} catch($e302303) {
if(R.isCont($e302303)) {
var $ss306307 = {"from":L[32],
"go":function(str_DASH_spacecolonequal109313) {
return $Hstr_DASH_spacecolonequal3967314(str_DASH_spacecolonequal109313,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e302303.stack[R.EXN_STACKHEIGHT++] = $ss306307;
}
if(R.isPyretException($e302303)) {
$e302303.pyretStack.push(L[32]);
}
throw $e302303;
}
var $ret308309 = $Hstr_DASH_spacecolonequal3967314($z304305,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret308309;
};
var $Hstr_DASH_spacecolonequal3967314 = function(str_DASH_spacecolonequal109313,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun19325 = G(PP337,"str",L[35]);
var $z317318 = D;
var $f323324 = function(_) {
return R.isFunction(anf_fun19325)?anf_fun19325.app((" =")):R.ffi.throwNonFunApp(L[34],anf_fun19325,[(" =")]);
};
try {
if(--R.GAS > 0) {
$z317318 = $f323324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f323324,
"from":L[34]});
}
} catch($e315316) {
if(R.isCont($e315316)) {
var $ss319320 = {"from":L[34],
"go":function(str_DASH_spaceequal110326) {
return $Hstr_DASH_spaceequal3966327(str_DASH_spaceequal110326,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e315316.stack[R.EXN_STACKHEIGHT++] = $ss319320;
}
if(R.isPyretException($e315316)) {
$e315316.pyretStack.push(L[34]);
}
throw $e315316;
}
var $ret321322 = $Hstr_DASH_spaceequal3966327($z317318,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret321322;
};
var $Hstr_DASH_spaceequal3966327 = function(str_DASH_spaceequal110326,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun20338 = G(PP337,"str",L[37]);
var $z330331 = D;
var $f336337 = function(_) {
return R.isFunction(anf_fun20338)?anf_fun20338.app(("import")):R.ffi.throwNonFunApp(L[36],anf_fun20338,[("import")]);
};
try {
if(--R.GAS > 0) {
$z330331 = $f336337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f336337,
"from":L[36]});
}
} catch($e328329) {
if(R.isCont($e328329)) {
var $ss332333 = {"from":L[36],
"go":function(str_DASH_import111339) {
return $Hstr_DASH_import3965340(str_DASH_import111339,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e328329.stack[R.EXN_STACKHEIGHT++] = $ss332333;
}
if(R.isPyretException($e328329)) {
$e328329.pyretStack.push(L[36]);
}
throw $e328329;
}
var $ret334335 = $Hstr_DASH_import3965340($z330331,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret334335;
};
var $Hstr_DASH_import3965340 = function(str_DASH_import111339,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun21351 = G(PP337,"str",L[39]);
var $z343344 = D;
var $f349350 = function(_) {
return R.isFunction(anf_fun21351)?anf_fun21351.app(("provide")):R.ffi.throwNonFunApp(L[38],anf_fun21351,[("provide")]);
};
try {
if(--R.GAS > 0) {
$z343344 = $f349350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f349350,
"from":L[38]});
}
} catch($e341342) {
if(R.isCont($e341342)) {
var $ss345346 = {"from":L[38],
"go":function(str_DASH_provide112352) {
return $Hstr_DASH_provide3964353(str_DASH_provide112352,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e341342.stack[R.EXN_STACKHEIGHT++] = $ss345346;
}
if(R.isPyretException($e341342)) {
$e341342.pyretStack.push(L[38]);
}
throw $e341342;
}
var $ret347348 = $Hstr_DASH_provide3964353($z343344,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret347348;
};
var $Hstr_DASH_provide3964353 = function(str_DASH_provide112352,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun22364 = G(PP337,"str",L[41]);
var $z356357 = D;
var $f362363 = function(_) {
return R.isFunction(anf_fun22364)?anf_fun22364.app(("as")):R.ffi.throwNonFunApp(L[40],anf_fun22364,[("as")]);
};
try {
if(--R.GAS > 0) {
$z356357 = $f362363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f362363,
"from":L[40]});
}
} catch($e354355) {
if(R.isCont($e354355)) {
var $ss358359 = {"from":L[40],
"go":function(str_DASH_as113365) {
return $Hstr_DASH_as3963366(str_DASH_as113365,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e354355.stack[R.EXN_STACKHEIGHT++] = $ss358359;
}
if(R.isPyretException($e354355)) {
$e354355.pyretStack.push(L[40]);
}
throw $e354355;
}
var $ret360361 = $Hstr_DASH_as3963366($z356357,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret360361;
};
var $Hstr_DASH_as3963366 = function(str_DASH_as113365,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun23377 = G(PP337,"str",L[43]);
var $z369370 = D;
var $f375376 = function(_) {
return R.isFunction(anf_fun23377)?anf_fun23377.app(("newtype ")):R.ffi.throwNonFunApp(L[42],anf_fun23377,[("newtype ")]);
};
try {
if(--R.GAS > 0) {
$z369370 = $f375376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f375376,
"from":L[42]});
}
} catch($e367368) {
if(R.isCont($e367368)) {
var $ss371372 = {"from":L[42],
"go":function(str_DASH_newtype114378) {
return $Hstr_DASH_newtype3962379(str_DASH_newtype114378,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e367368.stack[R.EXN_STACKHEIGHT++] = $ss371372;
}
if(R.isPyretException($e367368)) {
$e367368.pyretStack.push(L[42]);
}
throw $e367368;
}
var $ret373374 = $Hstr_DASH_newtype3962379($z369370,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret373374;
};
var $Hstr_DASH_newtype3962379 = function(str_DASH_newtype114378,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var anf_fun24390 = G(SL538,"builtin",L[45]);
var $z382383 = D;
var $f388389 = function(_) {
return R.isFunction(anf_fun24390)?anf_fun24390.app(("dummy-location")):R.ffi.throwNonFunApp(L[44],anf_fun24390,[("dummy-location")]);
};
try {
if(--R.GAS > 0) {
$z382383 = $f388389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f388389,
"from":L[44]});
}
} catch($e380381) {
if(R.isCont($e380381)) {
var $ss384385 = {"from":L[44],
"go":function(dummy_DASH_loc115391) {
return $Hdummy_DASH_loc3961392(dummy_DASH_loc115391,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e380381.stack[R.EXN_STACKHEIGHT++] = $ss384385;
}
if(R.isPyretException($e380381)) {
$e380381.pyretStack.push(L[44]);
}
throw $e380381;
}
var $ret386387 = $Hdummy_DASH_loc3961392($z382383,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret386387;
};
var $Hdummy_DASH_loc3961392 = function(dummy_DASH_loc115391,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,break_DASH_one9262,fold5391,link2992,list2593,sets1543,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35) {
var Loc116699 = G(SL538,"Srcloc",L[1179]);
var AProg14117393 = {"$var":D,
"$name":"AProg14"};
var AProg118395 = {"$var":D,
"$name":"AProg"};
var is_DASH_AProg119397 = {"$var":D,
"$name":"is-AProg"};
var is_DASH_a_DASH_program120399 = {"$var":D,
"$name":"is-a-program"};
var a_DASH_program121401 = {"$var":D,
"$name":"a-program"};
var AImportType15122403 = {"$var":D,
"$name":"AImportType15"};
var AImportType123405 = {"$var":D,
"$name":"AImportType"};
var is_DASH_AImportType124407 = {"$var":D,
"$name":"is-AImportType"};
var is_DASH_a_DASH_import_DASH_builtin125409 = {"$var":D,
"$name":"is-a-import-builtin"};
var a_DASH_import_DASH_builtin126411 = {"$var":D,
"$name":"a-import-builtin"};
var is_DASH_a_DASH_import_DASH_file127413 = {"$var":D,
"$name":"is-a-import-file"};
var a_DASH_import_DASH_file128415 = {"$var":D,
"$name":"a-import-file"};
var AImport16129417 = {"$var":D,
"$name":"AImport16"};
var AImport130419 = {"$var":D,
"$name":"AImport"};
var is_DASH_AImport131421 = {"$var":D,
"$name":"is-AImport"};
var is_DASH_a_DASH_import132423 = {"$var":D,
"$name":"is-a-import"};
var a_DASH_import133425 = {"$var":D,
"$name":"a-import"};
var is_DASH_a_DASH_import_DASH_types134427 = {"$var":D,
"$name":"is-a-import-types"};
var a_DASH_import_DASH_types135429 = {"$var":D,
"$name":"a-import-types"};
var ATypeBind17136431 = {"$var":D,
"$name":"ATypeBind17"};
var ATypeBind137433 = {"$var":D,
"$name":"ATypeBind"};
var is_DASH_ATypeBind138435 = {"$var":D,
"$name":"is-ATypeBind"};
var is_DASH_a_DASH_type_DASH_bind139437 = {"$var":D,
"$name":"is-a-type-bind"};
var a_DASH_type_DASH_bind140439 = {"$var":D,
"$name":"a-type-bind"};
var is_DASH_a_DASH_newtype_DASH_bind141441 = {"$var":D,
"$name":"is-a-newtype-bind"};
var a_DASH_newtype_DASH_bind142443 = {"$var":D,
"$name":"a-newtype-bind"};
var AExpr18143445 = {"$var":D,
"$name":"AExpr18"};
var AExpr144447 = {"$var":D,
"$name":"AExpr"};
var is_DASH_AExpr145449 = {"$var":D,
"$name":"is-AExpr"};
var is_DASH_a_DASH_type_DASH_let146451 = {"$var":D,
"$name":"is-a-type-let"};
var a_DASH_type_DASH_let147453 = {"$var":D,
"$name":"a-type-let"};
var is_DASH_a_DASH_let148455 = {"$var":D,
"$name":"is-a-let"};
var a_DASH_let149457 = {"$var":D,
"$name":"a-let"};
var is_DASH_a_DASH_var150459 = {"$var":D,
"$name":"is-a-var"};
var a_DASH_var151461 = {"$var":D,
"$name":"a-var"};
var is_DASH_a_DASH_seq152463 = {"$var":D,
"$name":"is-a-seq"};
var a_DASH_seq153465 = {"$var":D,
"$name":"a-seq"};
var is_DASH_a_DASH_tail_DASH_app154467 = {"$var":D,
"$name":"is-a-tail-app"};
var a_DASH_tail_DASH_app155469 = {"$var":D,
"$name":"a-tail-app"};
var is_DASH_a_DASH_split_DASH_app156471 = {"$var":D,
"$name":"is-a-split-app"};
var a_DASH_split_DASH_app157473 = {"$var":D,
"$name":"a-split-app"};
var is_DASH_a_DASH_if158475 = {"$var":D,
"$name":"is-a-if"};
var a_DASH_if159477 = {"$var":D,
"$name":"a-if"};
var is_DASH_a_DASH_lettable160479 = {"$var":D,
"$name":"is-a-lettable"};
var a_DASH_lettable161481 = {"$var":D,
"$name":"a-lettable"};
var ABind19162483 = {"$var":D,
"$name":"ABind19"};
var ABind163485 = {"$var":D,
"$name":"ABind"};
var is_DASH_ABind164487 = {"$var":D,
"$name":"is-ABind"};
var is_DASH_a_DASH_bind165489 = {"$var":D,
"$name":"is-a-bind"};
var a_DASH_bind166491 = {"$var":D,
"$name":"a-bind"};
var AVariant20167493 = {"$var":D,
"$name":"AVariant20"};
var AVariant168495 = {"$var":D,
"$name":"AVariant"};
var is_DASH_AVariant169497 = {"$var":D,
"$name":"is-AVariant"};
var is_DASH_a_DASH_variant170499 = {"$var":D,
"$name":"is-a-variant"};
var a_DASH_variant171501 = {"$var":D,
"$name":"a-variant"};
var is_DASH_a_DASH_singleton_DASH_variant172503 = {"$var":D,
"$name":"is-a-singleton-variant"};
var a_DASH_singleton_DASH_variant173505 = {"$var":D,
"$name":"a-singleton-variant"};
var AMemberType21174507 = {"$var":D,
"$name":"AMemberType21"};
var AMemberType175509 = {"$var":D,
"$name":"AMemberType"};
var is_DASH_AMemberType176511 = {"$var":D,
"$name":"is-AMemberType"};
var is_DASH_a_DASH_normal177513 = {"$var":D,
"$name":"is-a-normal"};
var a_DASH_normal178515 = {"$var":D,
"$name":"a-normal"};
var is_DASH_a_DASH_cyclic179517 = {"$var":D,
"$name":"is-a-cyclic"};
var a_DASH_cyclic180519 = {"$var":D,
"$name":"a-cyclic"};
var is_DASH_a_DASH_mutable181521 = {"$var":D,
"$name":"is-a-mutable"};
var a_DASH_mutable182523 = {"$var":D,
"$name":"a-mutable"};
var AVariantMember22183525 = {"$var":D,
"$name":"AVariantMember22"};
var AVariantMember184527 = {"$var":D,
"$name":"AVariantMember"};
var is_DASH_AVariantMember185529 = {"$var":D,
"$name":"is-AVariantMember"};
var is_DASH_a_DASH_variant_DASH_member186531 = {"$var":D,
"$name":"is-a-variant-member"};
var a_DASH_variant_DASH_member187533 = {"$var":D,
"$name":"a-variant-member"};
var ALettable23188535 = {"$var":D,
"$name":"ALettable23"};
var ALettable189537 = {"$var":D,
"$name":"ALettable"};
var is_DASH_ALettable190539 = {"$var":D,
"$name":"is-ALettable"};
var is_DASH_a_DASH_module191541 = {"$var":D,
"$name":"is-a-module"};
var a_DASH_module192543 = {"$var":D,
"$name":"a-module"};
var is_DASH_a_DASH_data_DASH_expr193545 = {"$var":D,
"$name":"is-a-data-expr"};
var a_DASH_data_DASH_expr194547 = {"$var":D,
"$name":"a-data-expr"};
var is_DASH_a_DASH_assign195549 = {"$var":D,
"$name":"is-a-assign"};
var a_DASH_assign196551 = {"$var":D,
"$name":"a-assign"};
var is_DASH_a_DASH_app197553 = {"$var":D,
"$name":"is-a-app"};
var a_DASH_app198555 = {"$var":D,
"$name":"a-app"};
var is_DASH_a_DASH_prim_DASH_app199557 = {"$var":D,
"$name":"is-a-prim-app"};
var a_DASH_prim_DASH_app200559 = {"$var":D,
"$name":"a-prim-app"};
var is_DASH_a_DASH_obj201561 = {"$var":D,
"$name":"is-a-obj"};
var a_DASH_obj202563 = {"$var":D,
"$name":"a-obj"};
var is_DASH_a_DASH_update203565 = {"$var":D,
"$name":"is-a-update"};
var a_DASH_update204567 = {"$var":D,
"$name":"a-update"};
var is_DASH_a_DASH_extend205569 = {"$var":D,
"$name":"is-a-extend"};
var a_DASH_extend206571 = {"$var":D,
"$name":"a-extend"};
var is_DASH_a_DASH_dot207573 = {"$var":D,
"$name":"is-a-dot"};
var a_DASH_dot208575 = {"$var":D,
"$name":"a-dot"};
var is_DASH_a_DASH_colon209577 = {"$var":D,
"$name":"is-a-colon"};
var a_DASH_colon210579 = {"$var":D,
"$name":"a-colon"};
var is_DASH_a_DASH_get_DASH_bang211581 = {"$var":D,
"$name":"is-a-get-bang"};
var a_DASH_get_DASH_bang212583 = {"$var":D,
"$name":"a-get-bang"};
var is_DASH_a_DASH_lam213585 = {"$var":D,
"$name":"is-a-lam"};
var a_DASH_lam214587 = {"$var":D,
"$name":"a-lam"};
var is_DASH_a_DASH_method215589 = {"$var":D,
"$name":"is-a-method"};
var a_DASH_method216591 = {"$var":D,
"$name":"a-method"};
var is_DASH_a_DASH_val217593 = {"$var":D,
"$name":"is-a-val"};
var a_DASH_val218595 = {"$var":D,
"$name":"a-val"};
var fun_DASH_method_DASH_pretty219597 = {"$var":D,
"$name":"fun-method-pretty"};
var AField24220599 = {"$var":D,
"$name":"AField24"};
var AField221601 = {"$var":D,
"$name":"AField"};
var is_DASH_AField222603 = {"$var":D,
"$name":"is-AField"};
var is_DASH_a_DASH_field223605 = {"$var":D,
"$name":"is-a-field"};
var a_DASH_field224607 = {"$var":D,
"$name":"a-field"};
var AVal25225609 = {"$var":D,
"$name":"AVal25"};
var AVal226611 = {"$var":D,
"$name":"AVal"};
var is_DASH_AVal227613 = {"$var":D,
"$name":"is-AVal"};
var is_DASH_a_DASH_srcloc228615 = {"$var":D,
"$name":"is-a-srcloc"};
var a_DASH_srcloc229617 = {"$var":D,
"$name":"a-srcloc"};
var is_DASH_a_DASH_num230619 = {"$var":D,
"$name":"is-a-num"};
var a_DASH_num231621 = {"$var":D,
"$name":"a-num"};
var is_DASH_a_DASH_str232623 = {"$var":D,
"$name":"is-a-str"};
var a_DASH_str233625 = {"$var":D,
"$name":"a-str"};
var is_DASH_a_DASH_bool234627 = {"$var":D,
"$name":"is-a-bool"};
var a_DASH_bool235629 = {"$var":D,
"$name":"a-bool"};
var is_DASH_a_DASH_array236631 = {"$var":D,
"$name":"is-a-array"};
var a_DASH_array237633 = {"$var":D,
"$name":"a-array"};
var is_DASH_a_DASH_undefined238635 = {"$var":D,
"$name":"is-a-undefined"};
var a_DASH_undefined239637 = {"$var":D,
"$name":"a-undefined"};
var is_DASH_a_DASH_id240639 = {"$var":D,
"$name":"is-a-id"};
var a_DASH_id241641 = {"$var":D,
"$name":"a-id"};
var is_DASH_a_DASH_id_DASH_var242643 = {"$var":D,
"$name":"is-a-id-var"};
var a_DASH_id_DASH_var243645 = {"$var":D,
"$name":"a-id-var"};
var is_DASH_a_DASH_id_DASH_letrec244647 = {"$var":D,
"$name":"is-a-id-letrec"};
var a_DASH_id_DASH_letrec245649 = {"$var":D,
"$name":"a-id-letrec"};
var strip_DASH_loc_DASH_prog246651 = {"$var":D,
"$name":"strip-loc-prog"};
var strip_DASH_loc_DASH_import247653 = {"$var":D,
"$name":"strip-loc-import"};
var strip_DASH_loc_DASH_import_DASH_type248655 = {"$var":D,
"$name":"strip-loc-import-type"};
var strip_DASH_loc_DASH_expr249657 = {"$var":D,
"$name":"strip-loc-expr"};
var strip_DASH_loc_DASH_bind250659 = {"$var":D,
"$name":"strip-loc-bind"};
var strip_DASH_loc_DASH_lettable251661 = {"$var":D,
"$name":"strip-loc-lettable"};
var strip_DASH_loc_DASH_field252663 = {"$var":D,
"$name":"strip-loc-field"};
var strip_DASH_loc_DASH_val253665 = {"$var":D,
"$name":"strip-loc-val"};
var anf_shared327177 = R.makeMethod(function(self2603582) {
return function(visitor2617287) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1174],1,arguments);
}
var anf_fun267286 = G(self2603582,"_match",L[1178]);
var anf_arg317288 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1175],0,arguments);
}
var anf_fun287301 = G(self2603582,"label",L[1177]);
var $z72937294 = D;
var $f72997300 = function(_) {
return R.isFunction(anf_fun287301)?anf_fun287301.app():R.ffi.throwNonFunApp(L[1176],anf_fun287301,[]);
};
try {
if(--R.GAS > 0) {
$z72937294 = $f72997300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72997300,
"from":L[1176]});
}
} catch($e72917292) {
if(R.isCont($e72917292)) {
var $ss72957296 = {"from":L[1176],
"go":function(anf_arg297302) {
return $Hanf_arg28377303(anf_arg297302,_plus26,raise30);
}};
$e72917292.stack[R.EXN_STACKHEIGHT++] = $ss72957296;
}
if(R.isPyretException($e72917292)) {
$e72917292.pyretStack.push(L[1176]);
}
throw $e72917292;
}
var $ret72977298 = $Hanf_arg28377303($z72937294,_plus26,raise30);
++R.GAS;
return $ret72977298;
});
var $z72787279 = D;
var $f72847285 = function(_) {
return R.isFunction(anf_fun267286)?anf_fun267286.app(visitor2617287,anf_arg317288):R.ffi.throwNonFunApp(L[1174],anf_fun267286,[visitor2617287,anf_arg317288]);
};
try {
if(--R.GAS > 0) {
$z72787279 = $f72847285();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72847285,
"from":L[1174]});
}
} catch($e72767277) {
if(R.isCont($e72767277)) {
var $ss72807281 = {"from":L[1174],
"go":function(ann_DASH_check_DASH_temp257289) {
return $Hann_DASH_check_DASH_temp28387290(ann_DASH_check_DASH_temp257289);
}};
$e72767277.stack[R.EXN_STACKHEIGHT++] = $ss72807281;
}
if(R.isPyretException($e72767277)) {
$e72767277.pyretStack.push(L[1174]);
}
throw $e72767277;
}
var $ret72827283 = $Hann_DASH_check_DASH_temp28387290($z72787279);
++R.GAS;
return $ret72827283;
};
},{"length":2});
var anf_variant_member467183 = R.makeMethod(function(self27254) {
return function(cases_DASH_funs37255,else_DASH_clause47266) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1156],2,arguments);
}
var if_DASH_67269 = R.hasField(cases_DASH_funs37255,("a-program"));
var if_helper347252 = R.makeFunction(function(if_helper_arg357274) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1156],1,arguments);
}
var ann_DASH_check_DASH_temp337275 = if_helper_arg357274;
return ann_DASH_check_DASH_temp337275;
});
var anf_if387273 = R.isBoolean(if_DASH_67269);
if(R.isPyretTrue(anf_if387273)) {
if(R.isPyretTrue(if_DASH_67269)) {
var call_DASH_a_DASH_program17247 = G(cases_DASH_funs37255,"a-program",L[1156]);
var anf_arg417248 = G(self27254,"l",L[1173]);
var anf_arg427249 = G(self27254,"imports",L[1172]);
var anf_arg437250 = G(self27254,"body",L[1171]);
var $z72397240 = D;
var $f72457246 = function(_) {
return R.isFunction(call_DASH_a_DASH_program17247)?call_DASH_a_DASH_program17247.app(anf_arg417248,anf_arg427249,anf_arg437250):R.ffi.throwNonFunApp(L[1156],call_DASH_a_DASH_program17247,[anf_arg417248,anf_arg427249,anf_arg437250]);
};
try {
if(--R.GAS > 0) {
$z72397240 = $f72457246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72457246,
"from":L[1156]});
}
} catch($e72377238) {
if(R.isCont($e72377238)) {
var $ss72417242 = {"from":L[1156],
"go":function(cont_tail_arg447251) {
return $Hcont_tail_arg28397253(cont_tail_arg447251,if_helper347252);
}};
$e72377238.stack[R.EXN_STACKHEIGHT++] = $ss72417242;
}
if(R.isPyretException($e72377238)) {
$e72377238.pyretStack.push(L[1156]);
}
throw $e72377238;
}
var $ret72437244 = $Hcont_tail_arg28397253($z72397240,if_helper347252);
++R.GAS;
return $ret72437244;
} else {
var $z72587259 = D;
var $f72647265 = function(_) {
return R.isFunction(else_DASH_clause47266)?else_DASH_clause47266.app():R.ffi.throwNonFunApp(L[1156],else_DASH_clause47266,[]);
};
try {
if(--R.GAS > 0) {
$z72587259 = $f72647265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72647265,
"from":L[1156]});
}
} catch($e72567257) {
if(R.isCont($e72567257)) {
var $ss72607261 = {"from":L[1156],
"go":function(cont_tail_arg397267) {
return $Hcont_tail_arg28407268(cont_tail_arg397267,if_helper347252);
}};
$e72567257.stack[R.EXN_STACKHEIGHT++] = $ss72607261;
}
if(R.isPyretException($e72567257)) {
$e72567257.pyretStack.push(L[1156]);
}
throw $e72567257;
}
var $ret72627263 = $Hcont_tail_arg28407268($z72587259,if_helper347252);
++R.GAS;
return $ret72627263;
}
} else {
var cont_tail_arg367272 = R.throwNonBooleanCondition(L[1156],("if"),if_DASH_67269);
if(--R.GAS > 0) {
$z72707271 = R.isFunction(if_helper347252)?if_helper347252.app(cont_tail_arg367272):R.ffi.throwNonFunApp(L[1156],if_helper347252,[cont_tail_arg367272]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper347252)?if_helper347252.app(cont_tail_arg367272):R.ffi.throwNonFunApp(L[1156],if_helper347252,[cont_tail_arg367272]);
},
"from":L[1156]});
}
++R.GAS;
return $z72707271;
}
};
},{"length":3});
var anf_variant_member607184 = R.makeMethod(function(self57235) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1156],0,arguments);
}
var anf_arg487233 = G(self57235,"l",L[1156]);
var $z72257226 = D;
var $f72317232 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg487233):R.ffi.throwNonFunApp(L[1156],torepr31,[anf_arg487233]);
};
try {
if(--R.GAS > 0) {
$z72257226 = $f72317232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72317232,
"from":L[1156]});
}
} catch($e72237224) {
if(R.isCont($e72237224)) {
var $ss72277228 = {"from":L[1156],
"go":function(anf_arg497234) {
return $Hanf_arg28507236(anf_arg497234,self57235,_plus26,torepr31);
}};
$e72237224.stack[R.EXN_STACKHEIGHT++] = $ss72277228;
}
if(R.isPyretException($e72237224)) {
$e72237224.pyretStack.push(L[1156]);
}
throw $e72237224;
}
var $ret72297230 = $Hanf_arg28507236($z72257226,self57235,_plus26,torepr31);
++R.GAS;
return $ret72297230;
};
},{"length":1});
var anf_variant_member627185 = R.makeMethod(function(self2573598) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1170],0,arguments);
}
var ann_DASH_check_DASH_temp617222 = ("a-program");
return ann_DASH_check_DASH_temp617222;
};
},{"length":1});
var anf_variant_member787186 = R.makeMethod(function(self2587206) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1169],0,arguments);
}
var anf_fun647205 = G(PP337,"group",L[1168]);
var anf_fun657200 = G(PP337,"flow-map",L[1167]);
var anf_arg667201 = G(PP337,"hardline",L[1166]);
var anf_arg697202 = R.makeFunction(function(i2597208) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1164],1,arguments);
}
var anf_fun687219 = G(i2597208,"tosource",L[1165]);
var $z72117212 = D;
var $f72177218 = function(_) {
return R.isFunction(anf_fun687219)?anf_fun687219.app():R.ffi.throwNonFunApp(L[1164],anf_fun687219,[]);
};
try {
if(--R.GAS > 0) {
$z72117212 = $f72177218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72177218,
"from":L[1164]});
}
} catch($e72097210) {
if(R.isCont($e72097210)) {
var $ss72137214 = {"from":L[1164],
"go":function(ann_DASH_check_DASH_temp677220) {
return $Hann_DASH_check_DASH_temp28517221(ann_DASH_check_DASH_temp677220);
}};
$e72097210.stack[R.EXN_STACKHEIGHT++] = $ss72137214;
}
if(R.isPyretException($e72097210)) {
$e72097210.pyretStack.push(L[1164]);
}
throw $e72097210;
}
var $ret72157216 = $Hann_DASH_check_DASH_temp28517221($z72117212);
++R.GAS;
return $ret72157216;
});
var anf_arg707203 = G(self2587206,"imports",L[1163]);
var $z71927193 = D;
var $f71987199 = function(_) {
return R.isFunction(anf_fun657200)?anf_fun657200.app(anf_arg667201,anf_arg697202,anf_arg707203):R.ffi.throwNonFunApp(L[1162],anf_fun657200,[anf_arg667201,anf_arg697202,anf_arg707203]);
};
try {
if(--R.GAS > 0) {
$z71927193 = $f71987199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71987199,
"from":L[1162]});
}
} catch($e71907191) {
if(R.isCont($e71907191)) {
var $ss71947195 = {"from":L[1162],
"go":function(anf_arg717204) {
return $Hanf_arg28567207(anf_arg717204,PP337,anf_fun647205,self2587206,_plus26);
}};
$e71907191.stack[R.EXN_STACKHEIGHT++] = $ss71947195;
}
if(R.isPyretException($e71907191)) {
$e71907191.pyretStack.push(L[1162]);
}
throw $e71907191;
}
var $ret71967197 = $Hanf_arg28567207($z71927193,PP337,anf_fun647205,self2587206,_plus26);
++R.GAS;
return $ret71967197;
};
},{"length":1});
var anf_assign79394 = (function() {
var $a_DASH_program_DASH_base71787179 = {"visit":anf_shared327177,
"_match":anf_variant_member467183,
"_torepr":anf_variant_member607184,
"label":anf_variant_member627185,
"tosource":anf_variant_member787186};
var $a_DASH_program_DASH_brands71817182 = {"$brand-a-program7180":true};
$a_DASH_program_DASH_brands71817182[AProgT26778._brand] = true
return R.makeObject({"AProg":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1157],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AProgT26778._brand));
}),
"is-a-program":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1156],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-program7180"));
}),
"a-program":R.makeFunction(function(l2547187,imports2557188,body2567189) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1158],3,arguments);
}
return R.checkAnnArgs([Loc9089,List1788,AExpr7465],[l2547187,imports2557188,body2567189],[L[1159],L[1160],L[1161]],function() {
var dict = R.create($a_DASH_program_DASH_base71787179);
dict["l"] = l2547187
dict["imports"] = imports2557188
dict["body"] = body2567189
return R.makeBrandedObject(dict,$a_DASH_program_DASH_brands71817182);
});
})});
})();
AProg14117393.$var = anf_assign79394;
var anf_assign80396 = G(AProg14117393.$var,"AProg",L[1157]);
AProg118395.$var = anf_assign80396;
var anf_assign81398 = G(AProg14117393.$var,"AProg",L[1157]);
is_DASH_AProg119397.$var = anf_assign81398;
var anf_assign82400 = G(AProg14117393.$var,"is-a-program",L[1156]);
is_DASH_a_DASH_program120399.$var = anf_assign82400;
var anf_assign83402 = G(AProg14117393.$var,"a-program",L[1156]);
a_DASH_program121401.$var = anf_assign83402;
var anf_variant_member967027 = R.makeMethod(function(self87155) {
return function(cases_DASH_funs97156,else_DASH_clause107167) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1136],2,arguments);
}
var if_DASH_127170 = R.hasField(cases_DASH_funs97156,("a-import-builtin"));
var if_helper857153 = R.makeFunction(function(if_helper_arg867175) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1136],1,arguments);
}
var ann_DASH_check_DASH_temp847176 = if_helper_arg867175;
return ann_DASH_check_DASH_temp847176;
});
var anf_if897174 = R.isBoolean(if_DASH_127170);
if(R.isPyretTrue(anf_if897174)) {
if(R.isPyretTrue(if_DASH_127170)) {
var call_DASH_a_DASH_import_DASH_builtin77149 = G(cases_DASH_funs97156,"a-import-builtin",L[1136]);
var anf_arg927150 = G(self87155,"l",L[1155]);
var anf_arg937151 = G(self87155,"lib",L[1154]);
var $z71417142 = D;
var $f71477148 = function(_) {
return R.isFunction(call_DASH_a_DASH_import_DASH_builtin77149)?call_DASH_a_DASH_import_DASH_builtin77149.app(anf_arg927150,anf_arg937151):R.ffi.throwNonFunApp(L[1136],call_DASH_a_DASH_import_DASH_builtin77149,[anf_arg927150,anf_arg937151]);
};
try {
if(--R.GAS > 0) {
$z71417142 = $f71477148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71477148,
"from":L[1136]});
}
} catch($e71397140) {
if(R.isCont($e71397140)) {
var $ss71437144 = {"from":L[1136],
"go":function(cont_tail_arg947152) {
return $Hcont_tail_arg28577154(cont_tail_arg947152,if_helper857153);
}};
$e71397140.stack[R.EXN_STACKHEIGHT++] = $ss71437144;
}
if(R.isPyretException($e71397140)) {
$e71397140.pyretStack.push(L[1136]);
}
throw $e71397140;
}
var $ret71457146 = $Hcont_tail_arg28577154($z71417142,if_helper857153);
++R.GAS;
return $ret71457146;
} else {
var $z71597160 = D;
var $f71657166 = function(_) {
return R.isFunction(else_DASH_clause107167)?else_DASH_clause107167.app():R.ffi.throwNonFunApp(L[1136],else_DASH_clause107167,[]);
};
try {
if(--R.GAS > 0) {
$z71597160 = $f71657166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71657166,
"from":L[1136]});
}
} catch($e71577158) {
if(R.isCont($e71577158)) {
var $ss71617162 = {"from":L[1136],
"go":function(cont_tail_arg907168) {
return $Hcont_tail_arg28587169(cont_tail_arg907168,if_helper857153);
}};
$e71577158.stack[R.EXN_STACKHEIGHT++] = $ss71617162;
}
if(R.isPyretException($e71577158)) {
$e71577158.pyretStack.push(L[1136]);
}
throw $e71577158;
}
var $ret71637164 = $Hcont_tail_arg28587169($z71597160,if_helper857153);
++R.GAS;
return $ret71637164;
}
} else {
var cont_tail_arg877173 = R.throwNonBooleanCondition(L[1136],("if"),if_DASH_127170);
if(--R.GAS > 0) {
$z71717172 = R.isFunction(if_helper857153)?if_helper857153.app(cont_tail_arg877173):R.ffi.throwNonFunApp(L[1136],if_helper857153,[cont_tail_arg877173]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper857153)?if_helper857153.app(cont_tail_arg877173):R.ffi.throwNonFunApp(L[1136],if_helper857153,[cont_tail_arg877173]);
},
"from":L[1136]});
}
++R.GAS;
return $z71717172;
}
};
},{"length":3});
var anf_variant_member1067028 = R.makeMethod(function(self117137) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1136],0,arguments);
}
var anf_arg987135 = G(self117137,"l",L[1136]);
var $z71277128 = D;
var $f71337134 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg987135):R.ffi.throwNonFunApp(L[1136],torepr31,[anf_arg987135]);
};
try {
if(--R.GAS > 0) {
$z71277128 = $f71337134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71337134,
"from":L[1136]});
}
} catch($e71257126) {
if(R.isCont($e71257126)) {
var $ss71297130 = {"from":L[1136],
"go":function(anf_arg997136) {
return $Hanf_arg28657138(anf_arg997136,self117137,_plus26,torepr31);
}};
$e71257126.stack[R.EXN_STACKHEIGHT++] = $ss71297130;
}
if(R.isPyretException($e71257126)) {
$e71257126.pyretStack.push(L[1136]);
}
throw $e71257126;
}
var $ret71317132 = $Hanf_arg28657138($z71277128,self117137,_plus26,torepr31);
++R.GAS;
return $ret71317132;
};
},{"length":1});
var anf_variant_member1107029 = R.makeMethod(function(self2647124) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1151],0,arguments);
}
var anf_fun1087120 = G(PP337,"str",L[1153]);
var anf_arg1097121 = G(self2647124,"lib",L[1152]);
var $z71127113 = D;
var $f71187119 = function(_) {
return R.isFunction(anf_fun1087120)?anf_fun1087120.app(anf_arg1097121):R.ffi.throwNonFunApp(L[1151],anf_fun1087120,[anf_arg1097121]);
};
try {
if(--R.GAS > 0) {
$z71127113 = $f71187119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71187119,
"from":L[1151]});
}
} catch($e71107111) {
if(R.isCont($e71107111)) {
var $ss71147115 = {"from":L[1151],
"go":function(ann_DASH_check_DASH_temp1077122) {
return $Hann_DASH_check_DASH_temp28667123(ann_DASH_check_DASH_temp1077122);
}};
$e71107111.stack[R.EXN_STACKHEIGHT++] = $ss71147115;
}
if(R.isPyretException($e71107111)) {
$e71107111.pyretStack.push(L[1151]);
}
throw $e71107111;
}
var $ret71167117 = $Hann_DASH_check_DASH_temp28667123($z71127113);
++R.GAS;
return $ret71167117;
};
},{"length":1});
var anf_variant_member1237037 = R.makeMethod(function(self147088) {
return function(cases_DASH_funs157089,else_DASH_clause167100) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1135],2,arguments);
}
var if_DASH_187103 = R.hasField(cases_DASH_funs157089,("a-import-file"));
var if_helper1127086 = R.makeFunction(function(if_helper_arg1137108) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1135],1,arguments);
}
var ann_DASH_check_DASH_temp1117109 = if_helper_arg1137108;
return ann_DASH_check_DASH_temp1117109;
});
var anf_if1167107 = R.isBoolean(if_DASH_187103);
if(R.isPyretTrue(anf_if1167107)) {
if(R.isPyretTrue(if_DASH_187103)) {
var call_DASH_a_DASH_import_DASH_file137082 = G(cases_DASH_funs157089,"a-import-file",L[1135]);
var anf_arg1197083 = G(self147088,"l",L[1150]);
var anf_arg1207084 = G(self147088,"file",L[1149]);
var $z70747075 = D;
var $f70807081 = function(_) {
return R.isFunction(call_DASH_a_DASH_import_DASH_file137082)?call_DASH_a_DASH_import_DASH_file137082.app(anf_arg1197083,anf_arg1207084):R.ffi.throwNonFunApp(L[1135],call_DASH_a_DASH_import_DASH_file137082,[anf_arg1197083,anf_arg1207084]);
};
try {
if(--R.GAS > 0) {
$z70747075 = $f70807081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70807081,
"from":L[1135]});
}
} catch($e70727073) {
if(R.isCont($e70727073)) {
var $ss70767077 = {"from":L[1135],
"go":function(cont_tail_arg1217085) {
return $Hcont_tail_arg28677087(cont_tail_arg1217085,if_helper1127086);
}};
$e70727073.stack[R.EXN_STACKHEIGHT++] = $ss70767077;
}
if(R.isPyretException($e70727073)) {
$e70727073.pyretStack.push(L[1135]);
}
throw $e70727073;
}
var $ret70787079 = $Hcont_tail_arg28677087($z70747075,if_helper1127086);
++R.GAS;
return $ret70787079;
} else {
var $z70927093 = D;
var $f70987099 = function(_) {
return R.isFunction(else_DASH_clause167100)?else_DASH_clause167100.app():R.ffi.throwNonFunApp(L[1135],else_DASH_clause167100,[]);
};
try {
if(--R.GAS > 0) {
$z70927093 = $f70987099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70987099,
"from":L[1135]});
}
} catch($e70907091) {
if(R.isCont($e70907091)) {
var $ss70947095 = {"from":L[1135],
"go":function(cont_tail_arg1177101) {
return $Hcont_tail_arg28687102(cont_tail_arg1177101,if_helper1127086);
}};
$e70907091.stack[R.EXN_STACKHEIGHT++] = $ss70947095;
}
if(R.isPyretException($e70907091)) {
$e70907091.pyretStack.push(L[1135]);
}
throw $e70907091;
}
var $ret70967097 = $Hcont_tail_arg28687102($z70927093,if_helper1127086);
++R.GAS;
return $ret70967097;
}
} else {
var cont_tail_arg1147106 = R.throwNonBooleanCondition(L[1135],("if"),if_DASH_187103);
if(--R.GAS > 0) {
$z71047105 = R.isFunction(if_helper1127086)?if_helper1127086.app(cont_tail_arg1147106):R.ffi.throwNonFunApp(L[1135],if_helper1127086,[cont_tail_arg1147106]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1127086)?if_helper1127086.app(cont_tail_arg1147106):R.ffi.throwNonFunApp(L[1135],if_helper1127086,[cont_tail_arg1147106]);
},
"from":L[1135]});
}
++R.GAS;
return $z71047105;
}
};
},{"length":3});
var anf_variant_member1337038 = R.makeMethod(function(self177070) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1135],0,arguments);
}
var anf_arg1257068 = G(self177070,"l",L[1135]);
var $z70607061 = D;
var $f70667067 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg1257068):R.ffi.throwNonFunApp(L[1135],torepr31,[anf_arg1257068]);
};
try {
if(--R.GAS > 0) {
$z70607061 = $f70667067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70667067,
"from":L[1135]});
}
} catch($e70587059) {
if(R.isCont($e70587059)) {
var $ss70627063 = {"from":L[1135],
"go":function(anf_arg1267069) {
return $Hanf_arg28757071(anf_arg1267069,self177070,_plus26,torepr31);
}};
$e70587059.stack[R.EXN_STACKHEIGHT++] = $ss70627063;
}
if(R.isPyretException($e70587059)) {
$e70587059.pyretStack.push(L[1135]);
}
throw $e70587059;
}
var $ret70647065 = $Hanf_arg28757071($z70607061,self177070,_plus26,torepr31);
++R.GAS;
return $ret70647065;
};
},{"length":1});
var anf_variant_member1397039 = R.makeMethod(function(self2677057) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1148],0,arguments);
}
var anf_fun1357055 = G(PP337,"dquote",L[1147]);
var anf_fun1367052 = G(PP337,"str",L[1146]);
var anf_arg1377053 = G(self2677057,"file",L[1145]);
var $z70447045 = D;
var $f70507051 = function(_) {
return R.isFunction(anf_fun1367052)?anf_fun1367052.app(anf_arg1377053):R.ffi.throwNonFunApp(L[1144],anf_fun1367052,[anf_arg1377053]);
};
try {
if(--R.GAS > 0) {
$z70447045 = $f70507051();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70507051,
"from":L[1144]});
}
} catch($e70427043) {
if(R.isCont($e70427043)) {
var $ss70467047 = {"from":L[1144],
"go":function(anf_arg1387054) {
return $Hanf_arg28777056(anf_arg1387054,anf_fun1357055);
}};
$e70427043.stack[R.EXN_STACKHEIGHT++] = $ss70467047;
}
if(R.isPyretException($e70427043)) {
$e70427043.pyretStack.push(L[1144]);
}
throw $e70427043;
}
var $ret70487049 = $Hanf_arg28777056($z70447045,anf_fun1357055);
++R.GAS;
return $ret70487049;
};
},{"length":1});
var anf_assign140404 = (function() {
var $a_DASH_import_DASH_builtin_DASH_base70227023 = {"_match":anf_variant_member967027,
"_torepr":anf_variant_member1067028,
"tosource":anf_variant_member1107029};
var $a_DASH_import_DASH_builtin_DASH_brands70257026 = {"$brand-a-import-builtin7024":true};
$a_DASH_import_DASH_builtin_DASH_brands70257026[AImportTypeT36972._brand] = true
var $a_DASH_import_DASH_file_DASH_base70327033 = {"_match":anf_variant_member1237037,
"_torepr":anf_variant_member1337038,
"tosource":anf_variant_member1397039};
var $a_DASH_import_DASH_file_DASH_brands70357036 = {"$brand-a-import-file7034":true};
$a_DASH_import_DASH_file_DASH_brands70357036[AImportTypeT36972._brand] = true
return R.makeObject({"AImportType":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1137],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AImportTypeT36972._brand));
}),
"is-a-import-builtin":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1136],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-import-builtin7024"));
}),
"a-import-builtin":R.makeFunction(function(l2627030,lib2637031) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1138],2,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35],[l2627030,lib2637031],[L[1139],L[1140]],function() {
var dict = R.create($a_DASH_import_DASH_builtin_DASH_base70227023);
dict["l"] = l2627030
dict["lib"] = lib2637031
return R.makeBrandedObject(dict,$a_DASH_import_DASH_builtin_DASH_brands70257026);
});
}),
"is-a-import-file":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1135],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-import-file7034"));
}),
"a-import-file":R.makeFunction(function(l2657040,file2667041) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1141],2,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35],[l2657040,file2667041],[L[1142],L[1143]],function() {
var dict = R.create($a_DASH_import_DASH_file_DASH_base70327033);
dict["l"] = l2657040
dict["file"] = file2667041
return R.makeBrandedObject(dict,$a_DASH_import_DASH_file_DASH_brands70357036);
});
})});
})();
AImportType15122403.$var = anf_assign140404;
var anf_assign141406 = G(AImportType15122403.$var,"AImportType",L[1137]);
AImportType123405.$var = anf_assign141406;
var anf_assign142408 = G(AImportType15122403.$var,"AImportType",L[1137]);
is_DASH_AImportType124407.$var = anf_assign142408;
var anf_assign143410 = G(AImportType15122403.$var,"is-a-import-builtin",L[1136]);
is_DASH_a_DASH_import_DASH_builtin125409.$var = anf_assign143410;
var anf_assign144412 = G(AImportType15122403.$var,"a-import-builtin",L[1136]);
a_DASH_import_DASH_builtin126411.$var = anf_assign144412;
var anf_assign145414 = G(AImportType15122403.$var,"is-a-import-file",L[1135]);
is_DASH_a_DASH_import_DASH_file127413.$var = anf_assign145414;
var anf_assign146416 = G(AImportType15122403.$var,"a-import-file",L[1135]);
a_DASH_import_DASH_file128415.$var = anf_assign146416;
var anf_shared1546824 = R.makeMethod(function(self2797021) {
return function(visitor2807004) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1130],1,arguments);
}
var anf_fun1487003 = G(self2797021,"_match",L[1134]);
var anf_arg1537005 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1131],0,arguments);
}
var anf_fun1507018 = G(self2797021,"label",L[1133]);
var $z70107011 = D;
var $f70167017 = function(_) {
return R.isFunction(anf_fun1507018)?anf_fun1507018.app():R.ffi.throwNonFunApp(L[1132],anf_fun1507018,[]);
};
try {
if(--R.GAS > 0) {
$z70107011 = $f70167017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70167017,
"from":L[1132]});
}
} catch($e70087009) {
if(R.isCont($e70087009)) {
var $ss70127013 = {"from":L[1132],
"go":function(anf_arg1517019) {
return $Hanf_arg28807020(anf_arg1517019,_plus26,raise30);
}};
$e70087009.stack[R.EXN_STACKHEIGHT++] = $ss70127013;
}
if(R.isPyretException($e70087009)) {
$e70087009.pyretStack.push(L[1132]);
}
throw $e70087009;
}
var $ret70147015 = $Hanf_arg28807020($z70107011,_plus26,raise30);
++R.GAS;
return $ret70147015;
});
var $z69956996 = D;
var $f70017002 = function(_) {
return R.isFunction(anf_fun1487003)?anf_fun1487003.app(visitor2807004,anf_arg1537005):R.ffi.throwNonFunApp(L[1130],anf_fun1487003,[visitor2807004,anf_arg1537005]);
};
try {
if(--R.GAS > 0) {
$z69956996 = $f70017002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70017002,
"from":L[1130]});
}
} catch($e69936994) {
if(R.isCont($e69936994)) {
var $ss69976998 = {"from":L[1130],
"go":function(ann_DASH_check_DASH_temp1477006) {
return $Hann_DASH_check_DASH_temp28817007(ann_DASH_check_DASH_temp1477006);
}};
$e69936994.stack[R.EXN_STACKHEIGHT++] = $ss69976998;
}
if(R.isPyretException($e69936994)) {
$e69936994.pyretStack.push(L[1130]);
}
throw $e69936994;
}
var $ret69997000 = $Hann_DASH_check_DASH_temp28817007($z69956996);
++R.GAS;
return $ret69997000;
};
},{"length":2});
var anf_variant_member1686830 = R.makeMethod(function(self206971) {
return function(cases_DASH_funs216972,else_DASH_clause226983) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1098],2,arguments);
}
var if_DASH_246986 = R.hasField(cases_DASH_funs216972,("a-import"));
var if_helper1566969 = R.makeFunction(function(if_helper_arg1576991) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1098],1,arguments);
}
var ann_DASH_check_DASH_temp1556992 = if_helper_arg1576991;
return ann_DASH_check_DASH_temp1556992;
});
var anf_if1606990 = R.isBoolean(if_DASH_246986);
if(R.isPyretTrue(anf_if1606990)) {
if(R.isPyretTrue(if_DASH_246986)) {
var call_DASH_a_DASH_import196964 = G(cases_DASH_funs216972,"a-import",L[1098]);
var anf_arg1636965 = G(self206971,"l",L[1129]);
var anf_arg1646966 = G(self206971,"import-type",L[1128]);
var anf_arg1656967 = G(self206971,"name",L[1127]);
var $z69566957 = D;
var $f69626963 = function(_) {
return R.isFunction(call_DASH_a_DASH_import196964)?call_DASH_a_DASH_import196964.app(anf_arg1636965,anf_arg1646966,anf_arg1656967):R.ffi.throwNonFunApp(L[1098],call_DASH_a_DASH_import196964,[anf_arg1636965,anf_arg1646966,anf_arg1656967]);
};
try {
if(--R.GAS > 0) {
$z69566957 = $f69626963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69626963,
"from":L[1098]});
}
} catch($e69546955) {
if(R.isCont($e69546955)) {
var $ss69586959 = {"from":L[1098],
"go":function(cont_tail_arg1666968) {
return $Hcont_tail_arg28826970(cont_tail_arg1666968,if_helper1566969);
}};
$e69546955.stack[R.EXN_STACKHEIGHT++] = $ss69586959;
}
if(R.isPyretException($e69546955)) {
$e69546955.pyretStack.push(L[1098]);
}
throw $e69546955;
}
var $ret69606961 = $Hcont_tail_arg28826970($z69566957,if_helper1566969);
++R.GAS;
return $ret69606961;
} else {
var $z69756976 = D;
var $f69816982 = function(_) {
return R.isFunction(else_DASH_clause226983)?else_DASH_clause226983.app():R.ffi.throwNonFunApp(L[1098],else_DASH_clause226983,[]);
};
try {
if(--R.GAS > 0) {
$z69756976 = $f69816982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69816982,
"from":L[1098]});
}
} catch($e69736974) {
if(R.isCont($e69736974)) {
var $ss69776978 = {"from":L[1098],
"go":function(cont_tail_arg1616984) {
return $Hcont_tail_arg28836985(cont_tail_arg1616984,if_helper1566969);
}};
$e69736974.stack[R.EXN_STACKHEIGHT++] = $ss69776978;
}
if(R.isPyretException($e69736974)) {
$e69736974.pyretStack.push(L[1098]);
}
throw $e69736974;
}
var $ret69796980 = $Hcont_tail_arg28836985($z69756976,if_helper1566969);
++R.GAS;
return $ret69796980;
}
} else {
var cont_tail_arg1586989 = R.throwNonBooleanCondition(L[1098],("if"),if_DASH_246986);
if(--R.GAS > 0) {
$z69876988 = R.isFunction(if_helper1566969)?if_helper1566969.app(cont_tail_arg1586989):R.ffi.throwNonFunApp(L[1098],if_helper1566969,[cont_tail_arg1586989]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1566969)?if_helper1566969.app(cont_tail_arg1586989):R.ffi.throwNonFunApp(L[1098],if_helper1566969,[cont_tail_arg1586989]);
},
"from":L[1098]});
}
++R.GAS;
return $z69876988;
}
};
},{"length":3});
var anf_variant_member1826831 = R.makeMethod(function(self236952) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1098],0,arguments);
}
var anf_arg1706950 = G(self236952,"l",L[1098]);
var $z69426943 = D;
var $f69486949 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg1706950):R.ffi.throwNonFunApp(L[1098],torepr31,[anf_arg1706950]);
};
try {
if(--R.GAS > 0) {
$z69426943 = $f69486949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69486949,
"from":L[1098]});
}
} catch($e69406941) {
if(R.isCont($e69406941)) {
var $ss69446945 = {"from":L[1098],
"go":function(anf_arg1716951) {
return $Hanf_arg28936953(anf_arg1716951,self236952,_plus26,torepr31);
}};
$e69406941.stack[R.EXN_STACKHEIGHT++] = $ss69446945;
}
if(R.isPyretException($e69406941)) {
$e69406941.pyretStack.push(L[1098]);
}
throw $e69406941;
}
var $ret69466947 = $Hanf_arg28936953($z69426943,self236952,_plus26,torepr31);
++R.GAS;
return $ret69466947;
};
},{"length":1});
var anf_variant_member1846832 = R.makeMethod(function(self2716939) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1126],0,arguments);
}
var ann_DASH_check_DASH_temp1836938 = ("a-import");
return ann_DASH_check_DASH_temp1836938;
};
},{"length":1});
var anf_variant_member1956833 = R.makeMethod(function(self2723443) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1125],0,arguments);
}
var anf_fun1866934 = G(PP337,"flow",L[1124]);
var anf_fun1876935 = G(list2593,"make",L[1123]);
var anf_bracket1886937 = G(self2723443,"import-type",L[1122]);
var anf_fun1896932 = G(anf_bracket1886937,"tosource",L[1121]);
var $z69246925 = D;
var $f69306931 = function(_) {
return R.isFunction(anf_fun1896932)?anf_fun1896932.app():R.ffi.throwNonFunApp(L[1120],anf_fun1896932,[]);
};
try {
if(--R.GAS > 0) {
$z69246925 = $f69306931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69306931,
"from":L[1120]});
}
} catch($e69226923) {
if(R.isCont($e69226923)) {
var $ss69266927 = {"from":L[1120],
"go":function(anf_array_val1906933) {
return $Hanf_array_val28976936(anf_array_val1906933,anf_fun1866934,anf_fun1876935,self2723443,str_DASH_as113365,str_DASH_import111339);
}};
$e69226923.stack[R.EXN_STACKHEIGHT++] = $ss69266927;
}
if(R.isPyretException($e69226923)) {
$e69226923.pyretStack.push(L[1120]);
}
throw $e69226923;
}
var $ret69286929 = $Hanf_array_val28976936($z69246925,anf_fun1866934,anf_fun1876935,self2723443,str_DASH_as113365,str_DASH_import111339);
++R.GAS;
return $ret69286929;
};
},{"length":1});
var anf_variant_member2106842 = R.makeMethod(function(self266900) {
return function(cases_DASH_funs276901,else_DASH_clause286912) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1097],2,arguments);
}
var if_DASH_306915 = R.hasField(cases_DASH_funs276901,("a-import-types"));
var if_helper1976898 = R.makeFunction(function(if_helper_arg1986920) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1097],1,arguments);
}
var ann_DASH_check_DASH_temp1966921 = if_helper_arg1986920;
return ann_DASH_check_DASH_temp1966921;
});
var anf_if2016919 = R.isBoolean(if_DASH_306915);
if(R.isPyretTrue(anf_if2016919)) {
if(R.isPyretTrue(if_DASH_306915)) {
var call_DASH_a_DASH_import_DASH_types256892 = G(cases_DASH_funs276901,"a-import-types",L[1097]);
var anf_arg2046893 = G(self266900,"l",L[1119]);
var anf_arg2056894 = G(self266900,"import-type",L[1118]);
var anf_arg2066895 = G(self266900,"name",L[1117]);
var anf_arg2076896 = G(self266900,"types",L[1116]);
var $z68846885 = D;
var $f68906891 = function(_) {
return R.isFunction(call_DASH_a_DASH_import_DASH_types256892)?call_DASH_a_DASH_import_DASH_types256892.app(anf_arg2046893,anf_arg2056894,anf_arg2066895,anf_arg2076896):R.ffi.throwNonFunApp(L[1097],call_DASH_a_DASH_import_DASH_types256892,[anf_arg2046893,anf_arg2056894,anf_arg2066895,anf_arg2076896]);
};
try {
if(--R.GAS > 0) {
$z68846885 = $f68906891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68906891,
"from":L[1097]});
}
} catch($e68826883) {
if(R.isCont($e68826883)) {
var $ss68866887 = {"from":L[1097],
"go":function(cont_tail_arg2086897) {
return $Hcont_tail_arg28986899(cont_tail_arg2086897,if_helper1976898);
}};
$e68826883.stack[R.EXN_STACKHEIGHT++] = $ss68866887;
}
if(R.isPyretException($e68826883)) {
$e68826883.pyretStack.push(L[1097]);
}
throw $e68826883;
}
var $ret68886889 = $Hcont_tail_arg28986899($z68846885,if_helper1976898);
++R.GAS;
return $ret68886889;
} else {
var $z69046905 = D;
var $f69106911 = function(_) {
return R.isFunction(else_DASH_clause286912)?else_DASH_clause286912.app():R.ffi.throwNonFunApp(L[1097],else_DASH_clause286912,[]);
};
try {
if(--R.GAS > 0) {
$z69046905 = $f69106911();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69106911,
"from":L[1097]});
}
} catch($e69026903) {
if(R.isCont($e69026903)) {
var $ss69066907 = {"from":L[1097],
"go":function(cont_tail_arg2026913) {
return $Hcont_tail_arg28996914(cont_tail_arg2026913,if_helper1976898);
}};
$e69026903.stack[R.EXN_STACKHEIGHT++] = $ss69066907;
}
if(R.isPyretException($e69026903)) {
$e69026903.pyretStack.push(L[1097]);
}
throw $e69026903;
}
var $ret69086909 = $Hcont_tail_arg28996914($z69046905,if_helper1976898);
++R.GAS;
return $ret69086909;
}
} else {
var cont_tail_arg1996918 = R.throwNonBooleanCondition(L[1097],("if"),if_DASH_306915);
if(--R.GAS > 0) {
$z69166917 = R.isFunction(if_helper1976898)?if_helper1976898.app(cont_tail_arg1996918):R.ffi.throwNonFunApp(L[1097],if_helper1976898,[cont_tail_arg1996918]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1976898)?if_helper1976898.app(cont_tail_arg1996918):R.ffi.throwNonFunApp(L[1097],if_helper1976898,[cont_tail_arg1996918]);
},
"from":L[1097]});
}
++R.GAS;
return $z69166917;
}
};
},{"length":3});
var anf_variant_member2286843 = R.makeMethod(function(self296880) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1097],0,arguments);
}
var anf_arg2126878 = G(self296880,"l",L[1097]);
var $z68706871 = D;
var $f68766877 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg2126878):R.ffi.throwNonFunApp(L[1097],torepr31,[anf_arg2126878]);
};
try {
if(--R.GAS > 0) {
$z68706871 = $f68766877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68766877,
"from":L[1097]});
}
} catch($e68686869) {
if(R.isCont($e68686869)) {
var $ss68726873 = {"from":L[1097],
"go":function(anf_arg2136879) {
return $Hanf_arg29126881(anf_arg2136879,self296880,_plus26,torepr31);
}};
$e68686869.stack[R.EXN_STACKHEIGHT++] = $ss68726873;
}
if(R.isPyretException($e68686869)) {
$e68686869.pyretStack.push(L[1097]);
}
throw $e68686869;
}
var $ret68746875 = $Hanf_arg29126881($z68706871,self296880,_plus26,torepr31);
++R.GAS;
return $ret68746875;
};
},{"length":1});
var anf_variant_member2306844 = R.makeMethod(function(self2776867) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1115],0,arguments);
}
var ann_DASH_check_DASH_temp2296866 = ("a-import-types");
return ann_DASH_check_DASH_temp2296866;
};
},{"length":1});
var anf_variant_member2456845 = R.makeMethod(function(self2783371) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1114],0,arguments);
}
var anf_fun2326862 = G(PP337,"flow",L[1113]);
var anf_fun2336863 = G(list2593,"make",L[1112]);
var anf_bracket2346865 = G(self2783371,"import-type",L[1111]);
var anf_fun2356860 = G(anf_bracket2346865,"tosource",L[1110]);
var $z68526853 = D;
var $f68586859 = function(_) {
return R.isFunction(anf_fun2356860)?anf_fun2356860.app():R.ffi.throwNonFunApp(L[1109],anf_fun2356860,[]);
};
try {
if(--R.GAS > 0) {
$z68526853 = $f68586859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68586859,
"from":L[1109]});
}
} catch($e68506851) {
if(R.isCont($e68506851)) {
var $ss68546855 = {"from":L[1109],
"go":function(anf_array_val2366861) {
return $Hanf_array_val29176864(anf_array_val2366861,PP337,anf_fun2326862,anf_fun2336863,self2783371,str_DASH_as113365,str_DASH_import111339);
}};
$e68506851.stack[R.EXN_STACKHEIGHT++] = $ss68546855;
}
if(R.isPyretException($e68506851)) {
$e68506851.pyretStack.push(L[1109]);
}
throw $e68506851;
}
var $ret68566857 = $Hanf_array_val29176864($z68526853,PP337,anf_fun2326862,anf_fun2336863,self2783371,str_DASH_as113365,str_DASH_import111339);
++R.GAS;
return $ret68566857;
};
},{"length":1});
var anf_assign246418 = (function() {
var $a_DASH_import_DASH_base68256826 = {"visit":anf_shared1546824,
"_match":anf_variant_member1686830,
"_torepr":anf_variant_member1826831,
"label":anf_variant_member1846832,
"tosource":anf_variant_member1956833};
var $a_DASH_import_DASH_brands68286829 = {"$brand-a-import6827":true};
$a_DASH_import_DASH_brands68286829[AImportT47170._brand] = true
var $a_DASH_import_DASH_types_DASH_base68376838 = {"visit":anf_shared1546824,
"_match":anf_variant_member2106842,
"_torepr":anf_variant_member2286843,
"label":anf_variant_member2306844,
"tosource":anf_variant_member2456845};
var $a_DASH_import_DASH_types_DASH_brands68406841 = {"$brand-a-import-types6839":true};
$a_DASH_import_DASH_types_DASH_brands68406841[AImportT47170._brand] = true
return R.makeObject({"AImport":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1099],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AImportT47170._brand));
}),
"is-a-import":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1098],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-import6827"));
}),
"a-import":R.makeFunction(function(l2686834,import_DASH_type2696835,name2706836) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1100],3,arguments);
}
return R.checkAnnArgs([Loc9089,AImportType6871,R.getDotAnn(L[1101],"A",A244,"Name")],[l2686834,import_DASH_type2696835,name2706836],[L[1102],L[1103],L[1101]],function() {
var dict = R.create($a_DASH_import_DASH_base68256826);
dict["l"] = l2686834
dict["import-type"] = import_DASH_type2696835
dict["name"] = name2706836
return R.makeBrandedObject(dict,$a_DASH_import_DASH_brands68286829);
});
}),
"is-a-import-types":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1097],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-import-types6839"));
}),
"a-import-types":R.makeFunction(function(l2736846,import_DASH_type2746847,name2756848,types2766849) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1104],4,arguments);
}
return R.checkAnnArgs([Loc9089,AImportType6871,R.getDotAnn(L[1105],"A",A244,"Name"),R.getDotAnn(L[1106],"A",A244,"Name")],[l2736846,import_DASH_type2746847,name2756848,types2766849],[L[1107],L[1108],L[1105],L[1106]],function() {
var dict = R.create($a_DASH_import_DASH_types_DASH_base68376838);
dict["l"] = l2736846
dict["import-type"] = import_DASH_type2746847
dict["name"] = name2756848
dict["types"] = types2766849
return R.makeBrandedObject(dict,$a_DASH_import_DASH_types_DASH_brands68406841);
});
})});
})();
AImport16129417.$var = anf_assign246418;
var anf_assign247420 = G(AImport16129417.$var,"AImport",L[1099]);
AImport130419.$var = anf_assign247420;
var anf_assign248422 = G(AImport16129417.$var,"AImport",L[1099]);
is_DASH_AImport131421.$var = anf_assign248422;
var anf_assign249424 = G(AImport16129417.$var,"is-a-import",L[1098]);
is_DASH_a_DASH_import132423.$var = anf_assign249424;
var anf_assign250426 = G(AImport16129417.$var,"a-import",L[1098]);
a_DASH_import133425.$var = anf_assign250426;
var anf_assign251428 = G(AImport16129417.$var,"is-a-import-types",L[1097]);
is_DASH_a_DASH_import_DASH_types134427.$var = anf_assign251428;
var anf_assign252430 = G(AImport16129417.$var,"a-import-types",L[1097]);
a_DASH_import_DASH_types135429.$var = anf_assign252430;
var anf_shared2606628 = R.makeMethod(function(self2916823) {
return function(visitor2926806) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1092],1,arguments);
}
var anf_fun2546805 = G(self2916823,"_match",L[1096]);
var anf_arg2596807 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1093],0,arguments);
}
var anf_fun2566820 = G(self2916823,"label",L[1095]);
var $z68126813 = D;
var $f68186819 = function(_) {
return R.isFunction(anf_fun2566820)?anf_fun2566820.app():R.ffi.throwNonFunApp(L[1094],anf_fun2566820,[]);
};
try {
if(--R.GAS > 0) {
$z68126813 = $f68186819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68186819,
"from":L[1094]});
}
} catch($e68106811) {
if(R.isCont($e68106811)) {
var $ss68146815 = {"from":L[1094],
"go":function(anf_arg2576821) {
return $Hanf_arg29206822(anf_arg2576821,_plus26,raise30);
}};
$e68106811.stack[R.EXN_STACKHEIGHT++] = $ss68146815;
}
if(R.isPyretException($e68106811)) {
$e68106811.pyretStack.push(L[1094]);
}
throw $e68106811;
}
var $ret68166817 = $Hanf_arg29206822($z68126813,_plus26,raise30);
++R.GAS;
return $ret68166817;
});
var $z67976798 = D;
var $f68036804 = function(_) {
return R.isFunction(anf_fun2546805)?anf_fun2546805.app(visitor2926806,anf_arg2596807):R.ffi.throwNonFunApp(L[1092],anf_fun2546805,[visitor2926806,anf_arg2596807]);
};
try {
if(--R.GAS > 0) {
$z67976798 = $f68036804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68036804,
"from":L[1092]});
}
} catch($e67956796) {
if(R.isCont($e67956796)) {
var $ss67996800 = {"from":L[1092],
"go":function(ann_DASH_check_DASH_temp2536808) {
return $Hann_DASH_check_DASH_temp29216809(ann_DASH_check_DASH_temp2536808);
}};
$e67956796.stack[R.EXN_STACKHEIGHT++] = $ss67996800;
}
if(R.isPyretException($e67956796)) {
$e67956796.pyretStack.push(L[1092]);
}
throw $e67956796;
}
var $ret68016802 = $Hann_DASH_check_DASH_temp29216809($z67976798);
++R.GAS;
return $ret68016802;
};
},{"length":2});
var anf_variant_member2746634 = R.makeMethod(function(self326773) {
return function(cases_DASH_funs336774,else_DASH_clause346785) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1064],2,arguments);
}
var if_DASH_366788 = R.hasField(cases_DASH_funs336774,("a-type-bind"));
var if_helper2626771 = R.makeFunction(function(if_helper_arg2636793) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1064],1,arguments);
}
var ann_DASH_check_DASH_temp2616794 = if_helper_arg2636793;
return ann_DASH_check_DASH_temp2616794;
});
var anf_if2666792 = R.isBoolean(if_DASH_366788);
if(R.isPyretTrue(anf_if2666792)) {
if(R.isPyretTrue(if_DASH_366788)) {
var call_DASH_a_DASH_type_DASH_bind316766 = G(cases_DASH_funs336774,"a-type-bind",L[1064]);
var anf_arg2696767 = G(self326773,"l",L[1091]);
var anf_arg2706768 = G(self326773,"name",L[1090]);
var anf_arg2716769 = G(self326773,"ann",L[1089]);
var $z67586759 = D;
var $f67646765 = function(_) {
return R.isFunction(call_DASH_a_DASH_type_DASH_bind316766)?call_DASH_a_DASH_type_DASH_bind316766.app(anf_arg2696767,anf_arg2706768,anf_arg2716769):R.ffi.throwNonFunApp(L[1064],call_DASH_a_DASH_type_DASH_bind316766,[anf_arg2696767,anf_arg2706768,anf_arg2716769]);
};
try {
if(--R.GAS > 0) {
$z67586759 = $f67646765();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67646765,
"from":L[1064]});
}
} catch($e67566757) {
if(R.isCont($e67566757)) {
var $ss67606761 = {"from":L[1064],
"go":function(cont_tail_arg2726770) {
return $Hcont_tail_arg29226772(cont_tail_arg2726770,if_helper2626771);
}};
$e67566757.stack[R.EXN_STACKHEIGHT++] = $ss67606761;
}
if(R.isPyretException($e67566757)) {
$e67566757.pyretStack.push(L[1064]);
}
throw $e67566757;
}
var $ret67626763 = $Hcont_tail_arg29226772($z67586759,if_helper2626771);
++R.GAS;
return $ret67626763;
} else {
var $z67776778 = D;
var $f67836784 = function(_) {
return R.isFunction(else_DASH_clause346785)?else_DASH_clause346785.app():R.ffi.throwNonFunApp(L[1064],else_DASH_clause346785,[]);
};
try {
if(--R.GAS > 0) {
$z67776778 = $f67836784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67836784,
"from":L[1064]});
}
} catch($e67756776) {
if(R.isCont($e67756776)) {
var $ss67796780 = {"from":L[1064],
"go":function(cont_tail_arg2676786) {
return $Hcont_tail_arg29236787(cont_tail_arg2676786,if_helper2626771);
}};
$e67756776.stack[R.EXN_STACKHEIGHT++] = $ss67796780;
}
if(R.isPyretException($e67756776)) {
$e67756776.pyretStack.push(L[1064]);
}
throw $e67756776;
}
var $ret67816782 = $Hcont_tail_arg29236787($z67776778,if_helper2626771);
++R.GAS;
return $ret67816782;
}
} else {
var cont_tail_arg2646791 = R.throwNonBooleanCondition(L[1064],("if"),if_DASH_366788);
if(--R.GAS > 0) {
$z67896790 = R.isFunction(if_helper2626771)?if_helper2626771.app(cont_tail_arg2646791):R.ffi.throwNonFunApp(L[1064],if_helper2626771,[cont_tail_arg2646791]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper2626771)?if_helper2626771.app(cont_tail_arg2646791):R.ffi.throwNonFunApp(L[1064],if_helper2626771,[cont_tail_arg2646791]);
},
"from":L[1064]});
}
++R.GAS;
return $z67896790;
}
};
},{"length":3});
var anf_variant_member2886635 = R.makeMethod(function(self356754) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1064],0,arguments);
}
var anf_arg2766752 = G(self356754,"l",L[1064]);
var $z67446745 = D;
var $f67506751 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg2766752):R.ffi.throwNonFunApp(L[1064],torepr31,[anf_arg2766752]);
};
try {
if(--R.GAS > 0) {
$z67446745 = $f67506751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67506751,
"from":L[1064]});
}
} catch($e67426743) {
if(R.isCont($e67426743)) {
var $ss67466747 = {"from":L[1064],
"go":function(anf_arg2776753) {
return $Hanf_arg29336755(anf_arg2776753,self356754,_plus26,torepr31);
}};
$e67426743.stack[R.EXN_STACKHEIGHT++] = $ss67466747;
}
if(R.isPyretException($e67426743)) {
$e67426743.pyretStack.push(L[1064]);
}
throw $e67426743;
}
var $ret67486749 = $Hanf_arg29336755($z67446745,self356754,_plus26,torepr31);
++R.GAS;
return $ret67486749;
};
},{"length":1});
var anf_variant_member2906636 = R.makeMethod(function(self2846741) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1088],0,arguments);
}
var ann_DASH_check_DASH_temp2896740 = ("a-type-bind");
return ann_DASH_check_DASH_temp2896740;
};
},{"length":1});
var anf_variant_member2996637 = R.makeMethod(function(self2856737) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1087],0,arguments);
}
var anf_fun2926736 = G(PP337,"infix",L[1086]);
var anf_bracket2936739 = G(self2856737,"name",L[1085]);
var anf_fun2946734 = G(anf_bracket2936739,"tosource",L[1084]);
var $z67266727 = D;
var $f67326733 = function(_) {
return R.isFunction(anf_fun2946734)?anf_fun2946734.app():R.ffi.throwNonFunApp(L[1083],anf_fun2946734,[]);
};
try {
if(--R.GAS > 0) {
$z67266727 = $f67326733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67326733,
"from":L[1083]});
}
} catch($e67246725) {
if(R.isCont($e67246725)) {
var $ss67286729 = {"from":L[1083],
"go":function(anf_arg2956735) {
return $Hanf_arg29366738(anf_arg2956735,INDENT9187,anf_fun2926736,self2856737,str_DASH_coloncolon99183);
}};
$e67246725.stack[R.EXN_STACKHEIGHT++] = $ss67286729;
}
if(R.isPyretException($e67246725)) {
$e67246725.pyretStack.push(L[1083]);
}
throw $e67246725;
}
var $ret67306731 = $Hanf_arg29366738($z67266727,INDENT9187,anf_fun2926736,self2856737,str_DASH_coloncolon99183);
++R.GAS;
return $ret67306731;
};
},{"length":1});
var anf_variant_member3136646 = R.makeMethod(function(self386702) {
return function(cases_DASH_funs396703,else_DASH_clause406714) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1063],2,arguments);
}
var if_DASH_426717 = R.hasField(cases_DASH_funs396703,("a-newtype-bind"));
var if_helper3016700 = R.makeFunction(function(if_helper_arg3026722) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1063],1,arguments);
}
var ann_DASH_check_DASH_temp3006723 = if_helper_arg3026722;
return ann_DASH_check_DASH_temp3006723;
});
var anf_if3056721 = R.isBoolean(if_DASH_426717);
if(R.isPyretTrue(anf_if3056721)) {
if(R.isPyretTrue(if_DASH_426717)) {
var call_DASH_a_DASH_newtype_DASH_bind376695 = G(cases_DASH_funs396703,"a-newtype-bind",L[1063]);
var anf_arg3086696 = G(self386702,"l",L[1082]);
var anf_arg3096697 = G(self386702,"name",L[1081]);
var anf_arg3106698 = G(self386702,"namet",L[1080]);
var $z66876688 = D;
var $f66936694 = function(_) {
return R.isFunction(call_DASH_a_DASH_newtype_DASH_bind376695)?call_DASH_a_DASH_newtype_DASH_bind376695.app(anf_arg3086696,anf_arg3096697,anf_arg3106698):R.ffi.throwNonFunApp(L[1063],call_DASH_a_DASH_newtype_DASH_bind376695,[anf_arg3086696,anf_arg3096697,anf_arg3106698]);
};
try {
if(--R.GAS > 0) {
$z66876688 = $f66936694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66936694,
"from":L[1063]});
}
} catch($e66856686) {
if(R.isCont($e66856686)) {
var $ss66896690 = {"from":L[1063],
"go":function(cont_tail_arg3116699) {
return $Hcont_tail_arg29376701(cont_tail_arg3116699,if_helper3016700);
}};
$e66856686.stack[R.EXN_STACKHEIGHT++] = $ss66896690;
}
if(R.isPyretException($e66856686)) {
$e66856686.pyretStack.push(L[1063]);
}
throw $e66856686;
}
var $ret66916692 = $Hcont_tail_arg29376701($z66876688,if_helper3016700);
++R.GAS;
return $ret66916692;
} else {
var $z67066707 = D;
var $f67126713 = function(_) {
return R.isFunction(else_DASH_clause406714)?else_DASH_clause406714.app():R.ffi.throwNonFunApp(L[1063],else_DASH_clause406714,[]);
};
try {
if(--R.GAS > 0) {
$z67066707 = $f67126713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67126713,
"from":L[1063]});
}
} catch($e67046705) {
if(R.isCont($e67046705)) {
var $ss67086709 = {"from":L[1063],
"go":function(cont_tail_arg3066715) {
return $Hcont_tail_arg29386716(cont_tail_arg3066715,if_helper3016700);
}};
$e67046705.stack[R.EXN_STACKHEIGHT++] = $ss67086709;
}
if(R.isPyretException($e67046705)) {
$e67046705.pyretStack.push(L[1063]);
}
throw $e67046705;
}
var $ret67106711 = $Hcont_tail_arg29386716($z67066707,if_helper3016700);
++R.GAS;
return $ret67106711;
}
} else {
var cont_tail_arg3036720 = R.throwNonBooleanCondition(L[1063],("if"),if_DASH_426717);
if(--R.GAS > 0) {
$z67186719 = R.isFunction(if_helper3016700)?if_helper3016700.app(cont_tail_arg3036720):R.ffi.throwNonFunApp(L[1063],if_helper3016700,[cont_tail_arg3036720]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper3016700)?if_helper3016700.app(cont_tail_arg3036720):R.ffi.throwNonFunApp(L[1063],if_helper3016700,[cont_tail_arg3036720]);
},
"from":L[1063]});
}
++R.GAS;
return $z67186719;
}
};
},{"length":3});
var anf_variant_member3276647 = R.makeMethod(function(self416683) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1063],0,arguments);
}
var anf_arg3156681 = G(self416683,"l",L[1063]);
var $z66736674 = D;
var $f66796680 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg3156681):R.ffi.throwNonFunApp(L[1063],torepr31,[anf_arg3156681]);
};
try {
if(--R.GAS > 0) {
$z66736674 = $f66796680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66796680,
"from":L[1063]});
}
} catch($e66716672) {
if(R.isCont($e66716672)) {
var $ss66756676 = {"from":L[1063],
"go":function(anf_arg3166682) {
return $Hanf_arg29486684(anf_arg3166682,self416683,_plus26,torepr31);
}};
$e66716672.stack[R.EXN_STACKHEIGHT++] = $ss66756676;
}
if(R.isPyretException($e66716672)) {
$e66716672.pyretStack.push(L[1063]);
}
throw $e66716672;
}
var $ret66776678 = $Hanf_arg29486684($z66736674,self416683,_plus26,torepr31);
++R.GAS;
return $ret66776678;
};
},{"length":1});
var anf_variant_member3296648 = R.makeMethod(function(self2896670) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1079],0,arguments);
}
var ann_DASH_check_DASH_temp3286669 = ("a-newtype-bind");
return ann_DASH_check_DASH_temp3286669;
};
},{"length":1});
var anf_variant_member3436649 = R.makeMethod(function(self2906666) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1078],0,arguments);
}
var anf_fun3316665 = G(PP337,"group",L[1077]);
var anf_bracket3326668 = G(self2906666,"name",L[1076]);
var anf_fun3336663 = G(anf_bracket3326668,"tosource",L[1075]);
var $z66556656 = D;
var $f66616662 = function(_) {
return R.isFunction(anf_fun3336663)?anf_fun3336663.app():R.ffi.throwNonFunApp(L[1074],anf_fun3336663,[]);
};
try {
if(--R.GAS > 0) {
$z66556656 = $f66616662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66616662,
"from":L[1074]});
}
} catch($e66536654) {
if(R.isCont($e66536654)) {
var $ss66576658 = {"from":L[1074],
"go":function(anf_arg3346664) {
return $Hanf_arg29566667(anf_arg3346664,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,str_DASH_newtype114378,_plus26);
}};
$e66536654.stack[R.EXN_STACKHEIGHT++] = $ss66576658;
}
if(R.isPyretException($e66536654)) {
$e66536654.pyretStack.push(L[1074]);
}
throw $e66536654;
}
var $ret66596660 = $Hanf_arg29566667($z66556656,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,str_DASH_newtype114378,_plus26);
++R.GAS;
return $ret66596660;
};
},{"length":1});
var anf_assign344432 = (function() {
var $a_DASH_type_DASH_bind_DASH_base66296630 = {"visit":anf_shared2606628,
"_match":anf_variant_member2746634,
"_torepr":anf_variant_member2886635,
"label":anf_variant_member2906636,
"tosource":anf_variant_member2996637};
var $a_DASH_type_DASH_bind_DASH_brands66326633 = {"$brand-a-type-bind6631":true};
$a_DASH_type_DASH_bind_DASH_brands66326633[ATypeBindT57380._brand] = true
var $a_DASH_newtype_DASH_bind_DASH_base66416642 = {"visit":anf_shared2606628,
"_match":anf_variant_member3136646,
"_torepr":anf_variant_member3276647,
"label":anf_variant_member3296648,
"tosource":anf_variant_member3436649};
var $a_DASH_newtype_DASH_bind_DASH_brands66446645 = {"$brand-a-newtype-bind6643":true};
$a_DASH_newtype_DASH_bind_DASH_brands66446645[ATypeBindT57380._brand] = true
return R.makeObject({"ATypeBind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1065],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ATypeBindT57380._brand));
}),
"is-a-type-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1064],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-type-bind6631"));
}),
"a-type-bind":R.makeFunction(function(l2816638,name2826639,ann2836640) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1066],3,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[1067],"A",A244,"Name"),R.getDotAnn(L[1068],"A",A244,"Ann")],[l2816638,name2826639,ann2836640],[L[1069],L[1067],L[1068]],function() {
var dict = R.create($a_DASH_type_DASH_bind_DASH_base66296630);
dict["l"] = l2816638
dict["name"] = name2826639
dict["ann"] = ann2836640
return R.makeBrandedObject(dict,$a_DASH_type_DASH_bind_DASH_brands66326633);
});
}),
"is-a-newtype-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1063],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-newtype-bind6643"));
}),
"a-newtype-bind":R.makeFunction(function(l2866650,name2876651,namet2886652) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1070],3,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[1071],"A",A244,"Name"),R.getDotAnn(L[1072],"A",A244,"Name")],[l2866650,name2876651,namet2886652],[L[1073],L[1071],L[1072]],function() {
var dict = R.create($a_DASH_newtype_DASH_bind_DASH_base66416642);
dict["l"] = l2866650
dict["name"] = name2876651
dict["namet"] = namet2886652
return R.makeBrandedObject(dict,$a_DASH_newtype_DASH_bind_DASH_brands66446645);
});
})});
})();
ATypeBind17136431.$var = anf_assign344432;
var anf_assign345434 = G(ATypeBind17136431.$var,"ATypeBind",L[1065]);
ATypeBind137433.$var = anf_assign345434;
var anf_assign346436 = G(ATypeBind17136431.$var,"ATypeBind",L[1065]);
is_DASH_ATypeBind138435.$var = anf_assign346436;
var anf_assign347438 = G(ATypeBind17136431.$var,"is-a-type-bind",L[1064]);
is_DASH_a_DASH_type_DASH_bind139437.$var = anf_assign347438;
var anf_assign348440 = G(ATypeBind17136431.$var,"a-type-bind",L[1064]);
a_DASH_type_DASH_bind140439.$var = anf_assign348440;
var anf_assign349442 = G(ATypeBind17136431.$var,"is-a-newtype-bind",L[1063]);
is_DASH_a_DASH_newtype_DASH_bind141441.$var = anf_assign349442;
var anf_assign350444 = G(ATypeBind17136431.$var,"a-newtype-bind",L[1063]);
a_DASH_newtype_DASH_bind142443.$var = anf_assign350444;
var anf_shared3585922 = R.makeMethod(function(self3406627) {
return function(visitor3416610) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1058],1,arguments);
}
var anf_fun3526609 = G(self3406627,"_match",L[1062]);
var anf_arg3576611 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1059],0,arguments);
}
var anf_fun3546624 = G(self3406627,"label",L[1061]);
var $z66166617 = D;
var $f66226623 = function(_) {
return R.isFunction(anf_fun3546624)?anf_fun3546624.app():R.ffi.throwNonFunApp(L[1060],anf_fun3546624,[]);
};
try {
if(--R.GAS > 0) {
$z66166617 = $f66226623();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66226623,
"from":L[1060]});
}
} catch($e66146615) {
if(R.isCont($e66146615)) {
var $ss66186619 = {"from":L[1060],
"go":function(anf_arg3556625) {
return $Hanf_arg29596626(anf_arg3556625,_plus26,raise30);
}};
$e66146615.stack[R.EXN_STACKHEIGHT++] = $ss66186619;
}
if(R.isPyretException($e66146615)) {
$e66146615.pyretStack.push(L[1060]);
}
throw $e66146615;
}
var $ret66206621 = $Hanf_arg29596626($z66166617,_plus26,raise30);
++R.GAS;
return $ret66206621;
});
var $z66016602 = D;
var $f66076608 = function(_) {
return R.isFunction(anf_fun3526609)?anf_fun3526609.app(visitor3416610,anf_arg3576611):R.ffi.throwNonFunApp(L[1058],anf_fun3526609,[visitor3416610,anf_arg3576611]);
};
try {
if(--R.GAS > 0) {
$z66016602 = $f66076608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66076608,
"from":L[1058]});
}
} catch($e65996600) {
if(R.isCont($e65996600)) {
var $ss66036604 = {"from":L[1058],
"go":function(ann_DASH_check_DASH_temp3516612) {
return $Hann_DASH_check_DASH_temp29606613(ann_DASH_check_DASH_temp3516612);
}};
$e65996600.stack[R.EXN_STACKHEIGHT++] = $ss66036604;
}
if(R.isPyretException($e65996600)) {
$e65996600.pyretStack.push(L[1058]);
}
throw $e65996600;
}
var $ret66056606 = $Hann_DASH_check_DASH_temp29606613($z66016602);
++R.GAS;
return $ret66056606;
};
},{"length":2});
var anf_variant_member3725928 = R.makeMethod(function(self446577) {
return function(cases_DASH_funs456578,else_DASH_clause466589) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[941],2,arguments);
}
var if_DASH_486592 = R.hasField(cases_DASH_funs456578,("a-type-let"));
var if_helper3606575 = R.makeFunction(function(if_helper_arg3616597) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[941],1,arguments);
}
var ann_DASH_check_DASH_temp3596598 = if_helper_arg3616597;
return ann_DASH_check_DASH_temp3596598;
});
var anf_if3646596 = R.isBoolean(if_DASH_486592);
if(R.isPyretTrue(anf_if3646596)) {
if(R.isPyretTrue(if_DASH_486592)) {
var call_DASH_a_DASH_type_DASH_let436570 = G(cases_DASH_funs456578,"a-type-let",L[941]);
var anf_arg3676571 = G(self446577,"l",L[1057]);
var anf_arg3686572 = G(self446577,"bind",L[1056]);
var anf_arg3696573 = G(self446577,"body",L[1055]);
var $z65626563 = D;
var $f65686569 = function(_) {
return R.isFunction(call_DASH_a_DASH_type_DASH_let436570)?call_DASH_a_DASH_type_DASH_let436570.app(anf_arg3676571,anf_arg3686572,anf_arg3696573):R.ffi.throwNonFunApp(L[941],call_DASH_a_DASH_type_DASH_let436570,[anf_arg3676571,anf_arg3686572,anf_arg3696573]);
};
try {
if(--R.GAS > 0) {
$z65626563 = $f65686569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65686569,
"from":L[941]});
}
} catch($e65606561) {
if(R.isCont($e65606561)) {
var $ss65646565 = {"from":L[941],
"go":function(cont_tail_arg3706574) {
return $Hcont_tail_arg29616576(cont_tail_arg3706574,if_helper3606575);
}};
$e65606561.stack[R.EXN_STACKHEIGHT++] = $ss65646565;
}
if(R.isPyretException($e65606561)) {
$e65606561.pyretStack.push(L[941]);
}
throw $e65606561;
}
var $ret65666567 = $Hcont_tail_arg29616576($z65626563,if_helper3606575);
++R.GAS;
return $ret65666567;
} else {
var $z65816582 = D;
var $f65876588 = function(_) {
return R.isFunction(else_DASH_clause466589)?else_DASH_clause466589.app():R.ffi.throwNonFunApp(L[941],else_DASH_clause466589,[]);
};
try {
if(--R.GAS > 0) {
$z65816582 = $f65876588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65876588,
"from":L[941]});
}
} catch($e65796580) {
if(R.isCont($e65796580)) {
var $ss65836584 = {"from":L[941],
"go":function(cont_tail_arg3656590) {
return $Hcont_tail_arg29626591(cont_tail_arg3656590,if_helper3606575);
}};
$e65796580.stack[R.EXN_STACKHEIGHT++] = $ss65836584;
}
if(R.isPyretException($e65796580)) {
$e65796580.pyretStack.push(L[941]);
}
throw $e65796580;
}
var $ret65856586 = $Hcont_tail_arg29626591($z65816582,if_helper3606575);
++R.GAS;
return $ret65856586;
}
} else {
var cont_tail_arg3626595 = R.throwNonBooleanCondition(L[941],("if"),if_DASH_486592);
if(--R.GAS > 0) {
$z65936594 = R.isFunction(if_helper3606575)?if_helper3606575.app(cont_tail_arg3626595):R.ffi.throwNonFunApp(L[941],if_helper3606575,[cont_tail_arg3626595]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper3606575)?if_helper3606575.app(cont_tail_arg3626595):R.ffi.throwNonFunApp(L[941],if_helper3606575,[cont_tail_arg3626595]);
},
"from":L[941]});
}
++R.GAS;
return $z65936594;
}
};
},{"length":3});
var anf_variant_member3865929 = R.makeMethod(function(self476558) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[941],0,arguments);
}
var anf_arg3746556 = G(self476558,"l",L[941]);
var $z65486549 = D;
var $f65546555 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg3746556):R.ffi.throwNonFunApp(L[941],torepr31,[anf_arg3746556]);
};
try {
if(--R.GAS > 0) {
$z65486549 = $f65546555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65546555,
"from":L[941]});
}
} catch($e65466547) {
if(R.isCont($e65466547)) {
var $ss65506551 = {"from":L[941],
"go":function(anf_arg3756557) {
return $Hanf_arg29726559(anf_arg3756557,self476558,_plus26,torepr31);
}};
$e65466547.stack[R.EXN_STACKHEIGHT++] = $ss65506551;
}
if(R.isPyretException($e65466547)) {
$e65466547.pyretStack.push(L[941]);
}
throw $e65466547;
}
var $ret65526553 = $Hanf_arg29726559($z65486549,self476558,_plus26,torepr31);
++R.GAS;
return $ret65526553;
};
},{"length":1});
var anf_variant_member3885930 = R.makeMethod(function(self2966545) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1054],0,arguments);
}
var ann_DASH_check_DASH_temp3876544 = ("a-type-let");
return ann_DASH_check_DASH_temp3876544;
};
},{"length":1});
var anf_variant_member4035931 = R.makeMethod(function(self2976541) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1053],0,arguments);
}
var anf_fun3906538 = G(PP337,"soft-surround",L[1052]);
var anf_fun3916539 = G(PP337,"group",L[1051]);
var anf_fun3926540 = G(PP337,"nest",L[1050]);
var anf_bracket3936543 = G(self2976541,"bind",L[1049]);
var anf_fun3946536 = G(anf_bracket3936543,"tosource",L[1048]);
var $z65286529 = D;
var $f65346535 = function(_) {
return R.isFunction(anf_fun3946536)?anf_fun3946536.app():R.ffi.throwNonFunApp(L[1047],anf_fun3946536,[]);
};
try {
if(--R.GAS > 0) {
$z65286529 = $f65346535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65346535,
"from":L[1047]});
}
} catch($e65266527) {
if(R.isCont($e65266527)) {
var $ss65306531 = {"from":L[1047],
"go":function(anf_arg3956537) {
return $Hanf_arg29796542(anf_arg3956537,INDENT9187,anf_fun3906538,anf_fun3916539,anf_fun3926540,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26);
}};
$e65266527.stack[R.EXN_STACKHEIGHT++] = $ss65306531;
}
if(R.isPyretException($e65266527)) {
$e65266527.pyretStack.push(L[1047]);
}
throw $e65266527;
}
var $ret65326533 = $Hanf_arg29796542($z65286529,INDENT9187,anf_fun3906538,anf_fun3916539,anf_fun3926540,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26);
++R.GAS;
return $ret65326533;
};
},{"length":1});
var anf_variant_member4185940 = R.makeMethod(function(self506504) {
return function(cases_DASH_funs516505,else_DASH_clause526516) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[940],2,arguments);
}
var if_DASH_546519 = R.hasField(cases_DASH_funs516505,("a-let"));
var if_helper4056502 = R.makeFunction(function(if_helper_arg4066524) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[940],1,arguments);
}
var ann_DASH_check_DASH_temp4046525 = if_helper_arg4066524;
return ann_DASH_check_DASH_temp4046525;
});
var anf_if4096523 = R.isBoolean(if_DASH_546519);
if(R.isPyretTrue(anf_if4096523)) {
if(R.isPyretTrue(if_DASH_546519)) {
var call_DASH_a_DASH_let496496 = G(cases_DASH_funs516505,"a-let",L[940]);
var anf_arg4126497 = G(self506504,"l",L[1046]);
var anf_arg4136498 = G(self506504,"bind",L[1045]);
var anf_arg4146499 = G(self506504,"e",L[1044]);
var anf_arg4156500 = G(self506504,"body",L[1043]);
var $z64886489 = D;
var $f64946495 = function(_) {
return R.isFunction(call_DASH_a_DASH_let496496)?call_DASH_a_DASH_let496496.app(anf_arg4126497,anf_arg4136498,anf_arg4146499,anf_arg4156500):R.ffi.throwNonFunApp(L[940],call_DASH_a_DASH_let496496,[anf_arg4126497,anf_arg4136498,anf_arg4146499,anf_arg4156500]);
};
try {
if(--R.GAS > 0) {
$z64886489 = $f64946495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64946495,
"from":L[940]});
}
} catch($e64866487) {
if(R.isCont($e64866487)) {
var $ss64906491 = {"from":L[940],
"go":function(cont_tail_arg4166501) {
return $Hcont_tail_arg29806503(cont_tail_arg4166501,if_helper4056502);
}};
$e64866487.stack[R.EXN_STACKHEIGHT++] = $ss64906491;
}
if(R.isPyretException($e64866487)) {
$e64866487.pyretStack.push(L[940]);
}
throw $e64866487;
}
var $ret64926493 = $Hcont_tail_arg29806503($z64886489,if_helper4056502);
++R.GAS;
return $ret64926493;
} else {
var $z65086509 = D;
var $f65146515 = function(_) {
return R.isFunction(else_DASH_clause526516)?else_DASH_clause526516.app():R.ffi.throwNonFunApp(L[940],else_DASH_clause526516,[]);
};
try {
if(--R.GAS > 0) {
$z65086509 = $f65146515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65146515,
"from":L[940]});
}
} catch($e65066507) {
if(R.isCont($e65066507)) {
var $ss65106511 = {"from":L[940],
"go":function(cont_tail_arg4106517) {
return $Hcont_tail_arg29816518(cont_tail_arg4106517,if_helper4056502);
}};
$e65066507.stack[R.EXN_STACKHEIGHT++] = $ss65106511;
}
if(R.isPyretException($e65066507)) {
$e65066507.pyretStack.push(L[940]);
}
throw $e65066507;
}
var $ret65126513 = $Hcont_tail_arg29816518($z65086509,if_helper4056502);
++R.GAS;
return $ret65126513;
}
} else {
var cont_tail_arg4076522 = R.throwNonBooleanCondition(L[940],("if"),if_DASH_546519);
if(--R.GAS > 0) {
$z65206521 = R.isFunction(if_helper4056502)?if_helper4056502.app(cont_tail_arg4076522):R.ffi.throwNonFunApp(L[940],if_helper4056502,[cont_tail_arg4076522]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper4056502)?if_helper4056502.app(cont_tail_arg4076522):R.ffi.throwNonFunApp(L[940],if_helper4056502,[cont_tail_arg4076522]);
},
"from":L[940]});
}
++R.GAS;
return $z65206521;
}
};
},{"length":3});
var anf_variant_member4365941 = R.makeMethod(function(self536484) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[940],0,arguments);
}
var anf_arg4206482 = G(self536484,"l",L[940]);
var $z64746475 = D;
var $f64806481 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg4206482):R.ffi.throwNonFunApp(L[940],torepr31,[anf_arg4206482]);
};
try {
if(--R.GAS > 0) {
$z64746475 = $f64806481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64806481,
"from":L[940]});
}
} catch($e64726473) {
if(R.isCont($e64726473)) {
var $ss64766477 = {"from":L[940],
"go":function(anf_arg4216483) {
return $Hanf_arg29946485(anf_arg4216483,self536484,_plus26,torepr31);
}};
$e64726473.stack[R.EXN_STACKHEIGHT++] = $ss64766477;
}
if(R.isPyretException($e64726473)) {
$e64726473.pyretStack.push(L[940]);
}
throw $e64726473;
}
var $ret64786479 = $Hanf_arg29946485($z64746475,self536484,_plus26,torepr31);
++R.GAS;
return $ret64786479;
};
},{"length":1});
var anf_variant_member4385942 = R.makeMethod(function(self3026471) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1042],0,arguments);
}
var ann_DASH_check_DASH_temp4376470 = ("a-let");
return ann_DASH_check_DASH_temp4376470;
};
},{"length":1});
var anf_variant_member4595943 = R.makeMethod(function(self3036467) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1041],0,arguments);
}
var anf_fun4406464 = G(PP337,"soft-surround",L[1040]);
var anf_fun4416465 = G(PP337,"group",L[1039]);
var anf_fun4426466 = G(PP337,"nest",L[1038]);
var anf_bracket4436469 = G(self3036467,"bind",L[1037]);
var anf_fun4446462 = G(anf_bracket4436469,"tosource",L[1036]);
var $z64546455 = D;
var $f64606461 = function(_) {
return R.isFunction(anf_fun4446462)?anf_fun4446462.app():R.ffi.throwNonFunApp(L[1035],anf_fun4446462,[]);
};
try {
if(--R.GAS > 0) {
$z64546455 = $f64606461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64606461,
"from":L[1035]});
}
} catch($e64526453) {
if(R.isCont($e64526453)) {
var $ss64566457 = {"from":L[1035],
"go":function(anf_arg4456463) {
return $Hanf_arg30056468(anf_arg4456463,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,break_DASH_one9262,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,str_DASH_spaceequal110326,_plus26);
}};
$e64526453.stack[R.EXN_STACKHEIGHT++] = $ss64566457;
}
if(R.isPyretException($e64526453)) {
$e64526453.pyretStack.push(L[1035]);
}
throw $e64526453;
}
var $ret64586459 = $Hanf_arg30056468($z64546455,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,break_DASH_one9262,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,str_DASH_spaceequal110326,_plus26);
++R.GAS;
return $ret64586459;
};
},{"length":1});
var anf_variant_member4745953 = R.makeMethod(function(self566430) {
return function(cases_DASH_funs576431,else_DASH_clause586442) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[939],2,arguments);
}
var if_DASH_606445 = R.hasField(cases_DASH_funs576431,("a-var"));
var if_helper4616428 = R.makeFunction(function(if_helper_arg4626450) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[939],1,arguments);
}
var ann_DASH_check_DASH_temp4606451 = if_helper_arg4626450;
return ann_DASH_check_DASH_temp4606451;
});
var anf_if4656449 = R.isBoolean(if_DASH_606445);
if(R.isPyretTrue(anf_if4656449)) {
if(R.isPyretTrue(if_DASH_606445)) {
var call_DASH_a_DASH_var556422 = G(cases_DASH_funs576431,"a-var",L[939]);
var anf_arg4686423 = G(self566430,"l",L[1034]);
var anf_arg4696424 = G(self566430,"bind",L[1033]);
var anf_arg4706425 = G(self566430,"e",L[1032]);
var anf_arg4716426 = G(self566430,"body",L[1031]);
var $z64146415 = D;
var $f64206421 = function(_) {
return R.isFunction(call_DASH_a_DASH_var556422)?call_DASH_a_DASH_var556422.app(anf_arg4686423,anf_arg4696424,anf_arg4706425,anf_arg4716426):R.ffi.throwNonFunApp(L[939],call_DASH_a_DASH_var556422,[anf_arg4686423,anf_arg4696424,anf_arg4706425,anf_arg4716426]);
};
try {
if(--R.GAS > 0) {
$z64146415 = $f64206421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64206421,
"from":L[939]});
}
} catch($e64126413) {
if(R.isCont($e64126413)) {
var $ss64166417 = {"from":L[939],
"go":function(cont_tail_arg4726427) {
return $Hcont_tail_arg30066429(cont_tail_arg4726427,if_helper4616428);
}};
$e64126413.stack[R.EXN_STACKHEIGHT++] = $ss64166417;
}
if(R.isPyretException($e64126413)) {
$e64126413.pyretStack.push(L[939]);
}
throw $e64126413;
}
var $ret64186419 = $Hcont_tail_arg30066429($z64146415,if_helper4616428);
++R.GAS;
return $ret64186419;
} else {
var $z64346435 = D;
var $f64406441 = function(_) {
return R.isFunction(else_DASH_clause586442)?else_DASH_clause586442.app():R.ffi.throwNonFunApp(L[939],else_DASH_clause586442,[]);
};
try {
if(--R.GAS > 0) {
$z64346435 = $f64406441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64406441,
"from":L[939]});
}
} catch($e64326433) {
if(R.isCont($e64326433)) {
var $ss64366437 = {"from":L[939],
"go":function(cont_tail_arg4666443) {
return $Hcont_tail_arg30076444(cont_tail_arg4666443,if_helper4616428);
}};
$e64326433.stack[R.EXN_STACKHEIGHT++] = $ss64366437;
}
if(R.isPyretException($e64326433)) {
$e64326433.pyretStack.push(L[939]);
}
throw $e64326433;
}
var $ret64386439 = $Hcont_tail_arg30076444($z64346435,if_helper4616428);
++R.GAS;
return $ret64386439;
}
} else {
var cont_tail_arg4636448 = R.throwNonBooleanCondition(L[939],("if"),if_DASH_606445);
if(--R.GAS > 0) {
$z64466447 = R.isFunction(if_helper4616428)?if_helper4616428.app(cont_tail_arg4636448):R.ffi.throwNonFunApp(L[939],if_helper4616428,[cont_tail_arg4636448]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper4616428)?if_helper4616428.app(cont_tail_arg4636448):R.ffi.throwNonFunApp(L[939],if_helper4616428,[cont_tail_arg4636448]);
},
"from":L[939]});
}
++R.GAS;
return $z64466447;
}
};
},{"length":3});
var anf_variant_member4925954 = R.makeMethod(function(self596410) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[939],0,arguments);
}
var anf_arg4766408 = G(self596410,"l",L[939]);
var $z64006401 = D;
var $f64066407 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg4766408):R.ffi.throwNonFunApp(L[939],torepr31,[anf_arg4766408]);
};
try {
if(--R.GAS > 0) {
$z64006401 = $f64066407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64066407,
"from":L[939]});
}
} catch($e63986399) {
if(R.isCont($e63986399)) {
var $ss64026403 = {"from":L[939],
"go":function(anf_arg4776409) {
return $Hanf_arg30206411(anf_arg4776409,self596410,_plus26,torepr31);
}};
$e63986399.stack[R.EXN_STACKHEIGHT++] = $ss64026403;
}
if(R.isPyretException($e63986399)) {
$e63986399.pyretStack.push(L[939]);
}
throw $e63986399;
}
var $ret64046405 = $Hanf_arg30206411($z64006401,self596410,_plus26,torepr31);
++R.GAS;
return $ret64046405;
};
},{"length":1});
var anf_variant_member4945955 = R.makeMethod(function(self3086397) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1030],0,arguments);
}
var ann_DASH_check_DASH_temp4936396 = ("a-var");
return ann_DASH_check_DASH_temp4936396;
};
},{"length":1});
var anf_variant_member5155956 = R.makeMethod(function(self3096393) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1029],0,arguments);
}
var anf_fun4966390 = G(PP337,"soft-surround",L[1028]);
var anf_fun4976391 = G(PP337,"group",L[1027]);
var anf_fun4986392 = G(PP337,"nest",L[1026]);
var anf_bracket4996395 = G(self3096393,"bind",L[1025]);
var anf_fun5006388 = G(anf_bracket4996395,"tosource",L[1024]);
var $z63806381 = D;
var $f63866387 = function(_) {
return R.isFunction(anf_fun5006388)?anf_fun5006388.app():R.ffi.throwNonFunApp(L[1023],anf_fun5006388,[]);
};
try {
if(--R.GAS > 0) {
$z63806381 = $f63866387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63866387,
"from":L[1023]});
}
} catch($e63786379) {
if(R.isCont($e63786379)) {
var $ss63826383 = {"from":L[1023],
"go":function(anf_arg5016389) {
return $Hanf_arg30316394(anf_arg5016389,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,break_DASH_one9262,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_spaceequal110326,str_DASH_var104248,_plus26);
}};
$e63786379.stack[R.EXN_STACKHEIGHT++] = $ss63826383;
}
if(R.isPyretException($e63786379)) {
$e63786379.pyretStack.push(L[1023]);
}
throw $e63786379;
}
var $ret63846385 = $Hanf_arg30316394($z63806381,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,break_DASH_one9262,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_spaceequal110326,str_DASH_var104248,_plus26);
++R.GAS;
return $ret63846385;
};
},{"length":1});
var anf_variant_member5295966 = R.makeMethod(function(self626356) {
return function(cases_DASH_funs636357,else_DASH_clause646368) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[938],2,arguments);
}
var if_DASH_666371 = R.hasField(cases_DASH_funs636357,("a-seq"));
var if_helper5176354 = R.makeFunction(function(if_helper_arg5186376) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[938],1,arguments);
}
var ann_DASH_check_DASH_temp5166377 = if_helper_arg5186376;
return ann_DASH_check_DASH_temp5166377;
});
var anf_if5216375 = R.isBoolean(if_DASH_666371);
if(R.isPyretTrue(anf_if5216375)) {
if(R.isPyretTrue(if_DASH_666371)) {
var call_DASH_a_DASH_seq616349 = G(cases_DASH_funs636357,"a-seq",L[938]);
var anf_arg5246350 = G(self626356,"l",L[1022]);
var anf_arg5256351 = G(self626356,"e1",L[1021]);
var anf_arg5266352 = G(self626356,"e2",L[1020]);
var $z63416342 = D;
var $f63476348 = function(_) {
return R.isFunction(call_DASH_a_DASH_seq616349)?call_DASH_a_DASH_seq616349.app(anf_arg5246350,anf_arg5256351,anf_arg5266352):R.ffi.throwNonFunApp(L[938],call_DASH_a_DASH_seq616349,[anf_arg5246350,anf_arg5256351,anf_arg5266352]);
};
try {
if(--R.GAS > 0) {
$z63416342 = $f63476348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63476348,
"from":L[938]});
}
} catch($e63396340) {
if(R.isCont($e63396340)) {
var $ss63436344 = {"from":L[938],
"go":function(cont_tail_arg5276353) {
return $Hcont_tail_arg30326355(cont_tail_arg5276353,if_helper5176354);
}};
$e63396340.stack[R.EXN_STACKHEIGHT++] = $ss63436344;
}
if(R.isPyretException($e63396340)) {
$e63396340.pyretStack.push(L[938]);
}
throw $e63396340;
}
var $ret63456346 = $Hcont_tail_arg30326355($z63416342,if_helper5176354);
++R.GAS;
return $ret63456346;
} else {
var $z63606361 = D;
var $f63666367 = function(_) {
return R.isFunction(else_DASH_clause646368)?else_DASH_clause646368.app():R.ffi.throwNonFunApp(L[938],else_DASH_clause646368,[]);
};
try {
if(--R.GAS > 0) {
$z63606361 = $f63666367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63666367,
"from":L[938]});
}
} catch($e63586359) {
if(R.isCont($e63586359)) {
var $ss63626363 = {"from":L[938],
"go":function(cont_tail_arg5226369) {
return $Hcont_tail_arg30336370(cont_tail_arg5226369,if_helper5176354);
}};
$e63586359.stack[R.EXN_STACKHEIGHT++] = $ss63626363;
}
if(R.isPyretException($e63586359)) {
$e63586359.pyretStack.push(L[938]);
}
throw $e63586359;
}
var $ret63646365 = $Hcont_tail_arg30336370($z63606361,if_helper5176354);
++R.GAS;
return $ret63646365;
}
} else {
var cont_tail_arg5196374 = R.throwNonBooleanCondition(L[938],("if"),if_DASH_666371);
if(--R.GAS > 0) {
$z63726373 = R.isFunction(if_helper5176354)?if_helper5176354.app(cont_tail_arg5196374):R.ffi.throwNonFunApp(L[938],if_helper5176354,[cont_tail_arg5196374]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper5176354)?if_helper5176354.app(cont_tail_arg5196374):R.ffi.throwNonFunApp(L[938],if_helper5176354,[cont_tail_arg5196374]);
},
"from":L[938]});
}
++R.GAS;
return $z63726373;
}
};
},{"length":3});
var anf_variant_member5435967 = R.makeMethod(function(self656337) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[938],0,arguments);
}
var anf_arg5316335 = G(self656337,"l",L[938]);
var $z63276328 = D;
var $f63336334 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg5316335):R.ffi.throwNonFunApp(L[938],torepr31,[anf_arg5316335]);
};
try {
if(--R.GAS > 0) {
$z63276328 = $f63336334();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63336334,
"from":L[938]});
}
} catch($e63256326) {
if(R.isCont($e63256326)) {
var $ss63296330 = {"from":L[938],
"go":function(anf_arg5326336) {
return $Hanf_arg30436338(anf_arg5326336,self656337,_plus26,torepr31);
}};
$e63256326.stack[R.EXN_STACKHEIGHT++] = $ss63296330;
}
if(R.isPyretException($e63256326)) {
$e63256326.pyretStack.push(L[938]);
}
throw $e63256326;
}
var $ret63316332 = $Hanf_arg30436338($z63276328,self656337,_plus26,torepr31);
++R.GAS;
return $ret63316332;
};
},{"length":1});
var anf_variant_member5455968 = R.makeMethod(function(self3136324) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1019],0,arguments);
}
var ann_DASH_check_DASH_temp5446323 = ("a-seq");
return ann_DASH_check_DASH_temp5446323;
};
},{"length":1});
var anf_variant_member5555969 = R.makeMethod(function(self3146320) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1018],0,arguments);
}
var anf_bracket5476322 = G(self3146320,"e1",L[1017]);
var anf_fun5486318 = G(anf_bracket5476322,"tosource",L[1016]);
var $z63106311 = D;
var $f63166317 = function(_) {
return R.isFunction(anf_fun5486318)?anf_fun5486318.app():R.ffi.throwNonFunApp(L[1015],anf_fun5486318,[]);
};
try {
if(--R.GAS > 0) {
$z63106311 = $f63166317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63166317,
"from":L[1015]});
}
} catch($e63086309) {
if(R.isCont($e63086309)) {
var $ss63126313 = {"from":L[1015],
"go":function(anf_arg5496319) {
return $Hanf_arg30476321(anf_arg5496319,PP337,self3146320,_plus26);
}};
$e63086309.stack[R.EXN_STACKHEIGHT++] = $ss63126313;
}
if(R.isPyretException($e63086309)) {
$e63086309.pyretStack.push(L[1015]);
}
throw $e63086309;
}
var $ret63146315 = $Hanf_arg30476321($z63106311,PP337,self3146320,_plus26);
++R.GAS;
return $ret63146315;
};
},{"length":1});
var anf_variant_member5695978 = R.makeMethod(function(self686286) {
return function(cases_DASH_funs696287,else_DASH_clause706298) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[937],2,arguments);
}
var if_DASH_726301 = R.hasField(cases_DASH_funs696287,("a-tail-app"));
var if_helper5576284 = R.makeFunction(function(if_helper_arg5586306) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[937],1,arguments);
}
var ann_DASH_check_DASH_temp5566307 = if_helper_arg5586306;
return ann_DASH_check_DASH_temp5566307;
});
var anf_if5616305 = R.isBoolean(if_DASH_726301);
if(R.isPyretTrue(anf_if5616305)) {
if(R.isPyretTrue(if_DASH_726301)) {
var call_DASH_a_DASH_tail_DASH_app676279 = G(cases_DASH_funs696287,"a-tail-app",L[937]);
var anf_arg5646280 = G(self686286,"l",L[1014]);
var anf_arg5656281 = G(self686286,"f",L[1013]);
var anf_arg5666282 = G(self686286,"args",L[1012]);
var $z62716272 = D;
var $f62776278 = function(_) {
return R.isFunction(call_DASH_a_DASH_tail_DASH_app676279)?call_DASH_a_DASH_tail_DASH_app676279.app(anf_arg5646280,anf_arg5656281,anf_arg5666282):R.ffi.throwNonFunApp(L[937],call_DASH_a_DASH_tail_DASH_app676279,[anf_arg5646280,anf_arg5656281,anf_arg5666282]);
};
try {
if(--R.GAS > 0) {
$z62716272 = $f62776278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62776278,
"from":L[937]});
}
} catch($e62696270) {
if(R.isCont($e62696270)) {
var $ss62736274 = {"from":L[937],
"go":function(cont_tail_arg5676283) {
return $Hcont_tail_arg30486285(cont_tail_arg5676283,if_helper5576284);
}};
$e62696270.stack[R.EXN_STACKHEIGHT++] = $ss62736274;
}
if(R.isPyretException($e62696270)) {
$e62696270.pyretStack.push(L[937]);
}
throw $e62696270;
}
var $ret62756276 = $Hcont_tail_arg30486285($z62716272,if_helper5576284);
++R.GAS;
return $ret62756276;
} else {
var $z62906291 = D;
var $f62966297 = function(_) {
return R.isFunction(else_DASH_clause706298)?else_DASH_clause706298.app():R.ffi.throwNonFunApp(L[937],else_DASH_clause706298,[]);
};
try {
if(--R.GAS > 0) {
$z62906291 = $f62966297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62966297,
"from":L[937]});
}
} catch($e62886289) {
if(R.isCont($e62886289)) {
var $ss62926293 = {"from":L[937],
"go":function(cont_tail_arg5626299) {
return $Hcont_tail_arg30496300(cont_tail_arg5626299,if_helper5576284);
}};
$e62886289.stack[R.EXN_STACKHEIGHT++] = $ss62926293;
}
if(R.isPyretException($e62886289)) {
$e62886289.pyretStack.push(L[937]);
}
throw $e62886289;
}
var $ret62946295 = $Hcont_tail_arg30496300($z62906291,if_helper5576284);
++R.GAS;
return $ret62946295;
}
} else {
var cont_tail_arg5596304 = R.throwNonBooleanCondition(L[937],("if"),if_DASH_726301);
if(--R.GAS > 0) {
$z63026303 = R.isFunction(if_helper5576284)?if_helper5576284.app(cont_tail_arg5596304):R.ffi.throwNonFunApp(L[937],if_helper5576284,[cont_tail_arg5596304]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper5576284)?if_helper5576284.app(cont_tail_arg5596304):R.ffi.throwNonFunApp(L[937],if_helper5576284,[cont_tail_arg5596304]);
},
"from":L[937]});
}
++R.GAS;
return $z63026303;
}
};
},{"length":3});
var anf_variant_member5835979 = R.makeMethod(function(self716267) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[937],0,arguments);
}
var anf_arg5716265 = G(self716267,"l",L[937]);
var $z62576258 = D;
var $f62636264 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg5716265):R.ffi.throwNonFunApp(L[937],torepr31,[anf_arg5716265]);
};
try {
if(--R.GAS > 0) {
$z62576258 = $f62636264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62636264,
"from":L[937]});
}
} catch($e62556256) {
if(R.isCont($e62556256)) {
var $ss62596260 = {"from":L[937],
"go":function(anf_arg5726266) {
return $Hanf_arg30596268(anf_arg5726266,self716267,_plus26,torepr31);
}};
$e62556256.stack[R.EXN_STACKHEIGHT++] = $ss62596260;
}
if(R.isPyretException($e62556256)) {
$e62556256.pyretStack.push(L[937]);
}
throw $e62556256;
}
var $ret62616262 = $Hanf_arg30596268($z62576258,self716267,_plus26,torepr31);
++R.GAS;
return $ret62616262;
};
},{"length":1});
var anf_variant_member5855980 = R.makeMethod(function(self3186254) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1011],0,arguments);
}
var ann_DASH_check_DASH_temp5846253 = ("a-tail-app");
return ann_DASH_check_DASH_temp5846253;
};
},{"length":1});
var anf_variant_member6055981 = R.makeMethod(function(self3196250) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1010],0,arguments);
}
var anf_fun5876249 = G(PP337,"group",L[1009]);
var anf_bracket5886252 = G(self3196250,"f",L[1008]);
var anf_fun5896247 = G(anf_bracket5886252,"tosource",L[1007]);
var $z62396240 = D;
var $f62456246 = function(_) {
return R.isFunction(anf_fun5896247)?anf_fun5896247.app():R.ffi.throwNonFunApp(L[1006],anf_fun5896247,[]);
};
try {
if(--R.GAS > 0) {
$z62396240 = $f62456246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62456246,
"from":L[1006]});
}
} catch($e62376238) {
if(R.isCont($e62376238)) {
var $ss62416242 = {"from":L[1006],
"go":function(anf_arg5906248) {
return $Hanf_arg30676251(anf_arg5906248,INDENT9187,PP337,anf_fun5876249,self3196250,_plus26);
}};
$e62376238.stack[R.EXN_STACKHEIGHT++] = $ss62416242;
}
if(R.isPyretException($e62376238)) {
$e62376238.pyretStack.push(L[1006]);
}
throw $e62376238;
}
var $ret62436244 = $Hanf_arg30676251($z62396240,INDENT9187,PP337,anf_fun5876249,self3196250,_plus26);
++R.GAS;
return $ret62436244;
};
},{"length":1});
var anf_variant_member6225990 = R.makeMethod(function(self746215) {
return function(cases_DASH_funs756216,else_DASH_clause766227) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[936],2,arguments);
}
var if_DASH_786230 = R.hasField(cases_DASH_funs756216,("a-split-app"));
var if_helper6076213 = R.makeFunction(function(if_helper_arg6086235) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[936],1,arguments);
}
var ann_DASH_check_DASH_temp6066236 = if_helper_arg6086235;
return ann_DASH_check_DASH_temp6066236;
});
var anf_if6116234 = R.isBoolean(if_DASH_786230);
if(R.isPyretTrue(anf_if6116234)) {
if(R.isPyretTrue(if_DASH_786230)) {
var call_DASH_a_DASH_split_DASH_app736205 = G(cases_DASH_funs756216,"a-split-app",L[936]);
var anf_arg6146206 = G(self746215,"l",L[1005]);
var anf_arg6156207 = G(self746215,"is-var",L[1004]);
var anf_arg6166208 = G(self746215,"f",L[1003]);
var anf_arg6176209 = G(self746215,"args",L[1002]);
var anf_arg6186210 = G(self746215,"helper",L[1001]);
var anf_arg6196211 = G(self746215,"helper-args",L[1000]);
var $z61976198 = D;
var $f62036204 = function(_) {
return R.isFunction(call_DASH_a_DASH_split_DASH_app736205)?call_DASH_a_DASH_split_DASH_app736205.app(anf_arg6146206,anf_arg6156207,anf_arg6166208,anf_arg6176209,anf_arg6186210,anf_arg6196211):R.ffi.throwNonFunApp(L[936],call_DASH_a_DASH_split_DASH_app736205,[anf_arg6146206,anf_arg6156207,anf_arg6166208,anf_arg6176209,anf_arg6186210,anf_arg6196211]);
};
try {
if(--R.GAS > 0) {
$z61976198 = $f62036204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62036204,
"from":L[936]});
}
} catch($e61956196) {
if(R.isCont($e61956196)) {
var $ss61996200 = {"from":L[936],
"go":function(cont_tail_arg6206212) {
return $Hcont_tail_arg30686214(cont_tail_arg6206212,if_helper6076213);
}};
$e61956196.stack[R.EXN_STACKHEIGHT++] = $ss61996200;
}
if(R.isPyretException($e61956196)) {
$e61956196.pyretStack.push(L[936]);
}
throw $e61956196;
}
var $ret62016202 = $Hcont_tail_arg30686214($z61976198,if_helper6076213);
++R.GAS;
return $ret62016202;
} else {
var $z62196220 = D;
var $f62256226 = function(_) {
return R.isFunction(else_DASH_clause766227)?else_DASH_clause766227.app():R.ffi.throwNonFunApp(L[936],else_DASH_clause766227,[]);
};
try {
if(--R.GAS > 0) {
$z62196220 = $f62256226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62256226,
"from":L[936]});
}
} catch($e62176218) {
if(R.isCont($e62176218)) {
var $ss62216222 = {"from":L[936],
"go":function(cont_tail_arg6126228) {
return $Hcont_tail_arg30696229(cont_tail_arg6126228,if_helper6076213);
}};
$e62176218.stack[R.EXN_STACKHEIGHT++] = $ss62216222;
}
if(R.isPyretException($e62176218)) {
$e62176218.pyretStack.push(L[936]);
}
throw $e62176218;
}
var $ret62236224 = $Hcont_tail_arg30696229($z62196220,if_helper6076213);
++R.GAS;
return $ret62236224;
}
} else {
var cont_tail_arg6096233 = R.throwNonBooleanCondition(L[936],("if"),if_DASH_786230);
if(--R.GAS > 0) {
$z62316232 = R.isFunction(if_helper6076213)?if_helper6076213.app(cont_tail_arg6096233):R.ffi.throwNonFunApp(L[936],if_helper6076213,[cont_tail_arg6096233]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper6076213)?if_helper6076213.app(cont_tail_arg6096233):R.ffi.throwNonFunApp(L[936],if_helper6076213,[cont_tail_arg6096233]);
},
"from":L[936]});
}
++R.GAS;
return $z62316232;
}
};
},{"length":3});
var anf_variant_member6485991 = R.makeMethod(function(self776193) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[936],0,arguments);
}
var anf_arg6246191 = G(self776193,"l",L[936]);
var $z61836184 = D;
var $f61896190 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg6246191):R.ffi.throwNonFunApp(L[936],torepr31,[anf_arg6246191]);
};
try {
if(--R.GAS > 0) {
$z61836184 = $f61896190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61896190,
"from":L[936]});
}
} catch($e61816182) {
if(R.isCont($e61816182)) {
var $ss61856186 = {"from":L[936],
"go":function(anf_arg6256192) {
return $Hanf_arg30886194(anf_arg6256192,self776193,_plus26,torepr31);
}};
$e61816182.stack[R.EXN_STACKHEIGHT++] = $ss61856186;
}
if(R.isPyretException($e61816182)) {
$e61816182.pyretStack.push(L[936]);
}
throw $e61816182;
}
var $ret61876188 = $Hanf_arg30886194($z61836184,self776193,_plus26,torepr31);
++R.GAS;
return $ret61876188;
};
},{"length":1});
var anf_variant_member6505992 = R.makeMethod(function(self3276180) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[999],0,arguments);
}
var ann_DASH_check_DASH_temp6496179 = ("a-split-app");
return ann_DASH_check_DASH_temp6496179;
};
},{"length":1});
var anf_variant_member7145993 = R.makeMethod(function(self3286177) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[998],0,arguments);
}
var anf_fun6526174 = G(PP337,"group",L[997]);
var anf_fun6536175 = G(PP337,"group",L[996]);
var anf_fun6546176 = G(PP337,"nest",L[995]);
var anf_fun6556172 = G(PP337,"str",L[994]);
var $z61646165 = D;
var $f61706171 = function(_) {
return R.isFunction(anf_fun6556172)?anf_fun6556172.app(("split ")):R.ffi.throwNonFunApp(L[993],anf_fun6556172,[("split ")]);
};
try {
if(--R.GAS > 0) {
$z61646165 = $f61706171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61706171,
"from":L[993]});
}
} catch($e61626163) {
if(R.isCont($e61626163)) {
var $ss61666167 = {"from":L[993],
"go":function(anf_arg6566173) {
return $Hanf_arg31196178(anf_arg6566173,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26);
}};
$e61626163.stack[R.EXN_STACKHEIGHT++] = $ss61666167;
}
if(R.isPyretException($e61626163)) {
$e61626163.pyretStack.push(L[993]);
}
throw $e61626163;
}
var $ret61686169 = $Hanf_arg31196178($z61646165,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret61686169;
};
},{"length":1});
var anf_variant_member7296005 = R.makeMethod(function(self806140) {
return function(cases_DASH_funs816141,else_DASH_clause826152) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[935],2,arguments);
}
var if_DASH_846155 = R.hasField(cases_DASH_funs816141,("a-if"));
var if_helper7166138 = R.makeFunction(function(if_helper_arg7176160) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[935],1,arguments);
}
var ann_DASH_check_DASH_temp7156161 = if_helper_arg7176160;
return ann_DASH_check_DASH_temp7156161;
});
var anf_if7206159 = R.isBoolean(if_DASH_846155);
if(R.isPyretTrue(anf_if7206159)) {
if(R.isPyretTrue(if_DASH_846155)) {
var call_DASH_a_DASH_if796132 = G(cases_DASH_funs816141,"a-if",L[935]);
var anf_arg7236133 = G(self806140,"l",L[992]);
var anf_arg7246134 = G(self806140,"c",L[991]);
var anf_arg7256135 = G(self806140,"t",L[990]);
var anf_arg7266136 = G(self806140,"e",L[989]);
var $z61246125 = D;
var $f61306131 = function(_) {
return R.isFunction(call_DASH_a_DASH_if796132)?call_DASH_a_DASH_if796132.app(anf_arg7236133,anf_arg7246134,anf_arg7256135,anf_arg7266136):R.ffi.throwNonFunApp(L[935],call_DASH_a_DASH_if796132,[anf_arg7236133,anf_arg7246134,anf_arg7256135,anf_arg7266136]);
};
try {
if(--R.GAS > 0) {
$z61246125 = $f61306131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61306131,
"from":L[935]});
}
} catch($e61226123) {
if(R.isCont($e61226123)) {
var $ss61266127 = {"from":L[935],
"go":function(cont_tail_arg7276137) {
return $Hcont_tail_arg31206139(cont_tail_arg7276137,if_helper7166138);
}};
$e61226123.stack[R.EXN_STACKHEIGHT++] = $ss61266127;
}
if(R.isPyretException($e61226123)) {
$e61226123.pyretStack.push(L[935]);
}
throw $e61226123;
}
var $ret61286129 = $Hcont_tail_arg31206139($z61246125,if_helper7166138);
++R.GAS;
return $ret61286129;
} else {
var $z61446145 = D;
var $f61506151 = function(_) {
return R.isFunction(else_DASH_clause826152)?else_DASH_clause826152.app():R.ffi.throwNonFunApp(L[935],else_DASH_clause826152,[]);
};
try {
if(--R.GAS > 0) {
$z61446145 = $f61506151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61506151,
"from":L[935]});
}
} catch($e61426143) {
if(R.isCont($e61426143)) {
var $ss61466147 = {"from":L[935],
"go":function(cont_tail_arg7216153) {
return $Hcont_tail_arg31216154(cont_tail_arg7216153,if_helper7166138);
}};
$e61426143.stack[R.EXN_STACKHEIGHT++] = $ss61466147;
}
if(R.isPyretException($e61426143)) {
$e61426143.pyretStack.push(L[935]);
}
throw $e61426143;
}
var $ret61486149 = $Hcont_tail_arg31216154($z61446145,if_helper7166138);
++R.GAS;
return $ret61486149;
}
} else {
var cont_tail_arg7186158 = R.throwNonBooleanCondition(L[935],("if"),if_DASH_846155);
if(--R.GAS > 0) {
$z61566157 = R.isFunction(if_helper7166138)?if_helper7166138.app(cont_tail_arg7186158):R.ffi.throwNonFunApp(L[935],if_helper7166138,[cont_tail_arg7186158]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper7166138)?if_helper7166138.app(cont_tail_arg7186158):R.ffi.throwNonFunApp(L[935],if_helper7166138,[cont_tail_arg7186158]);
},
"from":L[935]});
}
++R.GAS;
return $z61566157;
}
};
},{"length":3});
var anf_variant_member7476006 = R.makeMethod(function(self836120) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[935],0,arguments);
}
var anf_arg7316118 = G(self836120,"l",L[935]);
var $z61106111 = D;
var $f61166117 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg7316118):R.ffi.throwNonFunApp(L[935],torepr31,[anf_arg7316118]);
};
try {
if(--R.GAS > 0) {
$z61106111 = $f61166117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61166117,
"from":L[935]});
}
} catch($e61086109) {
if(R.isCont($e61086109)) {
var $ss61126113 = {"from":L[935],
"go":function(anf_arg7326119) {
return $Hanf_arg31346121(anf_arg7326119,self836120,_plus26,torepr31);
}};
$e61086109.stack[R.EXN_STACKHEIGHT++] = $ss61126113;
}
if(R.isPyretException($e61086109)) {
$e61086109.pyretStack.push(L[935]);
}
throw $e61086109;
}
var $ret61146115 = $Hanf_arg31346121($z61106111,self836120,_plus26,torepr31);
++R.GAS;
return $ret61146115;
};
},{"length":1});
var anf_variant_member7496007 = R.makeMethod(function(self3356107) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[988],0,arguments);
}
var ann_DASH_check_DASH_temp7486106 = ("a-if");
return ann_DASH_check_DASH_temp7486106;
};
},{"length":1});
var anf_variant_member7786008 = R.makeMethod(function(self3366104) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[987],0,arguments);
}
var anf_fun7516102 = G(PP337,"group",L[986]);
var anf_fun7526103 = G(PP337,"nest",L[985]);
var $z60936094 = D;
var $f60996100 = function(_) {
return R.isFunction(_times27)?_times27.app((2),INDENT9187):R.ffi.throwNonFunApp(L[984],_times27,[(2),INDENT9187]);
};
try {
if(--R.GAS > 0) {
$z60936094 = $f60996100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60996100,
"from":L[984]});
}
} catch($e60916092) {
if(R.isCont($e60916092)) {
var $ss60956096 = {"from":L[984],
"go":function(anf_arg7536101) {
return $Hanf_arg31526105(anf_arg7536101,INDENT9187,PP337,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_colon98170,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26);
}};
$e60916092.stack[R.EXN_STACKHEIGHT++] = $ss60956096;
}
if(R.isPyretException($e60916092)) {
$e60916092.pyretStack.push(L[984]);
}
throw $e60916092;
}
var $ret60976098 = $Hanf_arg31526105($z60936094,INDENT9187,PP337,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_colon98170,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26);
++R.GAS;
return $ret60976098;
};
},{"length":1});
var anf_variant_member7906018 = R.makeMethod(function(self866069) {
return function(cases_DASH_funs876070,else_DASH_clause886081) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[934],2,arguments);
}
var if_DASH_906084 = R.hasField(cases_DASH_funs876070,("a-lettable"));
var if_helper7806067 = R.makeFunction(function(if_helper_arg7816089) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[934],1,arguments);
}
var ann_DASH_check_DASH_temp7796090 = if_helper_arg7816089;
return ann_DASH_check_DASH_temp7796090;
});
var anf_if7846088 = R.isBoolean(if_DASH_906084);
if(R.isPyretTrue(anf_if7846088)) {
if(R.isPyretTrue(if_DASH_906084)) {
var call_DASH_a_DASH_lettable856064 = G(cases_DASH_funs876070,"a-lettable",L[934]);
var anf_arg7876065 = G(self866069,"e",L[983]);
var $z60566057 = D;
var $f60626063 = function(_) {
return R.isFunction(call_DASH_a_DASH_lettable856064)?call_DASH_a_DASH_lettable856064.app(anf_arg7876065):R.ffi.throwNonFunApp(L[934],call_DASH_a_DASH_lettable856064,[anf_arg7876065]);
};
try {
if(--R.GAS > 0) {
$z60566057 = $f60626063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60626063,
"from":L[934]});
}
} catch($e60546055) {
if(R.isCont($e60546055)) {
var $ss60586059 = {"from":L[934],
"go":function(cont_tail_arg7886066) {
return $Hcont_tail_arg31536068(cont_tail_arg7886066,if_helper7806067);
}};
$e60546055.stack[R.EXN_STACKHEIGHT++] = $ss60586059;
}
if(R.isPyretException($e60546055)) {
$e60546055.pyretStack.push(L[934]);
}
throw $e60546055;
}
var $ret60606061 = $Hcont_tail_arg31536068($z60566057,if_helper7806067);
++R.GAS;
return $ret60606061;
} else {
var $z60736074 = D;
var $f60796080 = function(_) {
return R.isFunction(else_DASH_clause886081)?else_DASH_clause886081.app():R.ffi.throwNonFunApp(L[934],else_DASH_clause886081,[]);
};
try {
if(--R.GAS > 0) {
$z60736074 = $f60796080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60796080,
"from":L[934]});
}
} catch($e60716072) {
if(R.isCont($e60716072)) {
var $ss60756076 = {"from":L[934],
"go":function(cont_tail_arg7856082) {
return $Hcont_tail_arg31546083(cont_tail_arg7856082,if_helper7806067);
}};
$e60716072.stack[R.EXN_STACKHEIGHT++] = $ss60756076;
}
if(R.isPyretException($e60716072)) {
$e60716072.pyretStack.push(L[934]);
}
throw $e60716072;
}
var $ret60776078 = $Hcont_tail_arg31546083($z60736074,if_helper7806067);
++R.GAS;
return $ret60776078;
}
} else {
var cont_tail_arg7826087 = R.throwNonBooleanCondition(L[934],("if"),if_DASH_906084);
if(--R.GAS > 0) {
$z60856086 = R.isFunction(if_helper7806067)?if_helper7806067.app(cont_tail_arg7826087):R.ffi.throwNonFunApp(L[934],if_helper7806067,[cont_tail_arg7826087]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper7806067)?if_helper7806067.app(cont_tail_arg7826087):R.ffi.throwNonFunApp(L[934],if_helper7806067,[cont_tail_arg7826087]);
},
"from":L[934]});
}
++R.GAS;
return $z60856086;
}
};
},{"length":3});
var anf_variant_member7966019 = R.makeMethod(function(self896053) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[934],0,arguments);
}
var anf_arg7926050 = G(self896053,"e",L[934]);
var $z60426043 = D;
var $f60486049 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg7926050):R.ffi.throwNonFunApp(L[934],torepr31,[anf_arg7926050]);
};
try {
if(--R.GAS > 0) {
$z60426043 = $f60486049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60486049,
"from":L[934]});
}
} catch($e60406041) {
if(R.isCont($e60406041)) {
var $ss60446045 = {"from":L[934],
"go":function(anf_arg7936051) {
return $Hanf_arg31586052(anf_arg7936051,_plus26);
}};
$e60406041.stack[R.EXN_STACKHEIGHT++] = $ss60446045;
}
if(R.isPyretException($e60406041)) {
$e60406041.pyretStack.push(L[934]);
}
throw $e60406041;
}
var $ret60466047 = $Hanf_arg31586052($z60426043,_plus26);
++R.GAS;
return $ret60466047;
};
},{"length":1});
var anf_variant_member7986020 = R.makeMethod(function(self3386039) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[982],0,arguments);
}
var ann_DASH_check_DASH_temp7976038 = ("a-lettable");
return ann_DASH_check_DASH_temp7976038;
};
},{"length":1});
var anf_variant_member8026021 = R.makeMethod(function(self3396037) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[979],0,arguments);
}
var anf_bracket8006036 = G(self3396037,"e",L[981]);
var anf_fun8016033 = G(anf_bracket8006036,"tosource",L[980]);
var $z60256026 = D;
var $f60316032 = function(_) {
return R.isFunction(anf_fun8016033)?anf_fun8016033.app():R.ffi.throwNonFunApp(L[979],anf_fun8016033,[]);
};
try {
if(--R.GAS > 0) {
$z60256026 = $f60316032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60316032,
"from":L[979]});
}
} catch($e60236024) {
if(R.isCont($e60236024)) {
var $ss60276028 = {"from":L[979],
"go":function(ann_DASH_check_DASH_temp7996034) {
return $Hann_DASH_check_DASH_temp31596035(ann_DASH_check_DASH_temp7996034);
}};
$e60236024.stack[R.EXN_STACKHEIGHT++] = $ss60276028;
}
if(R.isPyretException($e60236024)) {
$e60236024.pyretStack.push(L[979]);
}
throw $e60236024;
}
var $ret60296030 = $Hann_DASH_check_DASH_temp31596035($z60256026);
++R.GAS;
return $ret60296030;
};
},{"length":1});
var anf_assign803446 = (function() {
var $a_DASH_type_DASH_let_DASH_base59235924 = {"visit":anf_shared3585922,
"_match":anf_variant_member3725928,
"_torepr":anf_variant_member3865929,
"label":anf_variant_member3885930,
"tosource":anf_variant_member4035931};
var $a_DASH_type_DASH_let_DASH_brands59265927 = {"$brand-a-type-let5925":true};
$a_DASH_type_DASH_let_DASH_brands59265927[AExprT67566._brand] = true
var $a_DASH_let_DASH_base59355936 = {"visit":anf_shared3585922,
"_match":anf_variant_member4185940,
"_torepr":anf_variant_member4365941,
"label":anf_variant_member4385942,
"tosource":anf_variant_member4595943};
var $a_DASH_let_DASH_brands59385939 = {"$brand-a-let5937":true};
$a_DASH_let_DASH_brands59385939[AExprT67566._brand] = true
var $a_DASH_var_DASH_base59485949 = {"visit":anf_shared3585922,
"_match":anf_variant_member4745953,
"_torepr":anf_variant_member4925954,
"label":anf_variant_member4945955,
"tosource":anf_variant_member5155956};
var $a_DASH_var_DASH_brands59515952 = {"$brand-a-var5950":true};
$a_DASH_var_DASH_brands59515952[AExprT67566._brand] = true
var $a_DASH_seq_DASH_base59615962 = {"visit":anf_shared3585922,
"_match":anf_variant_member5295966,
"_torepr":anf_variant_member5435967,
"label":anf_variant_member5455968,
"tosource":anf_variant_member5555969};
var $a_DASH_seq_DASH_brands59645965 = {"$brand-a-seq5963":true};
$a_DASH_seq_DASH_brands59645965[AExprT67566._brand] = true
var $a_DASH_tail_DASH_app_DASH_base59735974 = {"visit":anf_shared3585922,
"_match":anf_variant_member5695978,
"_torepr":anf_variant_member5835979,
"label":anf_variant_member5855980,
"tosource":anf_variant_member6055981};
var $a_DASH_tail_DASH_app_DASH_brands59765977 = {"$brand-a-tail-app5975":true};
$a_DASH_tail_DASH_app_DASH_brands59765977[AExprT67566._brand] = true
var $a_DASH_split_DASH_app_DASH_base59855986 = {"visit":anf_shared3585922,
"_match":anf_variant_member6225990,
"_torepr":anf_variant_member6485991,
"label":anf_variant_member6505992,
"tosource":anf_variant_member7145993};
var $a_DASH_split_DASH_app_DASH_brands59885989 = {"$brand-a-split-app5987":true};
$a_DASH_split_DASH_app_DASH_brands59885989[AExprT67566._brand] = true
var $a_DASH_if_DASH_base60006001 = {"visit":anf_shared3585922,
"_match":anf_variant_member7296005,
"_torepr":anf_variant_member7476006,
"label":anf_variant_member7496007,
"tosource":anf_variant_member7786008};
var $a_DASH_if_DASH_brands60036004 = {"$brand-a-if6002":true};
$a_DASH_if_DASH_brands60036004[AExprT67566._brand] = true
var $a_DASH_lettable_DASH_base60136014 = {"visit":anf_shared3585922,
"_match":anf_variant_member7906018,
"_torepr":anf_variant_member7966019,
"label":anf_variant_member7986020,
"tosource":anf_variant_member8026021};
var $a_DASH_lettable_DASH_brands60166017 = {"$brand-a-lettable6015":true};
$a_DASH_lettable_DASH_brands60166017[AExprT67566._brand] = true
return R.makeObject({"AExpr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[942],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AExprT67566._brand));
}),
"is-a-type-let":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[941],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-type-let5925"));
}),
"a-type-let":R.makeFunction(function(l2935932,bind2945933,body2955934) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[943],3,arguments);
}
return R.checkAnnArgs([Loc9089,ATypeBind7279,AExpr7465],[l2935932,bind2945933,body2955934],[L[944],L[945],L[946]],function() {
var dict = R.create($a_DASH_type_DASH_let_DASH_base59235924);
dict["l"] = l2935932
dict["bind"] = bind2945933
dict["body"] = body2955934
return R.makeBrandedObject(dict,$a_DASH_type_DASH_let_DASH_brands59265927);
});
}),
"is-a-let":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[940],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-let5937"));
}),
"a-let":R.makeFunction(function(l2985944,bind2995945,e3005946,body3015947) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[947],4,arguments);
}
return R.checkAnnArgs([Loc9089,ABind7663,ALettable8473,AExpr7465],[l2985944,bind2995945,e3005946,body3015947],[L[948],L[949],L[950],L[951]],function() {
var dict = R.create($a_DASH_let_DASH_base59355936);
dict["l"] = l2985944
dict["bind"] = bind2995945
dict["e"] = e3005946
dict["body"] = body3015947
return R.makeBrandedObject(dict,$a_DASH_let_DASH_brands59385939);
});
}),
"is-a-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[939],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-var5950"));
}),
"a-var":R.makeFunction(function(l3045957,bind3055958,e3065959,body3075960) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[952],4,arguments);
}
return R.checkAnnArgs([Loc9089,ABind7663,ALettable8473,AExpr7465],[l3045957,bind3055958,e3065959,body3075960],[L[953],L[954],L[955],L[956]],function() {
var dict = R.create($a_DASH_var_DASH_base59485949);
dict["l"] = l3045957
dict["bind"] = bind3055958
dict["e"] = e3065959
dict["body"] = body3075960
return R.makeBrandedObject(dict,$a_DASH_var_DASH_brands59515952);
});
}),
"is-a-seq":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[938],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-seq5963"));
}),
"a-seq":R.makeFunction(function(l3105970,e13115971,e23125972) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[957],3,arguments);
}
return R.checkAnnArgs([Loc9089,ALettable8473,AExpr7465],[l3105970,e13115971,e23125972],[L[958],L[959],L[960]],function() {
var dict = R.create($a_DASH_seq_DASH_base59615962);
dict["l"] = l3105970
dict["e1"] = e13115971
dict["e2"] = e23125972
return R.makeBrandedObject(dict,$a_DASH_seq_DASH_brands59645965);
});
}),
"is-a-tail-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[937],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-tail-app5975"));
}),
"a-tail-app":R.makeFunction(function(l3155982,f3165983,args3175984) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[961],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,List1788],[l3155982,f3165983,args3175984],[L[962],L[963],L[964]],function() {
var dict = R.create($a_DASH_tail_DASH_app_DASH_base59735974);
dict["l"] = l3155982
dict["f"] = f3165983
dict["args"] = args3175984
return R.makeBrandedObject(dict,$a_DASH_tail_DASH_app_DASH_brands59765977);
});
}),
"is-a-split-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[936],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-split-app5987"));
}),
"a-split-app":R.makeFunction(function(l3215994,is_DASH_var3225995,f3235996,args3245997,helper3255998,helper_DASH_args3265999) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[965],6,arguments);
}
return R.checkAnnArgs([Loc9089,$type$Boolean33,AVal8881,List1788,R.getDotAnn(L[966],"A",A244,"Name"),List1788],[l3215994,is_DASH_var3225995,f3235996,args3245997,helper3255998,helper_DASH_args3265999],[L[967],L[968],L[969],L[970],L[966],L[971]],function() {
var dict = R.create($a_DASH_split_DASH_app_DASH_base59855986);
dict["l"] = l3215994
dict["is-var"] = is_DASH_var3225995
dict["f"] = f3235996
dict["args"] = args3245997
dict["helper"] = helper3255998
dict["helper-args"] = helper_DASH_args3265999
return R.makeBrandedObject(dict,$a_DASH_split_DASH_app_DASH_brands59885989);
});
}),
"is-a-if":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[935],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-if6002"));
}),
"a-if":R.makeFunction(function(l3316009,c3326010,t3336011,e3346012) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[972],4,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,AExpr7465,AExpr7465],[l3316009,c3326010,t3336011,e3346012],[L[973],L[974],L[975],L[976]],function() {
var dict = R.create($a_DASH_if_DASH_base60006001);
dict["l"] = l3316009
dict["c"] = c3326010
dict["t"] = t3336011
dict["e"] = e3346012
return R.makeBrandedObject(dict,$a_DASH_if_DASH_brands60036004);
});
}),
"is-a-lettable":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[934],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-lettable6015"));
}),
"a-lettable":R.makeFunction(function(e3376022) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[977],1,arguments);
}
return R.checkAnnArgs([ALettable8473],[e3376022],[L[978]],function() {
var dict = R.create($a_DASH_lettable_DASH_base60136014);
dict["e"] = e3376022
return R.makeBrandedObject(dict,$a_DASH_lettable_DASH_brands60166017);
});
})});
})();
AExpr18143445.$var = anf_assign803446;
var anf_assign804448 = G(AExpr18143445.$var,"AExpr",L[942]);
AExpr144447.$var = anf_assign804448;
var anf_assign805450 = G(AExpr18143445.$var,"AExpr",L[942]);
is_DASH_AExpr145449.$var = anf_assign805450;
var anf_assign806452 = G(AExpr18143445.$var,"is-a-type-let",L[941]);
is_DASH_a_DASH_type_DASH_let146451.$var = anf_assign806452;
var anf_assign807454 = G(AExpr18143445.$var,"a-type-let",L[941]);
a_DASH_type_DASH_let147453.$var = anf_assign807454;
var anf_assign808456 = G(AExpr18143445.$var,"is-a-let",L[940]);
is_DASH_a_DASH_let148455.$var = anf_assign808456;
var anf_assign809458 = G(AExpr18143445.$var,"a-let",L[940]);
a_DASH_let149457.$var = anf_assign809458;
var anf_assign810460 = G(AExpr18143445.$var,"is-a-var",L[939]);
is_DASH_a_DASH_var150459.$var = anf_assign810460;
var anf_assign811462 = G(AExpr18143445.$var,"a-var",L[939]);
a_DASH_var151461.$var = anf_assign811462;
var anf_assign812464 = G(AExpr18143445.$var,"is-a-seq",L[938]);
is_DASH_a_DASH_seq152463.$var = anf_assign812464;
var anf_assign813466 = G(AExpr18143445.$var,"a-seq",L[938]);
a_DASH_seq153465.$var = anf_assign813466;
var anf_assign814468 = G(AExpr18143445.$var,"is-a-tail-app",L[937]);
is_DASH_a_DASH_tail_DASH_app154467.$var = anf_assign814468;
var anf_assign815470 = G(AExpr18143445.$var,"a-tail-app",L[937]);
a_DASH_tail_DASH_app155469.$var = anf_assign815470;
var anf_assign816472 = G(AExpr18143445.$var,"is-a-split-app",L[936]);
is_DASH_a_DASH_split_DASH_app156471.$var = anf_assign816472;
var anf_assign817474 = G(AExpr18143445.$var,"a-split-app",L[936]);
a_DASH_split_DASH_app157473.$var = anf_assign817474;
var anf_assign818476 = G(AExpr18143445.$var,"is-a-if",L[935]);
is_DASH_a_DASH_if158475.$var = anf_assign818476;
var anf_assign819478 = G(AExpr18143445.$var,"a-if",L[935]);
a_DASH_if159477.$var = anf_assign819478;
var anf_assign820480 = G(AExpr18143445.$var,"is-a-lettable",L[934]);
is_DASH_a_DASH_lettable160479.$var = anf_assign820480;
var anf_assign821482 = G(AExpr18143445.$var,"a-lettable",L[934]);
a_DASH_lettable161481.$var = anf_assign821482;
var anf_shared8295810 = R.makeMethod(function(self3475921) {
return function(visitor3485904) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[929],1,arguments);
}
var anf_fun8235903 = G(self3475921,"_match",L[933]);
var anf_arg8285905 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[930],0,arguments);
}
var anf_fun8255918 = G(self3475921,"label",L[932]);
var $z59105911 = D;
var $f59165917 = function(_) {
return R.isFunction(anf_fun8255918)?anf_fun8255918.app():R.ffi.throwNonFunApp(L[931],anf_fun8255918,[]);
};
try {
if(--R.GAS > 0) {
$z59105911 = $f59165917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59165917,
"from":L[931]});
}
} catch($e59085909) {
if(R.isCont($e59085909)) {
var $ss59125913 = {"from":L[931],
"go":function(anf_arg8265919) {
return $Hanf_arg31625920(anf_arg8265919,_plus26,raise30);
}};
$e59085909.stack[R.EXN_STACKHEIGHT++] = $ss59125913;
}
if(R.isPyretException($e59085909)) {
$e59085909.pyretStack.push(L[931]);
}
throw $e59085909;
}
var $ret59145915 = $Hanf_arg31625920($z59105911,_plus26,raise30);
++R.GAS;
return $ret59145915;
});
var $z58955896 = D;
var $f59015902 = function(_) {
return R.isFunction(anf_fun8235903)?anf_fun8235903.app(visitor3485904,anf_arg8285905):R.ffi.throwNonFunApp(L[929],anf_fun8235903,[visitor3485904,anf_arg8285905]);
};
try {
if(--R.GAS > 0) {
$z58955896 = $f59015902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59015902,
"from":L[929]});
}
} catch($e58935894) {
if(R.isCont($e58935894)) {
var $ss58975898 = {"from":L[929],
"go":function(ann_DASH_check_DASH_temp8225906) {
return $Hann_DASH_check_DASH_temp31635907(ann_DASH_check_DASH_temp8225906);
}};
$e58935894.stack[R.EXN_STACKHEIGHT++] = $ss58975898;
}
if(R.isPyretException($e58935894)) {
$e58935894.pyretStack.push(L[929]);
}
throw $e58935894;
}
var $ret58995900 = $Hann_DASH_check_DASH_temp31635907($z58955896);
++R.GAS;
return $ret58995900;
};
},{"length":2});
var anf_variant_member8435816 = R.makeMethod(function(self925871) {
return function(cases_DASH_funs935872,else_DASH_clause945883) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[915],2,arguments);
}
var if_DASH_965886 = R.hasField(cases_DASH_funs935872,("a-bind"));
var if_helper8315869 = R.makeFunction(function(if_helper_arg8325891) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[915],1,arguments);
}
var ann_DASH_check_DASH_temp8305892 = if_helper_arg8325891;
return ann_DASH_check_DASH_temp8305892;
});
var anf_if8355890 = R.isBoolean(if_DASH_965886);
if(R.isPyretTrue(anf_if8355890)) {
if(R.isPyretTrue(if_DASH_965886)) {
var call_DASH_a_DASH_bind915864 = G(cases_DASH_funs935872,"a-bind",L[915]);
var anf_arg8385865 = G(self925871,"l",L[928]);
var anf_arg8395866 = G(self925871,"id",L[927]);
var anf_arg8405867 = G(self925871,"ann",L[926]);
var $z58565857 = D;
var $f58625863 = function(_) {
return R.isFunction(call_DASH_a_DASH_bind915864)?call_DASH_a_DASH_bind915864.app(anf_arg8385865,anf_arg8395866,anf_arg8405867):R.ffi.throwNonFunApp(L[915],call_DASH_a_DASH_bind915864,[anf_arg8385865,anf_arg8395866,anf_arg8405867]);
};
try {
if(--R.GAS > 0) {
$z58565857 = $f58625863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58625863,
"from":L[915]});
}
} catch($e58545855) {
if(R.isCont($e58545855)) {
var $ss58585859 = {"from":L[915],
"go":function(cont_tail_arg8415868) {
return $Hcont_tail_arg31645870(cont_tail_arg8415868,if_helper8315869);
}};
$e58545855.stack[R.EXN_STACKHEIGHT++] = $ss58585859;
}
if(R.isPyretException($e58545855)) {
$e58545855.pyretStack.push(L[915]);
}
throw $e58545855;
}
var $ret58605861 = $Hcont_tail_arg31645870($z58565857,if_helper8315869);
++R.GAS;
return $ret58605861;
} else {
var $z58755876 = D;
var $f58815882 = function(_) {
return R.isFunction(else_DASH_clause945883)?else_DASH_clause945883.app():R.ffi.throwNonFunApp(L[915],else_DASH_clause945883,[]);
};
try {
if(--R.GAS > 0) {
$z58755876 = $f58815882();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58815882,
"from":L[915]});
}
} catch($e58735874) {
if(R.isCont($e58735874)) {
var $ss58775878 = {"from":L[915],
"go":function(cont_tail_arg8365884) {
return $Hcont_tail_arg31655885(cont_tail_arg8365884,if_helper8315869);
}};
$e58735874.stack[R.EXN_STACKHEIGHT++] = $ss58775878;
}
if(R.isPyretException($e58735874)) {
$e58735874.pyretStack.push(L[915]);
}
throw $e58735874;
}
var $ret58795880 = $Hcont_tail_arg31655885($z58755876,if_helper8315869);
++R.GAS;
return $ret58795880;
}
} else {
var cont_tail_arg8335889 = R.throwNonBooleanCondition(L[915],("if"),if_DASH_965886);
if(--R.GAS > 0) {
$z58875888 = R.isFunction(if_helper8315869)?if_helper8315869.app(cont_tail_arg8335889):R.ffi.throwNonFunApp(L[915],if_helper8315869,[cont_tail_arg8335889]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper8315869)?if_helper8315869.app(cont_tail_arg8335889):R.ffi.throwNonFunApp(L[915],if_helper8315869,[cont_tail_arg8335889]);
},
"from":L[915]});
}
++R.GAS;
return $z58875888;
}
};
},{"length":3});
var anf_variant_member8575817 = R.makeMethod(function(self955852) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[915],0,arguments);
}
var anf_arg8455850 = G(self955852,"l",L[915]);
var $z58425843 = D;
var $f58485849 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg8455850):R.ffi.throwNonFunApp(L[915],torepr31,[anf_arg8455850]);
};
try {
if(--R.GAS > 0) {
$z58425843 = $f58485849();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58485849,
"from":L[915]});
}
} catch($e58405841) {
if(R.isCont($e58405841)) {
var $ss58445845 = {"from":L[915],
"go":function(anf_arg8465851) {
return $Hanf_arg31755853(anf_arg8465851,self955852,_plus26,torepr31);
}};
$e58405841.stack[R.EXN_STACKHEIGHT++] = $ss58445845;
}
if(R.isPyretException($e58405841)) {
$e58405841.pyretStack.push(L[915]);
}
throw $e58405841;
}
var $ret58465847 = $Hanf_arg31755853($z58425843,self955852,_plus26,torepr31);
++R.GAS;
return $ret58465847;
};
},{"length":1});
var anf_variant_member8595818 = R.makeMethod(function(self3455839) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[925],0,arguments);
}
var ann_DASH_check_DASH_temp8585838 = ("a-bind");
return ann_DASH_check_DASH_temp8585838;
};
},{"length":1});
var anf_variant_member8815819 = R.makeMethod(function(self3465836) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[924],0,arguments);
}
var anf_fun8615833 = G(A136,"is-a-blank",L[923]);
var anf_arg8625834 = G(self3465836,"ann",L[922]);
var $z58255826 = D;
var $f58315832 = function(_) {
return R.isFunction(anf_fun8615833)?anf_fun8615833.app(anf_arg8625834):R.ffi.throwNonFunApp(L[921],anf_fun8615833,[anf_arg8625834]);
};
try {
if(--R.GAS > 0) {
$z58255826 = $f58315832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58315832,
"from":L[921]});
}
} catch($e58235824) {
if(R.isCont($e58235824)) {
var $ss58275828 = {"from":L[921],
"go":function(if_DASH_975835) {
return $Hif_DASH_31805837(if_DASH_975835,INDENT9187,PP337,self3465836,str_DASH_coloncolon99183);
}};
$e58235824.stack[R.EXN_STACKHEIGHT++] = $ss58275828;
}
if(R.isPyretException($e58235824)) {
$e58235824.pyretStack.push(L[921]);
}
throw $e58235824;
}
var $ret58295830 = $Hif_DASH_31805837($z58255826,INDENT9187,PP337,self3465836,str_DASH_coloncolon99183);
++R.GAS;
return $ret58295830;
};
},{"length":1});
var anf_assign882484 = (function() {
var $a_DASH_bind_DASH_base58115812 = {"visit":anf_shared8295810,
"_match":anf_variant_member8435816,
"_torepr":anf_variant_member8575817,
"label":anf_variant_member8595818,
"tosource":anf_variant_member8815819};
var $a_DASH_bind_DASH_brands58145815 = {"$brand-a-bind5813":true};
$a_DASH_bind_DASH_brands58145815[ABindT77764._brand] = true
return R.makeObject({"ABind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[916],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ABindT77764._brand));
}),
"is-a-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[915],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-bind5813"));
}),
"a-bind":R.makeFunction(function(l3425820,id3435821,ann3445822) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[917],3,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[918],"A",A244,"Name"),R.getDotAnn(L[919],"A",A244,"Ann")],[l3425820,id3435821,ann3445822],[L[920],L[918],L[919]],function() {
var dict = R.create($a_DASH_bind_DASH_base58115812);
dict["l"] = l3425820
dict["id"] = id3435821
dict["ann"] = ann3445822
return R.makeBrandedObject(dict,$a_DASH_bind_DASH_brands58145815);
});
})});
})();
ABind19162483.$var = anf_assign882484;
var anf_assign883486 = G(ABind19162483.$var,"ABind",L[916]);
ABind163485.$var = anf_assign883486;
var anf_assign884488 = G(ABind19162483.$var,"ABind",L[916]);
is_DASH_ABind164487.$var = anf_assign884488;
var anf_assign885490 = G(ABind19162483.$var,"is-a-bind",L[915]);
is_DASH_a_DASH_bind165489.$var = anf_assign885490;
var anf_assign886492 = G(ABind19162483.$var,"a-bind",L[915]);
a_DASH_bind166491.$var = anf_assign886492;
var anf_shared8945614 = R.makeMethod(function(self3615809) {
return function(visitor3625792) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[910],1,arguments);
}
var anf_fun8885791 = G(self3615809,"_match",L[914]);
var anf_arg8935793 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[911],0,arguments);
}
var anf_fun8905806 = G(self3615809,"label",L[913]);
var $z57985799 = D;
var $f58045805 = function(_) {
return R.isFunction(anf_fun8905806)?anf_fun8905806.app():R.ffi.throwNonFunApp(L[912],anf_fun8905806,[]);
};
try {
if(--R.GAS > 0) {
$z57985799 = $f58045805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58045805,
"from":L[912]});
}
} catch($e57965797) {
if(R.isCont($e57965797)) {
var $ss58005801 = {"from":L[912],
"go":function(anf_arg8915807) {
return $Hanf_arg31835808(anf_arg8915807,_plus26,raise30);
}};
$e57965797.stack[R.EXN_STACKHEIGHT++] = $ss58005801;
}
if(R.isPyretException($e57965797)) {
$e57965797.pyretStack.push(L[912]);
}
throw $e57965797;
}
var $ret58025803 = $Hanf_arg31835808($z57985799,_plus26,raise30);
++R.GAS;
return $ret58025803;
});
var $z57835784 = D;
var $f57895790 = function(_) {
return R.isFunction(anf_fun8885791)?anf_fun8885791.app(visitor3625792,anf_arg8935793):R.ffi.throwNonFunApp(L[910],anf_fun8885791,[visitor3625792,anf_arg8935793]);
};
try {
if(--R.GAS > 0) {
$z57835784 = $f57895790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57895790,
"from":L[910]});
}
} catch($e57815782) {
if(R.isCont($e57815782)) {
var $ss57855786 = {"from":L[910],
"go":function(ann_DASH_check_DASH_temp8875794) {
return $Hann_DASH_check_DASH_temp31845795(ann_DASH_check_DASH_temp8875794);
}};
$e57815782.stack[R.EXN_STACKHEIGHT++] = $ss57855786;
}
if(R.isPyretException($e57815782)) {
$e57815782.pyretStack.push(L[910]);
}
throw $e57815782;
}
var $ret57875788 = $Hann_DASH_check_DASH_temp31845795($z57835784);
++R.GAS;
return $ret57875788;
};
},{"length":2});
var anf_variant_member9105620 = R.makeMethod(function(self995759) {
return function(cases_DASH_funs1005760,else_DASH_clause1015771) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[884],2,arguments);
}
var if_DASH_1035774 = R.hasField(cases_DASH_funs1005760,("a-variant"));
var if_helper8965757 = R.makeFunction(function(if_helper_arg8975779) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[884],1,arguments);
}
var ann_DASH_check_DASH_temp8955780 = if_helper_arg8975779;
return ann_DASH_check_DASH_temp8955780;
});
var anf_if9005778 = R.isBoolean(if_DASH_1035774);
if(R.isPyretTrue(anf_if9005778)) {
if(R.isPyretTrue(if_DASH_1035774)) {
var call_DASH_a_DASH_variant985750 = G(cases_DASH_funs1005760,"a-variant",L[884]);
var anf_arg9035751 = G(self995759,"l",L[909]);
var anf_arg9045752 = G(self995759,"constr-loc",L[908]);
var anf_arg9055753 = G(self995759,"name",L[907]);
var anf_arg9065754 = G(self995759,"members",L[906]);
var anf_arg9075755 = G(self995759,"with-members",L[905]);
var $z57425743 = D;
var $f57485749 = function(_) {
return R.isFunction(call_DASH_a_DASH_variant985750)?call_DASH_a_DASH_variant985750.app(anf_arg9035751,anf_arg9045752,anf_arg9055753,anf_arg9065754,anf_arg9075755):R.ffi.throwNonFunApp(L[884],call_DASH_a_DASH_variant985750,[anf_arg9035751,anf_arg9045752,anf_arg9055753,anf_arg9065754,anf_arg9075755]);
};
try {
if(--R.GAS > 0) {
$z57425743 = $f57485749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57485749,
"from":L[884]});
}
} catch($e57405741) {
if(R.isCont($e57405741)) {
var $ss57445745 = {"from":L[884],
"go":function(cont_tail_arg9085756) {
return $Hcont_tail_arg31855758(cont_tail_arg9085756,if_helper8965757);
}};
$e57405741.stack[R.EXN_STACKHEIGHT++] = $ss57445745;
}
if(R.isPyretException($e57405741)) {
$e57405741.pyretStack.push(L[884]);
}
throw $e57405741;
}
var $ret57465747 = $Hcont_tail_arg31855758($z57425743,if_helper8965757);
++R.GAS;
return $ret57465747;
} else {
var $z57635764 = D;
var $f57695770 = function(_) {
return R.isFunction(else_DASH_clause1015771)?else_DASH_clause1015771.app():R.ffi.throwNonFunApp(L[884],else_DASH_clause1015771,[]);
};
try {
if(--R.GAS > 0) {
$z57635764 = $f57695770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57695770,
"from":L[884]});
}
} catch($e57615762) {
if(R.isCont($e57615762)) {
var $ss57655766 = {"from":L[884],
"go":function(cont_tail_arg9015772) {
return $Hcont_tail_arg31865773(cont_tail_arg9015772,if_helper8965757);
}};
$e57615762.stack[R.EXN_STACKHEIGHT++] = $ss57655766;
}
if(R.isPyretException($e57615762)) {
$e57615762.pyretStack.push(L[884]);
}
throw $e57615762;
}
var $ret57675768 = $Hcont_tail_arg31865773($z57635764,if_helper8965757);
++R.GAS;
return $ret57675768;
}
} else {
var cont_tail_arg8985777 = R.throwNonBooleanCondition(L[884],("if"),if_DASH_1035774);
if(--R.GAS > 0) {
$z57755776 = R.isFunction(if_helper8965757)?if_helper8965757.app(cont_tail_arg8985777):R.ffi.throwNonFunApp(L[884],if_helper8965757,[cont_tail_arg8985777]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper8965757)?if_helper8965757.app(cont_tail_arg8985777):R.ffi.throwNonFunApp(L[884],if_helper8965757,[cont_tail_arg8985777]);
},
"from":L[884]});
}
++R.GAS;
return $z57755776;
}
};
},{"length":3});
var anf_variant_member9325621 = R.makeMethod(function(self1025738) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[884],0,arguments);
}
var anf_arg9125736 = G(self1025738,"l",L[884]);
var $z57285729 = D;
var $f57345735 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg9125736):R.ffi.throwNonFunApp(L[884],torepr31,[anf_arg9125736]);
};
try {
if(--R.GAS > 0) {
$z57285729 = $f57345735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57345735,
"from":L[884]});
}
} catch($e57265727) {
if(R.isCont($e57265727)) {
var $ss57305731 = {"from":L[884],
"go":function(anf_arg9135737) {
return $Hanf_arg32025739(anf_arg9135737,self1025738,_plus26,torepr31);
}};
$e57265727.stack[R.EXN_STACKHEIGHT++] = $ss57305731;
}
if(R.isPyretException($e57265727)) {
$e57265727.pyretStack.push(L[884]);
}
throw $e57265727;
}
var $ret57325733 = $Hanf_arg32025739($z57285729,self1025738,_plus26,torepr31);
++R.GAS;
return $ret57325733;
};
},{"length":1});
var anf_variant_member9345622 = R.makeMethod(function(self3545725) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[904],0,arguments);
}
var ann_DASH_check_DASH_temp9335724 = ("a-variant");
return ann_DASH_check_DASH_temp9335724;
};
},{"length":1});
var anf_variant_member9375623 = R.makeMethod(function(self3555723) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[902],0,arguments);
}
var anf_fun9365720 = G(PP337,"str",L[903]);
var $z57125713 = D;
var $f57185719 = function(_) {
return R.isFunction(anf_fun9365720)?anf_fun9365720.app(("a-variant")):R.ffi.throwNonFunApp(L[902],anf_fun9365720,[("a-variant")]);
};
try {
if(--R.GAS > 0) {
$z57125713 = $f57185719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57185719,
"from":L[902]});
}
} catch($e57105711) {
if(R.isCont($e57105711)) {
var $ss57145715 = {"from":L[902],
"go":function(ann_DASH_check_DASH_temp9355721) {
return $Hann_DASH_check_DASH_temp32035722(ann_DASH_check_DASH_temp9355721);
}};
$e57105711.stack[R.EXN_STACKHEIGHT++] = $ss57145715;
}
if(R.isPyretException($e57105711)) {
$e57105711.pyretStack.push(L[902]);
}
throw $e57105711;
}
var $ret57165717 = $Hann_DASH_check_DASH_temp32035722($z57125713);
++R.GAS;
return $ret57165717;
};
},{"length":1});
var anf_variant_member9515634 = R.makeMethod(function(self1055688) {
return function(cases_DASH_funs1065689,else_DASH_clause1075700) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[883],2,arguments);
}
var if_DASH_1095703 = R.hasField(cases_DASH_funs1065689,("a-singleton-variant"));
var if_helper9395686 = R.makeFunction(function(if_helper_arg9405708) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[883],1,arguments);
}
var ann_DASH_check_DASH_temp9385709 = if_helper_arg9405708;
return ann_DASH_check_DASH_temp9385709;
});
var anf_if9435707 = R.isBoolean(if_DASH_1095703);
if(R.isPyretTrue(anf_if9435707)) {
if(R.isPyretTrue(if_DASH_1095703)) {
var call_DASH_a_DASH_singleton_DASH_variant1045681 = G(cases_DASH_funs1065689,"a-singleton-variant",L[883]);
var anf_arg9465682 = G(self1055688,"l",L[901]);
var anf_arg9475683 = G(self1055688,"name",L[900]);
var anf_arg9485684 = G(self1055688,"with-members",L[899]);
var $z56735674 = D;
var $f56795680 = function(_) {
return R.isFunction(call_DASH_a_DASH_singleton_DASH_variant1045681)?call_DASH_a_DASH_singleton_DASH_variant1045681.app(anf_arg9465682,anf_arg9475683,anf_arg9485684):R.ffi.throwNonFunApp(L[883],call_DASH_a_DASH_singleton_DASH_variant1045681,[anf_arg9465682,anf_arg9475683,anf_arg9485684]);
};
try {
if(--R.GAS > 0) {
$z56735674 = $f56795680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56795680,
"from":L[883]});
}
} catch($e56715672) {
if(R.isCont($e56715672)) {
var $ss56755676 = {"from":L[883],
"go":function(cont_tail_arg9495685) {
return $Hcont_tail_arg32045687(cont_tail_arg9495685,if_helper9395686);
}};
$e56715672.stack[R.EXN_STACKHEIGHT++] = $ss56755676;
}
if(R.isPyretException($e56715672)) {
$e56715672.pyretStack.push(L[883]);
}
throw $e56715672;
}
var $ret56775678 = $Hcont_tail_arg32045687($z56735674,if_helper9395686);
++R.GAS;
return $ret56775678;
} else {
var $z56925693 = D;
var $f56985699 = function(_) {
return R.isFunction(else_DASH_clause1075700)?else_DASH_clause1075700.app():R.ffi.throwNonFunApp(L[883],else_DASH_clause1075700,[]);
};
try {
if(--R.GAS > 0) {
$z56925693 = $f56985699();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56985699,
"from":L[883]});
}
} catch($e56905691) {
if(R.isCont($e56905691)) {
var $ss56945695 = {"from":L[883],
"go":function(cont_tail_arg9445701) {
return $Hcont_tail_arg32055702(cont_tail_arg9445701,if_helper9395686);
}};
$e56905691.stack[R.EXN_STACKHEIGHT++] = $ss56945695;
}
if(R.isPyretException($e56905691)) {
$e56905691.pyretStack.push(L[883]);
}
throw $e56905691;
}
var $ret56965697 = $Hcont_tail_arg32055702($z56925693,if_helper9395686);
++R.GAS;
return $ret56965697;
}
} else {
var cont_tail_arg9415706 = R.throwNonBooleanCondition(L[883],("if"),if_DASH_1095703);
if(--R.GAS > 0) {
$z57045705 = R.isFunction(if_helper9395686)?if_helper9395686.app(cont_tail_arg9415706):R.ffi.throwNonFunApp(L[883],if_helper9395686,[cont_tail_arg9415706]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9395686)?if_helper9395686.app(cont_tail_arg9415706):R.ffi.throwNonFunApp(L[883],if_helper9395686,[cont_tail_arg9415706]);
},
"from":L[883]});
}
++R.GAS;
return $z57045705;
}
};
},{"length":3});
var anf_variant_member9655635 = R.makeMethod(function(self1085669) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[883],0,arguments);
}
var anf_arg9535667 = G(self1085669,"l",L[883]);
var $z56595660 = D;
var $f56655666 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg9535667):R.ffi.throwNonFunApp(L[883],torepr31,[anf_arg9535667]);
};
try {
if(--R.GAS > 0) {
$z56595660 = $f56655666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56655666,
"from":L[883]});
}
} catch($e56575658) {
if(R.isCont($e56575658)) {
var $ss56615662 = {"from":L[883],
"go":function(anf_arg9545668) {
return $Hanf_arg32155670(anf_arg9545668,self1085669,_plus26,torepr31);
}};
$e56575658.stack[R.EXN_STACKHEIGHT++] = $ss56615662;
}
if(R.isPyretException($e56575658)) {
$e56575658.pyretStack.push(L[883]);
}
throw $e56575658;
}
var $ret56635664 = $Hanf_arg32155670($z56595660,self1085669,_plus26,torepr31);
++R.GAS;
return $ret56635664;
};
},{"length":1});
var anf_variant_member9675636 = R.makeMethod(function(self3595656) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[898],0,arguments);
}
var ann_DASH_check_DASH_temp9665655 = ("a-variant");
return ann_DASH_check_DASH_temp9665655;
};
},{"length":1});
var anf_variant_member9705637 = R.makeMethod(function(self3605654) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[896],0,arguments);
}
var anf_fun9695651 = G(PP337,"str",L[897]);
var $z56435644 = D;
var $f56495650 = function(_) {
return R.isFunction(anf_fun9695651)?anf_fun9695651.app(("a-variant")):R.ffi.throwNonFunApp(L[896],anf_fun9695651,[("a-variant")]);
};
try {
if(--R.GAS > 0) {
$z56435644 = $f56495650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56495650,
"from":L[896]});
}
} catch($e56415642) {
if(R.isCont($e56415642)) {
var $ss56455646 = {"from":L[896],
"go":function(ann_DASH_check_DASH_temp9685652) {
return $Hann_DASH_check_DASH_temp32165653(ann_DASH_check_DASH_temp9685652);
}};
$e56415642.stack[R.EXN_STACKHEIGHT++] = $ss56455646;
}
if(R.isPyretException($e56415642)) {
$e56415642.pyretStack.push(L[896]);
}
throw $e56415642;
}
var $ret56475648 = $Hann_DASH_check_DASH_temp32165653($z56435644);
++R.GAS;
return $ret56475648;
};
},{"length":1});
var anf_assign971494 = (function() {
var $a_DASH_variant_DASH_base56155616 = {"visit":anf_shared8945614,
"_match":anf_variant_member9105620,
"_torepr":anf_variant_member9325621,
"label":anf_variant_member9345622,
"tosource":anf_variant_member9375623};
var $a_DASH_variant_DASH_brands56185619 = {"$brand-a-variant5617":true};
$a_DASH_variant_DASH_brands56185619[AVariantT87986._brand] = true
var $a_DASH_singleton_DASH_variant_DASH_base56295630 = {"visit":anf_shared8945614,
"_match":anf_variant_member9515634,
"_torepr":anf_variant_member9655635,
"label":anf_variant_member9675636,
"tosource":anf_variant_member9705637};
var $a_DASH_singleton_DASH_variant_DASH_brands56325633 = {"$brand-a-singleton-variant5631":true};
$a_DASH_singleton_DASH_variant_DASH_brands56325633[AVariantT87986._brand] = true
return R.makeObject({"AVariant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[885],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AVariantT87986._brand));
}),
"is-a-variant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[884],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-variant5617"));
}),
"a-variant":R.makeFunction(function(l3495624,constr_DASH_loc3505625,name3515626,members3525627,with_DASH_members3535628) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[886],5,arguments);
}
return R.checkAnnArgs([Loc9089,Loc9089,$type$String35,List1788,List1788],[l3495624,constr_DASH_loc3505625,name3515626,members3525627,with_DASH_members3535628],[L[887],L[888],L[889],L[890],L[891]],function() {
var dict = R.create($a_DASH_variant_DASH_base56155616);
dict["l"] = l3495624
dict["constr-loc"] = constr_DASH_loc3505625
dict["name"] = name3515626
dict["members"] = members3525627
dict["with-members"] = with_DASH_members3535628
return R.makeBrandedObject(dict,$a_DASH_variant_DASH_brands56185619);
});
}),
"is-a-singleton-variant":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[883],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-singleton-variant5631"));
}),
"a-singleton-variant":R.makeFunction(function(l3565638,name3575639,with_DASH_members3585640) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[892],3,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,List1788],[l3565638,name3575639,with_DASH_members3585640],[L[893],L[894],L[895]],function() {
var dict = R.create($a_DASH_singleton_DASH_variant_DASH_base56295630);
dict["l"] = l3565638
dict["name"] = name3575639
dict["with-members"] = with_DASH_members3585640
return R.makeBrandedObject(dict,$a_DASH_singleton_DASH_variant_DASH_brands56325633);
});
})});
})();
AVariant20167493.$var = anf_assign971494;
var anf_assign972496 = G(AVariant20167493.$var,"AVariant",L[885]);
AVariant168495.$var = anf_assign972496;
var anf_assign973498 = G(AVariant20167493.$var,"AVariant",L[885]);
is_DASH_AVariant169497.$var = anf_assign973498;
var anf_assign974500 = G(AVariant20167493.$var,"is-a-variant",L[884]);
is_DASH_a_DASH_variant170499.$var = anf_assign974500;
var anf_assign975502 = G(AVariant20167493.$var,"a-variant",L[884]);
a_DASH_variant171501.$var = anf_assign975502;
var anf_assign976504 = G(AVariant20167493.$var,"is-a-singleton-variant",L[883]);
is_DASH_a_DASH_singleton_DASH_variant172503.$var = anf_assign976504;
var anf_assign977506 = G(AVariant20167493.$var,"a-singleton-variant",L[883]);
a_DASH_singleton_DASH_variant173505.$var = anf_assign977506;
var anf_singleton_variant_member9885430 = R.makeMethod(function(self1115613) {
return function(cases_DASH_funs1125592,else_DASH_clause1135603) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[872],2,arguments);
}
var if_DASH_1155606 = R.hasField(cases_DASH_funs1125592,("a-normal"));
var if_helper9795590 = R.makeFunction(function(if_helper_arg9805611) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[872],1,arguments);
}
var ann_DASH_check_DASH_temp9785612 = if_helper_arg9805611;
return ann_DASH_check_DASH_temp9785612;
});
var anf_if9835610 = R.isBoolean(if_DASH_1155606);
if(R.isPyretTrue(anf_if9835610)) {
if(R.isPyretTrue(if_DASH_1155606)) {
var call_DASH_a_DASH_normal1105588 = G(cases_DASH_funs1125592,"a-normal",L[872]);
var $z55805581 = D;
var $f55865587 = function(_) {
return R.isFunction(call_DASH_a_DASH_normal1105588)?call_DASH_a_DASH_normal1105588.app():R.ffi.throwNonFunApp(L[872],call_DASH_a_DASH_normal1105588,[]);
};
try {
if(--R.GAS > 0) {
$z55805581 = $f55865587();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55865587,
"from":L[872]});
}
} catch($e55785579) {
if(R.isCont($e55785579)) {
var $ss55825583 = {"from":L[872],
"go":function(cont_tail_arg9865589) {
return $Hcont_tail_arg32175591(cont_tail_arg9865589,if_helper9795590);
}};
$e55785579.stack[R.EXN_STACKHEIGHT++] = $ss55825583;
}
if(R.isPyretException($e55785579)) {
$e55785579.pyretStack.push(L[872]);
}
throw $e55785579;
}
var $ret55845585 = $Hcont_tail_arg32175591($z55805581,if_helper9795590);
++R.GAS;
return $ret55845585;
} else {
var $z55955596 = D;
var $f56015602 = function(_) {
return R.isFunction(else_DASH_clause1135603)?else_DASH_clause1135603.app():R.ffi.throwNonFunApp(L[872],else_DASH_clause1135603,[]);
};
try {
if(--R.GAS > 0) {
$z55955596 = $f56015602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56015602,
"from":L[872]});
}
} catch($e55935594) {
if(R.isCont($e55935594)) {
var $ss55975598 = {"from":L[872],
"go":function(cont_tail_arg9845604) {
return $Hcont_tail_arg32185605(cont_tail_arg9845604,if_helper9795590);
}};
$e55935594.stack[R.EXN_STACKHEIGHT++] = $ss55975598;
}
if(R.isPyretException($e55935594)) {
$e55935594.pyretStack.push(L[872]);
}
throw $e55935594;
}
var $ret55995600 = $Hcont_tail_arg32185605($z55955596,if_helper9795590);
++R.GAS;
return $ret55995600;
}
} else {
var cont_tail_arg9815609 = R.throwNonBooleanCondition(L[872],("if"),if_DASH_1155606);
if(--R.GAS > 0) {
$z56075608 = R.isFunction(if_helper9795590)?if_helper9795590.app(cont_tail_arg9815609):R.ffi.throwNonFunApp(L[872],if_helper9795590,[cont_tail_arg9815609]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9795590)?if_helper9795590.app(cont_tail_arg9815609):R.ffi.throwNonFunApp(L[872],if_helper9795590,[cont_tail_arg9815609]);
},
"from":L[872]});
}
++R.GAS;
return $z56075608;
}
};
},{"length":3});
var anf_singleton_variant_member9905431 = R.makeMethod(function(self1145577) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[872],0,arguments);
}
var ann_DASH_check_DASH_temp9895576 = ("a-normal");
return ann_DASH_check_DASH_temp9895576;
};
},{"length":1});
var anf_singleton_variant_member9925432 = R.makeMethod(function(self3635575) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[882],0,arguments);
}
var ann_DASH_check_DASH_temp9915574 = ("a-normal");
return ann_DASH_check_DASH_temp9915574;
};
},{"length":1});
var anf_singleton_variant_member9955433 = R.makeMethod(function(self3645573) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[880],0,arguments);
}
var anf_fun9945570 = G(PP337,"str",L[881]);
var $z55625563 = D;
var $f55685569 = function(_) {
return R.isFunction(anf_fun9945570)?anf_fun9945570.app(("")):R.ffi.throwNonFunApp(L[880],anf_fun9945570,[("")]);
};
try {
if(--R.GAS > 0) {
$z55625563 = $f55685569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55685569,
"from":L[880]});
}
} catch($e55605561) {
if(R.isCont($e55605561)) {
var $ss55645565 = {"from":L[880],
"go":function(ann_DASH_check_DASH_temp9935571) {
return $Hann_DASH_check_DASH_temp32195572(ann_DASH_check_DASH_temp9935571);
}};
$e55605561.stack[R.EXN_STACKHEIGHT++] = $ss55645565;
}
if(R.isPyretException($e55605561)) {
$e55605561.pyretStack.push(L[880]);
}
throw $e55605561;
}
var $ret55665567 = $Hann_DASH_check_DASH_temp32195572($z55625563);
++R.GAS;
return $ret55665567;
};
},{"length":1});
var anf_singleton_variant_member10065439 = R.makeMethod(function(self1175559) {
return function(cases_DASH_funs1185538,else_DASH_clause1195549) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[871],2,arguments);
}
var if_DASH_1215552 = R.hasField(cases_DASH_funs1185538,("a-cyclic"));
var if_helper9975536 = R.makeFunction(function(if_helper_arg9985557) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[871],1,arguments);
}
var ann_DASH_check_DASH_temp9965558 = if_helper_arg9985557;
return ann_DASH_check_DASH_temp9965558;
});
var anf_if10015556 = R.isBoolean(if_DASH_1215552);
if(R.isPyretTrue(anf_if10015556)) {
if(R.isPyretTrue(if_DASH_1215552)) {
var call_DASH_a_DASH_cyclic1165534 = G(cases_DASH_funs1185538,"a-cyclic",L[871]);
var $z55265527 = D;
var $f55325533 = function(_) {
return R.isFunction(call_DASH_a_DASH_cyclic1165534)?call_DASH_a_DASH_cyclic1165534.app():R.ffi.throwNonFunApp(L[871],call_DASH_a_DASH_cyclic1165534,[]);
};
try {
if(--R.GAS > 0) {
$z55265527 = $f55325533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55325533,
"from":L[871]});
}
} catch($e55245525) {
if(R.isCont($e55245525)) {
var $ss55285529 = {"from":L[871],
"go":function(cont_tail_arg10045535) {
return $Hcont_tail_arg32205537(cont_tail_arg10045535,if_helper9975536);
}};
$e55245525.stack[R.EXN_STACKHEIGHT++] = $ss55285529;
}
if(R.isPyretException($e55245525)) {
$e55245525.pyretStack.push(L[871]);
}
throw $e55245525;
}
var $ret55305531 = $Hcont_tail_arg32205537($z55265527,if_helper9975536);
++R.GAS;
return $ret55305531;
} else {
var $z55415542 = D;
var $f55475548 = function(_) {
return R.isFunction(else_DASH_clause1195549)?else_DASH_clause1195549.app():R.ffi.throwNonFunApp(L[871],else_DASH_clause1195549,[]);
};
try {
if(--R.GAS > 0) {
$z55415542 = $f55475548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55475548,
"from":L[871]});
}
} catch($e55395540) {
if(R.isCont($e55395540)) {
var $ss55435544 = {"from":L[871],
"go":function(cont_tail_arg10025550) {
return $Hcont_tail_arg32215551(cont_tail_arg10025550,if_helper9975536);
}};
$e55395540.stack[R.EXN_STACKHEIGHT++] = $ss55435544;
}
if(R.isPyretException($e55395540)) {
$e55395540.pyretStack.push(L[871]);
}
throw $e55395540;
}
var $ret55455546 = $Hcont_tail_arg32215551($z55415542,if_helper9975536);
++R.GAS;
return $ret55455546;
}
} else {
var cont_tail_arg9995555 = R.throwNonBooleanCondition(L[871],("if"),if_DASH_1215552);
if(--R.GAS > 0) {
$z55535554 = R.isFunction(if_helper9975536)?if_helper9975536.app(cont_tail_arg9995555):R.ffi.throwNonFunApp(L[871],if_helper9975536,[cont_tail_arg9995555]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9975536)?if_helper9975536.app(cont_tail_arg9995555):R.ffi.throwNonFunApp(L[871],if_helper9975536,[cont_tail_arg9995555]);
},
"from":L[871]});
}
++R.GAS;
return $z55535554;
}
};
},{"length":3});
var anf_singleton_variant_member10085440 = R.makeMethod(function(self1205523) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[871],0,arguments);
}
var ann_DASH_check_DASH_temp10075522 = ("a-cyclic");
return ann_DASH_check_DASH_temp10075522;
};
},{"length":1});
var anf_singleton_variant_member10105441 = R.makeMethod(function(self3655521) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[879],0,arguments);
}
var ann_DASH_check_DASH_temp10095520 = ("a-cyclic");
return ann_DASH_check_DASH_temp10095520;
};
},{"length":1});
var anf_singleton_variant_member10135442 = R.makeMethod(function(self3665519) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[877],0,arguments);
}
var anf_fun10125516 = G(PP337,"str",L[878]);
var $z55085509 = D;
var $f55145515 = function(_) {
return R.isFunction(anf_fun10125516)?anf_fun10125516.app(("cyclic ")):R.ffi.throwNonFunApp(L[877],anf_fun10125516,[("cyclic ")]);
};
try {
if(--R.GAS > 0) {
$z55085509 = $f55145515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55145515,
"from":L[877]});
}
} catch($e55065507) {
if(R.isCont($e55065507)) {
var $ss55105511 = {"from":L[877],
"go":function(ann_DASH_check_DASH_temp10115517) {
return $Hann_DASH_check_DASH_temp32225518(ann_DASH_check_DASH_temp10115517);
}};
$e55065507.stack[R.EXN_STACKHEIGHT++] = $ss55105511;
}
if(R.isPyretException($e55065507)) {
$e55065507.pyretStack.push(L[877]);
}
throw $e55065507;
}
var $ret55125513 = $Hann_DASH_check_DASH_temp32225518($z55085509);
++R.GAS;
return $ret55125513;
};
},{"length":1});
var anf_singleton_variant_member10245448 = R.makeMethod(function(self1235505) {
return function(cases_DASH_funs1245484,else_DASH_clause1255495) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[870],2,arguments);
}
var if_DASH_1275498 = R.hasField(cases_DASH_funs1245484,("a-mutable"));
var if_helper10155482 = R.makeFunction(function(if_helper_arg10165503) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[870],1,arguments);
}
var ann_DASH_check_DASH_temp10145504 = if_helper_arg10165503;
return ann_DASH_check_DASH_temp10145504;
});
var anf_if10195502 = R.isBoolean(if_DASH_1275498);
if(R.isPyretTrue(anf_if10195502)) {
if(R.isPyretTrue(if_DASH_1275498)) {
var call_DASH_a_DASH_mutable1225480 = G(cases_DASH_funs1245484,"a-mutable",L[870]);
var $z54725473 = D;
var $f54785479 = function(_) {
return R.isFunction(call_DASH_a_DASH_mutable1225480)?call_DASH_a_DASH_mutable1225480.app():R.ffi.throwNonFunApp(L[870],call_DASH_a_DASH_mutable1225480,[]);
};
try {
if(--R.GAS > 0) {
$z54725473 = $f54785479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54785479,
"from":L[870]});
}
} catch($e54705471) {
if(R.isCont($e54705471)) {
var $ss54745475 = {"from":L[870],
"go":function(cont_tail_arg10225481) {
return $Hcont_tail_arg32235483(cont_tail_arg10225481,if_helper10155482);
}};
$e54705471.stack[R.EXN_STACKHEIGHT++] = $ss54745475;
}
if(R.isPyretException($e54705471)) {
$e54705471.pyretStack.push(L[870]);
}
throw $e54705471;
}
var $ret54765477 = $Hcont_tail_arg32235483($z54725473,if_helper10155482);
++R.GAS;
return $ret54765477;
} else {
var $z54875488 = D;
var $f54935494 = function(_) {
return R.isFunction(else_DASH_clause1255495)?else_DASH_clause1255495.app():R.ffi.throwNonFunApp(L[870],else_DASH_clause1255495,[]);
};
try {
if(--R.GAS > 0) {
$z54875488 = $f54935494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54935494,
"from":L[870]});
}
} catch($e54855486) {
if(R.isCont($e54855486)) {
var $ss54895490 = {"from":L[870],
"go":function(cont_tail_arg10205496) {
return $Hcont_tail_arg32245497(cont_tail_arg10205496,if_helper10155482);
}};
$e54855486.stack[R.EXN_STACKHEIGHT++] = $ss54895490;
}
if(R.isPyretException($e54855486)) {
$e54855486.pyretStack.push(L[870]);
}
throw $e54855486;
}
var $ret54915492 = $Hcont_tail_arg32245497($z54875488,if_helper10155482);
++R.GAS;
return $ret54915492;
}
} else {
var cont_tail_arg10175501 = R.throwNonBooleanCondition(L[870],("if"),if_DASH_1275498);
if(--R.GAS > 0) {
$z54995500 = R.isFunction(if_helper10155482)?if_helper10155482.app(cont_tail_arg10175501):R.ffi.throwNonFunApp(L[870],if_helper10155482,[cont_tail_arg10175501]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper10155482)?if_helper10155482.app(cont_tail_arg10175501):R.ffi.throwNonFunApp(L[870],if_helper10155482,[cont_tail_arg10175501]);
},
"from":L[870]});
}
++R.GAS;
return $z54995500;
}
};
},{"length":3});
var anf_singleton_variant_member10265449 = R.makeMethod(function(self1265469) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[870],0,arguments);
}
var ann_DASH_check_DASH_temp10255468 = ("a-mutable");
return ann_DASH_check_DASH_temp10255468;
};
},{"length":1});
var anf_singleton_variant_member10285450 = R.makeMethod(function(self3675467) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[876],0,arguments);
}
var ann_DASH_check_DASH_temp10275466 = ("a-mutable");
return ann_DASH_check_DASH_temp10275466;
};
},{"length":1});
var anf_singleton_variant_member10315451 = R.makeMethod(function(self3685465) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[874],0,arguments);
}
var anf_fun10305462 = G(PP337,"str",L[875]);
var $z54545455 = D;
var $f54605461 = function(_) {
return R.isFunction(anf_fun10305462)?anf_fun10305462.app(("mutable ")):R.ffi.throwNonFunApp(L[874],anf_fun10305462,[("mutable ")]);
};
try {
if(--R.GAS > 0) {
$z54545455 = $f54605461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54605461,
"from":L[874]});
}
} catch($e54525453) {
if(R.isCont($e54525453)) {
var $ss54565457 = {"from":L[874],
"go":function(ann_DASH_check_DASH_temp10295463) {
return $Hann_DASH_check_DASH_temp32255464(ann_DASH_check_DASH_temp10295463);
}};
$e54525453.stack[R.EXN_STACKHEIGHT++] = $ss54565457;
}
if(R.isPyretException($e54525453)) {
$e54525453.pyretStack.push(L[874]);
}
throw $e54525453;
}
var $ret54585459 = $Hann_DASH_check_DASH_temp32255464($z54545455);
++R.GAS;
return $ret54585459;
};
},{"length":1});
var anf_assign1032508 = (function() {
var $a_DASH_normal_DASH_base54255426 = {"_match":anf_singleton_variant_member9885430,
"_torepr":anf_singleton_variant_member9905431,
"label":anf_singleton_variant_member9925432,
"tosource":anf_singleton_variant_member9955433};
var $a_DASH_normal_DASH_brands54285429 = {"$brand-a-normal5427":true};
$a_DASH_normal_DASH_brands54285429[AMemberTypeT98176._brand] = true
var $a_DASH_cyclic_DASH_base54345435 = {"_match":anf_singleton_variant_member10065439,
"_torepr":anf_singleton_variant_member10085440,
"label":anf_singleton_variant_member10105441,
"tosource":anf_singleton_variant_member10135442};
var $a_DASH_cyclic_DASH_brands54375438 = {"$brand-a-cyclic5436":true};
$a_DASH_cyclic_DASH_brands54375438[AMemberTypeT98176._brand] = true
var $a_DASH_mutable_DASH_base54435444 = {"_match":anf_singleton_variant_member10245448,
"_torepr":anf_singleton_variant_member10265449,
"label":anf_singleton_variant_member10285450,
"tosource":anf_singleton_variant_member10315451};
var $a_DASH_mutable_DASH_brands54465447 = {"$brand-a-mutable5445":true};
$a_DASH_mutable_DASH_brands54465447[AMemberTypeT98176._brand] = true
return R.makeObject({"AMemberType":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[873],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AMemberTypeT98176._brand));
}),
"is-a-normal":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[872],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-normal5427"));
}),
"a-normal":R.makeBrandedObject($a_DASH_normal_DASH_base54255426,$a_DASH_normal_DASH_brands54285429),
"is-a-cyclic":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[871],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-cyclic5436"));
}),
"a-cyclic":R.makeBrandedObject($a_DASH_cyclic_DASH_base54345435,$a_DASH_cyclic_DASH_brands54375438),
"is-a-mutable":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[870],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-mutable5445"));
}),
"a-mutable":R.makeBrandedObject($a_DASH_mutable_DASH_base54435444,$a_DASH_mutable_DASH_brands54465447)});
})();
AMemberType21174507.$var = anf_assign1032508;
var anf_assign1033510 = G(AMemberType21174507.$var,"AMemberType",L[873]);
AMemberType175509.$var = anf_assign1033510;
var anf_assign1034512 = G(AMemberType21174507.$var,"AMemberType",L[873]);
is_DASH_AMemberType176511.$var = anf_assign1034512;
var anf_assign1035514 = G(AMemberType21174507.$var,"is-a-normal",L[872]);
is_DASH_a_DASH_normal177513.$var = anf_assign1035514;
var anf_assign1036516 = G(AMemberType21174507.$var,"a-normal",L[872]);
a_DASH_normal178515.$var = anf_assign1036516;
var anf_assign1037518 = G(AMemberType21174507.$var,"is-a-cyclic",L[871]);
is_DASH_a_DASH_cyclic179517.$var = anf_assign1037518;
var anf_assign1038520 = G(AMemberType21174507.$var,"a-cyclic",L[871]);
a_DASH_cyclic180519.$var = anf_assign1038520;
var anf_assign1039522 = G(AMemberType21174507.$var,"is-a-mutable",L[870]);
is_DASH_a_DASH_mutable181521.$var = anf_assign1039522;
var anf_assign1040524 = G(AMemberType21174507.$var,"a-mutable",L[870]);
a_DASH_mutable182523.$var = anf_assign1040524;
var anf_shared10485313 = R.makeMethod(function(self3745424) {
return function(visitor3755407) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[865],1,arguments);
}
var anf_fun10425406 = G(self3745424,"_match",L[869]);
var anf_arg10475408 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[866],0,arguments);
}
var anf_fun10445421 = G(self3745424,"label",L[868]);
var $z54135414 = D;
var $f54195420 = function(_) {
return R.isFunction(anf_fun10445421)?anf_fun10445421.app():R.ffi.throwNonFunApp(L[867],anf_fun10445421,[]);
};
try {
if(--R.GAS > 0) {
$z54135414 = $f54195420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54195420,
"from":L[867]});
}
} catch($e54115412) {
if(R.isCont($e54115412)) {
var $ss54155416 = {"from":L[867],
"go":function(anf_arg10455422) {
return $Hanf_arg32285423(anf_arg10455422,_plus26,raise30);
}};
$e54115412.stack[R.EXN_STACKHEIGHT++] = $ss54155416;
}
if(R.isPyretException($e54115412)) {
$e54115412.pyretStack.push(L[867]);
}
throw $e54115412;
}
var $ret54175418 = $Hanf_arg32285423($z54135414,_plus26,raise30);
++R.GAS;
return $ret54175418;
});
var $z53985399 = D;
var $f54045405 = function(_) {
return R.isFunction(anf_fun10425406)?anf_fun10425406.app(visitor3755407,anf_arg10475408):R.ffi.throwNonFunApp(L[865],anf_fun10425406,[visitor3755407,anf_arg10475408]);
};
try {
if(--R.GAS > 0) {
$z53985399 = $f54045405();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54045405,
"from":L[865]});
}
} catch($e53965397) {
if(R.isCont($e53965397)) {
var $ss54005401 = {"from":L[865],
"go":function(ann_DASH_check_DASH_temp10415409) {
return $Hann_DASH_check_DASH_temp32295410(ann_DASH_check_DASH_temp10415409);
}};
$e53965397.stack[R.EXN_STACKHEIGHT++] = $ss54005401;
}
if(R.isPyretException($e53965397)) {
$e53965397.pyretStack.push(L[865]);
}
throw $e53965397;
}
var $ret54025403 = $Hann_DASH_check_DASH_temp32295410($z53985399);
++R.GAS;
return $ret54025403;
};
},{"length":2});
var anf_variant_member10625319 = R.makeMethod(function(self1295374) {
return function(cases_DASH_funs1305375,else_DASH_clause1315386) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[851],2,arguments);
}
var if_DASH_1335389 = R.hasField(cases_DASH_funs1305375,("a-variant-member"));
var if_helper10505372 = R.makeFunction(function(if_helper_arg10515394) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[851],1,arguments);
}
var ann_DASH_check_DASH_temp10495395 = if_helper_arg10515394;
return ann_DASH_check_DASH_temp10495395;
});
var anf_if10545393 = R.isBoolean(if_DASH_1335389);
if(R.isPyretTrue(anf_if10545393)) {
if(R.isPyretTrue(if_DASH_1335389)) {
var call_DASH_a_DASH_variant_DASH_member1285367 = G(cases_DASH_funs1305375,"a-variant-member",L[851]);
var anf_arg10575368 = G(self1295374,"l",L[864]);
var anf_arg10585369 = G(self1295374,"member-type",L[863]);
var anf_arg10595370 = G(self1295374,"bind",L[862]);
var $z53595360 = D;
var $f53655366 = function(_) {
return R.isFunction(call_DASH_a_DASH_variant_DASH_member1285367)?call_DASH_a_DASH_variant_DASH_member1285367.app(anf_arg10575368,anf_arg10585369,anf_arg10595370):R.ffi.throwNonFunApp(L[851],call_DASH_a_DASH_variant_DASH_member1285367,[anf_arg10575368,anf_arg10585369,anf_arg10595370]);
};
try {
if(--R.GAS > 0) {
$z53595360 = $f53655366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53655366,
"from":L[851]});
}
} catch($e53575358) {
if(R.isCont($e53575358)) {
var $ss53615362 = {"from":L[851],
"go":function(cont_tail_arg10605371) {
return $Hcont_tail_arg32305373(cont_tail_arg10605371,if_helper10505372);
}};
$e53575358.stack[R.EXN_STACKHEIGHT++] = $ss53615362;
}
if(R.isPyretException($e53575358)) {
$e53575358.pyretStack.push(L[851]);
}
throw $e53575358;
}
var $ret53635364 = $Hcont_tail_arg32305373($z53595360,if_helper10505372);
++R.GAS;
return $ret53635364;
} else {
var $z53785379 = D;
var $f53845385 = function(_) {
return R.isFunction(else_DASH_clause1315386)?else_DASH_clause1315386.app():R.ffi.throwNonFunApp(L[851],else_DASH_clause1315386,[]);
};
try {
if(--R.GAS > 0) {
$z53785379 = $f53845385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53845385,
"from":L[851]});
}
} catch($e53765377) {
if(R.isCont($e53765377)) {
var $ss53805381 = {"from":L[851],
"go":function(cont_tail_arg10555387) {
return $Hcont_tail_arg32315388(cont_tail_arg10555387,if_helper10505372);
}};
$e53765377.stack[R.EXN_STACKHEIGHT++] = $ss53805381;
}
if(R.isPyretException($e53765377)) {
$e53765377.pyretStack.push(L[851]);
}
throw $e53765377;
}
var $ret53825383 = $Hcont_tail_arg32315388($z53785379,if_helper10505372);
++R.GAS;
return $ret53825383;
}
} else {
var cont_tail_arg10525392 = R.throwNonBooleanCondition(L[851],("if"),if_DASH_1335389);
if(--R.GAS > 0) {
$z53905391 = R.isFunction(if_helper10505372)?if_helper10505372.app(cont_tail_arg10525392):R.ffi.throwNonFunApp(L[851],if_helper10505372,[cont_tail_arg10525392]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper10505372)?if_helper10505372.app(cont_tail_arg10525392):R.ffi.throwNonFunApp(L[851],if_helper10505372,[cont_tail_arg10525392]);
},
"from":L[851]});
}
++R.GAS;
return $z53905391;
}
};
},{"length":3});
var anf_variant_member10765320 = R.makeMethod(function(self1325355) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[851],0,arguments);
}
var anf_arg10645353 = G(self1325355,"l",L[851]);
var $z53455346 = D;
var $f53515352 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg10645353):R.ffi.throwNonFunApp(L[851],torepr31,[anf_arg10645353]);
};
try {
if(--R.GAS > 0) {
$z53455346 = $f53515352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53515352,
"from":L[851]});
}
} catch($e53435344) {
if(R.isCont($e53435344)) {
var $ss53475348 = {"from":L[851],
"go":function(anf_arg10655354) {
return $Hanf_arg32415356(anf_arg10655354,self1325355,_plus26,torepr31);
}};
$e53435344.stack[R.EXN_STACKHEIGHT++] = $ss53475348;
}
if(R.isPyretException($e53435344)) {
$e53435344.pyretStack.push(L[851]);
}
throw $e53435344;
}
var $ret53495350 = $Hanf_arg32415356($z53455346,self1325355,_plus26,torepr31);
++R.GAS;
return $ret53495350;
};
},{"length":1});
var anf_variant_member10785321 = R.makeMethod(function(self3725342) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[861],0,arguments);
}
var ann_DASH_check_DASH_temp10775341 = ("a-variant-member");
return ann_DASH_check_DASH_temp10775341;
};
},{"length":1});
var anf_variant_member10865322 = R.makeMethod(function(self3735338) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[860],0,arguments);
}
var anf_bracket10805340 = G(self3735338,"member_type",L[859]);
var anf_fun10815336 = G(anf_bracket10805340,"tosource",L[858]);
var $z53285329 = D;
var $f53345335 = function(_) {
return R.isFunction(anf_fun10815336)?anf_fun10815336.app():R.ffi.throwNonFunApp(L[857],anf_fun10815336,[]);
};
try {
if(--R.GAS > 0) {
$z53285329 = $f53345335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53345335,
"from":L[857]});
}
} catch($e53265327) {
if(R.isCont($e53265327)) {
var $ss53305331 = {"from":L[857],
"go":function(anf_arg10825337) {
return $Hanf_arg32445339(anf_arg10825337,self3735338,_plus26);
}};
$e53265327.stack[R.EXN_STACKHEIGHT++] = $ss53305331;
}
if(R.isPyretException($e53265327)) {
$e53265327.pyretStack.push(L[857]);
}
throw $e53265327;
}
var $ret53325333 = $Hanf_arg32445339($z53285329,self3735338,_plus26);
++R.GAS;
return $ret53325333;
};
},{"length":1});
var anf_assign1087526 = (function() {
var $a_DASH_variant_DASH_member_DASH_base53145315 = {"visit":anf_shared10485313,
"_match":anf_variant_member10625319,
"_torepr":anf_variant_member10765320,
"label":anf_variant_member10785321,
"tosource":anf_variant_member10865322};
var $a_DASH_variant_DASH_member_DASH_brands53175318 = {"$brand-a-variant-member5316":true};
$a_DASH_variant_DASH_member_DASH_brands53175318[AVariantMemberT108385._brand] = true
return R.makeObject({"AVariantMember":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[852],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AVariantMemberT108385._brand));
}),
"is-a-variant-member":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[851],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-variant-member5316"));
}),
"a-variant-member":R.makeFunction(function(l3695323,member_DASH_type3705324,bind3715325) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[853],3,arguments);
}
return R.checkAnnArgs([Loc9089,AMemberType8075,ABind7663],[l3695323,member_DASH_type3705324,bind3715325],[L[854],L[855],L[856]],function() {
var dict = R.create($a_DASH_variant_DASH_member_DASH_base53145315);
dict["l"] = l3695323
dict["member-type"] = member_DASH_type3705324
dict["bind"] = bind3715325
return R.makeBrandedObject(dict,$a_DASH_variant_DASH_member_DASH_brands53175318);
});
})});
})();
AVariantMember22183525.$var = anf_assign1087526;
var anf_assign1088528 = G(AVariantMember22183525.$var,"AVariantMember",L[852]);
AVariantMember184527.$var = anf_assign1088528;
var anf_assign1089530 = G(AVariantMember22183525.$var,"AVariantMember",L[852]);
is_DASH_AVariantMember185529.$var = anf_assign1089530;
var anf_assign1090532 = G(AVariantMember22183525.$var,"is-a-variant-member",L[851]);
is_DASH_a_DASH_variant_DASH_member186531.$var = anf_assign1090532;
var anf_assign1091534 = G(AVariantMember22183525.$var,"a-variant-member",L[851]);
a_DASH_variant_DASH_member187533.$var = anf_assign1091534;
var anf_shared10994127 = R.makeMethod(function(self4535312) {
return function(visitor4545295) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[846],1,arguments);
}
var anf_fun10935294 = G(self4535312,"_match",L[850]);
var anf_arg10985296 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[847],0,arguments);
}
var anf_fun10955309 = G(self4535312,"label",L[849]);
var $z53015302 = D;
var $f53075308 = function(_) {
return R.isFunction(anf_fun10955309)?anf_fun10955309.app():R.ffi.throwNonFunApp(L[848],anf_fun10955309,[]);
};
try {
if(--R.GAS > 0) {
$z53015302 = $f53075308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53075308,
"from":L[848]});
}
} catch($e52995300) {
if(R.isCont($e52995300)) {
var $ss53035304 = {"from":L[848],
"go":function(anf_arg10965310) {
return $Hanf_arg32475311(anf_arg10965310,_plus26,raise30);
}};
$e52995300.stack[R.EXN_STACKHEIGHT++] = $ss53035304;
}
if(R.isPyretException($e52995300)) {
$e52995300.pyretStack.push(L[848]);
}
throw $e52995300;
}
var $ret53055306 = $Hanf_arg32475311($z53015302,_plus26,raise30);
++R.GAS;
return $ret53055306;
});
var $z52865287 = D;
var $f52925293 = function(_) {
return R.isFunction(anf_fun10935294)?anf_fun10935294.app(visitor4545295,anf_arg10985296):R.ffi.throwNonFunApp(L[846],anf_fun10935294,[visitor4545295,anf_arg10985296]);
};
try {
if(--R.GAS > 0) {
$z52865287 = $f52925293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52925293,
"from":L[846]});
}
} catch($e52845285) {
if(R.isCont($e52845285)) {
var $ss52885289 = {"from":L[846],
"go":function(ann_DASH_check_DASH_temp10925297) {
return $Hann_DASH_check_DASH_temp32485298(ann_DASH_check_DASH_temp10925297);
}};
$e52845285.stack[R.EXN_STACKHEIGHT++] = $ss52885289;
}
if(R.isPyretException($e52845285)) {
$e52845285.pyretStack.push(L[846]);
}
throw $e52845285;
}
var $ret52905291 = $Hann_DASH_check_DASH_temp32485298($z52865287);
++R.GAS;
return $ret52905291;
};
},{"length":2});
var anf_variant_member11154133 = R.makeMethod(function(self1355262) {
return function(cases_DASH_funs1365263,else_DASH_clause1375274) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[673],2,arguments);
}
var if_DASH_1395277 = R.hasField(cases_DASH_funs1365263,("a-module"));
var if_helper11015260 = R.makeFunction(function(if_helper_arg11025282) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[673],1,arguments);
}
var ann_DASH_check_DASH_temp11005283 = if_helper_arg11025282;
return ann_DASH_check_DASH_temp11005283;
});
var anf_if11055281 = R.isBoolean(if_DASH_1395277);
if(R.isPyretTrue(anf_if11055281)) {
if(R.isPyretTrue(if_DASH_1395277)) {
var call_DASH_a_DASH_module1345253 = G(cases_DASH_funs1365263,"a-module",L[673]);
var anf_arg11085254 = G(self1355262,"l",L[845]);
var anf_arg11095255 = G(self1355262,"answer",L[844]);
var anf_arg11105256 = G(self1355262,"provides",L[843]);
var anf_arg11115257 = G(self1355262,"types",L[842]);
var anf_arg11125258 = G(self1355262,"checks",L[841]);
var $z52455246 = D;
var $f52515252 = function(_) {
return R.isFunction(call_DASH_a_DASH_module1345253)?call_DASH_a_DASH_module1345253.app(anf_arg11085254,anf_arg11095255,anf_arg11105256,anf_arg11115257,anf_arg11125258):R.ffi.throwNonFunApp(L[673],call_DASH_a_DASH_module1345253,[anf_arg11085254,anf_arg11095255,anf_arg11105256,anf_arg11115257,anf_arg11125258]);
};
try {
if(--R.GAS > 0) {
$z52455246 = $f52515252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52515252,
"from":L[673]});
}
} catch($e52435244) {
if(R.isCont($e52435244)) {
var $ss52475248 = {"from":L[673],
"go":function(cont_tail_arg11135259) {
return $Hcont_tail_arg32495261(cont_tail_arg11135259,if_helper11015260);
}};
$e52435244.stack[R.EXN_STACKHEIGHT++] = $ss52475248;
}
if(R.isPyretException($e52435244)) {
$e52435244.pyretStack.push(L[673]);
}
throw $e52435244;
}
var $ret52495250 = $Hcont_tail_arg32495261($z52455246,if_helper11015260);
++R.GAS;
return $ret52495250;
} else {
var $z52665267 = D;
var $f52725273 = function(_) {
return R.isFunction(else_DASH_clause1375274)?else_DASH_clause1375274.app():R.ffi.throwNonFunApp(L[673],else_DASH_clause1375274,[]);
};
try {
if(--R.GAS > 0) {
$z52665267 = $f52725273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52725273,
"from":L[673]});
}
} catch($e52645265) {
if(R.isCont($e52645265)) {
var $ss52685269 = {"from":L[673],
"go":function(cont_tail_arg11065275) {
return $Hcont_tail_arg32505276(cont_tail_arg11065275,if_helper11015260);
}};
$e52645265.stack[R.EXN_STACKHEIGHT++] = $ss52685269;
}
if(R.isPyretException($e52645265)) {
$e52645265.pyretStack.push(L[673]);
}
throw $e52645265;
}
var $ret52705271 = $Hcont_tail_arg32505276($z52665267,if_helper11015260);
++R.GAS;
return $ret52705271;
}
} else {
var cont_tail_arg11035280 = R.throwNonBooleanCondition(L[673],("if"),if_DASH_1395277);
if(--R.GAS > 0) {
$z52785279 = R.isFunction(if_helper11015260)?if_helper11015260.app(cont_tail_arg11035280):R.ffi.throwNonFunApp(L[673],if_helper11015260,[cont_tail_arg11035280]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper11015260)?if_helper11015260.app(cont_tail_arg11035280):R.ffi.throwNonFunApp(L[673],if_helper11015260,[cont_tail_arg11035280]);
},
"from":L[673]});
}
++R.GAS;
return $z52785279;
}
};
},{"length":3});
var anf_variant_member11374134 = R.makeMethod(function(self1385241) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[673],0,arguments);
}
var anf_arg11175239 = G(self1385241,"l",L[673]);
var $z52315232 = D;
var $f52375238 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg11175239):R.ffi.throwNonFunApp(L[673],torepr31,[anf_arg11175239]);
};
try {
if(--R.GAS > 0) {
$z52315232 = $f52375238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52375238,
"from":L[673]});
}
} catch($e52295230) {
if(R.isCont($e52295230)) {
var $ss52335234 = {"from":L[673],
"go":function(anf_arg11185240) {
return $Hanf_arg32665242(anf_arg11185240,self1385241,_plus26,torepr31);
}};
$e52295230.stack[R.EXN_STACKHEIGHT++] = $ss52335234;
}
if(R.isPyretException($e52295230)) {
$e52295230.pyretStack.push(L[673]);
}
throw $e52295230;
}
var $ret52355236 = $Hanf_arg32665242($z52315232,self1385241,_plus26,torepr31);
++R.GAS;
return $ret52355236;
};
},{"length":1});
var anf_variant_member11394135 = R.makeMethod(function(self3815228) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[840],0,arguments);
}
var ann_DASH_check_DASH_temp11385227 = ("a-module");
return ann_DASH_check_DASH_temp11385227;
};
},{"length":1});
var anf_variant_member11864136 = R.makeMethod(function(self3825225) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[839],0,arguments);
}
var anf_fun11415223 = G(PP337,"str",L[838]);
var $z52155216 = D;
var $f52215222 = function(_) {
return R.isFunction(anf_fun11415223)?anf_fun11415223.app(("Module")):R.ffi.throwNonFunApp(L[837],anf_fun11415223,[("Module")]);
};
try {
if(--R.GAS > 0) {
$z52155216 = $f52215222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52215222,
"from":L[837]});
}
} catch($e52135214) {
if(R.isCont($e52135214)) {
var $ss52175218 = {"from":L[837],
"go":function(anf_arg11425224) {
return $Hanf_arg32855226(anf_arg11425224,INDENT9187,PP337,list2593,self3825225,str_DASH_colon98170,_plus26);
}};
$e52135214.stack[R.EXN_STACKHEIGHT++] = $ss52175218;
}
if(R.isPyretException($e52135214)) {
$e52135214.pyretStack.push(L[837]);
}
throw $e52135214;
}
var $ret52195220 = $Hanf_arg32855226($z52155216,INDENT9187,PP337,list2593,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret52195220;
};
},{"length":1});
var anf_variant_member12024147 = R.makeMethod(function(self1425191) {
return function(cases_DASH_funs1435192,else_DASH_clause1445203) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[672],2,arguments);
}
var if_DASH_1465206 = R.hasField(cases_DASH_funs1435192,("a-data-expr"));
var if_helper11885189 = R.makeFunction(function(if_helper_arg11895211) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[672],1,arguments);
}
var ann_DASH_check_DASH_temp11875212 = if_helper_arg11895211;
return ann_DASH_check_DASH_temp11875212;
});
var anf_if11925210 = R.isBoolean(if_DASH_1465206);
if(R.isPyretTrue(anf_if11925210)) {
if(R.isPyretTrue(if_DASH_1465206)) {
var call_DASH_a_DASH_data_DASH_expr1415182 = G(cases_DASH_funs1435192,"a-data-expr",L[672]);
var anf_arg11955183 = G(self1425191,"l",L[836]);
var anf_arg11965184 = G(self1425191,"name",L[835]);
var anf_arg11975185 = G(self1425191,"namet",L[834]);
var anf_arg11985186 = G(self1425191,"variants",L[833]);
var anf_arg11995187 = G(self1425191,"shared",L[832]);
var $z51745175 = D;
var $f51805181 = function(_) {
return R.isFunction(call_DASH_a_DASH_data_DASH_expr1415182)?call_DASH_a_DASH_data_DASH_expr1415182.app(anf_arg11955183,anf_arg11965184,anf_arg11975185,anf_arg11985186,anf_arg11995187):R.ffi.throwNonFunApp(L[672],call_DASH_a_DASH_data_DASH_expr1415182,[anf_arg11955183,anf_arg11965184,anf_arg11975185,anf_arg11985186,anf_arg11995187]);
};
try {
if(--R.GAS > 0) {
$z51745175 = $f51805181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51805181,
"from":L[672]});
}
} catch($e51725173) {
if(R.isCont($e51725173)) {
var $ss51765177 = {"from":L[672],
"go":function(cont_tail_arg12005188) {
return $Hcont_tail_arg32865190(cont_tail_arg12005188,if_helper11885189);
}};
$e51725173.stack[R.EXN_STACKHEIGHT++] = $ss51765177;
}
if(R.isPyretException($e51725173)) {
$e51725173.pyretStack.push(L[672]);
}
throw $e51725173;
}
var $ret51785179 = $Hcont_tail_arg32865190($z51745175,if_helper11885189);
++R.GAS;
return $ret51785179;
} else {
var $z51955196 = D;
var $f52015202 = function(_) {
return R.isFunction(else_DASH_clause1445203)?else_DASH_clause1445203.app():R.ffi.throwNonFunApp(L[672],else_DASH_clause1445203,[]);
};
try {
if(--R.GAS > 0) {
$z51955196 = $f52015202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52015202,
"from":L[672]});
}
} catch($e51935194) {
if(R.isCont($e51935194)) {
var $ss51975198 = {"from":L[672],
"go":function(cont_tail_arg11935204) {
return $Hcont_tail_arg32875205(cont_tail_arg11935204,if_helper11885189);
}};
$e51935194.stack[R.EXN_STACKHEIGHT++] = $ss51975198;
}
if(R.isPyretException($e51935194)) {
$e51935194.pyretStack.push(L[672]);
}
throw $e51935194;
}
var $ret51995200 = $Hcont_tail_arg32875205($z51955196,if_helper11885189);
++R.GAS;
return $ret51995200;
}
} else {
var cont_tail_arg11905209 = R.throwNonBooleanCondition(L[672],("if"),if_DASH_1465206);
if(--R.GAS > 0) {
$z52075208 = R.isFunction(if_helper11885189)?if_helper11885189.app(cont_tail_arg11905209):R.ffi.throwNonFunApp(L[672],if_helper11885189,[cont_tail_arg11905209]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper11885189)?if_helper11885189.app(cont_tail_arg11905209):R.ffi.throwNonFunApp(L[672],if_helper11885189,[cont_tail_arg11905209]);
},
"from":L[672]});
}
++R.GAS;
return $z52075208;
}
};
},{"length":3});
var anf_variant_member12244148 = R.makeMethod(function(self1455170) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[672],0,arguments);
}
var anf_arg12045168 = G(self1455170,"l",L[672]);
var $z51605161 = D;
var $f51665167 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg12045168):R.ffi.throwNonFunApp(L[672],torepr31,[anf_arg12045168]);
};
try {
if(--R.GAS > 0) {
$z51605161 = $f51665167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51665167,
"from":L[672]});
}
} catch($e51585159) {
if(R.isCont($e51585159)) {
var $ss51625163 = {"from":L[672],
"go":function(anf_arg12055169) {
return $Hanf_arg33035171(anf_arg12055169,self1455170,_plus26,torepr31);
}};
$e51585159.stack[R.EXN_STACKHEIGHT++] = $ss51625163;
}
if(R.isPyretException($e51585159)) {
$e51585159.pyretStack.push(L[672]);
}
throw $e51585159;
}
var $ret51645165 = $Hanf_arg33035171($z51605161,self1455170,_plus26,torepr31);
++R.GAS;
return $ret51645165;
};
},{"length":1});
var anf_variant_member12264149 = R.makeMethod(function(self3895157) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[831],0,arguments);
}
var ann_DASH_check_DASH_temp12255156 = ("a-data-expr");
return ann_DASH_check_DASH_temp12255156;
};
},{"length":1});
var anf_variant_member12294150 = R.makeMethod(function(self3905155) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[829],0,arguments);
}
var anf_fun12285152 = G(PP337,"str",L[830]);
var $z51445145 = D;
var $f51505151 = function(_) {
return R.isFunction(anf_fun12285152)?anf_fun12285152.app(("data-expr")):R.ffi.throwNonFunApp(L[829],anf_fun12285152,[("data-expr")]);
};
try {
if(--R.GAS > 0) {
$z51445145 = $f51505151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51505151,
"from":L[829]});
}
} catch($e51425143) {
if(R.isCont($e51425143)) {
var $ss51465147 = {"from":L[829],
"go":function(ann_DASH_check_DASH_temp12275153) {
return $Hann_DASH_check_DASH_temp33045154(ann_DASH_check_DASH_temp12275153);
}};
$e51425143.stack[R.EXN_STACKHEIGHT++] = $ss51465147;
}
if(R.isPyretException($e51425143)) {
$e51425143.pyretStack.push(L[829]);
}
throw $e51425143;
}
var $ret51485149 = $Hann_DASH_check_DASH_temp33045154($z51445145);
++R.GAS;
return $ret51485149;
};
},{"length":1});
var anf_variant_member12434161 = R.makeMethod(function(self1485120) {
return function(cases_DASH_funs1495121,else_DASH_clause1505132) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[671],2,arguments);
}
var if_DASH_1525135 = R.hasField(cases_DASH_funs1495121,("a-assign"));
var if_helper12315118 = R.makeFunction(function(if_helper_arg12325140) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[671],1,arguments);
}
var ann_DASH_check_DASH_temp12305141 = if_helper_arg12325140;
return ann_DASH_check_DASH_temp12305141;
});
var anf_if12355139 = R.isBoolean(if_DASH_1525135);
if(R.isPyretTrue(anf_if12355139)) {
if(R.isPyretTrue(if_DASH_1525135)) {
var call_DASH_a_DASH_assign1475113 = G(cases_DASH_funs1495121,"a-assign",L[671]);
var anf_arg12385114 = G(self1485120,"l",L[828]);
var anf_arg12395115 = G(self1485120,"id",L[827]);
var anf_arg12405116 = G(self1485120,"value",L[826]);
var $z51055106 = D;
var $f51115112 = function(_) {
return R.isFunction(call_DASH_a_DASH_assign1475113)?call_DASH_a_DASH_assign1475113.app(anf_arg12385114,anf_arg12395115,anf_arg12405116):R.ffi.throwNonFunApp(L[671],call_DASH_a_DASH_assign1475113,[anf_arg12385114,anf_arg12395115,anf_arg12405116]);
};
try {
if(--R.GAS > 0) {
$z51055106 = $f51115112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51115112,
"from":L[671]});
}
} catch($e51035104) {
if(R.isCont($e51035104)) {
var $ss51075108 = {"from":L[671],
"go":function(cont_tail_arg12415117) {
return $Hcont_tail_arg33055119(cont_tail_arg12415117,if_helper12315118);
}};
$e51035104.stack[R.EXN_STACKHEIGHT++] = $ss51075108;
}
if(R.isPyretException($e51035104)) {
$e51035104.pyretStack.push(L[671]);
}
throw $e51035104;
}
var $ret51095110 = $Hcont_tail_arg33055119($z51055106,if_helper12315118);
++R.GAS;
return $ret51095110;
} else {
var $z51245125 = D;
var $f51305131 = function(_) {
return R.isFunction(else_DASH_clause1505132)?else_DASH_clause1505132.app():R.ffi.throwNonFunApp(L[671],else_DASH_clause1505132,[]);
};
try {
if(--R.GAS > 0) {
$z51245125 = $f51305131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51305131,
"from":L[671]});
}
} catch($e51225123) {
if(R.isCont($e51225123)) {
var $ss51265127 = {"from":L[671],
"go":function(cont_tail_arg12365133) {
return $Hcont_tail_arg33065134(cont_tail_arg12365133,if_helper12315118);
}};
$e51225123.stack[R.EXN_STACKHEIGHT++] = $ss51265127;
}
if(R.isPyretException($e51225123)) {
$e51225123.pyretStack.push(L[671]);
}
throw $e51225123;
}
var $ret51285129 = $Hcont_tail_arg33065134($z51245125,if_helper12315118);
++R.GAS;
return $ret51285129;
}
} else {
var cont_tail_arg12335138 = R.throwNonBooleanCondition(L[671],("if"),if_DASH_1525135);
if(--R.GAS > 0) {
$z51365137 = R.isFunction(if_helper12315118)?if_helper12315118.app(cont_tail_arg12335138):R.ffi.throwNonFunApp(L[671],if_helper12315118,[cont_tail_arg12335138]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper12315118)?if_helper12315118.app(cont_tail_arg12335138):R.ffi.throwNonFunApp(L[671],if_helper12315118,[cont_tail_arg12335138]);
},
"from":L[671]});
}
++R.GAS;
return $z51365137;
}
};
},{"length":3});
var anf_variant_member12574162 = R.makeMethod(function(self1515101) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[671],0,arguments);
}
var anf_arg12455099 = G(self1515101,"l",L[671]);
var $z50915092 = D;
var $f50975098 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg12455099):R.ffi.throwNonFunApp(L[671],torepr31,[anf_arg12455099]);
};
try {
if(--R.GAS > 0) {
$z50915092 = $f50975098();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50975098,
"from":L[671]});
}
} catch($e50895090) {
if(R.isCont($e50895090)) {
var $ss50935094 = {"from":L[671],
"go":function(anf_arg12465100) {
return $Hanf_arg33165102(anf_arg12465100,self1515101,_plus26,torepr31);
}};
$e50895090.stack[R.EXN_STACKHEIGHT++] = $ss50935094;
}
if(R.isPyretException($e50895090)) {
$e50895090.pyretStack.push(L[671]);
}
throw $e50895090;
}
var $ret50955096 = $Hanf_arg33165102($z50915092,self1515101,_plus26,torepr31);
++R.GAS;
return $ret50955096;
};
},{"length":1});
var anf_variant_member12594163 = R.makeMethod(function(self3945088) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[825],0,arguments);
}
var ann_DASH_check_DASH_temp12585087 = ("a-assign");
return ann_DASH_check_DASH_temp12585087;
};
},{"length":1});
var anf_variant_member12734164 = R.makeMethod(function(self3955084) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[824],0,arguments);
}
var anf_fun12615082 = G(PP337,"group",L[823]);
var anf_fun12625083 = G(PP337,"nest",L[822]);
var anf_bracket12635086 = G(self3955084,"id",L[821]);
var anf_fun12645080 = G(anf_bracket12635086,"tosource",L[820]);
var $z50725073 = D;
var $f50785079 = function(_) {
return R.isFunction(anf_fun12645080)?anf_fun12645080.app():R.ffi.throwNonFunApp(L[819],anf_fun12645080,[]);
};
try {
if(--R.GAS > 0) {
$z50725073 = $f50785079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50785079,
"from":L[819]});
}
} catch($e50705071) {
if(R.isCont($e50705071)) {
var $ss50745075 = {"from":L[819],
"go":function(anf_arg12655081) {
return $Hanf_arg33235085(anf_arg12655081,INDENT9187,anf_fun12615082,anf_fun12625083,break_DASH_one9262,self3955084,str_DASH_spacecolonequal109313,_plus26);
}};
$e50705071.stack[R.EXN_STACKHEIGHT++] = $ss50745075;
}
if(R.isPyretException($e50705071)) {
$e50705071.pyretStack.push(L[819]);
}
throw $e50705071;
}
var $ret50765077 = $Hanf_arg33235085($z50725073,INDENT9187,anf_fun12615082,anf_fun12625083,break_DASH_one9262,self3955084,str_DASH_spacecolonequal109313,_plus26);
++R.GAS;
return $ret50765077;
};
},{"length":1});
var anf_variant_member12874173 = R.makeMethod(function(self1545048) {
return function(cases_DASH_funs1555049,else_DASH_clause1565060) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[670],2,arguments);
}
var if_DASH_1585063 = R.hasField(cases_DASH_funs1555049,("a-app"));
var if_helper12755046 = R.makeFunction(function(if_helper_arg12765068) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[670],1,arguments);
}
var ann_DASH_check_DASH_temp12745069 = if_helper_arg12765068;
return ann_DASH_check_DASH_temp12745069;
});
var anf_if12795067 = R.isBoolean(if_DASH_1585063);
if(R.isPyretTrue(anf_if12795067)) {
if(R.isPyretTrue(if_DASH_1585063)) {
var call_DASH_a_DASH_app1535041 = G(cases_DASH_funs1555049,"a-app",L[670]);
var anf_arg12825042 = G(self1545048,"l",L[818]);
var anf_arg12835043 = G(self1545048,"_fun",L[817]);
var anf_arg12845044 = G(self1545048,"args",L[816]);
var $z50335034 = D;
var $f50395040 = function(_) {
return R.isFunction(call_DASH_a_DASH_app1535041)?call_DASH_a_DASH_app1535041.app(anf_arg12825042,anf_arg12835043,anf_arg12845044):R.ffi.throwNonFunApp(L[670],call_DASH_a_DASH_app1535041,[anf_arg12825042,anf_arg12835043,anf_arg12845044]);
};
try {
if(--R.GAS > 0) {
$z50335034 = $f50395040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50395040,
"from":L[670]});
}
} catch($e50315032) {
if(R.isCont($e50315032)) {
var $ss50355036 = {"from":L[670],
"go":function(cont_tail_arg12855045) {
return $Hcont_tail_arg33245047(cont_tail_arg12855045,if_helper12755046);
}};
$e50315032.stack[R.EXN_STACKHEIGHT++] = $ss50355036;
}
if(R.isPyretException($e50315032)) {
$e50315032.pyretStack.push(L[670]);
}
throw $e50315032;
}
var $ret50375038 = $Hcont_tail_arg33245047($z50335034,if_helper12755046);
++R.GAS;
return $ret50375038;
} else {
var $z50525053 = D;
var $f50585059 = function(_) {
return R.isFunction(else_DASH_clause1565060)?else_DASH_clause1565060.app():R.ffi.throwNonFunApp(L[670],else_DASH_clause1565060,[]);
};
try {
if(--R.GAS > 0) {
$z50525053 = $f50585059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50585059,
"from":L[670]});
}
} catch($e50505051) {
if(R.isCont($e50505051)) {
var $ss50545055 = {"from":L[670],
"go":function(cont_tail_arg12805061) {
return $Hcont_tail_arg33255062(cont_tail_arg12805061,if_helper12755046);
}};
$e50505051.stack[R.EXN_STACKHEIGHT++] = $ss50545055;
}
if(R.isPyretException($e50505051)) {
$e50505051.pyretStack.push(L[670]);
}
throw $e50505051;
}
var $ret50565057 = $Hcont_tail_arg33255062($z50525053,if_helper12755046);
++R.GAS;
return $ret50565057;
}
} else {
var cont_tail_arg12775066 = R.throwNonBooleanCondition(L[670],("if"),if_DASH_1585063);
if(--R.GAS > 0) {
$z50645065 = R.isFunction(if_helper12755046)?if_helper12755046.app(cont_tail_arg12775066):R.ffi.throwNonFunApp(L[670],if_helper12755046,[cont_tail_arg12775066]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper12755046)?if_helper12755046.app(cont_tail_arg12775066):R.ffi.throwNonFunApp(L[670],if_helper12755046,[cont_tail_arg12775066]);
},
"from":L[670]});
}
++R.GAS;
return $z50645065;
}
};
},{"length":3});
var anf_variant_member13014174 = R.makeMethod(function(self1575029) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[670],0,arguments);
}
var anf_arg12895027 = G(self1575029,"l",L[670]);
var $z50195020 = D;
var $f50255026 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg12895027):R.ffi.throwNonFunApp(L[670],torepr31,[anf_arg12895027]);
};
try {
if(--R.GAS > 0) {
$z50195020 = $f50255026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50255026,
"from":L[670]});
}
} catch($e50175018) {
if(R.isCont($e50175018)) {
var $ss50215022 = {"from":L[670],
"go":function(anf_arg12905028) {
return $Hanf_arg33355030(anf_arg12905028,self1575029,_plus26,torepr31);
}};
$e50175018.stack[R.EXN_STACKHEIGHT++] = $ss50215022;
}
if(R.isPyretException($e50175018)) {
$e50175018.pyretStack.push(L[670]);
}
throw $e50175018;
}
var $ret50235024 = $Hanf_arg33355030($z50195020,self1575029,_plus26,torepr31);
++R.GAS;
return $ret50235024;
};
},{"length":1});
var anf_variant_member13034175 = R.makeMethod(function(self3995016) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[815],0,arguments);
}
var ann_DASH_check_DASH_temp13025015 = ("a-app");
return ann_DASH_check_DASH_temp13025015;
};
},{"length":1});
var anf_variant_member13234176 = R.makeMethod(function(self4005012) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[814],0,arguments);
}
var anf_fun13055011 = G(PP337,"group",L[813]);
var anf_bracket13065014 = G(self4005012,"_fun",L[812]);
var anf_fun13075009 = G(anf_bracket13065014,"tosource",L[811]);
var $z50015002 = D;
var $f50075008 = function(_) {
return R.isFunction(anf_fun13075009)?anf_fun13075009.app():R.ffi.throwNonFunApp(L[810],anf_fun13075009,[]);
};
try {
if(--R.GAS > 0) {
$z50015002 = $f50075008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50075008,
"from":L[810]});
}
} catch($e49995000) {
if(R.isCont($e49995000)) {
var $ss50035004 = {"from":L[810],
"go":function(anf_arg13085010) {
return $Hanf_arg33435013(anf_arg13085010,INDENT9187,PP337,anf_fun13055011,self4005012,_plus26);
}};
$e49995000.stack[R.EXN_STACKHEIGHT++] = $ss50035004;
}
if(R.isPyretException($e49995000)) {
$e49995000.pyretStack.push(L[810]);
}
throw $e49995000;
}
var $ret50055006 = $Hanf_arg33435013($z50015002,INDENT9187,PP337,anf_fun13055011,self4005012,_plus26);
++R.GAS;
return $ret50055006;
};
},{"length":1});
var anf_variant_member13374185 = R.makeMethod(function(self1604977) {
return function(cases_DASH_funs1614978,else_DASH_clause1624989) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[669],2,arguments);
}
var if_DASH_1644992 = R.hasField(cases_DASH_funs1614978,("a-prim-app"));
var if_helper13254975 = R.makeFunction(function(if_helper_arg13264997) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[669],1,arguments);
}
var ann_DASH_check_DASH_temp13244998 = if_helper_arg13264997;
return ann_DASH_check_DASH_temp13244998;
});
var anf_if13294996 = R.isBoolean(if_DASH_1644992);
if(R.isPyretTrue(anf_if13294996)) {
if(R.isPyretTrue(if_DASH_1644992)) {
var call_DASH_a_DASH_prim_DASH_app1594970 = G(cases_DASH_funs1614978,"a-prim-app",L[669]);
var anf_arg13324971 = G(self1604977,"l",L[809]);
var anf_arg13334972 = G(self1604977,"f",L[808]);
var anf_arg13344973 = G(self1604977,"args",L[807]);
var $z49624963 = D;
var $f49684969 = function(_) {
return R.isFunction(call_DASH_a_DASH_prim_DASH_app1594970)?call_DASH_a_DASH_prim_DASH_app1594970.app(anf_arg13324971,anf_arg13334972,anf_arg13344973):R.ffi.throwNonFunApp(L[669],call_DASH_a_DASH_prim_DASH_app1594970,[anf_arg13324971,anf_arg13334972,anf_arg13344973]);
};
try {
if(--R.GAS > 0) {
$z49624963 = $f49684969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49684969,
"from":L[669]});
}
} catch($e49604961) {
if(R.isCont($e49604961)) {
var $ss49644965 = {"from":L[669],
"go":function(cont_tail_arg13354974) {
return $Hcont_tail_arg33444976(cont_tail_arg13354974,if_helper13254975);
}};
$e49604961.stack[R.EXN_STACKHEIGHT++] = $ss49644965;
}
if(R.isPyretException($e49604961)) {
$e49604961.pyretStack.push(L[669]);
}
throw $e49604961;
}
var $ret49664967 = $Hcont_tail_arg33444976($z49624963,if_helper13254975);
++R.GAS;
return $ret49664967;
} else {
var $z49814982 = D;
var $f49874988 = function(_) {
return R.isFunction(else_DASH_clause1624989)?else_DASH_clause1624989.app():R.ffi.throwNonFunApp(L[669],else_DASH_clause1624989,[]);
};
try {
if(--R.GAS > 0) {
$z49814982 = $f49874988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49874988,
"from":L[669]});
}
} catch($e49794980) {
if(R.isCont($e49794980)) {
var $ss49834984 = {"from":L[669],
"go":function(cont_tail_arg13304990) {
return $Hcont_tail_arg33454991(cont_tail_arg13304990,if_helper13254975);
}};
$e49794980.stack[R.EXN_STACKHEIGHT++] = $ss49834984;
}
if(R.isPyretException($e49794980)) {
$e49794980.pyretStack.push(L[669]);
}
throw $e49794980;
}
var $ret49854986 = $Hcont_tail_arg33454991($z49814982,if_helper13254975);
++R.GAS;
return $ret49854986;
}
} else {
var cont_tail_arg13274995 = R.throwNonBooleanCondition(L[669],("if"),if_DASH_1644992);
if(--R.GAS > 0) {
$z49934994 = R.isFunction(if_helper13254975)?if_helper13254975.app(cont_tail_arg13274995):R.ffi.throwNonFunApp(L[669],if_helper13254975,[cont_tail_arg13274995]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper13254975)?if_helper13254975.app(cont_tail_arg13274995):R.ffi.throwNonFunApp(L[669],if_helper13254975,[cont_tail_arg13274995]);
},
"from":L[669]});
}
++R.GAS;
return $z49934994;
}
};
},{"length":3});
var anf_variant_member13514186 = R.makeMethod(function(self1634958) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[669],0,arguments);
}
var anf_arg13394956 = G(self1634958,"l",L[669]);
var $z49484949 = D;
var $f49544955 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg13394956):R.ffi.throwNonFunApp(L[669],torepr31,[anf_arg13394956]);
};
try {
if(--R.GAS > 0) {
$z49484949 = $f49544955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49544955,
"from":L[669]});
}
} catch($e49464947) {
if(R.isCont($e49464947)) {
var $ss49504951 = {"from":L[669],
"go":function(anf_arg13404957) {
return $Hanf_arg33554959(anf_arg13404957,self1634958,_plus26,torepr31);
}};
$e49464947.stack[R.EXN_STACKHEIGHT++] = $ss49504951;
}
if(R.isPyretException($e49464947)) {
$e49464947.pyretStack.push(L[669]);
}
throw $e49464947;
}
var $ret49524953 = $Hanf_arg33554959($z49484949,self1634958,_plus26,torepr31);
++R.GAS;
return $ret49524953;
};
},{"length":1});
var anf_variant_member13534187 = R.makeMethod(function(self4054945) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[806],0,arguments);
}
var ann_DASH_check_DASH_temp13524944 = ("a-prim-app");
return ann_DASH_check_DASH_temp13524944;
};
},{"length":1});
var anf_variant_member13734188 = R.makeMethod(function(self4064942) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[805],0,arguments);
}
var anf_fun13554941 = G(PP337,"group",L[804]);
var anf_fun13564938 = G(PP337,"str",L[803]);
var anf_arg13574939 = G(self4064942,"f",L[802]);
var $z49304931 = D;
var $f49364937 = function(_) {
return R.isFunction(anf_fun13564938)?anf_fun13564938.app(anf_arg13574939):R.ffi.throwNonFunApp(L[801],anf_fun13564938,[anf_arg13574939]);
};
try {
if(--R.GAS > 0) {
$z49304931 = $f49364937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49364937,
"from":L[801]});
}
} catch($e49284929) {
if(R.isCont($e49284929)) {
var $ss49324933 = {"from":L[801],
"go":function(anf_arg13584940) {
return $Hanf_arg33634943(anf_arg13584940,INDENT9187,PP337,anf_fun13554941,self4064942,_plus26);
}};
$e49284929.stack[R.EXN_STACKHEIGHT++] = $ss49324933;
}
if(R.isPyretException($e49284929)) {
$e49284929.pyretStack.push(L[801]);
}
throw $e49284929;
}
var $ret49344935 = $Hanf_arg33634943($z49304931,INDENT9187,PP337,anf_fun13554941,self4064942,_plus26);
++R.GAS;
return $ret49344935;
};
},{"length":1});
var anf_variant_member13864197 = R.makeMethod(function(self1664906) {
return function(cases_DASH_funs1674907,else_DASH_clause1684918) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[668],2,arguments);
}
var if_DASH_1704921 = R.hasField(cases_DASH_funs1674907,("a-obj"));
var if_helper13754904 = R.makeFunction(function(if_helper_arg13764926) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[668],1,arguments);
}
var ann_DASH_check_DASH_temp13744927 = if_helper_arg13764926;
return ann_DASH_check_DASH_temp13744927;
});
var anf_if13794925 = R.isBoolean(if_DASH_1704921);
if(R.isPyretTrue(anf_if13794925)) {
if(R.isPyretTrue(if_DASH_1704921)) {
var call_DASH_a_DASH_obj1654900 = G(cases_DASH_funs1674907,"a-obj",L[668]);
var anf_arg13824901 = G(self1664906,"l",L[800]);
var anf_arg13834902 = G(self1664906,"fields",L[799]);
var $z48924893 = D;
var $f48984899 = function(_) {
return R.isFunction(call_DASH_a_DASH_obj1654900)?call_DASH_a_DASH_obj1654900.app(anf_arg13824901,anf_arg13834902):R.ffi.throwNonFunApp(L[668],call_DASH_a_DASH_obj1654900,[anf_arg13824901,anf_arg13834902]);
};
try {
if(--R.GAS > 0) {
$z48924893 = $f48984899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48984899,
"from":L[668]});
}
} catch($e48904891) {
if(R.isCont($e48904891)) {
var $ss48944895 = {"from":L[668],
"go":function(cont_tail_arg13844903) {
return $Hcont_tail_arg33644905(cont_tail_arg13844903,if_helper13754904);
}};
$e48904891.stack[R.EXN_STACKHEIGHT++] = $ss48944895;
}
if(R.isPyretException($e48904891)) {
$e48904891.pyretStack.push(L[668]);
}
throw $e48904891;
}
var $ret48964897 = $Hcont_tail_arg33644905($z48924893,if_helper13754904);
++R.GAS;
return $ret48964897;
} else {
var $z49104911 = D;
var $f49164917 = function(_) {
return R.isFunction(else_DASH_clause1684918)?else_DASH_clause1684918.app():R.ffi.throwNonFunApp(L[668],else_DASH_clause1684918,[]);
};
try {
if(--R.GAS > 0) {
$z49104911 = $f49164917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49164917,
"from":L[668]});
}
} catch($e49084909) {
if(R.isCont($e49084909)) {
var $ss49124913 = {"from":L[668],
"go":function(cont_tail_arg13804919) {
return $Hcont_tail_arg33654920(cont_tail_arg13804919,if_helper13754904);
}};
$e49084909.stack[R.EXN_STACKHEIGHT++] = $ss49124913;
}
if(R.isPyretException($e49084909)) {
$e49084909.pyretStack.push(L[668]);
}
throw $e49084909;
}
var $ret49144915 = $Hcont_tail_arg33654920($z49104911,if_helper13754904);
++R.GAS;
return $ret49144915;
}
} else {
var cont_tail_arg13774924 = R.throwNonBooleanCondition(L[668],("if"),if_DASH_1704921);
if(--R.GAS > 0) {
$z49224923 = R.isFunction(if_helper13754904)?if_helper13754904.app(cont_tail_arg13774924):R.ffi.throwNonFunApp(L[668],if_helper13754904,[cont_tail_arg13774924]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper13754904)?if_helper13754904.app(cont_tail_arg13774924):R.ffi.throwNonFunApp(L[668],if_helper13754904,[cont_tail_arg13774924]);
},
"from":L[668]});
}
++R.GAS;
return $z49224923;
}
};
},{"length":3});
var anf_variant_member13964198 = R.makeMethod(function(self1694888) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[668],0,arguments);
}
var anf_arg13884886 = G(self1694888,"l",L[668]);
var $z48784879 = D;
var $f48844885 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg13884886):R.ffi.throwNonFunApp(L[668],torepr31,[anf_arg13884886]);
};
try {
if(--R.GAS > 0) {
$z48784879 = $f48844885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48844885,
"from":L[668]});
}
} catch($e48764877) {
if(R.isCont($e48764877)) {
var $ss48804881 = {"from":L[668],
"go":function(anf_arg13894887) {
return $Hanf_arg33724889(anf_arg13894887,self1694888,_plus26,torepr31);
}};
$e48764877.stack[R.EXN_STACKHEIGHT++] = $ss48804881;
}
if(R.isPyretException($e48764877)) {
$e48764877.pyretStack.push(L[668]);
}
throw $e48764877;
}
var $ret48824883 = $Hanf_arg33724889($z48784879,self1694888,_plus26,torepr31);
++R.GAS;
return $ret48824883;
};
},{"length":1});
var anf_variant_member13984199 = R.makeMethod(function(self4104875) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[798],0,arguments);
}
var ann_DASH_check_DASH_temp13974874 = ("a-obj");
return ann_DASH_check_DASH_temp13974874;
};
},{"length":1});
var anf_variant_member14134200 = R.makeMethod(function(self4114872) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[797],0,arguments);
}
var anf_fun14004871 = G(PP337,"surround-separate",L[796]);
var anf_arg14014868 = G(PP337,"lbrace",L[795]);
var anf_arg14024869 = G(PP337,"rbrace",L[794]);
var $z48604861 = D;
var $f48664867 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg14014868,anf_arg14024869):R.ffi.throwNonFunApp(L[793],_plus26,[anf_arg14014868,anf_arg14024869]);
};
try {
if(--R.GAS > 0) {
$z48604861 = $f48664867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48664867,
"from":L[793]});
}
} catch($e48584859) {
if(R.isCont($e48584859)) {
var $ss48624863 = {"from":L[793],
"go":function(anf_arg14034870) {
return $Hanf_arg33764873(anf_arg14034870,INDENT9187,PP337,anf_fun14004871,self4114872);
}};
$e48584859.stack[R.EXN_STACKHEIGHT++] = $ss48624863;
}
if(R.isPyretException($e48584859)) {
$e48584859.pyretStack.push(L[793]);
}
throw $e48584859;
}
var $ret48644865 = $Hanf_arg33764873($z48604861,INDENT9187,PP337,anf_fun14004871,self4114872);
++R.GAS;
return $ret48644865;
};
},{"length":1});
var anf_variant_member14274208 = R.makeMethod(function(self1724836) {
return function(cases_DASH_funs1734837,else_DASH_clause1744848) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[667],2,arguments);
}
var if_DASH_1764851 = R.hasField(cases_DASH_funs1734837,("a-update"));
var if_helper14154834 = R.makeFunction(function(if_helper_arg14164856) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[667],1,arguments);
}
var ann_DASH_check_DASH_temp14144857 = if_helper_arg14164856;
return ann_DASH_check_DASH_temp14144857;
});
var anf_if14194855 = R.isBoolean(if_DASH_1764851);
if(R.isPyretTrue(anf_if14194855)) {
if(R.isPyretTrue(if_DASH_1764851)) {
var call_DASH_a_DASH_update1714829 = G(cases_DASH_funs1734837,"a-update",L[667]);
var anf_arg14224830 = G(self1724836,"l",L[792]);
var anf_arg14234831 = G(self1724836,"supe",L[791]);
var anf_arg14244832 = G(self1724836,"fields",L[790]);
var $z48214822 = D;
var $f48274828 = function(_) {
return R.isFunction(call_DASH_a_DASH_update1714829)?call_DASH_a_DASH_update1714829.app(anf_arg14224830,anf_arg14234831,anf_arg14244832):R.ffi.throwNonFunApp(L[667],call_DASH_a_DASH_update1714829,[anf_arg14224830,anf_arg14234831,anf_arg14244832]);
};
try {
if(--R.GAS > 0) {
$z48214822 = $f48274828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48274828,
"from":L[667]});
}
} catch($e48194820) {
if(R.isCont($e48194820)) {
var $ss48234824 = {"from":L[667],
"go":function(cont_tail_arg14254833) {
return $Hcont_tail_arg33774835(cont_tail_arg14254833,if_helper14154834);
}};
$e48194820.stack[R.EXN_STACKHEIGHT++] = $ss48234824;
}
if(R.isPyretException($e48194820)) {
$e48194820.pyretStack.push(L[667]);
}
throw $e48194820;
}
var $ret48254826 = $Hcont_tail_arg33774835($z48214822,if_helper14154834);
++R.GAS;
return $ret48254826;
} else {
var $z48404841 = D;
var $f48464847 = function(_) {
return R.isFunction(else_DASH_clause1744848)?else_DASH_clause1744848.app():R.ffi.throwNonFunApp(L[667],else_DASH_clause1744848,[]);
};
try {
if(--R.GAS > 0) {
$z48404841 = $f48464847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48464847,
"from":L[667]});
}
} catch($e48384839) {
if(R.isCont($e48384839)) {
var $ss48424843 = {"from":L[667],
"go":function(cont_tail_arg14204849) {
return $Hcont_tail_arg33784850(cont_tail_arg14204849,if_helper14154834);
}};
$e48384839.stack[R.EXN_STACKHEIGHT++] = $ss48424843;
}
if(R.isPyretException($e48384839)) {
$e48384839.pyretStack.push(L[667]);
}
throw $e48384839;
}
var $ret48444845 = $Hcont_tail_arg33784850($z48404841,if_helper14154834);
++R.GAS;
return $ret48444845;
}
} else {
var cont_tail_arg14174854 = R.throwNonBooleanCondition(L[667],("if"),if_DASH_1764851);
if(--R.GAS > 0) {
$z48524853 = R.isFunction(if_helper14154834)?if_helper14154834.app(cont_tail_arg14174854):R.ffi.throwNonFunApp(L[667],if_helper14154834,[cont_tail_arg14174854]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14154834)?if_helper14154834.app(cont_tail_arg14174854):R.ffi.throwNonFunApp(L[667],if_helper14154834,[cont_tail_arg14174854]);
},
"from":L[667]});
}
++R.GAS;
return $z48524853;
}
};
},{"length":3});
var anf_variant_member14414209 = R.makeMethod(function(self1754817) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[667],0,arguments);
}
var anf_arg14294815 = G(self1754817,"l",L[667]);
var $z48074808 = D;
var $f48134814 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg14294815):R.ffi.throwNonFunApp(L[667],torepr31,[anf_arg14294815]);
};
try {
if(--R.GAS > 0) {
$z48074808 = $f48134814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48134814,
"from":L[667]});
}
} catch($e48054806) {
if(R.isCont($e48054806)) {
var $ss48094810 = {"from":L[667],
"go":function(anf_arg14304816) {
return $Hanf_arg33884818(anf_arg14304816,self1754817,_plus26,torepr31);
}};
$e48054806.stack[R.EXN_STACKHEIGHT++] = $ss48094810;
}
if(R.isPyretException($e48054806)) {
$e48054806.pyretStack.push(L[667]);
}
throw $e48054806;
}
var $ret48114812 = $Hanf_arg33884818($z48074808,self1754817,_plus26,torepr31);
++R.GAS;
return $ret48114812;
};
},{"length":1});
var anf_variant_member14434210 = R.makeMethod(function(self4164804) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[789],0,arguments);
}
var ann_DASH_check_DASH_temp14424803 = ("a-update");
return ann_DASH_check_DASH_temp14424803;
};
},{"length":1});
var anf_variant_member14464211 = R.makeMethod(function(self4174802) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[787],0,arguments);
}
var anf_fun14454799 = G(PP337,"str",L[788]);
var $z47914792 = D;
var $f47974798 = function(_) {
return R.isFunction(anf_fun14454799)?anf_fun14454799.app(("update")):R.ffi.throwNonFunApp(L[787],anf_fun14454799,[("update")]);
};
try {
if(--R.GAS > 0) {
$z47914792 = $f47974798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47974798,
"from":L[787]});
}
} catch($e47894790) {
if(R.isCont($e47894790)) {
var $ss47934794 = {"from":L[787],
"go":function(ann_DASH_check_DASH_temp14444800) {
return $Hann_DASH_check_DASH_temp33894801(ann_DASH_check_DASH_temp14444800);
}};
$e47894790.stack[R.EXN_STACKHEIGHT++] = $ss47934794;
}
if(R.isPyretException($e47894790)) {
$e47894790.pyretStack.push(L[787]);
}
throw $e47894790;
}
var $ret47954796 = $Hann_DASH_check_DASH_temp33894801($z47914792);
++R.GAS;
return $ret47954796;
};
},{"length":1});
var anf_variant_member14604220 = R.makeMethod(function(self1784767) {
return function(cases_DASH_funs1794768,else_DASH_clause1804779) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[666],2,arguments);
}
var if_DASH_1824782 = R.hasField(cases_DASH_funs1794768,("a-extend"));
var if_helper14484765 = R.makeFunction(function(if_helper_arg14494787) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[666],1,arguments);
}
var ann_DASH_check_DASH_temp14474788 = if_helper_arg14494787;
return ann_DASH_check_DASH_temp14474788;
});
var anf_if14524786 = R.isBoolean(if_DASH_1824782);
if(R.isPyretTrue(anf_if14524786)) {
if(R.isPyretTrue(if_DASH_1824782)) {
var call_DASH_a_DASH_extend1774760 = G(cases_DASH_funs1794768,"a-extend",L[666]);
var anf_arg14554761 = G(self1784767,"l",L[786]);
var anf_arg14564762 = G(self1784767,"supe",L[785]);
var anf_arg14574763 = G(self1784767,"fields",L[784]);
var $z47524753 = D;
var $f47584759 = function(_) {
return R.isFunction(call_DASH_a_DASH_extend1774760)?call_DASH_a_DASH_extend1774760.app(anf_arg14554761,anf_arg14564762,anf_arg14574763):R.ffi.throwNonFunApp(L[666],call_DASH_a_DASH_extend1774760,[anf_arg14554761,anf_arg14564762,anf_arg14574763]);
};
try {
if(--R.GAS > 0) {
$z47524753 = $f47584759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47584759,
"from":L[666]});
}
} catch($e47504751) {
if(R.isCont($e47504751)) {
var $ss47544755 = {"from":L[666],
"go":function(cont_tail_arg14584764) {
return $Hcont_tail_arg33904766(cont_tail_arg14584764,if_helper14484765);
}};
$e47504751.stack[R.EXN_STACKHEIGHT++] = $ss47544755;
}
if(R.isPyretException($e47504751)) {
$e47504751.pyretStack.push(L[666]);
}
throw $e47504751;
}
var $ret47564757 = $Hcont_tail_arg33904766($z47524753,if_helper14484765);
++R.GAS;
return $ret47564757;
} else {
var $z47714772 = D;
var $f47774778 = function(_) {
return R.isFunction(else_DASH_clause1804779)?else_DASH_clause1804779.app():R.ffi.throwNonFunApp(L[666],else_DASH_clause1804779,[]);
};
try {
if(--R.GAS > 0) {
$z47714772 = $f47774778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47774778,
"from":L[666]});
}
} catch($e47694770) {
if(R.isCont($e47694770)) {
var $ss47734774 = {"from":L[666],
"go":function(cont_tail_arg14534780) {
return $Hcont_tail_arg33914781(cont_tail_arg14534780,if_helper14484765);
}};
$e47694770.stack[R.EXN_STACKHEIGHT++] = $ss47734774;
}
if(R.isPyretException($e47694770)) {
$e47694770.pyretStack.push(L[666]);
}
throw $e47694770;
}
var $ret47754776 = $Hcont_tail_arg33914781($z47714772,if_helper14484765);
++R.GAS;
return $ret47754776;
}
} else {
var cont_tail_arg14504785 = R.throwNonBooleanCondition(L[666],("if"),if_DASH_1824782);
if(--R.GAS > 0) {
$z47834784 = R.isFunction(if_helper14484765)?if_helper14484765.app(cont_tail_arg14504785):R.ffi.throwNonFunApp(L[666],if_helper14484765,[cont_tail_arg14504785]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14484765)?if_helper14484765.app(cont_tail_arg14504785):R.ffi.throwNonFunApp(L[666],if_helper14484765,[cont_tail_arg14504785]);
},
"from":L[666]});
}
++R.GAS;
return $z47834784;
}
};
},{"length":3});
var anf_variant_member14744221 = R.makeMethod(function(self1814748) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[666],0,arguments);
}
var anf_arg14624746 = G(self1814748,"l",L[666]);
var $z47384739 = D;
var $f47444745 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg14624746):R.ffi.throwNonFunApp(L[666],torepr31,[anf_arg14624746]);
};
try {
if(--R.GAS > 0) {
$z47384739 = $f47444745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47444745,
"from":L[666]});
}
} catch($e47364737) {
if(R.isCont($e47364737)) {
var $ss47404741 = {"from":L[666],
"go":function(anf_arg14634747) {
return $Hanf_arg34014749(anf_arg14634747,self1814748,_plus26,torepr31);
}};
$e47364737.stack[R.EXN_STACKHEIGHT++] = $ss47404741;
}
if(R.isPyretException($e47364737)) {
$e47364737.pyretStack.push(L[666]);
}
throw $e47364737;
}
var $ret47424743 = $Hanf_arg34014749($z47384739,self1814748,_plus26,torepr31);
++R.GAS;
return $ret47424743;
};
},{"length":1});
var anf_variant_member14764222 = R.makeMethod(function(self4214735) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[783],0,arguments);
}
var ann_DASH_check_DASH_temp14754734 = ("a-extend");
return ann_DASH_check_DASH_temp14754734;
};
},{"length":1});
var anf_variant_member14794223 = R.makeMethod(function(self4224733) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[781],0,arguments);
}
var anf_fun14784730 = G(PP337,"str",L[782]);
var $z47224723 = D;
var $f47284729 = function(_) {
return R.isFunction(anf_fun14784730)?anf_fun14784730.app(("extend")):R.ffi.throwNonFunApp(L[781],anf_fun14784730,[("extend")]);
};
try {
if(--R.GAS > 0) {
$z47224723 = $f47284729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47284729,
"from":L[781]});
}
} catch($e47204721) {
if(R.isCont($e47204721)) {
var $ss47244725 = {"from":L[781],
"go":function(ann_DASH_check_DASH_temp14774731) {
return $Hann_DASH_check_DASH_temp34024732(ann_DASH_check_DASH_temp14774731);
}};
$e47204721.stack[R.EXN_STACKHEIGHT++] = $ss47244725;
}
if(R.isPyretException($e47204721)) {
$e47204721.pyretStack.push(L[781]);
}
throw $e47204721;
}
var $ret47264727 = $Hann_DASH_check_DASH_temp34024732($z47224723);
++R.GAS;
return $ret47264727;
};
},{"length":1});
var anf_variant_member14934232 = R.makeMethod(function(self1844698) {
return function(cases_DASH_funs1854699,else_DASH_clause1864710) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[665],2,arguments);
}
var if_DASH_1884713 = R.hasField(cases_DASH_funs1854699,("a-dot"));
var if_helper14814696 = R.makeFunction(function(if_helper_arg14824718) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[665],1,arguments);
}
var ann_DASH_check_DASH_temp14804719 = if_helper_arg14824718;
return ann_DASH_check_DASH_temp14804719;
});
var anf_if14854717 = R.isBoolean(if_DASH_1884713);
if(R.isPyretTrue(anf_if14854717)) {
if(R.isPyretTrue(if_DASH_1884713)) {
var call_DASH_a_DASH_dot1834691 = G(cases_DASH_funs1854699,"a-dot",L[665]);
var anf_arg14884692 = G(self1844698,"l",L[780]);
var anf_arg14894693 = G(self1844698,"obj",L[779]);
var anf_arg14904694 = G(self1844698,"field",L[778]);
var $z46834684 = D;
var $f46894690 = function(_) {
return R.isFunction(call_DASH_a_DASH_dot1834691)?call_DASH_a_DASH_dot1834691.app(anf_arg14884692,anf_arg14894693,anf_arg14904694):R.ffi.throwNonFunApp(L[665],call_DASH_a_DASH_dot1834691,[anf_arg14884692,anf_arg14894693,anf_arg14904694]);
};
try {
if(--R.GAS > 0) {
$z46834684 = $f46894690();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46894690,
"from":L[665]});
}
} catch($e46814682) {
if(R.isCont($e46814682)) {
var $ss46854686 = {"from":L[665],
"go":function(cont_tail_arg14914695) {
return $Hcont_tail_arg34034697(cont_tail_arg14914695,if_helper14814696);
}};
$e46814682.stack[R.EXN_STACKHEIGHT++] = $ss46854686;
}
if(R.isPyretException($e46814682)) {
$e46814682.pyretStack.push(L[665]);
}
throw $e46814682;
}
var $ret46874688 = $Hcont_tail_arg34034697($z46834684,if_helper14814696);
++R.GAS;
return $ret46874688;
} else {
var $z47024703 = D;
var $f47084709 = function(_) {
return R.isFunction(else_DASH_clause1864710)?else_DASH_clause1864710.app():R.ffi.throwNonFunApp(L[665],else_DASH_clause1864710,[]);
};
try {
if(--R.GAS > 0) {
$z47024703 = $f47084709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47084709,
"from":L[665]});
}
} catch($e47004701) {
if(R.isCont($e47004701)) {
var $ss47044705 = {"from":L[665],
"go":function(cont_tail_arg14864711) {
return $Hcont_tail_arg34044712(cont_tail_arg14864711,if_helper14814696);
}};
$e47004701.stack[R.EXN_STACKHEIGHT++] = $ss47044705;
}
if(R.isPyretException($e47004701)) {
$e47004701.pyretStack.push(L[665]);
}
throw $e47004701;
}
var $ret47064707 = $Hcont_tail_arg34044712($z47024703,if_helper14814696);
++R.GAS;
return $ret47064707;
}
} else {
var cont_tail_arg14834716 = R.throwNonBooleanCondition(L[665],("if"),if_DASH_1884713);
if(--R.GAS > 0) {
$z47144715 = R.isFunction(if_helper14814696)?if_helper14814696.app(cont_tail_arg14834716):R.ffi.throwNonFunApp(L[665],if_helper14814696,[cont_tail_arg14834716]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14814696)?if_helper14814696.app(cont_tail_arg14834716):R.ffi.throwNonFunApp(L[665],if_helper14814696,[cont_tail_arg14834716]);
},
"from":L[665]});
}
++R.GAS;
return $z47144715;
}
};
},{"length":3});
var anf_variant_member15074233 = R.makeMethod(function(self1874679) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[665],0,arguments);
}
var anf_arg14954677 = G(self1874679,"l",L[665]);
var $z46694670 = D;
var $f46754676 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg14954677):R.ffi.throwNonFunApp(L[665],torepr31,[anf_arg14954677]);
};
try {
if(--R.GAS > 0) {
$z46694670 = $f46754676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46754676,
"from":L[665]});
}
} catch($e46674668) {
if(R.isCont($e46674668)) {
var $ss46714672 = {"from":L[665],
"go":function(anf_arg14964678) {
return $Hanf_arg34144680(anf_arg14964678,self1874679,_plus26,torepr31);
}};
$e46674668.stack[R.EXN_STACKHEIGHT++] = $ss46714672;
}
if(R.isPyretException($e46674668)) {
$e46674668.pyretStack.push(L[665]);
}
throw $e46674668;
}
var $ret46734674 = $Hanf_arg34144680($z46694670,self1874679,_plus26,torepr31);
++R.GAS;
return $ret46734674;
};
},{"length":1});
var anf_variant_member15094234 = R.makeMethod(function(self4264666) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[777],0,arguments);
}
var ann_DASH_check_DASH_temp15084665 = ("a-dot");
return ann_DASH_check_DASH_temp15084665;
};
},{"length":1});
var anf_variant_member15184235 = R.makeMethod(function(self4274662) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[776],0,arguments);
}
var anf_fun15114661 = G(PP337,"infix",L[775]);
var anf_bracket15124664 = G(self4274662,"obj",L[774]);
var anf_fun15134659 = G(anf_bracket15124664,"tosource",L[773]);
var $z46514652 = D;
var $f46574658 = function(_) {
return R.isFunction(anf_fun15134659)?anf_fun15134659.app():R.ffi.throwNonFunApp(L[772],anf_fun15134659,[]);
};
try {
if(--R.GAS > 0) {
$z46514652 = $f46574658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46574658,
"from":L[772]});
}
} catch($e46494650) {
if(R.isCont($e46494650)) {
var $ss46534654 = {"from":L[772],
"go":function(anf_arg15144660) {
return $Hanf_arg34174663(anf_arg15144660,INDENT9187,PP337,anf_fun15114661,self4274662,str_DASH_period95131);
}};
$e46494650.stack[R.EXN_STACKHEIGHT++] = $ss46534654;
}
if(R.isPyretException($e46494650)) {
$e46494650.pyretStack.push(L[772]);
}
throw $e46494650;
}
var $ret46554656 = $Hanf_arg34174663($z46514652,INDENT9187,PP337,anf_fun15114661,self4274662,str_DASH_period95131);
++R.GAS;
return $ret46554656;
};
},{"length":1});
var anf_variant_member15324244 = R.makeMethod(function(self1904627) {
return function(cases_DASH_funs1914628,else_DASH_clause1924639) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[664],2,arguments);
}
var if_DASH_1944642 = R.hasField(cases_DASH_funs1914628,("a-colon"));
var if_helper15204625 = R.makeFunction(function(if_helper_arg15214647) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[664],1,arguments);
}
var ann_DASH_check_DASH_temp15194648 = if_helper_arg15214647;
return ann_DASH_check_DASH_temp15194648;
});
var anf_if15244646 = R.isBoolean(if_DASH_1944642);
if(R.isPyretTrue(anf_if15244646)) {
if(R.isPyretTrue(if_DASH_1944642)) {
var call_DASH_a_DASH_colon1894620 = G(cases_DASH_funs1914628,"a-colon",L[664]);
var anf_arg15274621 = G(self1904627,"l",L[771]);
var anf_arg15284622 = G(self1904627,"obj",L[770]);
var anf_arg15294623 = G(self1904627,"field",L[769]);
var $z46124613 = D;
var $f46184619 = function(_) {
return R.isFunction(call_DASH_a_DASH_colon1894620)?call_DASH_a_DASH_colon1894620.app(anf_arg15274621,anf_arg15284622,anf_arg15294623):R.ffi.throwNonFunApp(L[664],call_DASH_a_DASH_colon1894620,[anf_arg15274621,anf_arg15284622,anf_arg15294623]);
};
try {
if(--R.GAS > 0) {
$z46124613 = $f46184619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46184619,
"from":L[664]});
}
} catch($e46104611) {
if(R.isCont($e46104611)) {
var $ss46144615 = {"from":L[664],
"go":function(cont_tail_arg15304624) {
return $Hcont_tail_arg34184626(cont_tail_arg15304624,if_helper15204625);
}};
$e46104611.stack[R.EXN_STACKHEIGHT++] = $ss46144615;
}
if(R.isPyretException($e46104611)) {
$e46104611.pyretStack.push(L[664]);
}
throw $e46104611;
}
var $ret46164617 = $Hcont_tail_arg34184626($z46124613,if_helper15204625);
++R.GAS;
return $ret46164617;
} else {
var $z46314632 = D;
var $f46374638 = function(_) {
return R.isFunction(else_DASH_clause1924639)?else_DASH_clause1924639.app():R.ffi.throwNonFunApp(L[664],else_DASH_clause1924639,[]);
};
try {
if(--R.GAS > 0) {
$z46314632 = $f46374638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46374638,
"from":L[664]});
}
} catch($e46294630) {
if(R.isCont($e46294630)) {
var $ss46334634 = {"from":L[664],
"go":function(cont_tail_arg15254640) {
return $Hcont_tail_arg34194641(cont_tail_arg15254640,if_helper15204625);
}};
$e46294630.stack[R.EXN_STACKHEIGHT++] = $ss46334634;
}
if(R.isPyretException($e46294630)) {
$e46294630.pyretStack.push(L[664]);
}
throw $e46294630;
}
var $ret46354636 = $Hcont_tail_arg34194641($z46314632,if_helper15204625);
++R.GAS;
return $ret46354636;
}
} else {
var cont_tail_arg15224645 = R.throwNonBooleanCondition(L[664],("if"),if_DASH_1944642);
if(--R.GAS > 0) {
$z46434644 = R.isFunction(if_helper15204625)?if_helper15204625.app(cont_tail_arg15224645):R.ffi.throwNonFunApp(L[664],if_helper15204625,[cont_tail_arg15224645]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15204625)?if_helper15204625.app(cont_tail_arg15224645):R.ffi.throwNonFunApp(L[664],if_helper15204625,[cont_tail_arg15224645]);
},
"from":L[664]});
}
++R.GAS;
return $z46434644;
}
};
},{"length":3});
var anf_variant_member15464245 = R.makeMethod(function(self1934608) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[664],0,arguments);
}
var anf_arg15344606 = G(self1934608,"l",L[664]);
var $z45984599 = D;
var $f46044605 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg15344606):R.ffi.throwNonFunApp(L[664],torepr31,[anf_arg15344606]);
};
try {
if(--R.GAS > 0) {
$z45984599 = $f46044605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46044605,
"from":L[664]});
}
} catch($e45964597) {
if(R.isCont($e45964597)) {
var $ss46004601 = {"from":L[664],
"go":function(anf_arg15354607) {
return $Hanf_arg34294609(anf_arg15354607,self1934608,_plus26,torepr31);
}};
$e45964597.stack[R.EXN_STACKHEIGHT++] = $ss46004601;
}
if(R.isPyretException($e45964597)) {
$e45964597.pyretStack.push(L[664]);
}
throw $e45964597;
}
var $ret46024603 = $Hanf_arg34294609($z45984599,self1934608,_plus26,torepr31);
++R.GAS;
return $ret46024603;
};
},{"length":1});
var anf_variant_member15484246 = R.makeMethod(function(self4314595) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[768],0,arguments);
}
var ann_DASH_check_DASH_temp15474594 = ("a-colon");
return ann_DASH_check_DASH_temp15474594;
};
},{"length":1});
var anf_variant_member15574247 = R.makeMethod(function(self4324591) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[767],0,arguments);
}
var anf_fun15504590 = G(PP337,"infix",L[766]);
var anf_bracket15514593 = G(self4324591,"obj",L[765]);
var anf_fun15524588 = G(anf_bracket15514593,"tosource",L[764]);
var $z45804581 = D;
var $f45864587 = function(_) {
return R.isFunction(anf_fun15524588)?anf_fun15524588.app():R.ffi.throwNonFunApp(L[763],anf_fun15524588,[]);
};
try {
if(--R.GAS > 0) {
$z45804581 = $f45864587();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45864587,
"from":L[763]});
}
} catch($e45784579) {
if(R.isCont($e45784579)) {
var $ss45824583 = {"from":L[763],
"go":function(anf_arg15534589) {
return $Hanf_arg34324592(anf_arg15534589,INDENT9187,PP337,anf_fun15504590,self4324591,str_DASH_colon98170);
}};
$e45784579.stack[R.EXN_STACKHEIGHT++] = $ss45824583;
}
if(R.isPyretException($e45784579)) {
$e45784579.pyretStack.push(L[763]);
}
throw $e45784579;
}
var $ret45844585 = $Hanf_arg34324592($z45804581,INDENT9187,PP337,anf_fun15504590,self4324591,str_DASH_colon98170);
++R.GAS;
return $ret45844585;
};
},{"length":1});
var anf_variant_member15714256 = R.makeMethod(function(self1964556) {
return function(cases_DASH_funs1974557,else_DASH_clause1984568) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[663],2,arguments);
}
var if_DASH_2004571 = R.hasField(cases_DASH_funs1974557,("a-get-bang"));
var if_helper15594554 = R.makeFunction(function(if_helper_arg15604576) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[663],1,arguments);
}
var ann_DASH_check_DASH_temp15584577 = if_helper_arg15604576;
return ann_DASH_check_DASH_temp15584577;
});
var anf_if15634575 = R.isBoolean(if_DASH_2004571);
if(R.isPyretTrue(anf_if15634575)) {
if(R.isPyretTrue(if_DASH_2004571)) {
var call_DASH_a_DASH_get_DASH_bang1954549 = G(cases_DASH_funs1974557,"a-get-bang",L[663]);
var anf_arg15664550 = G(self1964556,"l",L[762]);
var anf_arg15674551 = G(self1964556,"obj",L[761]);
var anf_arg15684552 = G(self1964556,"field",L[760]);
var $z45414542 = D;
var $f45474548 = function(_) {
return R.isFunction(call_DASH_a_DASH_get_DASH_bang1954549)?call_DASH_a_DASH_get_DASH_bang1954549.app(anf_arg15664550,anf_arg15674551,anf_arg15684552):R.ffi.throwNonFunApp(L[663],call_DASH_a_DASH_get_DASH_bang1954549,[anf_arg15664550,anf_arg15674551,anf_arg15684552]);
};
try {
if(--R.GAS > 0) {
$z45414542 = $f45474548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45474548,
"from":L[663]});
}
} catch($e45394540) {
if(R.isCont($e45394540)) {
var $ss45434544 = {"from":L[663],
"go":function(cont_tail_arg15694553) {
return $Hcont_tail_arg34334555(cont_tail_arg15694553,if_helper15594554);
}};
$e45394540.stack[R.EXN_STACKHEIGHT++] = $ss45434544;
}
if(R.isPyretException($e45394540)) {
$e45394540.pyretStack.push(L[663]);
}
throw $e45394540;
}
var $ret45454546 = $Hcont_tail_arg34334555($z45414542,if_helper15594554);
++R.GAS;
return $ret45454546;
} else {
var $z45604561 = D;
var $f45664567 = function(_) {
return R.isFunction(else_DASH_clause1984568)?else_DASH_clause1984568.app():R.ffi.throwNonFunApp(L[663],else_DASH_clause1984568,[]);
};
try {
if(--R.GAS > 0) {
$z45604561 = $f45664567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45664567,
"from":L[663]});
}
} catch($e45584559) {
if(R.isCont($e45584559)) {
var $ss45624563 = {"from":L[663],
"go":function(cont_tail_arg15644569) {
return $Hcont_tail_arg34344570(cont_tail_arg15644569,if_helper15594554);
}};
$e45584559.stack[R.EXN_STACKHEIGHT++] = $ss45624563;
}
if(R.isPyretException($e45584559)) {
$e45584559.pyretStack.push(L[663]);
}
throw $e45584559;
}
var $ret45644565 = $Hcont_tail_arg34344570($z45604561,if_helper15594554);
++R.GAS;
return $ret45644565;
}
} else {
var cont_tail_arg15614574 = R.throwNonBooleanCondition(L[663],("if"),if_DASH_2004571);
if(--R.GAS > 0) {
$z45724573 = R.isFunction(if_helper15594554)?if_helper15594554.app(cont_tail_arg15614574):R.ffi.throwNonFunApp(L[663],if_helper15594554,[cont_tail_arg15614574]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15594554)?if_helper15594554.app(cont_tail_arg15614574):R.ffi.throwNonFunApp(L[663],if_helper15594554,[cont_tail_arg15614574]);
},
"from":L[663]});
}
++R.GAS;
return $z45724573;
}
};
},{"length":3});
var anf_variant_member15854257 = R.makeMethod(function(self1994537) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[663],0,arguments);
}
var anf_arg15734535 = G(self1994537,"l",L[663]);
var $z45274528 = D;
var $f45334534 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg15734535):R.ffi.throwNonFunApp(L[663],torepr31,[anf_arg15734535]);
};
try {
if(--R.GAS > 0) {
$z45274528 = $f45334534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45334534,
"from":L[663]});
}
} catch($e45254526) {
if(R.isCont($e45254526)) {
var $ss45294530 = {"from":L[663],
"go":function(anf_arg15744536) {
return $Hanf_arg34444538(anf_arg15744536,self1994537,_plus26,torepr31);
}};
$e45254526.stack[R.EXN_STACKHEIGHT++] = $ss45294530;
}
if(R.isPyretException($e45254526)) {
$e45254526.pyretStack.push(L[663]);
}
throw $e45254526;
}
var $ret45314532 = $Hanf_arg34444538($z45274528,self1994537,_plus26,torepr31);
++R.GAS;
return $ret45314532;
};
},{"length":1});
var anf_variant_member15874258 = R.makeMethod(function(self4364524) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[759],0,arguments);
}
var ann_DASH_check_DASH_temp15864523 = ("a-get-bang");
return ann_DASH_check_DASH_temp15864523;
};
},{"length":1});
var anf_variant_member15964259 = R.makeMethod(function(self4374520) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[758],0,arguments);
}
var anf_fun15894519 = G(PP337,"infix",L[757]);
var anf_bracket15904522 = G(self4374520,"obj",L[756]);
var anf_fun15914517 = G(anf_bracket15904522,"tosource",L[755]);
var $z45094510 = D;
var $f45154516 = function(_) {
return R.isFunction(anf_fun15914517)?anf_fun15914517.app():R.ffi.throwNonFunApp(L[754],anf_fun15914517,[]);
};
try {
if(--R.GAS > 0) {
$z45094510 = $f45154516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45154516,
"from":L[754]});
}
} catch($e45074508) {
if(R.isCont($e45074508)) {
var $ss45114512 = {"from":L[754],
"go":function(anf_arg15924518) {
return $Hanf_arg34474521(anf_arg15924518,INDENT9187,PP337,anf_fun15894519,self4374520,str_DASH_bang96144);
}};
$e45074508.stack[R.EXN_STACKHEIGHT++] = $ss45114512;
}
if(R.isPyretException($e45074508)) {
$e45074508.pyretStack.push(L[754]);
}
throw $e45074508;
}
var $ret45134514 = $Hanf_arg34474521($z45094510,INDENT9187,PP337,anf_fun15894519,self4374520,str_DASH_bang96144);
++R.GAS;
return $ret45134514;
};
},{"length":1});
var anf_variant_member16114268 = R.makeMethod(function(self2024485) {
return function(cases_DASH_funs2034486,else_DASH_clause2044497) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[662],2,arguments);
}
var if_DASH_2064500 = R.hasField(cases_DASH_funs2034486,("a-lam"));
var if_helper15984483 = R.makeFunction(function(if_helper_arg15994505) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[662],1,arguments);
}
var ann_DASH_check_DASH_temp15974506 = if_helper_arg15994505;
return ann_DASH_check_DASH_temp15974506;
});
var anf_if16024504 = R.isBoolean(if_DASH_2064500);
if(R.isPyretTrue(anf_if16024504)) {
if(R.isPyretTrue(if_DASH_2064500)) {
var call_DASH_a_DASH_lam2014477 = G(cases_DASH_funs2034486,"a-lam",L[662]);
var anf_arg16054478 = G(self2024485,"l",L[753]);
var anf_arg16064479 = G(self2024485,"args",L[752]);
var anf_arg16074480 = G(self2024485,"ret",L[751]);
var anf_arg16084481 = G(self2024485,"body",L[750]);
var $z44694470 = D;
var $f44754476 = function(_) {
return R.isFunction(call_DASH_a_DASH_lam2014477)?call_DASH_a_DASH_lam2014477.app(anf_arg16054478,anf_arg16064479,anf_arg16074480,anf_arg16084481):R.ffi.throwNonFunApp(L[662],call_DASH_a_DASH_lam2014477,[anf_arg16054478,anf_arg16064479,anf_arg16074480,anf_arg16084481]);
};
try {
if(--R.GAS > 0) {
$z44694470 = $f44754476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44754476,
"from":L[662]});
}
} catch($e44674468) {
if(R.isCont($e44674468)) {
var $ss44714472 = {"from":L[662],
"go":function(cont_tail_arg16094482) {
return $Hcont_tail_arg34484484(cont_tail_arg16094482,if_helper15984483);
}};
$e44674468.stack[R.EXN_STACKHEIGHT++] = $ss44714472;
}
if(R.isPyretException($e44674468)) {
$e44674468.pyretStack.push(L[662]);
}
throw $e44674468;
}
var $ret44734474 = $Hcont_tail_arg34484484($z44694470,if_helper15984483);
++R.GAS;
return $ret44734474;
} else {
var $z44894490 = D;
var $f44954496 = function(_) {
return R.isFunction(else_DASH_clause2044497)?else_DASH_clause2044497.app():R.ffi.throwNonFunApp(L[662],else_DASH_clause2044497,[]);
};
try {
if(--R.GAS > 0) {
$z44894490 = $f44954496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44954496,
"from":L[662]});
}
} catch($e44874488) {
if(R.isCont($e44874488)) {
var $ss44914492 = {"from":L[662],
"go":function(cont_tail_arg16034498) {
return $Hcont_tail_arg34494499(cont_tail_arg16034498,if_helper15984483);
}};
$e44874488.stack[R.EXN_STACKHEIGHT++] = $ss44914492;
}
if(R.isPyretException($e44874488)) {
$e44874488.pyretStack.push(L[662]);
}
throw $e44874488;
}
var $ret44934494 = $Hcont_tail_arg34494499($z44894490,if_helper15984483);
++R.GAS;
return $ret44934494;
}
} else {
var cont_tail_arg16004503 = R.throwNonBooleanCondition(L[662],("if"),if_DASH_2064500);
if(--R.GAS > 0) {
$z45014502 = R.isFunction(if_helper15984483)?if_helper15984483.app(cont_tail_arg16004503):R.ffi.throwNonFunApp(L[662],if_helper15984483,[cont_tail_arg16004503]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15984483)?if_helper15984483.app(cont_tail_arg16004503):R.ffi.throwNonFunApp(L[662],if_helper15984483,[cont_tail_arg16004503]);
},
"from":L[662]});
}
++R.GAS;
return $z45014502;
}
};
},{"length":3});
var anf_variant_member16294269 = R.makeMethod(function(self2054465) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[662],0,arguments);
}
var anf_arg16134463 = G(self2054465,"l",L[662]);
var $z44554456 = D;
var $f44614462 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg16134463):R.ffi.throwNonFunApp(L[662],torepr31,[anf_arg16134463]);
};
try {
if(--R.GAS > 0) {
$z44554456 = $f44614462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44614462,
"from":L[662]});
}
} catch($e44534454) {
if(R.isCont($e44534454)) {
var $ss44574458 = {"from":L[662],
"go":function(anf_arg16144464) {
return $Hanf_arg34624466(anf_arg16144464,self2054465,_plus26,torepr31);
}};
$e44534454.stack[R.EXN_STACKHEIGHT++] = $ss44574458;
}
if(R.isPyretException($e44534454)) {
$e44534454.pyretStack.push(L[662]);
}
throw $e44534454;
}
var $ret44594460 = $Hanf_arg34624466($z44554456,self2054465,_plus26,torepr31);
++R.GAS;
return $ret44594460;
};
},{"length":1});
var anf_variant_member16314270 = R.makeMethod(function(self4424452) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[749],0,arguments);
}
var ann_DASH_check_DASH_temp16304451 = ("a-lam");
return ann_DASH_check_DASH_temp16304451;
};
},{"length":1});
var anf_variant_member16374271 = R.makeMethod(function(self4434449) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[748],0,arguments);
}
var anf_fun16334447 = G(PP337,"str",L[747]);
var $z44394440 = D;
var $f44454446 = function(_) {
return R.isFunction(anf_fun16334447)?anf_fun16334447.app(("lam")):R.ffi.throwNonFunApp(L[746],anf_fun16334447,[("lam")]);
};
try {
if(--R.GAS > 0) {
$z44394440 = $f44454446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44454446,
"from":L[746]});
}
} catch($e44374438) {
if(R.isCont($e44374438)) {
var $ss44414442 = {"from":L[746],
"go":function(anf_arg16344448) {
return $Hanf_arg34644450(anf_arg16344448,fun_DASH_method_DASH_pretty219597,self4434449);
}};
$e44374438.stack[R.EXN_STACKHEIGHT++] = $ss44414442;
}
if(R.isPyretException($e44374438)) {
$e44374438.pyretStack.push(L[746]);
}
throw $e44374438;
}
var $ret44434444 = $Hanf_arg34644450($z44394440,fun_DASH_method_DASH_pretty219597,self4434449);
++R.GAS;
return $ret44434444;
};
},{"length":1});
var anf_variant_member16524281 = R.makeMethod(function(self2084415) {
return function(cases_DASH_funs2094416,else_DASH_clause2104427) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[661],2,arguments);
}
var if_DASH_2124430 = R.hasField(cases_DASH_funs2094416,("a-method"));
var if_helper16394413 = R.makeFunction(function(if_helper_arg16404435) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[661],1,arguments);
}
var ann_DASH_check_DASH_temp16384436 = if_helper_arg16404435;
return ann_DASH_check_DASH_temp16384436;
});
var anf_if16434434 = R.isBoolean(if_DASH_2124430);
if(R.isPyretTrue(anf_if16434434)) {
if(R.isPyretTrue(if_DASH_2124430)) {
var call_DASH_a_DASH_method2074407 = G(cases_DASH_funs2094416,"a-method",L[661]);
var anf_arg16464408 = G(self2084415,"l",L[745]);
var anf_arg16474409 = G(self2084415,"args",L[744]);
var anf_arg16484410 = G(self2084415,"ret",L[743]);
var anf_arg16494411 = G(self2084415,"body",L[742]);
var $z43994400 = D;
var $f44054406 = function(_) {
return R.isFunction(call_DASH_a_DASH_method2074407)?call_DASH_a_DASH_method2074407.app(anf_arg16464408,anf_arg16474409,anf_arg16484410,anf_arg16494411):R.ffi.throwNonFunApp(L[661],call_DASH_a_DASH_method2074407,[anf_arg16464408,anf_arg16474409,anf_arg16484410,anf_arg16494411]);
};
try {
if(--R.GAS > 0) {
$z43994400 = $f44054406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44054406,
"from":L[661]});
}
} catch($e43974398) {
if(R.isCont($e43974398)) {
var $ss44014402 = {"from":L[661],
"go":function(cont_tail_arg16504412) {
return $Hcont_tail_arg34654414(cont_tail_arg16504412,if_helper16394413);
}};
$e43974398.stack[R.EXN_STACKHEIGHT++] = $ss44014402;
}
if(R.isPyretException($e43974398)) {
$e43974398.pyretStack.push(L[661]);
}
throw $e43974398;
}
var $ret44034404 = $Hcont_tail_arg34654414($z43994400,if_helper16394413);
++R.GAS;
return $ret44034404;
} else {
var $z44194420 = D;
var $f44254426 = function(_) {
return R.isFunction(else_DASH_clause2104427)?else_DASH_clause2104427.app():R.ffi.throwNonFunApp(L[661],else_DASH_clause2104427,[]);
};
try {
if(--R.GAS > 0) {
$z44194420 = $f44254426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44254426,
"from":L[661]});
}
} catch($e44174418) {
if(R.isCont($e44174418)) {
var $ss44214422 = {"from":L[661],
"go":function(cont_tail_arg16444428) {
return $Hcont_tail_arg34664429(cont_tail_arg16444428,if_helper16394413);
}};
$e44174418.stack[R.EXN_STACKHEIGHT++] = $ss44214422;
}
if(R.isPyretException($e44174418)) {
$e44174418.pyretStack.push(L[661]);
}
throw $e44174418;
}
var $ret44234424 = $Hcont_tail_arg34664429($z44194420,if_helper16394413);
++R.GAS;
return $ret44234424;
}
} else {
var cont_tail_arg16414433 = R.throwNonBooleanCondition(L[661],("if"),if_DASH_2124430);
if(--R.GAS > 0) {
$z44314432 = R.isFunction(if_helper16394413)?if_helper16394413.app(cont_tail_arg16414433):R.ffi.throwNonFunApp(L[661],if_helper16394413,[cont_tail_arg16414433]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper16394413)?if_helper16394413.app(cont_tail_arg16414433):R.ffi.throwNonFunApp(L[661],if_helper16394413,[cont_tail_arg16414433]);
},
"from":L[661]});
}
++R.GAS;
return $z44314432;
}
};
},{"length":3});
var anf_variant_member16704282 = R.makeMethod(function(self2114395) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[661],0,arguments);
}
var anf_arg16544393 = G(self2114395,"l",L[661]);
var $z43854386 = D;
var $f43914392 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg16544393):R.ffi.throwNonFunApp(L[661],torepr31,[anf_arg16544393]);
};
try {
if(--R.GAS > 0) {
$z43854386 = $f43914392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43914392,
"from":L[661]});
}
} catch($e43834384) {
if(R.isCont($e43834384)) {
var $ss43874388 = {"from":L[661],
"go":function(anf_arg16554394) {
return $Hanf_arg34794396(anf_arg16554394,self2114395,_plus26,torepr31);
}};
$e43834384.stack[R.EXN_STACKHEIGHT++] = $ss43874388;
}
if(R.isPyretException($e43834384)) {
$e43834384.pyretStack.push(L[661]);
}
throw $e43834384;
}
var $ret43894390 = $Hanf_arg34794396($z43854386,self2114395,_plus26,torepr31);
++R.GAS;
return $ret43894390;
};
},{"length":1});
var anf_variant_member16724283 = R.makeMethod(function(self4484382) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[741],0,arguments);
}
var ann_DASH_check_DASH_temp16714381 = ("a-method");
return ann_DASH_check_DASH_temp16714381;
};
},{"length":1});
var anf_variant_member16784284 = R.makeMethod(function(self4494379) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[740],0,arguments);
}
var anf_fun16744377 = G(PP337,"str",L[739]);
var $z43694370 = D;
var $f43754376 = function(_) {
return R.isFunction(anf_fun16744377)?anf_fun16744377.app(("method")):R.ffi.throwNonFunApp(L[738],anf_fun16744377,[("method")]);
};
try {
if(--R.GAS > 0) {
$z43694370 = $f43754376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43754376,
"from":L[738]});
}
} catch($e43674368) {
if(R.isCont($e43674368)) {
var $ss43714372 = {"from":L[738],
"go":function(anf_arg16754378) {
return $Hanf_arg34814380(anf_arg16754378,fun_DASH_method_DASH_pretty219597,self4494379);
}};
$e43674368.stack[R.EXN_STACKHEIGHT++] = $ss43714372;
}
if(R.isPyretException($e43674368)) {
$e43674368.pyretStack.push(L[738]);
}
throw $e43674368;
}
var $ret43734374 = $Hanf_arg34814380($z43694370,fun_DASH_method_DASH_pretty219597,self4494379);
++R.GAS;
return $ret43734374;
};
},{"length":1});
var anf_variant_member16904294 = R.makeMethod(function(self2144345) {
return function(cases_DASH_funs2154346,else_DASH_clause2164357) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[660],2,arguments);
}
var if_DASH_2184360 = R.hasField(cases_DASH_funs2154346,("a-val"));
var if_helper16804343 = R.makeFunction(function(if_helper_arg16814365) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[660],1,arguments);
}
var ann_DASH_check_DASH_temp16794366 = if_helper_arg16814365;
return ann_DASH_check_DASH_temp16794366;
});
var anf_if16844364 = R.isBoolean(if_DASH_2184360);
if(R.isPyretTrue(anf_if16844364)) {
if(R.isPyretTrue(if_DASH_2184360)) {
var call_DASH_a_DASH_val2134340 = G(cases_DASH_funs2154346,"a-val",L[660]);
var anf_arg16874341 = G(self2144345,"v",L[737]);
var $z43324333 = D;
var $f43384339 = function(_) {
return R.isFunction(call_DASH_a_DASH_val2134340)?call_DASH_a_DASH_val2134340.app(anf_arg16874341):R.ffi.throwNonFunApp(L[660],call_DASH_a_DASH_val2134340,[anf_arg16874341]);
};
try {
if(--R.GAS > 0) {
$z43324333 = $f43384339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43384339,
"from":L[660]});
}
} catch($e43304331) {
if(R.isCont($e43304331)) {
var $ss43344335 = {"from":L[660],
"go":function(cont_tail_arg16884342) {
return $Hcont_tail_arg34824344(cont_tail_arg16884342,if_helper16804343);
}};
$e43304331.stack[R.EXN_STACKHEIGHT++] = $ss43344335;
}
if(R.isPyretException($e43304331)) {
$e43304331.pyretStack.push(L[660]);
}
throw $e43304331;
}
var $ret43364337 = $Hcont_tail_arg34824344($z43324333,if_helper16804343);
++R.GAS;
return $ret43364337;
} else {
var $z43494350 = D;
var $f43554356 = function(_) {
return R.isFunction(else_DASH_clause2164357)?else_DASH_clause2164357.app():R.ffi.throwNonFunApp(L[660],else_DASH_clause2164357,[]);
};
try {
if(--R.GAS > 0) {
$z43494350 = $f43554356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43554356,
"from":L[660]});
}
} catch($e43474348) {
if(R.isCont($e43474348)) {
var $ss43514352 = {"from":L[660],
"go":function(cont_tail_arg16854358) {
return $Hcont_tail_arg34834359(cont_tail_arg16854358,if_helper16804343);
}};
$e43474348.stack[R.EXN_STACKHEIGHT++] = $ss43514352;
}
if(R.isPyretException($e43474348)) {
$e43474348.pyretStack.push(L[660]);
}
throw $e43474348;
}
var $ret43534354 = $Hcont_tail_arg34834359($z43494350,if_helper16804343);
++R.GAS;
return $ret43534354;
}
} else {
var cont_tail_arg16824363 = R.throwNonBooleanCondition(L[660],("if"),if_DASH_2184360);
if(--R.GAS > 0) {
$z43614362 = R.isFunction(if_helper16804343)?if_helper16804343.app(cont_tail_arg16824363):R.ffi.throwNonFunApp(L[660],if_helper16804343,[cont_tail_arg16824363]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper16804343)?if_helper16804343.app(cont_tail_arg16824363):R.ffi.throwNonFunApp(L[660],if_helper16804343,[cont_tail_arg16824363]);
},
"from":L[660]});
}
++R.GAS;
return $z43614362;
}
};
},{"length":3});
var anf_variant_member16964295 = R.makeMethod(function(self2174329) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[660],0,arguments);
}
var anf_arg16924326 = G(self2174329,"v",L[660]);
var $z43184319 = D;
var $f43244325 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg16924326):R.ffi.throwNonFunApp(L[660],torepr31,[anf_arg16924326]);
};
try {
if(--R.GAS > 0) {
$z43184319 = $f43244325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43244325,
"from":L[660]});
}
} catch($e43164317) {
if(R.isCont($e43164317)) {
var $ss43204321 = {"from":L[660],
"go":function(anf_arg16934327) {
return $Hanf_arg34874328(anf_arg16934327,_plus26);
}};
$e43164317.stack[R.EXN_STACKHEIGHT++] = $ss43204321;
}
if(R.isPyretException($e43164317)) {
$e43164317.pyretStack.push(L[660]);
}
throw $e43164317;
}
var $ret43224323 = $Hanf_arg34874328($z43184319,_plus26);
++R.GAS;
return $ret43224323;
};
},{"length":1});
var anf_variant_member16984296 = R.makeMethod(function(self4514315) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[736],0,arguments);
}
var ann_DASH_check_DASH_temp16974314 = ("a-val");
return ann_DASH_check_DASH_temp16974314;
};
},{"length":1});
var anf_variant_member17024297 = R.makeMethod(function(self4524313) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[733],0,arguments);
}
var anf_bracket17004312 = G(self4524313,"v",L[735]);
var anf_fun17014309 = G(anf_bracket17004312,"tosource",L[734]);
var $z43014302 = D;
var $f43074308 = function(_) {
return R.isFunction(anf_fun17014309)?anf_fun17014309.app():R.ffi.throwNonFunApp(L[733],anf_fun17014309,[]);
};
try {
if(--R.GAS > 0) {
$z43014302 = $f43074308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43074308,
"from":L[733]});
}
} catch($e42994300) {
if(R.isCont($e42994300)) {
var $ss43034304 = {"from":L[733],
"go":function(ann_DASH_check_DASH_temp16994310) {
return $Hann_DASH_check_DASH_temp34884311(ann_DASH_check_DASH_temp16994310);
}};
$e42994300.stack[R.EXN_STACKHEIGHT++] = $ss43034304;
}
if(R.isPyretException($e42994300)) {
$e42994300.pyretStack.push(L[733]);
}
throw $e42994300;
}
var $ret43054306 = $Hann_DASH_check_DASH_temp34884311($z43014302);
++R.GAS;
return $ret43054306;
};
},{"length":1});
var anf_assign1703536 = (function() {
var $a_DASH_module_DASH_base41284129 = {"visit":anf_shared10994127,
"_match":anf_variant_member11154133,
"_torepr":anf_variant_member11374134,
"label":anf_variant_member11394135,
"tosource":anf_variant_member11864136};
var $a_DASH_module_DASH_brands41314132 = {"$brand-a-module4130":true};
$a_DASH_module_DASH_brands41314132[ALettableT118574._brand] = true
var $a_DASH_data_DASH_expr_DASH_base41424143 = {"visit":anf_shared10994127,
"_match":anf_variant_member12024147,
"_torepr":anf_variant_member12244148,
"label":anf_variant_member12264149,
"tosource":anf_variant_member12294150};
var $a_DASH_data_DASH_expr_DASH_brands41454146 = {"$brand-a-data-expr4144":true};
$a_DASH_data_DASH_expr_DASH_brands41454146[ALettableT118574._brand] = true
var $a_DASH_assign_DASH_base41564157 = {"visit":anf_shared10994127,
"_match":anf_variant_member12434161,
"_torepr":anf_variant_member12574162,
"label":anf_variant_member12594163,
"tosource":anf_variant_member12734164};
var $a_DASH_assign_DASH_brands41594160 = {"$brand-a-assign4158":true};
$a_DASH_assign_DASH_brands41594160[ALettableT118574._brand] = true
var $a_DASH_app_DASH_base41684169 = {"visit":anf_shared10994127,
"_match":anf_variant_member12874173,
"_torepr":anf_variant_member13014174,
"label":anf_variant_member13034175,
"tosource":anf_variant_member13234176};
var $a_DASH_app_DASH_brands41714172 = {"$brand-a-app4170":true};
$a_DASH_app_DASH_brands41714172[ALettableT118574._brand] = true
var $a_DASH_prim_DASH_app_DASH_base41804181 = {"visit":anf_shared10994127,
"_match":anf_variant_member13374185,
"_torepr":anf_variant_member13514186,
"label":anf_variant_member13534187,
"tosource":anf_variant_member13734188};
var $a_DASH_prim_DASH_app_DASH_brands41834184 = {"$brand-a-prim-app4182":true};
$a_DASH_prim_DASH_app_DASH_brands41834184[ALettableT118574._brand] = true
var $a_DASH_obj_DASH_base41924193 = {"visit":anf_shared10994127,
"_match":anf_variant_member13864197,
"_torepr":anf_variant_member13964198,
"label":anf_variant_member13984199,
"tosource":anf_variant_member14134200};
var $a_DASH_obj_DASH_brands41954196 = {"$brand-a-obj4194":true};
$a_DASH_obj_DASH_brands41954196[ALettableT118574._brand] = true
var $a_DASH_update_DASH_base42034204 = {"visit":anf_shared10994127,
"_match":anf_variant_member14274208,
"_torepr":anf_variant_member14414209,
"label":anf_variant_member14434210,
"tosource":anf_variant_member14464211};
var $a_DASH_update_DASH_brands42064207 = {"$brand-a-update4205":true};
$a_DASH_update_DASH_brands42064207[ALettableT118574._brand] = true
var $a_DASH_extend_DASH_base42154216 = {"visit":anf_shared10994127,
"_match":anf_variant_member14604220,
"_torepr":anf_variant_member14744221,
"label":anf_variant_member14764222,
"tosource":anf_variant_member14794223};
var $a_DASH_extend_DASH_brands42184219 = {"$brand-a-extend4217":true};
$a_DASH_extend_DASH_brands42184219[ALettableT118574._brand] = true
var $a_DASH_dot_DASH_base42274228 = {"visit":anf_shared10994127,
"_match":anf_variant_member14934232,
"_torepr":anf_variant_member15074233,
"label":anf_variant_member15094234,
"tosource":anf_variant_member15184235};
var $a_DASH_dot_DASH_brands42304231 = {"$brand-a-dot4229":true};
$a_DASH_dot_DASH_brands42304231[ALettableT118574._brand] = true
var $a_DASH_colon_DASH_base42394240 = {"visit":anf_shared10994127,
"_match":anf_variant_member15324244,
"_torepr":anf_variant_member15464245,
"label":anf_variant_member15484246,
"tosource":anf_variant_member15574247};
var $a_DASH_colon_DASH_brands42424243 = {"$brand-a-colon4241":true};
$a_DASH_colon_DASH_brands42424243[ALettableT118574._brand] = true
var $a_DASH_get_DASH_bang_DASH_base42514252 = {"visit":anf_shared10994127,
"_match":anf_variant_member15714256,
"_torepr":anf_variant_member15854257,
"label":anf_variant_member15874258,
"tosource":anf_variant_member15964259};
var $a_DASH_get_DASH_bang_DASH_brands42544255 = {"$brand-a-get-bang4253":true};
$a_DASH_get_DASH_bang_DASH_brands42544255[ALettableT118574._brand] = true
var $a_DASH_lam_DASH_base42634264 = {"visit":anf_shared10994127,
"_match":anf_variant_member16114268,
"_torepr":anf_variant_member16294269,
"label":anf_variant_member16314270,
"tosource":anf_variant_member16374271};
var $a_DASH_lam_DASH_brands42664267 = {"$brand-a-lam4265":true};
$a_DASH_lam_DASH_brands42664267[ALettableT118574._brand] = true
var $a_DASH_method_DASH_base42764277 = {"visit":anf_shared10994127,
"_match":anf_variant_member16524281,
"_torepr":anf_variant_member16704282,
"label":anf_variant_member16724283,
"tosource":anf_variant_member16784284};
var $a_DASH_method_DASH_brands42794280 = {"$brand-a-method4278":true};
$a_DASH_method_DASH_brands42794280[ALettableT118574._brand] = true
var $a_DASH_val_DASH_base42894290 = {"visit":anf_shared10994127,
"_match":anf_variant_member16904294,
"_torepr":anf_variant_member16964295,
"label":anf_variant_member16984296,
"tosource":anf_variant_member17024297};
var $a_DASH_val_DASH_brands42924293 = {"$brand-a-val4291":true};
$a_DASH_val_DASH_brands42924293[ALettableT118574._brand] = true
return R.makeObject({"ALettable":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[674],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ALettableT118574._brand));
}),
"is-a-module":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[673],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-module4130"));
}),
"a-module":R.makeFunction(function(l3764137,answer3774138,provides3784139,types3794140,checks3804141) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[675],5,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,AVal8881,AVal8881],[l3764137,answer3774138,provides3784139,checks3804141],[L[676],L[677],L[678],L[679]],function() {
var dict = R.create($a_DASH_module_DASH_base41284129);
dict["l"] = l3764137
dict["answer"] = answer3774138
dict["provides"] = provides3784139
dict["types"] = types3794140
dict["checks"] = checks3804141
return R.makeBrandedObject(dict,$a_DASH_module_DASH_brands41314132);
});
}),
"is-a-data-expr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[672],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-data-expr4144"));
}),
"a-data-expr":R.makeFunction(function(l3844151,name3854152,namet3864153,variants3874154,shared3884155) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[680],5,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,R.getDotAnn(L[681],"A",A244,"Name"),List1788,List1788],[l3844151,name3854152,namet3864153,variants3874154,shared3884155],[L[682],L[683],L[681],L[684],L[685]],function() {
var dict = R.create($a_DASH_data_DASH_expr_DASH_base41424143);
dict["l"] = l3844151
dict["name"] = name3854152
dict["namet"] = namet3864153
dict["variants"] = variants3874154
dict["shared"] = shared3884155
return R.makeBrandedObject(dict,$a_DASH_data_DASH_expr_DASH_brands41454146);
});
}),
"is-a-assign":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[671],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-assign4158"));
}),
"a-assign":R.makeFunction(function(l3914165,id3924166,value3934167) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[686],3,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[687],"A",A244,"Name"),AVal8881],[l3914165,id3924166,value3934167],[L[688],L[687],L[689]],function() {
var dict = R.create($a_DASH_assign_DASH_base41564157);
dict["l"] = l3914165
dict["id"] = id3924166
dict["value"] = value3934167
return R.makeBrandedObject(dict,$a_DASH_assign_DASH_brands41594160);
});
}),
"is-a-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[670],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-app4170"));
}),
"a-app":R.makeFunction(function(l3964177,_fun3974178,args3984179) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[690],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,List1788],[l3964177,_fun3974178,args3984179],[L[691],L[692],L[693]],function() {
var dict = R.create($a_DASH_app_DASH_base41684169);
dict["l"] = l3964177
dict["_fun"] = _fun3974178
dict["args"] = args3984179
return R.makeBrandedObject(dict,$a_DASH_app_DASH_brands41714172);
});
}),
"is-a-prim-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[669],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-prim-app4182"));
}),
"a-prim-app":R.makeFunction(function(l4024189,f4034190,args4044191) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[694],3,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,List1788],[l4024189,f4034190,args4044191],[L[695],L[696],L[697]],function() {
var dict = R.create($a_DASH_prim_DASH_app_DASH_base41804181);
dict["l"] = l4024189
dict["f"] = f4034190
dict["args"] = args4044191
return R.makeBrandedObject(dict,$a_DASH_prim_DASH_app_DASH_brands41834184);
});
}),
"is-a-obj":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[668],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-obj4194"));
}),
"a-obj":R.makeFunction(function(l4084201,fields4094202) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[698],2,arguments);
}
return R.checkAnnArgs([Loc9089,List1788],[l4084201,fields4094202],[L[699],L[700]],function() {
var dict = R.create($a_DASH_obj_DASH_base41924193);
dict["l"] = l4084201
dict["fields"] = fields4094202
return R.makeBrandedObject(dict,$a_DASH_obj_DASH_brands41954196);
});
}),
"is-a-update":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[667],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-update4205"));
}),
"a-update":R.makeFunction(function(l4134212,supe4144213,fields4154214) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[701],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,List1788],[l4134212,supe4144213,fields4154214],[L[702],L[703],L[704]],function() {
var dict = R.create($a_DASH_update_DASH_base42034204);
dict["l"] = l4134212
dict["supe"] = supe4144213
dict["fields"] = fields4154214
return R.makeBrandedObject(dict,$a_DASH_update_DASH_brands42064207);
});
}),
"is-a-extend":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[666],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-extend4217"));
}),
"a-extend":R.makeFunction(function(l4184224,supe4194225,fields4204226) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[705],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,List1788],[l4184224,supe4194225,fields4204226],[L[706],L[707],L[708]],function() {
var dict = R.create($a_DASH_extend_DASH_base42154216);
dict["l"] = l4184224
dict["supe"] = supe4194225
dict["fields"] = fields4204226
return R.makeBrandedObject(dict,$a_DASH_extend_DASH_brands42184219);
});
}),
"is-a-dot":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[665],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-dot4229"));
}),
"a-dot":R.makeFunction(function(l4234236,obj4244237,field4254238) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[709],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,$type$String35],[l4234236,obj4244237,field4254238],[L[710],L[711],L[712]],function() {
var dict = R.create($a_DASH_dot_DASH_base42274228);
dict["l"] = l4234236
dict["obj"] = obj4244237
dict["field"] = field4254238
return R.makeBrandedObject(dict,$a_DASH_dot_DASH_brands42304231);
});
}),
"is-a-colon":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[664],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-colon4241"));
}),
"a-colon":R.makeFunction(function(l4284248,obj4294249,field4304250) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[713],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,$type$String35],[l4284248,obj4294249,field4304250],[L[714],L[715],L[716]],function() {
var dict = R.create($a_DASH_colon_DASH_base42394240);
dict["l"] = l4284248
dict["obj"] = obj4294249
dict["field"] = field4304250
return R.makeBrandedObject(dict,$a_DASH_colon_DASH_brands42424243);
});
}),
"is-a-get-bang":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[663],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-get-bang4253"));
}),
"a-get-bang":R.makeFunction(function(l4334260,obj4344261,field4354262) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[717],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,$type$String35],[l4334260,obj4344261,field4354262],[L[718],L[719],L[720]],function() {
var dict = R.create($a_DASH_get_DASH_bang_DASH_base42514252);
dict["l"] = l4334260
dict["obj"] = obj4344261
dict["field"] = field4354262
return R.makeBrandedObject(dict,$a_DASH_get_DASH_bang_DASH_brands42544255);
});
}),
"is-a-lam":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[662],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-lam4265"));
}),
"a-lam":R.makeFunction(function(l4384272,args4394273,ret4404274,body4414275) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[721],4,arguments);
}
return R.checkAnnArgs([Loc9089,List1788,R.getDotAnn(L[722],"A",A244,"Ann"),AExpr7465],[l4384272,args4394273,ret4404274,body4414275],[L[723],L[724],L[722],L[725]],function() {
var dict = R.create($a_DASH_lam_DASH_base42634264);
dict["l"] = l4384272
dict["args"] = args4394273
dict["ret"] = ret4404274
dict["body"] = body4414275
return R.makeBrandedObject(dict,$a_DASH_lam_DASH_brands42664267);
});
}),
"is-a-method":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[661],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-method4278"));
}),
"a-method":R.makeFunction(function(l4444285,args4454286,ret4464287,body4474288) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[726],4,arguments);
}
return R.checkAnnArgs([Loc9089,List1788,R.getDotAnn(L[727],"A",A244,"Ann"),AExpr7465],[l4444285,args4454286,ret4464287,body4474288],[L[728],L[729],L[727],L[730]],function() {
var dict = R.create($a_DASH_method_DASH_base42764277);
dict["l"] = l4444285
dict["args"] = args4454286
dict["ret"] = ret4464287
dict["body"] = body4474288
return R.makeBrandedObject(dict,$a_DASH_method_DASH_brands42794280);
});
}),
"is-a-val":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[660],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-val4291"));
}),
"a-val":R.makeFunction(function(v4504298) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[731],1,arguments);
}
return R.checkAnnArgs([AVal8881],[v4504298],[L[732]],function() {
var dict = R.create($a_DASH_val_DASH_base42894290);
dict["v"] = v4504298
return R.makeBrandedObject(dict,$a_DASH_val_DASH_brands42924293);
});
})});
})();
ALettable23188535.$var = anf_assign1703536;
var anf_assign1704538 = G(ALettable23188535.$var,"ALettable",L[674]);
ALettable189537.$var = anf_assign1704538;
var anf_assign1705540 = G(ALettable23188535.$var,"ALettable",L[674]);
is_DASH_ALettable190539.$var = anf_assign1705540;
var anf_assign1706542 = G(ALettable23188535.$var,"is-a-module",L[673]);
is_DASH_a_DASH_module191541.$var = anf_assign1706542;
var anf_assign1707544 = G(ALettable23188535.$var,"a-module",L[673]);
a_DASH_module192543.$var = anf_assign1707544;
var anf_assign1708546 = G(ALettable23188535.$var,"is-a-data-expr",L[672]);
is_DASH_a_DASH_data_DASH_expr193545.$var = anf_assign1708546;
var anf_assign1709548 = G(ALettable23188535.$var,"a-data-expr",L[672]);
a_DASH_data_DASH_expr194547.$var = anf_assign1709548;
var anf_assign1710550 = G(ALettable23188535.$var,"is-a-assign",L[671]);
is_DASH_a_DASH_assign195549.$var = anf_assign1710550;
var anf_assign1711552 = G(ALettable23188535.$var,"a-assign",L[671]);
a_DASH_assign196551.$var = anf_assign1711552;
var anf_assign1712554 = G(ALettable23188535.$var,"is-a-app",L[670]);
is_DASH_a_DASH_app197553.$var = anf_assign1712554;
var anf_assign1713556 = G(ALettable23188535.$var,"a-app",L[670]);
a_DASH_app198555.$var = anf_assign1713556;
var anf_assign1714558 = G(ALettable23188535.$var,"is-a-prim-app",L[669]);
is_DASH_a_DASH_prim_DASH_app199557.$var = anf_assign1714558;
var anf_assign1715560 = G(ALettable23188535.$var,"a-prim-app",L[669]);
a_DASH_prim_DASH_app200559.$var = anf_assign1715560;
var anf_assign1716562 = G(ALettable23188535.$var,"is-a-obj",L[668]);
is_DASH_a_DASH_obj201561.$var = anf_assign1716562;
var anf_assign1717564 = G(ALettable23188535.$var,"a-obj",L[668]);
a_DASH_obj202563.$var = anf_assign1717564;
var anf_assign1718566 = G(ALettable23188535.$var,"is-a-update",L[667]);
is_DASH_a_DASH_update203565.$var = anf_assign1718566;
var anf_assign1719568 = G(ALettable23188535.$var,"a-update",L[667]);
a_DASH_update204567.$var = anf_assign1719568;
var anf_assign1720570 = G(ALettable23188535.$var,"is-a-extend",L[666]);
is_DASH_a_DASH_extend205569.$var = anf_assign1720570;
var anf_assign1721572 = G(ALettable23188535.$var,"a-extend",L[666]);
a_DASH_extend206571.$var = anf_assign1721572;
var anf_assign1722574 = G(ALettable23188535.$var,"is-a-dot",L[665]);
is_DASH_a_DASH_dot207573.$var = anf_assign1722574;
var anf_assign1723576 = G(ALettable23188535.$var,"a-dot",L[665]);
a_DASH_dot208575.$var = anf_assign1723576;
var anf_assign1724578 = G(ALettable23188535.$var,"is-a-colon",L[664]);
is_DASH_a_DASH_colon209577.$var = anf_assign1724578;
var anf_assign1725580 = G(ALettable23188535.$var,"a-colon",L[664]);
a_DASH_colon210579.$var = anf_assign1725580;
var anf_assign1726582 = G(ALettable23188535.$var,"is-a-get-bang",L[663]);
is_DASH_a_DASH_get_DASH_bang211581.$var = anf_assign1726582;
var anf_assign1727584 = G(ALettable23188535.$var,"a-get-bang",L[663]);
a_DASH_get_DASH_bang212583.$var = anf_assign1727584;
var anf_assign1728586 = G(ALettable23188535.$var,"is-a-lam",L[662]);
is_DASH_a_DASH_lam213585.$var = anf_assign1728586;
var anf_assign1729588 = G(ALettable23188535.$var,"a-lam",L[662]);
a_DASH_lam214587.$var = anf_assign1729588;
var anf_assign1730590 = G(ALettable23188535.$var,"is-a-method",L[661]);
is_DASH_a_DASH_method215589.$var = anf_assign1730590;
var anf_assign1731592 = G(ALettable23188535.$var,"a-method",L[661]);
a_DASH_method216591.$var = anf_assign1731592;
var anf_assign1732594 = G(ALettable23188535.$var,"is-a-val",L[660]);
is_DASH_a_DASH_val217593.$var = anf_assign1732594;
var anf_assign1733596 = G(ALettable23188535.$var,"a-val",L[660]);
a_DASH_val218595.$var = anf_assign1733596;
var anf_assign1755598 = R.makeFunction(function(typ4554108,args4564109,body4574110) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[654],3,arguments);
}
var anf_fun17354124 = G(PP337,"nest",L[659]);
var anf_fun17364125 = G(PP337,"surround-separate",L[658]);
var anf_arg17374121 = G(PP337,"lparen",L[657]);
var anf_arg17384122 = G(PP337,"rparen",L[656]);
var $z41134114 = D;
var $f41194120 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg17374121,anf_arg17384122):R.ffi.throwNonFunApp(L[655],_plus26,[anf_arg17374121,anf_arg17384122]);
};
try {
if(--R.GAS > 0) {
$z41134114 = $f41194120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41194120,
"from":L[655]});
}
} catch($e41114112) {
if(R.isCont($e41114112)) {
var $ss41154116 = {"from":L[655],
"go":function(anf_arg17394123) {
return $Hanf_arg34984126(anf_arg17394123,INDENT9187,PP337,anf_fun17354124,anf_fun17364125,args4564109,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26);
}};
$e41114112.stack[R.EXN_STACKHEIGHT++] = $ss41154116;
}
if(R.isPyretException($e41114112)) {
$e41114112.pyretStack.push(L[655]);
}
throw $e41114112;
}
var $ret41174118 = $Hanf_arg34984126($z41134114,INDENT9187,PP337,anf_fun17354124,anf_fun17364125,args4564109,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26);
++R.GAS;
return $ret41174118;
});
fun_DASH_method_DASH_pretty219597.$var = anf_assign1755598;
var anf_shared17633995 = R.makeMethod(function(self4664107) {
return function(visitor4674090) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[649],1,arguments);
}
var anf_fun17574089 = G(self4664107,"_match",L[653]);
var anf_arg17624091 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[650],0,arguments);
}
var anf_fun17594104 = G(self4664107,"label",L[652]);
var $z40964097 = D;
var $f41024103 = function(_) {
return R.isFunction(anf_fun17594104)?anf_fun17594104.app():R.ffi.throwNonFunApp(L[651],anf_fun17594104,[]);
};
try {
if(--R.GAS > 0) {
$z40964097 = $f41024103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41024103,
"from":L[651]});
}
} catch($e40944095) {
if(R.isCont($e40944095)) {
var $ss40984099 = {"from":L[651],
"go":function(anf_arg17604105) {
return $Hanf_arg35014106(anf_arg17604105,_plus26,raise30);
}};
$e40944095.stack[R.EXN_STACKHEIGHT++] = $ss40984099;
}
if(R.isPyretException($e40944095)) {
$e40944095.pyretStack.push(L[651]);
}
throw $e40944095;
}
var $ret41004101 = $Hanf_arg35014106($z40964097,_plus26,raise30);
++R.GAS;
return $ret41004101;
});
var $z40814082 = D;
var $f40874088 = function(_) {
return R.isFunction(anf_fun17574089)?anf_fun17574089.app(visitor4674090,anf_arg17624091):R.ffi.throwNonFunApp(L[649],anf_fun17574089,[visitor4674090,anf_arg17624091]);
};
try {
if(--R.GAS > 0) {
$z40814082 = $f40874088();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40874088,
"from":L[649]});
}
} catch($e40794080) {
if(R.isCont($e40794080)) {
var $ss40834084 = {"from":L[649],
"go":function(ann_DASH_check_DASH_temp17564092) {
return $Hann_DASH_check_DASH_temp35024093(ann_DASH_check_DASH_temp17564092);
}};
$e40794080.stack[R.EXN_STACKHEIGHT++] = $ss40834084;
}
if(R.isPyretException($e40794080)) {
$e40794080.pyretStack.push(L[649]);
}
throw $e40794080;
}
var $ret40854086 = $Hann_DASH_check_DASH_temp35024093($z40814082);
++R.GAS;
return $ret40854086;
};
},{"length":2});
var anf_variant_member17774001 = R.makeMethod(function(self2204057) {
return function(cases_DASH_funs2214058,else_DASH_clause2224069) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[634],2,arguments);
}
var if_DASH_2244072 = R.hasField(cases_DASH_funs2214058,("a-field"));
var if_helper17654055 = R.makeFunction(function(if_helper_arg17664077) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[634],1,arguments);
}
var ann_DASH_check_DASH_temp17644078 = if_helper_arg17664077;
return ann_DASH_check_DASH_temp17644078;
});
var anf_if17694076 = R.isBoolean(if_DASH_2244072);
if(R.isPyretTrue(anf_if17694076)) {
if(R.isPyretTrue(if_DASH_2244072)) {
var call_DASH_a_DASH_field2194050 = G(cases_DASH_funs2214058,"a-field",L[634]);
var anf_arg17724051 = G(self2204057,"l",L[648]);
var anf_arg17734052 = G(self2204057,"name",L[647]);
var anf_arg17744053 = G(self2204057,"value",L[646]);
var $z40424043 = D;
var $f40484049 = function(_) {
return R.isFunction(call_DASH_a_DASH_field2194050)?call_DASH_a_DASH_field2194050.app(anf_arg17724051,anf_arg17734052,anf_arg17744053):R.ffi.throwNonFunApp(L[634],call_DASH_a_DASH_field2194050,[anf_arg17724051,anf_arg17734052,anf_arg17744053]);
};
try {
if(--R.GAS > 0) {
$z40424043 = $f40484049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40484049,
"from":L[634]});
}
} catch($e40404041) {
if(R.isCont($e40404041)) {
var $ss40444045 = {"from":L[634],
"go":function(cont_tail_arg17754054) {
return $Hcont_tail_arg35034056(cont_tail_arg17754054,if_helper17654055);
}};
$e40404041.stack[R.EXN_STACKHEIGHT++] = $ss40444045;
}
if(R.isPyretException($e40404041)) {
$e40404041.pyretStack.push(L[634]);
}
throw $e40404041;
}
var $ret40464047 = $Hcont_tail_arg35034056($z40424043,if_helper17654055);
++R.GAS;
return $ret40464047;
} else {
var $z40614062 = D;
var $f40674068 = function(_) {
return R.isFunction(else_DASH_clause2224069)?else_DASH_clause2224069.app():R.ffi.throwNonFunApp(L[634],else_DASH_clause2224069,[]);
};
try {
if(--R.GAS > 0) {
$z40614062 = $f40674068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40674068,
"from":L[634]});
}
} catch($e40594060) {
if(R.isCont($e40594060)) {
var $ss40634064 = {"from":L[634],
"go":function(cont_tail_arg17704070) {
return $Hcont_tail_arg35044071(cont_tail_arg17704070,if_helper17654055);
}};
$e40594060.stack[R.EXN_STACKHEIGHT++] = $ss40634064;
}
if(R.isPyretException($e40594060)) {
$e40594060.pyretStack.push(L[634]);
}
throw $e40594060;
}
var $ret40654066 = $Hcont_tail_arg35044071($z40614062,if_helper17654055);
++R.GAS;
return $ret40654066;
}
} else {
var cont_tail_arg17674075 = R.throwNonBooleanCondition(L[634],("if"),if_DASH_2244072);
if(--R.GAS > 0) {
$z40734074 = R.isFunction(if_helper17654055)?if_helper17654055.app(cont_tail_arg17674075):R.ffi.throwNonFunApp(L[634],if_helper17654055,[cont_tail_arg17674075]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper17654055)?if_helper17654055.app(cont_tail_arg17674075):R.ffi.throwNonFunApp(L[634],if_helper17654055,[cont_tail_arg17674075]);
},
"from":L[634]});
}
++R.GAS;
return $z40734074;
}
};
},{"length":3});
var anf_variant_member17914002 = R.makeMethod(function(self2234038) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[634],0,arguments);
}
var anf_arg17794036 = G(self2234038,"l",L[634]);
var $z40284029 = D;
var $f40344035 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg17794036):R.ffi.throwNonFunApp(L[634],torepr31,[anf_arg17794036]);
};
try {
if(--R.GAS > 0) {
$z40284029 = $f40344035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40344035,
"from":L[634]});
}
} catch($e40264027) {
if(R.isCont($e40264027)) {
var $ss40304031 = {"from":L[634],
"go":function(anf_arg17804037) {
return $Hanf_arg35144039(anf_arg17804037,self2234038,_plus26,torepr31);
}};
$e40264027.stack[R.EXN_STACKHEIGHT++] = $ss40304031;
}
if(R.isPyretException($e40264027)) {
$e40264027.pyretStack.push(L[634]);
}
throw $e40264027;
}
var $ret40324033 = $Hanf_arg35144039($z40284029,self2234038,_plus26,torepr31);
++R.GAS;
return $ret40324033;
};
},{"length":1});
var anf_variant_member17934003 = R.makeMethod(function(self4644025) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[645],0,arguments);
}
var ann_DASH_check_DASH_temp17924024 = ("a-field");
return ann_DASH_check_DASH_temp17924024;
};
},{"length":1});
var anf_variant_member18044004 = R.makeMethod(function(self4654022) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[644],0,arguments);
}
var anf_fun17954021 = G(PP337,"nest",L[643]);
var anf_fun17964018 = G(PP337,"str",L[642]);
var anf_arg17974019 = G(self4654022,"name",L[641]);
var $z40104011 = D;
var $f40164017 = function(_) {
return R.isFunction(anf_fun17964018)?anf_fun17964018.app(anf_arg17974019):R.ffi.throwNonFunApp(L[640],anf_fun17964018,[anf_arg17974019]);
};
try {
if(--R.GAS > 0) {
$z40104011 = $f40164017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40164017,
"from":L[640]});
}
} catch($e40084009) {
if(R.isCont($e40084009)) {
var $ss40124013 = {"from":L[640],
"go":function(anf_arg17984020) {
return $Hanf_arg35194023(anf_arg17984020,INDENT9187,anf_fun17954021,self4654022,str_DASH_colonspace100196,_plus26);
}};
$e40084009.stack[R.EXN_STACKHEIGHT++] = $ss40124013;
}
if(R.isPyretException($e40084009)) {
$e40084009.pyretStack.push(L[640]);
}
throw $e40084009;
}
var $ret40144015 = $Hanf_arg35194023($z40104011,INDENT9187,anf_fun17954021,self4654022,str_DASH_colonspace100196,_plus26);
++R.GAS;
return $ret40144015;
};
},{"length":1});
var anf_assign1805600 = (function() {
var $a_DASH_field_DASH_base39963997 = {"visit":anf_shared17633995,
"_match":anf_variant_member17774001,
"_torepr":anf_variant_member17914002,
"label":anf_variant_member17934003,
"tosource":anf_variant_member18044004};
var $a_DASH_field_DASH_brands39994000 = {"$brand-a-field3998":true};
$a_DASH_field_DASH_brands39994000[AFieldT128768._brand] = true
return R.makeObject({"AField":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[635],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AFieldT128768._brand));
}),
"is-a-field":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[634],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-field3998"));
}),
"a-field":R.makeFunction(function(l4614005,name4624006,value4634007) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[636],3,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,AVal8881],[l4614005,name4624006,value4634007],[L[637],L[638],L[639]],function() {
var dict = R.create($a_DASH_field_DASH_base39963997);
dict["l"] = l4614005
dict["name"] = name4624006
dict["value"] = value4634007
return R.makeBrandedObject(dict,$a_DASH_field_DASH_brands39994000);
});
})});
})();
AField24220599.$var = anf_assign1805600;
var anf_assign1806602 = G(AField24220599.$var,"AField",L[635]);
AField221601.$var = anf_assign1806602;
var anf_assign1807604 = G(AField24220599.$var,"AField",L[635]);
is_DASH_AField222603.$var = anf_assign1807604;
var anf_assign1808606 = G(AField24220599.$var,"is-a-field",L[634]);
is_DASH_a_DASH_field223605.$var = anf_assign1808606;
var anf_assign1809608 = G(AField24220599.$var,"a-field",L[634]);
a_DASH_field224607.$var = anf_assign1809608;
var anf_shared18173241 = R.makeMethod(function(self5043994) {
return function(visitor5053977) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[629],1,arguments);
}
var anf_fun18113976 = G(self5043994,"_match",L[633]);
var anf_arg18163978 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[630],0,arguments);
}
var anf_fun18133991 = G(self5043994,"label",L[632]);
var $z39833984 = D;
var $f39893990 = function(_) {
return R.isFunction(anf_fun18133991)?anf_fun18133991.app():R.ffi.throwNonFunApp(L[631],anf_fun18133991,[]);
};
try {
if(--R.GAS > 0) {
$z39833984 = $f39893990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39893990,
"from":L[631]});
}
} catch($e39813982) {
if(R.isCont($e39813982)) {
var $ss39853986 = {"from":L[631],
"go":function(anf_arg18143992) {
return $Hanf_arg35223993(anf_arg18143992,_plus26,raise30);
}};
$e39813982.stack[R.EXN_STACKHEIGHT++] = $ss39853986;
}
if(R.isPyretException($e39813982)) {
$e39813982.pyretStack.push(L[631]);
}
throw $e39813982;
}
var $ret39873988 = $Hanf_arg35223993($z39833984,_plus26,raise30);
++R.GAS;
return $ret39873988;
});
var $z39683969 = D;
var $f39743975 = function(_) {
return R.isFunction(anf_fun18113976)?anf_fun18113976.app(visitor5053977,anf_arg18163978):R.ffi.throwNonFunApp(L[629],anf_fun18113976,[visitor5053977,anf_arg18163978]);
};
try {
if(--R.GAS > 0) {
$z39683969 = $f39743975();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39743975,
"from":L[629]});
}
} catch($e39663967) {
if(R.isCont($e39663967)) {
var $ss39703971 = {"from":L[629],
"go":function(ann_DASH_check_DASH_temp18103979) {
return $Hann_DASH_check_DASH_temp35233980(ann_DASH_check_DASH_temp18103979);
}};
$e39663967.stack[R.EXN_STACKHEIGHT++] = $ss39703971;
}
if(R.isPyretException($e39663967)) {
$e39663967.pyretStack.push(L[629]);
}
throw $e39663967;
}
var $ret39723973 = $Hann_DASH_check_DASH_temp35233980($z39683969);
++R.GAS;
return $ret39723973;
};
},{"length":2});
var anf_variant_member18303247 = R.makeMethod(function(self2263944) {
return function(cases_DASH_funs2273945,else_DASH_clause2283956) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[536],2,arguments);
}
var if_DASH_2303959 = R.hasField(cases_DASH_funs2273945,("a-srcloc"));
var if_helper18193942 = R.makeFunction(function(if_helper_arg18203964) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[536],1,arguments);
}
var ann_DASH_check_DASH_temp18183965 = if_helper_arg18203964;
return ann_DASH_check_DASH_temp18183965;
});
var anf_if18233963 = R.isBoolean(if_DASH_2303959);
if(R.isPyretTrue(anf_if18233963)) {
if(R.isPyretTrue(if_DASH_2303959)) {
var call_DASH_a_DASH_srcloc2253938 = G(cases_DASH_funs2273945,"a-srcloc",L[536]);
var anf_arg18263939 = G(self2263944,"l",L[628]);
var anf_arg18273940 = G(self2263944,"loc",L[627]);
var $z39303931 = D;
var $f39363937 = function(_) {
return R.isFunction(call_DASH_a_DASH_srcloc2253938)?call_DASH_a_DASH_srcloc2253938.app(anf_arg18263939,anf_arg18273940):R.ffi.throwNonFunApp(L[536],call_DASH_a_DASH_srcloc2253938,[anf_arg18263939,anf_arg18273940]);
};
try {
if(--R.GAS > 0) {
$z39303931 = $f39363937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39363937,
"from":L[536]});
}
} catch($e39283929) {
if(R.isCont($e39283929)) {
var $ss39323933 = {"from":L[536],
"go":function(cont_tail_arg18283941) {
return $Hcont_tail_arg35243943(cont_tail_arg18283941,if_helper18193942);
}};
$e39283929.stack[R.EXN_STACKHEIGHT++] = $ss39323933;
}
if(R.isPyretException($e39283929)) {
$e39283929.pyretStack.push(L[536]);
}
throw $e39283929;
}
var $ret39343935 = $Hcont_tail_arg35243943($z39303931,if_helper18193942);
++R.GAS;
return $ret39343935;
} else {
var $z39483949 = D;
var $f39543955 = function(_) {
return R.isFunction(else_DASH_clause2283956)?else_DASH_clause2283956.app():R.ffi.throwNonFunApp(L[536],else_DASH_clause2283956,[]);
};
try {
if(--R.GAS > 0) {
$z39483949 = $f39543955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39543955,
"from":L[536]});
}
} catch($e39463947) {
if(R.isCont($e39463947)) {
var $ss39503951 = {"from":L[536],
"go":function(cont_tail_arg18243957) {
return $Hcont_tail_arg35253958(cont_tail_arg18243957,if_helper18193942);
}};
$e39463947.stack[R.EXN_STACKHEIGHT++] = $ss39503951;
}
if(R.isPyretException($e39463947)) {
$e39463947.pyretStack.push(L[536]);
}
throw $e39463947;
}
var $ret39523953 = $Hcont_tail_arg35253958($z39483949,if_helper18193942);
++R.GAS;
return $ret39523953;
}
} else {
var cont_tail_arg18213962 = R.throwNonBooleanCondition(L[536],("if"),if_DASH_2303959);
if(--R.GAS > 0) {
$z39603961 = R.isFunction(if_helper18193942)?if_helper18193942.app(cont_tail_arg18213962):R.ffi.throwNonFunApp(L[536],if_helper18193942,[cont_tail_arg18213962]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18193942)?if_helper18193942.app(cont_tail_arg18213962):R.ffi.throwNonFunApp(L[536],if_helper18193942,[cont_tail_arg18213962]);
},
"from":L[536]});
}
++R.GAS;
return $z39603961;
}
};
},{"length":3});
var anf_variant_member18403248 = R.makeMethod(function(self2293926) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[536],0,arguments);
}
var anf_arg18323924 = G(self2293926,"l",L[536]);
var $z39163917 = D;
var $f39223923 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg18323924):R.ffi.throwNonFunApp(L[536],torepr31,[anf_arg18323924]);
};
try {
if(--R.GAS > 0) {
$z39163917 = $f39223923();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39223923,
"from":L[536]});
}
} catch($e39143915) {
if(R.isCont($e39143915)) {
var $ss39183919 = {"from":L[536],
"go":function(anf_arg18333925) {
return $Hanf_arg35323927(anf_arg18333925,self2293926,_plus26,torepr31);
}};
$e39143915.stack[R.EXN_STACKHEIGHT++] = $ss39183919;
}
if(R.isPyretException($e39143915)) {
$e39143915.pyretStack.push(L[536]);
}
throw $e39143915;
}
var $ret39203921 = $Hanf_arg35323927($z39163917,self2293926,_plus26,torepr31);
++R.GAS;
return $ret39203921;
};
},{"length":1});
var anf_variant_member18423249 = R.makeMethod(function(self4703913) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[626],0,arguments);
}
var ann_DASH_check_DASH_temp18413912 = ("a-srcloc");
return ann_DASH_check_DASH_temp18413912;
};
},{"length":1});
var anf_variant_member18473250 = R.makeMethod(function(self4713911) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[625],0,arguments);
}
var anf_fun18443909 = G(PP337,"str",L[624]);
var anf_arg18453907 = G(self4713911,"loc",L[623]);
var $z38993900 = D;
var $f39053906 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg18453907):R.ffi.throwNonFunApp(L[622],torepr31,[anf_arg18453907]);
};
try {
if(--R.GAS > 0) {
$z38993900 = $f39053906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39053906,
"from":L[622]});
}
} catch($e38973898) {
if(R.isCont($e38973898)) {
var $ss39013902 = {"from":L[622],
"go":function(anf_arg18463908) {
return $Hanf_arg35343910(anf_arg18463908,anf_fun18443909);
}};
$e38973898.stack[R.EXN_STACKHEIGHT++] = $ss39013902;
}
if(R.isPyretException($e38973898)) {
$e38973898.pyretStack.push(L[622]);
}
throw $e38973898;
}
var $ret39033904 = $Hanf_arg35343910($z38993900,anf_fun18443909);
++R.GAS;
return $ret39033904;
};
},{"length":1});
var anf_variant_member18603258 = R.makeMethod(function(self2323875) {
return function(cases_DASH_funs2333876,else_DASH_clause2343887) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[535],2,arguments);
}
var if_DASH_2363890 = R.hasField(cases_DASH_funs2333876,("a-num"));
var if_helper18493873 = R.makeFunction(function(if_helper_arg18503895) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[535],1,arguments);
}
var ann_DASH_check_DASH_temp18483896 = if_helper_arg18503895;
return ann_DASH_check_DASH_temp18483896;
});
var anf_if18533894 = R.isBoolean(if_DASH_2363890);
if(R.isPyretTrue(anf_if18533894)) {
if(R.isPyretTrue(if_DASH_2363890)) {
var call_DASH_a_DASH_num2313869 = G(cases_DASH_funs2333876,"a-num",L[535]);
var anf_arg18563870 = G(self2323875,"l",L[621]);
var anf_arg18573871 = G(self2323875,"n",L[620]);
var $z38613862 = D;
var $f38673868 = function(_) {
return R.isFunction(call_DASH_a_DASH_num2313869)?call_DASH_a_DASH_num2313869.app(anf_arg18563870,anf_arg18573871):R.ffi.throwNonFunApp(L[535],call_DASH_a_DASH_num2313869,[anf_arg18563870,anf_arg18573871]);
};
try {
if(--R.GAS > 0) {
$z38613862 = $f38673868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38673868,
"from":L[535]});
}
} catch($e38593860) {
if(R.isCont($e38593860)) {
var $ss38633864 = {"from":L[535],
"go":function(cont_tail_arg18583872) {
return $Hcont_tail_arg35353874(cont_tail_arg18583872,if_helper18493873);
}};
$e38593860.stack[R.EXN_STACKHEIGHT++] = $ss38633864;
}
if(R.isPyretException($e38593860)) {
$e38593860.pyretStack.push(L[535]);
}
throw $e38593860;
}
var $ret38653866 = $Hcont_tail_arg35353874($z38613862,if_helper18493873);
++R.GAS;
return $ret38653866;
} else {
var $z38793880 = D;
var $f38853886 = function(_) {
return R.isFunction(else_DASH_clause2343887)?else_DASH_clause2343887.app():R.ffi.throwNonFunApp(L[535],else_DASH_clause2343887,[]);
};
try {
if(--R.GAS > 0) {
$z38793880 = $f38853886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38853886,
"from":L[535]});
}
} catch($e38773878) {
if(R.isCont($e38773878)) {
var $ss38813882 = {"from":L[535],
"go":function(cont_tail_arg18543888) {
return $Hcont_tail_arg35363889(cont_tail_arg18543888,if_helper18493873);
}};
$e38773878.stack[R.EXN_STACKHEIGHT++] = $ss38813882;
}
if(R.isPyretException($e38773878)) {
$e38773878.pyretStack.push(L[535]);
}
throw $e38773878;
}
var $ret38833884 = $Hcont_tail_arg35363889($z38793880,if_helper18493873);
++R.GAS;
return $ret38833884;
}
} else {
var cont_tail_arg18513893 = R.throwNonBooleanCondition(L[535],("if"),if_DASH_2363890);
if(--R.GAS > 0) {
$z38913892 = R.isFunction(if_helper18493873)?if_helper18493873.app(cont_tail_arg18513893):R.ffi.throwNonFunApp(L[535],if_helper18493873,[cont_tail_arg18513893]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18493873)?if_helper18493873.app(cont_tail_arg18513893):R.ffi.throwNonFunApp(L[535],if_helper18493873,[cont_tail_arg18513893]);
},
"from":L[535]});
}
++R.GAS;
return $z38913892;
}
};
},{"length":3});
var anf_variant_member18703259 = R.makeMethod(function(self2353857) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[535],0,arguments);
}
var anf_arg18623855 = G(self2353857,"l",L[535]);
var $z38473848 = D;
var $f38533854 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg18623855):R.ffi.throwNonFunApp(L[535],torepr31,[anf_arg18623855]);
};
try {
if(--R.GAS > 0) {
$z38473848 = $f38533854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38533854,
"from":L[535]});
}
} catch($e38453846) {
if(R.isCont($e38453846)) {
var $ss38493850 = {"from":L[535],
"go":function(anf_arg18633856) {
return $Hanf_arg35433858(anf_arg18633856,self2353857,_plus26,torepr31);
}};
$e38453846.stack[R.EXN_STACKHEIGHT++] = $ss38493850;
}
if(R.isPyretException($e38453846)) {
$e38453846.pyretStack.push(L[535]);
}
throw $e38453846;
}
var $ret38513852 = $Hanf_arg35433858($z38473848,self2353857,_plus26,torepr31);
++R.GAS;
return $ret38513852;
};
},{"length":1});
var anf_variant_member18723260 = R.makeMethod(function(self4743844) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[619],0,arguments);
}
var ann_DASH_check_DASH_temp18713843 = ("a-num");
return ann_DASH_check_DASH_temp18713843;
};
},{"length":1});
var anf_variant_member18763261 = R.makeMethod(function(self4753842) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[616],0,arguments);
}
var anf_fun18743838 = G(PP337,"number",L[618]);
var anf_arg18753839 = G(self4753842,"n",L[617]);
var $z38303831 = D;
var $f38363837 = function(_) {
return R.isFunction(anf_fun18743838)?anf_fun18743838.app(anf_arg18753839):R.ffi.throwNonFunApp(L[616],anf_fun18743838,[anf_arg18753839]);
};
try {
if(--R.GAS > 0) {
$z38303831 = $f38363837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38363837,
"from":L[616]});
}
} catch($e38283829) {
if(R.isCont($e38283829)) {
var $ss38323833 = {"from":L[616],
"go":function(ann_DASH_check_DASH_temp18733840) {
return $Hann_DASH_check_DASH_temp35443841(ann_DASH_check_DASH_temp18733840);
}};
$e38283829.stack[R.EXN_STACKHEIGHT++] = $ss38323833;
}
if(R.isPyretException($e38283829)) {
$e38283829.pyretStack.push(L[616]);
}
throw $e38283829;
}
var $ret38343835 = $Hann_DASH_check_DASH_temp35443841($z38303831);
++R.GAS;
return $ret38343835;
};
},{"length":1});
var anf_variant_member18893269 = R.makeMethod(function(self2383806) {
return function(cases_DASH_funs2393807,else_DASH_clause2403818) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[534],2,arguments);
}
var if_DASH_2423821 = R.hasField(cases_DASH_funs2393807,("a-str"));
var if_helper18783804 = R.makeFunction(function(if_helper_arg18793826) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[534],1,arguments);
}
var ann_DASH_check_DASH_temp18773827 = if_helper_arg18793826;
return ann_DASH_check_DASH_temp18773827;
});
var anf_if18823825 = R.isBoolean(if_DASH_2423821);
if(R.isPyretTrue(anf_if18823825)) {
if(R.isPyretTrue(if_DASH_2423821)) {
var call_DASH_a_DASH_str2373800 = G(cases_DASH_funs2393807,"a-str",L[534]);
var anf_arg18853801 = G(self2383806,"l",L[615]);
var anf_arg18863802 = G(self2383806,"s",L[614]);
var $z37923793 = D;
var $f37983799 = function(_) {
return R.isFunction(call_DASH_a_DASH_str2373800)?call_DASH_a_DASH_str2373800.app(anf_arg18853801,anf_arg18863802):R.ffi.throwNonFunApp(L[534],call_DASH_a_DASH_str2373800,[anf_arg18853801,anf_arg18863802]);
};
try {
if(--R.GAS > 0) {
$z37923793 = $f37983799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37983799,
"from":L[534]});
}
} catch($e37903791) {
if(R.isCont($e37903791)) {
var $ss37943795 = {"from":L[534],
"go":function(cont_tail_arg18873803) {
return $Hcont_tail_arg35453805(cont_tail_arg18873803,if_helper18783804);
}};
$e37903791.stack[R.EXN_STACKHEIGHT++] = $ss37943795;
}
if(R.isPyretException($e37903791)) {
$e37903791.pyretStack.push(L[534]);
}
throw $e37903791;
}
var $ret37963797 = $Hcont_tail_arg35453805($z37923793,if_helper18783804);
++R.GAS;
return $ret37963797;
} else {
var $z38103811 = D;
var $f38163817 = function(_) {
return R.isFunction(else_DASH_clause2403818)?else_DASH_clause2403818.app():R.ffi.throwNonFunApp(L[534],else_DASH_clause2403818,[]);
};
try {
if(--R.GAS > 0) {
$z38103811 = $f38163817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38163817,
"from":L[534]});
}
} catch($e38083809) {
if(R.isCont($e38083809)) {
var $ss38123813 = {"from":L[534],
"go":function(cont_tail_arg18833819) {
return $Hcont_tail_arg35463820(cont_tail_arg18833819,if_helper18783804);
}};
$e38083809.stack[R.EXN_STACKHEIGHT++] = $ss38123813;
}
if(R.isPyretException($e38083809)) {
$e38083809.pyretStack.push(L[534]);
}
throw $e38083809;
}
var $ret38143815 = $Hcont_tail_arg35463820($z38103811,if_helper18783804);
++R.GAS;
return $ret38143815;
}
} else {
var cont_tail_arg18803824 = R.throwNonBooleanCondition(L[534],("if"),if_DASH_2423821);
if(--R.GAS > 0) {
$z38223823 = R.isFunction(if_helper18783804)?if_helper18783804.app(cont_tail_arg18803824):R.ffi.throwNonFunApp(L[534],if_helper18783804,[cont_tail_arg18803824]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18783804)?if_helper18783804.app(cont_tail_arg18803824):R.ffi.throwNonFunApp(L[534],if_helper18783804,[cont_tail_arg18803824]);
},
"from":L[534]});
}
++R.GAS;
return $z38223823;
}
};
},{"length":3});
var anf_variant_member18993270 = R.makeMethod(function(self2413788) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[534],0,arguments);
}
var anf_arg18913786 = G(self2413788,"l",L[534]);
var $z37783779 = D;
var $f37843785 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg18913786):R.ffi.throwNonFunApp(L[534],torepr31,[anf_arg18913786]);
};
try {
if(--R.GAS > 0) {
$z37783779 = $f37843785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37843785,
"from":L[534]});
}
} catch($e37763777) {
if(R.isCont($e37763777)) {
var $ss37803781 = {"from":L[534],
"go":function(anf_arg18923787) {
return $Hanf_arg35533789(anf_arg18923787,self2413788,_plus26,torepr31);
}};
$e37763777.stack[R.EXN_STACKHEIGHT++] = $ss37803781;
}
if(R.isPyretException($e37763777)) {
$e37763777.pyretStack.push(L[534]);
}
throw $e37763777;
}
var $ret37823783 = $Hanf_arg35533789($z37783779,self2413788,_plus26,torepr31);
++R.GAS;
return $ret37823783;
};
},{"length":1});
var anf_variant_member19013271 = R.makeMethod(function(self4783775) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[613],0,arguments);
}
var ann_DASH_check_DASH_temp19003774 = ("a-str");
return ann_DASH_check_DASH_temp19003774;
};
},{"length":1});
var anf_variant_member19073272 = R.makeMethod(function(self4793773) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[612],0,arguments);
}
var anf_fun19033771 = G(PP337,"squote",L[611]);
var anf_fun19043768 = G(PP337,"str",L[610]);
var anf_arg19053769 = G(self4793773,"s",L[609]);
var $z37603761 = D;
var $f37663767 = function(_) {
return R.isFunction(anf_fun19043768)?anf_fun19043768.app(anf_arg19053769):R.ffi.throwNonFunApp(L[608],anf_fun19043768,[anf_arg19053769]);
};
try {
if(--R.GAS > 0) {
$z37603761 = $f37663767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37663767,
"from":L[608]});
}
} catch($e37583759) {
if(R.isCont($e37583759)) {
var $ss37623763 = {"from":L[608],
"go":function(anf_arg19063770) {
return $Hanf_arg35553772(anf_arg19063770,anf_fun19033771);
}};
$e37583759.stack[R.EXN_STACKHEIGHT++] = $ss37623763;
}
if(R.isPyretException($e37583759)) {
$e37583759.pyretStack.push(L[608]);
}
throw $e37583759;
}
var $ret37643765 = $Hanf_arg35553772($z37603761,anf_fun19033771);
++R.GAS;
return $ret37643765;
};
},{"length":1});
var anf_variant_member19203280 = R.makeMethod(function(self2443736) {
return function(cases_DASH_funs2453737,else_DASH_clause2463748) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[533],2,arguments);
}
var if_DASH_2483751 = R.hasField(cases_DASH_funs2453737,("a-bool"));
var if_helper19093734 = R.makeFunction(function(if_helper_arg19103756) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[533],1,arguments);
}
var ann_DASH_check_DASH_temp19083757 = if_helper_arg19103756;
return ann_DASH_check_DASH_temp19083757;
});
var anf_if19133755 = R.isBoolean(if_DASH_2483751);
if(R.isPyretTrue(anf_if19133755)) {
if(R.isPyretTrue(if_DASH_2483751)) {
var call_DASH_a_DASH_bool2433730 = G(cases_DASH_funs2453737,"a-bool",L[533]);
var anf_arg19163731 = G(self2443736,"l",L[607]);
var anf_arg19173732 = G(self2443736,"b",L[606]);
var $z37223723 = D;
var $f37283729 = function(_) {
return R.isFunction(call_DASH_a_DASH_bool2433730)?call_DASH_a_DASH_bool2433730.app(anf_arg19163731,anf_arg19173732):R.ffi.throwNonFunApp(L[533],call_DASH_a_DASH_bool2433730,[anf_arg19163731,anf_arg19173732]);
};
try {
if(--R.GAS > 0) {
$z37223723 = $f37283729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37283729,
"from":L[533]});
}
} catch($e37203721) {
if(R.isCont($e37203721)) {
var $ss37243725 = {"from":L[533],
"go":function(cont_tail_arg19183733) {
return $Hcont_tail_arg35563735(cont_tail_arg19183733,if_helper19093734);
}};
$e37203721.stack[R.EXN_STACKHEIGHT++] = $ss37243725;
}
if(R.isPyretException($e37203721)) {
$e37203721.pyretStack.push(L[533]);
}
throw $e37203721;
}
var $ret37263727 = $Hcont_tail_arg35563735($z37223723,if_helper19093734);
++R.GAS;
return $ret37263727;
} else {
var $z37403741 = D;
var $f37463747 = function(_) {
return R.isFunction(else_DASH_clause2463748)?else_DASH_clause2463748.app():R.ffi.throwNonFunApp(L[533],else_DASH_clause2463748,[]);
};
try {
if(--R.GAS > 0) {
$z37403741 = $f37463747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37463747,
"from":L[533]});
}
} catch($e37383739) {
if(R.isCont($e37383739)) {
var $ss37423743 = {"from":L[533],
"go":function(cont_tail_arg19143749) {
return $Hcont_tail_arg35573750(cont_tail_arg19143749,if_helper19093734);
}};
$e37383739.stack[R.EXN_STACKHEIGHT++] = $ss37423743;
}
if(R.isPyretException($e37383739)) {
$e37383739.pyretStack.push(L[533]);
}
throw $e37383739;
}
var $ret37443745 = $Hcont_tail_arg35573750($z37403741,if_helper19093734);
++R.GAS;
return $ret37443745;
}
} else {
var cont_tail_arg19113754 = R.throwNonBooleanCondition(L[533],("if"),if_DASH_2483751);
if(--R.GAS > 0) {
$z37523753 = R.isFunction(if_helper19093734)?if_helper19093734.app(cont_tail_arg19113754):R.ffi.throwNonFunApp(L[533],if_helper19093734,[cont_tail_arg19113754]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19093734)?if_helper19093734.app(cont_tail_arg19113754):R.ffi.throwNonFunApp(L[533],if_helper19093734,[cont_tail_arg19113754]);
},
"from":L[533]});
}
++R.GAS;
return $z37523753;
}
};
},{"length":3});
var anf_variant_member19303281 = R.makeMethod(function(self2473718) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[533],0,arguments);
}
var anf_arg19223716 = G(self2473718,"l",L[533]);
var $z37083709 = D;
var $f37143715 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg19223716):R.ffi.throwNonFunApp(L[533],torepr31,[anf_arg19223716]);
};
try {
if(--R.GAS > 0) {
$z37083709 = $f37143715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37143715,
"from":L[533]});
}
} catch($e37063707) {
if(R.isCont($e37063707)) {
var $ss37103711 = {"from":L[533],
"go":function(anf_arg19233717) {
return $Hanf_arg35643719(anf_arg19233717,self2473718,_plus26,torepr31);
}};
$e37063707.stack[R.EXN_STACKHEIGHT++] = $ss37103711;
}
if(R.isPyretException($e37063707)) {
$e37063707.pyretStack.push(L[533]);
}
throw $e37063707;
}
var $ret37123713 = $Hanf_arg35643719($z37083709,self2473718,_plus26,torepr31);
++R.GAS;
return $ret37123713;
};
},{"length":1});
var anf_variant_member19323282 = R.makeMethod(function(self4823705) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[605],0,arguments);
}
var ann_DASH_check_DASH_temp19313704 = ("a-bool");
return ann_DASH_check_DASH_temp19313704;
};
},{"length":1});
var anf_variant_member19373283 = R.makeMethod(function(self4833703) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[604],0,arguments);
}
var anf_fun19343701 = G(PP337,"str",L[603]);
var anf_arg19353699 = G(self4833703,"b",L[602]);
var $z36913692 = D;
var $f36973698 = function(_) {
return R.isFunction(tostring32)?tostring32.app(anf_arg19353699):R.ffi.throwNonFunApp(L[601],tostring32,[anf_arg19353699]);
};
try {
if(--R.GAS > 0) {
$z36913692 = $f36973698();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36973698,
"from":L[601]});
}
} catch($e36893690) {
if(R.isCont($e36893690)) {
var $ss36933694 = {"from":L[601],
"go":function(anf_arg19363700) {
return $Hanf_arg35663702(anf_arg19363700,anf_fun19343701);
}};
$e36893690.stack[R.EXN_STACKHEIGHT++] = $ss36933694;
}
if(R.isPyretException($e36893690)) {
$e36893690.pyretStack.push(L[601]);
}
throw $e36893690;
}
var $ret36953696 = $Hanf_arg35663702($z36913692,anf_fun19343701);
++R.GAS;
return $ret36953696;
};
},{"length":1});
var anf_variant_member19503291 = R.makeMethod(function(self2503667) {
return function(cases_DASH_funs2513668,else_DASH_clause2523679) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[532],2,arguments);
}
var if_DASH_2543682 = R.hasField(cases_DASH_funs2513668,("a-array"));
var if_helper19393665 = R.makeFunction(function(if_helper_arg19403687) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[532],1,arguments);
}
var ann_DASH_check_DASH_temp19383688 = if_helper_arg19403687;
return ann_DASH_check_DASH_temp19383688;
});
var anf_if19433686 = R.isBoolean(if_DASH_2543682);
if(R.isPyretTrue(anf_if19433686)) {
if(R.isPyretTrue(if_DASH_2543682)) {
var call_DASH_a_DASH_array2493661 = G(cases_DASH_funs2513668,"a-array",L[532]);
var anf_arg19463662 = G(self2503667,"l",L[600]);
var anf_arg19473663 = G(self2503667,"values",L[599]);
var $z36533654 = D;
var $f36593660 = function(_) {
return R.isFunction(call_DASH_a_DASH_array2493661)?call_DASH_a_DASH_array2493661.app(anf_arg19463662,anf_arg19473663):R.ffi.throwNonFunApp(L[532],call_DASH_a_DASH_array2493661,[anf_arg19463662,anf_arg19473663]);
};
try {
if(--R.GAS > 0) {
$z36533654 = $f36593660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36593660,
"from":L[532]});
}
} catch($e36513652) {
if(R.isCont($e36513652)) {
var $ss36553656 = {"from":L[532],
"go":function(cont_tail_arg19483664) {
return $Hcont_tail_arg35673666(cont_tail_arg19483664,if_helper19393665);
}};
$e36513652.stack[R.EXN_STACKHEIGHT++] = $ss36553656;
}
if(R.isPyretException($e36513652)) {
$e36513652.pyretStack.push(L[532]);
}
throw $e36513652;
}
var $ret36573658 = $Hcont_tail_arg35673666($z36533654,if_helper19393665);
++R.GAS;
return $ret36573658;
} else {
var $z36713672 = D;
var $f36773678 = function(_) {
return R.isFunction(else_DASH_clause2523679)?else_DASH_clause2523679.app():R.ffi.throwNonFunApp(L[532],else_DASH_clause2523679,[]);
};
try {
if(--R.GAS > 0) {
$z36713672 = $f36773678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36773678,
"from":L[532]});
}
} catch($e36693670) {
if(R.isCont($e36693670)) {
var $ss36733674 = {"from":L[532],
"go":function(cont_tail_arg19443680) {
return $Hcont_tail_arg35683681(cont_tail_arg19443680,if_helper19393665);
}};
$e36693670.stack[R.EXN_STACKHEIGHT++] = $ss36733674;
}
if(R.isPyretException($e36693670)) {
$e36693670.pyretStack.push(L[532]);
}
throw $e36693670;
}
var $ret36753676 = $Hcont_tail_arg35683681($z36713672,if_helper19393665);
++R.GAS;
return $ret36753676;
}
} else {
var cont_tail_arg19413685 = R.throwNonBooleanCondition(L[532],("if"),if_DASH_2543682);
if(--R.GAS > 0) {
$z36833684 = R.isFunction(if_helper19393665)?if_helper19393665.app(cont_tail_arg19413685):R.ffi.throwNonFunApp(L[532],if_helper19393665,[cont_tail_arg19413685]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19393665)?if_helper19393665.app(cont_tail_arg19413685):R.ffi.throwNonFunApp(L[532],if_helper19393665,[cont_tail_arg19413685]);
},
"from":L[532]});
}
++R.GAS;
return $z36833684;
}
};
},{"length":3});
var anf_variant_member19603292 = R.makeMethod(function(self2533649) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[532],0,arguments);
}
var anf_arg19523647 = G(self2533649,"l",L[532]);
var $z36393640 = D;
var $f36453646 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg19523647):R.ffi.throwNonFunApp(L[532],torepr31,[anf_arg19523647]);
};
try {
if(--R.GAS > 0) {
$z36393640 = $f36453646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36453646,
"from":L[532]});
}
} catch($e36373638) {
if(R.isCont($e36373638)) {
var $ss36413642 = {"from":L[532],
"go":function(anf_arg19533648) {
return $Hanf_arg35753650(anf_arg19533648,self2533649,_plus26,torepr31);
}};
$e36373638.stack[R.EXN_STACKHEIGHT++] = $ss36413642;
}
if(R.isPyretException($e36373638)) {
$e36373638.pyretStack.push(L[532]);
}
throw $e36373638;
}
var $ret36433644 = $Hanf_arg35753650($z36393640,self2533649,_plus26,torepr31);
++R.GAS;
return $ret36433644;
};
},{"length":1});
var anf_variant_member19623293 = R.makeMethod(function(self4863636) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[598],0,arguments);
}
var ann_DASH_check_DASH_temp19613635 = ("a-array");
return ann_DASH_check_DASH_temp19613635;
};
},{"length":1});
var anf_variant_member19773294 = R.makeMethod(function(self4873633) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[597],0,arguments);
}
var anf_fun19643632 = G(PP337,"surround-separate",L[596]);
var anf_fun19653630 = G(PP337,"str",L[595]);
var $z36223623 = D;
var $f36283629 = function(_) {
return R.isFunction(anf_fun19653630)?anf_fun19653630.app(("[raw-array: ]")):R.ffi.throwNonFunApp(L[594],anf_fun19653630,[("[raw-array: ]")]);
};
try {
if(--R.GAS > 0) {
$z36223623 = $f36283629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36283629,
"from":L[594]});
}
} catch($e36203621) {
if(R.isCont($e36203621)) {
var $ss36243625 = {"from":L[594],
"go":function(anf_arg19663631) {
return $Hanf_arg35803634(anf_arg19663631,INDENT9187,PP337,anf_fun19643632,self4873633);
}};
$e36203621.stack[R.EXN_STACKHEIGHT++] = $ss36243625;
}
if(R.isPyretException($e36203621)) {
$e36203621.pyretStack.push(L[594]);
}
throw $e36203621;
}
var $ret36263627 = $Hanf_arg35803634($z36223623,INDENT9187,PP337,anf_fun19643632,self4873633);
++R.GAS;
return $ret36263627;
};
},{"length":1});
var anf_variant_member19893302 = R.makeMethod(function(self2573598) {
return function(cases_DASH_funs2583599,else_DASH_clause2593610) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[531],2,arguments);
}
var if_DASH_2613613 = R.hasField(cases_DASH_funs2583599,("a-undefined"));
var if_helper19793596 = R.makeFunction(function(if_helper_arg19803618) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[531],1,arguments);
}
var ann_DASH_check_DASH_temp19783619 = if_helper_arg19803618;
return ann_DASH_check_DASH_temp19783619;
});
var anf_if19833617 = R.isBoolean(if_DASH_2613613);
if(R.isPyretTrue(anf_if19833617)) {
if(R.isPyretTrue(if_DASH_2613613)) {
var call_DASH_a_DASH_undefined2563593 = G(cases_DASH_funs2583599,"a-undefined",L[531]);
var anf_arg19863594 = G(self2573598,"l",L[593]);
var $z35853586 = D;
var $f35913592 = function(_) {
return R.isFunction(call_DASH_a_DASH_undefined2563593)?call_DASH_a_DASH_undefined2563593.app(anf_arg19863594):R.ffi.throwNonFunApp(L[531],call_DASH_a_DASH_undefined2563593,[anf_arg19863594]);
};
try {
if(--R.GAS > 0) {
$z35853586 = $f35913592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35913592,
"from":L[531]});
}
} catch($e35833584) {
if(R.isCont($e35833584)) {
var $ss35873588 = {"from":L[531],
"go":function(cont_tail_arg19873595) {
return $Hcont_tail_arg35813597(cont_tail_arg19873595,if_helper19793596);
}};
$e35833584.stack[R.EXN_STACKHEIGHT++] = $ss35873588;
}
if(R.isPyretException($e35833584)) {
$e35833584.pyretStack.push(L[531]);
}
throw $e35833584;
}
var $ret35893590 = $Hcont_tail_arg35813597($z35853586,if_helper19793596);
++R.GAS;
return $ret35893590;
} else {
var $z36023603 = D;
var $f36083609 = function(_) {
return R.isFunction(else_DASH_clause2593610)?else_DASH_clause2593610.app():R.ffi.throwNonFunApp(L[531],else_DASH_clause2593610,[]);
};
try {
if(--R.GAS > 0) {
$z36023603 = $f36083609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36083609,
"from":L[531]});
}
} catch($e36003601) {
if(R.isCont($e36003601)) {
var $ss36043605 = {"from":L[531],
"go":function(cont_tail_arg19843611) {
return $Hcont_tail_arg35823612(cont_tail_arg19843611,if_helper19793596);
}};
$e36003601.stack[R.EXN_STACKHEIGHT++] = $ss36043605;
}
if(R.isPyretException($e36003601)) {
$e36003601.pyretStack.push(L[531]);
}
throw $e36003601;
}
var $ret36063607 = $Hcont_tail_arg35823612($z36023603,if_helper19793596);
++R.GAS;
return $ret36063607;
}
} else {
var cont_tail_arg19813616 = R.throwNonBooleanCondition(L[531],("if"),if_DASH_2613613);
if(--R.GAS > 0) {
$z36143615 = R.isFunction(if_helper19793596)?if_helper19793596.app(cont_tail_arg19813616):R.ffi.throwNonFunApp(L[531],if_helper19793596,[cont_tail_arg19813616]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19793596)?if_helper19793596.app(cont_tail_arg19813616):R.ffi.throwNonFunApp(L[531],if_helper19793596,[cont_tail_arg19813616]);
},
"from":L[531]});
}
++R.GAS;
return $z36143615;
}
};
},{"length":3});
var anf_variant_member19953303 = R.makeMethod(function(self2603582) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[531],0,arguments);
}
var anf_arg19913579 = G(self2603582,"l",L[531]);
var $z35713572 = D;
var $f35773578 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg19913579):R.ffi.throwNonFunApp(L[531],torepr31,[anf_arg19913579]);
};
try {
if(--R.GAS > 0) {
$z35713572 = $f35773578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35773578,
"from":L[531]});
}
} catch($e35693570) {
if(R.isCont($e35693570)) {
var $ss35733574 = {"from":L[531],
"go":function(anf_arg19923580) {
return $Hanf_arg35863581(anf_arg19923580,_plus26);
}};
$e35693570.stack[R.EXN_STACKHEIGHT++] = $ss35733574;
}
if(R.isPyretException($e35693570)) {
$e35693570.pyretStack.push(L[531]);
}
throw $e35693570;
}
var $ret35753576 = $Hanf_arg35863581($z35713572,_plus26);
++R.GAS;
return $ret35753576;
};
},{"length":1});
var anf_variant_member19973304 = R.makeMethod(function(self4893568) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[592],0,arguments);
}
var ann_DASH_check_DASH_temp19963567 = ("a-undefined");
return ann_DASH_check_DASH_temp19963567;
};
},{"length":1});
var anf_variant_member20003305 = R.makeMethod(function(self4903566) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[590],0,arguments);
}
var anf_fun19993563 = G(PP337,"str",L[591]);
var $z35553556 = D;
var $f35613562 = function(_) {
return R.isFunction(anf_fun19993563)?anf_fun19993563.app(("UNDEFINED")):R.ffi.throwNonFunApp(L[590],anf_fun19993563,[("UNDEFINED")]);
};
try {
if(--R.GAS > 0) {
$z35553556 = $f35613562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35613562,
"from":L[590]});
}
} catch($e35533554) {
if(R.isCont($e35533554)) {
var $ss35573558 = {"from":L[590],
"go":function(ann_DASH_check_DASH_temp19983564) {
return $Hann_DASH_check_DASH_temp35873565(ann_DASH_check_DASH_temp19983564);
}};
$e35533554.stack[R.EXN_STACKHEIGHT++] = $ss35573558;
}
if(R.isPyretException($e35533554)) {
$e35533554.pyretStack.push(L[590]);
}
throw $e35533554;
}
var $ret35593560 = $Hann_DASH_check_DASH_temp35873565($z35553556);
++R.GAS;
return $ret35593560;
};
},{"length":1});
var anf_variant_member20133312 = R.makeMethod(function(self2633531) {
return function(cases_DASH_funs2643532,else_DASH_clause2653543) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[530],2,arguments);
}
var if_DASH_2673546 = R.hasField(cases_DASH_funs2643532,("a-id"));
var if_helper20023529 = R.makeFunction(function(if_helper_arg20033551) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[530],1,arguments);
}
var ann_DASH_check_DASH_temp20013552 = if_helper_arg20033551;
return ann_DASH_check_DASH_temp20013552;
});
var anf_if20063550 = R.isBoolean(if_DASH_2673546);
if(R.isPyretTrue(anf_if20063550)) {
if(R.isPyretTrue(if_DASH_2673546)) {
var call_DASH_a_DASH_id2623525 = G(cases_DASH_funs2643532,"a-id",L[530]);
var anf_arg20093526 = G(self2633531,"l",L[589]);
var anf_arg20103527 = G(self2633531,"id",L[588]);
var $z35173518 = D;
var $f35233524 = function(_) {
return R.isFunction(call_DASH_a_DASH_id2623525)?call_DASH_a_DASH_id2623525.app(anf_arg20093526,anf_arg20103527):R.ffi.throwNonFunApp(L[530],call_DASH_a_DASH_id2623525,[anf_arg20093526,anf_arg20103527]);
};
try {
if(--R.GAS > 0) {
$z35173518 = $f35233524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35233524,
"from":L[530]});
}
} catch($e35153516) {
if(R.isCont($e35153516)) {
var $ss35193520 = {"from":L[530],
"go":function(cont_tail_arg20113528) {
return $Hcont_tail_arg35883530(cont_tail_arg20113528,if_helper20023529);
}};
$e35153516.stack[R.EXN_STACKHEIGHT++] = $ss35193520;
}
if(R.isPyretException($e35153516)) {
$e35153516.pyretStack.push(L[530]);
}
throw $e35153516;
}
var $ret35213522 = $Hcont_tail_arg35883530($z35173518,if_helper20023529);
++R.GAS;
return $ret35213522;
} else {
var $z35353536 = D;
var $f35413542 = function(_) {
return R.isFunction(else_DASH_clause2653543)?else_DASH_clause2653543.app():R.ffi.throwNonFunApp(L[530],else_DASH_clause2653543,[]);
};
try {
if(--R.GAS > 0) {
$z35353536 = $f35413542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35413542,
"from":L[530]});
}
} catch($e35333534) {
if(R.isCont($e35333534)) {
var $ss35373538 = {"from":L[530],
"go":function(cont_tail_arg20073544) {
return $Hcont_tail_arg35893545(cont_tail_arg20073544,if_helper20023529);
}};
$e35333534.stack[R.EXN_STACKHEIGHT++] = $ss35373538;
}
if(R.isPyretException($e35333534)) {
$e35333534.pyretStack.push(L[530]);
}
throw $e35333534;
}
var $ret35393540 = $Hcont_tail_arg35893545($z35353536,if_helper20023529);
++R.GAS;
return $ret35393540;
}
} else {
var cont_tail_arg20043549 = R.throwNonBooleanCondition(L[530],("if"),if_DASH_2673546);
if(--R.GAS > 0) {
$z35473548 = R.isFunction(if_helper20023529)?if_helper20023529.app(cont_tail_arg20043549):R.ffi.throwNonFunApp(L[530],if_helper20023529,[cont_tail_arg20043549]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20023529)?if_helper20023529.app(cont_tail_arg20043549):R.ffi.throwNonFunApp(L[530],if_helper20023529,[cont_tail_arg20043549]);
},
"from":L[530]});
}
++R.GAS;
return $z35473548;
}
};
},{"length":3});
var anf_variant_member20233313 = R.makeMethod(function(self2663513) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[530],0,arguments);
}
var anf_arg20153511 = G(self2663513,"l",L[530]);
var $z35033504 = D;
var $f35093510 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg20153511):R.ffi.throwNonFunApp(L[530],torepr31,[anf_arg20153511]);
};
try {
if(--R.GAS > 0) {
$z35033504 = $f35093510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35093510,
"from":L[530]});
}
} catch($e35013502) {
if(R.isCont($e35013502)) {
var $ss35053506 = {"from":L[530],
"go":function(anf_arg20163512) {
return $Hanf_arg35963514(anf_arg20163512,self2663513,_plus26,torepr31);
}};
$e35013502.stack[R.EXN_STACKHEIGHT++] = $ss35053506;
}
if(R.isPyretException($e35013502)) {
$e35013502.pyretStack.push(L[530]);
}
throw $e35013502;
}
var $ret35073508 = $Hanf_arg35963514($z35033504,self2663513,_plus26,torepr31);
++R.GAS;
return $ret35073508;
};
},{"length":1});
var anf_variant_member20253314 = R.makeMethod(function(self4933500) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[587],0,arguments);
}
var ann_DASH_check_DASH_temp20243499 = ("a-id");
return ann_DASH_check_DASH_temp20243499;
};
},{"length":1});
var anf_variant_member20313315 = R.makeMethod(function(self4943498) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[586],0,arguments);
}
var anf_fun20273495 = G(PP337,"str",L[585]);
var anf_bracket20283497 = G(self4943498,"id",L[584]);
var anf_fun20293493 = G(anf_bracket20283497,"tostring",L[583]);
var $z34853486 = D;
var $f34913492 = function(_) {
return R.isFunction(anf_fun20293493)?anf_fun20293493.app():R.ffi.throwNonFunApp(L[582],anf_fun20293493,[]);
};
try {
if(--R.GAS > 0) {
$z34853486 = $f34913492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34913492,
"from":L[582]});
}
} catch($e34833484) {
if(R.isCont($e34833484)) {
var $ss34873488 = {"from":L[582],
"go":function(anf_arg20303494) {
return $Hanf_arg35983496(anf_arg20303494,anf_fun20273495);
}};
$e34833484.stack[R.EXN_STACKHEIGHT++] = $ss34873488;
}
if(R.isPyretException($e34833484)) {
$e34833484.pyretStack.push(L[582]);
}
throw $e34833484;
}
var $ret34893490 = $Hanf_arg35983496($z34853486,anf_fun20273495);
++R.GAS;
return $ret34893490;
};
},{"length":1});
var anf_variant_member20443323 = R.makeMethod(function(self2693461) {
return function(cases_DASH_funs2703462,else_DASH_clause2713473) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[529],2,arguments);
}
var if_DASH_2733476 = R.hasField(cases_DASH_funs2703462,("a-id-var"));
var if_helper20333459 = R.makeFunction(function(if_helper_arg20343481) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[529],1,arguments);
}
var ann_DASH_check_DASH_temp20323482 = if_helper_arg20343481;
return ann_DASH_check_DASH_temp20323482;
});
var anf_if20373480 = R.isBoolean(if_DASH_2733476);
if(R.isPyretTrue(anf_if20373480)) {
if(R.isPyretTrue(if_DASH_2733476)) {
var call_DASH_a_DASH_id_DASH_var2683455 = G(cases_DASH_funs2703462,"a-id-var",L[529]);
var anf_arg20403456 = G(self2693461,"l",L[581]);
var anf_arg20413457 = G(self2693461,"id",L[580]);
var $z34473448 = D;
var $f34533454 = function(_) {
return R.isFunction(call_DASH_a_DASH_id_DASH_var2683455)?call_DASH_a_DASH_id_DASH_var2683455.app(anf_arg20403456,anf_arg20413457):R.ffi.throwNonFunApp(L[529],call_DASH_a_DASH_id_DASH_var2683455,[anf_arg20403456,anf_arg20413457]);
};
try {
if(--R.GAS > 0) {
$z34473448 = $f34533454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34533454,
"from":L[529]});
}
} catch($e34453446) {
if(R.isCont($e34453446)) {
var $ss34493450 = {"from":L[529],
"go":function(cont_tail_arg20423458) {
return $Hcont_tail_arg35993460(cont_tail_arg20423458,if_helper20333459);
}};
$e34453446.stack[R.EXN_STACKHEIGHT++] = $ss34493450;
}
if(R.isPyretException($e34453446)) {
$e34453446.pyretStack.push(L[529]);
}
throw $e34453446;
}
var $ret34513452 = $Hcont_tail_arg35993460($z34473448,if_helper20333459);
++R.GAS;
return $ret34513452;
} else {
var $z34653466 = D;
var $f34713472 = function(_) {
return R.isFunction(else_DASH_clause2713473)?else_DASH_clause2713473.app():R.ffi.throwNonFunApp(L[529],else_DASH_clause2713473,[]);
};
try {
if(--R.GAS > 0) {
$z34653466 = $f34713472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34713472,
"from":L[529]});
}
} catch($e34633464) {
if(R.isCont($e34633464)) {
var $ss34673468 = {"from":L[529],
"go":function(cont_tail_arg20383474) {
return $Hcont_tail_arg36003475(cont_tail_arg20383474,if_helper20333459);
}};
$e34633464.stack[R.EXN_STACKHEIGHT++] = $ss34673468;
}
if(R.isPyretException($e34633464)) {
$e34633464.pyretStack.push(L[529]);
}
throw $e34633464;
}
var $ret34693470 = $Hcont_tail_arg36003475($z34653466,if_helper20333459);
++R.GAS;
return $ret34693470;
}
} else {
var cont_tail_arg20353479 = R.throwNonBooleanCondition(L[529],("if"),if_DASH_2733476);
if(--R.GAS > 0) {
$z34773478 = R.isFunction(if_helper20333459)?if_helper20333459.app(cont_tail_arg20353479):R.ffi.throwNonFunApp(L[529],if_helper20333459,[cont_tail_arg20353479]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20333459)?if_helper20333459.app(cont_tail_arg20353479):R.ffi.throwNonFunApp(L[529],if_helper20333459,[cont_tail_arg20353479]);
},
"from":L[529]});
}
++R.GAS;
return $z34773478;
}
};
},{"length":3});
var anf_variant_member20543324 = R.makeMethod(function(self2723443) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[529],0,arguments);
}
var anf_arg20463441 = G(self2723443,"l",L[529]);
var $z34333434 = D;
var $f34393440 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg20463441):R.ffi.throwNonFunApp(L[529],torepr31,[anf_arg20463441]);
};
try {
if(--R.GAS > 0) {
$z34333434 = $f34393440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34393440,
"from":L[529]});
}
} catch($e34313432) {
if(R.isCont($e34313432)) {
var $ss34353436 = {"from":L[529],
"go":function(anf_arg20473442) {
return $Hanf_arg36073444(anf_arg20473442,self2723443,_plus26,torepr31);
}};
$e34313432.stack[R.EXN_STACKHEIGHT++] = $ss34353436;
}
if(R.isPyretException($e34313432)) {
$e34313432.pyretStack.push(L[529]);
}
throw $e34313432;
}
var $ret34373438 = $Hanf_arg36073444($z34333434,self2723443,_plus26,torepr31);
++R.GAS;
return $ret34373438;
};
},{"length":1});
var anf_variant_member20563325 = R.makeMethod(function(self4973430) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[579],0,arguments);
}
var ann_DASH_check_DASH_temp20553429 = ("a-id-var");
return ann_DASH_check_DASH_temp20553429;
};
},{"length":1});
var anf_variant_member20633326 = R.makeMethod(function(self4983428) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[578],0,arguments);
}
var anf_fun20583425 = G(PP337,"str",L[577]);
var anf_bracket20593427 = G(self4983428,"id",L[576]);
var anf_fun20603423 = G(anf_bracket20593427,"tostring",L[575]);
var $z34153416 = D;
var $f34213422 = function(_) {
return R.isFunction(anf_fun20603423)?anf_fun20603423.app():R.ffi.throwNonFunApp(L[574],anf_fun20603423,[]);
};
try {
if(--R.GAS > 0) {
$z34153416 = $f34213422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34213422,
"from":L[574]});
}
} catch($e34133414) {
if(R.isCont($e34133414)) {
var $ss34173418 = {"from":L[574],
"go":function(anf_arg20613424) {
return $Hanf_arg36103426(anf_arg20613424,anf_fun20583425,_plus26);
}};
$e34133414.stack[R.EXN_STACKHEIGHT++] = $ss34173418;
}
if(R.isPyretException($e34133414)) {
$e34133414.pyretStack.push(L[574]);
}
throw $e34133414;
}
var $ret34193420 = $Hanf_arg36103426($z34153416,anf_fun20583425,_plus26);
++R.GAS;
return $ret34193420;
};
},{"length":1});
var anf_variant_member20773334 = R.makeMethod(function(self2753390) {
return function(cases_DASH_funs2763391,else_DASH_clause2773402) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[528],2,arguments);
}
var if_DASH_2793405 = R.hasField(cases_DASH_funs2763391,("a-id-letrec"));
var if_helper20653388 = R.makeFunction(function(if_helper_arg20663411) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[528],1,arguments);
}
var ann_DASH_check_DASH_temp20643412 = if_helper_arg20663411;
return ann_DASH_check_DASH_temp20643412;
});
var anf_if20693410 = R.isBoolean(if_DASH_2793405);
if(R.isPyretTrue(anf_if20693410)) {
if(R.isPyretTrue(if_DASH_2793405)) {
var call_DASH_a_DASH_id_DASH_letrec2743383 = G(cases_DASH_funs2763391,"a-id-letrec",L[528]);
var anf_arg20723384 = G(self2753390,"l",L[573]);
var anf_arg20733385 = G(self2753390,"id",L[572]);
var anf_arg20743386 = G(self2753390,"safe",L[571]);
var $z33753376 = D;
var $f33813382 = function(_) {
return R.isFunction(call_DASH_a_DASH_id_DASH_letrec2743383)?call_DASH_a_DASH_id_DASH_letrec2743383.app(anf_arg20723384,anf_arg20733385,anf_arg20743386):R.ffi.throwNonFunApp(L[528],call_DASH_a_DASH_id_DASH_letrec2743383,[anf_arg20723384,anf_arg20733385,anf_arg20743386]);
};
try {
if(--R.GAS > 0) {
$z33753376 = $f33813382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33813382,
"from":L[528]});
}
} catch($e33733374) {
if(R.isCont($e33733374)) {
var $ss33773378 = {"from":L[528],
"go":function(cont_tail_arg20753387) {
return $Hcont_tail_arg36113389(cont_tail_arg20753387,if_helper20653388);
}};
$e33733374.stack[R.EXN_STACKHEIGHT++] = $ss33773378;
}
if(R.isPyretException($e33733374)) {
$e33733374.pyretStack.push(L[528]);
}
throw $e33733374;
}
var $ret33793380 = $Hcont_tail_arg36113389($z33753376,if_helper20653388);
++R.GAS;
return $ret33793380;
} else {
var $z33943395 = D;
var $f34003401 = function(_) {
return R.isFunction(else_DASH_clause2773402)?else_DASH_clause2773402.app():R.ffi.throwNonFunApp(L[528],else_DASH_clause2773402,[]);
};
try {
if(--R.GAS > 0) {
$z33943395 = $f34003401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34003401,
"from":L[528]});
}
} catch($e33923393) {
if(R.isCont($e33923393)) {
var $ss33963397 = {"from":L[528],
"go":function(cont_tail_arg20703403) {
return $Hcont_tail_arg36123404(cont_tail_arg20703403,if_helper20653388);
}};
$e33923393.stack[R.EXN_STACKHEIGHT++] = $ss33963397;
}
if(R.isPyretException($e33923393)) {
$e33923393.pyretStack.push(L[528]);
}
throw $e33923393;
}
var $ret33983399 = $Hcont_tail_arg36123404($z33943395,if_helper20653388);
++R.GAS;
return $ret33983399;
}
} else {
var cont_tail_arg20673408 = R.throwNonBooleanCondition(L[528],("if"),if_DASH_2793405);
if(--R.GAS > 0) {
$z34063407 = R.isFunction(if_helper20653388)?if_helper20653388.app(cont_tail_arg20673408):R.ffi.throwNonFunApp(L[528],if_helper20653388,[cont_tail_arg20673408]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20653388)?if_helper20653388.app(cont_tail_arg20673408):R.ffi.throwNonFunApp(L[528],if_helper20653388,[cont_tail_arg20673408]);
},
"from":L[528]});
}
++R.GAS;
return $z34063407;
}
};
},{"length":3});
var anf_variant_member20913335 = R.makeMethod(function(self2783371) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[528],0,arguments);
}
var anf_arg20793369 = G(self2783371,"l",L[528]);
var $z33613362 = D;
var $f33673368 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg20793369):R.ffi.throwNonFunApp(L[528],torepr31,[anf_arg20793369]);
};
try {
if(--R.GAS > 0) {
$z33613362 = $f33673368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33673368,
"from":L[528]});
}
} catch($e33593360) {
if(R.isCont($e33593360)) {
var $ss33633364 = {"from":L[528],
"go":function(anf_arg20803370) {
return $Hanf_arg36223372(anf_arg20803370,self2783371,_plus26,torepr31);
}};
$e33593360.stack[R.EXN_STACKHEIGHT++] = $ss33633364;
}
if(R.isPyretException($e33593360)) {
$e33593360.pyretStack.push(L[528]);
}
throw $e33593360;
}
var $ret33653366 = $Hanf_arg36223372($z33613362,self2783371,_plus26,torepr31);
++R.GAS;
return $ret33653366;
};
},{"length":1});
var anf_variant_member20933336 = R.makeMethod(function(self5023358) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[570],0,arguments);
}
var ann_DASH_check_DASH_temp20923357 = ("a-id-letrec");
return ann_DASH_check_DASH_temp20923357;
};
},{"length":1});
var anf_variant_member21003337 = R.makeMethod(function(self5033356) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[569],0,arguments);
}
var anf_fun20953353 = G(PP337,"str",L[568]);
var anf_bracket20963355 = G(self5033356,"id",L[567]);
var anf_fun20973351 = G(anf_bracket20963355,"tostring",L[566]);
var $z33433344 = D;
var $f33493350 = function(_) {
return R.isFunction(anf_fun20973351)?anf_fun20973351.app():R.ffi.throwNonFunApp(L[565],anf_fun20973351,[]);
};
try {
if(--R.GAS > 0) {
$z33433344 = $f33493350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33493350,
"from":L[565]});
}
} catch($e33413342) {
if(R.isCont($e33413342)) {
var $ss33453346 = {"from":L[565],
"go":function(anf_arg20983352) {
return $Hanf_arg36253354(anf_arg20983352,anf_fun20953353,_plus26);
}};
$e33413342.stack[R.EXN_STACKHEIGHT++] = $ss33453346;
}
if(R.isPyretException($e33413342)) {
$e33413342.pyretStack.push(L[565]);
}
throw $e33413342;
}
var $ret33473348 = $Hanf_arg36253354($z33433344,anf_fun20953353,_plus26);
++R.GAS;
return $ret33473348;
};
},{"length":1});
var anf_assign2101610 = (function() {
var $a_DASH_srcloc_DASH_base32423243 = {"visit":anf_shared18173241,
"_match":anf_variant_member18303247,
"_torepr":anf_variant_member18403248,
"label":anf_variant_member18423249,
"tosource":anf_variant_member18473250};
var $a_DASH_srcloc_DASH_brands32453246 = {"$brand-a-srcloc3244":true};
$a_DASH_srcloc_DASH_brands32453246[AValT138982._brand] = true
var $a_DASH_num_DASH_base32533254 = {"visit":anf_shared18173241,
"_match":anf_variant_member18603258,
"_torepr":anf_variant_member18703259,
"label":anf_variant_member18723260,
"tosource":anf_variant_member18763261};
var $a_DASH_num_DASH_brands32563257 = {"$brand-a-num3255":true};
$a_DASH_num_DASH_brands32563257[AValT138982._brand] = true
var $a_DASH_str_DASH_base32643265 = {"visit":anf_shared18173241,
"_match":anf_variant_member18893269,
"_torepr":anf_variant_member18993270,
"label":anf_variant_member19013271,
"tosource":anf_variant_member19073272};
var $a_DASH_str_DASH_brands32673268 = {"$brand-a-str3266":true};
$a_DASH_str_DASH_brands32673268[AValT138982._brand] = true
var $a_DASH_bool_DASH_base32753276 = {"visit":anf_shared18173241,
"_match":anf_variant_member19203280,
"_torepr":anf_variant_member19303281,
"label":anf_variant_member19323282,
"tosource":anf_variant_member19373283};
var $a_DASH_bool_DASH_brands32783279 = {"$brand-a-bool3277":true};
$a_DASH_bool_DASH_brands32783279[AValT138982._brand] = true
var $a_DASH_array_DASH_base32863287 = {"visit":anf_shared18173241,
"_match":anf_variant_member19503291,
"_torepr":anf_variant_member19603292,
"label":anf_variant_member19623293,
"tosource":anf_variant_member19773294};
var $a_DASH_array_DASH_brands32893290 = {"$brand-a-array3288":true};
$a_DASH_array_DASH_brands32893290[AValT138982._brand] = true
var $a_DASH_undefined_DASH_base32973298 = {"visit":anf_shared18173241,
"_match":anf_variant_member19893302,
"_torepr":anf_variant_member19953303,
"label":anf_variant_member19973304,
"tosource":anf_variant_member20003305};
var $a_DASH_undefined_DASH_brands33003301 = {"$brand-a-undefined3299":true};
$a_DASH_undefined_DASH_brands33003301[AValT138982._brand] = true
var $a_DASH_id_DASH_base33073308 = {"visit":anf_shared18173241,
"_match":anf_variant_member20133312,
"_torepr":anf_variant_member20233313,
"label":anf_variant_member20253314,
"tosource":anf_variant_member20313315};
var $a_DASH_id_DASH_brands33103311 = {"$brand-a-id3309":true};
$a_DASH_id_DASH_brands33103311[AValT138982._brand] = true
var $a_DASH_id_DASH_var_DASH_base33183319 = {"visit":anf_shared18173241,
"_match":anf_variant_member20443323,
"_torepr":anf_variant_member20543324,
"label":anf_variant_member20563325,
"tosource":anf_variant_member20633326};
var $a_DASH_id_DASH_var_DASH_brands33213322 = {"$brand-a-id-var3320":true};
$a_DASH_id_DASH_var_DASH_brands33213322[AValT138982._brand] = true
var $a_DASH_id_DASH_letrec_DASH_base33293330 = {"visit":anf_shared18173241,
"_match":anf_variant_member20773334,
"_torepr":anf_variant_member20913335,
"label":anf_variant_member20933336,
"tosource":anf_variant_member21003337};
var $a_DASH_id_DASH_letrec_DASH_brands33323333 = {"$brand-a-id-letrec3331":true};
$a_DASH_id_DASH_letrec_DASH_brands33323333[AValT138982._brand] = true
return R.makeObject({"AVal":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[537],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,AValT138982._brand));
}),
"is-a-srcloc":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[536],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-srcloc3244"));
}),
"a-srcloc":R.makeFunction(function(l4683251,loc4693252) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[538],2,arguments);
}
return R.checkAnnArgs([Loc9089,Loc9089],[l4683251,loc4693252],[L[539],L[540]],function() {
var dict = R.create($a_DASH_srcloc_DASH_base32423243);
dict["l"] = l4683251
dict["loc"] = loc4693252
return R.makeBrandedObject(dict,$a_DASH_srcloc_DASH_brands32453246);
});
}),
"is-a-num":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[535],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-num3255"));
}),
"a-num":R.makeFunction(function(l4723262,n4733263) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[541],2,arguments);
}
return R.checkAnnArgs([Loc9089,$type$Number34],[l4723262,n4733263],[L[542],L[543]],function() {
var dict = R.create($a_DASH_num_DASH_base32533254);
dict["l"] = l4723262
dict["n"] = n4733263
return R.makeBrandedObject(dict,$a_DASH_num_DASH_brands32563257);
});
}),
"is-a-str":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[534],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-str3266"));
}),
"a-str":R.makeFunction(function(l4763273,s4773274) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[544],2,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35],[l4763273,s4773274],[L[545],L[546]],function() {
var dict = R.create($a_DASH_str_DASH_base32643265);
dict["l"] = l4763273
dict["s"] = s4773274
return R.makeBrandedObject(dict,$a_DASH_str_DASH_brands32673268);
});
}),
"is-a-bool":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[533],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-bool3277"));
}),
"a-bool":R.makeFunction(function(l4803284,b4813285) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[547],2,arguments);
}
return R.checkAnnArgs([Loc9089,$type$Boolean33],[l4803284,b4813285],[L[548],L[549]],function() {
var dict = R.create($a_DASH_bool_DASH_base32753276);
dict["l"] = l4803284
dict["b"] = b4813285
return R.makeBrandedObject(dict,$a_DASH_bool_DASH_brands32783279);
});
}),
"is-a-array":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[532],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-array3288"));
}),
"a-array":R.makeFunction(function(l4843295,values4853296) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[550],2,arguments);
}
return R.checkAnnArgs([Loc9089,List1788],[l4843295,values4853296],[L[551],L[552]],function() {
var dict = R.create($a_DASH_array_DASH_base32863287);
dict["l"] = l4843295
dict["values"] = values4853296
return R.makeBrandedObject(dict,$a_DASH_array_DASH_brands32893290);
});
}),
"is-a-undefined":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[531],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-undefined3299"));
}),
"a-undefined":R.makeFunction(function(l4883306) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[553],1,arguments);
}
return R.checkAnnArgs([Loc9089],[l4883306],[L[554]],function() {
var dict = R.create($a_DASH_undefined_DASH_base32973298);
dict["l"] = l4883306
return R.makeBrandedObject(dict,$a_DASH_undefined_DASH_brands33003301);
});
}),
"is-a-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[530],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-id3309"));
}),
"a-id":R.makeFunction(function(l4913316,id4923317) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[555],2,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[556],"A",A244,"Name")],[l4913316,id4923317],[L[557],L[556]],function() {
var dict = R.create($a_DASH_id_DASH_base33073308);
dict["l"] = l4913316
dict["id"] = id4923317
return R.makeBrandedObject(dict,$a_DASH_id_DASH_brands33103311);
});
}),
"is-a-id-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[529],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-id-var3320"));
}),
"a-id-var":R.makeFunction(function(l4953327,id4963328) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[558],2,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[559],"A",A244,"Name")],[l4953327,id4963328],[L[560],L[559]],function() {
var dict = R.create($a_DASH_id_DASH_var_DASH_base33183319);
dict["l"] = l4953327
dict["id"] = id4963328
return R.makeBrandedObject(dict,$a_DASH_id_DASH_var_DASH_brands33213322);
});
}),
"is-a-id-letrec":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[528],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-a-id-letrec3331"));
}),
"a-id-letrec":R.makeFunction(function(l4993338,id5003339,safe5013340) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[561],3,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[562],"A",A244,"Name"),$type$Boolean33],[l4993338,id5003339,safe5013340],[L[563],L[562],L[564]],function() {
var dict = R.create($a_DASH_id_DASH_letrec_DASH_base33293330);
dict["l"] = l4993338
dict["id"] = id5003339
dict["safe"] = safe5013340
return R.makeBrandedObject(dict,$a_DASH_id_DASH_letrec_DASH_brands33323333);
});
})});
})();
AVal25225609.$var = anf_assign2101610;
var anf_assign2102612 = G(AVal25225609.$var,"AVal",L[537]);
AVal226611.$var = anf_assign2102612;
var anf_assign2103614 = G(AVal25225609.$var,"AVal",L[537]);
is_DASH_AVal227613.$var = anf_assign2103614;
var anf_assign2104616 = G(AVal25225609.$var,"is-a-srcloc",L[536]);
is_DASH_a_DASH_srcloc228615.$var = anf_assign2104616;
var anf_assign2105618 = G(AVal25225609.$var,"a-srcloc",L[536]);
a_DASH_srcloc229617.$var = anf_assign2105618;
var anf_assign2106620 = G(AVal25225609.$var,"is-a-num",L[535]);
is_DASH_a_DASH_num230619.$var = anf_assign2106620;
var anf_assign2107622 = G(AVal25225609.$var,"a-num",L[535]);
a_DASH_num231621.$var = anf_assign2107622;
var anf_assign2108624 = G(AVal25225609.$var,"is-a-str",L[534]);
is_DASH_a_DASH_str232623.$var = anf_assign2108624;
var anf_assign2109626 = G(AVal25225609.$var,"a-str",L[534]);
a_DASH_str233625.$var = anf_assign2109626;
var anf_assign2110628 = G(AVal25225609.$var,"is-a-bool",L[533]);
is_DASH_a_DASH_bool234627.$var = anf_assign2110628;
var anf_assign2111630 = G(AVal25225609.$var,"a-bool",L[533]);
a_DASH_bool235629.$var = anf_assign2111630;
var anf_assign2112632 = G(AVal25225609.$var,"is-a-array",L[532]);
is_DASH_a_DASH_array236631.$var = anf_assign2112632;
var anf_assign2113634 = G(AVal25225609.$var,"a-array",L[532]);
a_DASH_array237633.$var = anf_assign2113634;
var anf_assign2114636 = G(AVal25225609.$var,"is-a-undefined",L[531]);
is_DASH_a_DASH_undefined238635.$var = anf_assign2114636;
var anf_assign2115638 = G(AVal25225609.$var,"a-undefined",L[531]);
a_DASH_undefined239637.$var = anf_assign2115638;
var anf_assign2116640 = G(AVal25225609.$var,"is-a-id",L[530]);
is_DASH_a_DASH_id240639.$var = anf_assign2116640;
var anf_assign2117642 = G(AVal25225609.$var,"a-id",L[530]);
a_DASH_id241641.$var = anf_assign2117642;
var anf_assign2118644 = G(AVal25225609.$var,"is-a-id-var",L[529]);
is_DASH_a_DASH_id_DASH_var242643.$var = anf_assign2118644;
var anf_assign2119646 = G(AVal25225609.$var,"a-id-var",L[529]);
a_DASH_id_DASH_var243645.$var = anf_assign2119646;
var anf_assign2120648 = G(AVal25225609.$var,"is-a-id-letrec",L[528]);
is_DASH_a_DASH_id_DASH_letrec244647.$var = anf_assign2120648;
var anf_assign2121650 = G(AVal25225609.$var,"a-id-letrec",L[528]);
a_DASH_id_DASH_letrec245649.$var = anf_assign2121650;
var anf_assign2132652 = R.makeFunction(function(p5063206) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[521],1,arguments);
}
return R.checkAnnArgs([AProg6677],[p5063206],[L[527]],function() {
var cases_DASH_val2803240 = p5063206;
var anf_fun21233217 = G(cases_DASH_val2803240,"_match",L[522]);
var anf_obj21283223 = R.makeFunction(function($underscore5073224,imports5083225,body5093226) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[523],3,arguments);
}
var anf_fun21253237 = G(imports5083225,"map",L[526]);
var $z32293230 = D;
var $f32353236 = function(_) {
return R.isFunction(anf_fun21253237)?anf_fun21253237.app(strip_DASH_loc_DASH_import247653.$var === D?U(L[524],"strip-loc-import"):strip_DASH_loc_DASH_import247653.$var):R.ffi.throwNonFunApp(L[525],anf_fun21253237,[strip_DASH_loc_DASH_import247653.$var === D?U(L[524],"strip-loc-import"):strip_DASH_loc_DASH_import247653.$var]);
};
try {
if(--R.GAS > 0) {
$z32293230 = $f32353236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32353236,
"from":L[525]});
}
} catch($e32273228) {
if(R.isCont($e32273228)) {
var $ss32313232 = {"from":L[525],
"go":function(anf_arg21263238) {
return $Hanf_arg36283239(anf_arg21263238,a_DASH_program121401,body5093226,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657);
}};
$e32273228.stack[R.EXN_STACKHEIGHT++] = $ss32313232;
}
if(R.isPyretException($e32273228)) {
$e32273228.pyretStack.push(L[525]);
}
throw $e32273228;
}
var $ret32333234 = $Hanf_arg36283239($z32293230,a_DASH_program121401,body5093226,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657);
++R.GAS;
return $ret32333234;
});
var anf_arg21293218 = R.makeObject({"a-program":anf_obj21283223});
var anf_arg21313219 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[522],0,arguments);
}
var ann_DASH_check_DASH_temp21303222 = R.throwNoBranchesMatched(L[522],("cases"));
return ann_DASH_check_DASH_temp21303222;
});
var $z32093210 = D;
var $f32153216 = function(_) {
return R.isFunction(anf_fun21233217)?anf_fun21233217.app(anf_arg21293218,anf_arg21313219):R.ffi.throwNonFunApp(L[521],anf_fun21233217,[anf_arg21293218,anf_arg21313219]);
};
try {
if(--R.GAS > 0) {
$z32093210 = $f32153216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32153216,
"from":L[521]});
}
} catch($e32073208) {
if(R.isCont($e32073208)) {
var $ss32113212 = {"from":L[521],
"go":function(ann_DASH_check_DASH_temp21223220) {
return $Hann_DASH_check_DASH_temp36293221(ann_DASH_check_DASH_temp21223220);
}};
$e32073208.stack[R.EXN_STACKHEIGHT++] = $ss32113212;
}
if(R.isPyretException($e32073208)) {
$e32073208.pyretStack.push(L[521]);
}
throw $e32073208;
}
var $ret32133214 = $Hann_DASH_check_DASH_temp36293221($z32093210);
++R.GAS;
return $ret32133214;
});
});
strip_DASH_loc_DASH_prog246651.$var = anf_assign2132652;
var anf_assign2153654 = R.makeFunction(function(i5103155) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[512],1,arguments);
}
return R.checkAnnArgs([AImport7069],[i5103155],[L[520]],function() {
var cases_DASH_val2813205 = i5103155;
var anf_fun21343166 = G(cases_DASH_val2813205,"_match",L[513]);
var anf_obj21403172 = R.makeFunction(function($underscore5113190,import_DASH_type5123191,name5133192) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[517],3,arguments);
}
var $z31953196 = D;
var $f32013202 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_import_DASH_type248655.$var === D?U(L[518],"strip-loc-import-type"):strip_DASH_loc_DASH_import_DASH_type248655.$var)?strip_DASH_loc_DASH_import_DASH_type248655.$var === D?U(L[518],"strip-loc-import-type"):strip_DASH_loc_DASH_import_DASH_type248655.$var.app(import_DASH_type5123191):R.ffi.throwNonFunApp(L[519],strip_DASH_loc_DASH_import_DASH_type248655.$var === D?U(L[518],"strip-loc-import-type"):strip_DASH_loc_DASH_import_DASH_type248655.$var,[import_DASH_type5123191]);
};
try {
if(--R.GAS > 0) {
$z31953196 = $f32013202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32013202,
"from":L[519]});
}
} catch($e31933194) {
if(R.isCont($e31933194)) {
var $ss31973198 = {"from":L[519],
"go":function(anf_arg21363203) {
return $Hanf_arg36323204(anf_arg21363203,A136,a_DASH_import133425,dummy_DASH_loc115391,name5133192);
}};
$e31933194.stack[R.EXN_STACKHEIGHT++] = $ss31973198;
}
if(R.isPyretException($e31933194)) {
$e31933194.pyretStack.push(L[519]);
}
throw $e31933194;
}
var $ret31993200 = $Hanf_arg36323204($z31953196,A136,a_DASH_import133425,dummy_DASH_loc115391,name5133192);
++R.GAS;
return $ret31993200;
});
var anf_obj21493173 = R.makeFunction(function($underscore5143174,import_DASH_type5153175,name5163176,types5173177) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[514],4,arguments);
}
var $z31803181 = D;
var $f31863187 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_import_DASH_type248655.$var === D?U(L[515],"strip-loc-import-type"):strip_DASH_loc_DASH_import_DASH_type248655.$var)?strip_DASH_loc_DASH_import_DASH_type248655.$var === D?U(L[515],"strip-loc-import-type"):strip_DASH_loc_DASH_import_DASH_type248655.$var.app(import_DASH_type5153175):R.ffi.throwNonFunApp(L[516],strip_DASH_loc_DASH_import_DASH_type248655.$var === D?U(L[515],"strip-loc-import-type"):strip_DASH_loc_DASH_import_DASH_type248655.$var,[import_DASH_type5153175]);
};
try {
if(--R.GAS > 0) {
$z31803181 = $f31863187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31863187,
"from":L[516]});
}
} catch($e31783179) {
if(R.isCont($e31783179)) {
var $ss31823183 = {"from":L[516],
"go":function(anf_arg21423188) {
return $Hanf_arg36363189(anf_arg21423188,A136,a_DASH_import_DASH_types135429,dummy_DASH_loc115391,name5163176,types5173177);
}};
$e31783179.stack[R.EXN_STACKHEIGHT++] = $ss31823183;
}
if(R.isPyretException($e31783179)) {
$e31783179.pyretStack.push(L[516]);
}
throw $e31783179;
}
var $ret31843185 = $Hanf_arg36363189($z31803181,A136,a_DASH_import_DASH_types135429,dummy_DASH_loc115391,name5163176,types5173177);
++R.GAS;
return $ret31843185;
});
var anf_arg21503167 = R.makeObject({"a-import":anf_obj21403172,
"a-import-types":anf_obj21493173});
var anf_arg21523168 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[513],0,arguments);
}
var ann_DASH_check_DASH_temp21513171 = R.throwNoBranchesMatched(L[513],("cases"));
return ann_DASH_check_DASH_temp21513171;
});
var $z31583159 = D;
var $f31643165 = function(_) {
return R.isFunction(anf_fun21343166)?anf_fun21343166.app(anf_arg21503167,anf_arg21523168):R.ffi.throwNonFunApp(L[512],anf_fun21343166,[anf_arg21503167,anf_arg21523168]);
};
try {
if(--R.GAS > 0) {
$z31583159 = $f31643165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31643165,
"from":L[512]});
}
} catch($e31563157) {
if(R.isCont($e31563157)) {
var $ss31603161 = {"from":L[512],
"go":function(ann_DASH_check_DASH_temp21333169) {
return $Hann_DASH_check_DASH_temp36373170(ann_DASH_check_DASH_temp21333169);
}};
$e31563157.stack[R.EXN_STACKHEIGHT++] = $ss31603161;
}
if(R.isPyretException($e31563157)) {
$e31563157.pyretStack.push(L[512]);
}
throw $e31563157;
}
var $ret31623163 = $Hann_DASH_check_DASH_temp36373170($z31583159);
++R.GAS;
return $ret31623163;
});
});
strip_DASH_loc_DASH_import247653.$var = anf_assign2153654;
var anf_assign2163656 = R.makeFunction(function(i5183105) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[507],1,arguments);
}
return R.checkAnnArgs([AImportType6871],[i5183105],[L[511]],function() {
var cases_DASH_val2823154 = i5183105;
var anf_fun21553116 = G(cases_DASH_val2823154,"_match",L[508]);
var anf_obj21573122 = R.makeFunction(function($underscore5193139,name5203140,id5213141) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[510],3,arguments);
}
var $z31443145 = D;
var $f31503151 = function(_) {
return R.isFunction(a_DASH_import_DASH_builtin126411.$var)?a_DASH_import_DASH_builtin126411.$var.app(dummy_DASH_loc115391,name5203140,id5213141):R.ffi.throwNonFunApp(L[510],a_DASH_import_DASH_builtin126411.$var,[dummy_DASH_loc115391,name5203140,id5213141]);
};
try {
if(--R.GAS > 0) {
$z31443145 = $f31503151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31503151,
"from":L[510]});
}
} catch($e31423143) {
if(R.isCont($e31423143)) {
var $ss31463147 = {"from":L[510],
"go":function(ann_DASH_check_DASH_temp21563152) {
return $Hann_DASH_check_DASH_temp36383153(ann_DASH_check_DASH_temp21563152);
}};
$e31423143.stack[R.EXN_STACKHEIGHT++] = $ss31463147;
}
if(R.isPyretException($e31423143)) {
$e31423143.pyretStack.push(L[510]);
}
throw $e31423143;
}
var $ret31483149 = $Hann_DASH_check_DASH_temp36383153($z31443145);
++R.GAS;
return $ret31483149;
});
var anf_obj21593123 = R.makeFunction(function($underscore5223124,file5233125,id5243126) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[509],3,arguments);
}
var $z31293130 = D;
var $f31353136 = function(_) {
return R.isFunction(a_DASH_import_DASH_builtin126411.$var)?a_DASH_import_DASH_builtin126411.$var.app(dummy_DASH_loc115391,file5233125,id5243126):R.ffi.throwNonFunApp(L[509],a_DASH_import_DASH_builtin126411.$var,[dummy_DASH_loc115391,file5233125,id5243126]);
};
try {
if(--R.GAS > 0) {
$z31293130 = $f31353136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31353136,
"from":L[509]});
}
} catch($e31273128) {
if(R.isCont($e31273128)) {
var $ss31313132 = {"from":L[509],
"go":function(ann_DASH_check_DASH_temp21583137) {
return $Hann_DASH_check_DASH_temp36393138(ann_DASH_check_DASH_temp21583137);
}};
$e31273128.stack[R.EXN_STACKHEIGHT++] = $ss31313132;
}
if(R.isPyretException($e31273128)) {
$e31273128.pyretStack.push(L[509]);
}
throw $e31273128;
}
var $ret31333134 = $Hann_DASH_check_DASH_temp36393138($z31293130);
++R.GAS;
return $ret31333134;
});
var anf_arg21603117 = R.makeObject({"a-import-builtin":anf_obj21573122,
"a-import-file":anf_obj21593123});
var anf_arg21623118 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[508],0,arguments);
}
var ann_DASH_check_DASH_temp21613121 = R.throwNoBranchesMatched(L[508],("cases"));
return ann_DASH_check_DASH_temp21613121;
});
var $z31083109 = D;
var $f31143115 = function(_) {
return R.isFunction(anf_fun21553116)?anf_fun21553116.app(anf_arg21603117,anf_arg21623118):R.ffi.throwNonFunApp(L[507],anf_fun21553116,[anf_arg21603117,anf_arg21623118]);
};
try {
if(--R.GAS > 0) {
$z31083109 = $f31143115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31143115,
"from":L[507]});
}
} catch($e31063107) {
if(R.isCont($e31063107)) {
var $ss31103111 = {"from":L[507],
"go":function(ann_DASH_check_DASH_temp21543119) {
return $Hann_DASH_check_DASH_temp36403120(ann_DASH_check_DASH_temp21543119);
}};
$e31063107.stack[R.EXN_STACKHEIGHT++] = $ss31103111;
}
if(R.isPyretException($e31063107)) {
$e31063107.pyretStack.push(L[507]);
}
throw $e31063107;
}
var $ret31123113 = $Hann_DASH_check_DASH_temp36403120($z31083109);
++R.GAS;
return $ret31123113;
});
});
strip_DASH_loc_DASH_import_DASH_type248655.$var = anf_assign2163656;
var anf_assign2200658 = R.makeFunction(function(expr5252971) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[485],1,arguments);
}
return R.checkAnnArgs([AExpr7465],[expr5252971],[L[506]],function() {
var cases_DASH_val2833104 = expr5252971;
var anf_fun21652982 = G(cases_DASH_val2833104,"_match",L[486]);
var anf_obj21672988 = R.makeFunction(function($underscore5263089,bind5273090,body5283091) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[505],3,arguments);
}
var $z30943095 = D;
var $f31003101 = function(_) {
return R.isFunction(a_DASH_type_DASH_let147453.$var)?a_DASH_type_DASH_let147453.$var.app(dummy_DASH_loc115391,bind5273090,body5283091):R.ffi.throwNonFunApp(L[505],a_DASH_type_DASH_let147453.$var,[dummy_DASH_loc115391,bind5273090,body5283091]);
};
try {
if(--R.GAS > 0) {
$z30943095 = $f31003101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31003101,
"from":L[505]});
}
} catch($e30923093) {
if(R.isCont($e30923093)) {
var $ss30963097 = {"from":L[505],
"go":function(ann_DASH_check_DASH_temp21663102) {
return $Hann_DASH_check_DASH_temp36413103(ann_DASH_check_DASH_temp21663102);
}};
$e30923093.stack[R.EXN_STACKHEIGHT++] = $ss30963097;
}
if(R.isPyretException($e30923093)) {
$e30923093.pyretStack.push(L[505]);
}
throw $e30923093;
}
var $ret30983099 = $Hann_DASH_check_DASH_temp36413103($z30943095);
++R.GAS;
return $ret30983099;
});
var anf_obj21722989 = R.makeFunction(function($underscore5293073,bind5303074,val5313075,body5323076) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[502],4,arguments);
}
var $z30793080 = D;
var $f30853086 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_bind250659.$var === D?U(L[503],"strip-loc-bind"):strip_DASH_loc_DASH_bind250659.$var)?strip_DASH_loc_DASH_bind250659.$var === D?U(L[503],"strip-loc-bind"):strip_DASH_loc_DASH_bind250659.$var.app(bind5303074):R.ffi.throwNonFunApp(L[504],strip_DASH_loc_DASH_bind250659.$var === D?U(L[503],"strip-loc-bind"):strip_DASH_loc_DASH_bind250659.$var,[bind5303074]);
};
try {
if(--R.GAS > 0) {
$z30793080 = $f30853086();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30853086,
"from":L[504]});
}
} catch($e30773078) {
if(R.isCont($e30773078)) {
var $ss30813082 = {"from":L[504],
"go":function(anf_arg21693087) {
return $Hanf_arg36453088(anf_arg21693087,a_DASH_let149457,body5323076,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_lettable251661,val5313075);
}};
$e30773078.stack[R.EXN_STACKHEIGHT++] = $ss30813082;
}
if(R.isPyretException($e30773078)) {
$e30773078.pyretStack.push(L[504]);
}
throw $e30773078;
}
var $ret30833084 = $Hanf_arg36453088($z30793080,a_DASH_let149457,body5323076,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_lettable251661,val5313075);
++R.GAS;
return $ret30833084;
});
var anf_obj21772990 = R.makeFunction(function($underscore5333057,bind5343058,val5353059,body5363060) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[499],4,arguments);
}
var $z30633064 = D;
var $f30693070 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_bind250659.$var === D?U(L[500],"strip-loc-bind"):strip_DASH_loc_DASH_bind250659.$var)?strip_DASH_loc_DASH_bind250659.$var === D?U(L[500],"strip-loc-bind"):strip_DASH_loc_DASH_bind250659.$var.app(bind5343058):R.ffi.throwNonFunApp(L[501],strip_DASH_loc_DASH_bind250659.$var === D?U(L[500],"strip-loc-bind"):strip_DASH_loc_DASH_bind250659.$var,[bind5343058]);
};
try {
if(--R.GAS > 0) {
$z30633064 = $f30693070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30693070,
"from":L[501]});
}
} catch($e30613062) {
if(R.isCont($e30613062)) {
var $ss30653066 = {"from":L[501],
"go":function(anf_arg21743071) {
return $Hanf_arg36493072(anf_arg21743071,a_DASH_var151461,body5363060,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_lettable251661,val5353059);
}};
$e30613062.stack[R.EXN_STACKHEIGHT++] = $ss30653066;
}
if(R.isPyretException($e30613062)) {
$e30613062.pyretStack.push(L[501]);
}
throw $e30613062;
}
var $ret30673068 = $Hanf_arg36493072($z30633064,a_DASH_var151461,body5363060,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_lettable251661,val5353059);
++R.GAS;
return $ret30673068;
});
var anf_obj21812991 = R.makeFunction(function($underscore5373042,e15383043,e25393044) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[496],3,arguments);
}
var $z30473048 = D;
var $f30533054 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_lettable251661.$var === D?U(L[497],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var)?strip_DASH_loc_DASH_lettable251661.$var === D?U(L[497],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var.app(e15383043):R.ffi.throwNonFunApp(L[498],strip_DASH_loc_DASH_lettable251661.$var === D?U(L[497],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var,[e15383043]);
};
try {
if(--R.GAS > 0) {
$z30473048 = $f30533054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30533054,
"from":L[498]});
}
} catch($e30453046) {
if(R.isCont($e30453046)) {
var $ss30493050 = {"from":L[498],
"go":function(anf_arg21793055) {
return $Hanf_arg36523056(anf_arg21793055,a_DASH_seq153465,dummy_DASH_loc115391,e25393044,strip_DASH_loc_DASH_expr249657);
}};
$e30453046.stack[R.EXN_STACKHEIGHT++] = $ss30493050;
}
if(R.isPyretException($e30453046)) {
$e30453046.pyretStack.push(L[498]);
}
throw $e30453046;
}
var $ret30513052 = $Hanf_arg36523056($z30473048,a_DASH_seq153465,dummy_DASH_loc115391,e25393044,strip_DASH_loc_DASH_expr249657);
++R.GAS;
return $ret30513052;
});
var anf_obj21862992 = R.makeFunction(function($underscore5403026,c5413027,t5423028,e5433029) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[493],4,arguments);
}
var $z30323033 = D;
var $f30383039 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[494],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[494],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(c5413027):R.ffi.throwNonFunApp(L[495],strip_DASH_loc_DASH_val253665.$var === D?U(L[494],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[c5413027]);
};
try {
if(--R.GAS > 0) {
$z30323033 = $f30383039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30383039,
"from":L[495]});
}
} catch($e30303031) {
if(R.isCont($e30303031)) {
var $ss30343035 = {"from":L[495],
"go":function(anf_arg21833040) {
return $Hanf_arg36563041(anf_arg21833040,a_DASH_if159477,dummy_DASH_loc115391,e5433029,strip_DASH_loc_DASH_expr249657,t5423028);
}};
$e30303031.stack[R.EXN_STACKHEIGHT++] = $ss30343035;
}
if(R.isPyretException($e30303031)) {
$e30303031.pyretStack.push(L[495]);
}
throw $e30303031;
}
var $ret30363037 = $Hanf_arg36563041($z30323033,a_DASH_if159477,dummy_DASH_loc115391,e5433029,strip_DASH_loc_DASH_expr249657,t5423028);
++R.GAS;
return $ret30363037;
});
var anf_obj21932993 = R.makeFunction(function($underscore5443008,is_DASH_var5453009,f5463010,args5473011,helper5483012,helper_DASH_args5493013) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[490],6,arguments);
}
var $z30163017 = D;
var $f30223023 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[491],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[491],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(f5463010):R.ffi.throwNonFunApp(L[492],strip_DASH_loc_DASH_val253665.$var === D?U(L[491],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[f5463010]);
};
try {
if(--R.GAS > 0) {
$z30163017 = $f30223023();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30223023,
"from":L[492]});
}
} catch($e30143015) {
if(R.isCont($e30143015)) {
var $ss30183019 = {"from":L[492],
"go":function(anf_arg21883024) {
return $Hanf_arg36603025(anf_arg21883024,a_DASH_split_DASH_app157473,args5473011,dummy_DASH_loc115391,helper_DASH_args5493013,helper5483012,is_DASH_var5453009,strip_DASH_loc_DASH_val253665);
}};
$e30143015.stack[R.EXN_STACKHEIGHT++] = $ss30183019;
}
if(R.isPyretException($e30143015)) {
$e30143015.pyretStack.push(L[492]);
}
throw $e30143015;
}
var $ret30203021 = $Hanf_arg36603025($z30163017,a_DASH_split_DASH_app157473,args5473011,dummy_DASH_loc115391,helper_DASH_args5493013,helper5483012,is_DASH_var5453009,strip_DASH_loc_DASH_val253665);
++R.GAS;
return $ret30203021;
});
var anf_obj21962994 = R.makeFunction(function(e5502995) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[487],1,arguments);
}
var $z29982999 = D;
var $f30043005 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_lettable251661.$var === D?U(L[488],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var)?strip_DASH_loc_DASH_lettable251661.$var === D?U(L[488],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var.app(e5502995):R.ffi.throwNonFunApp(L[489],strip_DASH_loc_DASH_lettable251661.$var === D?U(L[488],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var,[e5502995]);
};
try {
if(--R.GAS > 0) {
$z29982999 = $f30043005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30043005,
"from":L[489]});
}
} catch($e29962997) {
if(R.isCont($e29962997)) {
var $ss30003001 = {"from":L[489],
"go":function(anf_arg21953006) {
return $Hanf_arg36623007(anf_arg21953006,a_DASH_lettable161481);
}};
$e29962997.stack[R.EXN_STACKHEIGHT++] = $ss30003001;
}
if(R.isPyretException($e29962997)) {
$e29962997.pyretStack.push(L[489]);
}
throw $e29962997;
}
var $ret30023003 = $Hanf_arg36623007($z29982999,a_DASH_lettable161481);
++R.GAS;
return $ret30023003;
});
var anf_arg21972983 = R.makeObject({"a-type-let":anf_obj21672988,
"a-let":anf_obj21722989,
"a-var":anf_obj21772990,
"a-seq":anf_obj21812991,
"a-if":anf_obj21862992,
"a-split-app":anf_obj21932993,
"a-lettable":anf_obj21962994});
var anf_arg21992984 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[486],0,arguments);
}
var ann_DASH_check_DASH_temp21982987 = R.throwNoBranchesMatched(L[486],("cases"));
return ann_DASH_check_DASH_temp21982987;
});
var $z29742975 = D;
var $f29802981 = function(_) {
return R.isFunction(anf_fun21652982)?anf_fun21652982.app(anf_arg21972983,anf_arg21992984):R.ffi.throwNonFunApp(L[485],anf_fun21652982,[anf_arg21972983,anf_arg21992984]);
};
try {
if(--R.GAS > 0) {
$z29742975 = $f29802981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29802981,
"from":L[485]});
}
} catch($e29722973) {
if(R.isCont($e29722973)) {
var $ss29762977 = {"from":L[485],
"go":function(ann_DASH_check_DASH_temp21642985) {
return $Hann_DASH_check_DASH_temp36632986(ann_DASH_check_DASH_temp21642985);
}};
$e29722973.stack[R.EXN_STACKHEIGHT++] = $ss29762977;
}
if(R.isPyretException($e29722973)) {
$e29722973.pyretStack.push(L[485]);
}
throw $e29722973;
}
var $ret29782979 = $Hann_DASH_check_DASH_temp36632986($z29742975);
++R.GAS;
return $ret29782979;
});
});
strip_DASH_loc_DASH_expr249657.$var = anf_assign2200658;
var anf_assign2211660 = R.makeFunction(function(bind5512935) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[478],1,arguments);
}
return R.checkAnnArgs([ABind7663],[bind5512935],[L[484]],function() {
var cases_DASH_val2842970 = bind5512935;
var anf_fun22022946 = G(cases_DASH_val2842970,"_match",L[479]);
var anf_obj22072952 = R.makeFunction(function($underscore5522953,id5532954,ann5542955) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[480],3,arguments);
}
var anf_fun22042966 = G(ann5542955,"visit",L[483]);
var anf_arg22052967 = G(A136,"dummy-loc-visitor",L[482]);
var $z29582959 = D;
var $f29642965 = function(_) {
return R.isFunction(anf_fun22042966)?anf_fun22042966.app(anf_arg22052967):R.ffi.throwNonFunApp(L[481],anf_fun22042966,[anf_arg22052967]);
};
try {
if(--R.GAS > 0) {
$z29582959 = $f29642965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29642965,
"from":L[481]});
}
} catch($e29562957) {
if(R.isCont($e29562957)) {
var $ss29602961 = {"from":L[481],
"go":function(anf_arg22062968) {
return $Hanf_arg36652969(anf_arg22062968,a_DASH_bind166491,dummy_DASH_loc115391,id5532954);
}};
$e29562957.stack[R.EXN_STACKHEIGHT++] = $ss29602961;
}
if(R.isPyretException($e29562957)) {
$e29562957.pyretStack.push(L[481]);
}
throw $e29562957;
}
var $ret29622963 = $Hanf_arg36652969($z29582959,a_DASH_bind166491,dummy_DASH_loc115391,id5532954);
++R.GAS;
return $ret29622963;
});
var anf_arg22082947 = R.makeObject({"a-bind":anf_obj22072952});
var anf_arg22102948 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[479],0,arguments);
}
var ann_DASH_check_DASH_temp22092951 = R.throwNoBranchesMatched(L[479],("cases"));
return ann_DASH_check_DASH_temp22092951;
});
var $z29382939 = D;
var $f29442945 = function(_) {
return R.isFunction(anf_fun22022946)?anf_fun22022946.app(anf_arg22082947,anf_arg22102948):R.ffi.throwNonFunApp(L[478],anf_fun22022946,[anf_arg22082947,anf_arg22102948]);
};
try {
if(--R.GAS > 0) {
$z29382939 = $f29442945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29442945,
"from":L[478]});
}
} catch($e29362937) {
if(R.isCont($e29362937)) {
var $ss29402941 = {"from":L[478],
"go":function(ann_DASH_check_DASH_temp22012949) {
return $Hann_DASH_check_DASH_temp36662950(ann_DASH_check_DASH_temp22012949);
}};
$e29362937.stack[R.EXN_STACKHEIGHT++] = $ss29402941;
}
if(R.isPyretException($e29362937)) {
$e29362937.pyretStack.push(L[478]);
}
throw $e29362937;
}
var $ret29422943 = $Hann_DASH_check_DASH_temp36662950($z29382939);
++R.GAS;
return $ret29422943;
});
});
strip_DASH_loc_DASH_bind250659.$var = anf_assign2211660;
var anf_assign2274662 = R.makeFunction(function(lettable5552702) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[434],1,arguments);
}
return R.checkAnnArgs([ALettable8473],[lettable5552702],[L[477]],function() {
var cases_DASH_val2882934 = lettable5552702;
var anf_fun22132713 = G(cases_DASH_val2882934,"_match",L[435]);
var anf_obj22242719 = R.makeFunction(function($underscore5562917,answer5572918,provides5582919,types5592920,checks5602921) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[474],5,arguments);
}
var $z29242925 = D;
var $f29302931 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[475],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[475],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(answer5572918):R.ffi.throwNonFunApp(L[476],strip_DASH_loc_DASH_val253665.$var === D?U(L[475],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[answer5572918]);
};
try {
if(--R.GAS > 0) {
$z29242925 = $f29302931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29302931,
"from":L[476]});
}
} catch($e29222923) {
if(R.isCont($e29222923)) {
var $ss29262927 = {"from":L[476],
"go":function(anf_arg22152932) {
return $Hanf_arg36722933(anf_arg22152932,A136,a_DASH_module192543,checks5602921,dummy_DASH_loc115391,provides5582919,strip_DASH_loc_DASH_val253665,types5592920);
}};
$e29222923.stack[R.EXN_STACKHEIGHT++] = $ss29262927;
}
if(R.isPyretException($e29222923)) {
$e29222923.pyretStack.push(L[476]);
}
throw $e29222923;
}
var $ret29282929 = $Hanf_arg36722933($z29242925,A136,a_DASH_module192543,checks5602921,dummy_DASH_loc115391,provides5582919,strip_DASH_loc_DASH_val253665,types5592920);
++R.GAS;
return $ret29282929;
});
var anf_obj22272720 = R.makeFunction(function($underscore5612902,id5622903,value5632904) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[471],3,arguments);
}
var $z29072908 = D;
var $f29132914 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[472],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[472],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(value5632904):R.ffi.throwNonFunApp(L[473],strip_DASH_loc_DASH_val253665.$var === D?U(L[472],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[value5632904]);
};
try {
if(--R.GAS > 0) {
$z29072908 = $f29132914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29132914,
"from":L[473]});
}
} catch($e29052906) {
if(R.isCont($e29052906)) {
var $ss29092910 = {"from":L[473],
"go":function(anf_arg22262915) {
return $Hanf_arg36742916(anf_arg22262915,a_DASH_assign196551,dummy_DASH_loc115391,id5622903);
}};
$e29052906.stack[R.EXN_STACKHEIGHT++] = $ss29092910;
}
if(R.isPyretException($e29052906)) {
$e29052906.pyretStack.push(L[473]);
}
throw $e29052906;
}
var $ret29112912 = $Hanf_arg36742916($z29072908,a_DASH_assign196551,dummy_DASH_loc115391,id5622903);
++R.GAS;
return $ret29112912;
});
var anf_obj22322721 = R.makeFunction(function($underscore5642887,f5652888,args5662889) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[468],3,arguments);
}
var $z28922893 = D;
var $f28982899 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[469],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[469],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(f5652888):R.ffi.throwNonFunApp(L[470],strip_DASH_loc_DASH_val253665.$var === D?U(L[469],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[f5652888]);
};
try {
if(--R.GAS > 0) {
$z28922893 = $f28982899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28982899,
"from":L[470]});
}
} catch($e28902891) {
if(R.isCont($e28902891)) {
var $ss28942895 = {"from":L[470],
"go":function(anf_arg22292900) {
return $Hanf_arg36772901(anf_arg22292900,a_DASH_app198555,args5662889,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665);
}};
$e28902891.stack[R.EXN_STACKHEIGHT++] = $ss28942895;
}
if(R.isPyretException($e28902891)) {
$e28902891.pyretStack.push(L[470]);
}
throw $e28902891;
}
var $ret28962897 = $Hanf_arg36772901($z28922893,a_DASH_app198555,args5662889,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665);
++R.GAS;
return $ret28962897;
});
var anf_obj22362722 = R.makeFunction(function($underscore5672871,f5682872,args5692873) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[464],3,arguments);
}
var anf_fun22342884 = G(args5692873,"map",L[467]);
var $z28762877 = D;
var $f28822883 = function(_) {
return R.isFunction(anf_fun22342884)?anf_fun22342884.app(strip_DASH_loc_DASH_val253665.$var === D?U(L[465],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var):R.ffi.throwNonFunApp(L[466],anf_fun22342884,[strip_DASH_loc_DASH_val253665.$var === D?U(L[465],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var]);
};
try {
if(--R.GAS > 0) {
$z28762877 = $f28822883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28822883,
"from":L[466]});
}
} catch($e28742875) {
if(R.isCont($e28742875)) {
var $ss28782879 = {"from":L[466],
"go":function(anf_arg22352885) {
return $Hanf_arg36792886(anf_arg22352885,a_DASH_prim_DASH_app200559,dummy_DASH_loc115391,f5682872);
}};
$e28742875.stack[R.EXN_STACKHEIGHT++] = $ss28782879;
}
if(R.isPyretException($e28742875)) {
$e28742875.pyretStack.push(L[466]);
}
throw $e28742875;
}
var $ret28802881 = $Hanf_arg36792886($z28762877,a_DASH_prim_DASH_app200559,dummy_DASH_loc115391,f5682872);
++R.GAS;
return $ret28802881;
});
var anf_obj22402723 = R.makeFunction(function($underscore5702856,fields5712857) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[460],2,arguments);
}
var anf_fun22382868 = G(fields5712857,"map",L[463]);
var $z28602861 = D;
var $f28662867 = function(_) {
return R.isFunction(anf_fun22382868)?anf_fun22382868.app(strip_DASH_loc_DASH_field252663.$var === D?U(L[461],"strip-loc-field"):strip_DASH_loc_DASH_field252663.$var):R.ffi.throwNonFunApp(L[462],anf_fun22382868,[strip_DASH_loc_DASH_field252663.$var === D?U(L[461],"strip-loc-field"):strip_DASH_loc_DASH_field252663.$var]);
};
try {
if(--R.GAS > 0) {
$z28602861 = $f28662867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28662867,
"from":L[462]});
}
} catch($e28582859) {
if(R.isCont($e28582859)) {
var $ss28622863 = {"from":L[462],
"go":function(anf_arg22392869) {
return $Hanf_arg36812870(anf_arg22392869,a_DASH_obj202563,dummy_DASH_loc115391);
}};
$e28582859.stack[R.EXN_STACKHEIGHT++] = $ss28622863;
}
if(R.isPyretException($e28582859)) {
$e28582859.pyretStack.push(L[462]);
}
throw $e28582859;
}
var $ret28642865 = $Hanf_arg36812870($z28602861,a_DASH_obj202563,dummy_DASH_loc115391);
++R.GAS;
return $ret28642865;
});
var anf_obj22462724 = R.makeFunction(function($underscore5722839,supe5732840,fields5742841) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[456],3,arguments);
}
var ann_DASH_check_DASH_temp22412842 = R.makeFunction(function(arg_DASH_2862843) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[457],1,arguments);
}
var $z28462847 = D;
var $f28522853 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[458],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[458],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(supe5732840):R.ffi.throwNonFunApp(L[459],strip_DASH_loc_DASH_val253665.$var === D?U(L[458],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[supe5732840]);
};
try {
if(--R.GAS > 0) {
$z28462847 = $f28522853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28522853,
"from":L[459]});
}
} catch($e28442845) {
if(R.isCont($e28442845)) {
var $ss28482849 = {"from":L[459],
"go":function(anf_arg22432854) {
return $Hanf_arg36842855(anf_arg22432854,a_DASH_update204567,arg_DASH_2862843,fields5742841,strip_DASH_loc_DASH_field252663);
}};
$e28442845.stack[R.EXN_STACKHEIGHT++] = $ss28482849;
}
if(R.isPyretException($e28442845)) {
$e28442845.pyretStack.push(L[459]);
}
throw $e28442845;
}
var $ret28502851 = $Hanf_arg36842855($z28462847,a_DASH_update204567,arg_DASH_2862843,fields5742841,strip_DASH_loc_DASH_field252663);
++R.GAS;
return $ret28502851;
});
return ann_DASH_check_DASH_temp22412842;
});
var anf_obj22522725 = R.makeFunction(function($underscore5752822,supe5762823,fields5772824) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[452],3,arguments);
}
var ann_DASH_check_DASH_temp22472825 = R.makeFunction(function(arg_DASH_2872826) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[453],1,arguments);
}
var $z28292830 = D;
var $f28352836 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[454],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[454],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(supe5762823):R.ffi.throwNonFunApp(L[455],strip_DASH_loc_DASH_val253665.$var === D?U(L[454],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[supe5762823]);
};
try {
if(--R.GAS > 0) {
$z28292830 = $f28352836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28352836,
"from":L[455]});
}
} catch($e28272828) {
if(R.isCont($e28272828)) {
var $ss28312832 = {"from":L[455],
"go":function(anf_arg22492837) {
return $Hanf_arg36872838(anf_arg22492837,a_DASH_extend206571,arg_DASH_2872826,fields5772824,strip_DASH_loc_DASH_field252663);
}};
$e28272828.stack[R.EXN_STACKHEIGHT++] = $ss28312832;
}
if(R.isPyretException($e28272828)) {
$e28272828.pyretStack.push(L[455]);
}
throw $e28272828;
}
var $ret28332834 = $Hanf_arg36872838($z28292830,a_DASH_extend206571,arg_DASH_2872826,fields5772824,strip_DASH_loc_DASH_field252663);
++R.GAS;
return $ret28332834;
});
return ann_DASH_check_DASH_temp22472825;
});
var anf_obj22552726 = R.makeFunction(function($underscore5782807,obj5792808,field5802809) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[449],3,arguments);
}
var $z28122813 = D;
var $f28182819 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[450],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[450],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(obj5792808):R.ffi.throwNonFunApp(L[451],strip_DASH_loc_DASH_val253665.$var === D?U(L[450],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[obj5792808]);
};
try {
if(--R.GAS > 0) {
$z28122813 = $f28182819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28182819,
"from":L[451]});
}
} catch($e28102811) {
if(R.isCont($e28102811)) {
var $ss28142815 = {"from":L[451],
"go":function(anf_arg22542820) {
return $Hanf_arg36892821(anf_arg22542820,a_DASH_dot208575,dummy_DASH_loc115391,field5802809);
}};
$e28102811.stack[R.EXN_STACKHEIGHT++] = $ss28142815;
}
if(R.isPyretException($e28102811)) {
$e28102811.pyretStack.push(L[451]);
}
throw $e28102811;
}
var $ret28162817 = $Hanf_arg36892821($z28122813,a_DASH_dot208575,dummy_DASH_loc115391,field5802809);
++R.GAS;
return $ret28162817;
});
var anf_obj22582727 = R.makeFunction(function($underscore5812792,obj5822793,field5832794) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[446],3,arguments);
}
var $z27972798 = D;
var $f28032804 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[447],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[447],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(obj5822793):R.ffi.throwNonFunApp(L[448],strip_DASH_loc_DASH_val253665.$var === D?U(L[447],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[obj5822793]);
};
try {
if(--R.GAS > 0) {
$z27972798 = $f28032804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28032804,
"from":L[448]});
}
} catch($e27952796) {
if(R.isCont($e27952796)) {
var $ss27992800 = {"from":L[448],
"go":function(anf_arg22572805) {
return $Hanf_arg36912806(anf_arg22572805,a_DASH_colon210579,dummy_DASH_loc115391,field5832794);
}};
$e27952796.stack[R.EXN_STACKHEIGHT++] = $ss27992800;
}
if(R.isPyretException($e27952796)) {
$e27952796.pyretStack.push(L[448]);
}
throw $e27952796;
}
var $ret28012802 = $Hanf_arg36912806($z27972798,a_DASH_colon210579,dummy_DASH_loc115391,field5832794);
++R.GAS;
return $ret28012802;
});
var anf_obj22612728 = R.makeFunction(function($underscore5842777,obj5852778,field5862779) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[443],3,arguments);
}
var $z27822783 = D;
var $f27882789 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[444],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[444],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(obj5852778):R.ffi.throwNonFunApp(L[445],strip_DASH_loc_DASH_val253665.$var === D?U(L[444],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[obj5852778]);
};
try {
if(--R.GAS > 0) {
$z27822783 = $f27882789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27882789,
"from":L[445]});
}
} catch($e27802781) {
if(R.isCont($e27802781)) {
var $ss27842785 = {"from":L[445],
"go":function(anf_arg22602790) {
return $Hanf_arg36932791(anf_arg22602790,a_DASH_get_DASH_bang212583,dummy_DASH_loc115391,field5862779);
}};
$e27802781.stack[R.EXN_STACKHEIGHT++] = $ss27842785;
}
if(R.isPyretException($e27802781)) {
$e27802781.pyretStack.push(L[445]);
}
throw $e27802781;
}
var $ret27862787 = $Hanf_arg36932791($z27822783,a_DASH_get_DASH_bang212583,dummy_DASH_loc115391,field5862779);
++R.GAS;
return $ret27862787;
});
var anf_obj22642729 = R.makeFunction(function($underscore5872761,args5882762,ret5892763,body5902764) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[441],4,arguments);
}
var $z27672768 = D;
var $f27732774 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_expr249657.$var)?strip_DASH_loc_DASH_expr249657.$var.app(body5902764):R.ffi.throwNonFunApp(L[442],strip_DASH_loc_DASH_expr249657.$var,[body5902764]);
};
try {
if(--R.GAS > 0) {
$z27672768 = $f27732774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27732774,
"from":L[442]});
}
} catch($e27652766) {
if(R.isCont($e27652766)) {
var $ss27692770 = {"from":L[442],
"go":function(anf_arg22632775) {
return $Hanf_arg36952776(anf_arg22632775,a_DASH_lam214587,args5882762,dummy_DASH_loc115391,ret5892763);
}};
$e27652766.stack[R.EXN_STACKHEIGHT++] = $ss27692770;
}
if(R.isPyretException($e27652766)) {
$e27652766.pyretStack.push(L[442]);
}
throw $e27652766;
}
var $ret27712772 = $Hanf_arg36952776($z27672768,a_DASH_lam214587,args5882762,dummy_DASH_loc115391,ret5892763);
++R.GAS;
return $ret27712772;
});
var anf_obj22672730 = R.makeFunction(function($underscore5912745,args5922746,ret5932747,body5942748) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[439],4,arguments);
}
var $z27512752 = D;
var $f27572758 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_expr249657.$var)?strip_DASH_loc_DASH_expr249657.$var.app(body5942748):R.ffi.throwNonFunApp(L[440],strip_DASH_loc_DASH_expr249657.$var,[body5942748]);
};
try {
if(--R.GAS > 0) {
$z27512752 = $f27572758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27572758,
"from":L[440]});
}
} catch($e27492750) {
if(R.isCont($e27492750)) {
var $ss27532754 = {"from":L[440],
"go":function(anf_arg22662759) {
return $Hanf_arg36972760(anf_arg22662759,a_DASH_method216591,args5922746,dummy_DASH_loc115391,ret5932747);
}};
$e27492750.stack[R.EXN_STACKHEIGHT++] = $ss27532754;
}
if(R.isPyretException($e27492750)) {
$e27492750.pyretStack.push(L[440]);
}
throw $e27492750;
}
var $ret27552756 = $Hanf_arg36972760($z27512752,a_DASH_method216591,args5922746,dummy_DASH_loc115391,ret5932747);
++R.GAS;
return $ret27552756;
});
var anf_obj22702731 = R.makeFunction(function(v5952732) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[436],1,arguments);
}
var $z27352736 = D;
var $f27412742 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[437],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[437],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(v5952732):R.ffi.throwNonFunApp(L[438],strip_DASH_loc_DASH_val253665.$var === D?U(L[437],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[v5952732]);
};
try {
if(--R.GAS > 0) {
$z27352736 = $f27412742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27412742,
"from":L[438]});
}
} catch($e27332734) {
if(R.isCont($e27332734)) {
var $ss27372738 = {"from":L[438],
"go":function(anf_arg22692743) {
return $Hanf_arg36992744(anf_arg22692743,a_DASH_val218595);
}};
$e27332734.stack[R.EXN_STACKHEIGHT++] = $ss27372738;
}
if(R.isPyretException($e27332734)) {
$e27332734.pyretStack.push(L[438]);
}
throw $e27332734;
}
var $ret27392740 = $Hanf_arg36992744($z27352736,a_DASH_val218595);
++R.GAS;
return $ret27392740;
});
var anf_arg22712714 = R.makeObject({"a-module":anf_obj22242719,
"a-assign":anf_obj22272720,
"a-app":anf_obj22322721,
"a-prim-app":anf_obj22362722,
"a-obj":anf_obj22402723,
"a-update":anf_obj22462724,
"a-extend":anf_obj22522725,
"a-dot":anf_obj22552726,
"a-colon":anf_obj22582727,
"a-get-bang":anf_obj22612728,
"a-lam":anf_obj22642729,
"a-method":anf_obj22672730,
"a-val":anf_obj22702731});
var anf_arg22732715 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[435],0,arguments);
}
var ann_DASH_check_DASH_temp22722718 = R.throwNoBranchesMatched(L[435],("cases"));
return ann_DASH_check_DASH_temp22722718;
});
var $z27052706 = D;
var $f27112712 = function(_) {
return R.isFunction(anf_fun22132713)?anf_fun22132713.app(anf_arg22712714,anf_arg22732715):R.ffi.throwNonFunApp(L[434],anf_fun22132713,[anf_arg22712714,anf_arg22732715]);
};
try {
if(--R.GAS > 0) {
$z27052706 = $f27112712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27112712,
"from":L[434]});
}
} catch($e27032704) {
if(R.isCont($e27032704)) {
var $ss27072708 = {"from":L[434],
"go":function(ann_DASH_check_DASH_temp22122716) {
return $Hann_DASH_check_DASH_temp37002717(ann_DASH_check_DASH_temp22122716);
}};
$e27032704.stack[R.EXN_STACKHEIGHT++] = $ss27072708;
}
if(R.isPyretException($e27032704)) {
$e27032704.pyretStack.push(L[434]);
}
throw $e27032704;
}
var $ret27092710 = $Hann_DASH_check_DASH_temp37002717($z27052706);
++R.GAS;
return $ret27092710;
});
});
strip_DASH_loc_DASH_lettable251661.$var = anf_assign2274662;
var anf_assign2283664 = R.makeFunction(function(field5962668) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[428],1,arguments);
}
return R.checkAnnArgs([AField8667],[field5962668],[L[433]],function() {
var cases_DASH_val2892701 = field5962668;
var anf_fun22762679 = G(cases_DASH_val2892701,"_match",L[429]);
var anf_obj22792685 = R.makeFunction(function($underscore5972686,name5982687,value5992688) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[430],3,arguments);
}
var $z26912692 = D;
var $f26972698 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[431],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[431],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(value5992688):R.ffi.throwNonFunApp(L[432],strip_DASH_loc_DASH_val253665.$var === D?U(L[431],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[value5992688]);
};
try {
if(--R.GAS > 0) {
$z26912692 = $f26972698();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26972698,
"from":L[432]});
}
} catch($e26892690) {
if(R.isCont($e26892690)) {
var $ss26932694 = {"from":L[432],
"go":function(anf_arg22782699) {
return $Hanf_arg37022700(anf_arg22782699,a_DASH_field224607,dummy_DASH_loc115391,name5982687);
}};
$e26892690.stack[R.EXN_STACKHEIGHT++] = $ss26932694;
}
if(R.isPyretException($e26892690)) {
$e26892690.pyretStack.push(L[432]);
}
throw $e26892690;
}
var $ret26952696 = $Hanf_arg37022700($z26912692,a_DASH_field224607,dummy_DASH_loc115391,name5982687);
++R.GAS;
return $ret26952696;
});
var anf_arg22802680 = R.makeObject({"a-field":anf_obj22792685});
var anf_arg22822681 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[429],0,arguments);
}
var ann_DASH_check_DASH_temp22812684 = R.throwNoBranchesMatched(L[429],("cases"));
return ann_DASH_check_DASH_temp22812684;
});
var $z26712672 = D;
var $f26772678 = function(_) {
return R.isFunction(anf_fun22762679)?anf_fun22762679.app(anf_arg22802680,anf_arg22822681):R.ffi.throwNonFunApp(L[428],anf_fun22762679,[anf_arg22802680,anf_arg22822681]);
};
try {
if(--R.GAS > 0) {
$z26712672 = $f26772678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26772678,
"from":L[428]});
}
} catch($e26692670) {
if(R.isCont($e26692670)) {
var $ss26732674 = {"from":L[428],
"go":function(ann_DASH_check_DASH_temp22752682) {
return $Hann_DASH_check_DASH_temp37032683(ann_DASH_check_DASH_temp22752682);
}};
$e26692670.stack[R.EXN_STACKHEIGHT++] = $ss26732674;
}
if(R.isPyretException($e26692670)) {
$e26692670.pyretStack.push(L[428]);
}
throw $e26692670;
}
var $ret26752676 = $Hann_DASH_check_DASH_temp37032683($z26712672);
++R.GAS;
return $ret26752676;
});
});
strip_DASH_loc_DASH_field252663.$var = anf_assign2283664;
var anf_assign2307666 = R.makeFunction(function(val6002515) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[416],1,arguments);
}
return R.checkAnnArgs([AVal8881],[val6002515],[L[427]],function() {
var cases_DASH_val2902667 = val6002515;
var anf_fun22852526 = G(cases_DASH_val2902667,"_match",L[417]);
var anf_obj22872532 = R.makeFunction(function($underscore6012653,l6022654) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[426],2,arguments);
}
var $z26572658 = D;
var $f26632664 = function(_) {
return R.isFunction(a_DASH_srcloc229617.$var)?a_DASH_srcloc229617.$var.app(dummy_DASH_loc115391,l6022654):R.ffi.throwNonFunApp(L[426],a_DASH_srcloc229617.$var,[dummy_DASH_loc115391,l6022654]);
};
try {
if(--R.GAS > 0) {
$z26572658 = $f26632664();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26632664,
"from":L[426]});
}
} catch($e26552656) {
if(R.isCont($e26552656)) {
var $ss26592660 = {"from":L[426],
"go":function(ann_DASH_check_DASH_temp22862665) {
return $Hann_DASH_check_DASH_temp37042666(ann_DASH_check_DASH_temp22862665);
}};
$e26552656.stack[R.EXN_STACKHEIGHT++] = $ss26592660;
}
if(R.isPyretException($e26552656)) {
$e26552656.pyretStack.push(L[426]);
}
throw $e26552656;
}
var $ret26612662 = $Hann_DASH_check_DASH_temp37042666($z26572658);
++R.GAS;
return $ret26612662;
});
var anf_obj22892533 = R.makeFunction(function($underscore6032639,n6042640) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[425],2,arguments);
}
var $z26432644 = D;
var $f26492650 = function(_) {
return R.isFunction(a_DASH_num231621.$var)?a_DASH_num231621.$var.app(dummy_DASH_loc115391,n6042640):R.ffi.throwNonFunApp(L[425],a_DASH_num231621.$var,[dummy_DASH_loc115391,n6042640]);
};
try {
if(--R.GAS > 0) {
$z26432644 = $f26492650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26492650,
"from":L[425]});
}
} catch($e26412642) {
if(R.isCont($e26412642)) {
var $ss26452646 = {"from":L[425],
"go":function(ann_DASH_check_DASH_temp22882651) {
return $Hann_DASH_check_DASH_temp37052652(ann_DASH_check_DASH_temp22882651);
}};
$e26412642.stack[R.EXN_STACKHEIGHT++] = $ss26452646;
}
if(R.isPyretException($e26412642)) {
$e26412642.pyretStack.push(L[425]);
}
throw $e26412642;
}
var $ret26472648 = $Hann_DASH_check_DASH_temp37052652($z26432644);
++R.GAS;
return $ret26472648;
});
var anf_obj22912534 = R.makeFunction(function($underscore6052625,s6062626) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[424],2,arguments);
}
var $z26292630 = D;
var $f26352636 = function(_) {
return R.isFunction(a_DASH_str233625.$var)?a_DASH_str233625.$var.app(dummy_DASH_loc115391,s6062626):R.ffi.throwNonFunApp(L[424],a_DASH_str233625.$var,[dummy_DASH_loc115391,s6062626]);
};
try {
if(--R.GAS > 0) {
$z26292630 = $f26352636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26352636,
"from":L[424]});
}
} catch($e26272628) {
if(R.isCont($e26272628)) {
var $ss26312632 = {"from":L[424],
"go":function(ann_DASH_check_DASH_temp22902637) {
return $Hann_DASH_check_DASH_temp37062638(ann_DASH_check_DASH_temp22902637);
}};
$e26272628.stack[R.EXN_STACKHEIGHT++] = $ss26312632;
}
if(R.isPyretException($e26272628)) {
$e26272628.pyretStack.push(L[424]);
}
throw $e26272628;
}
var $ret26332634 = $Hann_DASH_check_DASH_temp37062638($z26292630);
++R.GAS;
return $ret26332634;
});
var anf_obj22932535 = R.makeFunction(function($underscore6072611,b6082612) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[423],2,arguments);
}
var $z26152616 = D;
var $f26212622 = function(_) {
return R.isFunction(a_DASH_bool235629.$var)?a_DASH_bool235629.$var.app(dummy_DASH_loc115391,b6082612):R.ffi.throwNonFunApp(L[423],a_DASH_bool235629.$var,[dummy_DASH_loc115391,b6082612]);
};
try {
if(--R.GAS > 0) {
$z26152616 = $f26212622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26212622,
"from":L[423]});
}
} catch($e26132614) {
if(R.isCont($e26132614)) {
var $ss26172618 = {"from":L[423],
"go":function(ann_DASH_check_DASH_temp22922623) {
return $Hann_DASH_check_DASH_temp37072624(ann_DASH_check_DASH_temp22922623);
}};
$e26132614.stack[R.EXN_STACKHEIGHT++] = $ss26172618;
}
if(R.isPyretException($e26132614)) {
$e26132614.pyretStack.push(L[423]);
}
throw $e26132614;
}
var $ret26192620 = $Hann_DASH_check_DASH_temp37072624($z26152616);
++R.GAS;
return $ret26192620;
});
var anf_obj22952536 = R.makeFunction(function($underscore6092597,vs6102598) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[422],2,arguments);
}
var $z26012602 = D;
var $f26072608 = function(_) {
return R.isFunction(a_DASH_array237633.$var)?a_DASH_array237633.$var.app(dummy_DASH_loc115391,vs6102598):R.ffi.throwNonFunApp(L[422],a_DASH_array237633.$var,[dummy_DASH_loc115391,vs6102598]);
};
try {
if(--R.GAS > 0) {
$z26012602 = $f26072608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26072608,
"from":L[422]});
}
} catch($e25992600) {
if(R.isCont($e25992600)) {
var $ss26032604 = {"from":L[422],
"go":function(ann_DASH_check_DASH_temp22942609) {
return $Hann_DASH_check_DASH_temp37082610(ann_DASH_check_DASH_temp22942609);
}};
$e25992600.stack[R.EXN_STACKHEIGHT++] = $ss26032604;
}
if(R.isPyretException($e25992600)) {
$e25992600.pyretStack.push(L[422]);
}
throw $e25992600;
}
var $ret26052606 = $Hann_DASH_check_DASH_temp37082610($z26012602);
++R.GAS;
return $ret26052606;
});
var anf_obj22972537 = R.makeFunction(function($underscore6112584) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[421],1,arguments);
}
var $z25872588 = D;
var $f25932594 = function(_) {
return R.isFunction(a_DASH_undefined239637.$var)?a_DASH_undefined239637.$var.app(dummy_DASH_loc115391):R.ffi.throwNonFunApp(L[421],a_DASH_undefined239637.$var,[dummy_DASH_loc115391]);
};
try {
if(--R.GAS > 0) {
$z25872588 = $f25932594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25932594,
"from":L[421]});
}
} catch($e25852586) {
if(R.isCont($e25852586)) {
var $ss25892590 = {"from":L[421],
"go":function(ann_DASH_check_DASH_temp22962595) {
return $Hann_DASH_check_DASH_temp37092596(ann_DASH_check_DASH_temp22962595);
}};
$e25852586.stack[R.EXN_STACKHEIGHT++] = $ss25892590;
}
if(R.isPyretException($e25852586)) {
$e25852586.pyretStack.push(L[421]);
}
throw $e25852586;
}
var $ret25912592 = $Hann_DASH_check_DASH_temp37092596($z25872588);
++R.GAS;
return $ret25912592;
});
var anf_obj22992538 = R.makeFunction(function($underscore6122570,id6132571) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[420],2,arguments);
}
var $z25742575 = D;
var $f25802581 = function(_) {
return R.isFunction(a_DASH_id241641.$var)?a_DASH_id241641.$var.app(dummy_DASH_loc115391,id6132571):R.ffi.throwNonFunApp(L[420],a_DASH_id241641.$var,[dummy_DASH_loc115391,id6132571]);
};
try {
if(--R.GAS > 0) {
$z25742575 = $f25802581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25802581,
"from":L[420]});
}
} catch($e25722573) {
if(R.isCont($e25722573)) {
var $ss25762577 = {"from":L[420],
"go":function(ann_DASH_check_DASH_temp22982582) {
return $Hann_DASH_check_DASH_temp37102583(ann_DASH_check_DASH_temp22982582);
}};
$e25722573.stack[R.EXN_STACKHEIGHT++] = $ss25762577;
}
if(R.isPyretException($e25722573)) {
$e25722573.pyretStack.push(L[420]);
}
throw $e25722573;
}
var $ret25782579 = $Hann_DASH_check_DASH_temp37102583($z25742575);
++R.GAS;
return $ret25782579;
});
var anf_obj23012539 = R.makeFunction(function($underscore6142556,id6152557) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[419],2,arguments);
}
var $z25602561 = D;
var $f25662567 = function(_) {
return R.isFunction(a_DASH_id_DASH_var243645.$var)?a_DASH_id_DASH_var243645.$var.app(dummy_DASH_loc115391,id6152557):R.ffi.throwNonFunApp(L[419],a_DASH_id_DASH_var243645.$var,[dummy_DASH_loc115391,id6152557]);
};
try {
if(--R.GAS > 0) {
$z25602561 = $f25662567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25662567,
"from":L[419]});
}
} catch($e25582559) {
if(R.isCont($e25582559)) {
var $ss25622563 = {"from":L[419],
"go":function(ann_DASH_check_DASH_temp23002568) {
return $Hann_DASH_check_DASH_temp37112569(ann_DASH_check_DASH_temp23002568);
}};
$e25582559.stack[R.EXN_STACKHEIGHT++] = $ss25622563;
}
if(R.isPyretException($e25582559)) {
$e25582559.pyretStack.push(L[419]);
}
throw $e25582559;
}
var $ret25642565 = $Hann_DASH_check_DASH_temp37112569($z25602561);
++R.GAS;
return $ret25642565;
});
var anf_obj23032540 = R.makeFunction(function($underscore6162541,id6172542,safe6182543) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[418],3,arguments);
}
var $z25462547 = D;
var $f25522553 = function(_) {
return R.isFunction(a_DASH_id_DASH_letrec245649.$var)?a_DASH_id_DASH_letrec245649.$var.app(dummy_DASH_loc115391,id6172542,safe6182543):R.ffi.throwNonFunApp(L[418],a_DASH_id_DASH_letrec245649.$var,[dummy_DASH_loc115391,id6172542,safe6182543]);
};
try {
if(--R.GAS > 0) {
$z25462547 = $f25522553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25522553,
"from":L[418]});
}
} catch($e25442545) {
if(R.isCont($e25442545)) {
var $ss25482549 = {"from":L[418],
"go":function(ann_DASH_check_DASH_temp23022554) {
return $Hann_DASH_check_DASH_temp37122555(ann_DASH_check_DASH_temp23022554);
}};
$e25442545.stack[R.EXN_STACKHEIGHT++] = $ss25482549;
}
if(R.isPyretException($e25442545)) {
$e25442545.pyretStack.push(L[418]);
}
throw $e25442545;
}
var $ret25502551 = $Hann_DASH_check_DASH_temp37122555($z25462547);
++R.GAS;
return $ret25502551;
});
var anf_arg23042527 = R.makeObject({"a-srcloc":anf_obj22872532,
"a-num":anf_obj22892533,
"a-str":anf_obj22912534,
"a-bool":anf_obj22932535,
"a-array":anf_obj22952536,
"a-undefined":anf_obj22972537,
"a-id":anf_obj22992538,
"a-id-var":anf_obj23012539,
"a-id-letrec":anf_obj23032540});
var anf_arg23062528 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[417],0,arguments);
}
var ann_DASH_check_DASH_temp23052531 = R.throwNoBranchesMatched(L[417],("cases"));
return ann_DASH_check_DASH_temp23052531;
});
var $z25182519 = D;
var $f25242525 = function(_) {
return R.isFunction(anf_fun22852526)?anf_fun22852526.app(anf_arg23042527,anf_arg23062528):R.ffi.throwNonFunApp(L[416],anf_fun22852526,[anf_arg23042527,anf_arg23062528]);
};
try {
if(--R.GAS > 0) {
$z25182519 = $f25242525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25242525,
"from":L[416]});
}
} catch($e25162517) {
if(R.isCont($e25162517)) {
var $ss25202521 = {"from":L[416],
"go":function(ann_DASH_check_DASH_temp22842529) {
return $Hann_DASH_check_DASH_temp37132530(ann_DASH_check_DASH_temp22842529);
}};
$e25162517.stack[R.EXN_STACKHEIGHT++] = $ss25202521;
}
if(R.isPyretException($e25162517)) {
$e25162517.pyretStack.push(L[416]);
}
throw $e25162517;
}
var $ret25222523 = $Hann_DASH_check_DASH_temp37132530($z25182519);
++R.GAS;
return $ret25222523;
});
});
strip_DASH_loc_DASH_val253665.$var = anf_assign2307666;
var anf_obj23151618 = R.makeMethod(function(self6202507) {
return function(l6212510,answer6222514,provides6232511,types6242512,checks6252509) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[415],5,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,AVal8881,List1788,AVal8881],[l6212510,answer6222514,provides6232511,types6242512,checks6252509],[L[410],L[411],L[412],L[413],L[414]],function() {
var anf_fun23092506 = G(answer6222514,"visit",L[409]);
var $z24982499 = D;
var $f25042505 = function(_) {
return R.isFunction(anf_fun23092506)?anf_fun23092506.app(self6202507):R.ffi.throwNonFunApp(L[408],anf_fun23092506,[self6202507]);
};
try {
if(--R.GAS > 0) {
$z24982499 = $f25042505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25042505,
"from":L[408]});
}
} catch($e24962497) {
if(R.isCont($e24962497)) {
var $ss25002501 = {"from":L[408],
"go":function(anf_arg23102508) {
return $Hanf_arg37172513(anf_arg23102508,a_DASH_module192543,checks6252509,l6212510,provides6232511,self6202507,types6242512);
}};
$e24962497.stack[R.EXN_STACKHEIGHT++] = $ss25002501;
}
if(R.isPyretException($e24962497)) {
$e24962497.pyretStack.push(L[408]);
}
throw $e24962497;
}
var $ret25022503 = $Hanf_arg37172513($z24982499,a_DASH_module192543,checks6252509,l6212510,provides6232511,self6202507,types6242512);
++R.GAS;
return $ret25022503;
});
};
},{"length":6});
var anf_obj23241619 = R.makeMethod(function(self6262479) {
return function(l6272478,imports6282495,body6292477) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[407],3,arguments);
}
return R.checkAnnArgs([Loc9089,List1788,AExpr7465],[l6272478,imports6282495,body6292477],[L[404],L[405],L[406]],function() {
var anf_fun23172474 = G(imports6282495,"map",L[403]);
var anf_arg23202475 = R.makeFunction(function(recv_DASH_2912481) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[402],1,arguments);
}
var anf_fun23192492 = G(recv_DASH_2912481,"visit",L[402]);
var $z24842485 = D;
var $f24902491 = function(_) {
return R.isFunction(anf_fun23192492)?anf_fun23192492.app(self6262479):R.ffi.throwNonFunApp(L[402],anf_fun23192492,[self6262479]);
};
try {
if(--R.GAS > 0) {
$z24842485 = $f24902491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24902491,
"from":L[402]});
}
} catch($e24822483) {
if(R.isCont($e24822483)) {
var $ss24862487 = {"from":L[402],
"go":function(ann_DASH_check_DASH_temp23182493) {
return $Hann_DASH_check_DASH_temp37182494(ann_DASH_check_DASH_temp23182493);
}};
$e24822483.stack[R.EXN_STACKHEIGHT++] = $ss24862487;
}
if(R.isPyretException($e24822483)) {
$e24822483.pyretStack.push(L[402]);
}
throw $e24822483;
}
var $ret24882489 = $Hann_DASH_check_DASH_temp37182494($z24842485);
++R.GAS;
return $ret24882489;
});
var $z24662467 = D;
var $f24722473 = function(_) {
return R.isFunction(anf_fun23172474)?anf_fun23172474.app(anf_arg23202475):R.ffi.throwNonFunApp(L[401],anf_fun23172474,[anf_arg23202475]);
};
try {
if(--R.GAS > 0) {
$z24662467 = $f24722473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24722473,
"from":L[401]});
}
} catch($e24642465) {
if(R.isCont($e24642465)) {
var $ss24682469 = {"from":L[401],
"go":function(anf_arg23212476) {
return $Hanf_arg37212480(anf_arg23212476,a_DASH_program121401,body6292477,l6272478,self6262479);
}};
$e24642465.stack[R.EXN_STACKHEIGHT++] = $ss24682469;
}
if(R.isPyretException($e24642465)) {
$e24642465.pyretStack.push(L[401]);
}
throw $e24642465;
}
var $ret24702471 = $Hanf_arg37212480($z24662467,a_DASH_program121401,body6292477,l6272478,self6262479);
++R.GAS;
return $ret24702471;
});
};
},{"length":4});
var anf_obj23301620 = R.makeMethod(function(self6302458) {
return function(l6312460,import_DASH_type6322463,name6332461) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[400],3,arguments);
}
return R.checkAnnArgs([Loc9089,AImportType6871,R.getDotAnn(L[397],"A",A244,"Name")],[l6312460,import_DASH_type6322463,name6332461],[L[398],L[399],L[397]],function() {
var anf_fun23262457 = G(import_DASH_type6322463,"visit",L[396]);
var $z24492450 = D;
var $f24552456 = function(_) {
return R.isFunction(anf_fun23262457)?anf_fun23262457.app(self6302458):R.ffi.throwNonFunApp(L[395],anf_fun23262457,[self6302458]);
};
try {
if(--R.GAS > 0) {
$z24492450 = $f24552456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24552456,
"from":L[395]});
}
} catch($e24472448) {
if(R.isCont($e24472448)) {
var $ss24512452 = {"from":L[395],
"go":function(anf_arg23272459) {
return $Hanf_arg37242462(anf_arg23272459,a_DASH_import133425,l6312460,name6332461,self6302458);
}};
$e24472448.stack[R.EXN_STACKHEIGHT++] = $ss24512452;
}
if(R.isPyretException($e24472448)) {
$e24472448.pyretStack.push(L[395]);
}
throw $e24472448;
}
var $ret24532454 = $Hanf_arg37242462($z24492450,a_DASH_import133425,l6312460,name6332461,self6302458);
++R.GAS;
return $ret24532454;
});
};
},{"length":4});
var anf_obj23381621 = R.makeMethod(function(self6342440) {
return function(l6352442,import_DASH_type6362446,name6372443,types6382444) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[394],4,arguments);
}
return R.checkAnnArgs([Loc9089,AImportType6871,R.getDotAnn(L[390],"A",A244,"NAme"),R.getDotAnn(L[391],"A",A244,"Name")],[l6352442,import_DASH_type6362446,name6372443,types6382444],[L[392],L[393],L[390],L[391]],function() {
var anf_fun23322439 = G(import_DASH_type6362446,"visit",L[389]);
var $z24312432 = D;
var $f24372438 = function(_) {
return R.isFunction(anf_fun23322439)?anf_fun23322439.app(self6342440):R.ffi.throwNonFunApp(L[388],anf_fun23322439,[self6342440]);
};
try {
if(--R.GAS > 0) {
$z24312432 = $f24372438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24372438,
"from":L[388]});
}
} catch($e24292430) {
if(R.isCont($e24292430)) {
var $ss24332434 = {"from":L[388],
"go":function(anf_arg23332441) {
return $Hanf_arg37282445(anf_arg23332441,a_DASH_import_DASH_types135429,l6352442,name6372443,self6342440,types6382444);
}};
$e24292430.stack[R.EXN_STACKHEIGHT++] = $ss24332434;
}
if(R.isPyretException($e24292430)) {
$e24292430.pyretStack.push(L[388]);
}
throw $e24292430;
}
var $ret24352436 = $Hanf_arg37282445($z24312432,a_DASH_import_DASH_types135429,l6352442,name6372443,self6342440,types6382444);
++R.GAS;
return $ret24352436;
});
};
},{"length":5});
var anf_obj23401622 = R.makeMethod(function(self6392428) {
return function(l6402423,file6412424,name6422425) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[384],3,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,R.getDotAnn(L[385],"A",A244,"Name")],[l6402423,file6412424,name6422425],[L[386],L[387],L[385]],function() {
var $z24152416 = D;
var $f24212422 = function(_) {
return R.isFunction(a_DASH_import_DASH_file128415.$var)?a_DASH_import_DASH_file128415.$var.app(l6402423,file6412424,name6422425):R.ffi.throwNonFunApp(L[384],a_DASH_import_DASH_file128415.$var,[l6402423,file6412424,name6422425]);
};
try {
if(--R.GAS > 0) {
$z24152416 = $f24212422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24212422,
"from":L[384]});
}
} catch($e24132414) {
if(R.isCont($e24132414)) {
var $ss24172418 = {"from":L[384],
"go":function(ann_DASH_check_DASH_temp23392426) {
return $Hann_DASH_check_DASH_temp37292427(ann_DASH_check_DASH_temp23392426);
}};
$e24132414.stack[R.EXN_STACKHEIGHT++] = $ss24172418;
}
if(R.isPyretException($e24132414)) {
$e24132414.pyretStack.push(L[384]);
}
throw $e24132414;
}
var $ret24192420 = $Hann_DASH_check_DASH_temp37292427($z24152416);
++R.GAS;
return $ret24192420;
});
};
},{"length":4});
var anf_obj23421623 = R.makeMethod(function(self6432412) {
return function(l6442407,lib6452408,name6462409) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[380],3,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,R.getDotAnn(L[381],"A",A244,"Name")],[l6442407,lib6452408,name6462409],[L[382],L[383],L[381]],function() {
var $z23992400 = D;
var $f24052406 = function(_) {
return R.isFunction(a_DASH_import_DASH_builtin126411.$var)?a_DASH_import_DASH_builtin126411.$var.app(l6442407,lib6452408,name6462409):R.ffi.throwNonFunApp(L[380],a_DASH_import_DASH_builtin126411.$var,[l6442407,lib6452408,name6462409]);
};
try {
if(--R.GAS > 0) {
$z23992400 = $f24052406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24052406,
"from":L[380]});
}
} catch($e23972398) {
if(R.isCont($e23972398)) {
var $ss24012402 = {"from":L[380],
"go":function(ann_DASH_check_DASH_temp23412410) {
return $Hann_DASH_check_DASH_temp37302411(ann_DASH_check_DASH_temp23412410);
}};
$e23972398.stack[R.EXN_STACKHEIGHT++] = $ss24012402;
}
if(R.isPyretException($e23972398)) {
$e23972398.pyretStack.push(L[380]);
}
throw $e23972398;
}
var $ret24032404 = $Hann_DASH_check_DASH_temp37302411($z23992400);
++R.GAS;
return $ret24032404;
});
};
},{"length":4});
var anf_obj23441624 = R.makeMethod(function(self6472396) {
return function(l6482391,name6492392,ann6502393) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[379],3,arguments);
}
var $z23832384 = D;
var $f23892390 = function(_) {
return R.isFunction(a_DASH_type_DASH_bind140439.$var)?a_DASH_type_DASH_bind140439.$var.app(l6482391,name6492392,ann6502393):R.ffi.throwNonFunApp(L[379],a_DASH_type_DASH_bind140439.$var,[l6482391,name6492392,ann6502393]);
};
try {
if(--R.GAS > 0) {
$z23832384 = $f23892390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23892390,
"from":L[379]});
}
} catch($e23812382) {
if(R.isCont($e23812382)) {
var $ss23852386 = {"from":L[379],
"go":function(ann_DASH_check_DASH_temp23432394) {
return $Hann_DASH_check_DASH_temp37312395(ann_DASH_check_DASH_temp23432394);
}};
$e23812382.stack[R.EXN_STACKHEIGHT++] = $ss23852386;
}
if(R.isPyretException($e23812382)) {
$e23812382.pyretStack.push(L[379]);
}
throw $e23812382;
}
var $ret23872388 = $Hann_DASH_check_DASH_temp37312395($z23832384);
++R.GAS;
return $ret23872388;
};
},{"length":4});
var anf_obj23461625 = R.makeMethod(function(self6512380) {
return function(l6522375,name6532376,nameb6542377) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[378],3,arguments);
}
var $z23672368 = D;
var $f23732374 = function(_) {
return R.isFunction(a_DASH_newtype_DASH_bind142443.$var)?a_DASH_newtype_DASH_bind142443.$var.app(l6522375,name6532376,nameb6542377):R.ffi.throwNonFunApp(L[378],a_DASH_newtype_DASH_bind142443.$var,[l6522375,name6532376,nameb6542377]);
};
try {
if(--R.GAS > 0) {
$z23672368 = $f23732374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23732374,
"from":L[378]});
}
} catch($e23652366) {
if(R.isCont($e23652366)) {
var $ss23692370 = {"from":L[378],
"go":function(ann_DASH_check_DASH_temp23452378) {
return $Hann_DASH_check_DASH_temp37322379(ann_DASH_check_DASH_temp23452378);
}};
$e23652366.stack[R.EXN_STACKHEIGHT++] = $ss23692370;
}
if(R.isPyretException($e23652366)) {
$e23652366.pyretStack.push(L[378]);
}
throw $e23652366;
}
var $ret23712372 = $Hann_DASH_check_DASH_temp37322379($z23672368);
++R.GAS;
return $ret23712372;
};
},{"length":4});
var anf_obj23521626 = R.makeMethod(function(self6552359) {
return function(l6562362,bind6572364,body6582361) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[377],3,arguments);
}
var anf_fun23482358 = G(bind6572364,"visit",L[376]);
var $z23502351 = D;
var $f23562357 = function(_) {
return R.isFunction(anf_fun23482358)?anf_fun23482358.app(self6552359):R.ffi.throwNonFunApp(L[375],anf_fun23482358,[self6552359]);
};
try {
if(--R.GAS > 0) {
$z23502351 = $f23562357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23562357,
"from":L[375]});
}
} catch($e23482349) {
if(R.isCont($e23482349)) {
var $ss23522353 = {"from":L[375],
"go":function(anf_arg23492360) {
return $Hanf_arg37352363(anf_arg23492360,a_DASH_type_DASH_let147453,body6582361,l6562362,self6552359);
}};
$e23482349.stack[R.EXN_STACKHEIGHT++] = $ss23522353;
}
if(R.isPyretException($e23482349)) {
$e23482349.pyretStack.push(L[375]);
}
throw $e23482349;
}
var $ret23542355 = $Hanf_arg37352363($z23502351,a_DASH_type_DASH_let147453,body6582361,l6562362,self6552359);
++R.GAS;
return $ret23542355;
};
},{"length":4});
var anf_obj23601627 = R.makeMethod(function(self6592341) {
return function(l6602345,bind6612347,e6622344,body6632343) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[374],4,arguments);
}
return R.checkAnnArgs([Loc9089,ABind7663,ALettable8473,AExpr7465],[l6602345,bind6612347,e6622344,body6632343],[L[370],L[371],L[372],L[373]],function() {
var anf_fun23542340 = G(bind6612347,"visit",L[369]);
var $z23322333 = D;
var $f23382339 = function(_) {
return R.isFunction(anf_fun23542340)?anf_fun23542340.app(self6592341):R.ffi.throwNonFunApp(L[368],anf_fun23542340,[self6592341]);
};
try {
if(--R.GAS > 0) {
$z23322333 = $f23382339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23382339,
"from":L[368]});
}
} catch($e23302331) {
if(R.isCont($e23302331)) {
var $ss23342335 = {"from":L[368],
"go":function(anf_arg23552342) {
return $Hanf_arg37392346(anf_arg23552342,a_DASH_let149457,body6632343,e6622344,l6602345,self6592341);
}};
$e23302331.stack[R.EXN_STACKHEIGHT++] = $ss23342335;
}
if(R.isPyretException($e23302331)) {
$e23302331.pyretStack.push(L[368]);
}
throw $e23302331;
}
var $ret23362337 = $Hanf_arg37392346($z23322333,a_DASH_let149457,body6632343,e6622344,l6602345,self6592341);
++R.GAS;
return $ret23362337;
});
};
},{"length":5});
var anf_obj23681628 = R.makeMethod(function(self6642323) {
return function(l6652327,bind6662329,e6672326,body6682325) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[367],4,arguments);
}
return R.checkAnnArgs([Loc9089,ABind7663,ALettable8473,AExpr7465],[l6652327,bind6662329,e6672326,body6682325],[L[363],L[364],L[365],L[366]],function() {
var anf_fun23622322 = G(bind6662329,"visit",L[362]);
var $z23142315 = D;
var $f23202321 = function(_) {
return R.isFunction(anf_fun23622322)?anf_fun23622322.app(self6642323):R.ffi.throwNonFunApp(L[361],anf_fun23622322,[self6642323]);
};
try {
if(--R.GAS > 0) {
$z23142315 = $f23202321();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23202321,
"from":L[361]});
}
} catch($e23122313) {
if(R.isCont($e23122313)) {
var $ss23162317 = {"from":L[361],
"go":function(anf_arg23632324) {
return $Hanf_arg37432328(anf_arg23632324,a_DASH_var151461,body6682325,e6672326,l6652327,self6642323);
}};
$e23122313.stack[R.EXN_STACKHEIGHT++] = $ss23162317;
}
if(R.isPyretException($e23122313)) {
$e23122313.pyretStack.push(L[361]);
}
throw $e23122313;
}
var $ret23182319 = $Hanf_arg37432328($z23142315,a_DASH_var151461,body6682325,e6672326,l6652327,self6642323);
++R.GAS;
return $ret23182319;
});
};
},{"length":5});
var anf_obj23741629 = R.makeMethod(function(self6692306) {
return function(l6702309,e16712311,e26722308) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[360],3,arguments);
}
return R.checkAnnArgs([Loc9089,ALettable8473,AExpr7465],[l6702309,e16712311,e26722308],[L[357],L[358],L[359]],function() {
var anf_fun23702305 = G(e16712311,"visit",L[356]);
var $z22972298 = D;
var $f23032304 = function(_) {
return R.isFunction(anf_fun23702305)?anf_fun23702305.app(self6692306):R.ffi.throwNonFunApp(L[355],anf_fun23702305,[self6692306]);
};
try {
if(--R.GAS > 0) {
$z22972298 = $f23032304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23032304,
"from":L[355]});
}
} catch($e22952296) {
if(R.isCont($e22952296)) {
var $ss22992300 = {"from":L[355],
"go":function(anf_arg23712307) {
return $Hanf_arg37462310(anf_arg23712307,a_DASH_seq153465,e26722308,l6702309,self6692306);
}};
$e22952296.stack[R.EXN_STACKHEIGHT++] = $ss22992300;
}
if(R.isPyretException($e22952296)) {
$e22952296.pyretStack.push(L[355]);
}
throw $e22952296;
}
var $ret23012302 = $Hanf_arg37462310($z22972298,a_DASH_seq153465,e26722308,l6702309,self6692306);
++R.GAS;
return $ret23012302;
});
};
},{"length":4});
var anf_obj23861630 = R.makeMethod(function(self6732277) {
return function(l6742274,name6752275,namet6762276,variants6772294,shared6782278) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[354],5,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,R.getDotAnn(L[349],"A",A244,"Name"),List1788,List1788],[l6742274,name6752275,namet6762276,variants6772294,shared6782278],[L[350],L[351],L[349],L[352],L[353]],function() {
var anf_fun23762271 = G(variants6772294,"map",L[348]);
var anf_arg23792272 = R.makeFunction(function(recv_DASH_2922280) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[347],1,arguments);
}
var anf_fun23782291 = G(recv_DASH_2922280,"visit",L[347]);
var $z22832284 = D;
var $f22892290 = function(_) {
return R.isFunction(anf_fun23782291)?anf_fun23782291.app(self6732277):R.ffi.throwNonFunApp(L[347],anf_fun23782291,[self6732277]);
};
try {
if(--R.GAS > 0) {
$z22832284 = $f22892290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22892290,
"from":L[347]});
}
} catch($e22812282) {
if(R.isCont($e22812282)) {
var $ss22852286 = {"from":L[347],
"go":function(ann_DASH_check_DASH_temp23772292) {
return $Hann_DASH_check_DASH_temp37472293(ann_DASH_check_DASH_temp23772292);
}};
$e22812282.stack[R.EXN_STACKHEIGHT++] = $ss22852286;
}
if(R.isPyretException($e22812282)) {
$e22812282.pyretStack.push(L[347]);
}
throw $e22812282;
}
var $ret22872288 = $Hann_DASH_check_DASH_temp37472293($z22832284);
++R.GAS;
return $ret22872288;
});
var $z22632264 = D;
var $f22692270 = function(_) {
return R.isFunction(anf_fun23762271)?anf_fun23762271.app(anf_arg23792272):R.ffi.throwNonFunApp(L[346],anf_fun23762271,[anf_arg23792272]);
};
try {
if(--R.GAS > 0) {
$z22632264 = $f22692270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22692270,
"from":L[346]});
}
} catch($e22612262) {
if(R.isCont($e22612262)) {
var $ss22652266 = {"from":L[346],
"go":function(anf_arg23802273) {
return $Hanf_arg37512279(anf_arg23802273,a_DASH_data_DASH_expr194547,l6742274,name6752275,namet6762276,self6732277,shared6782278);
}};
$e22612262.stack[R.EXN_STACKHEIGHT++] = $ss22652266;
}
if(R.isPyretException($e22612262)) {
$e22612262.pyretStack.push(L[346]);
}
throw $e22612262;
}
var $ret22672268 = $Hanf_arg37512279($z22632264,a_DASH_data_DASH_expr194547,l6742274,name6752275,namet6762276,self6732277,shared6782278);
++R.GAS;
return $ret22672268;
});
};
},{"length":6});
var anf_obj23981631 = R.makeMethod(function(self6792243) {
return function(l6802241,constr_DASH_loc6812240,name6822242,members6832260,with_DASH_members6842244) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[345],5,arguments);
}
return R.checkAnnArgs([Loc9089,Loc9089,$type$String35,List1788,List1788],[l6802241,constr_DASH_loc6812240,name6822242,members6832260,with_DASH_members6842244],[L[340],L[341],L[342],L[343],L[344]],function() {
var anf_fun23882237 = G(members6832260,"map",L[339]);
var anf_arg23912238 = R.makeFunction(function(recv_DASH_2942246) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[338],1,arguments);
}
var anf_fun23902257 = G(recv_DASH_2942246,"visit",L[338]);
var $z22492250 = D;
var $f22552256 = function(_) {
return R.isFunction(anf_fun23902257)?anf_fun23902257.app(self6792243):R.ffi.throwNonFunApp(L[338],anf_fun23902257,[self6792243]);
};
try {
if(--R.GAS > 0) {
$z22492250 = $f22552256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22552256,
"from":L[338]});
}
} catch($e22472248) {
if(R.isCont($e22472248)) {
var $ss22512252 = {"from":L[338],
"go":function(ann_DASH_check_DASH_temp23892258) {
return $Hann_DASH_check_DASH_temp37522259(ann_DASH_check_DASH_temp23892258);
}};
$e22472248.stack[R.EXN_STACKHEIGHT++] = $ss22512252;
}
if(R.isPyretException($e22472248)) {
$e22472248.pyretStack.push(L[338]);
}
throw $e22472248;
}
var $ret22532254 = $Hann_DASH_check_DASH_temp37522259($z22492250);
++R.GAS;
return $ret22532254;
});
var $z22292230 = D;
var $f22352236 = function(_) {
return R.isFunction(anf_fun23882237)?anf_fun23882237.app(anf_arg23912238):R.ffi.throwNonFunApp(L[337],anf_fun23882237,[anf_arg23912238]);
};
try {
if(--R.GAS > 0) {
$z22292230 = $f22352236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22352236,
"from":L[337]});
}
} catch($e22272228) {
if(R.isCont($e22272228)) {
var $ss22312232 = {"from":L[337],
"go":function(anf_arg23922239) {
return $Hanf_arg37562245(anf_arg23922239,a_DASH_variant171501,constr_DASH_loc6812240,l6802241,name6822242,self6792243,with_DASH_members6842244);
}};
$e22272228.stack[R.EXN_STACKHEIGHT++] = $ss22312232;
}
if(R.isPyretException($e22272228)) {
$e22272228.pyretStack.push(L[337]);
}
throw $e22272228;
}
var $ret22332234 = $Hanf_arg37562245($z22292230,a_DASH_variant171501,constr_DASH_loc6812240,l6802241,name6822242,self6792243,with_DASH_members6842244);
++R.GAS;
return $ret22332234;
});
};
},{"length":6});
var anf_obj24051632 = R.makeMethod(function(self6852223) {
return function(l6862208,name6872209,with_DASH_members6882226) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[336],3,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,List1788],[l6862208,name6872209,with_DASH_members6882226],[L[333],L[334],L[335]],function() {
var anf_fun24002205 = G(with_DASH_members6882226,"map",L[332]);
var anf_arg24032206 = R.makeFunction(function(recv_DASH_2962211) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[331],1,arguments);
}
var anf_fun24022222 = G(recv_DASH_2962211,"visit",L[331]);
var $z22142215 = D;
var $f22202221 = function(_) {
return R.isFunction(anf_fun24022222)?anf_fun24022222.app(self6852223):R.ffi.throwNonFunApp(L[331],anf_fun24022222,[self6852223]);
};
try {
if(--R.GAS > 0) {
$z22142215 = $f22202221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22202221,
"from":L[331]});
}
} catch($e22122213) {
if(R.isCont($e22122213)) {
var $ss22162217 = {"from":L[331],
"go":function(ann_DASH_check_DASH_temp24012224) {
return $Hann_DASH_check_DASH_temp37572225(ann_DASH_check_DASH_temp24012224);
}};
$e22122213.stack[R.EXN_STACKHEIGHT++] = $ss22162217;
}
if(R.isPyretException($e22122213)) {
$e22122213.pyretStack.push(L[331]);
}
throw $e22122213;
}
var $ret22182219 = $Hann_DASH_check_DASH_temp37572225($z22142215);
++R.GAS;
return $ret22182219;
});
var $z21972198 = D;
var $f22032204 = function(_) {
return R.isFunction(anf_fun24002205)?anf_fun24002205.app(anf_arg24032206):R.ffi.throwNonFunApp(L[330],anf_fun24002205,[anf_arg24032206]);
};
try {
if(--R.GAS > 0) {
$z21972198 = $f22032204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22032204,
"from":L[330]});
}
} catch($e21952196) {
if(R.isCont($e21952196)) {
var $ss21992200 = {"from":L[330],
"go":function(anf_arg24042207) {
return $Hanf_arg37592210(anf_arg24042207,a_DASH_singleton_DASH_variant173505,l6862208,name6872209);
}};
$e21952196.stack[R.EXN_STACKHEIGHT++] = $ss21992200;
}
if(R.isPyretException($e21952196)) {
$e21952196.pyretStack.push(L[330]);
}
throw $e21952196;
}
var $ret22012202 = $Hanf_arg37592210($z21972198,a_DASH_singleton_DASH_variant173505,l6862208,name6872209);
++R.GAS;
return $ret22012202;
});
};
},{"length":4});
var anf_obj24091633 = R.makeMethod(function(self6892189) {
return function(l6902191,member_DASH_type6912192,bind6922194) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[329],3,arguments);
}
return R.checkAnnArgs([Loc9089,AMemberType8075,ABind7663],[l6902191,member_DASH_type6912192,bind6922194],[L[326],L[327],L[328]],function() {
var anf_fun24072188 = G(bind6922194,"visit",L[325]);
var $z21802181 = D;
var $f21862187 = function(_) {
return R.isFunction(anf_fun24072188)?anf_fun24072188.app(self6892189):R.ffi.throwNonFunApp(L[324],anf_fun24072188,[self6892189]);
};
try {
if(--R.GAS > 0) {
$z21802181 = $f21862187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21862187,
"from":L[324]});
}
} catch($e21782179) {
if(R.isCont($e21782179)) {
var $ss21822183 = {"from":L[324],
"go":function(anf_arg24082190) {
return $Hanf_arg37612193(anf_arg24082190,a_DASH_variant_DASH_member187533,l6902191,member_DASH_type6912192);
}};
$e21782179.stack[R.EXN_STACKHEIGHT++] = $ss21822183;
}
if(R.isPyretException($e21782179)) {
$e21782179.pyretStack.push(L[324]);
}
throw $e21782179;
}
var $ret21842185 = $Hanf_arg37612193($z21802181,a_DASH_variant_DASH_member187533,l6902191,member_DASH_type6912192);
++R.GAS;
return $ret21842185;
});
};
},{"length":4});
var anf_obj24181634 = R.makeMethod(function(self6932172) {
return function(l6942175,_fun6952177,args6962174) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[323],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,List1788],[l6942175,_fun6952177,args6962174],[L[320],L[321],L[322]],function() {
var anf_fun24112171 = G(_fun6952177,"visit",L[319]);
var $z21632164 = D;
var $f21692170 = function(_) {
return R.isFunction(anf_fun24112171)?anf_fun24112171.app(self6932172):R.ffi.throwNonFunApp(L[318],anf_fun24112171,[self6932172]);
};
try {
if(--R.GAS > 0) {
$z21632164 = $f21692170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21692170,
"from":L[318]});
}
} catch($e21612162) {
if(R.isCont($e21612162)) {
var $ss21652166 = {"from":L[318],
"go":function(anf_arg24122173) {
return $Hanf_arg37652176(anf_arg24122173,a_DASH_tail_DASH_app155469,args6962174,l6942175,self6932172);
}};
$e21612162.stack[R.EXN_STACKHEIGHT++] = $ss21652166;
}
if(R.isPyretException($e21612162)) {
$e21612162.pyretStack.push(L[318]);
}
throw $e21612162;
}
var $ret21672168 = $Hanf_arg37652176($z21632164,a_DASH_tail_DASH_app155469,args6962174,l6942175,self6932172);
++R.GAS;
return $ret21672168;
});
};
},{"length":4});
var anf_obj24321635 = R.makeMethod(function(self6972152) {
return function(l6982158,is_DASH_var6992157,f7002160,args7012154,helper7022156,helper_DASH_args7032155) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[317],6,arguments);
}
return R.checkAnnArgs([Loc9089,$type$Boolean33,AVal8881,List1788,$type$String35,List1788],[l6982158,is_DASH_var6992157,f7002160,args7012154,helper7022156,helper_DASH_args7032155],[L[311],L[312],L[313],L[314],L[315],L[316]],function() {
var anf_fun24202151 = G(f7002160,"visit",L[310]);
var $z21432144 = D;
var $f21492150 = function(_) {
return R.isFunction(anf_fun24202151)?anf_fun24202151.app(self6972152):R.ffi.throwNonFunApp(L[309],anf_fun24202151,[self6972152]);
};
try {
if(--R.GAS > 0) {
$z21432144 = $f21492150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21492150,
"from":L[309]});
}
} catch($e21412142) {
if(R.isCont($e21412142)) {
var $ss21452146 = {"from":L[309],
"go":function(anf_arg24212153) {
return $Hanf_arg37712159(anf_arg24212153,a_DASH_split_DASH_app157473,args7012154,helper_DASH_args7032155,helper7022156,is_DASH_var6992157,l6982158,self6972152);
}};
$e21412142.stack[R.EXN_STACKHEIGHT++] = $ss21452146;
}
if(R.isPyretException($e21412142)) {
$e21412142.pyretStack.push(L[309]);
}
throw $e21412142;
}
var $ret21472148 = $Hanf_arg37712159($z21432144,a_DASH_split_DASH_app157473,args7012154,helper_DASH_args7032155,helper7022156,is_DASH_var6992157,l6982158,self6972152);
++R.GAS;
return $ret21472148;
});
};
},{"length":7});
var anf_obj24401636 = R.makeMethod(function(self7042134) {
return function(l7052137,c7062140,t7072138,e7082136) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[308],4,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,AExpr7465,AExpr7465],[l7052137,c7062140,t7072138,e7082136],[L[304],L[305],L[306],L[307]],function() {
var anf_fun24342133 = G(c7062140,"visit",L[303]);
var $z21252126 = D;
var $f21312132 = function(_) {
return R.isFunction(anf_fun24342133)?anf_fun24342133.app(self7042134):R.ffi.throwNonFunApp(L[302],anf_fun24342133,[self7042134]);
};
try {
if(--R.GAS > 0) {
$z21252126 = $f21312132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21312132,
"from":L[302]});
}
} catch($e21232124) {
if(R.isCont($e21232124)) {
var $ss21272128 = {"from":L[302],
"go":function(anf_arg24352135) {
return $Hanf_arg37752139(anf_arg24352135,a_DASH_if159477,e7082136,l7052137,self7042134,t7072138);
}};
$e21232124.stack[R.EXN_STACKHEIGHT++] = $ss21272128;
}
if(R.isPyretException($e21232124)) {
$e21232124.pyretStack.push(L[302]);
}
throw $e21232124;
}
var $ret21292130 = $Hanf_arg37752139($z21252126,a_DASH_if159477,e7082136,l7052137,self7042134,t7072138);
++R.GAS;
return $ret21292130;
});
};
},{"length":5});
var anf_obj24441637 = R.makeMethod(function(self7092119) {
return function(e7102122) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[301],1,arguments);
}
return R.checkAnnArgs([ALettable8473],[e7102122],[L[300]],function() {
var anf_fun24422118 = G(e7102122,"visit",L[299]);
var $z21102111 = D;
var $f21162117 = function(_) {
return R.isFunction(anf_fun24422118)?anf_fun24422118.app(self7092119):R.ffi.throwNonFunApp(L[298],anf_fun24422118,[self7092119]);
};
try {
if(--R.GAS > 0) {
$z21102111 = $f21162117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21162117,
"from":L[298]});
}
} catch($e21082109) {
if(R.isCont($e21082109)) {
var $ss21122113 = {"from":L[298],
"go":function(anf_arg24432120) {
return $Hanf_arg37772121(anf_arg24432120,a_DASH_lettable161481);
}};
$e21082109.stack[R.EXN_STACKHEIGHT++] = $ss21122113;
}
if(R.isPyretException($e21082109)) {
$e21082109.pyretStack.push(L[298]);
}
throw $e21082109;
}
var $ret21142115 = $Hanf_arg37772121($z21102111,a_DASH_lettable161481);
++R.GAS;
return $ret21142115;
});
};
},{"length":2});
var anf_obj24481638 = R.makeMethod(function(self7112102) {
return function(l7122105,id7132104,value7142107) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[297],3,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[294],"A",A244,"Name"),AVal8881],[l7122105,id7132104,value7142107],[L[295],L[294],L[296]],function() {
var anf_fun24462101 = G(value7142107,"visit",L[293]);
var $z20932094 = D;
var $f20992100 = function(_) {
return R.isFunction(anf_fun24462101)?anf_fun24462101.app(self7112102):R.ffi.throwNonFunApp(L[292],anf_fun24462101,[self7112102]);
};
try {
if(--R.GAS > 0) {
$z20932094 = $f20992100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20992100,
"from":L[292]});
}
} catch($e20912092) {
if(R.isCont($e20912092)) {
var $ss20952096 = {"from":L[292],
"go":function(anf_arg24472103) {
return $Hanf_arg37792106(anf_arg24472103,a_DASH_assign196551,id7132104,l7122105);
}};
$e20912092.stack[R.EXN_STACKHEIGHT++] = $ss20952096;
}
if(R.isPyretException($e20912092)) {
$e20912092.pyretStack.push(L[292]);
}
throw $e20912092;
}
var $ret20972098 = $Hanf_arg37792106($z20932094,a_DASH_assign196551,id7132104,l7122105);
++R.GAS;
return $ret20972098;
});
};
},{"length":4});
var anf_obj24571639 = R.makeMethod(function(self7152085) {
return function(l7162088,_fun7172090,args7182087) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[291],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,List1788],[l7162088,_fun7172090,args7182087],[L[288],L[289],L[290]],function() {
var anf_fun24502084 = G(_fun7172090,"visit",L[287]);
var $z20762077 = D;
var $f20822083 = function(_) {
return R.isFunction(anf_fun24502084)?anf_fun24502084.app(self7152085):R.ffi.throwNonFunApp(L[286],anf_fun24502084,[self7152085]);
};
try {
if(--R.GAS > 0) {
$z20762077 = $f20822083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20822083,
"from":L[286]});
}
} catch($e20742075) {
if(R.isCont($e20742075)) {
var $ss20782079 = {"from":L[286],
"go":function(anf_arg24512086) {
return $Hanf_arg37832089(anf_arg24512086,a_DASH_app198555,args7182087,l7162088,self7152085);
}};
$e20742075.stack[R.EXN_STACKHEIGHT++] = $ss20782079;
}
if(R.isPyretException($e20742075)) {
$e20742075.pyretStack.push(L[286]);
}
throw $e20742075;
}
var $ret20802081 = $Hanf_arg37832089($z20762077,a_DASH_app198555,args7182087,l7162088,self7152085);
++R.GAS;
return $ret20802081;
});
};
},{"length":4});
var anf_obj24641640 = R.makeMethod(function(self7192070) {
return function(l7202056,f7212055,args7222073) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[285],3,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,List1788],[l7202056,f7212055,args7222073],[L[282],L[283],L[284]],function() {
var anf_fun24592052 = G(args7222073,"map",L[281]);
var anf_arg24622053 = R.makeFunction(function(recv_DASH_3012058) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[280],1,arguments);
}
var anf_fun24612069 = G(recv_DASH_3012058,"visit",L[280]);
var $z20612062 = D;
var $f20672068 = function(_) {
return R.isFunction(anf_fun24612069)?anf_fun24612069.app(self7192070):R.ffi.throwNonFunApp(L[280],anf_fun24612069,[self7192070]);
};
try {
if(--R.GAS > 0) {
$z20612062 = $f20672068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20672068,
"from":L[280]});
}
} catch($e20592060) {
if(R.isCont($e20592060)) {
var $ss20632064 = {"from":L[280],
"go":function(ann_DASH_check_DASH_temp24602071) {
return $Hann_DASH_check_DASH_temp37842072(ann_DASH_check_DASH_temp24602071);
}};
$e20592060.stack[R.EXN_STACKHEIGHT++] = $ss20632064;
}
if(R.isPyretException($e20592060)) {
$e20592060.pyretStack.push(L[280]);
}
throw $e20592060;
}
var $ret20652066 = $Hann_DASH_check_DASH_temp37842072($z20612062);
++R.GAS;
return $ret20652066;
});
var $z20442045 = D;
var $f20502051 = function(_) {
return R.isFunction(anf_fun24592052)?anf_fun24592052.app(anf_arg24622053):R.ffi.throwNonFunApp(L[279],anf_fun24592052,[anf_arg24622053]);
};
try {
if(--R.GAS > 0) {
$z20442045 = $f20502051();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20502051,
"from":L[279]});
}
} catch($e20422043) {
if(R.isCont($e20422043)) {
var $ss20462047 = {"from":L[279],
"go":function(anf_arg24632054) {
return $Hanf_arg37862057(anf_arg24632054,a_DASH_prim_DASH_app200559,f7212055,l7202056);
}};
$e20422043.stack[R.EXN_STACKHEIGHT++] = $ss20462047;
}
if(R.isPyretException($e20422043)) {
$e20422043.pyretStack.push(L[279]);
}
throw $e20422043;
}
var $ret20482049 = $Hanf_arg37862057($z20442045,a_DASH_prim_DASH_app200559,f7212055,l7202056);
++R.GAS;
return $ret20482049;
});
};
},{"length":4});
var anf_obj24711641 = R.makeMethod(function(self7232038) {
return function(l7242024,fields7252041) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[278],2,arguments);
}
return R.checkAnnArgs([Loc9089,List1788],[l7242024,fields7252041],[L[276],L[277]],function() {
var anf_fun24662021 = G(fields7252041,"map",L[275]);
var anf_arg24692022 = R.makeFunction(function(recv_DASH_3022026) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[274],1,arguments);
}
var anf_fun24682037 = G(recv_DASH_3022026,"visit",L[274]);
var $z20292030 = D;
var $f20352036 = function(_) {
return R.isFunction(anf_fun24682037)?anf_fun24682037.app(self7232038):R.ffi.throwNonFunApp(L[274],anf_fun24682037,[self7232038]);
};
try {
if(--R.GAS > 0) {
$z20292030 = $f20352036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20352036,
"from":L[274]});
}
} catch($e20272028) {
if(R.isCont($e20272028)) {
var $ss20312032 = {"from":L[274],
"go":function(ann_DASH_check_DASH_temp24672039) {
return $Hann_DASH_check_DASH_temp37872040(ann_DASH_check_DASH_temp24672039);
}};
$e20272028.stack[R.EXN_STACKHEIGHT++] = $ss20312032;
}
if(R.isPyretException($e20272028)) {
$e20272028.pyretStack.push(L[274]);
}
throw $e20272028;
}
var $ret20332034 = $Hann_DASH_check_DASH_temp37872040($z20292030);
++R.GAS;
return $ret20332034;
});
var $z20132014 = D;
var $f20192020 = function(_) {
return R.isFunction(anf_fun24662021)?anf_fun24662021.app(anf_arg24692022):R.ffi.throwNonFunApp(L[273],anf_fun24662021,[anf_arg24692022]);
};
try {
if(--R.GAS > 0) {
$z20132014 = $f20192020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20192020,
"from":L[273]});
}
} catch($e20112012) {
if(R.isCont($e20112012)) {
var $ss20152016 = {"from":L[273],
"go":function(anf_arg24702023) {
return $Hanf_arg37892025(anf_arg24702023,a_DASH_obj202563,l7242024);
}};
$e20112012.stack[R.EXN_STACKHEIGHT++] = $ss20152016;
}
if(R.isPyretException($e20112012)) {
$e20112012.pyretStack.push(L[273]);
}
throw $e20112012;
}
var $ret20172018 = $Hanf_arg37892025($z20132014,a_DASH_obj202563,l7242024);
++R.GAS;
return $ret20172018;
});
};
},{"length":3});
var anf_obj24801642 = R.makeMethod(function(self7262005) {
return function(l7272008,supe7282010,fields7292007) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[272],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,List1788],[l7272008,supe7282010,fields7292007],[L[269],L[270],L[271]],function() {
var anf_fun24732004 = G(supe7282010,"visit",L[268]);
var $z19961997 = D;
var $f20022003 = function(_) {
return R.isFunction(anf_fun24732004)?anf_fun24732004.app(self7262005):R.ffi.throwNonFunApp(L[267],anf_fun24732004,[self7262005]);
};
try {
if(--R.GAS > 0) {
$z19961997 = $f20022003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20022003,
"from":L[267]});
}
} catch($e19941995) {
if(R.isCont($e19941995)) {
var $ss19981999 = {"from":L[267],
"go":function(anf_arg24742006) {
return $Hanf_arg37932009(anf_arg24742006,a_DASH_update204567,fields7292007,l7272008,self7262005);
}};
$e19941995.stack[R.EXN_STACKHEIGHT++] = $ss19981999;
}
if(R.isPyretException($e19941995)) {
$e19941995.pyretStack.push(L[267]);
}
throw $e19941995;
}
var $ret20002001 = $Hanf_arg37932009($z19961997,a_DASH_update204567,fields7292007,l7272008,self7262005);
++R.GAS;
return $ret20002001;
});
};
},{"length":4});
var anf_obj24891643 = R.makeMethod(function(self7301988) {
return function(l7311991,supe7321993,fields7331990) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[266],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,List1788],[l7311991,supe7321993,fields7331990],[L[263],L[264],L[265]],function() {
var anf_fun24821987 = G(supe7321993,"visit",L[262]);
var $z19791980 = D;
var $f19851986 = function(_) {
return R.isFunction(anf_fun24821987)?anf_fun24821987.app(self7301988):R.ffi.throwNonFunApp(L[261],anf_fun24821987,[self7301988]);
};
try {
if(--R.GAS > 0) {
$z19791980 = $f19851986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19851986,
"from":L[261]});
}
} catch($e19771978) {
if(R.isCont($e19771978)) {
var $ss19811982 = {"from":L[261],
"go":function(anf_arg24831989) {
return $Hanf_arg37971992(anf_arg24831989,a_DASH_extend206571,fields7331990,l7311991,self7301988);
}};
$e19771978.stack[R.EXN_STACKHEIGHT++] = $ss19811982;
}
if(R.isPyretException($e19771978)) {
$e19771978.pyretStack.push(L[261]);
}
throw $e19771978;
}
var $ret19831984 = $Hanf_arg37971992($z19791980,a_DASH_extend206571,fields7331990,l7311991,self7301988);
++R.GAS;
return $ret19831984;
});
};
},{"length":4});
var anf_obj24931644 = R.makeMethod(function(self7341971) {
return function(l7351974,obj7361976,field7371973) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[260],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,$type$String35],[l7351974,obj7361976,field7371973],[L[257],L[258],L[259]],function() {
var anf_fun24911970 = G(obj7361976,"visit",L[256]);
var $z19621963 = D;
var $f19681969 = function(_) {
return R.isFunction(anf_fun24911970)?anf_fun24911970.app(self7341971):R.ffi.throwNonFunApp(L[255],anf_fun24911970,[self7341971]);
};
try {
if(--R.GAS > 0) {
$z19621963 = $f19681969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19681969,
"from":L[255]});
}
} catch($e19601961) {
if(R.isCont($e19601961)) {
var $ss19641965 = {"from":L[255],
"go":function(anf_arg24921972) {
return $Hanf_arg37991975(anf_arg24921972,a_DASH_dot208575,field7371973,l7351974);
}};
$e19601961.stack[R.EXN_STACKHEIGHT++] = $ss19641965;
}
if(R.isPyretException($e19601961)) {
$e19601961.pyretStack.push(L[255]);
}
throw $e19601961;
}
var $ret19661967 = $Hanf_arg37991975($z19621963,a_DASH_dot208575,field7371973,l7351974);
++R.GAS;
return $ret19661967;
});
};
},{"length":4});
var anf_obj24971645 = R.makeMethod(function(self7381954) {
return function(l7391957,obj7401959,field7411956) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[254],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,$type$String35],[l7391957,obj7401959,field7411956],[L[251],L[252],L[253]],function() {
var anf_fun24951953 = G(obj7401959,"visit",L[250]);
var $z19451946 = D;
var $f19511952 = function(_) {
return R.isFunction(anf_fun24951953)?anf_fun24951953.app(self7381954):R.ffi.throwNonFunApp(L[249],anf_fun24951953,[self7381954]);
};
try {
if(--R.GAS > 0) {
$z19451946 = $f19511952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19511952,
"from":L[249]});
}
} catch($e19431944) {
if(R.isCont($e19431944)) {
var $ss19471948 = {"from":L[249],
"go":function(anf_arg24961955) {
return $Hanf_arg38011958(anf_arg24961955,a_DASH_colon210579,field7411956,l7391957);
}};
$e19431944.stack[R.EXN_STACKHEIGHT++] = $ss19471948;
}
if(R.isPyretException($e19431944)) {
$e19431944.pyretStack.push(L[249]);
}
throw $e19431944;
}
var $ret19491950 = $Hanf_arg38011958($z19451946,a_DASH_colon210579,field7411956,l7391957);
++R.GAS;
return $ret19491950;
});
};
},{"length":4});
var anf_obj25011646 = R.makeMethod(function(self7421937) {
return function(l7431940,obj7441942,field7451939) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[248],3,arguments);
}
return R.checkAnnArgs([Loc9089,AVal8881,$type$String35],[l7431940,obj7441942,field7451939],[L[245],L[246],L[247]],function() {
var anf_fun24991936 = G(obj7441942,"visit",L[244]);
var $z19281929 = D;
var $f19341935 = function(_) {
return R.isFunction(anf_fun24991936)?anf_fun24991936.app(self7421937):R.ffi.throwNonFunApp(L[243],anf_fun24991936,[self7421937]);
};
try {
if(--R.GAS > 0) {
$z19281929 = $f19341935();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19341935,
"from":L[243]});
}
} catch($e19261927) {
if(R.isCont($e19261927)) {
var $ss19301931 = {"from":L[243],
"go":function(anf_arg25001938) {
return $Hanf_arg38031941(anf_arg25001938,a_DASH_get_DASH_bang212583,field7451939,l7431940);
}};
$e19261927.stack[R.EXN_STACKHEIGHT++] = $ss19301931;
}
if(R.isPyretException($e19261927)) {
$e19261927.pyretStack.push(L[243]);
}
throw $e19261927;
}
var $ret19321933 = $Hanf_arg38031941($z19281929,a_DASH_get_DASH_bang212583,field7451939,l7431940);
++R.GAS;
return $ret19321933;
});
};
},{"length":4});
var anf_obj25101647 = R.makeMethod(function(self7461909) {
return function(l7471907,args7481925,ret7491908,body7501906) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[242],4,arguments);
}
return R.checkAnnArgs([Loc9089,List1788,R.getDotAnn(L[238],"A",A244,"Ann"),AExpr7465],[l7471907,args7481925,ret7491908,body7501906],[L[239],L[240],L[238],L[241]],function() {
var anf_fun25031903 = G(args7481925,"map",L[237]);
var anf_arg25061904 = R.makeFunction(function(recv_DASH_3051911) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[236],1,arguments);
}
var anf_fun25051922 = G(recv_DASH_3051911,"visit",L[236]);
var $z19141915 = D;
var $f19201921 = function(_) {
return R.isFunction(anf_fun25051922)?anf_fun25051922.app(self7461909):R.ffi.throwNonFunApp(L[236],anf_fun25051922,[self7461909]);
};
try {
if(--R.GAS > 0) {
$z19141915 = $f19201921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19201921,
"from":L[236]});
}
} catch($e19121913) {
if(R.isCont($e19121913)) {
var $ss19161917 = {"from":L[236],
"go":function(ann_DASH_check_DASH_temp25041923) {
return $Hann_DASH_check_DASH_temp38041924(ann_DASH_check_DASH_temp25041923);
}};
$e19121913.stack[R.EXN_STACKHEIGHT++] = $ss19161917;
}
if(R.isPyretException($e19121913)) {
$e19121913.pyretStack.push(L[236]);
}
throw $e19121913;
}
var $ret19181919 = $Hann_DASH_check_DASH_temp38041924($z19141915);
++R.GAS;
return $ret19181919;
});
var $z18951896 = D;
var $f19011902 = function(_) {
return R.isFunction(anf_fun25031903)?anf_fun25031903.app(anf_arg25061904):R.ffi.throwNonFunApp(L[235],anf_fun25031903,[anf_arg25061904]);
};
try {
if(--R.GAS > 0) {
$z18951896 = $f19011902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19011902,
"from":L[235]});
}
} catch($e18931894) {
if(R.isCont($e18931894)) {
var $ss18971898 = {"from":L[235],
"go":function(anf_arg25071905) {
return $Hanf_arg38071910(anf_arg25071905,a_DASH_lam214587,body7501906,l7471907,ret7491908,self7461909);
}};
$e18931894.stack[R.EXN_STACKHEIGHT++] = $ss18971898;
}
if(R.isPyretException($e18931894)) {
$e18931894.pyretStack.push(L[235]);
}
throw $e18931894;
}
var $ret18991900 = $Hanf_arg38071910($z18951896,a_DASH_lam214587,body7501906,l7471907,ret7491908,self7461909);
++R.GAS;
return $ret18991900;
});
};
},{"length":5});
var anf_obj25191648 = R.makeMethod(function(self7511876) {
return function(l7521874,args7531892,ret7541875,body7551873) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[234],4,arguments);
}
return R.checkAnnArgs([Loc9089,List1788,R.getDotAnn(L[230],"A",A244,"Ann"),AExpr7465],[l7521874,args7531892,ret7541875,body7551873],[L[231],L[232],L[230],L[233]],function() {
var anf_fun25121870 = G(args7531892,"map",L[229]);
var anf_arg25151871 = R.makeFunction(function(recv_DASH_3061878) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[228],1,arguments);
}
var anf_fun25141889 = G(recv_DASH_3061878,"visit",L[228]);
var $z18811882 = D;
var $f18871888 = function(_) {
return R.isFunction(anf_fun25141889)?anf_fun25141889.app(self7511876):R.ffi.throwNonFunApp(L[228],anf_fun25141889,[self7511876]);
};
try {
if(--R.GAS > 0) {
$z18811882 = $f18871888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18871888,
"from":L[228]});
}
} catch($e18791880) {
if(R.isCont($e18791880)) {
var $ss18831884 = {"from":L[228],
"go":function(ann_DASH_check_DASH_temp25131890) {
return $Hann_DASH_check_DASH_temp38081891(ann_DASH_check_DASH_temp25131890);
}};
$e18791880.stack[R.EXN_STACKHEIGHT++] = $ss18831884;
}
if(R.isPyretException($e18791880)) {
$e18791880.pyretStack.push(L[228]);
}
throw $e18791880;
}
var $ret18851886 = $Hann_DASH_check_DASH_temp38081891($z18811882);
++R.GAS;
return $ret18851886;
});
var $z18621863 = D;
var $f18681869 = function(_) {
return R.isFunction(anf_fun25121870)?anf_fun25121870.app(anf_arg25151871):R.ffi.throwNonFunApp(L[227],anf_fun25121870,[anf_arg25151871]);
};
try {
if(--R.GAS > 0) {
$z18621863 = $f18681869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18681869,
"from":L[227]});
}
} catch($e18601861) {
if(R.isCont($e18601861)) {
var $ss18641865 = {"from":L[227],
"go":function(anf_arg25161872) {
return $Hanf_arg38111877(anf_arg25161872,a_DASH_method216591,body7551873,l7521874,ret7541875,self7511876);
}};
$e18601861.stack[R.EXN_STACKHEIGHT++] = $ss18641865;
}
if(R.isPyretException($e18601861)) {
$e18601861.pyretStack.push(L[227]);
}
throw $e18601861;
}
var $ret18661867 = $Hanf_arg38111877($z18621863,a_DASH_method216591,body7551873,l7521874,ret7541875,self7511876);
++R.GAS;
return $ret18661867;
});
};
},{"length":5});
var anf_obj25231649 = R.makeMethod(function(self7561856) {
return function(v7571859) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[226],1,arguments);
}
return R.checkAnnArgs([AVal8881],[v7571859],[L[225]],function() {
var anf_fun25211855 = G(v7571859,"visit",L[224]);
var $z18471848 = D;
var $f18531854 = function(_) {
return R.isFunction(anf_fun25211855)?anf_fun25211855.app(self7561856):R.ffi.throwNonFunApp(L[223],anf_fun25211855,[self7561856]);
};
try {
if(--R.GAS > 0) {
$z18471848 = $f18531854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18531854,
"from":L[223]});
}
} catch($e18451846) {
if(R.isCont($e18451846)) {
var $ss18491850 = {"from":L[223],
"go":function(anf_arg25221857) {
return $Hanf_arg38131858(anf_arg25221857,a_DASH_val218595);
}};
$e18451846.stack[R.EXN_STACKHEIGHT++] = $ss18491850;
}
if(R.isPyretException($e18451846)) {
$e18451846.pyretStack.push(L[223]);
}
throw $e18451846;
}
var $ret18511852 = $Hanf_arg38131858($z18471848,a_DASH_val218595);
++R.GAS;
return $ret18511852;
});
};
},{"length":2});
var anf_obj25251650 = R.makeMethod(function(self7581844) {
return function(l7591839,id7601840,ann7611841) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[219],3,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[220],"A",A244,"Name"),R.getDotAnn(L[221],"A",A244,"Ann")],[l7591839,id7601840,ann7611841],[L[222],L[220],L[221]],function() {
var $z18311832 = D;
var $f18371838 = function(_) {
return R.isFunction(a_DASH_bind166491.$var)?a_DASH_bind166491.$var.app(l7591839,id7601840,ann7611841):R.ffi.throwNonFunApp(L[219],a_DASH_bind166491.$var,[l7591839,id7601840,ann7611841]);
};
try {
if(--R.GAS > 0) {
$z18311832 = $f18371838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18371838,
"from":L[219]});
}
} catch($e18291830) {
if(R.isCont($e18291830)) {
var $ss18331834 = {"from":L[219],
"go":function(ann_DASH_check_DASH_temp25241842) {
return $Hann_DASH_check_DASH_temp38141843(ann_DASH_check_DASH_temp25241842);
}};
$e18291830.stack[R.EXN_STACKHEIGHT++] = $ss18331834;
}
if(R.isPyretException($e18291830)) {
$e18291830.pyretStack.push(L[219]);
}
throw $e18291830;
}
var $ret18351836 = $Hann_DASH_check_DASH_temp38141843($z18311832);
++R.GAS;
return $ret18351836;
});
};
},{"length":4});
var anf_obj25291651 = R.makeMethod(function(self7621823) {
return function(l7631825,name7641826,value7651828) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[218],3,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35,AVal8881],[l7631825,name7641826,value7651828],[L[215],L[216],L[217]],function() {
var anf_fun25271822 = G(value7651828,"visit",L[214]);
var $z18141815 = D;
var $f18201821 = function(_) {
return R.isFunction(anf_fun25271822)?anf_fun25271822.app(self7621823):R.ffi.throwNonFunApp(L[213],anf_fun25271822,[self7621823]);
};
try {
if(--R.GAS > 0) {
$z18141815 = $f18201821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18201821,
"from":L[213]});
}
} catch($e18121813) {
if(R.isCont($e18121813)) {
var $ss18161817 = {"from":L[213],
"go":function(anf_arg25281824) {
return $Hanf_arg38161827(anf_arg25281824,a_DASH_field224607,l7631825,name7641826);
}};
$e18121813.stack[R.EXN_STACKHEIGHT++] = $ss18161817;
}
if(R.isPyretException($e18121813)) {
$e18121813.pyretStack.push(L[213]);
}
throw $e18121813;
}
var $ret18181819 = $Hanf_arg38161827($z18141815,a_DASH_field224607,l7631825,name7641826);
++R.GAS;
return $ret18181819;
});
};
},{"length":4});
var anf_obj25311652 = R.makeMethod(function(self7661811) {
return function(l7671807,loc7681808) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[212],2,arguments);
}
var $z17991800 = D;
var $f18051806 = function(_) {
return R.isFunction(a_DASH_srcloc229617.$var)?a_DASH_srcloc229617.$var.app(l7671807,loc7681808):R.ffi.throwNonFunApp(L[212],a_DASH_srcloc229617.$var,[l7671807,loc7681808]);
};
try {
if(--R.GAS > 0) {
$z17991800 = $f18051806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18051806,
"from":L[212]});
}
} catch($e17971798) {
if(R.isCont($e17971798)) {
var $ss18011802 = {"from":L[212],
"go":function(ann_DASH_check_DASH_temp25301809) {
return $Hann_DASH_check_DASH_temp38171810(ann_DASH_check_DASH_temp25301809);
}};
$e17971798.stack[R.EXN_STACKHEIGHT++] = $ss18011802;
}
if(R.isPyretException($e17971798)) {
$e17971798.pyretStack.push(L[212]);
}
throw $e17971798;
}
var $ret18031804 = $Hann_DASH_check_DASH_temp38171810($z17991800);
++R.GAS;
return $ret18031804;
};
},{"length":3});
var anf_obj25331653 = R.makeMethod(function(self7691796) {
return function(l7701792,n7711793) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[209],2,arguments);
}
return R.checkAnnArgs([Loc9089,$type$Number34],[l7701792,n7711793],[L[210],L[211]],function() {
var $z17841785 = D;
var $f17901791 = function(_) {
return R.isFunction(a_DASH_num231621.$var)?a_DASH_num231621.$var.app(l7701792,n7711793):R.ffi.throwNonFunApp(L[209],a_DASH_num231621.$var,[l7701792,n7711793]);
};
try {
if(--R.GAS > 0) {
$z17841785 = $f17901791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17901791,
"from":L[209]});
}
} catch($e17821783) {
if(R.isCont($e17821783)) {
var $ss17861787 = {"from":L[209],
"go":function(ann_DASH_check_DASH_temp25321794) {
return $Hann_DASH_check_DASH_temp38181795(ann_DASH_check_DASH_temp25321794);
}};
$e17821783.stack[R.EXN_STACKHEIGHT++] = $ss17861787;
}
if(R.isPyretException($e17821783)) {
$e17821783.pyretStack.push(L[209]);
}
throw $e17821783;
}
var $ret17881789 = $Hann_DASH_check_DASH_temp38181795($z17841785);
++R.GAS;
return $ret17881789;
});
};
},{"length":3});
var anf_obj25401654 = R.makeMethod(function(self7721778) {
return function(l7731764,vals7741781) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[208],2,arguments);
}
return R.checkAnnArgs([Loc9089,List1788],[l7731764,vals7741781],[L[206],L[207]],function() {
var anf_fun25351761 = G(vals7741781,"map",L[205]);
var anf_arg25381762 = R.makeFunction(function(recv_DASH_3071766) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[204],1,arguments);
}
var anf_fun25371777 = G(recv_DASH_3071766,"visit",L[204]);
var $z17691770 = D;
var $f17751776 = function(_) {
return R.isFunction(anf_fun25371777)?anf_fun25371777.app(self7721778):R.ffi.throwNonFunApp(L[204],anf_fun25371777,[self7721778]);
};
try {
if(--R.GAS > 0) {
$z17691770 = $f17751776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17751776,
"from":L[204]});
}
} catch($e17671768) {
if(R.isCont($e17671768)) {
var $ss17711772 = {"from":L[204],
"go":function(ann_DASH_check_DASH_temp25361779) {
return $Hann_DASH_check_DASH_temp38191780(ann_DASH_check_DASH_temp25361779);
}};
$e17671768.stack[R.EXN_STACKHEIGHT++] = $ss17711772;
}
if(R.isPyretException($e17671768)) {
$e17671768.pyretStack.push(L[204]);
}
throw $e17671768;
}
var $ret17731774 = $Hann_DASH_check_DASH_temp38191780($z17691770);
++R.GAS;
return $ret17731774;
});
var $z17531754 = D;
var $f17591760 = function(_) {
return R.isFunction(anf_fun25351761)?anf_fun25351761.app(anf_arg25381762):R.ffi.throwNonFunApp(L[203],anf_fun25351761,[anf_arg25381762]);
};
try {
if(--R.GAS > 0) {
$z17531754 = $f17591760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17591760,
"from":L[203]});
}
} catch($e17511752) {
if(R.isCont($e17511752)) {
var $ss17551756 = {"from":L[203],
"go":function(anf_arg25391763) {
return $Hanf_arg38211765(anf_arg25391763,a_DASH_array237633,l7731764);
}};
$e17511752.stack[R.EXN_STACKHEIGHT++] = $ss17551756;
}
if(R.isPyretException($e17511752)) {
$e17511752.pyretStack.push(L[203]);
}
throw $e17511752;
}
var $ret17571758 = $Hanf_arg38211765($z17531754,a_DASH_array237633,l7731764);
++R.GAS;
return $ret17571758;
});
};
},{"length":3});
var anf_obj25421655 = R.makeMethod(function(self7751750) {
return function(l7761746,s7771747) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[200],2,arguments);
}
return R.checkAnnArgs([Loc9089,$type$String35],[l7761746,s7771747],[L[201],L[202]],function() {
var $z17381739 = D;
var $f17441745 = function(_) {
return R.isFunction(a_DASH_str233625.$var)?a_DASH_str233625.$var.app(l7761746,s7771747):R.ffi.throwNonFunApp(L[200],a_DASH_str233625.$var,[l7761746,s7771747]);
};
try {
if(--R.GAS > 0) {
$z17381739 = $f17441745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17441745,
"from":L[200]});
}
} catch($e17361737) {
if(R.isCont($e17361737)) {
var $ss17401741 = {"from":L[200],
"go":function(ann_DASH_check_DASH_temp25411748) {
return $Hann_DASH_check_DASH_temp38221749(ann_DASH_check_DASH_temp25411748);
}};
$e17361737.stack[R.EXN_STACKHEIGHT++] = $ss17401741;
}
if(R.isPyretException($e17361737)) {
$e17361737.pyretStack.push(L[200]);
}
throw $e17361737;
}
var $ret17421743 = $Hann_DASH_check_DASH_temp38221749($z17381739);
++R.GAS;
return $ret17421743;
});
};
},{"length":3});
var anf_obj25441656 = R.makeMethod(function(self7781735) {
return function(l7791731,b7801732) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[197],2,arguments);
}
return R.checkAnnArgs([Loc9089,$type$Boolean33],[l7791731,b7801732],[L[198],L[199]],function() {
var $z17231724 = D;
var $f17291730 = function(_) {
return R.isFunction(a_DASH_bool235629.$var)?a_DASH_bool235629.$var.app(l7791731,b7801732):R.ffi.throwNonFunApp(L[197],a_DASH_bool235629.$var,[l7791731,b7801732]);
};
try {
if(--R.GAS > 0) {
$z17231724 = $f17291730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17291730,
"from":L[197]});
}
} catch($e17211722) {
if(R.isCont($e17211722)) {
var $ss17251726 = {"from":L[197],
"go":function(ann_DASH_check_DASH_temp25431733) {
return $Hann_DASH_check_DASH_temp38231734(ann_DASH_check_DASH_temp25431733);
}};
$e17211722.stack[R.EXN_STACKHEIGHT++] = $ss17251726;
}
if(R.isPyretException($e17211722)) {
$e17211722.pyretStack.push(L[197]);
}
throw $e17211722;
}
var $ret17271728 = $Hann_DASH_check_DASH_temp38231734($z17231724);
++R.GAS;
return $ret17271728;
});
};
},{"length":3});
var anf_obj25461657 = R.makeMethod(function(self7811720) {
return function(l7821717) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[195],1,arguments);
}
return R.checkAnnArgs([Loc9089],[l7821717],[L[196]],function() {
var $z17091710 = D;
var $f17151716 = function(_) {
return R.isFunction(a_DASH_undefined239637.$var)?a_DASH_undefined239637.$var.app(l7821717):R.ffi.throwNonFunApp(L[195],a_DASH_undefined239637.$var,[l7821717]);
};
try {
if(--R.GAS > 0) {
$z17091710 = $f17151716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17151716,
"from":L[195]});
}
} catch($e17071708) {
if(R.isCont($e17071708)) {
var $ss17111712 = {"from":L[195],
"go":function(ann_DASH_check_DASH_temp25451718) {
return $Hann_DASH_check_DASH_temp38241719(ann_DASH_check_DASH_temp25451718);
}};
$e17071708.stack[R.EXN_STACKHEIGHT++] = $ss17111712;
}
if(R.isPyretException($e17071708)) {
$e17071708.pyretStack.push(L[195]);
}
throw $e17071708;
}
var $ret17131714 = $Hann_DASH_check_DASH_temp38241719($z17091710);
++R.GAS;
return $ret17131714;
});
};
},{"length":2});
var anf_obj25481658 = R.makeMethod(function(self7831706) {
return function(l7841702,id7851703) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[192],2,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[193],"A",A244,"Name")],[l7841702,id7851703],[L[194],L[193]],function() {
var $z16941695 = D;
var $f17001701 = function(_) {
return R.isFunction(a_DASH_id241641.$var)?a_DASH_id241641.$var.app(l7841702,id7851703):R.ffi.throwNonFunApp(L[192],a_DASH_id241641.$var,[l7841702,id7851703]);
};
try {
if(--R.GAS > 0) {
$z16941695 = $f17001701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17001701,
"from":L[192]});
}
} catch($e16921693) {
if(R.isCont($e16921693)) {
var $ss16961697 = {"from":L[192],
"go":function(ann_DASH_check_DASH_temp25471704) {
return $Hann_DASH_check_DASH_temp38251705(ann_DASH_check_DASH_temp25471704);
}};
$e16921693.stack[R.EXN_STACKHEIGHT++] = $ss16961697;
}
if(R.isPyretException($e16921693)) {
$e16921693.pyretStack.push(L[192]);
}
throw $e16921693;
}
var $ret16981699 = $Hann_DASH_check_DASH_temp38251705($z16941695);
++R.GAS;
return $ret16981699;
});
};
},{"length":3});
var anf_obj25501659 = R.makeMethod(function(self7861691) {
return function(l7871687,id7881688) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[189],2,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[190],"A",A244,"Name")],[l7871687,id7881688],[L[191],L[190]],function() {
var $z16791680 = D;
var $f16851686 = function(_) {
return R.isFunction(a_DASH_id_DASH_var243645.$var)?a_DASH_id_DASH_var243645.$var.app(l7871687,id7881688):R.ffi.throwNonFunApp(L[189],a_DASH_id_DASH_var243645.$var,[l7871687,id7881688]);
};
try {
if(--R.GAS > 0) {
$z16791680 = $f16851686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16851686,
"from":L[189]});
}
} catch($e16771678) {
if(R.isCont($e16771678)) {
var $ss16811682 = {"from":L[189],
"go":function(ann_DASH_check_DASH_temp25491689) {
return $Hann_DASH_check_DASH_temp38261690(ann_DASH_check_DASH_temp25491689);
}};
$e16771678.stack[R.EXN_STACKHEIGHT++] = $ss16811682;
}
if(R.isPyretException($e16771678)) {
$e16771678.pyretStack.push(L[189]);
}
throw $e16771678;
}
var $ret16831684 = $Hann_DASH_check_DASH_temp38261690($z16791680);
++R.GAS;
return $ret16831684;
});
};
},{"length":3});
var anf_obj25521660 = R.makeMethod(function(self7891676) {
return function(l7901671,id7911672,safe7921673) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[185],3,arguments);
}
return R.checkAnnArgs([Loc9089,R.getDotAnn(L[186],"A",A244,"Name"),$type$Boolean33],[l7901671,id7911672,safe7921673],[L[187],L[186],L[188]],function() {
var $z16631664 = D;
var $f16691670 = function(_) {
return R.isFunction(a_DASH_id_DASH_letrec245649.$var)?a_DASH_id_DASH_letrec245649.$var.app(l7901671,id7911672,safe7921673):R.ffi.throwNonFunApp(L[185],a_DASH_id_DASH_letrec245649.$var,[l7901671,id7911672,safe7921673]);
};
try {
if(--R.GAS > 0) {
$z16631664 = $f16691670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16691670,
"from":L[185]});
}
} catch($e16611662) {
if(R.isCont($e16611662)) {
var $ss16651666 = {"from":L[185],
"go":function(ann_DASH_check_DASH_temp25511674) {
return $Hann_DASH_check_DASH_temp38271675(ann_DASH_check_DASH_temp25511674);
}};
$e16611662.stack[R.EXN_STACKHEIGHT++] = $ss16651666;
}
if(R.isPyretException($e16611662)) {
$e16611662.pyretStack.push(L[185]);
}
throw $e16611662;
}
var $ret16671668 = $Hann_DASH_check_DASH_temp38271675($z16631664);
++R.GAS;
return $ret16671668;
});
};
},{"length":4});
var default_DASH_map_DASH_visitor619700 = R.makeObject({"a-module":anf_obj23151618,
"a-program":anf_obj23241619,
"a-import":anf_obj23301620,
"a-import-types":anf_obj23381621,
"a-import-file":anf_obj23401622,
"a-import-builtin":anf_obj23421623,
"a-type-bind":anf_obj23441624,
"a-newtype-bind":anf_obj23461625,
"a-type-let":anf_obj23521626,
"a-let":anf_obj23601627,
"a-var":anf_obj23681628,
"a-seq":anf_obj23741629,
"a-data-expr":anf_obj23861630,
"a-variant":anf_obj23981631,
"a-singleton-variant":anf_obj24051632,
"a-variant-member":anf_obj24091633,
"a-tail-app":anf_obj24181634,
"a-split-app":anf_obj24321635,
"a-if":anf_obj24401636,
"a-lettable":anf_obj24441637,
"a-assign":anf_obj24481638,
"a-app":anf_obj24571639,
"a-prim-app":anf_obj24641640,
"a-obj":anf_obj24711641,
"a-update":anf_obj24801642,
"a-extend":anf_obj24891643,
"a-dot":anf_obj24931644,
"a-colon":anf_obj24971645,
"a-get-bang":anf_obj25011646,
"a-lam":anf_obj25101647,
"a-method":anf_obj25191648,
"a-val":anf_obj25231649,
"a-bind":anf_obj25251650,
"a-field":anf_obj25291651,
"a-srcloc":anf_obj25311652,
"a-num":anf_obj25331653,
"a-array":anf_obj25401654,
"a-str":anf_obj25421655,
"a-bool":anf_obj25441656,
"a-undefined":anf_obj25461657,
"a-id":anf_obj25481658,
"a-id-var":anf_obj25501659,
"a-id-letrec":anf_obj25521660});
var freevars_DASH_list_DASH_acc793667 = {"$var":D,
"$name":"freevars-list-acc"};
var freevars_DASH_ann_DASH_acc794669 = {"$var":D,
"$name":"freevars-ann-acc"};
var freevars_DASH_e_DASH_acc795671 = {"$var":D,
"$name":"freevars-e-acc"};
var freevars_DASH_e796673 = {"$var":D,
"$name":"freevars-e"};
var freevars_DASH_variant_DASH_acc797675 = {"$var":D,
"$name":"freevars-variant-acc"};
var freevars_DASH_l_DASH_acc798677 = {"$var":D,
"$name":"freevars-l-acc"};
var freevars_DASH_l799679 = {"$var":D,
"$name":"freevars-l"};
var freevars_DASH_v_DASH_acc800681 = {"$var":D,
"$name":"freevars-v-acc"};
var freevars_DASH_v801683 = {"$var":D,
"$name":"freevars-v"};
var unions802685 = {"$var":D,
"$name":"unions"};
var anf_assign2556668 = R.makeFunction(function(anns8031589,seen_DASH_so_DASH_far8041590) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[181],2,arguments);
}
return R.checkAnnArgs([List1788],[anns8031589],[L[184]],function() {
var anf_arg25551601 = R.makeFunction(function(acc8051604,a8061605) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[182],2,arguments);
}
var $z16081609 = D;
var $f16141615 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var === D?U(L[183],"freevars-ann-acc"):freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var === D?U(L[183],"freevars-ann-acc"):freevars_DASH_ann_DASH_acc794669.$var.app(a8061605,acc8051604):R.ffi.throwNonFunApp(L[182],freevars_DASH_ann_DASH_acc794669.$var === D?U(L[183],"freevars-ann-acc"):freevars_DASH_ann_DASH_acc794669.$var,[a8061605,acc8051604]);
};
try {
if(--R.GAS > 0) {
$z16081609 = $f16141615();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16141615,
"from":L[182]});
}
} catch($e16061607) {
if(R.isCont($e16061607)) {
var $ss16101611 = {"from":L[182],
"go":function(ann_DASH_check_DASH_temp25541616) {
return $Hann_DASH_check_DASH_temp38281617(ann_DASH_check_DASH_temp25541616);
}};
$e16061607.stack[R.EXN_STACKHEIGHT++] = $ss16101611;
}
if(R.isPyretException($e16061607)) {
$e16061607.pyretStack.push(L[182]);
}
throw $e16061607;
}
var $ret16121613 = $Hann_DASH_check_DASH_temp38281617($z16081609);
++R.GAS;
return $ret16121613;
});
var $z15931594 = D;
var $f15991600 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg25551601,seen_DASH_so_DASH_far8041590,anns8031589):R.ffi.throwNonFunApp(L[181],fold5391,[anf_arg25551601,seen_DASH_so_DASH_far8041590,anns8031589]);
};
try {
if(--R.GAS > 0) {
$z15931594 = $f15991600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15991600,
"from":L[181]});
}
} catch($e15911592) {
if(R.isCont($e15911592)) {
var $ss15951596 = {"from":L[181],
"go":function(ann_DASH_check_DASH_temp25531602) {
return $Hann_DASH_check_DASH_temp38291603(ann_DASH_check_DASH_temp25531602);
}};
$e15911592.stack[R.EXN_STACKHEIGHT++] = $ss15951596;
}
if(R.isPyretException($e15911592)) {
$e15911592.pyretStack.push(L[181]);
}
throw $e15911592;
}
var $ret15971598 = $Hann_DASH_check_DASH_temp38291603($z15931594);
++R.GAS;
return $ret15971598;
});
});
freevars_DASH_list_DASH_acc793667.$var = anf_assign2556668;
var anf_assign2600670 = R.makeFunction(function(ann8071421,seen_DASH_so_DASH_far8081422) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[155],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[179],"A",A244,"Ann"),Set2090],[ann8071421,seen_DASH_so_DASH_far8081422],[L[179],L[180]],function() {
var lst_DASH_a8091491 = R.makeFunction(function(arg_DASH_3081576) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[178],1,arguments);
}
var $z15791580 = D;
var $f15851586 = function(_) {
return R.isFunction(freevars_DASH_list_DASH_acc793667.$var)?freevars_DASH_list_DASH_acc793667.$var.app(arg_DASH_3081576,seen_DASH_so_DASH_far8081422):R.ffi.throwNonFunApp(L[178],freevars_DASH_list_DASH_acc793667.$var,[arg_DASH_3081576,seen_DASH_so_DASH_far8081422]);
};
try {
if(--R.GAS > 0) {
$z15791580 = $f15851586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15851586,
"from":L[178]});
}
} catch($e15771578) {
if(R.isCont($e15771578)) {
var $ss15811582 = {"from":L[178],
"go":function(ann_DASH_check_DASH_temp25581587) {
return $Hann_DASH_check_DASH_temp38301588(ann_DASH_check_DASH_temp25581587);
}};
$e15771578.stack[R.EXN_STACKHEIGHT++] = $ss15811582;
}
if(R.isPyretException($e15771578)) {
$e15771578.pyretStack.push(L[178]);
}
throw $e15771578;
}
var $ret15831584 = $Hann_DASH_check_DASH_temp38301588($z15791580);
++R.GAS;
return $ret15831584;
});
var cases_DASH_val3111575 = ann8071421;
var anf_fun25591433 = G(cases_DASH_val3111575,"_match",L[156]);
var anf_obj25611439 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[177],0,arguments);
}
var ann_DASH_check_DASH_temp25601574 = seen_DASH_so_DASH_far8081422;
return ann_DASH_check_DASH_temp25601574;
});
var anf_obj25631440 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[176],0,arguments);
}
var ann_DASH_check_DASH_temp25621573 = seen_DASH_so_DASH_far8081422;
return ann_DASH_check_DASH_temp25621573;
});
var anf_obj25661441 = R.makeFunction(function(l8101558,name8111559) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[174],2,arguments);
}
var anf_fun25651570 = G(seen_DASH_so_DASH_far8081422,"add",L[175]);
var $z15621563 = D;
var $f15681569 = function(_) {
return R.isFunction(anf_fun25651570)?anf_fun25651570.app(name8111559):R.ffi.throwNonFunApp(L[174],anf_fun25651570,[name8111559]);
};
try {
if(--R.GAS > 0) {
$z15621563 = $f15681569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15681569,
"from":L[174]});
}
} catch($e15601561) {
if(R.isCont($e15601561)) {
var $ss15641565 = {"from":L[174],
"go":function(ann_DASH_check_DASH_temp25641571) {
return $Hann_DASH_check_DASH_temp38311572(ann_DASH_check_DASH_temp25641571);
}};
$e15601561.stack[R.EXN_STACKHEIGHT++] = $ss15641565;
}
if(R.isPyretException($e15601561)) {
$e15601561.pyretStack.push(L[174]);
}
throw $e15601561;
}
var $ret15661567 = $Hann_DASH_check_DASH_temp38311572($z15621563);
++R.GAS;
return $ret15661567;
});
var anf_obj25691442 = R.makeFunction(function(l8121542,left8131543,right8141544) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[172],3,arguments);
}
var anf_fun25681555 = G(seen_DASH_so_DASH_far8081422,"add",L[173]);
var $z15471548 = D;
var $f15531554 = function(_) {
return R.isFunction(anf_fun25681555)?anf_fun25681555.app(left8131543):R.ffi.throwNonFunApp(L[172],anf_fun25681555,[left8131543]);
};
try {
if(--R.GAS > 0) {
$z15471548 = $f15531554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15531554,
"from":L[172]});
}
} catch($e15451546) {
if(R.isCont($e15451546)) {
var $ss15491550 = {"from":L[172],
"go":function(ann_DASH_check_DASH_temp25671556) {
return $Hann_DASH_check_DASH_temp38321557(ann_DASH_check_DASH_temp25671556);
}};
$e15451546.stack[R.EXN_STACKHEIGHT++] = $ss15491550;
}
if(R.isPyretException($e15451546)) {
$e15451546.pyretStack.push(L[172]);
}
throw $e15451546;
}
var $ret15511552 = $Hann_DASH_check_DASH_temp38321557($z15471548);
++R.GAS;
return $ret15511552;
});
var anf_obj25721443 = R.makeFunction(function(l8151526,args8161527,ret8171528,$underscore8181529) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[170],4,arguments);
}
var $z15321533 = D;
var $f15381539 = function(_) {
return R.isFunction(link2992)?link2992.app(ret8171528,args8161527):R.ffi.throwNonFunApp(L[171],link2992,[ret8171528,args8161527]);
};
try {
if(--R.GAS > 0) {
$z15321533 = $f15381539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15381539,
"from":L[171]});
}
} catch($e15301531) {
if(R.isCont($e15301531)) {
var $ss15341535 = {"from":L[171],
"go":function(anf_arg25711540) {
return $Hanf_arg38341541(anf_arg25711540,lst_DASH_a8091491);
}};
$e15301531.stack[R.EXN_STACKHEIGHT++] = $ss15341535;
}
if(R.isPyretException($e15301531)) {
$e15301531.pyretStack.push(L[171]);
}
throw $e15301531;
}
var $ret15361537 = $Hanf_arg38341541($z15321533,lst_DASH_a8091491);
++R.GAS;
return $ret15361537;
});
var anf_obj25751444 = R.makeFunction(function(l8191511,args8201512,ret8211513) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[168],3,arguments);
}
var $z15161517 = D;
var $f15221523 = function(_) {
return R.isFunction(link2992)?link2992.app(ret8211513,args8201512):R.ffi.throwNonFunApp(L[169],link2992,[ret8211513,args8201512]);
};
try {
if(--R.GAS > 0) {
$z15161517 = $f15221523();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15221523,
"from":L[169]});
}
} catch($e15141515) {
if(R.isCont($e15141515)) {
var $ss15181519 = {"from":L[169],
"go":function(anf_arg25741524) {
return $Hanf_arg38361525(anf_arg25741524,lst_DASH_a8091491);
}};
$e15141515.stack[R.EXN_STACKHEIGHT++] = $ss15181519;
}
if(R.isPyretException($e15141515)) {
$e15141515.pyretStack.push(L[169]);
}
throw $e15141515;
}
var $ret15201521 = $Hanf_arg38361525($z15161517,lst_DASH_a8091491);
++R.GAS;
return $ret15201521;
});
var anf_obj25811445 = R.makeFunction(function(l8221493,fields8231494) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[164],2,arguments);
}
var anf_fun25771505 = G(fields8231494,"map",L[167]);
var anf_arg25791506 = R.makeFunction(function(recv_DASH_3091509) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[166],1,arguments);
}
var ann_DASH_check_DASH_temp25781510 = G(recv_DASH_3091509,"ann",L[166]);
return ann_DASH_check_DASH_temp25781510;
});
var $z14971498 = D;
var $f15031504 = function(_) {
return R.isFunction(anf_fun25771505)?anf_fun25771505.app(anf_arg25791506):R.ffi.throwNonFunApp(L[165],anf_fun25771505,[anf_arg25791506]);
};
try {
if(--R.GAS > 0) {
$z14971498 = $f15031504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15031504,
"from":L[165]});
}
} catch($e14951496) {
if(R.isCont($e14951496)) {
var $ss14991500 = {"from":L[165],
"go":function(anf_arg25801507) {
return $Hanf_arg38381508(anf_arg25801507,lst_DASH_a8091491);
}};
$e14951496.stack[R.EXN_STACKHEIGHT++] = $ss14991500;
}
if(R.isPyretException($e14951496)) {
$e14951496.pyretStack.push(L[165]);
}
throw $e14951496;
}
var $ret15011502 = $Hanf_arg38381508($z14971498,lst_DASH_a8091491);
++R.GAS;
return $ret15011502;
});
var anf_obj25841446 = R.makeFunction(function(l8241477,a8251478,args8261479) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[162],3,arguments);
}
var $z14821483 = D;
var $f14881489 = function(_) {
return R.isFunction(link2992)?link2992.app(a8251478,args8261479):R.ffi.throwNonFunApp(L[163],link2992,[a8251478,args8261479]);
};
try {
if(--R.GAS > 0) {
$z14821483 = $f14881489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14881489,
"from":L[163]});
}
} catch($e14801481) {
if(R.isCont($e14801481)) {
var $ss14841485 = {"from":L[163],
"go":function(anf_arg25831490) {
return $Hanf_arg38401492(anf_arg25831490,lst_DASH_a8091491);
}};
$e14801481.stack[R.EXN_STACKHEIGHT++] = $ss14841485;
}
if(R.isPyretException($e14801481)) {
$e14801481.pyretStack.push(L[163]);
}
throw $e14801481;
}
var $ret14861487 = $Hanf_arg38401492($z14821483,lst_DASH_a8091491);
++R.GAS;
return $ret14861487;
});
var anf_obj25961447 = R.makeFunction(function(l8271448,a8281449,pred8291450) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[157],3,arguments);
}
var cases_DASH_val3101476 = pred8291450;
var anf_fun25861461 = G(cases_DASH_val3101476,"_match",L[159]);
var anf_obj25881467 = R.makeFunction(function($underscore8311473,n8321474) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[161],2,arguments);
}
var ann_DASH_check_DASH_temp25871475 = n8321474;
return ann_DASH_check_DASH_temp25871475;
});
var anf_obj25901468 = R.makeFunction(function($underscore8331469,n8341470,$underscore8351471) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[160],3,arguments);
}
var ann_DASH_check_DASH_temp25891472 = n8341470;
return ann_DASH_check_DASH_temp25891472;
});
var anf_arg25911462 = R.makeObject({"s-id":anf_obj25881467,
"s-id-letrec":anf_obj25901468});
var anf_arg25931463 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[159],0,arguments);
}
var ann_DASH_check_DASH_temp25921466 = R.throwNoBranchesMatched(L[159],("cases"));
return ann_DASH_check_DASH_temp25921466;
});
var $z14531454 = D;
var $f14591460 = function(_) {
return R.isFunction(anf_fun25861461)?anf_fun25861461.app(anf_arg25911462,anf_arg25931463):R.ffi.throwNonFunApp(L[158],anf_fun25861461,[anf_arg25911462,anf_arg25931463]);
};
try {
if(--R.GAS > 0) {
$z14531454 = $f14591460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14591460,
"from":L[158]});
}
} catch($e14511452) {
if(R.isCont($e14511452)) {
var $ss14551456 = {"from":L[158],
"go":function(name8301464) {
return $Hname38431465(name8301464,a8281449,freevars_DASH_ann_DASH_acc794669,seen_DASH_so_DASH_far8081422);
}};
$e14511452.stack[R.EXN_STACKHEIGHT++] = $ss14551456;
}
if(R.isPyretException($e14511452)) {
$e14511452.pyretStack.push(L[158]);
}
throw $e14511452;
}
var $ret14571458 = $Hname38431465($z14531454,a8281449,freevars_DASH_ann_DASH_acc794669,seen_DASH_so_DASH_far8081422);
++R.GAS;
return $ret14571458;
});
var anf_arg25971434 = R.makeObject({"a-blank":anf_obj25611439,
"a-any":anf_obj25631440,
"a-name":anf_obj25661441,
"a-dot":anf_obj25691442,
"a-arrow":anf_obj25721443,
"a-method":anf_obj25751444,
"a-record":anf_obj25811445,
"a-app":anf_obj25841446,
"a-pred":anf_obj25961447});
var anf_arg25991435 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[156],0,arguments);
}
var ann_DASH_check_DASH_temp25981438 = R.throwNoBranchesMatched(L[156],("cases"));
return ann_DASH_check_DASH_temp25981438;
});
var $z14251426 = D;
var $f14311432 = function(_) {
return R.isFunction(anf_fun25591433)?anf_fun25591433.app(anf_arg25971434,anf_arg25991435):R.ffi.throwNonFunApp(L[155],anf_fun25591433,[anf_arg25971434,anf_arg25991435]);
};
try {
if(--R.GAS > 0) {
$z14251426 = $f14311432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14311432,
"from":L[155]});
}
} catch($e14231424) {
if(R.isCont($e14231424)) {
var $ss14271428 = {"from":L[155],
"go":function(ann_DASH_check_DASH_temp25571436) {
return $Hann_DASH_check_DASH_temp38441437(ann_DASH_check_DASH_temp25571436,A244,Set2090);
}};
$e14231424.stack[R.EXN_STACKHEIGHT++] = $ss14271428;
}
if(R.isPyretException($e14231424)) {
$e14231424.pyretStack.push(L[155]);
}
throw $e14231424;
}
var $ret14291430 = $Hann_DASH_check_DASH_temp38441437($z14251426,A244,Set2090);
++R.GAS;
return $ret14291430;
});
});
freevars_DASH_ann_DASH_acc794669.$var = anf_assign2600670;
var anf_assign2654672 = R.makeFunction(function(expr8361270,seen_DASH_so_DASH_far8371271) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[132],2,arguments);
}
return R.checkAnnArgs([AExpr7465,Set2090],[expr8361270,seen_DASH_so_DASH_far8371271],[L[153],L[154]],function() {
var cases_DASH_val3131420 = expr8361270;
var anf_fun26021282 = G(cases_DASH_val3131420,"_match",L[133]);
var anf_obj26171288 = R.makeFunction(function($underscore8381405,b8391406,body8401407) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[151],3,arguments);
}
var $z14101411 = D;
var $f14161417 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(body8401407,seen_DASH_so_DASH_far8371271):R.ffi.throwNonFunApp(L[152],freevars_DASH_e_DASH_acc795671.$var,[body8401407,seen_DASH_so_DASH_far8371271]);
};
try {
if(--R.GAS > 0) {
$z14101411 = $f14161417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14161417,
"from":L[152]});
}
} catch($e14081409) {
if(R.isCont($e14081409)) {
var $ss14121413 = {"from":L[152],
"go":function(body_DASH_ids8411418) {
return $Hbody_DASH_ids38501419(body_DASH_ids8411418,b8391406,freevars_DASH_ann_DASH_acc794669);
}};
$e14081409.stack[R.EXN_STACKHEIGHT++] = $ss14121413;
}
if(R.isPyretException($e14081409)) {
$e14081409.pyretStack.push(L[152]);
}
throw $e14081409;
}
var $ret14141415 = $Hbody_DASH_ids38501419($z14101411,b8391406,freevars_DASH_ann_DASH_acc794669);
++R.GAS;
return $ret14141415;
});
var anf_obj26241289 = R.makeFunction(function($underscore8481389,b8491390,e8501391,body8511392) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[149],4,arguments);
}
var $z13951396 = D;
var $f14011402 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(body8511392,seen_DASH_so_DASH_far8371271):R.ffi.throwNonFunApp(L[150],freevars_DASH_e_DASH_acc795671.$var,[body8511392,seen_DASH_so_DASH_far8371271]);
};
try {
if(--R.GAS > 0) {
$z13951396 = $f14011402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14011402,
"from":L[150]});
}
} catch($e13931394) {
if(R.isCont($e13931394)) {
var $ss13971398 = {"from":L[150],
"go":function(from_DASH_body8521403) {
return $Hfrom_DASH_body38541404(from_DASH_body8521403,b8491390,e8501391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677);
}};
$e13931394.stack[R.EXN_STACKHEIGHT++] = $ss13971398;
}
if(R.isPyretException($e13931394)) {
$e13931394.pyretStack.push(L[150]);
}
throw $e13931394;
}
var $ret13991400 = $Hfrom_DASH_body38541404($z13951396,b8491390,e8501391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677);
++R.GAS;
return $ret13991400;
});
var anf_obj26311290 = R.makeFunction(function($underscore8531373,b8541374,e8551375,body8561376) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[147],4,arguments);
}
var $z13791380 = D;
var $f13851386 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(body8561376,seen_DASH_so_DASH_far8371271):R.ffi.throwNonFunApp(L[148],freevars_DASH_e_DASH_acc795671.$var,[body8561376,seen_DASH_so_DASH_far8371271]);
};
try {
if(--R.GAS > 0) {
$z13791380 = $f13851386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13851386,
"from":L[148]});
}
} catch($e13771378) {
if(R.isCont($e13771378)) {
var $ss13811382 = {"from":L[148],
"go":function(from_DASH_body8571387) {
return $Hfrom_DASH_body38581388(from_DASH_body8571387,b8541374,e8551375,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677);
}};
$e13771378.stack[R.EXN_STACKHEIGHT++] = $ss13811382;
}
if(R.isPyretException($e13771378)) {
$e13771378.pyretStack.push(L[148]);
}
throw $e13771378;
}
var $ret13831384 = $Hfrom_DASH_body38581388($z13791380,b8541374,e8551375,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677);
++R.GAS;
return $ret13831384;
});
var anf_obj26331291 = R.makeFunction(function($underscore8581358,e18591359,e28601360) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[145],3,arguments);
}
var $z13631364 = D;
var $f13691370 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(e28601360,seen_DASH_so_DASH_far8371271):R.ffi.throwNonFunApp(L[146],freevars_DASH_e_DASH_acc795671.$var,[e28601360,seen_DASH_so_DASH_far8371271]);
};
try {
if(--R.GAS > 0) {
$z13631364 = $f13691370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13691370,
"from":L[146]});
}
} catch($e13611362) {
if(R.isCont($e13611362)) {
var $ss13651366 = {"from":L[146],
"go":function(from_DASH_e28611371) {
return $Hfrom_DASH_e238601372(from_DASH_e28611371,e18591359,freevars_DASH_l_DASH_acc798677);
}};
$e13611362.stack[R.EXN_STACKHEIGHT++] = $ss13651366;
}
if(R.isPyretException($e13611362)) {
$e13611362.pyretStack.push(L[146]);
}
throw $e13611362;
}
var $ret13671368 = $Hfrom_DASH_e238601372($z13631364,e18591359,freevars_DASH_l_DASH_acc798677);
++R.GAS;
return $ret13671368;
});
var anf_obj26371292 = R.makeFunction(function($underscore8621343,f8631344,args8641345) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[142],3,arguments);
}
var $z13481349 = D;
var $f13541355 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[143],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[143],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(f8631344,seen_DASH_so_DASH_far8371271):R.ffi.throwNonFunApp(L[144],freevars_DASH_v_DASH_acc800681.$var === D?U(L[143],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[f8631344,seen_DASH_so_DASH_far8371271]);
};
try {
if(--R.GAS > 0) {
$z13481349 = $f13541355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13541355,
"from":L[144]});
}
} catch($e13461347) {
if(R.isCont($e13461347)) {
var $ss13501351 = {"from":L[144],
"go":function(from_DASH_f8651356) {
return $Hfrom_DASH_f38631357(from_DASH_f8651356,args8641345,fold5391,freevars_DASH_v_DASH_acc800681);
}};
$e13461347.stack[R.EXN_STACKHEIGHT++] = $ss13501351;
}
if(R.isPyretException($e13461347)) {
$e13461347.pyretStack.push(L[144]);
}
throw $e13461347;
}
var $ret13521353 = $Hfrom_DASH_f38631357($z13481349,args8641345,fold5391,freevars_DASH_v_DASH_acc800681);
++R.GAS;
return $ret13521353;
});
var anf_obj26441293 = R.makeFunction(function($underscore8681325,$underscore8691326,f8701327,args8711328,name8721329,helper_DASH_args8731330) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[139],6,arguments);
}
var $z13331334 = D;
var $f13391340 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[140],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[140],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(f8701327,seen_DASH_so_DASH_far8371271):R.ffi.throwNonFunApp(L[141],freevars_DASH_v_DASH_acc800681.$var === D?U(L[140],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[f8701327,seen_DASH_so_DASH_far8371271]);
};
try {
if(--R.GAS > 0) {
$z13331334 = $f13391340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13391340,
"from":L[141]});
}
} catch($e13311332) {
if(R.isCont($e13311332)) {
var $ss13351336 = {"from":L[141],
"go":function(from_DASH_f8741341) {
return $Hfrom_DASH_f38691342(from_DASH_f8741341,args8711328,fold5391,freevars_DASH_v_DASH_acc800681,helper_DASH_args8731330,name8721329);
}};
$e13311332.stack[R.EXN_STACKHEIGHT++] = $ss13351336;
}
if(R.isPyretException($e13311332)) {
$e13311332.pyretStack.push(L[141]);
}
throw $e13311332;
}
var $ret13371338 = $Hfrom_DASH_f38691342($z13331334,args8711328,fold5391,freevars_DASH_v_DASH_acc800681,helper_DASH_args8731330,name8721329);
++R.GAS;
return $ret13371338;
});
var anf_obj26461294 = R.makeFunction(function(e8811312) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[137],1,arguments);
}
var $z13151316 = D;
var $f13211322 = function(_) {
return R.isFunction(freevars_DASH_l_DASH_acc798677.$var === D?U(L[138],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var)?freevars_DASH_l_DASH_acc798677.$var === D?U(L[138],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var.app(e8811312,seen_DASH_so_DASH_far8371271):R.ffi.throwNonFunApp(L[137],freevars_DASH_l_DASH_acc798677.$var === D?U(L[138],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var,[e8811312,seen_DASH_so_DASH_far8371271]);
};
try {
if(--R.GAS > 0) {
$z13151316 = $f13211322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13211322,
"from":L[137]});
}
} catch($e13131314) {
if(R.isCont($e13131314)) {
var $ss13171318 = {"from":L[137],
"go":function(ann_DASH_check_DASH_temp26451323) {
return $Hann_DASH_check_DASH_temp38701324(ann_DASH_check_DASH_temp26451323);
}};
$e13131314.stack[R.EXN_STACKHEIGHT++] = $ss13171318;
}
if(R.isPyretException($e13131314)) {
$e13131314.pyretStack.push(L[137]);
}
throw $e13131314;
}
var $ret13191320 = $Hann_DASH_check_DASH_temp38701324($z13151316);
++R.GAS;
return $ret13191320;
});
var anf_obj26501295 = R.makeFunction(function($underscore8821296,c8831297,t8841298,a8851299) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[134],4,arguments);
}
var $z13021303 = D;
var $f13081309 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[135],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[135],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(c8831297,seen_DASH_so_DASH_far8371271):R.ffi.throwNonFunApp(L[136],freevars_DASH_v_DASH_acc800681.$var === D?U(L[135],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[c8831297,seen_DASH_so_DASH_far8371271]);
};
try {
if(--R.GAS > 0) {
$z13021303 = $f13081309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13081309,
"from":L[136]});
}
} catch($e13001301) {
if(R.isCont($e13001301)) {
var $ss13041305 = {"from":L[136],
"go":function(anf_arg26481310) {
return $Hanf_arg38731311(anf_arg26481310,a8851299,freevars_DASH_e_DASH_acc795671,t8841298);
}};
$e13001301.stack[R.EXN_STACKHEIGHT++] = $ss13041305;
}
if(R.isPyretException($e13001301)) {
$e13001301.pyretStack.push(L[136]);
}
throw $e13001301;
}
var $ret13061307 = $Hanf_arg38731311($z13021303,a8851299,freevars_DASH_e_DASH_acc795671,t8841298);
++R.GAS;
return $ret13061307;
});
var anf_arg26511283 = R.makeObject({"a-type-let":anf_obj26171288,
"a-let":anf_obj26241289,
"a-var":anf_obj26311290,
"a-seq":anf_obj26331291,
"a-tail-app":anf_obj26371292,
"a-split-app":anf_obj26441293,
"a-lettable":anf_obj26461294,
"a-if":anf_obj26501295});
var anf_arg26531284 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[133],0,arguments);
}
var ann_DASH_check_DASH_temp26521287 = R.throwNoBranchesMatched(L[133],("cases"));
return ann_DASH_check_DASH_temp26521287;
});
var $z12741275 = D;
var $f12801281 = function(_) {
return R.isFunction(anf_fun26021282)?anf_fun26021282.app(anf_arg26511283,anf_arg26531284):R.ffi.throwNonFunApp(L[132],anf_fun26021282,[anf_arg26511283,anf_arg26531284]);
};
try {
if(--R.GAS > 0) {
$z12741275 = $f12801281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12801281,
"from":L[132]});
}
} catch($e12721273) {
if(R.isCont($e12721273)) {
var $ss12761277 = {"from":L[132],
"go":function(ann_DASH_check_DASH_temp26011285) {
return $Hann_DASH_check_DASH_temp38741286(ann_DASH_check_DASH_temp26011285,A244,Set2090);
}};
$e12721273.stack[R.EXN_STACKHEIGHT++] = $ss12761277;
}
if(R.isPyretException($e12721273)) {
$e12721273.pyretStack.push(L[132]);
}
throw $e12721273;
}
var $ret12781279 = $Hann_DASH_check_DASH_temp38741286($z12741275,A244,Set2090);
++R.GAS;
return $ret12781279;
});
});
freevars_DASH_e_DASH_acc795671.$var = anf_assign2654672;
var anf_assign2657674 = R.makeFunction(function(expr8861256) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[129],1,arguments);
}
return R.checkAnnArgs([AExpr7465],[expr8861256],[L[131]],function() {
var anf_arg26561267 = G(sets1543,"empty-tree-set",L[130]);
var $z12591260 = D;
var $f12651266 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(expr8861256,anf_arg26561267):R.ffi.throwNonFunApp(L[129],freevars_DASH_e_DASH_acc795671.$var,[expr8861256,anf_arg26561267]);
};
try {
if(--R.GAS > 0) {
$z12591260 = $f12651266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12651266,
"from":L[129]});
}
} catch($e12571258) {
if(R.isCont($e12571258)) {
var $ss12611262 = {"from":L[129],
"go":function(ann_DASH_check_DASH_temp26551268) {
return $Hann_DASH_check_DASH_temp38751269(ann_DASH_check_DASH_temp26551268,A244,Set2090);
}};
$e12571258.stack[R.EXN_STACKHEIGHT++] = $ss12611262;
}
if(R.isPyretException($e12571258)) {
$e12571258.pyretStack.push(L[129]);
}
throw $e12571258;
}
var $ret12631264 = $Hann_DASH_check_DASH_temp38751269($z12591260,A244,Set2090);
++R.GAS;
return $ret12631264;
});
});
freevars_DASH_e796673.$var = anf_assign2657674;
var anf_assign2675676 = R.makeFunction(function(v8871197,seen_DASH_so_DASH_far8881198) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[119],2,arguments);
}
return R.checkAnnArgs([AVariant7883,Set2090],[v8871197,seen_DASH_so_DASH_far8881198],[L[127],L[128]],function() {
var cases_DASH_val3141255 = v8871197;
var anf_fun26591209 = G(cases_DASH_val3141255,"_match",L[121]);
var anf_obj26651215 = R.makeFunction(function($underscore8901221,$underscore8911222,$underscore8921223,members8931224,$underscore8941225) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[123],5,arguments);
}
var anf_arg26641236 = R.makeFunction(function(acc8951239,m8961240) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[124],2,arguments);
}
var anf_bracket26621254 = G(m8961240,"bind",L[126]);
var anf_arg26631251 = G(anf_bracket26621254,"ann",L[125]);
var $z12431244 = D;
var $f12491250 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(anf_arg26631251,acc8951239):R.ffi.throwNonFunApp(L[124],freevars_DASH_ann_DASH_acc794669.$var,[anf_arg26631251,acc8951239]);
};
try {
if(--R.GAS > 0) {
$z12431244 = $f12491250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12491250,
"from":L[124]});
}
} catch($e12411242) {
if(R.isCont($e12411242)) {
var $ss12451246 = {"from":L[124],
"go":function(ann_DASH_check_DASH_temp26611252) {
return $Hann_DASH_check_DASH_temp38761253(ann_DASH_check_DASH_temp26611252);
}};
$e12411242.stack[R.EXN_STACKHEIGHT++] = $ss12451246;
}
if(R.isPyretException($e12411242)) {
$e12411242.pyretStack.push(L[124]);
}
throw $e12411242;
}
var $ret12471248 = $Hann_DASH_check_DASH_temp38761253($z12431244);
++R.GAS;
return $ret12471248;
});
var $z12281229 = D;
var $f12341235 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg26641236,seen_DASH_so_DASH_far8881198,members8931224):R.ffi.throwNonFunApp(L[123],fold5391,[anf_arg26641236,seen_DASH_so_DASH_far8881198,members8931224]);
};
try {
if(--R.GAS > 0) {
$z12281229 = $f12341235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12341235,
"from":L[123]});
}
} catch($e12261227) {
if(R.isCont($e12261227)) {
var $ss12301231 = {"from":L[123],
"go":function(ann_DASH_check_DASH_temp26601237) {
return $Hann_DASH_check_DASH_temp38771238(ann_DASH_check_DASH_temp26601237);
}};
$e12261227.stack[R.EXN_STACKHEIGHT++] = $ss12301231;
}
if(R.isPyretException($e12261227)) {
$e12261227.pyretStack.push(L[123]);
}
throw $e12261227;
}
var $ret12321233 = $Hann_DASH_check_DASH_temp38771238($z12281229);
++R.GAS;
return $ret12321233;
});
var anf_obj26671216 = R.makeFunction(function($underscore8971217,$underscore8981218,$underscore8991219) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[122],3,arguments);
}
var ann_DASH_check_DASH_temp26661220 = seen_DASH_so_DASH_far8881198;
return ann_DASH_check_DASH_temp26661220;
});
var anf_arg26681210 = R.makeObject({"a-variant":anf_obj26651215,
"a-singleton-variant":anf_obj26671216});
var anf_arg26701211 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[121],0,arguments);
}
var ann_DASH_check_DASH_temp26691214 = R.throwNoBranchesMatched(L[121],("cases"));
return ann_DASH_check_DASH_temp26691214;
});
var $z12011202 = D;
var $f12071208 = function(_) {
return R.isFunction(anf_fun26591209)?anf_fun26591209.app(anf_arg26681210,anf_arg26701211):R.ffi.throwNonFunApp(L[120],anf_fun26591209,[anf_arg26681210,anf_arg26701211]);
};
try {
if(--R.GAS > 0) {
$z12011202 = $f12071208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12071208,
"from":L[120]});
}
} catch($e11991200) {
if(R.isCont($e11991200)) {
var $ss12031204 = {"from":L[120],
"go":function(from_DASH_members8891212) {
return $Hfrom_DASH_members38801213(from_DASH_members8891212,A244,Set2090,fold5391,freevars_DASH_v_DASH_acc800681,v8871197);
}};
$e11991200.stack[R.EXN_STACKHEIGHT++] = $ss12031204;
}
if(R.isPyretException($e11991200)) {
$e11991200.pyretStack.push(L[120]);
}
throw $e11991200;
}
var $ret12051206 = $Hfrom_DASH_members38801213($z12011202,A244,Set2090,fold5391,freevars_DASH_v_DASH_acc800681,v8871197);
++R.GAS;
return $ret12051206;
});
});
freevars_DASH_variant_DASH_acc797675.$var = anf_assign2675676;
var anf_assign2759678 = R.makeFunction(function(e902889,seen_DASH_so_DASH_far903890) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[76],2,arguments);
}
return R.checkAnnArgs([ALettable8473,Set2090],[e902889,seen_DASH_so_DASH_far903890],[L[117],L[118]],function() {
var cases_DASH_val3181196 = e902889;
var anf_fun2677901 = G(cases_DASH_val3181196,"_match",L[77]);
var anf_obj2686918 = R.makeFunction(function($underscore9041175,ans9051176,provs9061177,types9071178,checks9081179) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[113],5,arguments);
}
var anf_fun26791190 = G(types9071178,"map",L[116]);
var anf_arg26811191 = R.makeFunction(function(recv_DASH_3151194) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[115],1,arguments);
}
var ann_DASH_check_DASH_temp26801195 = G(recv_DASH_3151194,"ann",L[115]);
return ann_DASH_check_DASH_temp26801195;
});
var $z11821183 = D;
var $f11881189 = function(_) {
return R.isFunction(anf_fun26791190)?anf_fun26791190.app(anf_arg26811191):R.ffi.throwNonFunApp(L[114],anf_fun26791190,[anf_arg26811191]);
};
try {
if(--R.GAS > 0) {
$z11821183 = $f11881189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11881189,
"from":L[114]});
}
} catch($e11801181) {
if(R.isCont($e11801181)) {
var $ss11841185 = {"from":L[114],
"go":function(anf_arg26821192) {
return $Hanf_arg38851193(anf_arg26821192,ans9051176,checks9081179,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,provs9061177,seen_DASH_so_DASH_far903890);
}};
$e11801181.stack[R.EXN_STACKHEIGHT++] = $ss11841185;
}
if(R.isPyretException($e11801181)) {
$e11801181.pyretStack.push(L[114]);
}
throw $e11801181;
}
var $ret11861187 = $Hanf_arg38851193($z11821183,ans9051176,checks9081179,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,provs9061177,seen_DASH_so_DASH_far903890);
++R.GAS;
return $ret11861187;
});
var anf_obj2690919 = R.makeFunction(function($underscore9091159,id9101160,v9111161) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[110],3,arguments);
}
var anf_fun26881172 = G(seen_DASH_so_DASH_far903890,"add",L[112]);
var $z11641165 = D;
var $f11701171 = function(_) {
return R.isFunction(anf_fun26881172)?anf_fun26881172.app(id9101160):R.ffi.throwNonFunApp(L[111],anf_fun26881172,[id9101160]);
};
try {
if(--R.GAS > 0) {
$z11641165 = $f11701171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11701171,
"from":L[111]});
}
} catch($e11621163) {
if(R.isCont($e11621163)) {
var $ss11661167 = {"from":L[111],
"go":function(anf_arg26891173) {
return $Hanf_arg38871174(anf_arg26891173,freevars_DASH_v_DASH_acc800681,v9111161);
}};
$e11621163.stack[R.EXN_STACKHEIGHT++] = $ss11661167;
}
if(R.isPyretException($e11621163)) {
$e11621163.pyretStack.push(L[111]);
}
throw $e11621163;
}
var $ret11681169 = $Hanf_arg38871174($z11641165,freevars_DASH_v_DASH_acc800681,v9111161);
++R.GAS;
return $ret11681169;
});
var anf_obj2694920 = R.makeFunction(function($underscore9121144,f9131145,args9141146) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[107],3,arguments);
}
var $z11491150 = D;
var $f11551156 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[108],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[108],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(f9131145,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[109],freevars_DASH_v_DASH_acc800681.$var === D?U(L[108],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[f9131145,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z11491150 = $f11551156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11551156,
"from":L[109]});
}
} catch($e11471148) {
if(R.isCont($e11471148)) {
var $ss11511152 = {"from":L[109],
"go":function(from_DASH_f9151157) {
return $Hfrom_DASH_f38901158(from_DASH_f9151157,args9141146,fold5391,freevars_DASH_v_DASH_acc800681);
}};
$e11471148.stack[R.EXN_STACKHEIGHT++] = $ss11511152;
}
if(R.isPyretException($e11471148)) {
$e11471148.pyretStack.push(L[109]);
}
throw $e11471148;
}
var $ret11531154 = $Hfrom_DASH_f38901158($z11491150,args9141146,fold5391,freevars_DASH_v_DASH_acc800681);
++R.GAS;
return $ret11531154;
});
var anf_obj2698921 = R.makeFunction(function($underscore9181114,$underscore9191115,args9201116) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[104],3,arguments);
}
var anf_arg26971127 = R.makeFunction(function(acc9211130,arg9221131) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[105],2,arguments);
}
var $z11341135 = D;
var $f11401141 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[106],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[106],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(arg9221131,acc9211130):R.ffi.throwNonFunApp(L[105],freevars_DASH_v_DASH_acc800681.$var === D?U(L[106],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[arg9221131,acc9211130]);
};
try {
if(--R.GAS > 0) {
$z11341135 = $f11401141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11401141,
"from":L[105]});
}
} catch($e11321133) {
if(R.isCont($e11321133)) {
var $ss11361137 = {"from":L[105],
"go":function(ann_DASH_check_DASH_temp26961142) {
return $Hann_DASH_check_DASH_temp38911143(ann_DASH_check_DASH_temp26961142);
}};
$e11321133.stack[R.EXN_STACKHEIGHT++] = $ss11361137;
}
if(R.isPyretException($e11321133)) {
$e11321133.pyretStack.push(L[105]);
}
throw $e11321133;
}
var $ret11381139 = $Hann_DASH_check_DASH_temp38911143($z11341135);
++R.GAS;
return $ret11381139;
});
var $z11191120 = D;
var $f11251126 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg26971127,seen_DASH_so_DASH_far903890,args9201116):R.ffi.throwNonFunApp(L[104],fold5391,[anf_arg26971127,seen_DASH_so_DASH_far903890,args9201116]);
};
try {
if(--R.GAS > 0) {
$z11191120 = $f11251126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11251126,
"from":L[104]});
}
} catch($e11171118) {
if(R.isCont($e11171118)) {
var $ss11211122 = {"from":L[104],
"go":function(ann_DASH_check_DASH_temp26951128) {
return $Hann_DASH_check_DASH_temp38921129(ann_DASH_check_DASH_temp26951128);
}};
$e11171118.stack[R.EXN_STACKHEIGHT++] = $ss11211122;
}
if(R.isPyretException($e11171118)) {
$e11171118.pyretStack.push(L[104]);
}
throw $e11171118;
}
var $ret11231124 = $Hann_DASH_check_DASH_temp38921129($z11191120);
++R.GAS;
return $ret11231124;
});
var anf_obj2710922 = R.makeFunction(function($underscore9231098,args9241099,ret9251100,body9261101) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[102],4,arguments);
}
var $z11041105 = D;
var $f11101111 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(body9261101,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[103],freevars_DASH_e_DASH_acc795671.$var,[body9261101,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z11041105 = $f11101111();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11101111,
"from":L[103]});
}
} catch($e11021103) {
if(R.isCont($e11021103)) {
var $ss11061107 = {"from":L[103],
"go":function(from_DASH_body9271112) {
return $Hfrom_DASH_body38991113(from_DASH_body9271112,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100,sets1543);
}};
$e11021103.stack[R.EXN_STACKHEIGHT++] = $ss11061107;
}
if(R.isPyretException($e11021103)) {
$e11021103.pyretStack.push(L[103]);
}
throw $e11021103;
}
var $ret11081109 = $Hfrom_DASH_body38991113($z11041105,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100,sets1543);
++R.GAS;
return $ret11081109;
});
var anf_obj2722923 = R.makeFunction(function($underscore9321082,args9331083,ret9341084,body9351085) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[100],4,arguments);
}
var $z10881089 = D;
var $f10941095 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(body9351085,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[101],freevars_DASH_e_DASH_acc795671.$var,[body9351085,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z10881089 = $f10941095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10941095,
"from":L[101]});
}
} catch($e10861087) {
if(R.isCont($e10861087)) {
var $ss10901091 = {"from":L[101],
"go":function(from_DASH_body9361096) {
return $Hfrom_DASH_body39061097(from_DASH_body9361096,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084,sets1543);
}};
$e10861087.stack[R.EXN_STACKHEIGHT++] = $ss10901091;
}
if(R.isPyretException($e10861087)) {
$e10861087.pyretStack.push(L[101]);
}
throw $e10861087;
}
var $ret10921093 = $Hfrom_DASH_body39061097($z10881089,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084,sets1543);
++R.GAS;
return $ret10921093;
});
var anf_obj2727924 = R.makeFunction(function($underscore9411052,fields9421053) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[96],2,arguments);
}
var anf_arg27261064 = R.makeFunction(function(acc9431067,f9441068) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[97],2,arguments);
}
var anf_arg27251079 = G(f9441068,"value",L[99]);
var $z10711072 = D;
var $f10771078 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[98],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[98],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(anf_arg27251079,acc9431067):R.ffi.throwNonFunApp(L[97],freevars_DASH_v_DASH_acc800681.$var === D?U(L[98],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[anf_arg27251079,acc9431067]);
};
try {
if(--R.GAS > 0) {
$z10711072 = $f10771078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10771078,
"from":L[97]});
}
} catch($e10691070) {
if(R.isCont($e10691070)) {
var $ss10731074 = {"from":L[97],
"go":function(ann_DASH_check_DASH_temp27241080) {
return $Hann_DASH_check_DASH_temp39071081(ann_DASH_check_DASH_temp27241080);
}};
$e10691070.stack[R.EXN_STACKHEIGHT++] = $ss10731074;
}
if(R.isPyretException($e10691070)) {
$e10691070.pyretStack.push(L[97]);
}
throw $e10691070;
}
var $ret10751076 = $Hann_DASH_check_DASH_temp39071081($z10711072);
++R.GAS;
return $ret10751076;
});
var $z10561057 = D;
var $f10621063 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg27261064,seen_DASH_so_DASH_far903890,fields9421053):R.ffi.throwNonFunApp(L[96],fold5391,[anf_arg27261064,seen_DASH_so_DASH_far903890,fields9421053]);
};
try {
if(--R.GAS > 0) {
$z10561057 = $f10621063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10621063,
"from":L[96]});
}
} catch($e10541055) {
if(R.isCont($e10541055)) {
var $ss10581059 = {"from":L[96],
"go":function(ann_DASH_check_DASH_temp27231065) {
return $Hann_DASH_check_DASH_temp39081066(ann_DASH_check_DASH_temp27231065);
}};
$e10541055.stack[R.EXN_STACKHEIGHT++] = $ss10581059;
}
if(R.isPyretException($e10541055)) {
$e10541055.pyretStack.push(L[96]);
}
throw $e10541055;
}
var $ret10601061 = $Hann_DASH_check_DASH_temp39081066($z10561057);
++R.GAS;
return $ret10601061;
});
var anf_obj2732925 = R.makeFunction(function($underscore9451037,supe9461038,fields9471039) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[93],3,arguments);
}
var $z10421043 = D;
var $f10481049 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[94],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[94],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(supe9461038,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[95],freevars_DASH_v_DASH_acc800681.$var === D?U(L[94],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[supe9461038,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z10421043 = $f10481049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10481049,
"from":L[95]});
}
} catch($e10401041) {
if(R.isCont($e10401041)) {
var $ss10441045 = {"from":L[95],
"go":function(from_DASH_supe9481050) {
return $Hfrom_DASH_supe39111051(from_DASH_supe9481050,fields9471039,fold5391,freevars_DASH_v_DASH_acc800681);
}};
$e10401041.stack[R.EXN_STACKHEIGHT++] = $ss10441045;
}
if(R.isPyretException($e10401041)) {
$e10401041.pyretStack.push(L[95]);
}
throw $e10401041;
}
var $ret10461047 = $Hfrom_DASH_supe39111051($z10421043,fields9471039,fold5391,freevars_DASH_v_DASH_acc800681);
++R.GAS;
return $ret10461047;
});
var anf_obj2740926 = R.makeFunction(function($underscore9511005,$underscore9521006,namet9531007,variants9541008,shared9551009) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[90],5,arguments);
}
var anf_arg27351020 = R.makeFunction(function(acc9571023,v9581024) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[92],2,arguments);
}
var $z10271028 = D;
var $f10331034 = function(_) {
return R.isFunction(freevars_DASH_variant_DASH_acc797675.$var)?freevars_DASH_variant_DASH_acc797675.$var.app(v9581024,acc9571023):R.ffi.throwNonFunApp(L[92],freevars_DASH_variant_DASH_acc797675.$var,[v9581024,acc9571023]);
};
try {
if(--R.GAS > 0) {
$z10271028 = $f10331034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10331034,
"from":L[92]});
}
} catch($e10251026) {
if(R.isCont($e10251026)) {
var $ss10291030 = {"from":L[92],
"go":function(ann_DASH_check_DASH_temp27341035) {
return $Hann_DASH_check_DASH_temp39121036(ann_DASH_check_DASH_temp27341035);
}};
$e10251026.stack[R.EXN_STACKHEIGHT++] = $ss10291030;
}
if(R.isPyretException($e10251026)) {
$e10251026.pyretStack.push(L[92]);
}
throw $e10251026;
}
var $ret10311032 = $Hann_DASH_check_DASH_temp39121036($z10271028);
++R.GAS;
return $ret10311032;
});
var $z10121013 = D;
var $f10181019 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg27351020,seen_DASH_so_DASH_far903890,variants9541008):R.ffi.throwNonFunApp(L[91],fold5391,[anf_arg27351020,seen_DASH_so_DASH_far903890,variants9541008]);
};
try {
if(--R.GAS > 0) {
$z10121013 = $f10181019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10181019,
"from":L[91]});
}
} catch($e10101011) {
if(R.isCont($e10101011)) {
var $ss10141015 = {"from":L[91],
"go":function(from_DASH_variants9561021) {
return $Hfrom_DASH_variants39161022(from_DASH_variants9561021,fold5391,freevars_DASH_v_DASH_acc800681,namet9531007,shared9551009);
}};
$e10101011.stack[R.EXN_STACKHEIGHT++] = $ss10141015;
}
if(R.isPyretException($e10101011)) {
$e10101011.pyretStack.push(L[91]);
}
throw $e10101011;
}
var $ret10161017 = $Hfrom_DASH_variants39161022($z10121013,fold5391,freevars_DASH_v_DASH_acc800681,namet9531007,shared9551009);
++R.GAS;
return $ret10161017;
});
var anf_obj2745927 = R.makeFunction(function($underscore962990,supe963991,fields964992) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[87],3,arguments);
}
var $z995996 = D;
var $f10011002 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[88],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[88],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(supe963991,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[89],freevars_DASH_v_DASH_acc800681.$var === D?U(L[88],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[supe963991,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z995996 = $f10011002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10011002,
"from":L[89]});
}
} catch($e993994) {
if(R.isCont($e993994)) {
var $ss997998 = {"from":L[89],
"go":function(from_DASH_supe9651003) {
return $Hfrom_DASH_supe39191004(from_DASH_supe9651003,fields964992,fold5391,freevars_DASH_v_DASH_acc800681);
}};
$e993994.stack[R.EXN_STACKHEIGHT++] = $ss997998;
}
if(R.isPyretException($e993994)) {
$e993994.pyretStack.push(L[89]);
}
throw $e993994;
}
var $ret9991000 = $Hfrom_DASH_supe39191004($z995996,fields964992,fold5391,freevars_DASH_v_DASH_acc800681);
++R.GAS;
return $ret9991000;
});
var anf_obj2747928 = R.makeFunction(function($underscore968975,obj969976,$underscore970977) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[85],3,arguments);
}
var $z980981 = D;
var $f986987 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[86],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[86],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(obj969976,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[85],freevars_DASH_v_DASH_acc800681.$var === D?U(L[86],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[obj969976,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z980981 = $f986987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f986987,
"from":L[85]});
}
} catch($e978979) {
if(R.isCont($e978979)) {
var $ss982983 = {"from":L[85],
"go":function(ann_DASH_check_DASH_temp2746988) {
return $Hann_DASH_check_DASH_temp3920989(ann_DASH_check_DASH_temp2746988);
}};
$e978979.stack[R.EXN_STACKHEIGHT++] = $ss982983;
}
if(R.isPyretException($e978979)) {
$e978979.pyretStack.push(L[85]);
}
throw $e978979;
}
var $ret984985 = $Hann_DASH_check_DASH_temp3920989($z980981);
++R.GAS;
return $ret984985;
});
var anf_obj2749929 = R.makeFunction(function($underscore971960,obj972961,$underscore973962) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[83],3,arguments);
}
var $z965966 = D;
var $f971972 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[84],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[84],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(obj972961,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[83],freevars_DASH_v_DASH_acc800681.$var === D?U(L[84],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[obj972961,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z965966 = $f971972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f971972,
"from":L[83]});
}
} catch($e963964) {
if(R.isCont($e963964)) {
var $ss967968 = {"from":L[83],
"go":function(ann_DASH_check_DASH_temp2748973) {
return $Hann_DASH_check_DASH_temp3921974(ann_DASH_check_DASH_temp2748973);
}};
$e963964.stack[R.EXN_STACKHEIGHT++] = $ss967968;
}
if(R.isPyretException($e963964)) {
$e963964.pyretStack.push(L[83]);
}
throw $e963964;
}
var $ret969970 = $Hann_DASH_check_DASH_temp3921974($z965966);
++R.GAS;
return $ret969970;
});
var anf_obj2751930 = R.makeFunction(function($underscore974945,obj975946,$underscore976947) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[81],3,arguments);
}
var $z950951 = D;
var $f956957 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[82],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[82],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(obj975946,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[81],freevars_DASH_v_DASH_acc800681.$var === D?U(L[82],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[obj975946,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z950951 = $f956957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f956957,
"from":L[81]});
}
} catch($e948949) {
if(R.isCont($e948949)) {
var $ss952953 = {"from":L[81],
"go":function(ann_DASH_check_DASH_temp2750958) {
return $Hann_DASH_check_DASH_temp3922959(ann_DASH_check_DASH_temp2750958);
}};
$e948949.stack[R.EXN_STACKHEIGHT++] = $ss952953;
}
if(R.isPyretException($e948949)) {
$e948949.pyretStack.push(L[81]);
}
throw $e948949;
}
var $ret954955 = $Hann_DASH_check_DASH_temp3922959($z950951);
++R.GAS;
return $ret954955;
});
var anf_obj2753931 = R.makeFunction(function(v977932) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[79],1,arguments);
}
var $z935936 = D;
var $f941942 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[80],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[80],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(v977932,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[79],freevars_DASH_v_DASH_acc800681.$var === D?U(L[80],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[v977932,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z935936 = $f941942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f941942,
"from":L[79]});
}
} catch($e933934) {
if(R.isCont($e933934)) {
var $ss937938 = {"from":L[79],
"go":function(ann_DASH_check_DASH_temp2752943) {
return $Hann_DASH_check_DASH_temp3923944(ann_DASH_check_DASH_temp2752943);
}};
$e933934.stack[R.EXN_STACKHEIGHT++] = $ss937938;
}
if(R.isPyretException($e933934)) {
$e933934.pyretStack.push(L[79]);
}
throw $e933934;
}
var $ret939940 = $Hann_DASH_check_DASH_temp3923944($z935936);
++R.GAS;
return $ret939940;
});
var anf_arg2754902 = R.makeObject({"a-module":anf_obj2686918,
"a-assign":anf_obj2690919,
"a-app":anf_obj2694920,
"a-prim-app":anf_obj2698921,
"a-lam":anf_obj2710922,
"a-method":anf_obj2722923,
"a-obj":anf_obj2727924,
"a-update":anf_obj2732925,
"a-data-expr":anf_obj2740926,
"a-extend":anf_obj2745927,
"a-dot":anf_obj2747928,
"a-colon":anf_obj2749929,
"a-get-bang":anf_obj2751930,
"a-val":anf_obj2753931});
var anf_arg2758903 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[77],0,arguments);
}
var $z908909 = D;
var $f914915 = function(_) {
return R.isFunction(torepr31)?torepr31.app(e902889):R.ffi.throwNonFunApp(L[78],torepr31,[e902889]);
};
try {
if(--R.GAS > 0) {
$z908909 = $f914915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f914915,
"from":L[78]});
}
} catch($e906907) {
if(R.isCont($e906907)) {
var $ss910911 = {"from":L[78],
"go":function(anf_arg2756916) {
return $Hanf_arg3926917(anf_arg2756916,_plus26,raise30);
}};
$e906907.stack[R.EXN_STACKHEIGHT++] = $ss910911;
}
if(R.isPyretException($e906907)) {
$e906907.pyretStack.push(L[78]);
}
throw $e906907;
}
var $ret912913 = $Hanf_arg3926917($z908909,_plus26,raise30);
++R.GAS;
return $ret912913;
});
var $z893894 = D;
var $f899900 = function(_) {
return R.isFunction(anf_fun2677901)?anf_fun2677901.app(anf_arg2754902,anf_arg2758903):R.ffi.throwNonFunApp(L[76],anf_fun2677901,[anf_arg2754902,anf_arg2758903]);
};
try {
if(--R.GAS > 0) {
$z893894 = $f899900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f899900,
"from":L[76]});
}
} catch($e891892) {
if(R.isCont($e891892)) {
var $ss895896 = {"from":L[76],
"go":function(ann_DASH_check_DASH_temp2676904) {
return $Hann_DASH_check_DASH_temp3927905(ann_DASH_check_DASH_temp2676904,A244,Set2090);
}};
$e891892.stack[R.EXN_STACKHEIGHT++] = $ss895896;
}
if(R.isPyretException($e891892)) {
$e891892.pyretStack.push(L[76]);
}
throw $e891892;
}
var $ret897898 = $Hann_DASH_check_DASH_temp3927905($z893894,A244,Set2090);
++R.GAS;
return $ret897898;
});
});
freevars_DASH_l_DASH_acc798677.$var = anf_assign2759678;
var anf_assign2762680 = R.makeFunction(function(e978875) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[73],1,arguments);
}
return R.checkAnnArgs([ALettable8473],[e978875],[L[75]],function() {
var anf_arg2761886 = G(sets1543,"empty-tree-set",L[74]);
var $z878879 = D;
var $f884885 = function(_) {
return R.isFunction(freevars_DASH_l_DASH_acc798677.$var)?freevars_DASH_l_DASH_acc798677.$var.app(e978875,anf_arg2761886):R.ffi.throwNonFunApp(L[73],freevars_DASH_l_DASH_acc798677.$var,[e978875,anf_arg2761886]);
};
try {
if(--R.GAS > 0) {
$z878879 = $f884885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f884885,
"from":L[73]});
}
} catch($e876877) {
if(R.isCont($e876877)) {
var $ss880881 = {"from":L[73],
"go":function(ann_DASH_check_DASH_temp2760887) {
return $Hann_DASH_check_DASH_temp3928888(ann_DASH_check_DASH_temp2760887,A244,Set2090);
}};
$e876877.stack[R.EXN_STACKHEIGHT++] = $ss880881;
}
if(R.isPyretException($e876877)) {
$e876877.pyretStack.push(L[73]);
}
throw $e876877;
}
var $ret882883 = $Hann_DASH_check_DASH_temp3928888($z878879,A244,Set2090);
++R.GAS;
return $ret882883;
});
});
freevars_DASH_l799679.$var = anf_assign2762680;
var anf_assign2793682 = R.makeFunction(function(v979747,seen_DASH_so_DASH_far980748) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[55],2,arguments);
}
return R.checkAnnArgs([AVal8881,Set2090],[v979747,seen_DASH_so_DASH_far980748],[L[71],L[72]],function() {
var cases_DASH_val319874 = v979747;
var anf_fun2764759 = G(cases_DASH_val319874,"_match",L[56]);
var anf_obj2768776 = R.makeFunction(function($underscore981845,vs982846) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[69],2,arguments);
}
var anf_arg2767857 = R.makeFunction(function(acc983860,v984861) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[70],2,arguments);
}
var $z864865 = D;
var $f870871 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var.app(v984861,acc983860):R.ffi.throwNonFunApp(L[70],freevars_DASH_v_DASH_acc800681.$var,[v984861,acc983860]);
};
try {
if(--R.GAS > 0) {
$z864865 = $f870871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f870871,
"from":L[70]});
}
} catch($e862863) {
if(R.isCont($e862863)) {
var $ss866867 = {"from":L[70],
"go":function(ann_DASH_check_DASH_temp2766872) {
return $Hann_DASH_check_DASH_temp3929873(ann_DASH_check_DASH_temp2766872);
}};
$e862863.stack[R.EXN_STACKHEIGHT++] = $ss866867;
}
if(R.isPyretException($e862863)) {
$e862863.pyretStack.push(L[70]);
}
throw $e862863;
}
var $ret868869 = $Hann_DASH_check_DASH_temp3929873($z864865);
++R.GAS;
return $ret868869;
});
var $z849850 = D;
var $f855856 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg2767857,seen_DASH_so_DASH_far980748,vs982846):R.ffi.throwNonFunApp(L[69],fold5391,[anf_arg2767857,seen_DASH_so_DASH_far980748,vs982846]);
};
try {
if(--R.GAS > 0) {
$z849850 = $f855856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f855856,
"from":L[69]});
}
} catch($e847848) {
if(R.isCont($e847848)) {
var $ss851852 = {"from":L[69],
"go":function(ann_DASH_check_DASH_temp2765858) {
return $Hann_DASH_check_DASH_temp3930859(ann_DASH_check_DASH_temp2765858);
}};
$e847848.stack[R.EXN_STACKHEIGHT++] = $ss851852;
}
if(R.isPyretException($e847848)) {
$e847848.pyretStack.push(L[69]);
}
throw $e847848;
}
var $ret853854 = $Hann_DASH_check_DASH_temp3930859($z849850);
++R.GAS;
return $ret853854;
});
var anf_obj2771777 = R.makeFunction(function($underscore985830,id986831) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[67],2,arguments);
}
var anf_fun2770842 = G(seen_DASH_so_DASH_far980748,"add",L[68]);
var $z834835 = D;
var $f840841 = function(_) {
return R.isFunction(anf_fun2770842)?anf_fun2770842.app(id986831):R.ffi.throwNonFunApp(L[67],anf_fun2770842,[id986831]);
};
try {
if(--R.GAS > 0) {
$z834835 = $f840841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f840841,
"from":L[67]});
}
} catch($e832833) {
if(R.isCont($e832833)) {
var $ss836837 = {"from":L[67],
"go":function(ann_DASH_check_DASH_temp2769843) {
return $Hann_DASH_check_DASH_temp3931844(ann_DASH_check_DASH_temp2769843);
}};
$e832833.stack[R.EXN_STACKHEIGHT++] = $ss836837;
}
if(R.isPyretException($e832833)) {
$e832833.pyretStack.push(L[67]);
}
throw $e832833;
}
var $ret838839 = $Hann_DASH_check_DASH_temp3931844($z834835);
++R.GAS;
return $ret838839;
});
var anf_obj2774778 = R.makeFunction(function($underscore987815,id988816) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[65],2,arguments);
}
var anf_fun2773827 = G(seen_DASH_so_DASH_far980748,"add",L[66]);
var $z819820 = D;
var $f825826 = function(_) {
return R.isFunction(anf_fun2773827)?anf_fun2773827.app(id988816):R.ffi.throwNonFunApp(L[65],anf_fun2773827,[id988816]);
};
try {
if(--R.GAS > 0) {
$z819820 = $f825826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f825826,
"from":L[65]});
}
} catch($e817818) {
if(R.isCont($e817818)) {
var $ss821822 = {"from":L[65],
"go":function(ann_DASH_check_DASH_temp2772828) {
return $Hann_DASH_check_DASH_temp3932829(ann_DASH_check_DASH_temp2772828);
}};
$e817818.stack[R.EXN_STACKHEIGHT++] = $ss821822;
}
if(R.isPyretException($e817818)) {
$e817818.pyretStack.push(L[65]);
}
throw $e817818;
}
var $ret823824 = $Hann_DASH_check_DASH_temp3932829($z819820);
++R.GAS;
return $ret823824;
});
var anf_obj2777779 = R.makeFunction(function($underscore989799,id990800,$underscore991801) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[63],3,arguments);
}
var anf_fun2776812 = G(seen_DASH_so_DASH_far980748,"add",L[64]);
var $z804805 = D;
var $f810811 = function(_) {
return R.isFunction(anf_fun2776812)?anf_fun2776812.app(id990800):R.ffi.throwNonFunApp(L[63],anf_fun2776812,[id990800]);
};
try {
if(--R.GAS > 0) {
$z804805 = $f810811();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f810811,
"from":L[63]});
}
} catch($e802803) {
if(R.isCont($e802803)) {
var $ss806807 = {"from":L[63],
"go":function(ann_DASH_check_DASH_temp2775813) {
return $Hann_DASH_check_DASH_temp3933814(ann_DASH_check_DASH_temp2775813);
}};
$e802803.stack[R.EXN_STACKHEIGHT++] = $ss806807;
}
if(R.isPyretException($e802803)) {
$e802803.pyretStack.push(L[63]);
}
throw $e802803;
}
var $ret808809 = $Hann_DASH_check_DASH_temp3933814($z804805);
++R.GAS;
return $ret808809;
});
var anf_obj2779780 = R.makeFunction(function($underscore992796,$underscore993797) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[62],2,arguments);
}
var ann_DASH_check_DASH_temp2778798 = seen_DASH_so_DASH_far980748;
return ann_DASH_check_DASH_temp2778798;
});
var anf_obj2781781 = R.makeFunction(function($underscore994793,$underscore995794) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[61],2,arguments);
}
var ann_DASH_check_DASH_temp2780795 = seen_DASH_so_DASH_far980748;
return ann_DASH_check_DASH_temp2780795;
});
var anf_obj2783782 = R.makeFunction(function($underscore996790,$underscore997791) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[60],2,arguments);
}
var ann_DASH_check_DASH_temp2782792 = seen_DASH_so_DASH_far980748;
return ann_DASH_check_DASH_temp2782792;
});
var anf_obj2785783 = R.makeFunction(function($underscore998787,$underscore999788) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[59],2,arguments);
}
var ann_DASH_check_DASH_temp2784789 = seen_DASH_so_DASH_far980748;
return ann_DASH_check_DASH_temp2784789;
});
var anf_obj2787784 = R.makeFunction(function($underscore1000785) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[58],1,arguments);
}
var ann_DASH_check_DASH_temp2786786 = seen_DASH_so_DASH_far980748;
return ann_DASH_check_DASH_temp2786786;
});
var anf_arg2788760 = R.makeObject({"a-array":anf_obj2768776,
"a-id":anf_obj2771777,
"a-id-var":anf_obj2774778,
"a-id-letrec":anf_obj2777779,
"a-srcloc":anf_obj2779780,
"a-num":anf_obj2781781,
"a-str":anf_obj2783782,
"a-bool":anf_obj2785783,
"a-undefined":anf_obj2787784});
var anf_arg2792761 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[56],0,arguments);
}
var $z766767 = D;
var $f772773 = function(_) {
return R.isFunction(torepr31)?torepr31.app(v979747):R.ffi.throwNonFunApp(L[57],torepr31,[v979747]);
};
try {
if(--R.GAS > 0) {
$z766767 = $f772773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f772773,
"from":L[57]});
}
} catch($e764765) {
if(R.isCont($e764765)) {
var $ss768769 = {"from":L[57],
"go":function(anf_arg2790774) {
return $Hanf_arg3936775(anf_arg2790774,_plus26,raise30);
}};
$e764765.stack[R.EXN_STACKHEIGHT++] = $ss768769;
}
if(R.isPyretException($e764765)) {
$e764765.pyretStack.push(L[57]);
}
throw $e764765;
}
var $ret770771 = $Hanf_arg3936775($z766767,_plus26,raise30);
++R.GAS;
return $ret770771;
});
var $z751752 = D;
var $f757758 = function(_) {
return R.isFunction(anf_fun2764759)?anf_fun2764759.app(anf_arg2788760,anf_arg2792761):R.ffi.throwNonFunApp(L[55],anf_fun2764759,[anf_arg2788760,anf_arg2792761]);
};
try {
if(--R.GAS > 0) {
$z751752 = $f757758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f757758,
"from":L[55]});
}
} catch($e749750) {
if(R.isCont($e749750)) {
var $ss753754 = {"from":L[55],
"go":function(ann_DASH_check_DASH_temp2763762) {
return $Hann_DASH_check_DASH_temp3937763(ann_DASH_check_DASH_temp2763762,A244,Set2090);
}};
$e749750.stack[R.EXN_STACKHEIGHT++] = $ss753754;
}
if(R.isPyretException($e749750)) {
$e749750.pyretStack.push(L[55]);
}
throw $e749750;
}
var $ret755756 = $Hann_DASH_check_DASH_temp3937763($z751752,A244,Set2090);
++R.GAS;
return $ret755756;
});
});
freevars_DASH_v_DASH_acc800681.$var = anf_assign2793682;
var anf_assign2796684 = R.makeFunction(function(v1001733) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[52],1,arguments);
}
return R.checkAnnArgs([AVal8881],[v1001733],[L[54]],function() {
var anf_arg2795744 = G(sets1543,"empty-tree-set",L[53]);
var $z736737 = D;
var $f742743 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var.app(v1001733,anf_arg2795744):R.ffi.throwNonFunApp(L[52],freevars_DASH_v_DASH_acc800681.$var,[v1001733,anf_arg2795744]);
};
try {
if(--R.GAS > 0) {
$z736737 = $f742743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f742743,
"from":L[52]});
}
} catch($e734735) {
if(R.isCont($e734735)) {
var $ss738739 = {"from":L[52],
"go":function(ann_DASH_check_DASH_temp2794745) {
return $Hann_DASH_check_DASH_temp3938746(ann_DASH_check_DASH_temp2794745,A244,Set2090);
}};
$e734735.stack[R.EXN_STACKHEIGHT++] = $ss738739;
}
if(R.isPyretException($e734735)) {
$e734735.pyretStack.push(L[52]);
}
throw $e734735;
}
var $ret740741 = $Hann_DASH_check_DASH_temp3938746($z736737,A244,Set2090);
++R.GAS;
return $ret740741;
});
});
freevars_DASH_v801683.$var = anf_assign2796684;
var anf_assign2802686 = R.makeFunction(function(ss1003703) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[47],1,arguments);
}
return R.checkAnnArgs([List1788],[ss1003703],[L[51]],function() {
var anf_arg2800714 = R.makeFunction(function(unioned1004718,s1005719) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[49],2,arguments);
}
var anf_fun2799730 = G(unioned1004718,"union",L[50]);
var $z722723 = D;
var $f728729 = function(_) {
return R.isFunction(anf_fun2799730)?anf_fun2799730.app(s1005719):R.ffi.throwNonFunApp(L[49],anf_fun2799730,[s1005719]);
};
try {
if(--R.GAS > 0) {
$z722723 = $f728729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f728729,
"from":L[49]});
}
} catch($e720721) {
if(R.isCont($e720721)) {
var $ss724725 = {"from":L[49],
"go":function(ann_DASH_check_DASH_temp2798731) {
return $Hann_DASH_check_DASH_temp3939732(ann_DASH_check_DASH_temp2798731);
}};
$e720721.stack[R.EXN_STACKHEIGHT++] = $ss724725;
}
if(R.isPyretException($e720721)) {
$e720721.pyretStack.push(L[49]);
}
throw $e720721;
}
var $ret726727 = $Hann_DASH_check_DASH_temp3939732($z722723);
++R.GAS;
return $ret726727;
});
var anf_arg2801715 = G(sets1543,"empty-tree-set",L[48]);
var $z706707 = D;
var $f712713 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg2800714,anf_arg2801715,ss1003703):R.ffi.throwNonFunApp(L[47],fold5391,[anf_arg2800714,anf_arg2801715,ss1003703]);
};
try {
if(--R.GAS > 0) {
$z706707 = $f712713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f712713,
"from":L[47]});
}
} catch($e704705) {
if(R.isCont($e704705)) {
var $ss708709 = {"from":L[47],
"go":function(ann_DASH_check_DASH_temp2797716) {
return $Hann_DASH_check_DASH_temp3940717(ann_DASH_check_DASH_temp2797716,Set2090);
}};
$e704705.stack[R.EXN_STACKHEIGHT++] = $ss708709;
}
if(R.isPyretException($e704705)) {
$e704705.pyretStack.push(L[47]);
}
throw $e704705;
}
var $ret710711 = $Hann_DASH_check_DASH_temp3940717($z706707,Set2090);
++R.GAS;
return $ret710711;
});
});
unions802685.$var = anf_assign2802686;
var result_DASH_after_DASH_checks11006701 = nothing29;
var anf_fun2803697 = G(builtins28,"current-checker",L[46]);
var $z689690 = D;
var $f695696 = function(_) {
return R.isFunction(anf_fun2803697)?anf_fun2803697.app():R.ffi.throwNonFunApp(L[46],anf_fun2803697,[]);
};
try {
if(--R.GAS > 0) {
$z689690 = $f695696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f695696,
"from":L[46]});
}
} catch($e687688) {
if(R.isCont($e687688)) {
var $ss691692 = {"from":L[46],
"go":function(anf_bracket2804698) {
return $Hanf_bracket3960702(anf_bracket2804698,A136,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,list2593,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28);
}};
$e687688.stack[R.EXN_STACKHEIGHT++] = $ss691692;
}
if(R.isPyretException($e687688)) {
$e687688.pyretStack.push(L[46]);
}
throw $e687688;
}
var $ret693694 = $Hanf_bracket3960702($z689690,A136,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,list2593,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28);
++R.GAS;
return $ret693694;
};
var $Hanf_bracket3960702 = function(anf_bracket2804698,A136,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,list2593,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28) {
var anf_fun28057317 = G(anf_bracket2804698,"run-checks",L[46]);
var anf_fun28067314 = G(list2593,"make",L[46]);
var anf_obj28267319 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[129],0,arguments);
}
var d10077333 = dummy_DASH_loc115391;
var anf_bracket28087335 = G(A136,"global-names",L[1182]);
var n10087331 = G(anf_bracket28087335,"make-atom",L[1181]);
var $z73237324 = D;
var $f73297330 = function(_) {
return R.isFunction(n10087331)?n10087331.app(("x")):R.ffi.throwNonFunApp(L[1180],n10087331,[("x")]);
};
try {
if(--R.GAS > 0) {
$z73237324 = $f73297330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73297330,
"from":L[1180]});
}
} catch($e73217322) {
if(R.isCont($e73217322)) {
var $ss73257326 = {"from":L[1180],
"go":function(x10097332) {
return $Hx39547334(x10097332,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,n10087331,builtins28);
}};
$e73217322.stack[R.EXN_STACKHEIGHT++] = $ss73257326;
}
if(R.isPyretException($e73217322)) {
$e73217322.pyretStack.push(L[1180]);
}
throw $e73217322;
}
var $ret73277328 = $Hx39547334($z73237324,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,n10087331,builtins28);
++R.GAS;
return $ret73277328;
});
var anf_obj28277320 = R.makeSrcloc(L[129]);
var anf_array_val28287315 = R.makeObject({"name":("freevars-e"),
"run":anf_obj28267319,
"location":anf_obj28277320});
var $z73067307 = D;
var $f73127313 = function(_) {
return R.isFunction(anf_fun28067314)?anf_fun28067314.app([anf_array_val28287315]):R.ffi.throwNonFunApp(L[46],anf_fun28067314,[[anf_array_val28287315]]);
};
try {
if(--R.GAS > 0) {
$z73067307 = $f73127313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73127313,
"from":L[46]});
}
} catch($e73047305) {
if(R.isCont($e73047305)) {
var $ss73087309 = {"from":L[46],
"go":function(anf_arg28297316) {
return $Hanf_arg39597318(anf_arg28297316,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,anf_fun28057317,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28);
}};
$e73047305.stack[R.EXN_STACKHEIGHT++] = $ss73087309;
}
if(R.isPyretException($e73047305)) {
$e73047305.pyretStack.push(L[46]);
}
throw $e73047305;
}
var $ret73107311 = $Hanf_arg39597318($z73067307,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,anf_fun28057317,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28);
++R.GAS;
return $ret73107311;
};
var $Hanf_arg39597318 = function(anf_arg28297316,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,anf_fun28057317,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28) {
var $z73387339 = D;
var $f73447345 = function(_) {
return R.isFunction(anf_fun28057317)?anf_fun28057317.app(("src/arr/compiler/ast-anf.arr"),anf_arg28297316):R.ffi.throwNonFunApp(L[46],anf_fun28057317,[("src/arr/compiler/ast-anf.arr"),anf_arg28297316]);
};
try {
if(--R.GAS > 0) {
$z73387339 = $f73447345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73447345,
"from":L[46]});
}
} catch($e73367337) {
if(R.isCont($e73367337)) {
var $ss73407341 = {"from":L[46],
"go":function(anf_begin_app_dropped39557346) {
return $Hanf_begin_app_dropped39587347(anf_begin_app_dropped39557346,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28);
}};
$e73367337.stack[R.EXN_STACKHEIGHT++] = $ss73407341;
}
if(R.isPyretException($e73367337)) {
$e73367337.pyretStack.push(L[46]);
}
throw $e73367337;
}
var $ret73427343 = $Hanf_begin_app_dropped39587347($z73387339,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28);
++R.GAS;
return $ret73427343;
};
var $Hanf_begin_app_dropped39587347 = function(anf_begin_app_dropped39557346,ABind163485,ABind7663,AExpr144447,AExpr7465,AField221601,AField8667,AImport130419,AImport7069,AImportType123405,AImportType6871,ALettable189537,ALettable8473,AMemberType175509,AMemberType8075,AProg118395,AProg6677,ATypeBind137433,ATypeBind7279,AVal226611,AVal8881,AVariant168495,AVariant7883,AVariantMember184527,AVariantMember8284,INDENT9187,Loc116699,Loc9089,a_DASH_app198555,a_DASH_array237633,a_DASH_assign196551,a_DASH_bind166491,a_DASH_bool235629,a_DASH_colon210579,a_DASH_cyclic180519,a_DASH_data_DASH_expr194547,a_DASH_dot208575,a_DASH_extend206571,a_DASH_field224607,a_DASH_get_DASH_bang212583,a_DASH_id_DASH_letrec245649,a_DASH_id_DASH_var243645,a_DASH_id241641,a_DASH_if159477,a_DASH_import_DASH_builtin126411,a_DASH_import_DASH_file128415,a_DASH_import_DASH_types135429,a_DASH_import133425,a_DASH_lam214587,a_DASH_let149457,a_DASH_lettable161481,a_DASH_method216591,a_DASH_module192543,a_DASH_mutable182523,a_DASH_newtype_DASH_bind142443,a_DASH_normal178515,a_DASH_num231621,a_DASH_obj202563,a_DASH_prim_DASH_app200559,a_DASH_program121401,a_DASH_seq153465,a_DASH_singleton_DASH_variant173505,a_DASH_split_DASH_app157473,a_DASH_srcloc229617,a_DASH_str233625,a_DASH_tail_DASH_app155469,a_DASH_type_DASH_bind140439,a_DASH_type_DASH_let147453,a_DASH_undefined239637,a_DASH_update204567,a_DASH_val218595,a_DASH_var151461,a_DASH_variant_DASH_member187533,a_DASH_variant171501,break_DASH_one9262,default_DASH_map_DASH_visitor619700,dummy_DASH_loc115391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_e_DASH_acc795671,freevars_DASH_e796673,freevars_DASH_l_DASH_acc798677,freevars_DASH_l799679,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,freevars_DASH_v801683,freevars_DASH_variant_DASH_acc797675,fun_DASH_method_DASH_pretty219597,is_DASH_ABind164487,is_DASH_AExpr145449,is_DASH_AField222603,is_DASH_AImport131421,is_DASH_AImportType124407,is_DASH_ALettable190539,is_DASH_AMemberType176511,is_DASH_AProg119397,is_DASH_ATypeBind138435,is_DASH_AVal227613,is_DASH_AVariant169497,is_DASH_AVariantMember185529,is_DASH_a_DASH_app197553,is_DASH_a_DASH_array236631,is_DASH_a_DASH_assign195549,is_DASH_a_DASH_bind165489,is_DASH_a_DASH_bool234627,is_DASH_a_DASH_colon209577,is_DASH_a_DASH_cyclic179517,is_DASH_a_DASH_data_DASH_expr193545,is_DASH_a_DASH_dot207573,is_DASH_a_DASH_extend205569,is_DASH_a_DASH_field223605,is_DASH_a_DASH_get_DASH_bang211581,is_DASH_a_DASH_id_DASH_letrec244647,is_DASH_a_DASH_id_DASH_var242643,is_DASH_a_DASH_id240639,is_DASH_a_DASH_if158475,is_DASH_a_DASH_import_DASH_builtin125409,is_DASH_a_DASH_import_DASH_file127413,is_DASH_a_DASH_import_DASH_types134427,is_DASH_a_DASH_import132423,is_DASH_a_DASH_lam213585,is_DASH_a_DASH_let148455,is_DASH_a_DASH_lettable160479,is_DASH_a_DASH_method215589,is_DASH_a_DASH_module191541,is_DASH_a_DASH_mutable181521,is_DASH_a_DASH_newtype_DASH_bind141441,is_DASH_a_DASH_normal177513,is_DASH_a_DASH_num230619,is_DASH_a_DASH_obj201561,is_DASH_a_DASH_prim_DASH_app199557,is_DASH_a_DASH_program120399,is_DASH_a_DASH_seq152463,is_DASH_a_DASH_singleton_DASH_variant172503,is_DASH_a_DASH_split_DASH_app156471,is_DASH_a_DASH_srcloc228615,is_DASH_a_DASH_str232623,is_DASH_a_DASH_tail_DASH_app154467,is_DASH_a_DASH_type_DASH_bind139437,is_DASH_a_DASH_type_DASH_let146451,is_DASH_a_DASH_undefined238635,is_DASH_a_DASH_update203565,is_DASH_a_DASH_val217593,is_DASH_a_DASH_var150459,is_DASH_a_DASH_variant_DASH_member186531,is_DASH_a_DASH_variant170499,result_DASH_after_DASH_checks11006701,str_DASH_as113365,str_DASH_bang96144,str_DASH_brackets97157,str_DASH_colon98170,str_DASH_coloncolon99183,str_DASH_colonspace100196,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_except108300,str_DASH_if105261,str_DASH_import111339,str_DASH_let103235,str_DASH_letrec94118,str_DASH_method93105,str_DASH_newtype114378,str_DASH_period95131,str_DASH_provide112352,str_DASH_spacecolonequal109313,str_DASH_spaceequal110326,str_DASH_try107287,str_DASH_type_DASH_let102222,str_DASH_var104248,strip_DASH_loc_DASH_bind250659,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_field252663,strip_DASH_loc_DASH_import_DASH_type248655,strip_DASH_loc_DASH_import247653,strip_DASH_loc_DASH_lettable251661,strip_DASH_loc_DASH_prog246651,strip_DASH_loc_DASH_val253665,unions802685,builtins28) {
var provides28307360 = R.makeObject({"INDENT":INDENT9187,
"break-one":break_DASH_one9262,
"str-method":str_DASH_method93105,
"str-letrec":str_DASH_letrec94118,
"str-period":str_DASH_period95131,
"str-bang":str_DASH_bang96144,
"str-brackets":str_DASH_brackets97157,
"str-colon":str_DASH_colon98170,
"str-coloncolon":str_DASH_coloncolon99183,
"str-colonspace":str_DASH_colonspace100196,
"str-end":str_DASH_end101209,
"str-type-let":str_DASH_type_DASH_let102222,
"str-let":str_DASH_let103235,
"str-var":str_DASH_var104248,
"str-if":str_DASH_if105261,
"str-elsecolon":str_DASH_elsecolon106274,
"str-try":str_DASH_try107287,
"str-except":str_DASH_except108300,
"str-spacecolonequal":str_DASH_spacecolonequal109313,
"str-spaceequal":str_DASH_spaceequal110326,
"str-import":str_DASH_import111339,
"str-provide":str_DASH_provide112352,
"str-as":str_DASH_as113365,
"str-newtype":str_DASH_newtype114378,
"dummy-loc":dummy_DASH_loc115391,
"Loc":Loc116699,
"AProg":AProg118395.$var,
"is-AProg":is_DASH_AProg119397.$var,
"a-program":a_DASH_program121401.$var,
"is-a-program":is_DASH_a_DASH_program120399.$var,
"AImportType":AImportType123405.$var,
"is-AImportType":is_DASH_AImportType124407.$var,
"a-import-builtin":a_DASH_import_DASH_builtin126411.$var,
"is-a-import-builtin":is_DASH_a_DASH_import_DASH_builtin125409.$var,
"a-import-file":a_DASH_import_DASH_file128415.$var,
"is-a-import-file":is_DASH_a_DASH_import_DASH_file127413.$var,
"AImport":AImport130419.$var,
"is-AImport":is_DASH_AImport131421.$var,
"a-import":a_DASH_import133425.$var,
"is-a-import":is_DASH_a_DASH_import132423.$var,
"a-import-types":a_DASH_import_DASH_types135429.$var,
"is-a-import-types":is_DASH_a_DASH_import_DASH_types134427.$var,
"ATypeBind":ATypeBind137433.$var,
"is-ATypeBind":is_DASH_ATypeBind138435.$var,
"a-type-bind":a_DASH_type_DASH_bind140439.$var,
"is-a-type-bind":is_DASH_a_DASH_type_DASH_bind139437.$var,
"a-newtype-bind":a_DASH_newtype_DASH_bind142443.$var,
"is-a-newtype-bind":is_DASH_a_DASH_newtype_DASH_bind141441.$var,
"AExpr":AExpr144447.$var,
"is-AExpr":is_DASH_AExpr145449.$var,
"a-type-let":a_DASH_type_DASH_let147453.$var,
"is-a-type-let":is_DASH_a_DASH_type_DASH_let146451.$var,
"a-let":a_DASH_let149457.$var,
"is-a-let":is_DASH_a_DASH_let148455.$var,
"a-var":a_DASH_var151461.$var,
"is-a-var":is_DASH_a_DASH_var150459.$var,
"a-seq":a_DASH_seq153465.$var,
"is-a-seq":is_DASH_a_DASH_seq152463.$var,
"a-tail-app":a_DASH_tail_DASH_app155469.$var,
"is-a-tail-app":is_DASH_a_DASH_tail_DASH_app154467.$var,
"a-split-app":a_DASH_split_DASH_app157473.$var,
"is-a-split-app":is_DASH_a_DASH_split_DASH_app156471.$var,
"a-if":a_DASH_if159477.$var,
"is-a-if":is_DASH_a_DASH_if158475.$var,
"a-lettable":a_DASH_lettable161481.$var,
"is-a-lettable":is_DASH_a_DASH_lettable160479.$var,
"ABind":ABind163485.$var,
"is-ABind":is_DASH_ABind164487.$var,
"a-bind":a_DASH_bind166491.$var,
"is-a-bind":is_DASH_a_DASH_bind165489.$var,
"AVariant":AVariant168495.$var,
"is-AVariant":is_DASH_AVariant169497.$var,
"a-variant":a_DASH_variant171501.$var,
"is-a-variant":is_DASH_a_DASH_variant170499.$var,
"a-singleton-variant":a_DASH_singleton_DASH_variant173505.$var,
"is-a-singleton-variant":is_DASH_a_DASH_singleton_DASH_variant172503.$var,
"AMemberType":AMemberType175509.$var,
"is-AMemberType":is_DASH_AMemberType176511.$var,
"a-normal":a_DASH_normal178515.$var,
"is-a-normal":is_DASH_a_DASH_normal177513.$var,
"a-cyclic":a_DASH_cyclic180519.$var,
"is-a-cyclic":is_DASH_a_DASH_cyclic179517.$var,
"a-mutable":a_DASH_mutable182523.$var,
"is-a-mutable":is_DASH_a_DASH_mutable181521.$var,
"AVariantMember":AVariantMember184527.$var,
"is-AVariantMember":is_DASH_AVariantMember185529.$var,
"a-variant-member":a_DASH_variant_DASH_member187533.$var,
"is-a-variant-member":is_DASH_a_DASH_variant_DASH_member186531.$var,
"ALettable":ALettable189537.$var,
"is-ALettable":is_DASH_ALettable190539.$var,
"a-module":a_DASH_module192543.$var,
"is-a-module":is_DASH_a_DASH_module191541.$var,
"a-data-expr":a_DASH_data_DASH_expr194547.$var,
"is-a-data-expr":is_DASH_a_DASH_data_DASH_expr193545.$var,
"a-assign":a_DASH_assign196551.$var,
"is-a-assign":is_DASH_a_DASH_assign195549.$var,
"a-app":a_DASH_app198555.$var,
"is-a-app":is_DASH_a_DASH_app197553.$var,
"a-prim-app":a_DASH_prim_DASH_app200559.$var,
"is-a-prim-app":is_DASH_a_DASH_prim_DASH_app199557.$var,
"a-obj":a_DASH_obj202563.$var,
"is-a-obj":is_DASH_a_DASH_obj201561.$var,
"a-update":a_DASH_update204567.$var,
"is-a-update":is_DASH_a_DASH_update203565.$var,
"a-extend":a_DASH_extend206571.$var,
"is-a-extend":is_DASH_a_DASH_extend205569.$var,
"a-dot":a_DASH_dot208575.$var,
"is-a-dot":is_DASH_a_DASH_dot207573.$var,
"a-colon":a_DASH_colon210579.$var,
"is-a-colon":is_DASH_a_DASH_colon209577.$var,
"a-get-bang":a_DASH_get_DASH_bang212583.$var,
"is-a-get-bang":is_DASH_a_DASH_get_DASH_bang211581.$var,
"a-lam":a_DASH_lam214587.$var,
"is-a-lam":is_DASH_a_DASH_lam213585.$var,
"a-method":a_DASH_method216591.$var,
"is-a-method":is_DASH_a_DASH_method215589.$var,
"a-val":a_DASH_val218595.$var,
"is-a-val":is_DASH_a_DASH_val217593.$var,
"fun-method-pretty":fun_DASH_method_DASH_pretty219597.$var,
"AField":AField221601.$var,
"is-AField":is_DASH_AField222603.$var,
"a-field":a_DASH_field224607.$var,
"is-a-field":is_DASH_a_DASH_field223605.$var,
"AVal":AVal226611.$var,
"is-AVal":is_DASH_AVal227613.$var,
"a-srcloc":a_DASH_srcloc229617.$var,
"is-a-srcloc":is_DASH_a_DASH_srcloc228615.$var,
"a-num":a_DASH_num231621.$var,
"is-a-num":is_DASH_a_DASH_num230619.$var,
"a-str":a_DASH_str233625.$var,
"is-a-str":is_DASH_a_DASH_str232623.$var,
"a-bool":a_DASH_bool235629.$var,
"is-a-bool":is_DASH_a_DASH_bool234627.$var,
"a-array":a_DASH_array237633.$var,
"is-a-array":is_DASH_a_DASH_array236631.$var,
"a-undefined":a_DASH_undefined239637.$var,
"is-a-undefined":is_DASH_a_DASH_undefined238635.$var,
"a-id":a_DASH_id241641.$var,
"is-a-id":is_DASH_a_DASH_id240639.$var,
"a-id-var":a_DASH_id_DASH_var243645.$var,
"is-a-id-var":is_DASH_a_DASH_id_DASH_var242643.$var,
"a-id-letrec":a_DASH_id_DASH_letrec245649.$var,
"is-a-id-letrec":is_DASH_a_DASH_id_DASH_letrec244647.$var,
"strip-loc-prog":strip_DASH_loc_DASH_prog246651.$var,
"strip-loc-import":strip_DASH_loc_DASH_import247653.$var,
"strip-loc-import-type":strip_DASH_loc_DASH_import_DASH_type248655.$var,
"strip-loc-expr":strip_DASH_loc_DASH_expr249657.$var,
"strip-loc-bind":strip_DASH_loc_DASH_bind250659.$var,
"strip-loc-lettable":strip_DASH_loc_DASH_lettable251661.$var,
"strip-loc-field":strip_DASH_loc_DASH_field252663.$var,
"strip-loc-val":strip_DASH_loc_DASH_val253665.$var,
"default-map-visitor":default_DASH_map_DASH_visitor619700,
"freevars-list-acc":freevars_DASH_list_DASH_acc793667.$var,
"freevars-ann-acc":freevars_DASH_ann_DASH_acc794669.$var,
"freevars-e-acc":freevars_DASH_e_DASH_acc795671.$var,
"freevars-e":freevars_DASH_e796673.$var,
"freevars-variant-acc":freevars_DASH_variant_DASH_acc797675.$var,
"freevars-l-acc":freevars_DASH_l_DASH_acc798677.$var,
"freevars-l":freevars_DASH_l799679.$var,
"freevars-v-acc":freevars_DASH_v_DASH_acc800681.$var,
"freevars-v":freevars_DASH_v801683.$var,
"unions":unions802685.$var,
"result-after-checks1":result_DASH_after_DASH_checks11006701});
var anf_fun28317358 = G(builtins28,"current-checker",L[1157]);
var $z73507351 = D;
var $f73567357 = function(_) {
return R.isFunction(anf_fun28317358)?anf_fun28317358.app():R.ffi.throwNonFunApp(L[1157],anf_fun28317358,[]);
};
try {
if(--R.GAS > 0) {
$z73507351 = $f73567357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73567357,
"from":L[1157]});
}
} catch($e73487349) {
if(R.isCont($e73487349)) {
var $ss73527353 = {"from":L[1157],
"go":function(anf_bracket28327359) {
return $Hanf_bracket39577361(anf_bracket28327359,ABind7663,AExpr7465,AField8667,AImport7069,AImportType6871,ALettable8473,AMemberType8075,AProg6677,ATypeBind7279,AVal8881,AVariant7883,AVariantMember8284,Loc9089,provides28307360,result_DASH_after_DASH_checks11006701);
}};
$e73487349.stack[R.EXN_STACKHEIGHT++] = $ss73527353;
}
if(R.isPyretException($e73487349)) {
$e73487349.pyretStack.push(L[1157]);
}
throw $e73487349;
}
var $ret73547355 = $Hanf_bracket39577361($z73507351,ABind7663,AExpr7465,AField8667,AImport7069,AImportType6871,ALettable8473,AMemberType8075,AProg6677,ATypeBind7279,AVal8881,AVariant7883,AVariantMember8284,Loc9089,provides28307360,result_DASH_after_DASH_checks11006701);
++R.GAS;
return $ret73547355;
};
var $Hanf_bracket39577361 = function(anf_bracket28327359,ABind7663,AExpr7465,AField8667,AImport7069,AImportType6871,ALettable8473,AMemberType8075,AProg6677,ATypeBind7279,AVal8881,AVariant7883,AVariantMember8284,Loc9089,provides28307360,result_DASH_after_DASH_checks11006701) {
var anf_fun28337372 = G(anf_bracket28327359,"results",L[1157]);
var $z73647365 = D;
var $f73707371 = function(_) {
return R.isFunction(anf_fun28337372)?anf_fun28337372.app():R.ffi.throwNonFunApp(L[1157],anf_fun28337372,[]);
};
try {
if(--R.GAS > 0) {
$z73647365 = $f73707371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73707371,
"from":L[1157]});
}
} catch($e73627363) {
if(R.isCont($e73627363)) {
var $ss73667367 = {"from":L[1157],
"go":function(checks28347373) {
return $Hchecks39567374(checks28347373,ABind7663,AExpr7465,AField8667,AImport7069,AImportType6871,ALettable8473,AMemberType8075,AProg6677,ATypeBind7279,AVal8881,AVariant7883,AVariantMember8284,Loc9089,provides28307360,result_DASH_after_DASH_checks11006701);
}};
$e73627363.stack[R.EXN_STACKHEIGHT++] = $ss73667367;
}
if(R.isPyretException($e73627363)) {
$e73627363.pyretStack.push(L[1157]);
}
throw $e73627363;
}
var $ret73687369 = $Hchecks39567374($z73647365,ABind7663,AExpr7465,AField8667,AImport7069,AImportType6871,ALettable8473,AMemberType8075,AProg6677,ATypeBind7279,AVal8881,AVariant7883,AVariantMember8284,Loc9089,provides28307360,result_DASH_after_DASH_checks11006701);
++R.GAS;
return $ret73687369;
};
var $Hchecks39567374 = function(checks28347373,ABind7663,AExpr7465,AField8667,AImport7069,AImportType6871,ALettable8473,AMemberType8075,AProg6677,ATypeBind7279,AVal8881,AVariant7883,AVariantMember8284,Loc9089,provides28307360,result_DASH_after_DASH_checks11006701) {
return R.makeObject({"answer":result_DASH_after_DASH_checks11006701,
"provide-plus-types":R.makeObject({"values":provides28307360,
"types":{"Loc":Loc9089,
"AProg":AProg6677,
"AImportType":AImportType6871,
"AImport":AImport7069,
"ATypeBind":ATypeBind7279,
"AExpr":AExpr7465,
"ABind":ABind7663,
"AVariant":AVariant7883,
"AMemberType":AMemberType8075,
"AVariantMember":AVariantMember8284,
"ALettable":ALettable8473,
"AField":AField8667,
"AVal":AVal8881}}),
"checks":checks28347373});
};
var $Hx39547334 = function(x10097332,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,n10087331,builtins28) {
var $z73777378 = D;
var $f73837384 = function(_) {
return R.isFunction(n10087331)?n10087331.app(("y")):R.ffi.throwNonFunApp(L[1183],n10087331,[("y")]);
};
try {
if(--R.GAS > 0) {
$z73777378 = $f73837384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73837384,
"from":L[1183]});
}
} catch($e73757376) {
if(R.isCont($e73757376)) {
var $ss73797380 = {"from":L[1183],
"go":function(y10107385) {
return $Hy39537386(y10107385,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,x10097332,builtins28);
}};
$e73757376.stack[R.EXN_STACKHEIGHT++] = $ss73797380;
}
if(R.isPyretException($e73757376)) {
$e73757376.pyretStack.push(L[1183]);
}
throw $e73757376;
}
var $ret73817382 = $Hy39537386($z73777378,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,x10097332,builtins28);
++R.GAS;
return $ret73817382;
};
var $Hy39537386 = function(y10107385,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,x10097332,builtins28) {
var anf_fun28097397 = G(builtins28,"current-checker",L[1184]);
var $z73897390 = D;
var $f73957396 = function(_) {
return R.isFunction(anf_fun28097397)?anf_fun28097397.app():R.ffi.throwNonFunApp(L[1184],anf_fun28097397,[]);
};
try {
if(--R.GAS > 0) {
$z73897390 = $f73957396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73957396,
"from":L[1184]});
}
} catch($e73877388) {
if(R.isCont($e73877388)) {
var $ss73917392 = {"from":L[1184],
"go":function(anf_bracket28107398) {
return $Hanf_bracket39527399(anf_bracket28107398,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,x10097332,y10107385);
}};
$e73877388.stack[R.EXN_STACKHEIGHT++] = $ss73917392;
}
if(R.isPyretException($e73877388)) {
$e73877388.pyretStack.push(L[1184]);
}
throw $e73877388;
}
var $ret73937394 = $Hanf_bracket39527399($z73897390,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,x10097332,y10107385);
++R.GAS;
return $ret73937394;
};
var $Hanf_bracket39527399 = function(anf_bracket28107398,A136,a_DASH_bind166491,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,d10077333,freevars_DASH_e796673,list2593,x10097332,y10107385) {
var anf_fun28117412 = G(anf_bracket28107398,"check-is",L[1184]);
var anf_arg28127410 = G(A136,"a-blank",L[1186]);
var $z74027403 = D;
var $f74087409 = function(_) {
return R.isFunction(a_DASH_bind166491.$var)?a_DASH_bind166491.$var.app(d10077333,x10097332,anf_arg28127410):R.ffi.throwNonFunApp(L[1185],a_DASH_bind166491.$var,[d10077333,x10097332,anf_arg28127410]);
};
try {
if(--R.GAS > 0) {
$z74027403 = $f74087409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74087409,
"from":L[1185]});
}
} catch($e74007401) {
if(R.isCont($e74007401)) {
var $ss74047405 = {"from":L[1185],
"go":function(anf_arg28137411) {
return $Hanf_arg39517413(anf_arg28137411,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
}};
$e74007401.stack[R.EXN_STACKHEIGHT++] = $ss74047405;
}
if(R.isPyretException($e74007401)) {
$e74007401.pyretStack.push(L[1185]);
}
throw $e74007401;
}
var $ret74067407 = $Hanf_arg39517413($z74027403,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
++R.GAS;
return $ret74067407;
};
var $Hanf_arg39517413 = function(anf_arg28137411,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_num231621,a_DASH_val218595,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385) {
var $z74167417 = D;
var $f74227423 = function(_) {
return R.isFunction(a_DASH_num231621.$var)?a_DASH_num231621.$var.app(d10077333,(4)):R.ffi.throwNonFunApp(L[1187],a_DASH_num231621.$var,[d10077333,(4)]);
};
try {
if(--R.GAS > 0) {
$z74167417 = $f74227423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74227423,
"from":L[1187]});
}
} catch($e74147415) {
if(R.isCont($e74147415)) {
var $ss74187419 = {"from":L[1187],
"go":function(anf_arg28147424) {
return $Hanf_arg39507425(anf_arg28147424,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
}};
$e74147415.stack[R.EXN_STACKHEIGHT++] = $ss74187419;
}
if(R.isPyretException($e74147415)) {
$e74147415.pyretStack.push(L[1187]);
}
throw $e74147415;
}
var $ret74207421 = $Hanf_arg39507425($z74167417,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
++R.GAS;
return $ret74207421;
};
var $Hanf_arg39507425 = function(anf_arg28147424,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385) {
var $z74287429 = D;
var $f74347435 = function(_) {
return R.isFunction(a_DASH_val218595.$var)?a_DASH_val218595.$var.app(anf_arg28147424):R.ffi.throwNonFunApp(L[1188],a_DASH_val218595.$var,[anf_arg28147424]);
};
try {
if(--R.GAS > 0) {
$z74287429 = $f74347435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74347435,
"from":L[1188]});
}
} catch($e74267427) {
if(R.isCont($e74267427)) {
var $ss74307431 = {"from":L[1188],
"go":function(anf_arg28157436) {
return $Hanf_arg39497437(anf_arg28157436,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
}};
$e74267427.stack[R.EXN_STACKHEIGHT++] = $ss74307431;
}
if(R.isPyretException($e74267427)) {
$e74267427.pyretStack.push(L[1188]);
}
throw $e74267427;
}
var $ret74327433 = $Hanf_arg39497437($z74287429,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
++R.GAS;
return $ret74327433;
};
var $Hanf_arg39497437 = function(anf_arg28157436,a_DASH_id241641,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385) {
var $z74407441 = D;
var $f74467447 = function(_) {
return R.isFunction(a_DASH_id241641.$var)?a_DASH_id241641.$var.app(d10077333,y10107385):R.ffi.throwNonFunApp(L[1189],a_DASH_id241641.$var,[d10077333,y10107385]);
};
try {
if(--R.GAS > 0) {
$z74407441 = $f74467447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74467447,
"from":L[1189]});
}
} catch($e74387439) {
if(R.isCont($e74387439)) {
var $ss74427443 = {"from":L[1189],
"go":function(anf_arg28167448) {
return $Hanf_arg39487449(anf_arg28167448,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
}};
$e74387439.stack[R.EXN_STACKHEIGHT++] = $ss74427443;
}
if(R.isPyretException($e74387439)) {
$e74387439.pyretStack.push(L[1189]);
}
throw $e74387439;
}
var $ret74447445 = $Hanf_arg39487449($z74407441,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
++R.GAS;
return $ret74447445;
};
var $Hanf_arg39487449 = function(anf_arg28167448,a_DASH_let149457,a_DASH_lettable161481,a_DASH_val218595,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385) {
var $z74527453 = D;
var $f74587459 = function(_) {
return R.isFunction(a_DASH_val218595.$var)?a_DASH_val218595.$var.app(anf_arg28167448):R.ffi.throwNonFunApp(L[1190],a_DASH_val218595.$var,[anf_arg28167448]);
};
try {
if(--R.GAS > 0) {
$z74527453 = $f74587459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74587459,
"from":L[1190]});
}
} catch($e74507451) {
if(R.isCont($e74507451)) {
var $ss74547455 = {"from":L[1190],
"go":function(anf_arg28177460) {
return $Hanf_arg39477461(anf_arg28177460,a_DASH_let149457,a_DASH_lettable161481,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
}};
$e74507451.stack[R.EXN_STACKHEIGHT++] = $ss74547455;
}
if(R.isPyretException($e74507451)) {
$e74507451.pyretStack.push(L[1190]);
}
throw $e74507451;
}
var $ret74567457 = $Hanf_arg39477461($z74527453,a_DASH_let149457,a_DASH_lettable161481,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
++R.GAS;
return $ret74567457;
};
var $Hanf_arg39477461 = function(anf_arg28177460,a_DASH_let149457,a_DASH_lettable161481,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385) {
var $z74647465 = D;
var $f74707471 = function(_) {
return R.isFunction(a_DASH_lettable161481.$var)?a_DASH_lettable161481.$var.app(anf_arg28177460):R.ffi.throwNonFunApp(L[1191],a_DASH_lettable161481.$var,[anf_arg28177460]);
};
try {
if(--R.GAS > 0) {
$z74647465 = $f74707471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74707471,
"from":L[1191]});
}
} catch($e74627463) {
if(R.isCont($e74627463)) {
var $ss74667467 = {"from":L[1191],
"go":function(anf_arg28187472) {
return $Hanf_arg39467473(anf_arg28187472,a_DASH_let149457,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
}};
$e74627463.stack[R.EXN_STACKHEIGHT++] = $ss74667467;
}
if(R.isPyretException($e74627463)) {
$e74627463.pyretStack.push(L[1191]);
}
throw $e74627463;
}
var $ret74687469 = $Hanf_arg39467473($z74647465,a_DASH_let149457,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385);
++R.GAS;
return $ret74687469;
};
var $Hanf_arg39467473 = function(anf_arg28187472,a_DASH_let149457,anf_arg28137411,anf_arg28157436,anf_fun28117412,d10077333,freevars_DASH_e796673,list2593,y10107385) {
var $z74767477 = D;
var $f74827483 = function(_) {
return R.isFunction(a_DASH_let149457.$var)?a_DASH_let149457.$var.app(d10077333,anf_arg28137411,anf_arg28157436,anf_arg28187472):R.ffi.throwNonFunApp(L[1192],a_DASH_let149457.$var,[d10077333,anf_arg28137411,anf_arg28157436,anf_arg28187472]);
};
try {
if(--R.GAS > 0) {
$z74767477 = $f74827483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74827483,
"from":L[1192]});
}
} catch($e74747475) {
if(R.isCont($e74747475)) {
var $ss74787479 = {"from":L[1192],
"go":function(anf_arg28197484) {
return $Hanf_arg39457485(anf_arg28197484,anf_fun28117412,freevars_DASH_e796673,list2593,y10107385);
}};
$e74747475.stack[R.EXN_STACKHEIGHT++] = $ss74787479;
}
if(R.isPyretException($e74747475)) {
$e74747475.pyretStack.push(L[1192]);
}
throw $e74747475;
}
var $ret74807481 = $Hanf_arg39457485($z74767477,anf_fun28117412,freevars_DASH_e796673,list2593,y10107385);
++R.GAS;
return $ret74807481;
};
var $Hanf_arg39457485 = function(anf_arg28197484,anf_fun28117412,freevars_DASH_e796673,list2593,y10107385) {
var $z74887489 = D;
var $f74947495 = function(_) {
return R.isFunction(freevars_DASH_e796673.$var)?freevars_DASH_e796673.$var.app(anf_arg28197484):R.ffi.throwNonFunApp(L[1193],freevars_DASH_e796673.$var,[anf_arg28197484]);
};
try {
if(--R.GAS > 0) {
$z74887489 = $f74947495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74947495,
"from":L[1193]});
}
} catch($e74867487) {
if(R.isCont($e74867487)) {
var $ss74907491 = {"from":L[1193],
"go":function(anf_bracket28207496) {
return $Hanf_bracket39447497(anf_bracket28207496,anf_fun28117412,list2593,y10107385);
}};
$e74867487.stack[R.EXN_STACKHEIGHT++] = $ss74907491;
}
if(R.isPyretException($e74867487)) {
$e74867487.pyretStack.push(L[1193]);
}
throw $e74867487;
}
var $ret74927493 = $Hanf_bracket39447497($z74887489,anf_fun28117412,list2593,y10107385);
++R.GAS;
return $ret74927493;
};
var $Hanf_bracket39447497 = function(anf_bracket28207496,anf_fun28117412,list2593,y10107385) {
var anf_fun28217508 = G(anf_bracket28207496,"to-list",L[1195]);
var $z75007501 = D;
var $f75067507 = function(_) {
return R.isFunction(anf_fun28217508)?anf_fun28217508.app():R.ffi.throwNonFunApp(L[1194],anf_fun28217508,[]);
};
try {
if(--R.GAS > 0) {
$z75007501 = $f75067507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75067507,
"from":L[1194]});
}
} catch($e74987499) {
if(R.isCont($e74987499)) {
var $ss75027503 = {"from":L[1194],
"go":function(anf_arg28227509) {
return $Hanf_arg39437510(anf_arg28227509,anf_fun28117412,list2593,y10107385);
}};
$e74987499.stack[R.EXN_STACKHEIGHT++] = $ss75027503;
}
if(R.isPyretException($e74987499)) {
$e74987499.pyretStack.push(L[1194]);
}
throw $e74987499;
}
var $ret75047505 = $Hanf_arg39437510($z75007501,anf_fun28117412,list2593,y10107385);
++R.GAS;
return $ret75047505;
};
var $Hanf_arg39437510 = function(anf_arg28227509,anf_fun28117412,list2593,y10107385) {
var anf_fun28237521 = G(list2593,"make",L[1196]);
var $z75137514 = D;
var $f75197520 = function(_) {
return R.isFunction(anf_fun28237521)?anf_fun28237521.app([y10107385]):R.ffi.throwNonFunApp(L[1196],anf_fun28237521,[[y10107385]]);
};
try {
if(--R.GAS > 0) {
$z75137514 = $f75197520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75197520,
"from":L[1196]});
}
} catch($e75117512) {
if(R.isCont($e75117512)) {
var $ss75157516 = {"from":L[1196],
"go":function(anf_arg28247522) {
return $Hanf_arg39427523(anf_arg28247522,anf_arg28227509,anf_fun28117412);
}};
$e75117512.stack[R.EXN_STACKHEIGHT++] = $ss75157516;
}
if(R.isPyretException($e75117512)) {
$e75117512.pyretStack.push(L[1196]);
}
throw $e75117512;
}
var $ret75177518 = $Hanf_arg39427523($z75137514,anf_arg28227509,anf_fun28117412);
++R.GAS;
return $ret75177518;
};
var $Hanf_arg39427523 = function(anf_arg28247522,anf_arg28227509,anf_fun28117412) {
var anf_arg28257534 = R.makeSrcloc(L[1184]);
var $z75267527 = D;
var $f75327533 = function(_) {
return R.isFunction(anf_fun28117412)?anf_fun28117412.app(("freevars-e(a-let(d,\n    a-bind(d, x, A.a-blank),\n    a-val(a-num(d, 4)),\n    a-lettable(a-val(a-id(d, y)))))\n  .to-list() is\n  [list: y]"),anf_arg28227509,anf_arg28247522,anf_arg28257534):R.ffi.throwNonFunApp(L[129],anf_fun28117412,[("freevars-e(a-let(d,\n    a-bind(d, x, A.a-blank),\n    a-val(a-num(d, 4)),\n    a-lettable(a-val(a-id(d, y)))))\n  .to-list() is\n  [list: y]"),anf_arg28227509,anf_arg28247522,anf_arg28257534]);
};
try {
if(--R.GAS > 0) {
$z75267527 = $f75327533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75327533,
"from":L[129]});
}
} catch($e75247525) {
if(R.isCont($e75247525)) {
var $ss75287529 = {"from":L[129],
"go":function(ann_DASH_check_DASH_temp28077535) {
return $Hann_DASH_check_DASH_temp39417536(ann_DASH_check_DASH_temp28077535);
}};
$e75247525.stack[R.EXN_STACKHEIGHT++] = $ss75287529;
}
if(R.isPyretException($e75247525)) {
$e75247525.pyretStack.push(L[129]);
}
throw $e75247525;
}
var $ret75307531 = $Hann_DASH_check_DASH_temp39417536($z75267527);
++R.GAS;
return $ret75307531;
};
var $Hann_DASH_check_DASH_temp39417536 = function(ann_DASH_check_DASH_temp28077535) {
return ann_DASH_check_DASH_temp28077535;
};
var $Hann_DASH_check_DASH_temp3940717 = function(ann_DASH_check_DASH_temp2797716,Set2090) {
return ann_DASH_check_DASH_temp2797716;
};
var $Hann_DASH_check_DASH_temp3939732 = function(ann_DASH_check_DASH_temp2798731) {
return ann_DASH_check_DASH_temp2798731;
};
var $Hann_DASH_check_DASH_temp3938746 = function(ann_DASH_check_DASH_temp2794745,A244,Set2090) {
return ann_DASH_check_DASH_temp2794745;
};
var $Hann_DASH_check_DASH_temp3937763 = function(ann_DASH_check_DASH_temp2763762,A244,Set2090) {
return ann_DASH_check_DASH_temp2763762;
};
var $Hanf_arg3936775 = function(anf_arg2790774,_plus26,raise30) {
var $z75397540 = D;
var $f75457546 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("Unknown AVal in freevars-v "),anf_arg2790774):R.ffi.throwNonFunApp(L[1197],_plus26,[("Unknown AVal in freevars-v "),anf_arg2790774]);
};
try {
if(--R.GAS > 0) {
$z75397540 = $f75457546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75457546,
"from":L[1197]});
}
} catch($e75377538) {
if(R.isCont($e75377538)) {
var $ss75417542 = {"from":L[1197],
"go":function(anf_arg27917547) {
return $Hanf_arg39357548(anf_arg27917547,raise30);
}};
$e75377538.stack[R.EXN_STACKHEIGHT++] = $ss75417542;
}
if(R.isPyretException($e75377538)) {
$e75377538.pyretStack.push(L[1197]);
}
throw $e75377538;
}
var $ret75437544 = $Hanf_arg39357548($z75397540,raise30);
++R.GAS;
return $ret75437544;
};
var $Hanf_arg39357548 = function(anf_arg27917547,raise30) {
var $z75517552 = D;
var $f75577558 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg27917547):R.ffi.throwNonFunApp(L[56],raise30,[anf_arg27917547]);
};
try {
if(--R.GAS > 0) {
$z75517552 = $f75577558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75577558,
"from":L[56]});
}
} catch($e75497550) {
if(R.isCont($e75497550)) {
var $ss75537554 = {"from":L[56],
"go":function(ann_DASH_check_DASH_temp27897559) {
return $Hann_DASH_check_DASH_temp39347560(ann_DASH_check_DASH_temp27897559);
}};
$e75497550.stack[R.EXN_STACKHEIGHT++] = $ss75537554;
}
if(R.isPyretException($e75497550)) {
$e75497550.pyretStack.push(L[56]);
}
throw $e75497550;
}
var $ret75557556 = $Hann_DASH_check_DASH_temp39347560($z75517552);
++R.GAS;
return $ret75557556;
};
var $Hann_DASH_check_DASH_temp39347560 = function(ann_DASH_check_DASH_temp27897559) {
return ann_DASH_check_DASH_temp27897559;
};
var $Hann_DASH_check_DASH_temp3933814 = function(ann_DASH_check_DASH_temp2775813) {
return ann_DASH_check_DASH_temp2775813;
};
var $Hann_DASH_check_DASH_temp3932829 = function(ann_DASH_check_DASH_temp2772828) {
return ann_DASH_check_DASH_temp2772828;
};
var $Hann_DASH_check_DASH_temp3931844 = function(ann_DASH_check_DASH_temp2769843) {
return ann_DASH_check_DASH_temp2769843;
};
var $Hann_DASH_check_DASH_temp3930859 = function(ann_DASH_check_DASH_temp2765858) {
return ann_DASH_check_DASH_temp2765858;
};
var $Hann_DASH_check_DASH_temp3929873 = function(ann_DASH_check_DASH_temp2766872) {
return ann_DASH_check_DASH_temp2766872;
};
var $Hann_DASH_check_DASH_temp3928888 = function(ann_DASH_check_DASH_temp2760887,A244,Set2090) {
return ann_DASH_check_DASH_temp2760887;
};
var $Hann_DASH_check_DASH_temp3927905 = function(ann_DASH_check_DASH_temp2676904,A244,Set2090) {
return ann_DASH_check_DASH_temp2676904;
};
var $Hanf_arg3926917 = function(anf_arg2756916,_plus26,raise30) {
var $z75637564 = D;
var $f75697570 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("Non-lettable in freevars-l "),anf_arg2756916):R.ffi.throwNonFunApp(L[1198],_plus26,[("Non-lettable in freevars-l "),anf_arg2756916]);
};
try {
if(--R.GAS > 0) {
$z75637564 = $f75697570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75697570,
"from":L[1198]});
}
} catch($e75617562) {
if(R.isCont($e75617562)) {
var $ss75657566 = {"from":L[1198],
"go":function(anf_arg27577571) {
return $Hanf_arg39257572(anf_arg27577571,raise30);
}};
$e75617562.stack[R.EXN_STACKHEIGHT++] = $ss75657566;
}
if(R.isPyretException($e75617562)) {
$e75617562.pyretStack.push(L[1198]);
}
throw $e75617562;
}
var $ret75677568 = $Hanf_arg39257572($z75637564,raise30);
++R.GAS;
return $ret75677568;
};
var $Hanf_arg39257572 = function(anf_arg27577571,raise30) {
var $z75757576 = D;
var $f75817582 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg27577571):R.ffi.throwNonFunApp(L[77],raise30,[anf_arg27577571]);
};
try {
if(--R.GAS > 0) {
$z75757576 = $f75817582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75817582,
"from":L[77]});
}
} catch($e75737574) {
if(R.isCont($e75737574)) {
var $ss75777578 = {"from":L[77],
"go":function(ann_DASH_check_DASH_temp27557583) {
return $Hann_DASH_check_DASH_temp39247584(ann_DASH_check_DASH_temp27557583);
}};
$e75737574.stack[R.EXN_STACKHEIGHT++] = $ss75777578;
}
if(R.isPyretException($e75737574)) {
$e75737574.pyretStack.push(L[77]);
}
throw $e75737574;
}
var $ret75797580 = $Hann_DASH_check_DASH_temp39247584($z75757576);
++R.GAS;
return $ret75797580;
};
var $Hann_DASH_check_DASH_temp39247584 = function(ann_DASH_check_DASH_temp27557583) {
return ann_DASH_check_DASH_temp27557583;
};
var $Hann_DASH_check_DASH_temp3923944 = function(ann_DASH_check_DASH_temp2752943) {
return ann_DASH_check_DASH_temp2752943;
};
var $Hann_DASH_check_DASH_temp3922959 = function(ann_DASH_check_DASH_temp2750958) {
return ann_DASH_check_DASH_temp2750958;
};
var $Hann_DASH_check_DASH_temp3921974 = function(ann_DASH_check_DASH_temp2748973) {
return ann_DASH_check_DASH_temp2748973;
};
var $Hann_DASH_check_DASH_temp3920989 = function(ann_DASH_check_DASH_temp2746988) {
return ann_DASH_check_DASH_temp2746988;
};
var $Hfrom_DASH_supe39191004 = function(from_DASH_supe9651003,fields964992,fold5391,freevars_DASH_v_DASH_acc800681) {
var anf_arg27447595 = R.makeFunction(function(acc9667598,f9677599) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1199],2,arguments);
}
var anf_arg27437610 = G(f9677599,"value",L[1201]);
var $z76027603 = D;
var $f76087609 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1200],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1200],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(anf_arg27437610,acc9667598):R.ffi.throwNonFunApp(L[1199],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1200],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[anf_arg27437610,acc9667598]);
};
try {
if(--R.GAS > 0) {
$z76027603 = $f76087609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76087609,
"from":L[1199]});
}
} catch($e76007601) {
if(R.isCont($e76007601)) {
var $ss76047605 = {"from":L[1199],
"go":function(ann_DASH_check_DASH_temp27427611) {
return $Hann_DASH_check_DASH_temp39177612(ann_DASH_check_DASH_temp27427611);
}};
$e76007601.stack[R.EXN_STACKHEIGHT++] = $ss76047605;
}
if(R.isPyretException($e76007601)) {
$e76007601.pyretStack.push(L[1199]);
}
throw $e76007601;
}
var $ret76067607 = $Hann_DASH_check_DASH_temp39177612($z76027603);
++R.GAS;
return $ret76067607;
});
var $z75877588 = D;
var $f75937594 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg27447595,from_DASH_supe9651003,fields964992):R.ffi.throwNonFunApp(L[87],fold5391,[anf_arg27447595,from_DASH_supe9651003,fields964992]);
};
try {
if(--R.GAS > 0) {
$z75877588 = $f75937594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75937594,
"from":L[87]});
}
} catch($e75857586) {
if(R.isCont($e75857586)) {
var $ss75897590 = {"from":L[87],
"go":function(ann_DASH_check_DASH_temp27417596) {
return $Hann_DASH_check_DASH_temp39187597(ann_DASH_check_DASH_temp27417596);
}};
$e75857586.stack[R.EXN_STACKHEIGHT++] = $ss75897590;
}
if(R.isPyretException($e75857586)) {
$e75857586.pyretStack.push(L[87]);
}
throw $e75857586;
}
var $ret75917592 = $Hann_DASH_check_DASH_temp39187597($z75877588);
++R.GAS;
return $ret75917592;
};
var $Hann_DASH_check_DASH_temp39187597 = function(ann_DASH_check_DASH_temp27417596) {
return ann_DASH_check_DASH_temp27417596;
};
var $Hann_DASH_check_DASH_temp39177612 = function(ann_DASH_check_DASH_temp27427611) {
return ann_DASH_check_DASH_temp27427611;
};
var $Hfrom_DASH_variants39161022 = function(from_DASH_variants9561021,fold5391,freevars_DASH_v_DASH_acc800681,namet9531007,shared9551009) {
var anf_arg27387623 = R.makeFunction(function(acc9607626,s9617627) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1203],2,arguments);
}
var anf_arg27377638 = G(s9617627,"value",L[1205]);
var $z76307631 = D;
var $f76367637 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1204],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1204],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(anf_arg27377638,acc9607626):R.ffi.throwNonFunApp(L[1203],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1204],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[anf_arg27377638,acc9607626]);
};
try {
if(--R.GAS > 0) {
$z76307631 = $f76367637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76367637,
"from":L[1203]});
}
} catch($e76287629) {
if(R.isCont($e76287629)) {
var $ss76327633 = {"from":L[1203],
"go":function(ann_DASH_check_DASH_temp27367639) {
return $Hann_DASH_check_DASH_temp39137640(ann_DASH_check_DASH_temp27367639);
}};
$e76287629.stack[R.EXN_STACKHEIGHT++] = $ss76327633;
}
if(R.isPyretException($e76287629)) {
$e76287629.pyretStack.push(L[1203]);
}
throw $e76287629;
}
var $ret76347635 = $Hann_DASH_check_DASH_temp39137640($z76307631);
++R.GAS;
return $ret76347635;
});
var $z76157616 = D;
var $f76217622 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg27387623,from_DASH_variants9561021,shared9551009):R.ffi.throwNonFunApp(L[1202],fold5391,[anf_arg27387623,from_DASH_variants9561021,shared9551009]);
};
try {
if(--R.GAS > 0) {
$z76157616 = $f76217622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76217622,
"from":L[1202]});
}
} catch($e76137614) {
if(R.isCont($e76137614)) {
var $ss76177618 = {"from":L[1202],
"go":function(from_DASH_shared9597624) {
return $Hfrom_DASH_shared39157625(from_DASH_shared9597624,namet9531007);
}};
$e76137614.stack[R.EXN_STACKHEIGHT++] = $ss76177618;
}
if(R.isPyretException($e76137614)) {
$e76137614.pyretStack.push(L[1202]);
}
throw $e76137614;
}
var $ret76197620 = $Hfrom_DASH_shared39157625($z76157616,namet9531007);
++R.GAS;
return $ret76197620;
};
var $Hfrom_DASH_shared39157625 = function(from_DASH_shared9597624,namet9531007) {
var anf_fun27397651 = G(from_DASH_shared9597624,"add",L[1206]);
var $z76437644 = D;
var $f76497650 = function(_) {
return R.isFunction(anf_fun27397651)?anf_fun27397651.app(namet9531007):R.ffi.throwNonFunApp(L[90],anf_fun27397651,[namet9531007]);
};
try {
if(--R.GAS > 0) {
$z76437644 = $f76497650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76497650,
"from":L[90]});
}
} catch($e76417642) {
if(R.isCont($e76417642)) {
var $ss76457646 = {"from":L[90],
"go":function(ann_DASH_check_DASH_temp27337652) {
return $Hann_DASH_check_DASH_temp39147653(ann_DASH_check_DASH_temp27337652);
}};
$e76417642.stack[R.EXN_STACKHEIGHT++] = $ss76457646;
}
if(R.isPyretException($e76417642)) {
$e76417642.pyretStack.push(L[90]);
}
throw $e76417642;
}
var $ret76477648 = $Hann_DASH_check_DASH_temp39147653($z76437644);
++R.GAS;
return $ret76477648;
};
var $Hann_DASH_check_DASH_temp39147653 = function(ann_DASH_check_DASH_temp27337652) {
return ann_DASH_check_DASH_temp27337652;
};
var $Hann_DASH_check_DASH_temp39137640 = function(ann_DASH_check_DASH_temp27367639) {
return ann_DASH_check_DASH_temp27367639;
};
var $Hann_DASH_check_DASH_temp39121036 = function(ann_DASH_check_DASH_temp27341035) {
return ann_DASH_check_DASH_temp27341035;
};
var $Hfrom_DASH_supe39111051 = function(from_DASH_supe9481050,fields9471039,fold5391,freevars_DASH_v_DASH_acc800681) {
var anf_arg27317664 = R.makeFunction(function(acc9497667,f9507668) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1207],2,arguments);
}
var anf_arg27307679 = G(f9507668,"value",L[1209]);
var $z76717672 = D;
var $f76777678 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1208],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1208],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(anf_arg27307679,acc9497667):R.ffi.throwNonFunApp(L[1207],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1208],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[anf_arg27307679,acc9497667]);
};
try {
if(--R.GAS > 0) {
$z76717672 = $f76777678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76777678,
"from":L[1207]});
}
} catch($e76697670) {
if(R.isCont($e76697670)) {
var $ss76737674 = {"from":L[1207],
"go":function(ann_DASH_check_DASH_temp27297680) {
return $Hann_DASH_check_DASH_temp39097681(ann_DASH_check_DASH_temp27297680);
}};
$e76697670.stack[R.EXN_STACKHEIGHT++] = $ss76737674;
}
if(R.isPyretException($e76697670)) {
$e76697670.pyretStack.push(L[1207]);
}
throw $e76697670;
}
var $ret76757676 = $Hann_DASH_check_DASH_temp39097681($z76717672);
++R.GAS;
return $ret76757676;
});
var $z76567657 = D;
var $f76627663 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg27317664,from_DASH_supe9481050,fields9471039):R.ffi.throwNonFunApp(L[93],fold5391,[anf_arg27317664,from_DASH_supe9481050,fields9471039]);
};
try {
if(--R.GAS > 0) {
$z76567657 = $f76627663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76627663,
"from":L[93]});
}
} catch($e76547655) {
if(R.isCont($e76547655)) {
var $ss76587659 = {"from":L[93],
"go":function(ann_DASH_check_DASH_temp27287665) {
return $Hann_DASH_check_DASH_temp39107666(ann_DASH_check_DASH_temp27287665);
}};
$e76547655.stack[R.EXN_STACKHEIGHT++] = $ss76587659;
}
if(R.isPyretException($e76547655)) {
$e76547655.pyretStack.push(L[93]);
}
throw $e76547655;
}
var $ret76607661 = $Hann_DASH_check_DASH_temp39107666($z76567657);
++R.GAS;
return $ret76607661;
};
var $Hann_DASH_check_DASH_temp39107666 = function(ann_DASH_check_DASH_temp27287665) {
return ann_DASH_check_DASH_temp27287665;
};
var $Hann_DASH_check_DASH_temp39097681 = function(ann_DASH_check_DASH_temp27297680) {
return ann_DASH_check_DASH_temp27297680;
};
var $Hann_DASH_check_DASH_temp39081066 = function(ann_DASH_check_DASH_temp27231065) {
return ann_DASH_check_DASH_temp27231065;
};
var $Hann_DASH_check_DASH_temp39071081 = function(ann_DASH_check_DASH_temp27241080) {
return ann_DASH_check_DASH_temp27241080;
};
var $Hfrom_DASH_body39061097 = function(from_DASH_body9361096,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084,sets1543) {
var anf_fun27127695 = G(from_DASH_body9361096,"difference",L[1214]);
var anf_fun27137696 = G(sets1543,"list-to-tree-set",L[1213]);
var anf_fun27147692 = G(args9331083,"map",L[1212]);
var anf_arg27167693 = R.makeFunction(function(recv_DASH_3177698) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1211],1,arguments);
}
var ann_DASH_check_DASH_temp27157699 = G(recv_DASH_3177698,"id",L[1211]);
return ann_DASH_check_DASH_temp27157699;
});
var $z76847685 = D;
var $f76907691 = function(_) {
return R.isFunction(anf_fun27147692)?anf_fun27147692.app(anf_arg27167693):R.ffi.throwNonFunApp(L[1210],anf_fun27147692,[anf_arg27167693]);
};
try {
if(--R.GAS > 0) {
$z76847685 = $f76907691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76907691,
"from":L[1210]});
}
} catch($e76827683) {
if(R.isCont($e76827683)) {
var $ss76867687 = {"from":L[1210],
"go":function(anf_arg27177694) {
return $Hanf_arg39057697(anf_arg27177694,anf_fun27127695,anf_fun27137696,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084);
}};
$e76827683.stack[R.EXN_STACKHEIGHT++] = $ss76867687;
}
if(R.isPyretException($e76827683)) {
$e76827683.pyretStack.push(L[1210]);
}
throw $e76827683;
}
var $ret76887689 = $Hanf_arg39057697($z76847685,anf_fun27127695,anf_fun27137696,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084);
++R.GAS;
return $ret76887689;
};
var $Hanf_arg39057697 = function(anf_arg27177694,anf_fun27127695,anf_fun27137696,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084) {
var $z77027703 = D;
var $f77087709 = function(_) {
return R.isFunction(anf_fun27137696)?anf_fun27137696.app(anf_arg27177694):R.ffi.throwNonFunApp(L[1215],anf_fun27137696,[anf_arg27177694]);
};
try {
if(--R.GAS > 0) {
$z77027703 = $f77087709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77087709,
"from":L[1215]});
}
} catch($e77007701) {
if(R.isCont($e77007701)) {
var $ss77047705 = {"from":L[1215],
"go":function(anf_arg27187710) {
return $Hanf_arg39047711(anf_arg27187710,anf_fun27127695,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084);
}};
$e77007701.stack[R.EXN_STACKHEIGHT++] = $ss77047705;
}
if(R.isPyretException($e77007701)) {
$e77007701.pyretStack.push(L[1215]);
}
throw $e77007701;
}
var $ret77067707 = $Hanf_arg39047711($z77027703,anf_fun27127695,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084);
++R.GAS;
return $ret77067707;
};
var $Hanf_arg39047711 = function(anf_arg27187710,anf_fun27127695,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084) {
var $z77147715 = D;
var $f77207721 = function(_) {
return R.isFunction(anf_fun27127695)?anf_fun27127695.app(anf_arg27187710):R.ffi.throwNonFunApp(L[1216],anf_fun27127695,[anf_arg27187710]);
};
try {
if(--R.GAS > 0) {
$z77147715 = $f77207721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77207721,
"from":L[1216]});
}
} catch($e77127713) {
if(R.isCont($e77127713)) {
var $ss77167717 = {"from":L[1216],
"go":function(without_DASH_args9377722) {
return $Hwithout_DASH_args39037723(without_DASH_args9377722,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084);
}};
$e77127713.stack[R.EXN_STACKHEIGHT++] = $ss77167717;
}
if(R.isPyretException($e77127713)) {
$e77127713.pyretStack.push(L[1216]);
}
throw $e77127713;
}
var $ret77187719 = $Hwithout_DASH_args39037723($z77147715,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084);
++R.GAS;
return $ret77187719;
};
var $Hwithout_DASH_args39037723 = function(without_DASH_args9377722,args9331083,fold5391,freevars_DASH_ann_DASH_acc794669,ret9341084) {
var anf_arg27217734 = R.makeFunction(function(acc9397737,a9407738) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1218],2,arguments);
}
var anf_arg27207749 = G(a9407738,"ann",L[1219]);
var $z77417742 = D;
var $f77477748 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(anf_arg27207749,acc9397737):R.ffi.throwNonFunApp(L[1218],freevars_DASH_ann_DASH_acc794669.$var,[anf_arg27207749,acc9397737]);
};
try {
if(--R.GAS > 0) {
$z77417742 = $f77477748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77477748,
"from":L[1218]});
}
} catch($e77397740) {
if(R.isCont($e77397740)) {
var $ss77437744 = {"from":L[1218],
"go":function(ann_DASH_check_DASH_temp27197750) {
return $Hann_DASH_check_DASH_temp39007751(ann_DASH_check_DASH_temp27197750);
}};
$e77397740.stack[R.EXN_STACKHEIGHT++] = $ss77437744;
}
if(R.isPyretException($e77397740)) {
$e77397740.pyretStack.push(L[1218]);
}
throw $e77397740;
}
var $ret77457746 = $Hann_DASH_check_DASH_temp39007751($z77417742);
++R.GAS;
return $ret77457746;
});
var $z77267727 = D;
var $f77327733 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg27217734,without_DASH_args9377722,args9331083):R.ffi.throwNonFunApp(L[1217],fold5391,[anf_arg27217734,without_DASH_args9377722,args9331083]);
};
try {
if(--R.GAS > 0) {
$z77267727 = $f77327733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77327733,
"from":L[1217]});
}
} catch($e77247725) {
if(R.isCont($e77247725)) {
var $ss77287729 = {"from":L[1217],
"go":function(from_DASH_args9387735) {
return $Hfrom_DASH_args39027736(from_DASH_args9387735,freevars_DASH_ann_DASH_acc794669,ret9341084);
}};
$e77247725.stack[R.EXN_STACKHEIGHT++] = $ss77287729;
}
if(R.isPyretException($e77247725)) {
$e77247725.pyretStack.push(L[1217]);
}
throw $e77247725;
}
var $ret77307731 = $Hfrom_DASH_args39027736($z77267727,freevars_DASH_ann_DASH_acc794669,ret9341084);
++R.GAS;
return $ret77307731;
};
var $Hfrom_DASH_args39027736 = function(from_DASH_args9387735,freevars_DASH_ann_DASH_acc794669,ret9341084) {
var $z77547755 = D;
var $f77607761 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(ret9341084,from_DASH_args9387735):R.ffi.throwNonFunApp(L[100],freevars_DASH_ann_DASH_acc794669.$var,[ret9341084,from_DASH_args9387735]);
};
try {
if(--R.GAS > 0) {
$z77547755 = $f77607761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77607761,
"from":L[100]});
}
} catch($e77527753) {
if(R.isCont($e77527753)) {
var $ss77567757 = {"from":L[100],
"go":function(ann_DASH_check_DASH_temp27117762) {
return $Hann_DASH_check_DASH_temp39017763(ann_DASH_check_DASH_temp27117762);
}};
$e77527753.stack[R.EXN_STACKHEIGHT++] = $ss77567757;
}
if(R.isPyretException($e77527753)) {
$e77527753.pyretStack.push(L[100]);
}
throw $e77527753;
}
var $ret77587759 = $Hann_DASH_check_DASH_temp39017763($z77547755);
++R.GAS;
return $ret77587759;
};
var $Hann_DASH_check_DASH_temp39017763 = function(ann_DASH_check_DASH_temp27117762) {
return ann_DASH_check_DASH_temp27117762;
};
var $Hann_DASH_check_DASH_temp39007751 = function(ann_DASH_check_DASH_temp27197750) {
return ann_DASH_check_DASH_temp27197750;
};
var $Hfrom_DASH_body38991113 = function(from_DASH_body9271112,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100,sets1543) {
var anf_fun27007777 = G(from_DASH_body9271112,"difference",L[1224]);
var anf_fun27017778 = G(sets1543,"list-to-tree-set",L[1223]);
var anf_fun27027774 = G(args9241099,"map",L[1222]);
var anf_arg27047775 = R.makeFunction(function(recv_DASH_3167780) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1221],1,arguments);
}
var ann_DASH_check_DASH_temp27037781 = G(recv_DASH_3167780,"id",L[1221]);
return ann_DASH_check_DASH_temp27037781;
});
var $z77667767 = D;
var $f77727773 = function(_) {
return R.isFunction(anf_fun27027774)?anf_fun27027774.app(anf_arg27047775):R.ffi.throwNonFunApp(L[1220],anf_fun27027774,[anf_arg27047775]);
};
try {
if(--R.GAS > 0) {
$z77667767 = $f77727773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77727773,
"from":L[1220]});
}
} catch($e77647765) {
if(R.isCont($e77647765)) {
var $ss77687769 = {"from":L[1220],
"go":function(anf_arg27057776) {
return $Hanf_arg38987779(anf_arg27057776,anf_fun27007777,anf_fun27017778,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100);
}};
$e77647765.stack[R.EXN_STACKHEIGHT++] = $ss77687769;
}
if(R.isPyretException($e77647765)) {
$e77647765.pyretStack.push(L[1220]);
}
throw $e77647765;
}
var $ret77707771 = $Hanf_arg38987779($z77667767,anf_fun27007777,anf_fun27017778,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100);
++R.GAS;
return $ret77707771;
};
var $Hanf_arg38987779 = function(anf_arg27057776,anf_fun27007777,anf_fun27017778,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100) {
var $z77847785 = D;
var $f77907791 = function(_) {
return R.isFunction(anf_fun27017778)?anf_fun27017778.app(anf_arg27057776):R.ffi.throwNonFunApp(L[1225],anf_fun27017778,[anf_arg27057776]);
};
try {
if(--R.GAS > 0) {
$z77847785 = $f77907791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77907791,
"from":L[1225]});
}
} catch($e77827783) {
if(R.isCont($e77827783)) {
var $ss77867787 = {"from":L[1225],
"go":function(anf_arg27067792) {
return $Hanf_arg38977793(anf_arg27067792,anf_fun27007777,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100);
}};
$e77827783.stack[R.EXN_STACKHEIGHT++] = $ss77867787;
}
if(R.isPyretException($e77827783)) {
$e77827783.pyretStack.push(L[1225]);
}
throw $e77827783;
}
var $ret77887789 = $Hanf_arg38977793($z77847785,anf_fun27007777,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100);
++R.GAS;
return $ret77887789;
};
var $Hanf_arg38977793 = function(anf_arg27067792,anf_fun27007777,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100) {
var $z77967797 = D;
var $f78027803 = function(_) {
return R.isFunction(anf_fun27007777)?anf_fun27007777.app(anf_arg27067792):R.ffi.throwNonFunApp(L[1226],anf_fun27007777,[anf_arg27067792]);
};
try {
if(--R.GAS > 0) {
$z77967797 = $f78027803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78027803,
"from":L[1226]});
}
} catch($e77947795) {
if(R.isCont($e77947795)) {
var $ss77987799 = {"from":L[1226],
"go":function(without_DASH_args9287804) {
return $Hwithout_DASH_args38967805(without_DASH_args9287804,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100);
}};
$e77947795.stack[R.EXN_STACKHEIGHT++] = $ss77987799;
}
if(R.isPyretException($e77947795)) {
$e77947795.pyretStack.push(L[1226]);
}
throw $e77947795;
}
var $ret78007801 = $Hwithout_DASH_args38967805($z77967797,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100);
++R.GAS;
return $ret78007801;
};
var $Hwithout_DASH_args38967805 = function(without_DASH_args9287804,args9241099,fold5391,freevars_DASH_ann_DASH_acc794669,ret9251100) {
var anf_arg27097816 = R.makeFunction(function(acc9307819,a9317820) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1228],2,arguments);
}
var anf_arg27087831 = G(a9317820,"ann",L[1229]);
var $z78237824 = D;
var $f78297830 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(anf_arg27087831,acc9307819):R.ffi.throwNonFunApp(L[1228],freevars_DASH_ann_DASH_acc794669.$var,[anf_arg27087831,acc9307819]);
};
try {
if(--R.GAS > 0) {
$z78237824 = $f78297830();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78297830,
"from":L[1228]});
}
} catch($e78217822) {
if(R.isCont($e78217822)) {
var $ss78257826 = {"from":L[1228],
"go":function(ann_DASH_check_DASH_temp27077832) {
return $Hann_DASH_check_DASH_temp38937833(ann_DASH_check_DASH_temp27077832);
}};
$e78217822.stack[R.EXN_STACKHEIGHT++] = $ss78257826;
}
if(R.isPyretException($e78217822)) {
$e78217822.pyretStack.push(L[1228]);
}
throw $e78217822;
}
var $ret78277828 = $Hann_DASH_check_DASH_temp38937833($z78237824);
++R.GAS;
return $ret78277828;
});
var $z78087809 = D;
var $f78147815 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg27097816,without_DASH_args9287804,args9241099):R.ffi.throwNonFunApp(L[1227],fold5391,[anf_arg27097816,without_DASH_args9287804,args9241099]);
};
try {
if(--R.GAS > 0) {
$z78087809 = $f78147815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78147815,
"from":L[1227]});
}
} catch($e78067807) {
if(R.isCont($e78067807)) {
var $ss78107811 = {"from":L[1227],
"go":function(from_DASH_args9297817) {
return $Hfrom_DASH_args38957818(from_DASH_args9297817,freevars_DASH_ann_DASH_acc794669,ret9251100);
}};
$e78067807.stack[R.EXN_STACKHEIGHT++] = $ss78107811;
}
if(R.isPyretException($e78067807)) {
$e78067807.pyretStack.push(L[1227]);
}
throw $e78067807;
}
var $ret78127813 = $Hfrom_DASH_args38957818($z78087809,freevars_DASH_ann_DASH_acc794669,ret9251100);
++R.GAS;
return $ret78127813;
};
var $Hfrom_DASH_args38957818 = function(from_DASH_args9297817,freevars_DASH_ann_DASH_acc794669,ret9251100) {
var $z78367837 = D;
var $f78427843 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(ret9251100,from_DASH_args9297817):R.ffi.throwNonFunApp(L[102],freevars_DASH_ann_DASH_acc794669.$var,[ret9251100,from_DASH_args9297817]);
};
try {
if(--R.GAS > 0) {
$z78367837 = $f78427843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78427843,
"from":L[102]});
}
} catch($e78347835) {
if(R.isCont($e78347835)) {
var $ss78387839 = {"from":L[102],
"go":function(ann_DASH_check_DASH_temp26997844) {
return $Hann_DASH_check_DASH_temp38947845(ann_DASH_check_DASH_temp26997844);
}};
$e78347835.stack[R.EXN_STACKHEIGHT++] = $ss78387839;
}
if(R.isPyretException($e78347835)) {
$e78347835.pyretStack.push(L[102]);
}
throw $e78347835;
}
var $ret78407841 = $Hann_DASH_check_DASH_temp38947845($z78367837);
++R.GAS;
return $ret78407841;
};
var $Hann_DASH_check_DASH_temp38947845 = function(ann_DASH_check_DASH_temp26997844) {
return ann_DASH_check_DASH_temp26997844;
};
var $Hann_DASH_check_DASH_temp38937833 = function(ann_DASH_check_DASH_temp27077832) {
return ann_DASH_check_DASH_temp27077832;
};
var $Hann_DASH_check_DASH_temp38921129 = function(ann_DASH_check_DASH_temp26951128) {
return ann_DASH_check_DASH_temp26951128;
};
var $Hann_DASH_check_DASH_temp38911143 = function(ann_DASH_check_DASH_temp26961142) {
return ann_DASH_check_DASH_temp26961142;
};
var $Hfrom_DASH_f38901158 = function(from_DASH_f9151157,args9141146,fold5391,freevars_DASH_v_DASH_acc800681) {
var anf_arg26937856 = R.makeFunction(function(acc9167859,arg9177860) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1230],2,arguments);
}
var $z78637864 = D;
var $f78697870 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1231],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1231],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(arg9177860,acc9167859):R.ffi.throwNonFunApp(L[1230],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1231],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[arg9177860,acc9167859]);
};
try {
if(--R.GAS > 0) {
$z78637864 = $f78697870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78697870,
"from":L[1230]});
}
} catch($e78617862) {
if(R.isCont($e78617862)) {
var $ss78657866 = {"from":L[1230],
"go":function(ann_DASH_check_DASH_temp26927871) {
return $Hann_DASH_check_DASH_temp38887872(ann_DASH_check_DASH_temp26927871);
}};
$e78617862.stack[R.EXN_STACKHEIGHT++] = $ss78657866;
}
if(R.isPyretException($e78617862)) {
$e78617862.pyretStack.push(L[1230]);
}
throw $e78617862;
}
var $ret78677868 = $Hann_DASH_check_DASH_temp38887872($z78637864);
++R.GAS;
return $ret78677868;
});
var $z78487849 = D;
var $f78547855 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg26937856,from_DASH_f9151157,args9141146):R.ffi.throwNonFunApp(L[107],fold5391,[anf_arg26937856,from_DASH_f9151157,args9141146]);
};
try {
if(--R.GAS > 0) {
$z78487849 = $f78547855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78547855,
"from":L[107]});
}
} catch($e78467847) {
if(R.isCont($e78467847)) {
var $ss78507851 = {"from":L[107],
"go":function(ann_DASH_check_DASH_temp26917857) {
return $Hann_DASH_check_DASH_temp38897858(ann_DASH_check_DASH_temp26917857);
}};
$e78467847.stack[R.EXN_STACKHEIGHT++] = $ss78507851;
}
if(R.isPyretException($e78467847)) {
$e78467847.pyretStack.push(L[107]);
}
throw $e78467847;
}
var $ret78527853 = $Hann_DASH_check_DASH_temp38897858($z78487849);
++R.GAS;
return $ret78527853;
};
var $Hann_DASH_check_DASH_temp38897858 = function(ann_DASH_check_DASH_temp26917857) {
return ann_DASH_check_DASH_temp26917857;
};
var $Hann_DASH_check_DASH_temp38887872 = function(ann_DASH_check_DASH_temp26927871) {
return ann_DASH_check_DASH_temp26927871;
};
var $Hanf_arg38871174 = function(anf_arg26891173,freevars_DASH_v_DASH_acc800681,v9111161) {
var $z78757876 = D;
var $f78817882 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1232],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1232],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(v9111161,anf_arg26891173):R.ffi.throwNonFunApp(L[110],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1232],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[v9111161,anf_arg26891173]);
};
try {
if(--R.GAS > 0) {
$z78757876 = $f78817882();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78817882,
"from":L[110]});
}
} catch($e78737874) {
if(R.isCont($e78737874)) {
var $ss78777878 = {"from":L[110],
"go":function(ann_DASH_check_DASH_temp26877883) {
return $Hann_DASH_check_DASH_temp38867884(ann_DASH_check_DASH_temp26877883);
}};
$e78737874.stack[R.EXN_STACKHEIGHT++] = $ss78777878;
}
if(R.isPyretException($e78737874)) {
$e78737874.pyretStack.push(L[110]);
}
throw $e78737874;
}
var $ret78797880 = $Hann_DASH_check_DASH_temp38867884($z78757876);
++R.GAS;
return $ret78797880;
};
var $Hann_DASH_check_DASH_temp38867884 = function(ann_DASH_check_DASH_temp26877883) {
return ann_DASH_check_DASH_temp26877883;
};
var $Hanf_arg38851193 = function(anf_arg26821192,ans9051176,checks9081179,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,provs9061177,seen_DASH_so_DASH_far903890) {
var $z78877888 = D;
var $f78937894 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1233],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1233],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(checks9081179,seen_DASH_so_DASH_far903890):R.ffi.throwNonFunApp(L[1234],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1233],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[checks9081179,seen_DASH_so_DASH_far903890]);
};
try {
if(--R.GAS > 0) {
$z78877888 = $f78937894();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78937894,
"from":L[1234]});
}
} catch($e78857886) {
if(R.isCont($e78857886)) {
var $ss78897890 = {"from":L[1234],
"go":function(anf_arg26837895) {
return $Hanf_arg38847896(anf_arg26837895,anf_arg26821192,ans9051176,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,provs9061177);
}};
$e78857886.stack[R.EXN_STACKHEIGHT++] = $ss78897890;
}
if(R.isPyretException($e78857886)) {
$e78857886.pyretStack.push(L[1234]);
}
throw $e78857886;
}
var $ret78917892 = $Hanf_arg38847896($z78877888,anf_arg26821192,ans9051176,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,provs9061177);
++R.GAS;
return $ret78917892;
};
var $Hanf_arg38847896 = function(anf_arg26837895,anf_arg26821192,ans9051176,freevars_DASH_list_DASH_acc793667,freevars_DASH_v_DASH_acc800681,provs9061177) {
var $z78997900 = D;
var $f79057906 = function(_) {
return R.isFunction(freevars_DASH_list_DASH_acc793667.$var)?freevars_DASH_list_DASH_acc793667.$var.app(anf_arg26821192,anf_arg26837895):R.ffi.throwNonFunApp(L[1235],freevars_DASH_list_DASH_acc793667.$var,[anf_arg26821192,anf_arg26837895]);
};
try {
if(--R.GAS > 0) {
$z78997900 = $f79057906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79057906,
"from":L[1235]});
}
} catch($e78977898) {
if(R.isCont($e78977898)) {
var $ss79017902 = {"from":L[1235],
"go":function(anf_arg26847907) {
return $Hanf_arg38837908(anf_arg26847907,ans9051176,freevars_DASH_v_DASH_acc800681,provs9061177);
}};
$e78977898.stack[R.EXN_STACKHEIGHT++] = $ss79017902;
}
if(R.isPyretException($e78977898)) {
$e78977898.pyretStack.push(L[1235]);
}
throw $e78977898;
}
var $ret79037904 = $Hanf_arg38837908($z78997900,ans9051176,freevars_DASH_v_DASH_acc800681,provs9061177);
++R.GAS;
return $ret79037904;
};
var $Hanf_arg38837908 = function(anf_arg26847907,ans9051176,freevars_DASH_v_DASH_acc800681,provs9061177) {
var $z79117912 = D;
var $f79177918 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1236],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1236],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(provs9061177,anf_arg26847907):R.ffi.throwNonFunApp(L[1237],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1236],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[provs9061177,anf_arg26847907]);
};
try {
if(--R.GAS > 0) {
$z79117912 = $f79177918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79177918,
"from":L[1237]});
}
} catch($e79097910) {
if(R.isCont($e79097910)) {
var $ss79137914 = {"from":L[1237],
"go":function(anf_arg26857919) {
return $Hanf_arg38827920(anf_arg26857919,ans9051176,freevars_DASH_v_DASH_acc800681);
}};
$e79097910.stack[R.EXN_STACKHEIGHT++] = $ss79137914;
}
if(R.isPyretException($e79097910)) {
$e79097910.pyretStack.push(L[1237]);
}
throw $e79097910;
}
var $ret79157916 = $Hanf_arg38827920($z79117912,ans9051176,freevars_DASH_v_DASH_acc800681);
++R.GAS;
return $ret79157916;
};
var $Hanf_arg38827920 = function(anf_arg26857919,ans9051176,freevars_DASH_v_DASH_acc800681) {
var $z79237924 = D;
var $f79297930 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1238],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1238],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(ans9051176,anf_arg26857919):R.ffi.throwNonFunApp(L[113],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1238],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[ans9051176,anf_arg26857919]);
};
try {
if(--R.GAS > 0) {
$z79237924 = $f79297930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79297930,
"from":L[113]});
}
} catch($e79217922) {
if(R.isCont($e79217922)) {
var $ss79257926 = {"from":L[113],
"go":function(ann_DASH_check_DASH_temp26787931) {
return $Hann_DASH_check_DASH_temp38817932(ann_DASH_check_DASH_temp26787931);
}};
$e79217922.stack[R.EXN_STACKHEIGHT++] = $ss79257926;
}
if(R.isPyretException($e79217922)) {
$e79217922.pyretStack.push(L[113]);
}
throw $e79217922;
}
var $ret79277928 = $Hann_DASH_check_DASH_temp38817932($z79237924);
++R.GAS;
return $ret79277928;
};
var $Hann_DASH_check_DASH_temp38817932 = function(ann_DASH_check_DASH_temp26787931) {
return ann_DASH_check_DASH_temp26787931;
};
var $Hfrom_DASH_members38801213 = function(from_DASH_members8891212,A244,Set2090,fold5391,freevars_DASH_v_DASH_acc800681,v8871197) {
var anf_arg26737943 = R.makeFunction(function(acc9007947,m9017948) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1240],2,arguments);
}
var anf_arg26727959 = G(m9017948,"value",L[1242]);
var $z79517952 = D;
var $f79577958 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1241],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1241],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(anf_arg26727959,acc9007947):R.ffi.throwNonFunApp(L[1240],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1241],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[anf_arg26727959,acc9007947]);
};
try {
if(--R.GAS > 0) {
$z79517952 = $f79577958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79577958,
"from":L[1240]});
}
} catch($e79497950) {
if(R.isCont($e79497950)) {
var $ss79537954 = {"from":L[1240],
"go":function(ann_DASH_check_DASH_temp26717960) {
return $Hann_DASH_check_DASH_temp38787961(ann_DASH_check_DASH_temp26717960);
}};
$e79497950.stack[R.EXN_STACKHEIGHT++] = $ss79537954;
}
if(R.isPyretException($e79497950)) {
$e79497950.pyretStack.push(L[1240]);
}
throw $e79497950;
}
var $ret79557956 = $Hann_DASH_check_DASH_temp38787961($z79517952);
++R.GAS;
return $ret79557956;
});
var anf_arg26747944 = G(v8871197,"with-members",L[1239]);
var $z79357936 = D;
var $f79417942 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg26737943,from_DASH_members8891212,anf_arg26747944):R.ffi.throwNonFunApp(L[119],fold5391,[anf_arg26737943,from_DASH_members8891212,anf_arg26747944]);
};
try {
if(--R.GAS > 0) {
$z79357936 = $f79417942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79417942,
"from":L[119]});
}
} catch($e79337934) {
if(R.isCont($e79337934)) {
var $ss79377938 = {"from":L[119],
"go":function(ann_DASH_check_DASH_temp26587945) {
return $Hann_DASH_check_DASH_temp38797946(ann_DASH_check_DASH_temp26587945,A244,Set2090);
}};
$e79337934.stack[R.EXN_STACKHEIGHT++] = $ss79377938;
}
if(R.isPyretException($e79337934)) {
$e79337934.pyretStack.push(L[119]);
}
throw $e79337934;
}
var $ret79397940 = $Hann_DASH_check_DASH_temp38797946($z79357936,A244,Set2090);
++R.GAS;
return $ret79397940;
};
var $Hann_DASH_check_DASH_temp38797946 = function(ann_DASH_check_DASH_temp26587945,A244,Set2090) {
return ann_DASH_check_DASH_temp26587945;
};
var $Hann_DASH_check_DASH_temp38787961 = function(ann_DASH_check_DASH_temp26717960) {
return ann_DASH_check_DASH_temp26717960;
};
var $Hann_DASH_check_DASH_temp38771238 = function(ann_DASH_check_DASH_temp26601237) {
return ann_DASH_check_DASH_temp26601237;
};
var $Hann_DASH_check_DASH_temp38761253 = function(ann_DASH_check_DASH_temp26611252) {
return ann_DASH_check_DASH_temp26611252;
};
var $Hann_DASH_check_DASH_temp38751269 = function(ann_DASH_check_DASH_temp26551268,A244,Set2090) {
return ann_DASH_check_DASH_temp26551268;
};
var $Hann_DASH_check_DASH_temp38741286 = function(ann_DASH_check_DASH_temp26011285,A244,Set2090) {
return ann_DASH_check_DASH_temp26011285;
};
var $Hanf_arg38731311 = function(anf_arg26481310,a8851299,freevars_DASH_e_DASH_acc795671,t8841298) {
var $z79647965 = D;
var $f79707971 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(t8841298,anf_arg26481310):R.ffi.throwNonFunApp(L[1243],freevars_DASH_e_DASH_acc795671.$var,[t8841298,anf_arg26481310]);
};
try {
if(--R.GAS > 0) {
$z79647965 = $f79707971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79707971,
"from":L[1243]});
}
} catch($e79627963) {
if(R.isCont($e79627963)) {
var $ss79667967 = {"from":L[1243],
"go":function(anf_arg26497972) {
return $Hanf_arg38727973(anf_arg26497972,a8851299,freevars_DASH_e_DASH_acc795671);
}};
$e79627963.stack[R.EXN_STACKHEIGHT++] = $ss79667967;
}
if(R.isPyretException($e79627963)) {
$e79627963.pyretStack.push(L[1243]);
}
throw $e79627963;
}
var $ret79687969 = $Hanf_arg38727973($z79647965,a8851299,freevars_DASH_e_DASH_acc795671);
++R.GAS;
return $ret79687969;
};
var $Hanf_arg38727973 = function(anf_arg26497972,a8851299,freevars_DASH_e_DASH_acc795671) {
var $z79767977 = D;
var $f79827983 = function(_) {
return R.isFunction(freevars_DASH_e_DASH_acc795671.$var)?freevars_DASH_e_DASH_acc795671.$var.app(a8851299,anf_arg26497972):R.ffi.throwNonFunApp(L[134],freevars_DASH_e_DASH_acc795671.$var,[a8851299,anf_arg26497972]);
};
try {
if(--R.GAS > 0) {
$z79767977 = $f79827983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79827983,
"from":L[134]});
}
} catch($e79747975) {
if(R.isCont($e79747975)) {
var $ss79787979 = {"from":L[134],
"go":function(ann_DASH_check_DASH_temp26477984) {
return $Hann_DASH_check_DASH_temp38717985(ann_DASH_check_DASH_temp26477984);
}};
$e79747975.stack[R.EXN_STACKHEIGHT++] = $ss79787979;
}
if(R.isPyretException($e79747975)) {
$e79747975.pyretStack.push(L[134]);
}
throw $e79747975;
}
var $ret79807981 = $Hann_DASH_check_DASH_temp38717985($z79767977);
++R.GAS;
return $ret79807981;
};
var $Hann_DASH_check_DASH_temp38717985 = function(ann_DASH_check_DASH_temp26477984) {
return ann_DASH_check_DASH_temp26477984;
};
var $Hann_DASH_check_DASH_temp38701324 = function(ann_DASH_check_DASH_temp26451323) {
return ann_DASH_check_DASH_temp26451323;
};
var $Hfrom_DASH_f38691342 = function(from_DASH_f8741341,args8711328,fold5391,freevars_DASH_v_DASH_acc800681,helper_DASH_args8731330,name8721329) {
var anf_arg26407996 = R.makeFunction(function(acc8767999,arg8778000) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1245],2,arguments);
}
var $z80038004 = D;
var $f80098010 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1246],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1246],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(arg8778000,acc8767999):R.ffi.throwNonFunApp(L[1245],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1246],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[arg8778000,acc8767999]);
};
try {
if(--R.GAS > 0) {
$z80038004 = $f80098010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80098010,
"from":L[1245]});
}
} catch($e80018002) {
if(R.isCont($e80018002)) {
var $ss80058006 = {"from":L[1245],
"go":function(ann_DASH_check_DASH_temp26398011) {
return $Hann_DASH_check_DASH_temp38648012(ann_DASH_check_DASH_temp26398011);
}};
$e80018002.stack[R.EXN_STACKHEIGHT++] = $ss80058006;
}
if(R.isPyretException($e80018002)) {
$e80018002.pyretStack.push(L[1245]);
}
throw $e80018002;
}
var $ret80078008 = $Hann_DASH_check_DASH_temp38648012($z80038004);
++R.GAS;
return $ret80078008;
});
var $z79887989 = D;
var $f79947995 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg26407996,from_DASH_f8741341,args8711328):R.ffi.throwNonFunApp(L[1244],fold5391,[anf_arg26407996,from_DASH_f8741341,args8711328]);
};
try {
if(--R.GAS > 0) {
$z79887989 = $f79947995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79947995,
"from":L[1244]});
}
} catch($e79867987) {
if(R.isCont($e79867987)) {
var $ss79907991 = {"from":L[1244],
"go":function(with_DASH_args8757997) {
return $Hwith_DASH_args38687998(with_DASH_args8757997,fold5391,freevars_DASH_v_DASH_acc800681,helper_DASH_args8731330,name8721329);
}};
$e79867987.stack[R.EXN_STACKHEIGHT++] = $ss79907991;
}
if(R.isPyretException($e79867987)) {
$e79867987.pyretStack.push(L[1244]);
}
throw $e79867987;
}
var $ret79927993 = $Hwith_DASH_args38687998($z79887989,fold5391,freevars_DASH_v_DASH_acc800681,helper_DASH_args8731330,name8721329);
++R.GAS;
return $ret79927993;
};
var $Hwith_DASH_args38687998 = function(with_DASH_args8757997,fold5391,freevars_DASH_v_DASH_acc800681,helper_DASH_args8731330,name8721329) {
var anf_arg26428023 = R.makeFunction(function(acc8798026,arg8808027) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1248],2,arguments);
}
var $z80308031 = D;
var $f80368037 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1249],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1249],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(arg8808027,acc8798026):R.ffi.throwNonFunApp(L[1248],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1249],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[arg8808027,acc8798026]);
};
try {
if(--R.GAS > 0) {
$z80308031 = $f80368037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80368037,
"from":L[1248]});
}
} catch($e80288029) {
if(R.isCont($e80288029)) {
var $ss80328033 = {"from":L[1248],
"go":function(ann_DASH_check_DASH_temp26418038) {
return $Hann_DASH_check_DASH_temp38658039(ann_DASH_check_DASH_temp26418038);
}};
$e80288029.stack[R.EXN_STACKHEIGHT++] = $ss80328033;
}
if(R.isPyretException($e80288029)) {
$e80288029.pyretStack.push(L[1248]);
}
throw $e80288029;
}
var $ret80348035 = $Hann_DASH_check_DASH_temp38658039($z80308031);
++R.GAS;
return $ret80348035;
});
var $z80158016 = D;
var $f80218022 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg26428023,with_DASH_args8757997,helper_DASH_args8731330):R.ffi.throwNonFunApp(L[1247],fold5391,[anf_arg26428023,with_DASH_args8757997,helper_DASH_args8731330]);
};
try {
if(--R.GAS > 0) {
$z80158016 = $f80218022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80218022,
"from":L[1247]});
}
} catch($e80138014) {
if(R.isCont($e80138014)) {
var $ss80178018 = {"from":L[1247],
"go":function(with_DASH_helper_DASH_args8788024) {
return $Hwith_DASH_helper_DASH_args38678025(with_DASH_helper_DASH_args8788024,name8721329);
}};
$e80138014.stack[R.EXN_STACKHEIGHT++] = $ss80178018;
}
if(R.isPyretException($e80138014)) {
$e80138014.pyretStack.push(L[1247]);
}
throw $e80138014;
}
var $ret80198020 = $Hwith_DASH_helper_DASH_args38678025($z80158016,name8721329);
++R.GAS;
return $ret80198020;
};
var $Hwith_DASH_helper_DASH_args38678025 = function(with_DASH_helper_DASH_args8788024,name8721329) {
var anf_fun26438050 = G(with_DASH_helper_DASH_args8788024,"remove",L[1250]);
var $z80428043 = D;
var $f80488049 = function(_) {
return R.isFunction(anf_fun26438050)?anf_fun26438050.app(name8721329):R.ffi.throwNonFunApp(L[139],anf_fun26438050,[name8721329]);
};
try {
if(--R.GAS > 0) {
$z80428043 = $f80488049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80488049,
"from":L[139]});
}
} catch($e80408041) {
if(R.isCont($e80408041)) {
var $ss80448045 = {"from":L[139],
"go":function(ann_DASH_check_DASH_temp26388051) {
return $Hann_DASH_check_DASH_temp38668052(ann_DASH_check_DASH_temp26388051);
}};
$e80408041.stack[R.EXN_STACKHEIGHT++] = $ss80448045;
}
if(R.isPyretException($e80408041)) {
$e80408041.pyretStack.push(L[139]);
}
throw $e80408041;
}
var $ret80468047 = $Hann_DASH_check_DASH_temp38668052($z80428043);
++R.GAS;
return $ret80468047;
};
var $Hann_DASH_check_DASH_temp38668052 = function(ann_DASH_check_DASH_temp26388051) {
return ann_DASH_check_DASH_temp26388051;
};
var $Hann_DASH_check_DASH_temp38658039 = function(ann_DASH_check_DASH_temp26418038) {
return ann_DASH_check_DASH_temp26418038;
};
var $Hann_DASH_check_DASH_temp38648012 = function(ann_DASH_check_DASH_temp26398011) {
return ann_DASH_check_DASH_temp26398011;
};
var $Hfrom_DASH_f38631357 = function(from_DASH_f8651356,args8641345,fold5391,freevars_DASH_v_DASH_acc800681) {
var anf_arg26368063 = R.makeFunction(function(acc8668066,arg8678067) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1251],2,arguments);
}
var $z80708071 = D;
var $f80768077 = function(_) {
return R.isFunction(freevars_DASH_v_DASH_acc800681.$var === D?U(L[1252],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var)?freevars_DASH_v_DASH_acc800681.$var === D?U(L[1252],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var.app(arg8678067,acc8668066):R.ffi.throwNonFunApp(L[1251],freevars_DASH_v_DASH_acc800681.$var === D?U(L[1252],"freevars-v-acc"):freevars_DASH_v_DASH_acc800681.$var,[arg8678067,acc8668066]);
};
try {
if(--R.GAS > 0) {
$z80708071 = $f80768077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80768077,
"from":L[1251]});
}
} catch($e80688069) {
if(R.isCont($e80688069)) {
var $ss80728073 = {"from":L[1251],
"go":function(ann_DASH_check_DASH_temp26358078) {
return $Hann_DASH_check_DASH_temp38618079(ann_DASH_check_DASH_temp26358078);
}};
$e80688069.stack[R.EXN_STACKHEIGHT++] = $ss80728073;
}
if(R.isPyretException($e80688069)) {
$e80688069.pyretStack.push(L[1251]);
}
throw $e80688069;
}
var $ret80748075 = $Hann_DASH_check_DASH_temp38618079($z80708071);
++R.GAS;
return $ret80748075;
});
var $z80558056 = D;
var $f80618062 = function(_) {
return R.isFunction(fold5391)?fold5391.app(anf_arg26368063,from_DASH_f8651356,args8641345):R.ffi.throwNonFunApp(L[142],fold5391,[anf_arg26368063,from_DASH_f8651356,args8641345]);
};
try {
if(--R.GAS > 0) {
$z80558056 = $f80618062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80618062,
"from":L[142]});
}
} catch($e80538054) {
if(R.isCont($e80538054)) {
var $ss80578058 = {"from":L[142],
"go":function(ann_DASH_check_DASH_temp26348064) {
return $Hann_DASH_check_DASH_temp38628065(ann_DASH_check_DASH_temp26348064);
}};
$e80538054.stack[R.EXN_STACKHEIGHT++] = $ss80578058;
}
if(R.isPyretException($e80538054)) {
$e80538054.pyretStack.push(L[142]);
}
throw $e80538054;
}
var $ret80598060 = $Hann_DASH_check_DASH_temp38628065($z80558056);
++R.GAS;
return $ret80598060;
};
var $Hann_DASH_check_DASH_temp38628065 = function(ann_DASH_check_DASH_temp26348064) {
return ann_DASH_check_DASH_temp26348064;
};
var $Hann_DASH_check_DASH_temp38618079 = function(ann_DASH_check_DASH_temp26358078) {
return ann_DASH_check_DASH_temp26358078;
};
var $Hfrom_DASH_e238601372 = function(from_DASH_e28611371,e18591359,freevars_DASH_l_DASH_acc798677) {
var $z80828083 = D;
var $f80888089 = function(_) {
return R.isFunction(freevars_DASH_l_DASH_acc798677.$var === D?U(L[1253],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var)?freevars_DASH_l_DASH_acc798677.$var === D?U(L[1253],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var.app(e18591359,from_DASH_e28611371):R.ffi.throwNonFunApp(L[145],freevars_DASH_l_DASH_acc798677.$var === D?U(L[1253],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var,[e18591359,from_DASH_e28611371]);
};
try {
if(--R.GAS > 0) {
$z80828083 = $f80888089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80888089,
"from":L[145]});
}
} catch($e80808081) {
if(R.isCont($e80808081)) {
var $ss80848085 = {"from":L[145],
"go":function(ann_DASH_check_DASH_temp26328090) {
return $Hann_DASH_check_DASH_temp38598091(ann_DASH_check_DASH_temp26328090);
}};
$e80808081.stack[R.EXN_STACKHEIGHT++] = $ss80848085;
}
if(R.isPyretException($e80808081)) {
$e80808081.pyretStack.push(L[145]);
}
throw $e80808081;
}
var $ret80868087 = $Hann_DASH_check_DASH_temp38598091($z80828083);
++R.GAS;
return $ret80868087;
};
var $Hann_DASH_check_DASH_temp38598091 = function(ann_DASH_check_DASH_temp26328090) {
return ann_DASH_check_DASH_temp26328090;
};
var $Hfrom_DASH_body38581388 = function(from_DASH_body8571387,b8541374,e8551375,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677) {
var anf_arg26268105 = G(b8541374,"ann",L[1257]);
var anf_fun26278102 = G(from_DASH_body8571387,"remove",L[1256]);
var anf_arg26288103 = G(b8541374,"id",L[1255]);
var $z80948095 = D;
var $f81008101 = function(_) {
return R.isFunction(anf_fun26278102)?anf_fun26278102.app(anf_arg26288103):R.ffi.throwNonFunApp(L[1254],anf_fun26278102,[anf_arg26288103]);
};
try {
if(--R.GAS > 0) {
$z80948095 = $f81008101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81008101,
"from":L[1254]});
}
} catch($e80928093) {
if(R.isCont($e80928093)) {
var $ss80968097 = {"from":L[1254],
"go":function(anf_arg26298104) {
return $Hanf_arg38578106(anf_arg26298104,anf_arg26268105,e8551375,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677);
}};
$e80928093.stack[R.EXN_STACKHEIGHT++] = $ss80968097;
}
if(R.isPyretException($e80928093)) {
$e80928093.pyretStack.push(L[1254]);
}
throw $e80928093;
}
var $ret80988099 = $Hanf_arg38578106($z80948095,anf_arg26268105,e8551375,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677);
++R.GAS;
return $ret80988099;
};
var $Hanf_arg38578106 = function(anf_arg26298104,anf_arg26268105,e8551375,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677) {
var $z81098110 = D;
var $f81158116 = function(_) {
return R.isFunction(freevars_DASH_l_DASH_acc798677.$var === D?U(L[1258],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var)?freevars_DASH_l_DASH_acc798677.$var === D?U(L[1258],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var.app(e8551375,anf_arg26298104):R.ffi.throwNonFunApp(L[1259],freevars_DASH_l_DASH_acc798677.$var === D?U(L[1258],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var,[e8551375,anf_arg26298104]);
};
try {
if(--R.GAS > 0) {
$z81098110 = $f81158116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81158116,
"from":L[1259]});
}
} catch($e81078108) {
if(R.isCont($e81078108)) {
var $ss81118112 = {"from":L[1259],
"go":function(anf_arg26308117) {
return $Hanf_arg38568118(anf_arg26308117,anf_arg26268105,freevars_DASH_ann_DASH_acc794669);
}};
$e81078108.stack[R.EXN_STACKHEIGHT++] = $ss81118112;
}
if(R.isPyretException($e81078108)) {
$e81078108.pyretStack.push(L[1259]);
}
throw $e81078108;
}
var $ret81138114 = $Hanf_arg38568118($z81098110,anf_arg26268105,freevars_DASH_ann_DASH_acc794669);
++R.GAS;
return $ret81138114;
};
var $Hanf_arg38568118 = function(anf_arg26308117,anf_arg26268105,freevars_DASH_ann_DASH_acc794669) {
var $z81218122 = D;
var $f81278128 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(anf_arg26268105,anf_arg26308117):R.ffi.throwNonFunApp(L[147],freevars_DASH_ann_DASH_acc794669.$var,[anf_arg26268105,anf_arg26308117]);
};
try {
if(--R.GAS > 0) {
$z81218122 = $f81278128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81278128,
"from":L[147]});
}
} catch($e81198120) {
if(R.isCont($e81198120)) {
var $ss81238124 = {"from":L[147],
"go":function(ann_DASH_check_DASH_temp26258129) {
return $Hann_DASH_check_DASH_temp38558130(ann_DASH_check_DASH_temp26258129);
}};
$e81198120.stack[R.EXN_STACKHEIGHT++] = $ss81238124;
}
if(R.isPyretException($e81198120)) {
$e81198120.pyretStack.push(L[147]);
}
throw $e81198120;
}
var $ret81258126 = $Hann_DASH_check_DASH_temp38558130($z81218122);
++R.GAS;
return $ret81258126;
};
var $Hann_DASH_check_DASH_temp38558130 = function(ann_DASH_check_DASH_temp26258129) {
return ann_DASH_check_DASH_temp26258129;
};
var $Hfrom_DASH_body38541404 = function(from_DASH_body8521403,b8491390,e8501391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677) {
var anf_arg26198144 = G(b8491390,"ann",L[1263]);
var anf_fun26208141 = G(from_DASH_body8521403,"remove",L[1262]);
var anf_arg26218142 = G(b8491390,"id",L[1261]);
var $z81338134 = D;
var $f81398140 = function(_) {
return R.isFunction(anf_fun26208141)?anf_fun26208141.app(anf_arg26218142):R.ffi.throwNonFunApp(L[1260],anf_fun26208141,[anf_arg26218142]);
};
try {
if(--R.GAS > 0) {
$z81338134 = $f81398140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81398140,
"from":L[1260]});
}
} catch($e81318132) {
if(R.isCont($e81318132)) {
var $ss81358136 = {"from":L[1260],
"go":function(anf_arg26228143) {
return $Hanf_arg38538145(anf_arg26228143,anf_arg26198144,e8501391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677);
}};
$e81318132.stack[R.EXN_STACKHEIGHT++] = $ss81358136;
}
if(R.isPyretException($e81318132)) {
$e81318132.pyretStack.push(L[1260]);
}
throw $e81318132;
}
var $ret81378138 = $Hanf_arg38538145($z81338134,anf_arg26198144,e8501391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677);
++R.GAS;
return $ret81378138;
};
var $Hanf_arg38538145 = function(anf_arg26228143,anf_arg26198144,e8501391,freevars_DASH_ann_DASH_acc794669,freevars_DASH_l_DASH_acc798677) {
var $z81488149 = D;
var $f81548155 = function(_) {
return R.isFunction(freevars_DASH_l_DASH_acc798677.$var === D?U(L[1264],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var)?freevars_DASH_l_DASH_acc798677.$var === D?U(L[1264],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var.app(e8501391,anf_arg26228143):R.ffi.throwNonFunApp(L[1265],freevars_DASH_l_DASH_acc798677.$var === D?U(L[1264],"freevars-l-acc"):freevars_DASH_l_DASH_acc798677.$var,[e8501391,anf_arg26228143]);
};
try {
if(--R.GAS > 0) {
$z81488149 = $f81548155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81548155,
"from":L[1265]});
}
} catch($e81468147) {
if(R.isCont($e81468147)) {
var $ss81508151 = {"from":L[1265],
"go":function(anf_arg26238156) {
return $Hanf_arg38528157(anf_arg26238156,anf_arg26198144,freevars_DASH_ann_DASH_acc794669);
}};
$e81468147.stack[R.EXN_STACKHEIGHT++] = $ss81508151;
}
if(R.isPyretException($e81468147)) {
$e81468147.pyretStack.push(L[1265]);
}
throw $e81468147;
}
var $ret81528153 = $Hanf_arg38528157($z81488149,anf_arg26198144,freevars_DASH_ann_DASH_acc794669);
++R.GAS;
return $ret81528153;
};
var $Hanf_arg38528157 = function(anf_arg26238156,anf_arg26198144,freevars_DASH_ann_DASH_acc794669) {
var $z81608161 = D;
var $f81668167 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(anf_arg26198144,anf_arg26238156):R.ffi.throwNonFunApp(L[149],freevars_DASH_ann_DASH_acc794669.$var,[anf_arg26198144,anf_arg26238156]);
};
try {
if(--R.GAS > 0) {
$z81608161 = $f81668167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81668167,
"from":L[149]});
}
} catch($e81588159) {
if(R.isCont($e81588159)) {
var $ss81628163 = {"from":L[149],
"go":function(ann_DASH_check_DASH_temp26188168) {
return $Hann_DASH_check_DASH_temp38518169(ann_DASH_check_DASH_temp26188168);
}};
$e81588159.stack[R.EXN_STACKHEIGHT++] = $ss81628163;
}
if(R.isPyretException($e81588159)) {
$e81588159.pyretStack.push(L[149]);
}
throw $e81588159;
}
var $ret81648165 = $Hann_DASH_check_DASH_temp38518169($z81608161);
++R.GAS;
return $ret81648165;
};
var $Hann_DASH_check_DASH_temp38518169 = function(ann_DASH_check_DASH_temp26188168) {
return ann_DASH_check_DASH_temp26188168;
};
var $Hbody_DASH_ids38501419 = function(body_DASH_ids8411418,b8391406,freevars_DASH_ann_DASH_acc794669) {
var cases_DASH_val3128220 = b8391406;
var anf_fun26048180 = G(cases_DASH_val3128220,"_match",L[1266]);
var anf_obj26088186 = R.makeFunction(function($underscore8428204,name8438205,ann8448206) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1270],3,arguments);
}
var anf_fun26068217 = G(body_DASH_ids8411418,"remove",L[1272]);
var $z82098210 = D;
var $f82158216 = function(_) {
return R.isFunction(anf_fun26068217)?anf_fun26068217.app(name8438205):R.ffi.throwNonFunApp(L[1271],anf_fun26068217,[name8438205]);
};
try {
if(--R.GAS > 0) {
$z82098210 = $f82158216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82158216,
"from":L[1271]});
}
} catch($e82078208) {
if(R.isCont($e82078208)) {
var $ss82118212 = {"from":L[1271],
"go":function(anf_arg26078218) {
return $Hanf_arg38468219(anf_arg26078218,ann8448206,freevars_DASH_ann_DASH_acc794669);
}};
$e82078208.stack[R.EXN_STACKHEIGHT++] = $ss82118212;
}
if(R.isPyretException($e82078208)) {
$e82078208.pyretStack.push(L[1271]);
}
throw $e82078208;
}
var $ret82138214 = $Hanf_arg38468219($z82098210,ann8448206,freevars_DASH_ann_DASH_acc794669);
++R.GAS;
return $ret82138214;
});
var anf_obj26138187 = R.makeFunction(function($underscore8458188,name8468189,nameb8478190) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1267],3,arguments);
}
var anf_fun26108201 = G(body_DASH_ids8411418,"remove",L[1269]);
var $z81938194 = D;
var $f81998200 = function(_) {
return R.isFunction(anf_fun26108201)?anf_fun26108201.app(name8468189):R.ffi.throwNonFunApp(L[1268],anf_fun26108201,[name8468189]);
};
try {
if(--R.GAS > 0) {
$z81938194 = $f81998200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81998200,
"from":L[1268]});
}
} catch($e81918192) {
if(R.isCont($e81918192)) {
var $ss81958196 = {"from":L[1268],
"go":function(anf_bracket26118202) {
return $Hanf_bracket38488203(anf_bracket26118202,nameb8478190);
}};
$e81918192.stack[R.EXN_STACKHEIGHT++] = $ss81958196;
}
if(R.isPyretException($e81918192)) {
$e81918192.pyretStack.push(L[1268]);
}
throw $e81918192;
}
var $ret81978198 = $Hanf_bracket38488203($z81938194,nameb8478190);
++R.GAS;
return $ret81978198;
});
var anf_arg26148181 = R.makeObject({"a-type-bind":anf_obj26088186,
"a-newtype-bind":anf_obj26138187});
var anf_arg26168182 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1266],0,arguments);
}
var ann_DASH_check_DASH_temp26158185 = R.throwNoBranchesMatched(L[1266],("cases"));
return ann_DASH_check_DASH_temp26158185;
});
var $z81728173 = D;
var $f81788179 = function(_) {
return R.isFunction(anf_fun26048180)?anf_fun26048180.app(anf_arg26148181,anf_arg26168182):R.ffi.throwNonFunApp(L[151],anf_fun26048180,[anf_arg26148181,anf_arg26168182]);
};
try {
if(--R.GAS > 0) {
$z81728173 = $f81788179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81788179,
"from":L[151]});
}
} catch($e81708171) {
if(R.isCont($e81708171)) {
var $ss81748175 = {"from":L[151],
"go":function(ann_DASH_check_DASH_temp26038183) {
return $Hann_DASH_check_DASH_temp38498184(ann_DASH_check_DASH_temp26038183);
}};
$e81708171.stack[R.EXN_STACKHEIGHT++] = $ss81748175;
}
if(R.isPyretException($e81708171)) {
$e81708171.pyretStack.push(L[151]);
}
throw $e81708171;
}
var $ret81768177 = $Hann_DASH_check_DASH_temp38498184($z81728173);
++R.GAS;
return $ret81768177;
};
var $Hann_DASH_check_DASH_temp38498184 = function(ann_DASH_check_DASH_temp26038183) {
return ann_DASH_check_DASH_temp26038183;
};
var $Hanf_bracket38488203 = function(anf_bracket26118202,nameb8478190) {
var anf_fun26128231 = G(anf_bracket26118202,"remove",L[1273]);
var $z82238224 = D;
var $f82298230 = function(_) {
return R.isFunction(anf_fun26128231)?anf_fun26128231.app(nameb8478190):R.ffi.throwNonFunApp(L[1267],anf_fun26128231,[nameb8478190]);
};
try {
if(--R.GAS > 0) {
$z82238224 = $f82298230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82298230,
"from":L[1267]});
}
} catch($e82218222) {
if(R.isCont($e82218222)) {
var $ss82258226 = {"from":L[1267],
"go":function(ann_DASH_check_DASH_temp26098232) {
return $Hann_DASH_check_DASH_temp38478233(ann_DASH_check_DASH_temp26098232);
}};
$e82218222.stack[R.EXN_STACKHEIGHT++] = $ss82258226;
}
if(R.isPyretException($e82218222)) {
$e82218222.pyretStack.push(L[1267]);
}
throw $e82218222;
}
var $ret82278228 = $Hann_DASH_check_DASH_temp38478233($z82238224);
++R.GAS;
return $ret82278228;
};
var $Hann_DASH_check_DASH_temp38478233 = function(ann_DASH_check_DASH_temp26098232) {
return ann_DASH_check_DASH_temp26098232;
};
var $Hanf_arg38468219 = function(anf_arg26078218,ann8448206,freevars_DASH_ann_DASH_acc794669) {
var $z82368237 = D;
var $f82428243 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(ann8448206,anf_arg26078218):R.ffi.throwNonFunApp(L[1270],freevars_DASH_ann_DASH_acc794669.$var,[ann8448206,anf_arg26078218]);
};
try {
if(--R.GAS > 0) {
$z82368237 = $f82428243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82428243,
"from":L[1270]});
}
} catch($e82348235) {
if(R.isCont($e82348235)) {
var $ss82388239 = {"from":L[1270],
"go":function(ann_DASH_check_DASH_temp26058244) {
return $Hann_DASH_check_DASH_temp38458245(ann_DASH_check_DASH_temp26058244);
}};
$e82348235.stack[R.EXN_STACKHEIGHT++] = $ss82388239;
}
if(R.isPyretException($e82348235)) {
$e82348235.pyretStack.push(L[1270]);
}
throw $e82348235;
}
var $ret82408241 = $Hann_DASH_check_DASH_temp38458245($z82368237);
++R.GAS;
return $ret82408241;
};
var $Hann_DASH_check_DASH_temp38458245 = function(ann_DASH_check_DASH_temp26058244) {
return ann_DASH_check_DASH_temp26058244;
};
var $Hann_DASH_check_DASH_temp38441437 = function(ann_DASH_check_DASH_temp25571436,A244,Set2090) {
return ann_DASH_check_DASH_temp25571436;
};
var $Hname38431465 = function(name8301464,a8281449,freevars_DASH_ann_DASH_acc794669,seen_DASH_so_DASH_far8081422) {
var anf_fun25948256 = G(seen_DASH_so_DASH_far8081422,"add",L[1275]);
var $z82488249 = D;
var $f82548255 = function(_) {
return R.isFunction(anf_fun25948256)?anf_fun25948256.app(name8301464):R.ffi.throwNonFunApp(L[1274],anf_fun25948256,[name8301464]);
};
try {
if(--R.GAS > 0) {
$z82488249 = $f82548255();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82548255,
"from":L[1274]});
}
} catch($e82468247) {
if(R.isCont($e82468247)) {
var $ss82508251 = {"from":L[1274],
"go":function(anf_arg25958257) {
return $Hanf_arg38428258(anf_arg25958257,a8281449,freevars_DASH_ann_DASH_acc794669);
}};
$e82468247.stack[R.EXN_STACKHEIGHT++] = $ss82508251;
}
if(R.isPyretException($e82468247)) {
$e82468247.pyretStack.push(L[1274]);
}
throw $e82468247;
}
var $ret82528253 = $Hanf_arg38428258($z82488249,a8281449,freevars_DASH_ann_DASH_acc794669);
++R.GAS;
return $ret82528253;
};
var $Hanf_arg38428258 = function(anf_arg25958257,a8281449,freevars_DASH_ann_DASH_acc794669) {
var $z82618262 = D;
var $f82678268 = function(_) {
return R.isFunction(freevars_DASH_ann_DASH_acc794669.$var)?freevars_DASH_ann_DASH_acc794669.$var.app(a8281449,anf_arg25958257):R.ffi.throwNonFunApp(L[157],freevars_DASH_ann_DASH_acc794669.$var,[a8281449,anf_arg25958257]);
};
try {
if(--R.GAS > 0) {
$z82618262 = $f82678268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82678268,
"from":L[157]});
}
} catch($e82598260) {
if(R.isCont($e82598260)) {
var $ss82638264 = {"from":L[157],
"go":function(ann_DASH_check_DASH_temp25858269) {
return $Hann_DASH_check_DASH_temp38418270(ann_DASH_check_DASH_temp25858269);
}};
$e82598260.stack[R.EXN_STACKHEIGHT++] = $ss82638264;
}
if(R.isPyretException($e82598260)) {
$e82598260.pyretStack.push(L[157]);
}
throw $e82598260;
}
var $ret82658266 = $Hann_DASH_check_DASH_temp38418270($z82618262);
++R.GAS;
return $ret82658266;
};
var $Hann_DASH_check_DASH_temp38418270 = function(ann_DASH_check_DASH_temp25858269) {
return ann_DASH_check_DASH_temp25858269;
};
var $Hanf_arg38401492 = function(anf_arg25831490,lst_DASH_a8091491) {
var $z82738274 = D;
var $f82798280 = function(_) {
return R.isFunction(lst_DASH_a8091491)?lst_DASH_a8091491.app(anf_arg25831490):R.ffi.throwNonFunApp(L[162],lst_DASH_a8091491,[anf_arg25831490]);
};
try {
if(--R.GAS > 0) {
$z82738274 = $f82798280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82798280,
"from":L[162]});
}
} catch($e82718272) {
if(R.isCont($e82718272)) {
var $ss82758276 = {"from":L[162],
"go":function(ann_DASH_check_DASH_temp25828281) {
return $Hann_DASH_check_DASH_temp38398282(ann_DASH_check_DASH_temp25828281);
}};
$e82718272.stack[R.EXN_STACKHEIGHT++] = $ss82758276;
}
if(R.isPyretException($e82718272)) {
$e82718272.pyretStack.push(L[162]);
}
throw $e82718272;
}
var $ret82778278 = $Hann_DASH_check_DASH_temp38398282($z82738274);
++R.GAS;
return $ret82778278;
};
var $Hann_DASH_check_DASH_temp38398282 = function(ann_DASH_check_DASH_temp25828281) {
return ann_DASH_check_DASH_temp25828281;
};
var $Hanf_arg38381508 = function(anf_arg25801507,lst_DASH_a8091491) {
var $z82858286 = D;
var $f82918292 = function(_) {
return R.isFunction(lst_DASH_a8091491)?lst_DASH_a8091491.app(anf_arg25801507):R.ffi.throwNonFunApp(L[164],lst_DASH_a8091491,[anf_arg25801507]);
};
try {
if(--R.GAS > 0) {
$z82858286 = $f82918292();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82918292,
"from":L[164]});
}
} catch($e82838284) {
if(R.isCont($e82838284)) {
var $ss82878288 = {"from":L[164],
"go":function(ann_DASH_check_DASH_temp25768293) {
return $Hann_DASH_check_DASH_temp38378294(ann_DASH_check_DASH_temp25768293);
}};
$e82838284.stack[R.EXN_STACKHEIGHT++] = $ss82878288;
}
if(R.isPyretException($e82838284)) {
$e82838284.pyretStack.push(L[164]);
}
throw $e82838284;
}
var $ret82898290 = $Hann_DASH_check_DASH_temp38378294($z82858286);
++R.GAS;
return $ret82898290;
};
var $Hann_DASH_check_DASH_temp38378294 = function(ann_DASH_check_DASH_temp25768293) {
return ann_DASH_check_DASH_temp25768293;
};
var $Hanf_arg38361525 = function(anf_arg25741524,lst_DASH_a8091491) {
var $z82978298 = D;
var $f83038304 = function(_) {
return R.isFunction(lst_DASH_a8091491)?lst_DASH_a8091491.app(anf_arg25741524):R.ffi.throwNonFunApp(L[168],lst_DASH_a8091491,[anf_arg25741524]);
};
try {
if(--R.GAS > 0) {
$z82978298 = $f83038304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83038304,
"from":L[168]});
}
} catch($e82958296) {
if(R.isCont($e82958296)) {
var $ss82998300 = {"from":L[168],
"go":function(ann_DASH_check_DASH_temp25738305) {
return $Hann_DASH_check_DASH_temp38358306(ann_DASH_check_DASH_temp25738305);
}};
$e82958296.stack[R.EXN_STACKHEIGHT++] = $ss82998300;
}
if(R.isPyretException($e82958296)) {
$e82958296.pyretStack.push(L[168]);
}
throw $e82958296;
}
var $ret83018302 = $Hann_DASH_check_DASH_temp38358306($z82978298);
++R.GAS;
return $ret83018302;
};
var $Hann_DASH_check_DASH_temp38358306 = function(ann_DASH_check_DASH_temp25738305) {
return ann_DASH_check_DASH_temp25738305;
};
var $Hanf_arg38341541 = function(anf_arg25711540,lst_DASH_a8091491) {
var $z83098310 = D;
var $f83158316 = function(_) {
return R.isFunction(lst_DASH_a8091491)?lst_DASH_a8091491.app(anf_arg25711540):R.ffi.throwNonFunApp(L[170],lst_DASH_a8091491,[anf_arg25711540]);
};
try {
if(--R.GAS > 0) {
$z83098310 = $f83158316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83158316,
"from":L[170]});
}
} catch($e83078308) {
if(R.isCont($e83078308)) {
var $ss83118312 = {"from":L[170],
"go":function(ann_DASH_check_DASH_temp25708317) {
return $Hann_DASH_check_DASH_temp38338318(ann_DASH_check_DASH_temp25708317);
}};
$e83078308.stack[R.EXN_STACKHEIGHT++] = $ss83118312;
}
if(R.isPyretException($e83078308)) {
$e83078308.pyretStack.push(L[170]);
}
throw $e83078308;
}
var $ret83138314 = $Hann_DASH_check_DASH_temp38338318($z83098310);
++R.GAS;
return $ret83138314;
};
var $Hann_DASH_check_DASH_temp38338318 = function(ann_DASH_check_DASH_temp25708317) {
return ann_DASH_check_DASH_temp25708317;
};
var $Hann_DASH_check_DASH_temp38321557 = function(ann_DASH_check_DASH_temp25671556) {
return ann_DASH_check_DASH_temp25671556;
};
var $Hann_DASH_check_DASH_temp38311572 = function(ann_DASH_check_DASH_temp25641571) {
return ann_DASH_check_DASH_temp25641571;
};
var $Hann_DASH_check_DASH_temp38301588 = function(ann_DASH_check_DASH_temp25581587) {
return ann_DASH_check_DASH_temp25581587;
};
var $Hann_DASH_check_DASH_temp38291603 = function(ann_DASH_check_DASH_temp25531602) {
return ann_DASH_check_DASH_temp25531602;
};
var $Hann_DASH_check_DASH_temp38281617 = function(ann_DASH_check_DASH_temp25541616) {
return ann_DASH_check_DASH_temp25541616;
};
var $Hann_DASH_check_DASH_temp38271675 = function(ann_DASH_check_DASH_temp25511674) {
return ann_DASH_check_DASH_temp25511674;
};
var $Hann_DASH_check_DASH_temp38261690 = function(ann_DASH_check_DASH_temp25491689) {
return ann_DASH_check_DASH_temp25491689;
};
var $Hann_DASH_check_DASH_temp38251705 = function(ann_DASH_check_DASH_temp25471704) {
return ann_DASH_check_DASH_temp25471704;
};
var $Hann_DASH_check_DASH_temp38241719 = function(ann_DASH_check_DASH_temp25451718) {
return ann_DASH_check_DASH_temp25451718;
};
var $Hann_DASH_check_DASH_temp38231734 = function(ann_DASH_check_DASH_temp25431733) {
return ann_DASH_check_DASH_temp25431733;
};
var $Hann_DASH_check_DASH_temp38221749 = function(ann_DASH_check_DASH_temp25411748) {
return ann_DASH_check_DASH_temp25411748;
};
var $Hanf_arg38211765 = function(anf_arg25391763,a_DASH_array237633,l7731764) {
var $z83218322 = D;
var $f83278328 = function(_) {
return R.isFunction(a_DASH_array237633.$var)?a_DASH_array237633.$var.app(l7731764,anf_arg25391763):R.ffi.throwNonFunApp(L[208],a_DASH_array237633.$var,[l7731764,anf_arg25391763]);
};
try {
if(--R.GAS > 0) {
$z83218322 = $f83278328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83278328,
"from":L[208]});
}
} catch($e83198320) {
if(R.isCont($e83198320)) {
var $ss83238324 = {"from":L[208],
"go":function(ann_DASH_check_DASH_temp25348329) {
return $Hann_DASH_check_DASH_temp38208330(ann_DASH_check_DASH_temp25348329);
}};
$e83198320.stack[R.EXN_STACKHEIGHT++] = $ss83238324;
}
if(R.isPyretException($e83198320)) {
$e83198320.pyretStack.push(L[208]);
}
throw $e83198320;
}
var $ret83258326 = $Hann_DASH_check_DASH_temp38208330($z83218322);
++R.GAS;
return $ret83258326;
};
var $Hann_DASH_check_DASH_temp38208330 = function(ann_DASH_check_DASH_temp25348329) {
return ann_DASH_check_DASH_temp25348329;
};
var $Hann_DASH_check_DASH_temp38191780 = function(ann_DASH_check_DASH_temp25361779) {
return ann_DASH_check_DASH_temp25361779;
};
var $Hann_DASH_check_DASH_temp38181795 = function(ann_DASH_check_DASH_temp25321794) {
return ann_DASH_check_DASH_temp25321794;
};
var $Hann_DASH_check_DASH_temp38171810 = function(ann_DASH_check_DASH_temp25301809) {
return ann_DASH_check_DASH_temp25301809;
};
var $Hanf_arg38161827 = function(anf_arg25281824,a_DASH_field224607,l7631825,name7641826) {
var $z83338334 = D;
var $f83398340 = function(_) {
return R.isFunction(a_DASH_field224607.$var)?a_DASH_field224607.$var.app(l7631825,name7641826,anf_arg25281824):R.ffi.throwNonFunApp(L[218],a_DASH_field224607.$var,[l7631825,name7641826,anf_arg25281824]);
};
try {
if(--R.GAS > 0) {
$z83338334 = $f83398340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83398340,
"from":L[218]});
}
} catch($e83318332) {
if(R.isCont($e83318332)) {
var $ss83358336 = {"from":L[218],
"go":function(ann_DASH_check_DASH_temp25268341) {
return $Hann_DASH_check_DASH_temp38158342(ann_DASH_check_DASH_temp25268341);
}};
$e83318332.stack[R.EXN_STACKHEIGHT++] = $ss83358336;
}
if(R.isPyretException($e83318332)) {
$e83318332.pyretStack.push(L[218]);
}
throw $e83318332;
}
var $ret83378338 = $Hann_DASH_check_DASH_temp38158342($z83338334);
++R.GAS;
return $ret83378338;
};
var $Hann_DASH_check_DASH_temp38158342 = function(ann_DASH_check_DASH_temp25268341) {
return ann_DASH_check_DASH_temp25268341;
};
var $Hann_DASH_check_DASH_temp38141843 = function(ann_DASH_check_DASH_temp25241842) {
return ann_DASH_check_DASH_temp25241842;
};
var $Hanf_arg38131858 = function(anf_arg25221857,a_DASH_val218595) {
var $z83458346 = D;
var $f83518352 = function(_) {
return R.isFunction(a_DASH_val218595.$var)?a_DASH_val218595.$var.app(anf_arg25221857):R.ffi.throwNonFunApp(L[226],a_DASH_val218595.$var,[anf_arg25221857]);
};
try {
if(--R.GAS > 0) {
$z83458346 = $f83518352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83518352,
"from":L[226]});
}
} catch($e83438344) {
if(R.isCont($e83438344)) {
var $ss83478348 = {"from":L[226],
"go":function(ann_DASH_check_DASH_temp25208353) {
return $Hann_DASH_check_DASH_temp38128354(ann_DASH_check_DASH_temp25208353);
}};
$e83438344.stack[R.EXN_STACKHEIGHT++] = $ss83478348;
}
if(R.isPyretException($e83438344)) {
$e83438344.pyretStack.push(L[226]);
}
throw $e83438344;
}
var $ret83498350 = $Hann_DASH_check_DASH_temp38128354($z83458346);
++R.GAS;
return $ret83498350;
};
var $Hann_DASH_check_DASH_temp38128354 = function(ann_DASH_check_DASH_temp25208353) {
return ann_DASH_check_DASH_temp25208353;
};
var $Hanf_arg38111877 = function(anf_arg25161872,a_DASH_method216591,body7551873,l7521874,ret7541875,self7511876) {
var anf_fun25178365 = G(body7551873,"visit",L[1277]);
var $z83578358 = D;
var $f83638364 = function(_) {
return R.isFunction(anf_fun25178365)?anf_fun25178365.app(self7511876):R.ffi.throwNonFunApp(L[1276],anf_fun25178365,[self7511876]);
};
try {
if(--R.GAS > 0) {
$z83578358 = $f83638364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83638364,
"from":L[1276]});
}
} catch($e83558356) {
if(R.isCont($e83558356)) {
var $ss83598360 = {"from":L[1276],
"go":function(anf_arg25188366) {
return $Hanf_arg38108367(anf_arg25188366,a_DASH_method216591,anf_arg25161872,l7521874,ret7541875);
}};
$e83558356.stack[R.EXN_STACKHEIGHT++] = $ss83598360;
}
if(R.isPyretException($e83558356)) {
$e83558356.pyretStack.push(L[1276]);
}
throw $e83558356;
}
var $ret83618362 = $Hanf_arg38108367($z83578358,a_DASH_method216591,anf_arg25161872,l7521874,ret7541875);
++R.GAS;
return $ret83618362;
};
var $Hanf_arg38108367 = function(anf_arg25188366,a_DASH_method216591,anf_arg25161872,l7521874,ret7541875) {
var $z83708371 = D;
var $f83768377 = function(_) {
return R.isFunction(a_DASH_method216591.$var)?a_DASH_method216591.$var.app(l7521874,anf_arg25161872,ret7541875,anf_arg25188366):R.ffi.throwNonFunApp(L[234],a_DASH_method216591.$var,[l7521874,anf_arg25161872,ret7541875,anf_arg25188366]);
};
try {
if(--R.GAS > 0) {
$z83708371 = $f83768377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83768377,
"from":L[234]});
}
} catch($e83688369) {
if(R.isCont($e83688369)) {
var $ss83728373 = {"from":L[234],
"go":function(ann_DASH_check_DASH_temp25118378) {
return $Hann_DASH_check_DASH_temp38098379(ann_DASH_check_DASH_temp25118378);
}};
$e83688369.stack[R.EXN_STACKHEIGHT++] = $ss83728373;
}
if(R.isPyretException($e83688369)) {
$e83688369.pyretStack.push(L[234]);
}
throw $e83688369;
}
var $ret83748375 = $Hann_DASH_check_DASH_temp38098379($z83708371);
++R.GAS;
return $ret83748375;
};
var $Hann_DASH_check_DASH_temp38098379 = function(ann_DASH_check_DASH_temp25118378) {
return ann_DASH_check_DASH_temp25118378;
};
var $Hann_DASH_check_DASH_temp38081891 = function(ann_DASH_check_DASH_temp25131890) {
return ann_DASH_check_DASH_temp25131890;
};
var $Hanf_arg38071910 = function(anf_arg25071905,a_DASH_lam214587,body7501906,l7471907,ret7491908,self7461909) {
var anf_fun25088390 = G(body7501906,"visit",L[1279]);
var $z83828383 = D;
var $f83888389 = function(_) {
return R.isFunction(anf_fun25088390)?anf_fun25088390.app(self7461909):R.ffi.throwNonFunApp(L[1278],anf_fun25088390,[self7461909]);
};
try {
if(--R.GAS > 0) {
$z83828383 = $f83888389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83888389,
"from":L[1278]});
}
} catch($e83808381) {
if(R.isCont($e83808381)) {
var $ss83848385 = {"from":L[1278],
"go":function(anf_arg25098391) {
return $Hanf_arg38068392(anf_arg25098391,a_DASH_lam214587,anf_arg25071905,l7471907,ret7491908);
}};
$e83808381.stack[R.EXN_STACKHEIGHT++] = $ss83848385;
}
if(R.isPyretException($e83808381)) {
$e83808381.pyretStack.push(L[1278]);
}
throw $e83808381;
}
var $ret83868387 = $Hanf_arg38068392($z83828383,a_DASH_lam214587,anf_arg25071905,l7471907,ret7491908);
++R.GAS;
return $ret83868387;
};
var $Hanf_arg38068392 = function(anf_arg25098391,a_DASH_lam214587,anf_arg25071905,l7471907,ret7491908) {
var $z83958396 = D;
var $f84018402 = function(_) {
return R.isFunction(a_DASH_lam214587.$var)?a_DASH_lam214587.$var.app(l7471907,anf_arg25071905,ret7491908,anf_arg25098391):R.ffi.throwNonFunApp(L[242],a_DASH_lam214587.$var,[l7471907,anf_arg25071905,ret7491908,anf_arg25098391]);
};
try {
if(--R.GAS > 0) {
$z83958396 = $f84018402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84018402,
"from":L[242]});
}
} catch($e83938394) {
if(R.isCont($e83938394)) {
var $ss83978398 = {"from":L[242],
"go":function(ann_DASH_check_DASH_temp25028403) {
return $Hann_DASH_check_DASH_temp38058404(ann_DASH_check_DASH_temp25028403);
}};
$e83938394.stack[R.EXN_STACKHEIGHT++] = $ss83978398;
}
if(R.isPyretException($e83938394)) {
$e83938394.pyretStack.push(L[242]);
}
throw $e83938394;
}
var $ret83998400 = $Hann_DASH_check_DASH_temp38058404($z83958396);
++R.GAS;
return $ret83998400;
};
var $Hann_DASH_check_DASH_temp38058404 = function(ann_DASH_check_DASH_temp25028403) {
return ann_DASH_check_DASH_temp25028403;
};
var $Hann_DASH_check_DASH_temp38041924 = function(ann_DASH_check_DASH_temp25041923) {
return ann_DASH_check_DASH_temp25041923;
};
var $Hanf_arg38031941 = function(anf_arg25001938,a_DASH_get_DASH_bang212583,field7451939,l7431940) {
var $z84078408 = D;
var $f84138414 = function(_) {
return R.isFunction(a_DASH_get_DASH_bang212583.$var)?a_DASH_get_DASH_bang212583.$var.app(l7431940,anf_arg25001938,field7451939):R.ffi.throwNonFunApp(L[248],a_DASH_get_DASH_bang212583.$var,[l7431940,anf_arg25001938,field7451939]);
};
try {
if(--R.GAS > 0) {
$z84078408 = $f84138414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84138414,
"from":L[248]});
}
} catch($e84058406) {
if(R.isCont($e84058406)) {
var $ss84098410 = {"from":L[248],
"go":function(ann_DASH_check_DASH_temp24988415) {
return $Hann_DASH_check_DASH_temp38028416(ann_DASH_check_DASH_temp24988415);
}};
$e84058406.stack[R.EXN_STACKHEIGHT++] = $ss84098410;
}
if(R.isPyretException($e84058406)) {
$e84058406.pyretStack.push(L[248]);
}
throw $e84058406;
}
var $ret84118412 = $Hann_DASH_check_DASH_temp38028416($z84078408);
++R.GAS;
return $ret84118412;
};
var $Hann_DASH_check_DASH_temp38028416 = function(ann_DASH_check_DASH_temp24988415) {
return ann_DASH_check_DASH_temp24988415;
};
var $Hanf_arg38011958 = function(anf_arg24961955,a_DASH_colon210579,field7411956,l7391957) {
var $z84198420 = D;
var $f84258426 = function(_) {
return R.isFunction(a_DASH_colon210579.$var)?a_DASH_colon210579.$var.app(l7391957,anf_arg24961955,field7411956):R.ffi.throwNonFunApp(L[254],a_DASH_colon210579.$var,[l7391957,anf_arg24961955,field7411956]);
};
try {
if(--R.GAS > 0) {
$z84198420 = $f84258426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84258426,
"from":L[254]});
}
} catch($e84178418) {
if(R.isCont($e84178418)) {
var $ss84218422 = {"from":L[254],
"go":function(ann_DASH_check_DASH_temp24948427) {
return $Hann_DASH_check_DASH_temp38008428(ann_DASH_check_DASH_temp24948427);
}};
$e84178418.stack[R.EXN_STACKHEIGHT++] = $ss84218422;
}
if(R.isPyretException($e84178418)) {
$e84178418.pyretStack.push(L[254]);
}
throw $e84178418;
}
var $ret84238424 = $Hann_DASH_check_DASH_temp38008428($z84198420);
++R.GAS;
return $ret84238424;
};
var $Hann_DASH_check_DASH_temp38008428 = function(ann_DASH_check_DASH_temp24948427) {
return ann_DASH_check_DASH_temp24948427;
};
var $Hanf_arg37991975 = function(anf_arg24921972,a_DASH_dot208575,field7371973,l7351974) {
var $z84318432 = D;
var $f84378438 = function(_) {
return R.isFunction(a_DASH_dot208575.$var)?a_DASH_dot208575.$var.app(l7351974,anf_arg24921972,field7371973):R.ffi.throwNonFunApp(L[260],a_DASH_dot208575.$var,[l7351974,anf_arg24921972,field7371973]);
};
try {
if(--R.GAS > 0) {
$z84318432 = $f84378438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84378438,
"from":L[260]});
}
} catch($e84298430) {
if(R.isCont($e84298430)) {
var $ss84338434 = {"from":L[260],
"go":function(ann_DASH_check_DASH_temp24908439) {
return $Hann_DASH_check_DASH_temp37988440(ann_DASH_check_DASH_temp24908439);
}};
$e84298430.stack[R.EXN_STACKHEIGHT++] = $ss84338434;
}
if(R.isPyretException($e84298430)) {
$e84298430.pyretStack.push(L[260]);
}
throw $e84298430;
}
var $ret84358436 = $Hann_DASH_check_DASH_temp37988440($z84318432);
++R.GAS;
return $ret84358436;
};
var $Hann_DASH_check_DASH_temp37988440 = function(ann_DASH_check_DASH_temp24908439) {
return ann_DASH_check_DASH_temp24908439;
};
var $Hanf_arg37971992 = function(anf_arg24831989,a_DASH_extend206571,fields7331990,l7311991,self7301988) {
var anf_fun24848451 = G(fields7331990,"map",L[1282]);
var anf_arg24878452 = R.makeFunction(function(recv_DASH_3048455) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1281],1,arguments);
}
var anf_fun24868466 = G(recv_DASH_3048455,"visit",L[1281]);
var $z84588459 = D;
var $f84648465 = function(_) {
return R.isFunction(anf_fun24868466)?anf_fun24868466.app(self7301988):R.ffi.throwNonFunApp(L[1281],anf_fun24868466,[self7301988]);
};
try {
if(--R.GAS > 0) {
$z84588459 = $f84648465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84648465,
"from":L[1281]});
}
} catch($e84568457) {
if(R.isCont($e84568457)) {
var $ss84608461 = {"from":L[1281],
"go":function(ann_DASH_check_DASH_temp24858467) {
return $Hann_DASH_check_DASH_temp37948468(ann_DASH_check_DASH_temp24858467);
}};
$e84568457.stack[R.EXN_STACKHEIGHT++] = $ss84608461;
}
if(R.isPyretException($e84568457)) {
$e84568457.pyretStack.push(L[1281]);
}
throw $e84568457;
}
var $ret84628463 = $Hann_DASH_check_DASH_temp37948468($z84588459);
++R.GAS;
return $ret84628463;
});
var $z84438444 = D;
var $f84498450 = function(_) {
return R.isFunction(anf_fun24848451)?anf_fun24848451.app(anf_arg24878452):R.ffi.throwNonFunApp(L[1280],anf_fun24848451,[anf_arg24878452]);
};
try {
if(--R.GAS > 0) {
$z84438444 = $f84498450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84498450,
"from":L[1280]});
}
} catch($e84418442) {
if(R.isCont($e84418442)) {
var $ss84458446 = {"from":L[1280],
"go":function(anf_arg24888453) {
return $Hanf_arg37968454(anf_arg24888453,a_DASH_extend206571,anf_arg24831989,l7311991);
}};
$e84418442.stack[R.EXN_STACKHEIGHT++] = $ss84458446;
}
if(R.isPyretException($e84418442)) {
$e84418442.pyretStack.push(L[1280]);
}
throw $e84418442;
}
var $ret84478448 = $Hanf_arg37968454($z84438444,a_DASH_extend206571,anf_arg24831989,l7311991);
++R.GAS;
return $ret84478448;
};
var $Hanf_arg37968454 = function(anf_arg24888453,a_DASH_extend206571,anf_arg24831989,l7311991) {
var $z84718472 = D;
var $f84778478 = function(_) {
return R.isFunction(a_DASH_extend206571.$var)?a_DASH_extend206571.$var.app(l7311991,anf_arg24831989,anf_arg24888453):R.ffi.throwNonFunApp(L[266],a_DASH_extend206571.$var,[l7311991,anf_arg24831989,anf_arg24888453]);
};
try {
if(--R.GAS > 0) {
$z84718472 = $f84778478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84778478,
"from":L[266]});
}
} catch($e84698470) {
if(R.isCont($e84698470)) {
var $ss84738474 = {"from":L[266],
"go":function(ann_DASH_check_DASH_temp24818479) {
return $Hann_DASH_check_DASH_temp37958480(ann_DASH_check_DASH_temp24818479);
}};
$e84698470.stack[R.EXN_STACKHEIGHT++] = $ss84738474;
}
if(R.isPyretException($e84698470)) {
$e84698470.pyretStack.push(L[266]);
}
throw $e84698470;
}
var $ret84758476 = $Hann_DASH_check_DASH_temp37958480($z84718472);
++R.GAS;
return $ret84758476;
};
var $Hann_DASH_check_DASH_temp37958480 = function(ann_DASH_check_DASH_temp24818479) {
return ann_DASH_check_DASH_temp24818479;
};
var $Hann_DASH_check_DASH_temp37948468 = function(ann_DASH_check_DASH_temp24858467) {
return ann_DASH_check_DASH_temp24858467;
};
var $Hanf_arg37932009 = function(anf_arg24742006,a_DASH_update204567,fields7292007,l7272008,self7262005) {
var anf_fun24758491 = G(fields7292007,"map",L[1285]);
var anf_arg24788492 = R.makeFunction(function(recv_DASH_3038495) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1284],1,arguments);
}
var anf_fun24778506 = G(recv_DASH_3038495,"visit",L[1284]);
var $z84988499 = D;
var $f85048505 = function(_) {
return R.isFunction(anf_fun24778506)?anf_fun24778506.app(self7262005):R.ffi.throwNonFunApp(L[1284],anf_fun24778506,[self7262005]);
};
try {
if(--R.GAS > 0) {
$z84988499 = $f85048505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85048505,
"from":L[1284]});
}
} catch($e84968497) {
if(R.isCont($e84968497)) {
var $ss85008501 = {"from":L[1284],
"go":function(ann_DASH_check_DASH_temp24768507) {
return $Hann_DASH_check_DASH_temp37908508(ann_DASH_check_DASH_temp24768507);
}};
$e84968497.stack[R.EXN_STACKHEIGHT++] = $ss85008501;
}
if(R.isPyretException($e84968497)) {
$e84968497.pyretStack.push(L[1284]);
}
throw $e84968497;
}
var $ret85028503 = $Hann_DASH_check_DASH_temp37908508($z84988499);
++R.GAS;
return $ret85028503;
});
var $z84838484 = D;
var $f84898490 = function(_) {
return R.isFunction(anf_fun24758491)?anf_fun24758491.app(anf_arg24788492):R.ffi.throwNonFunApp(L[1283],anf_fun24758491,[anf_arg24788492]);
};
try {
if(--R.GAS > 0) {
$z84838484 = $f84898490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84898490,
"from":L[1283]});
}
} catch($e84818482) {
if(R.isCont($e84818482)) {
var $ss84858486 = {"from":L[1283],
"go":function(anf_arg24798493) {
return $Hanf_arg37928494(anf_arg24798493,a_DASH_update204567,anf_arg24742006,l7272008);
}};
$e84818482.stack[R.EXN_STACKHEIGHT++] = $ss84858486;
}
if(R.isPyretException($e84818482)) {
$e84818482.pyretStack.push(L[1283]);
}
throw $e84818482;
}
var $ret84878488 = $Hanf_arg37928494($z84838484,a_DASH_update204567,anf_arg24742006,l7272008);
++R.GAS;
return $ret84878488;
};
var $Hanf_arg37928494 = function(anf_arg24798493,a_DASH_update204567,anf_arg24742006,l7272008) {
var $z85118512 = D;
var $f85178518 = function(_) {
return R.isFunction(a_DASH_update204567.$var)?a_DASH_update204567.$var.app(l7272008,anf_arg24742006,anf_arg24798493):R.ffi.throwNonFunApp(L[272],a_DASH_update204567.$var,[l7272008,anf_arg24742006,anf_arg24798493]);
};
try {
if(--R.GAS > 0) {
$z85118512 = $f85178518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85178518,
"from":L[272]});
}
} catch($e85098510) {
if(R.isCont($e85098510)) {
var $ss85138514 = {"from":L[272],
"go":function(ann_DASH_check_DASH_temp24728519) {
return $Hann_DASH_check_DASH_temp37918520(ann_DASH_check_DASH_temp24728519);
}};
$e85098510.stack[R.EXN_STACKHEIGHT++] = $ss85138514;
}
if(R.isPyretException($e85098510)) {
$e85098510.pyretStack.push(L[272]);
}
throw $e85098510;
}
var $ret85158516 = $Hann_DASH_check_DASH_temp37918520($z85118512);
++R.GAS;
return $ret85158516;
};
var $Hann_DASH_check_DASH_temp37918520 = function(ann_DASH_check_DASH_temp24728519) {
return ann_DASH_check_DASH_temp24728519;
};
var $Hann_DASH_check_DASH_temp37908508 = function(ann_DASH_check_DASH_temp24768507) {
return ann_DASH_check_DASH_temp24768507;
};
var $Hanf_arg37892025 = function(anf_arg24702023,a_DASH_obj202563,l7242024) {
var $z85238524 = D;
var $f85298530 = function(_) {
return R.isFunction(a_DASH_obj202563.$var)?a_DASH_obj202563.$var.app(l7242024,anf_arg24702023):R.ffi.throwNonFunApp(L[278],a_DASH_obj202563.$var,[l7242024,anf_arg24702023]);
};
try {
if(--R.GAS > 0) {
$z85238524 = $f85298530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85298530,
"from":L[278]});
}
} catch($e85218522) {
if(R.isCont($e85218522)) {
var $ss85258526 = {"from":L[278],
"go":function(ann_DASH_check_DASH_temp24658531) {
return $Hann_DASH_check_DASH_temp37888532(ann_DASH_check_DASH_temp24658531);
}};
$e85218522.stack[R.EXN_STACKHEIGHT++] = $ss85258526;
}
if(R.isPyretException($e85218522)) {
$e85218522.pyretStack.push(L[278]);
}
throw $e85218522;
}
var $ret85278528 = $Hann_DASH_check_DASH_temp37888532($z85238524);
++R.GAS;
return $ret85278528;
};
var $Hann_DASH_check_DASH_temp37888532 = function(ann_DASH_check_DASH_temp24658531) {
return ann_DASH_check_DASH_temp24658531;
};
var $Hann_DASH_check_DASH_temp37872040 = function(ann_DASH_check_DASH_temp24672039) {
return ann_DASH_check_DASH_temp24672039;
};
var $Hanf_arg37862057 = function(anf_arg24632054,a_DASH_prim_DASH_app200559,f7212055,l7202056) {
var $z85358536 = D;
var $f85418542 = function(_) {
return R.isFunction(a_DASH_prim_DASH_app200559.$var)?a_DASH_prim_DASH_app200559.$var.app(l7202056,f7212055,anf_arg24632054):R.ffi.throwNonFunApp(L[285],a_DASH_prim_DASH_app200559.$var,[l7202056,f7212055,anf_arg24632054]);
};
try {
if(--R.GAS > 0) {
$z85358536 = $f85418542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85418542,
"from":L[285]});
}
} catch($e85338534) {
if(R.isCont($e85338534)) {
var $ss85378538 = {"from":L[285],
"go":function(ann_DASH_check_DASH_temp24588543) {
return $Hann_DASH_check_DASH_temp37858544(ann_DASH_check_DASH_temp24588543);
}};
$e85338534.stack[R.EXN_STACKHEIGHT++] = $ss85378538;
}
if(R.isPyretException($e85338534)) {
$e85338534.pyretStack.push(L[285]);
}
throw $e85338534;
}
var $ret85398540 = $Hann_DASH_check_DASH_temp37858544($z85358536);
++R.GAS;
return $ret85398540;
};
var $Hann_DASH_check_DASH_temp37858544 = function(ann_DASH_check_DASH_temp24588543) {
return ann_DASH_check_DASH_temp24588543;
};
var $Hann_DASH_check_DASH_temp37842072 = function(ann_DASH_check_DASH_temp24602071) {
return ann_DASH_check_DASH_temp24602071;
};
var $Hanf_arg37832089 = function(anf_arg24512086,a_DASH_app198555,args7182087,l7162088,self7152085) {
var anf_fun24528555 = G(args7182087,"map",L[1288]);
var anf_arg24558556 = R.makeFunction(function(recv_DASH_3008559) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1287],1,arguments);
}
var anf_fun24548570 = G(recv_DASH_3008559,"visit",L[1287]);
var $z85628563 = D;
var $f85688569 = function(_) {
return R.isFunction(anf_fun24548570)?anf_fun24548570.app(self7152085):R.ffi.throwNonFunApp(L[1287],anf_fun24548570,[self7152085]);
};
try {
if(--R.GAS > 0) {
$z85628563 = $f85688569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85688569,
"from":L[1287]});
}
} catch($e85608561) {
if(R.isCont($e85608561)) {
var $ss85648565 = {"from":L[1287],
"go":function(ann_DASH_check_DASH_temp24538571) {
return $Hann_DASH_check_DASH_temp37808572(ann_DASH_check_DASH_temp24538571);
}};
$e85608561.stack[R.EXN_STACKHEIGHT++] = $ss85648565;
}
if(R.isPyretException($e85608561)) {
$e85608561.pyretStack.push(L[1287]);
}
throw $e85608561;
}
var $ret85668567 = $Hann_DASH_check_DASH_temp37808572($z85628563);
++R.GAS;
return $ret85668567;
});
var $z85478548 = D;
var $f85538554 = function(_) {
return R.isFunction(anf_fun24528555)?anf_fun24528555.app(anf_arg24558556):R.ffi.throwNonFunApp(L[1286],anf_fun24528555,[anf_arg24558556]);
};
try {
if(--R.GAS > 0) {
$z85478548 = $f85538554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85538554,
"from":L[1286]});
}
} catch($e85458546) {
if(R.isCont($e85458546)) {
var $ss85498550 = {"from":L[1286],
"go":function(anf_arg24568557) {
return $Hanf_arg37828558(anf_arg24568557,a_DASH_app198555,anf_arg24512086,l7162088);
}};
$e85458546.stack[R.EXN_STACKHEIGHT++] = $ss85498550;
}
if(R.isPyretException($e85458546)) {
$e85458546.pyretStack.push(L[1286]);
}
throw $e85458546;
}
var $ret85518552 = $Hanf_arg37828558($z85478548,a_DASH_app198555,anf_arg24512086,l7162088);
++R.GAS;
return $ret85518552;
};
var $Hanf_arg37828558 = function(anf_arg24568557,a_DASH_app198555,anf_arg24512086,l7162088) {
var $z85758576 = D;
var $f85818582 = function(_) {
return R.isFunction(a_DASH_app198555.$var)?a_DASH_app198555.$var.app(l7162088,anf_arg24512086,anf_arg24568557):R.ffi.throwNonFunApp(L[291],a_DASH_app198555.$var,[l7162088,anf_arg24512086,anf_arg24568557]);
};
try {
if(--R.GAS > 0) {
$z85758576 = $f85818582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85818582,
"from":L[291]});
}
} catch($e85738574) {
if(R.isCont($e85738574)) {
var $ss85778578 = {"from":L[291],
"go":function(ann_DASH_check_DASH_temp24498583) {
return $Hann_DASH_check_DASH_temp37818584(ann_DASH_check_DASH_temp24498583);
}};
$e85738574.stack[R.EXN_STACKHEIGHT++] = $ss85778578;
}
if(R.isPyretException($e85738574)) {
$e85738574.pyretStack.push(L[291]);
}
throw $e85738574;
}
var $ret85798580 = $Hann_DASH_check_DASH_temp37818584($z85758576);
++R.GAS;
return $ret85798580;
};
var $Hann_DASH_check_DASH_temp37818584 = function(ann_DASH_check_DASH_temp24498583) {
return ann_DASH_check_DASH_temp24498583;
};
var $Hann_DASH_check_DASH_temp37808572 = function(ann_DASH_check_DASH_temp24538571) {
return ann_DASH_check_DASH_temp24538571;
};
var $Hanf_arg37792106 = function(anf_arg24472103,a_DASH_assign196551,id7132104,l7122105) {
var $z85878588 = D;
var $f85938594 = function(_) {
return R.isFunction(a_DASH_assign196551.$var)?a_DASH_assign196551.$var.app(l7122105,id7132104,anf_arg24472103):R.ffi.throwNonFunApp(L[297],a_DASH_assign196551.$var,[l7122105,id7132104,anf_arg24472103]);
};
try {
if(--R.GAS > 0) {
$z85878588 = $f85938594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85938594,
"from":L[297]});
}
} catch($e85858586) {
if(R.isCont($e85858586)) {
var $ss85898590 = {"from":L[297],
"go":function(ann_DASH_check_DASH_temp24458595) {
return $Hann_DASH_check_DASH_temp37788596(ann_DASH_check_DASH_temp24458595);
}};
$e85858586.stack[R.EXN_STACKHEIGHT++] = $ss85898590;
}
if(R.isPyretException($e85858586)) {
$e85858586.pyretStack.push(L[297]);
}
throw $e85858586;
}
var $ret85918592 = $Hann_DASH_check_DASH_temp37788596($z85878588);
++R.GAS;
return $ret85918592;
};
var $Hann_DASH_check_DASH_temp37788596 = function(ann_DASH_check_DASH_temp24458595) {
return ann_DASH_check_DASH_temp24458595;
};
var $Hanf_arg37772121 = function(anf_arg24432120,a_DASH_lettable161481) {
var $z85998600 = D;
var $f86058606 = function(_) {
return R.isFunction(a_DASH_lettable161481.$var)?a_DASH_lettable161481.$var.app(anf_arg24432120):R.ffi.throwNonFunApp(L[301],a_DASH_lettable161481.$var,[anf_arg24432120]);
};
try {
if(--R.GAS > 0) {
$z85998600 = $f86058606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86058606,
"from":L[301]});
}
} catch($e85978598) {
if(R.isCont($e85978598)) {
var $ss86018602 = {"from":L[301],
"go":function(ann_DASH_check_DASH_temp24418607) {
return $Hann_DASH_check_DASH_temp37768608(ann_DASH_check_DASH_temp24418607);
}};
$e85978598.stack[R.EXN_STACKHEIGHT++] = $ss86018602;
}
if(R.isPyretException($e85978598)) {
$e85978598.pyretStack.push(L[301]);
}
throw $e85978598;
}
var $ret86038604 = $Hann_DASH_check_DASH_temp37768608($z85998600);
++R.GAS;
return $ret86038604;
};
var $Hann_DASH_check_DASH_temp37768608 = function(ann_DASH_check_DASH_temp24418607) {
return ann_DASH_check_DASH_temp24418607;
};
var $Hanf_arg37752139 = function(anf_arg24352135,a_DASH_if159477,e7082136,l7052137,self7042134,t7072138) {
var anf_fun24368619 = G(t7072138,"visit",L[1290]);
var $z86118612 = D;
var $f86178618 = function(_) {
return R.isFunction(anf_fun24368619)?anf_fun24368619.app(self7042134):R.ffi.throwNonFunApp(L[1289],anf_fun24368619,[self7042134]);
};
try {
if(--R.GAS > 0) {
$z86118612 = $f86178618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86178618,
"from":L[1289]});
}
} catch($e86098610) {
if(R.isCont($e86098610)) {
var $ss86138614 = {"from":L[1289],
"go":function(anf_arg24378620) {
return $Hanf_arg37748621(anf_arg24378620,a_DASH_if159477,anf_arg24352135,e7082136,l7052137,self7042134);
}};
$e86098610.stack[R.EXN_STACKHEIGHT++] = $ss86138614;
}
if(R.isPyretException($e86098610)) {
$e86098610.pyretStack.push(L[1289]);
}
throw $e86098610;
}
var $ret86158616 = $Hanf_arg37748621($z86118612,a_DASH_if159477,anf_arg24352135,e7082136,l7052137,self7042134);
++R.GAS;
return $ret86158616;
};
var $Hanf_arg37748621 = function(anf_arg24378620,a_DASH_if159477,anf_arg24352135,e7082136,l7052137,self7042134) {
var anf_fun24388632 = G(e7082136,"visit",L[1292]);
var $z86248625 = D;
var $f86308631 = function(_) {
return R.isFunction(anf_fun24388632)?anf_fun24388632.app(self7042134):R.ffi.throwNonFunApp(L[1291],anf_fun24388632,[self7042134]);
};
try {
if(--R.GAS > 0) {
$z86248625 = $f86308631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86308631,
"from":L[1291]});
}
} catch($e86228623) {
if(R.isCont($e86228623)) {
var $ss86268627 = {"from":L[1291],
"go":function(anf_arg24398633) {
return $Hanf_arg37738634(anf_arg24398633,a_DASH_if159477,anf_arg24352135,anf_arg24378620,l7052137);
}};
$e86228623.stack[R.EXN_STACKHEIGHT++] = $ss86268627;
}
if(R.isPyretException($e86228623)) {
$e86228623.pyretStack.push(L[1291]);
}
throw $e86228623;
}
var $ret86288629 = $Hanf_arg37738634($z86248625,a_DASH_if159477,anf_arg24352135,anf_arg24378620,l7052137);
++R.GAS;
return $ret86288629;
};
var $Hanf_arg37738634 = function(anf_arg24398633,a_DASH_if159477,anf_arg24352135,anf_arg24378620,l7052137) {
var $z86378638 = D;
var $f86438644 = function(_) {
return R.isFunction(a_DASH_if159477.$var)?a_DASH_if159477.$var.app(l7052137,anf_arg24352135,anf_arg24378620,anf_arg24398633):R.ffi.throwNonFunApp(L[308],a_DASH_if159477.$var,[l7052137,anf_arg24352135,anf_arg24378620,anf_arg24398633]);
};
try {
if(--R.GAS > 0) {
$z86378638 = $f86438644();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86438644,
"from":L[308]});
}
} catch($e86358636) {
if(R.isCont($e86358636)) {
var $ss86398640 = {"from":L[308],
"go":function(ann_DASH_check_DASH_temp24338645) {
return $Hann_DASH_check_DASH_temp37728646(ann_DASH_check_DASH_temp24338645);
}};
$e86358636.stack[R.EXN_STACKHEIGHT++] = $ss86398640;
}
if(R.isPyretException($e86358636)) {
$e86358636.pyretStack.push(L[308]);
}
throw $e86358636;
}
var $ret86418642 = $Hann_DASH_check_DASH_temp37728646($z86378638);
++R.GAS;
return $ret86418642;
};
var $Hann_DASH_check_DASH_temp37728646 = function(ann_DASH_check_DASH_temp24338645) {
return ann_DASH_check_DASH_temp24338645;
};
var $Hanf_arg37712159 = function(anf_arg24212153,a_DASH_split_DASH_app157473,args7012154,helper_DASH_args7032155,helper7022156,is_DASH_var6992157,l6982158,self6972152) {
var anf_fun24228657 = G(args7012154,"map",L[1295]);
var anf_arg24258658 = R.makeFunction(function(recv_DASH_2988661) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1294],1,arguments);
}
var anf_fun24248672 = G(recv_DASH_2988661,"visit",L[1294]);
var $z86648665 = D;
var $f86708671 = function(_) {
return R.isFunction(anf_fun24248672)?anf_fun24248672.app(self6972152):R.ffi.throwNonFunApp(L[1294],anf_fun24248672,[self6972152]);
};
try {
if(--R.GAS > 0) {
$z86648665 = $f86708671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86708671,
"from":L[1294]});
}
} catch($e86628663) {
if(R.isCont($e86628663)) {
var $ss86668667 = {"from":L[1294],
"go":function(ann_DASH_check_DASH_temp24238673) {
return $Hann_DASH_check_DASH_temp37668674(ann_DASH_check_DASH_temp24238673);
}};
$e86628663.stack[R.EXN_STACKHEIGHT++] = $ss86668667;
}
if(R.isPyretException($e86628663)) {
$e86628663.pyretStack.push(L[1294]);
}
throw $e86628663;
}
var $ret86688669 = $Hann_DASH_check_DASH_temp37668674($z86648665);
++R.GAS;
return $ret86688669;
});
var $z86498650 = D;
var $f86558656 = function(_) {
return R.isFunction(anf_fun24228657)?anf_fun24228657.app(anf_arg24258658):R.ffi.throwNonFunApp(L[1293],anf_fun24228657,[anf_arg24258658]);
};
try {
if(--R.GAS > 0) {
$z86498650 = $f86558656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86558656,
"from":L[1293]});
}
} catch($e86478648) {
if(R.isCont($e86478648)) {
var $ss86518652 = {"from":L[1293],
"go":function(anf_arg24268659) {
return $Hanf_arg37708660(anf_arg24268659,a_DASH_split_DASH_app157473,anf_arg24212153,helper_DASH_args7032155,helper7022156,is_DASH_var6992157,l6982158,self6972152);
}};
$e86478648.stack[R.EXN_STACKHEIGHT++] = $ss86518652;
}
if(R.isPyretException($e86478648)) {
$e86478648.pyretStack.push(L[1293]);
}
throw $e86478648;
}
var $ret86538654 = $Hanf_arg37708660($z86498650,a_DASH_split_DASH_app157473,anf_arg24212153,helper_DASH_args7032155,helper7022156,is_DASH_var6992157,l6982158,self6972152);
++R.GAS;
return $ret86538654;
};
var $Hanf_arg37708660 = function(anf_arg24268659,a_DASH_split_DASH_app157473,anf_arg24212153,helper_DASH_args7032155,helper7022156,is_DASH_var6992157,l6982158,self6972152) {
var anf_fun24278685 = G(helper_DASH_args7032155,"map",L[1298]);
var anf_arg24308686 = R.makeFunction(function(recv_DASH_2998689) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1297],1,arguments);
}
var anf_fun24298700 = G(recv_DASH_2998689,"visit",L[1297]);
var $z86928693 = D;
var $f86988699 = function(_) {
return R.isFunction(anf_fun24298700)?anf_fun24298700.app(self6972152):R.ffi.throwNonFunApp(L[1297],anf_fun24298700,[self6972152]);
};
try {
if(--R.GAS > 0) {
$z86928693 = $f86988699();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86988699,
"from":L[1297]});
}
} catch($e86908691) {
if(R.isCont($e86908691)) {
var $ss86948695 = {"from":L[1297],
"go":function(ann_DASH_check_DASH_temp24288701) {
return $Hann_DASH_check_DASH_temp37678702(ann_DASH_check_DASH_temp24288701);
}};
$e86908691.stack[R.EXN_STACKHEIGHT++] = $ss86948695;
}
if(R.isPyretException($e86908691)) {
$e86908691.pyretStack.push(L[1297]);
}
throw $e86908691;
}
var $ret86968697 = $Hann_DASH_check_DASH_temp37678702($z86928693);
++R.GAS;
return $ret86968697;
});
var $z86778678 = D;
var $f86838684 = function(_) {
return R.isFunction(anf_fun24278685)?anf_fun24278685.app(anf_arg24308686):R.ffi.throwNonFunApp(L[1296],anf_fun24278685,[anf_arg24308686]);
};
try {
if(--R.GAS > 0) {
$z86778678 = $f86838684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86838684,
"from":L[1296]});
}
} catch($e86758676) {
if(R.isCont($e86758676)) {
var $ss86798680 = {"from":L[1296],
"go":function(anf_arg24318687) {
return $Hanf_arg37698688(anf_arg24318687,a_DASH_split_DASH_app157473,anf_arg24212153,anf_arg24268659,helper7022156,is_DASH_var6992157,l6982158);
}};
$e86758676.stack[R.EXN_STACKHEIGHT++] = $ss86798680;
}
if(R.isPyretException($e86758676)) {
$e86758676.pyretStack.push(L[1296]);
}
throw $e86758676;
}
var $ret86818682 = $Hanf_arg37698688($z86778678,a_DASH_split_DASH_app157473,anf_arg24212153,anf_arg24268659,helper7022156,is_DASH_var6992157,l6982158);
++R.GAS;
return $ret86818682;
};
var $Hanf_arg37698688 = function(anf_arg24318687,a_DASH_split_DASH_app157473,anf_arg24212153,anf_arg24268659,helper7022156,is_DASH_var6992157,l6982158) {
var $z87058706 = D;
var $f87118712 = function(_) {
return R.isFunction(a_DASH_split_DASH_app157473.$var)?a_DASH_split_DASH_app157473.$var.app(l6982158,is_DASH_var6992157,anf_arg24212153,anf_arg24268659,helper7022156,anf_arg24318687):R.ffi.throwNonFunApp(L[317],a_DASH_split_DASH_app157473.$var,[l6982158,is_DASH_var6992157,anf_arg24212153,anf_arg24268659,helper7022156,anf_arg24318687]);
};
try {
if(--R.GAS > 0) {
$z87058706 = $f87118712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87118712,
"from":L[317]});
}
} catch($e87038704) {
if(R.isCont($e87038704)) {
var $ss87078708 = {"from":L[317],
"go":function(ann_DASH_check_DASH_temp24198713) {
return $Hann_DASH_check_DASH_temp37688714(ann_DASH_check_DASH_temp24198713);
}};
$e87038704.stack[R.EXN_STACKHEIGHT++] = $ss87078708;
}
if(R.isPyretException($e87038704)) {
$e87038704.pyretStack.push(L[317]);
}
throw $e87038704;
}
var $ret87098710 = $Hann_DASH_check_DASH_temp37688714($z87058706);
++R.GAS;
return $ret87098710;
};
var $Hann_DASH_check_DASH_temp37688714 = function(ann_DASH_check_DASH_temp24198713) {
return ann_DASH_check_DASH_temp24198713;
};
var $Hann_DASH_check_DASH_temp37678702 = function(ann_DASH_check_DASH_temp24288701) {
return ann_DASH_check_DASH_temp24288701;
};
var $Hann_DASH_check_DASH_temp37668674 = function(ann_DASH_check_DASH_temp24238673) {
return ann_DASH_check_DASH_temp24238673;
};
var $Hanf_arg37652176 = function(anf_arg24122173,a_DASH_tail_DASH_app155469,args6962174,l6942175,self6932172) {
var anf_fun24138725 = G(args6962174,"map",L[1301]);
var anf_arg24168726 = R.makeFunction(function(recv_DASH_2978729) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1300],1,arguments);
}
var anf_fun24158740 = G(recv_DASH_2978729,"visit",L[1300]);
var $z87328733 = D;
var $f87388739 = function(_) {
return R.isFunction(anf_fun24158740)?anf_fun24158740.app(self6932172):R.ffi.throwNonFunApp(L[1300],anf_fun24158740,[self6932172]);
};
try {
if(--R.GAS > 0) {
$z87328733 = $f87388739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87388739,
"from":L[1300]});
}
} catch($e87308731) {
if(R.isCont($e87308731)) {
var $ss87348735 = {"from":L[1300],
"go":function(ann_DASH_check_DASH_temp24148741) {
return $Hann_DASH_check_DASH_temp37628742(ann_DASH_check_DASH_temp24148741);
}};
$e87308731.stack[R.EXN_STACKHEIGHT++] = $ss87348735;
}
if(R.isPyretException($e87308731)) {
$e87308731.pyretStack.push(L[1300]);
}
throw $e87308731;
}
var $ret87368737 = $Hann_DASH_check_DASH_temp37628742($z87328733);
++R.GAS;
return $ret87368737;
});
var $z87178718 = D;
var $f87238724 = function(_) {
return R.isFunction(anf_fun24138725)?anf_fun24138725.app(anf_arg24168726):R.ffi.throwNonFunApp(L[1299],anf_fun24138725,[anf_arg24168726]);
};
try {
if(--R.GAS > 0) {
$z87178718 = $f87238724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87238724,
"from":L[1299]});
}
} catch($e87158716) {
if(R.isCont($e87158716)) {
var $ss87198720 = {"from":L[1299],
"go":function(anf_arg24178727) {
return $Hanf_arg37648728(anf_arg24178727,a_DASH_tail_DASH_app155469,anf_arg24122173,l6942175);
}};
$e87158716.stack[R.EXN_STACKHEIGHT++] = $ss87198720;
}
if(R.isPyretException($e87158716)) {
$e87158716.pyretStack.push(L[1299]);
}
throw $e87158716;
}
var $ret87218722 = $Hanf_arg37648728($z87178718,a_DASH_tail_DASH_app155469,anf_arg24122173,l6942175);
++R.GAS;
return $ret87218722;
};
var $Hanf_arg37648728 = function(anf_arg24178727,a_DASH_tail_DASH_app155469,anf_arg24122173,l6942175) {
var $z87458746 = D;
var $f87518752 = function(_) {
return R.isFunction(a_DASH_tail_DASH_app155469.$var)?a_DASH_tail_DASH_app155469.$var.app(l6942175,anf_arg24122173,anf_arg24178727):R.ffi.throwNonFunApp(L[323],a_DASH_tail_DASH_app155469.$var,[l6942175,anf_arg24122173,anf_arg24178727]);
};
try {
if(--R.GAS > 0) {
$z87458746 = $f87518752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87518752,
"from":L[323]});
}
} catch($e87438744) {
if(R.isCont($e87438744)) {
var $ss87478748 = {"from":L[323],
"go":function(ann_DASH_check_DASH_temp24108753) {
return $Hann_DASH_check_DASH_temp37638754(ann_DASH_check_DASH_temp24108753);
}};
$e87438744.stack[R.EXN_STACKHEIGHT++] = $ss87478748;
}
if(R.isPyretException($e87438744)) {
$e87438744.pyretStack.push(L[323]);
}
throw $e87438744;
}
var $ret87498750 = $Hann_DASH_check_DASH_temp37638754($z87458746);
++R.GAS;
return $ret87498750;
};
var $Hann_DASH_check_DASH_temp37638754 = function(ann_DASH_check_DASH_temp24108753) {
return ann_DASH_check_DASH_temp24108753;
};
var $Hann_DASH_check_DASH_temp37628742 = function(ann_DASH_check_DASH_temp24148741) {
return ann_DASH_check_DASH_temp24148741;
};
var $Hanf_arg37612193 = function(anf_arg24082190,a_DASH_variant_DASH_member187533,l6902191,member_DASH_type6912192) {
var $z87578758 = D;
var $f87638764 = function(_) {
return R.isFunction(a_DASH_variant_DASH_member187533.$var)?a_DASH_variant_DASH_member187533.$var.app(l6902191,member_DASH_type6912192,anf_arg24082190):R.ffi.throwNonFunApp(L[329],a_DASH_variant_DASH_member187533.$var,[l6902191,member_DASH_type6912192,anf_arg24082190]);
};
try {
if(--R.GAS > 0) {
$z87578758 = $f87638764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87638764,
"from":L[329]});
}
} catch($e87558756) {
if(R.isCont($e87558756)) {
var $ss87598760 = {"from":L[329],
"go":function(ann_DASH_check_DASH_temp24068765) {
return $Hann_DASH_check_DASH_temp37608766(ann_DASH_check_DASH_temp24068765);
}};
$e87558756.stack[R.EXN_STACKHEIGHT++] = $ss87598760;
}
if(R.isPyretException($e87558756)) {
$e87558756.pyretStack.push(L[329]);
}
throw $e87558756;
}
var $ret87618762 = $Hann_DASH_check_DASH_temp37608766($z87578758);
++R.GAS;
return $ret87618762;
};
var $Hann_DASH_check_DASH_temp37608766 = function(ann_DASH_check_DASH_temp24068765) {
return ann_DASH_check_DASH_temp24068765;
};
var $Hanf_arg37592210 = function(anf_arg24042207,a_DASH_singleton_DASH_variant173505,l6862208,name6872209) {
var $z87698770 = D;
var $f87758776 = function(_) {
return R.isFunction(a_DASH_singleton_DASH_variant173505.$var)?a_DASH_singleton_DASH_variant173505.$var.app(l6862208,name6872209,anf_arg24042207):R.ffi.throwNonFunApp(L[336],a_DASH_singleton_DASH_variant173505.$var,[l6862208,name6872209,anf_arg24042207]);
};
try {
if(--R.GAS > 0) {
$z87698770 = $f87758776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87758776,
"from":L[336]});
}
} catch($e87678768) {
if(R.isCont($e87678768)) {
var $ss87718772 = {"from":L[336],
"go":function(ann_DASH_check_DASH_temp23998777) {
return $Hann_DASH_check_DASH_temp37588778(ann_DASH_check_DASH_temp23998777);
}};
$e87678768.stack[R.EXN_STACKHEIGHT++] = $ss87718772;
}
if(R.isPyretException($e87678768)) {
$e87678768.pyretStack.push(L[336]);
}
throw $e87678768;
}
var $ret87738774 = $Hann_DASH_check_DASH_temp37588778($z87698770);
++R.GAS;
return $ret87738774;
};
var $Hann_DASH_check_DASH_temp37588778 = function(ann_DASH_check_DASH_temp23998777) {
return ann_DASH_check_DASH_temp23998777;
};
var $Hann_DASH_check_DASH_temp37572225 = function(ann_DASH_check_DASH_temp24012224) {
return ann_DASH_check_DASH_temp24012224;
};
var $Hanf_arg37562245 = function(anf_arg23922239,a_DASH_variant171501,constr_DASH_loc6812240,l6802241,name6822242,self6792243,with_DASH_members6842244) {
var anf_fun23938789 = G(with_DASH_members6842244,"map",L[1304]);
var anf_arg23968790 = R.makeFunction(function(recv_DASH_2958793) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1303],1,arguments);
}
var anf_fun23958804 = G(recv_DASH_2958793,"visit",L[1303]);
var $z87968797 = D;
var $f88028803 = function(_) {
return R.isFunction(anf_fun23958804)?anf_fun23958804.app(self6792243):R.ffi.throwNonFunApp(L[1303],anf_fun23958804,[self6792243]);
};
try {
if(--R.GAS > 0) {
$z87968797 = $f88028803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88028803,
"from":L[1303]});
}
} catch($e87948795) {
if(R.isCont($e87948795)) {
var $ss87988799 = {"from":L[1303],
"go":function(ann_DASH_check_DASH_temp23948805) {
return $Hann_DASH_check_DASH_temp37538806(ann_DASH_check_DASH_temp23948805);
}};
$e87948795.stack[R.EXN_STACKHEIGHT++] = $ss87988799;
}
if(R.isPyretException($e87948795)) {
$e87948795.pyretStack.push(L[1303]);
}
throw $e87948795;
}
var $ret88008801 = $Hann_DASH_check_DASH_temp37538806($z87968797);
++R.GAS;
return $ret88008801;
});
var $z87818782 = D;
var $f87878788 = function(_) {
return R.isFunction(anf_fun23938789)?anf_fun23938789.app(anf_arg23968790):R.ffi.throwNonFunApp(L[1302],anf_fun23938789,[anf_arg23968790]);
};
try {
if(--R.GAS > 0) {
$z87818782 = $f87878788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87878788,
"from":L[1302]});
}
} catch($e87798780) {
if(R.isCont($e87798780)) {
var $ss87838784 = {"from":L[1302],
"go":function(anf_arg23978791) {
return $Hanf_arg37558792(anf_arg23978791,a_DASH_variant171501,anf_arg23922239,constr_DASH_loc6812240,l6802241,name6822242);
}};
$e87798780.stack[R.EXN_STACKHEIGHT++] = $ss87838784;
}
if(R.isPyretException($e87798780)) {
$e87798780.pyretStack.push(L[1302]);
}
throw $e87798780;
}
var $ret87858786 = $Hanf_arg37558792($z87818782,a_DASH_variant171501,anf_arg23922239,constr_DASH_loc6812240,l6802241,name6822242);
++R.GAS;
return $ret87858786;
};
var $Hanf_arg37558792 = function(anf_arg23978791,a_DASH_variant171501,anf_arg23922239,constr_DASH_loc6812240,l6802241,name6822242) {
var $z88098810 = D;
var $f88158816 = function(_) {
return R.isFunction(a_DASH_variant171501.$var)?a_DASH_variant171501.$var.app(l6802241,constr_DASH_loc6812240,name6822242,anf_arg23922239,anf_arg23978791):R.ffi.throwNonFunApp(L[345],a_DASH_variant171501.$var,[l6802241,constr_DASH_loc6812240,name6822242,anf_arg23922239,anf_arg23978791]);
};
try {
if(--R.GAS > 0) {
$z88098810 = $f88158816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88158816,
"from":L[345]});
}
} catch($e88078808) {
if(R.isCont($e88078808)) {
var $ss88118812 = {"from":L[345],
"go":function(ann_DASH_check_DASH_temp23878817) {
return $Hann_DASH_check_DASH_temp37548818(ann_DASH_check_DASH_temp23878817);
}};
$e88078808.stack[R.EXN_STACKHEIGHT++] = $ss88118812;
}
if(R.isPyretException($e88078808)) {
$e88078808.pyretStack.push(L[345]);
}
throw $e88078808;
}
var $ret88138814 = $Hann_DASH_check_DASH_temp37548818($z88098810);
++R.GAS;
return $ret88138814;
};
var $Hann_DASH_check_DASH_temp37548818 = function(ann_DASH_check_DASH_temp23878817) {
return ann_DASH_check_DASH_temp23878817;
};
var $Hann_DASH_check_DASH_temp37538806 = function(ann_DASH_check_DASH_temp23948805) {
return ann_DASH_check_DASH_temp23948805;
};
var $Hann_DASH_check_DASH_temp37522259 = function(ann_DASH_check_DASH_temp23892258) {
return ann_DASH_check_DASH_temp23892258;
};
var $Hanf_arg37512279 = function(anf_arg23802273,a_DASH_data_DASH_expr194547,l6742274,name6752275,namet6762276,self6732277,shared6782278) {
var anf_fun23818829 = G(shared6782278,"map",L[1307]);
var anf_arg23848830 = R.makeFunction(function(recv_DASH_2938833) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1306],1,arguments);
}
var anf_fun23838844 = G(recv_DASH_2938833,"visit",L[1306]);
var $z88368837 = D;
var $f88428843 = function(_) {
return R.isFunction(anf_fun23838844)?anf_fun23838844.app(self6732277):R.ffi.throwNonFunApp(L[1306],anf_fun23838844,[self6732277]);
};
try {
if(--R.GAS > 0) {
$z88368837 = $f88428843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88428843,
"from":L[1306]});
}
} catch($e88348835) {
if(R.isCont($e88348835)) {
var $ss88388839 = {"from":L[1306],
"go":function(ann_DASH_check_DASH_temp23828845) {
return $Hann_DASH_check_DASH_temp37488846(ann_DASH_check_DASH_temp23828845);
}};
$e88348835.stack[R.EXN_STACKHEIGHT++] = $ss88388839;
}
if(R.isPyretException($e88348835)) {
$e88348835.pyretStack.push(L[1306]);
}
throw $e88348835;
}
var $ret88408841 = $Hann_DASH_check_DASH_temp37488846($z88368837);
++R.GAS;
return $ret88408841;
});
var $z88218822 = D;
var $f88278828 = function(_) {
return R.isFunction(anf_fun23818829)?anf_fun23818829.app(anf_arg23848830):R.ffi.throwNonFunApp(L[1305],anf_fun23818829,[anf_arg23848830]);
};
try {
if(--R.GAS > 0) {
$z88218822 = $f88278828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88278828,
"from":L[1305]});
}
} catch($e88198820) {
if(R.isCont($e88198820)) {
var $ss88238824 = {"from":L[1305],
"go":function(anf_arg23858831) {
return $Hanf_arg37508832(anf_arg23858831,a_DASH_data_DASH_expr194547,anf_arg23802273,l6742274,name6752275,namet6762276);
}};
$e88198820.stack[R.EXN_STACKHEIGHT++] = $ss88238824;
}
if(R.isPyretException($e88198820)) {
$e88198820.pyretStack.push(L[1305]);
}
throw $e88198820;
}
var $ret88258826 = $Hanf_arg37508832($z88218822,a_DASH_data_DASH_expr194547,anf_arg23802273,l6742274,name6752275,namet6762276);
++R.GAS;
return $ret88258826;
};
var $Hanf_arg37508832 = function(anf_arg23858831,a_DASH_data_DASH_expr194547,anf_arg23802273,l6742274,name6752275,namet6762276) {
var $z88498850 = D;
var $f88558856 = function(_) {
return R.isFunction(a_DASH_data_DASH_expr194547.$var)?a_DASH_data_DASH_expr194547.$var.app(l6742274,name6752275,namet6762276,anf_arg23802273,anf_arg23858831):R.ffi.throwNonFunApp(L[354],a_DASH_data_DASH_expr194547.$var,[l6742274,name6752275,namet6762276,anf_arg23802273,anf_arg23858831]);
};
try {
if(--R.GAS > 0) {
$z88498850 = $f88558856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88558856,
"from":L[354]});
}
} catch($e88478848) {
if(R.isCont($e88478848)) {
var $ss88518852 = {"from":L[354],
"go":function(ann_DASH_check_DASH_temp23758857) {
return $Hann_DASH_check_DASH_temp37498858(ann_DASH_check_DASH_temp23758857);
}};
$e88478848.stack[R.EXN_STACKHEIGHT++] = $ss88518852;
}
if(R.isPyretException($e88478848)) {
$e88478848.pyretStack.push(L[354]);
}
throw $e88478848;
}
var $ret88538854 = $Hann_DASH_check_DASH_temp37498858($z88498850);
++R.GAS;
return $ret88538854;
};
var $Hann_DASH_check_DASH_temp37498858 = function(ann_DASH_check_DASH_temp23758857) {
return ann_DASH_check_DASH_temp23758857;
};
var $Hann_DASH_check_DASH_temp37488846 = function(ann_DASH_check_DASH_temp23828845) {
return ann_DASH_check_DASH_temp23828845;
};
var $Hann_DASH_check_DASH_temp37472293 = function(ann_DASH_check_DASH_temp23772292) {
return ann_DASH_check_DASH_temp23772292;
};
var $Hanf_arg37462310 = function(anf_arg23712307,a_DASH_seq153465,e26722308,l6702309,self6692306) {
var anf_fun23728869 = G(e26722308,"visit",L[1309]);
var $z88618862 = D;
var $f88678868 = function(_) {
return R.isFunction(anf_fun23728869)?anf_fun23728869.app(self6692306):R.ffi.throwNonFunApp(L[1308],anf_fun23728869,[self6692306]);
};
try {
if(--R.GAS > 0) {
$z88618862 = $f88678868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88678868,
"from":L[1308]});
}
} catch($e88598860) {
if(R.isCont($e88598860)) {
var $ss88638864 = {"from":L[1308],
"go":function(anf_arg23738870) {
return $Hanf_arg37458871(anf_arg23738870,a_DASH_seq153465,anf_arg23712307,l6702309);
}};
$e88598860.stack[R.EXN_STACKHEIGHT++] = $ss88638864;
}
if(R.isPyretException($e88598860)) {
$e88598860.pyretStack.push(L[1308]);
}
throw $e88598860;
}
var $ret88658866 = $Hanf_arg37458871($z88618862,a_DASH_seq153465,anf_arg23712307,l6702309);
++R.GAS;
return $ret88658866;
};
var $Hanf_arg37458871 = function(anf_arg23738870,a_DASH_seq153465,anf_arg23712307,l6702309) {
var $z88748875 = D;
var $f88808881 = function(_) {
return R.isFunction(a_DASH_seq153465.$var)?a_DASH_seq153465.$var.app(l6702309,anf_arg23712307,anf_arg23738870):R.ffi.throwNonFunApp(L[360],a_DASH_seq153465.$var,[l6702309,anf_arg23712307,anf_arg23738870]);
};
try {
if(--R.GAS > 0) {
$z88748875 = $f88808881();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88808881,
"from":L[360]});
}
} catch($e88728873) {
if(R.isCont($e88728873)) {
var $ss88768877 = {"from":L[360],
"go":function(ann_DASH_check_DASH_temp23698882) {
return $Hann_DASH_check_DASH_temp37448883(ann_DASH_check_DASH_temp23698882);
}};
$e88728873.stack[R.EXN_STACKHEIGHT++] = $ss88768877;
}
if(R.isPyretException($e88728873)) {
$e88728873.pyretStack.push(L[360]);
}
throw $e88728873;
}
var $ret88788879 = $Hann_DASH_check_DASH_temp37448883($z88748875);
++R.GAS;
return $ret88788879;
};
var $Hann_DASH_check_DASH_temp37448883 = function(ann_DASH_check_DASH_temp23698882) {
return ann_DASH_check_DASH_temp23698882;
};
var $Hanf_arg37432328 = function(anf_arg23632324,a_DASH_var151461,body6682325,e6672326,l6652327,self6642323) {
var anf_fun23648894 = G(e6672326,"visit",L[1311]);
var $z88868887 = D;
var $f88928893 = function(_) {
return R.isFunction(anf_fun23648894)?anf_fun23648894.app(self6642323):R.ffi.throwNonFunApp(L[1310],anf_fun23648894,[self6642323]);
};
try {
if(--R.GAS > 0) {
$z88868887 = $f88928893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88928893,
"from":L[1310]});
}
} catch($e88848885) {
if(R.isCont($e88848885)) {
var $ss88888889 = {"from":L[1310],
"go":function(anf_arg23658895) {
return $Hanf_arg37428896(anf_arg23658895,a_DASH_var151461,anf_arg23632324,body6682325,l6652327,self6642323);
}};
$e88848885.stack[R.EXN_STACKHEIGHT++] = $ss88888889;
}
if(R.isPyretException($e88848885)) {
$e88848885.pyretStack.push(L[1310]);
}
throw $e88848885;
}
var $ret88908891 = $Hanf_arg37428896($z88868887,a_DASH_var151461,anf_arg23632324,body6682325,l6652327,self6642323);
++R.GAS;
return $ret88908891;
};
var $Hanf_arg37428896 = function(anf_arg23658895,a_DASH_var151461,anf_arg23632324,body6682325,l6652327,self6642323) {
var anf_fun23668907 = G(body6682325,"visit",L[1313]);
var $z88998900 = D;
var $f89058906 = function(_) {
return R.isFunction(anf_fun23668907)?anf_fun23668907.app(self6642323):R.ffi.throwNonFunApp(L[1312],anf_fun23668907,[self6642323]);
};
try {
if(--R.GAS > 0) {
$z88998900 = $f89058906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89058906,
"from":L[1312]});
}
} catch($e88978898) {
if(R.isCont($e88978898)) {
var $ss89018902 = {"from":L[1312],
"go":function(anf_arg23678908) {
return $Hanf_arg37418909(anf_arg23678908,a_DASH_var151461,anf_arg23632324,anf_arg23658895,l6652327);
}};
$e88978898.stack[R.EXN_STACKHEIGHT++] = $ss89018902;
}
if(R.isPyretException($e88978898)) {
$e88978898.pyretStack.push(L[1312]);
}
throw $e88978898;
}
var $ret89038904 = $Hanf_arg37418909($z88998900,a_DASH_var151461,anf_arg23632324,anf_arg23658895,l6652327);
++R.GAS;
return $ret89038904;
};
var $Hanf_arg37418909 = function(anf_arg23678908,a_DASH_var151461,anf_arg23632324,anf_arg23658895,l6652327) {
var $z89128913 = D;
var $f89188919 = function(_) {
return R.isFunction(a_DASH_var151461.$var)?a_DASH_var151461.$var.app(l6652327,anf_arg23632324,anf_arg23658895,anf_arg23678908):R.ffi.throwNonFunApp(L[367],a_DASH_var151461.$var,[l6652327,anf_arg23632324,anf_arg23658895,anf_arg23678908]);
};
try {
if(--R.GAS > 0) {
$z89128913 = $f89188919();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89188919,
"from":L[367]});
}
} catch($e89108911) {
if(R.isCont($e89108911)) {
var $ss89148915 = {"from":L[367],
"go":function(ann_DASH_check_DASH_temp23618920) {
return $Hann_DASH_check_DASH_temp37408921(ann_DASH_check_DASH_temp23618920);
}};
$e89108911.stack[R.EXN_STACKHEIGHT++] = $ss89148915;
}
if(R.isPyretException($e89108911)) {
$e89108911.pyretStack.push(L[367]);
}
throw $e89108911;
}
var $ret89168917 = $Hann_DASH_check_DASH_temp37408921($z89128913);
++R.GAS;
return $ret89168917;
};
var $Hann_DASH_check_DASH_temp37408921 = function(ann_DASH_check_DASH_temp23618920) {
return ann_DASH_check_DASH_temp23618920;
};
var $Hanf_arg37392346 = function(anf_arg23552342,a_DASH_let149457,body6632343,e6622344,l6602345,self6592341) {
var anf_fun23568932 = G(e6622344,"visit",L[1315]);
var $z89248925 = D;
var $f89308931 = function(_) {
return R.isFunction(anf_fun23568932)?anf_fun23568932.app(self6592341):R.ffi.throwNonFunApp(L[1314],anf_fun23568932,[self6592341]);
};
try {
if(--R.GAS > 0) {
$z89248925 = $f89308931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89308931,
"from":L[1314]});
}
} catch($e89228923) {
if(R.isCont($e89228923)) {
var $ss89268927 = {"from":L[1314],
"go":function(anf_arg23578933) {
return $Hanf_arg37388934(anf_arg23578933,a_DASH_let149457,anf_arg23552342,body6632343,l6602345,self6592341);
}};
$e89228923.stack[R.EXN_STACKHEIGHT++] = $ss89268927;
}
if(R.isPyretException($e89228923)) {
$e89228923.pyretStack.push(L[1314]);
}
throw $e89228923;
}
var $ret89288929 = $Hanf_arg37388934($z89248925,a_DASH_let149457,anf_arg23552342,body6632343,l6602345,self6592341);
++R.GAS;
return $ret89288929;
};
var $Hanf_arg37388934 = function(anf_arg23578933,a_DASH_let149457,anf_arg23552342,body6632343,l6602345,self6592341) {
var anf_fun23588945 = G(body6632343,"visit",L[1317]);
var $z89378938 = D;
var $f89438944 = function(_) {
return R.isFunction(anf_fun23588945)?anf_fun23588945.app(self6592341):R.ffi.throwNonFunApp(L[1316],anf_fun23588945,[self6592341]);
};
try {
if(--R.GAS > 0) {
$z89378938 = $f89438944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89438944,
"from":L[1316]});
}
} catch($e89358936) {
if(R.isCont($e89358936)) {
var $ss89398940 = {"from":L[1316],
"go":function(anf_arg23598946) {
return $Hanf_arg37378947(anf_arg23598946,a_DASH_let149457,anf_arg23552342,anf_arg23578933,l6602345);
}};
$e89358936.stack[R.EXN_STACKHEIGHT++] = $ss89398940;
}
if(R.isPyretException($e89358936)) {
$e89358936.pyretStack.push(L[1316]);
}
throw $e89358936;
}
var $ret89418942 = $Hanf_arg37378947($z89378938,a_DASH_let149457,anf_arg23552342,anf_arg23578933,l6602345);
++R.GAS;
return $ret89418942;
};
var $Hanf_arg37378947 = function(anf_arg23598946,a_DASH_let149457,anf_arg23552342,anf_arg23578933,l6602345) {
var $z89508951 = D;
var $f89568957 = function(_) {
return R.isFunction(a_DASH_let149457.$var)?a_DASH_let149457.$var.app(l6602345,anf_arg23552342,anf_arg23578933,anf_arg23598946):R.ffi.throwNonFunApp(L[374],a_DASH_let149457.$var,[l6602345,anf_arg23552342,anf_arg23578933,anf_arg23598946]);
};
try {
if(--R.GAS > 0) {
$z89508951 = $f89568957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89568957,
"from":L[374]});
}
} catch($e89488949) {
if(R.isCont($e89488949)) {
var $ss89528953 = {"from":L[374],
"go":function(ann_DASH_check_DASH_temp23538958) {
return $Hann_DASH_check_DASH_temp37368959(ann_DASH_check_DASH_temp23538958);
}};
$e89488949.stack[R.EXN_STACKHEIGHT++] = $ss89528953;
}
if(R.isPyretException($e89488949)) {
$e89488949.pyretStack.push(L[374]);
}
throw $e89488949;
}
var $ret89548955 = $Hann_DASH_check_DASH_temp37368959($z89508951);
++R.GAS;
return $ret89548955;
};
var $Hann_DASH_check_DASH_temp37368959 = function(ann_DASH_check_DASH_temp23538958) {
return ann_DASH_check_DASH_temp23538958;
};
var $Hanf_arg37352363 = function(anf_arg23492360,a_DASH_type_DASH_let147453,body6582361,l6562362,self6552359) {
var anf_fun23508970 = G(body6582361,"visit",L[1319]);
var $z89628963 = D;
var $f89688969 = function(_) {
return R.isFunction(anf_fun23508970)?anf_fun23508970.app(self6552359):R.ffi.throwNonFunApp(L[1318],anf_fun23508970,[self6552359]);
};
try {
if(--R.GAS > 0) {
$z89628963 = $f89688969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89688969,
"from":L[1318]});
}
} catch($e89608961) {
if(R.isCont($e89608961)) {
var $ss89648965 = {"from":L[1318],
"go":function(anf_arg23518971) {
return $Hanf_arg37348972(anf_arg23518971,a_DASH_type_DASH_let147453,anf_arg23492360,l6562362);
}};
$e89608961.stack[R.EXN_STACKHEIGHT++] = $ss89648965;
}
if(R.isPyretException($e89608961)) {
$e89608961.pyretStack.push(L[1318]);
}
throw $e89608961;
}
var $ret89668967 = $Hanf_arg37348972($z89628963,a_DASH_type_DASH_let147453,anf_arg23492360,l6562362);
++R.GAS;
return $ret89668967;
};
var $Hanf_arg37348972 = function(anf_arg23518971,a_DASH_type_DASH_let147453,anf_arg23492360,l6562362) {
var $z89758976 = D;
var $f89818982 = function(_) {
return R.isFunction(a_DASH_type_DASH_let147453.$var)?a_DASH_type_DASH_let147453.$var.app(l6562362,anf_arg23492360,anf_arg23518971):R.ffi.throwNonFunApp(L[377],a_DASH_type_DASH_let147453.$var,[l6562362,anf_arg23492360,anf_arg23518971]);
};
try {
if(--R.GAS > 0) {
$z89758976 = $f89818982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89818982,
"from":L[377]});
}
} catch($e89738974) {
if(R.isCont($e89738974)) {
var $ss89778978 = {"from":L[377],
"go":function(ann_DASH_check_DASH_temp23478983) {
return $Hann_DASH_check_DASH_temp37338984(ann_DASH_check_DASH_temp23478983);
}};
$e89738974.stack[R.EXN_STACKHEIGHT++] = $ss89778978;
}
if(R.isPyretException($e89738974)) {
$e89738974.pyretStack.push(L[377]);
}
throw $e89738974;
}
var $ret89798980 = $Hann_DASH_check_DASH_temp37338984($z89758976);
++R.GAS;
return $ret89798980;
};
var $Hann_DASH_check_DASH_temp37338984 = function(ann_DASH_check_DASH_temp23478983) {
return ann_DASH_check_DASH_temp23478983;
};
var $Hann_DASH_check_DASH_temp37322379 = function(ann_DASH_check_DASH_temp23452378) {
return ann_DASH_check_DASH_temp23452378;
};
var $Hann_DASH_check_DASH_temp37312395 = function(ann_DASH_check_DASH_temp23432394) {
return ann_DASH_check_DASH_temp23432394;
};
var $Hann_DASH_check_DASH_temp37302411 = function(ann_DASH_check_DASH_temp23412410) {
return ann_DASH_check_DASH_temp23412410;
};
var $Hann_DASH_check_DASH_temp37292427 = function(ann_DASH_check_DASH_temp23392426) {
return ann_DASH_check_DASH_temp23392426;
};
var $Hanf_arg37282445 = function(anf_arg23332441,a_DASH_import_DASH_types135429,l6352442,name6372443,self6342440,types6382444) {
var anf_fun23348995 = G(name6372443,"visit",L[1321]);
var $z89878988 = D;
var $f89938994 = function(_) {
return R.isFunction(anf_fun23348995)?anf_fun23348995.app(self6342440):R.ffi.throwNonFunApp(L[1320],anf_fun23348995,[self6342440]);
};
try {
if(--R.GAS > 0) {
$z89878988 = $f89938994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89938994,
"from":L[1320]});
}
} catch($e89858986) {
if(R.isCont($e89858986)) {
var $ss89898990 = {"from":L[1320],
"go":function(anf_arg23358996) {
return $Hanf_arg37278997(anf_arg23358996,a_DASH_import_DASH_types135429,anf_arg23332441,l6352442,self6342440,types6382444);
}};
$e89858986.stack[R.EXN_STACKHEIGHT++] = $ss89898990;
}
if(R.isPyretException($e89858986)) {
$e89858986.pyretStack.push(L[1320]);
}
throw $e89858986;
}
var $ret89918992 = $Hanf_arg37278997($z89878988,a_DASH_import_DASH_types135429,anf_arg23332441,l6352442,self6342440,types6382444);
++R.GAS;
return $ret89918992;
};
var $Hanf_arg37278997 = function(anf_arg23358996,a_DASH_import_DASH_types135429,anf_arg23332441,l6352442,self6342440,types6382444) {
var anf_fun23369008 = G(types6382444,"visit",L[1323]);
var $z90009001 = D;
var $f90069007 = function(_) {
return R.isFunction(anf_fun23369008)?anf_fun23369008.app(self6342440):R.ffi.throwNonFunApp(L[1322],anf_fun23369008,[self6342440]);
};
try {
if(--R.GAS > 0) {
$z90009001 = $f90069007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90069007,
"from":L[1322]});
}
} catch($e89988999) {
if(R.isCont($e89988999)) {
var $ss90029003 = {"from":L[1322],
"go":function(anf_arg23379009) {
return $Hanf_arg37269010(anf_arg23379009,a_DASH_import_DASH_types135429,anf_arg23332441,anf_arg23358996,l6352442);
}};
$e89988999.stack[R.EXN_STACKHEIGHT++] = $ss90029003;
}
if(R.isPyretException($e89988999)) {
$e89988999.pyretStack.push(L[1322]);
}
throw $e89988999;
}
var $ret90049005 = $Hanf_arg37269010($z90009001,a_DASH_import_DASH_types135429,anf_arg23332441,anf_arg23358996,l6352442);
++R.GAS;
return $ret90049005;
};
var $Hanf_arg37269010 = function(anf_arg23379009,a_DASH_import_DASH_types135429,anf_arg23332441,anf_arg23358996,l6352442) {
var $z90139014 = D;
var $f90199020 = function(_) {
return R.isFunction(a_DASH_import_DASH_types135429.$var)?a_DASH_import_DASH_types135429.$var.app(l6352442,anf_arg23332441,anf_arg23358996,anf_arg23379009):R.ffi.throwNonFunApp(L[394],a_DASH_import_DASH_types135429.$var,[l6352442,anf_arg23332441,anf_arg23358996,anf_arg23379009]);
};
try {
if(--R.GAS > 0) {
$z90139014 = $f90199020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90199020,
"from":L[394]});
}
} catch($e90119012) {
if(R.isCont($e90119012)) {
var $ss90159016 = {"from":L[394],
"go":function(ann_DASH_check_DASH_temp23319021) {
return $Hann_DASH_check_DASH_temp37259022(ann_DASH_check_DASH_temp23319021);
}};
$e90119012.stack[R.EXN_STACKHEIGHT++] = $ss90159016;
}
if(R.isPyretException($e90119012)) {
$e90119012.pyretStack.push(L[394]);
}
throw $e90119012;
}
var $ret90179018 = $Hann_DASH_check_DASH_temp37259022($z90139014);
++R.GAS;
return $ret90179018;
};
var $Hann_DASH_check_DASH_temp37259022 = function(ann_DASH_check_DASH_temp23319021) {
return ann_DASH_check_DASH_temp23319021;
};
var $Hanf_arg37242462 = function(anf_arg23272459,a_DASH_import133425,l6312460,name6332461,self6302458) {
var anf_fun23289033 = G(name6332461,"visit",L[1325]);
var $z90259026 = D;
var $f90319032 = function(_) {
return R.isFunction(anf_fun23289033)?anf_fun23289033.app(self6302458):R.ffi.throwNonFunApp(L[1324],anf_fun23289033,[self6302458]);
};
try {
if(--R.GAS > 0) {
$z90259026 = $f90319032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90319032,
"from":L[1324]});
}
} catch($e90239024) {
if(R.isCont($e90239024)) {
var $ss90279028 = {"from":L[1324],
"go":function(anf_arg23299034) {
return $Hanf_arg37239035(anf_arg23299034,a_DASH_import133425,anf_arg23272459,l6312460);
}};
$e90239024.stack[R.EXN_STACKHEIGHT++] = $ss90279028;
}
if(R.isPyretException($e90239024)) {
$e90239024.pyretStack.push(L[1324]);
}
throw $e90239024;
}
var $ret90299030 = $Hanf_arg37239035($z90259026,a_DASH_import133425,anf_arg23272459,l6312460);
++R.GAS;
return $ret90299030;
};
var $Hanf_arg37239035 = function(anf_arg23299034,a_DASH_import133425,anf_arg23272459,l6312460) {
var $z90389039 = D;
var $f90449045 = function(_) {
return R.isFunction(a_DASH_import133425.$var)?a_DASH_import133425.$var.app(l6312460,anf_arg23272459,anf_arg23299034):R.ffi.throwNonFunApp(L[400],a_DASH_import133425.$var,[l6312460,anf_arg23272459,anf_arg23299034]);
};
try {
if(--R.GAS > 0) {
$z90389039 = $f90449045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90449045,
"from":L[400]});
}
} catch($e90369037) {
if(R.isCont($e90369037)) {
var $ss90409041 = {"from":L[400],
"go":function(ann_DASH_check_DASH_temp23259046) {
return $Hann_DASH_check_DASH_temp37229047(ann_DASH_check_DASH_temp23259046);
}};
$e90369037.stack[R.EXN_STACKHEIGHT++] = $ss90409041;
}
if(R.isPyretException($e90369037)) {
$e90369037.pyretStack.push(L[400]);
}
throw $e90369037;
}
var $ret90429043 = $Hann_DASH_check_DASH_temp37229047($z90389039);
++R.GAS;
return $ret90429043;
};
var $Hann_DASH_check_DASH_temp37229047 = function(ann_DASH_check_DASH_temp23259046) {
return ann_DASH_check_DASH_temp23259046;
};
var $Hanf_arg37212480 = function(anf_arg23212476,a_DASH_program121401,body6292477,l6272478,self6262479) {
var anf_fun23229058 = G(body6292477,"visit",L[1327]);
var $z90509051 = D;
var $f90569057 = function(_) {
return R.isFunction(anf_fun23229058)?anf_fun23229058.app(self6262479):R.ffi.throwNonFunApp(L[1326],anf_fun23229058,[self6262479]);
};
try {
if(--R.GAS > 0) {
$z90509051 = $f90569057();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90569057,
"from":L[1326]});
}
} catch($e90489049) {
if(R.isCont($e90489049)) {
var $ss90529053 = {"from":L[1326],
"go":function(anf_arg23239059) {
return $Hanf_arg37209060(anf_arg23239059,a_DASH_program121401,anf_arg23212476,l6272478);
}};
$e90489049.stack[R.EXN_STACKHEIGHT++] = $ss90529053;
}
if(R.isPyretException($e90489049)) {
$e90489049.pyretStack.push(L[1326]);
}
throw $e90489049;
}
var $ret90549055 = $Hanf_arg37209060($z90509051,a_DASH_program121401,anf_arg23212476,l6272478);
++R.GAS;
return $ret90549055;
};
var $Hanf_arg37209060 = function(anf_arg23239059,a_DASH_program121401,anf_arg23212476,l6272478) {
var $z90639064 = D;
var $f90699070 = function(_) {
return R.isFunction(a_DASH_program121401.$var)?a_DASH_program121401.$var.app(l6272478,anf_arg23212476,anf_arg23239059):R.ffi.throwNonFunApp(L[407],a_DASH_program121401.$var,[l6272478,anf_arg23212476,anf_arg23239059]);
};
try {
if(--R.GAS > 0) {
$z90639064 = $f90699070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90699070,
"from":L[407]});
}
} catch($e90619062) {
if(R.isCont($e90619062)) {
var $ss90659066 = {"from":L[407],
"go":function(ann_DASH_check_DASH_temp23169071) {
return $Hann_DASH_check_DASH_temp37199072(ann_DASH_check_DASH_temp23169071);
}};
$e90619062.stack[R.EXN_STACKHEIGHT++] = $ss90659066;
}
if(R.isPyretException($e90619062)) {
$e90619062.pyretStack.push(L[407]);
}
throw $e90619062;
}
var $ret90679068 = $Hann_DASH_check_DASH_temp37199072($z90639064);
++R.GAS;
return $ret90679068;
};
var $Hann_DASH_check_DASH_temp37199072 = function(ann_DASH_check_DASH_temp23169071) {
return ann_DASH_check_DASH_temp23169071;
};
var $Hann_DASH_check_DASH_temp37182494 = function(ann_DASH_check_DASH_temp23182493) {
return ann_DASH_check_DASH_temp23182493;
};
var $Hanf_arg37172513 = function(anf_arg23102508,a_DASH_module192543,checks6252509,l6212510,provides6232511,self6202507,types6242512) {
var anf_fun23119083 = G(provides6232511,"visit",L[1329]);
var $z90759076 = D;
var $f90819082 = function(_) {
return R.isFunction(anf_fun23119083)?anf_fun23119083.app(self6202507):R.ffi.throwNonFunApp(L[1328],anf_fun23119083,[self6202507]);
};
try {
if(--R.GAS > 0) {
$z90759076 = $f90819082();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90819082,
"from":L[1328]});
}
} catch($e90739074) {
if(R.isCont($e90739074)) {
var $ss90779078 = {"from":L[1328],
"go":function(anf_arg23129084) {
return $Hanf_arg37169085(anf_arg23129084,a_DASH_module192543,anf_arg23102508,checks6252509,l6212510,self6202507,types6242512);
}};
$e90739074.stack[R.EXN_STACKHEIGHT++] = $ss90779078;
}
if(R.isPyretException($e90739074)) {
$e90739074.pyretStack.push(L[1328]);
}
throw $e90739074;
}
var $ret90799080 = $Hanf_arg37169085($z90759076,a_DASH_module192543,anf_arg23102508,checks6252509,l6212510,self6202507,types6242512);
++R.GAS;
return $ret90799080;
};
var $Hanf_arg37169085 = function(anf_arg23129084,a_DASH_module192543,anf_arg23102508,checks6252509,l6212510,self6202507,types6242512) {
var anf_fun23139096 = G(checks6252509,"visit",L[1331]);
var $z90889089 = D;
var $f90949095 = function(_) {
return R.isFunction(anf_fun23139096)?anf_fun23139096.app(self6202507):R.ffi.throwNonFunApp(L[1330],anf_fun23139096,[self6202507]);
};
try {
if(--R.GAS > 0) {
$z90889089 = $f90949095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90949095,
"from":L[1330]});
}
} catch($e90869087) {
if(R.isCont($e90869087)) {
var $ss90909091 = {"from":L[1330],
"go":function(anf_arg23149097) {
return $Hanf_arg37159098(anf_arg23149097,a_DASH_module192543,anf_arg23102508,anf_arg23129084,l6212510,types6242512);
}};
$e90869087.stack[R.EXN_STACKHEIGHT++] = $ss90909091;
}
if(R.isPyretException($e90869087)) {
$e90869087.pyretStack.push(L[1330]);
}
throw $e90869087;
}
var $ret90929093 = $Hanf_arg37159098($z90889089,a_DASH_module192543,anf_arg23102508,anf_arg23129084,l6212510,types6242512);
++R.GAS;
return $ret90929093;
};
var $Hanf_arg37159098 = function(anf_arg23149097,a_DASH_module192543,anf_arg23102508,anf_arg23129084,l6212510,types6242512) {
var $z91019102 = D;
var $f91079108 = function(_) {
return R.isFunction(a_DASH_module192543.$var)?a_DASH_module192543.$var.app(l6212510,anf_arg23102508,anf_arg23129084,types6242512,anf_arg23149097):R.ffi.throwNonFunApp(L[415],a_DASH_module192543.$var,[l6212510,anf_arg23102508,anf_arg23129084,types6242512,anf_arg23149097]);
};
try {
if(--R.GAS > 0) {
$z91019102 = $f91079108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91079108,
"from":L[415]});
}
} catch($e90999100) {
if(R.isCont($e90999100)) {
var $ss91039104 = {"from":L[415],
"go":function(ann_DASH_check_DASH_temp23089109) {
return $Hann_DASH_check_DASH_temp37149110(ann_DASH_check_DASH_temp23089109);
}};
$e90999100.stack[R.EXN_STACKHEIGHT++] = $ss91039104;
}
if(R.isPyretException($e90999100)) {
$e90999100.pyretStack.push(L[415]);
}
throw $e90999100;
}
var $ret91059106 = $Hann_DASH_check_DASH_temp37149110($z91019102);
++R.GAS;
return $ret91059106;
};
var $Hann_DASH_check_DASH_temp37149110 = function(ann_DASH_check_DASH_temp23089109) {
return ann_DASH_check_DASH_temp23089109;
};
var $Hann_DASH_check_DASH_temp37132530 = function(ann_DASH_check_DASH_temp22842529) {
return ann_DASH_check_DASH_temp22842529;
};
var $Hann_DASH_check_DASH_temp37122555 = function(ann_DASH_check_DASH_temp23022554) {
return ann_DASH_check_DASH_temp23022554;
};
var $Hann_DASH_check_DASH_temp37112569 = function(ann_DASH_check_DASH_temp23002568) {
return ann_DASH_check_DASH_temp23002568;
};
var $Hann_DASH_check_DASH_temp37102583 = function(ann_DASH_check_DASH_temp22982582) {
return ann_DASH_check_DASH_temp22982582;
};
var $Hann_DASH_check_DASH_temp37092596 = function(ann_DASH_check_DASH_temp22962595) {
return ann_DASH_check_DASH_temp22962595;
};
var $Hann_DASH_check_DASH_temp37082610 = function(ann_DASH_check_DASH_temp22942609) {
return ann_DASH_check_DASH_temp22942609;
};
var $Hann_DASH_check_DASH_temp37072624 = function(ann_DASH_check_DASH_temp22922623) {
return ann_DASH_check_DASH_temp22922623;
};
var $Hann_DASH_check_DASH_temp37062638 = function(ann_DASH_check_DASH_temp22902637) {
return ann_DASH_check_DASH_temp22902637;
};
var $Hann_DASH_check_DASH_temp37052652 = function(ann_DASH_check_DASH_temp22882651) {
return ann_DASH_check_DASH_temp22882651;
};
var $Hann_DASH_check_DASH_temp37042666 = function(ann_DASH_check_DASH_temp22862665) {
return ann_DASH_check_DASH_temp22862665;
};
var $Hann_DASH_check_DASH_temp37032683 = function(ann_DASH_check_DASH_temp22752682) {
return ann_DASH_check_DASH_temp22752682;
};
var $Hanf_arg37022700 = function(anf_arg22782699,a_DASH_field224607,dummy_DASH_loc115391,name5982687) {
var $z91139114 = D;
var $f91199120 = function(_) {
return R.isFunction(a_DASH_field224607.$var)?a_DASH_field224607.$var.app(dummy_DASH_loc115391,name5982687,anf_arg22782699):R.ffi.throwNonFunApp(L[430],a_DASH_field224607.$var,[dummy_DASH_loc115391,name5982687,anf_arg22782699]);
};
try {
if(--R.GAS > 0) {
$z91139114 = $f91199120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91199120,
"from":L[430]});
}
} catch($e91119112) {
if(R.isCont($e91119112)) {
var $ss91159116 = {"from":L[430],
"go":function(ann_DASH_check_DASH_temp22779121) {
return $Hann_DASH_check_DASH_temp37019122(ann_DASH_check_DASH_temp22779121);
}};
$e91119112.stack[R.EXN_STACKHEIGHT++] = $ss91159116;
}
if(R.isPyretException($e91119112)) {
$e91119112.pyretStack.push(L[430]);
}
throw $e91119112;
}
var $ret91179118 = $Hann_DASH_check_DASH_temp37019122($z91139114);
++R.GAS;
return $ret91179118;
};
var $Hann_DASH_check_DASH_temp37019122 = function(ann_DASH_check_DASH_temp22779121) {
return ann_DASH_check_DASH_temp22779121;
};
var $Hann_DASH_check_DASH_temp37002717 = function(ann_DASH_check_DASH_temp22122716) {
return ann_DASH_check_DASH_temp22122716;
};
var $Hanf_arg36992744 = function(anf_arg22692743,a_DASH_val218595) {
var $z91259126 = D;
var $f91319132 = function(_) {
return R.isFunction(a_DASH_val218595.$var)?a_DASH_val218595.$var.app(anf_arg22692743):R.ffi.throwNonFunApp(L[436],a_DASH_val218595.$var,[anf_arg22692743]);
};
try {
if(--R.GAS > 0) {
$z91259126 = $f91319132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91319132,
"from":L[436]});
}
} catch($e91239124) {
if(R.isCont($e91239124)) {
var $ss91279128 = {"from":L[436],
"go":function(ann_DASH_check_DASH_temp22689133) {
return $Hann_DASH_check_DASH_temp36989134(ann_DASH_check_DASH_temp22689133);
}};
$e91239124.stack[R.EXN_STACKHEIGHT++] = $ss91279128;
}
if(R.isPyretException($e91239124)) {
$e91239124.pyretStack.push(L[436]);
}
throw $e91239124;
}
var $ret91299130 = $Hann_DASH_check_DASH_temp36989134($z91259126);
++R.GAS;
return $ret91299130;
};
var $Hann_DASH_check_DASH_temp36989134 = function(ann_DASH_check_DASH_temp22689133) {
return ann_DASH_check_DASH_temp22689133;
};
var $Hanf_arg36972760 = function(anf_arg22662759,a_DASH_method216591,args5922746,dummy_DASH_loc115391,ret5932747) {
var $z91379138 = D;
var $f91439144 = function(_) {
return R.isFunction(a_DASH_method216591.$var)?a_DASH_method216591.$var.app(dummy_DASH_loc115391,args5922746,ret5932747,anf_arg22662759):R.ffi.throwNonFunApp(L[439],a_DASH_method216591.$var,[dummy_DASH_loc115391,args5922746,ret5932747,anf_arg22662759]);
};
try {
if(--R.GAS > 0) {
$z91379138 = $f91439144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91439144,
"from":L[439]});
}
} catch($e91359136) {
if(R.isCont($e91359136)) {
var $ss91399140 = {"from":L[439],
"go":function(ann_DASH_check_DASH_temp22659145) {
return $Hann_DASH_check_DASH_temp36969146(ann_DASH_check_DASH_temp22659145);
}};
$e91359136.stack[R.EXN_STACKHEIGHT++] = $ss91399140;
}
if(R.isPyretException($e91359136)) {
$e91359136.pyretStack.push(L[439]);
}
throw $e91359136;
}
var $ret91419142 = $Hann_DASH_check_DASH_temp36969146($z91379138);
++R.GAS;
return $ret91419142;
};
var $Hann_DASH_check_DASH_temp36969146 = function(ann_DASH_check_DASH_temp22659145) {
return ann_DASH_check_DASH_temp22659145;
};
var $Hanf_arg36952776 = function(anf_arg22632775,a_DASH_lam214587,args5882762,dummy_DASH_loc115391,ret5892763) {
var $z91499150 = D;
var $f91559156 = function(_) {
return R.isFunction(a_DASH_lam214587.$var)?a_DASH_lam214587.$var.app(dummy_DASH_loc115391,args5882762,ret5892763,anf_arg22632775):R.ffi.throwNonFunApp(L[441],a_DASH_lam214587.$var,[dummy_DASH_loc115391,args5882762,ret5892763,anf_arg22632775]);
};
try {
if(--R.GAS > 0) {
$z91499150 = $f91559156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91559156,
"from":L[441]});
}
} catch($e91479148) {
if(R.isCont($e91479148)) {
var $ss91519152 = {"from":L[441],
"go":function(ann_DASH_check_DASH_temp22629157) {
return $Hann_DASH_check_DASH_temp36949158(ann_DASH_check_DASH_temp22629157);
}};
$e91479148.stack[R.EXN_STACKHEIGHT++] = $ss91519152;
}
if(R.isPyretException($e91479148)) {
$e91479148.pyretStack.push(L[441]);
}
throw $e91479148;
}
var $ret91539154 = $Hann_DASH_check_DASH_temp36949158($z91499150);
++R.GAS;
return $ret91539154;
};
var $Hann_DASH_check_DASH_temp36949158 = function(ann_DASH_check_DASH_temp22629157) {
return ann_DASH_check_DASH_temp22629157;
};
var $Hanf_arg36932791 = function(anf_arg22602790,a_DASH_get_DASH_bang212583,dummy_DASH_loc115391,field5862779) {
var $z91619162 = D;
var $f91679168 = function(_) {
return R.isFunction(a_DASH_get_DASH_bang212583.$var)?a_DASH_get_DASH_bang212583.$var.app(dummy_DASH_loc115391,anf_arg22602790,field5862779):R.ffi.throwNonFunApp(L[443],a_DASH_get_DASH_bang212583.$var,[dummy_DASH_loc115391,anf_arg22602790,field5862779]);
};
try {
if(--R.GAS > 0) {
$z91619162 = $f91679168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91679168,
"from":L[443]});
}
} catch($e91599160) {
if(R.isCont($e91599160)) {
var $ss91639164 = {"from":L[443],
"go":function(ann_DASH_check_DASH_temp22599169) {
return $Hann_DASH_check_DASH_temp36929170(ann_DASH_check_DASH_temp22599169);
}};
$e91599160.stack[R.EXN_STACKHEIGHT++] = $ss91639164;
}
if(R.isPyretException($e91599160)) {
$e91599160.pyretStack.push(L[443]);
}
throw $e91599160;
}
var $ret91659166 = $Hann_DASH_check_DASH_temp36929170($z91619162);
++R.GAS;
return $ret91659166;
};
var $Hann_DASH_check_DASH_temp36929170 = function(ann_DASH_check_DASH_temp22599169) {
return ann_DASH_check_DASH_temp22599169;
};
var $Hanf_arg36912806 = function(anf_arg22572805,a_DASH_colon210579,dummy_DASH_loc115391,field5832794) {
var $z91739174 = D;
var $f91799180 = function(_) {
return R.isFunction(a_DASH_colon210579.$var)?a_DASH_colon210579.$var.app(dummy_DASH_loc115391,anf_arg22572805,field5832794):R.ffi.throwNonFunApp(L[446],a_DASH_colon210579.$var,[dummy_DASH_loc115391,anf_arg22572805,field5832794]);
};
try {
if(--R.GAS > 0) {
$z91739174 = $f91799180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91799180,
"from":L[446]});
}
} catch($e91719172) {
if(R.isCont($e91719172)) {
var $ss91759176 = {"from":L[446],
"go":function(ann_DASH_check_DASH_temp22569181) {
return $Hann_DASH_check_DASH_temp36909182(ann_DASH_check_DASH_temp22569181);
}};
$e91719172.stack[R.EXN_STACKHEIGHT++] = $ss91759176;
}
if(R.isPyretException($e91719172)) {
$e91719172.pyretStack.push(L[446]);
}
throw $e91719172;
}
var $ret91779178 = $Hann_DASH_check_DASH_temp36909182($z91739174);
++R.GAS;
return $ret91779178;
};
var $Hann_DASH_check_DASH_temp36909182 = function(ann_DASH_check_DASH_temp22569181) {
return ann_DASH_check_DASH_temp22569181;
};
var $Hanf_arg36892821 = function(anf_arg22542820,a_DASH_dot208575,dummy_DASH_loc115391,field5802809) {
var $z91859186 = D;
var $f91919192 = function(_) {
return R.isFunction(a_DASH_dot208575.$var)?a_DASH_dot208575.$var.app(dummy_DASH_loc115391,anf_arg22542820,field5802809):R.ffi.throwNonFunApp(L[449],a_DASH_dot208575.$var,[dummy_DASH_loc115391,anf_arg22542820,field5802809]);
};
try {
if(--R.GAS > 0) {
$z91859186 = $f91919192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91919192,
"from":L[449]});
}
} catch($e91839184) {
if(R.isCont($e91839184)) {
var $ss91879188 = {"from":L[449],
"go":function(ann_DASH_check_DASH_temp22539193) {
return $Hann_DASH_check_DASH_temp36889194(ann_DASH_check_DASH_temp22539193);
}};
$e91839184.stack[R.EXN_STACKHEIGHT++] = $ss91879188;
}
if(R.isPyretException($e91839184)) {
$e91839184.pyretStack.push(L[449]);
}
throw $e91839184;
}
var $ret91899190 = $Hann_DASH_check_DASH_temp36889194($z91859186);
++R.GAS;
return $ret91899190;
};
var $Hann_DASH_check_DASH_temp36889194 = function(ann_DASH_check_DASH_temp22539193) {
return ann_DASH_check_DASH_temp22539193;
};
var $Hanf_arg36872838 = function(anf_arg22492837,a_DASH_extend206571,arg_DASH_2872826,fields5772824,strip_DASH_loc_DASH_field252663) {
var anf_fun22509205 = G(fields5772824,"map",L[1334]);
var $z91979198 = D;
var $f92039204 = function(_) {
return R.isFunction(anf_fun22509205)?anf_fun22509205.app(strip_DASH_loc_DASH_field252663.$var === D?U(L[1332],"strip-loc-field"):strip_DASH_loc_DASH_field252663.$var):R.ffi.throwNonFunApp(L[1333],anf_fun22509205,[strip_DASH_loc_DASH_field252663.$var === D?U(L[1332],"strip-loc-field"):strip_DASH_loc_DASH_field252663.$var]);
};
try {
if(--R.GAS > 0) {
$z91979198 = $f92039204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92039204,
"from":L[1333]});
}
} catch($e91959196) {
if(R.isCont($e91959196)) {
var $ss91999200 = {"from":L[1333],
"go":function(anf_arg22519206) {
return $Hanf_arg36869207(anf_arg22519206,a_DASH_extend206571,anf_arg22492837,arg_DASH_2872826);
}};
$e91959196.stack[R.EXN_STACKHEIGHT++] = $ss91999200;
}
if(R.isPyretException($e91959196)) {
$e91959196.pyretStack.push(L[1333]);
}
throw $e91959196;
}
var $ret92019202 = $Hanf_arg36869207($z91979198,a_DASH_extend206571,anf_arg22492837,arg_DASH_2872826);
++R.GAS;
return $ret92019202;
};
var $Hanf_arg36869207 = function(anf_arg22519206,a_DASH_extend206571,anf_arg22492837,arg_DASH_2872826) {
var $z92109211 = D;
var $f92169217 = function(_) {
return R.isFunction(a_DASH_extend206571.$var)?a_DASH_extend206571.$var.app(arg_DASH_2872826,anf_arg22492837,anf_arg22519206):R.ffi.throwNonFunApp(L[453],a_DASH_extend206571.$var,[arg_DASH_2872826,anf_arg22492837,anf_arg22519206]);
};
try {
if(--R.GAS > 0) {
$z92109211 = $f92169217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92169217,
"from":L[453]});
}
} catch($e92089209) {
if(R.isCont($e92089209)) {
var $ss92129213 = {"from":L[453],
"go":function(ann_DASH_check_DASH_temp22489218) {
return $Hann_DASH_check_DASH_temp36859219(ann_DASH_check_DASH_temp22489218);
}};
$e92089209.stack[R.EXN_STACKHEIGHT++] = $ss92129213;
}
if(R.isPyretException($e92089209)) {
$e92089209.pyretStack.push(L[453]);
}
throw $e92089209;
}
var $ret92149215 = $Hann_DASH_check_DASH_temp36859219($z92109211);
++R.GAS;
return $ret92149215;
};
var $Hann_DASH_check_DASH_temp36859219 = function(ann_DASH_check_DASH_temp22489218) {
return ann_DASH_check_DASH_temp22489218;
};
var $Hanf_arg36842855 = function(anf_arg22432854,a_DASH_update204567,arg_DASH_2862843,fields5742841,strip_DASH_loc_DASH_field252663) {
var anf_fun22449230 = G(fields5742841,"map",L[1337]);
var $z92229223 = D;
var $f92289229 = function(_) {
return R.isFunction(anf_fun22449230)?anf_fun22449230.app(strip_DASH_loc_DASH_field252663.$var === D?U(L[1335],"strip-loc-field"):strip_DASH_loc_DASH_field252663.$var):R.ffi.throwNonFunApp(L[1336],anf_fun22449230,[strip_DASH_loc_DASH_field252663.$var === D?U(L[1335],"strip-loc-field"):strip_DASH_loc_DASH_field252663.$var]);
};
try {
if(--R.GAS > 0) {
$z92229223 = $f92289229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92289229,
"from":L[1336]});
}
} catch($e92209221) {
if(R.isCont($e92209221)) {
var $ss92249225 = {"from":L[1336],
"go":function(anf_arg22459231) {
return $Hanf_arg36839232(anf_arg22459231,a_DASH_update204567,anf_arg22432854,arg_DASH_2862843);
}};
$e92209221.stack[R.EXN_STACKHEIGHT++] = $ss92249225;
}
if(R.isPyretException($e92209221)) {
$e92209221.pyretStack.push(L[1336]);
}
throw $e92209221;
}
var $ret92269227 = $Hanf_arg36839232($z92229223,a_DASH_update204567,anf_arg22432854,arg_DASH_2862843);
++R.GAS;
return $ret92269227;
};
var $Hanf_arg36839232 = function(anf_arg22459231,a_DASH_update204567,anf_arg22432854,arg_DASH_2862843) {
var $z92359236 = D;
var $f92419242 = function(_) {
return R.isFunction(a_DASH_update204567.$var)?a_DASH_update204567.$var.app(arg_DASH_2862843,anf_arg22432854,anf_arg22459231):R.ffi.throwNonFunApp(L[457],a_DASH_update204567.$var,[arg_DASH_2862843,anf_arg22432854,anf_arg22459231]);
};
try {
if(--R.GAS > 0) {
$z92359236 = $f92419242();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92419242,
"from":L[457]});
}
} catch($e92339234) {
if(R.isCont($e92339234)) {
var $ss92379238 = {"from":L[457],
"go":function(ann_DASH_check_DASH_temp22429243) {
return $Hann_DASH_check_DASH_temp36829244(ann_DASH_check_DASH_temp22429243);
}};
$e92339234.stack[R.EXN_STACKHEIGHT++] = $ss92379238;
}
if(R.isPyretException($e92339234)) {
$e92339234.pyretStack.push(L[457]);
}
throw $e92339234;
}
var $ret92399240 = $Hann_DASH_check_DASH_temp36829244($z92359236);
++R.GAS;
return $ret92399240;
};
var $Hann_DASH_check_DASH_temp36829244 = function(ann_DASH_check_DASH_temp22429243) {
return ann_DASH_check_DASH_temp22429243;
};
var $Hanf_arg36812870 = function(anf_arg22392869,a_DASH_obj202563,dummy_DASH_loc115391) {
var $z92479248 = D;
var $f92539254 = function(_) {
return R.isFunction(a_DASH_obj202563.$var)?a_DASH_obj202563.$var.app(dummy_DASH_loc115391,anf_arg22392869):R.ffi.throwNonFunApp(L[460],a_DASH_obj202563.$var,[dummy_DASH_loc115391,anf_arg22392869]);
};
try {
if(--R.GAS > 0) {
$z92479248 = $f92539254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92539254,
"from":L[460]});
}
} catch($e92459246) {
if(R.isCont($e92459246)) {
var $ss92499250 = {"from":L[460],
"go":function(ann_DASH_check_DASH_temp22379255) {
return $Hann_DASH_check_DASH_temp36809256(ann_DASH_check_DASH_temp22379255);
}};
$e92459246.stack[R.EXN_STACKHEIGHT++] = $ss92499250;
}
if(R.isPyretException($e92459246)) {
$e92459246.pyretStack.push(L[460]);
}
throw $e92459246;
}
var $ret92519252 = $Hann_DASH_check_DASH_temp36809256($z92479248);
++R.GAS;
return $ret92519252;
};
var $Hann_DASH_check_DASH_temp36809256 = function(ann_DASH_check_DASH_temp22379255) {
return ann_DASH_check_DASH_temp22379255;
};
var $Hanf_arg36792886 = function(anf_arg22352885,a_DASH_prim_DASH_app200559,dummy_DASH_loc115391,f5682872) {
var $z92599260 = D;
var $f92659266 = function(_) {
return R.isFunction(a_DASH_prim_DASH_app200559.$var)?a_DASH_prim_DASH_app200559.$var.app(dummy_DASH_loc115391,f5682872,anf_arg22352885):R.ffi.throwNonFunApp(L[464],a_DASH_prim_DASH_app200559.$var,[dummy_DASH_loc115391,f5682872,anf_arg22352885]);
};
try {
if(--R.GAS > 0) {
$z92599260 = $f92659266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92659266,
"from":L[464]});
}
} catch($e92579258) {
if(R.isCont($e92579258)) {
var $ss92619262 = {"from":L[464],
"go":function(ann_DASH_check_DASH_temp22339267) {
return $Hann_DASH_check_DASH_temp36789268(ann_DASH_check_DASH_temp22339267);
}};
$e92579258.stack[R.EXN_STACKHEIGHT++] = $ss92619262;
}
if(R.isPyretException($e92579258)) {
$e92579258.pyretStack.push(L[464]);
}
throw $e92579258;
}
var $ret92639264 = $Hann_DASH_check_DASH_temp36789268($z92599260);
++R.GAS;
return $ret92639264;
};
var $Hann_DASH_check_DASH_temp36789268 = function(ann_DASH_check_DASH_temp22339267) {
return ann_DASH_check_DASH_temp22339267;
};
var $Hanf_arg36772901 = function(anf_arg22292900,a_DASH_app198555,args5662889,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665) {
var anf_fun22309279 = G(args5662889,"map",L[1340]);
var $z92719272 = D;
var $f92779278 = function(_) {
return R.isFunction(anf_fun22309279)?anf_fun22309279.app(strip_DASH_loc_DASH_val253665.$var === D?U(L[1338],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var):R.ffi.throwNonFunApp(L[1339],anf_fun22309279,[strip_DASH_loc_DASH_val253665.$var === D?U(L[1338],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var]);
};
try {
if(--R.GAS > 0) {
$z92719272 = $f92779278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92779278,
"from":L[1339]});
}
} catch($e92699270) {
if(R.isCont($e92699270)) {
var $ss92739274 = {"from":L[1339],
"go":function(anf_arg22319280) {
return $Hanf_arg36769281(anf_arg22319280,a_DASH_app198555,anf_arg22292900,dummy_DASH_loc115391);
}};
$e92699270.stack[R.EXN_STACKHEIGHT++] = $ss92739274;
}
if(R.isPyretException($e92699270)) {
$e92699270.pyretStack.push(L[1339]);
}
throw $e92699270;
}
var $ret92759276 = $Hanf_arg36769281($z92719272,a_DASH_app198555,anf_arg22292900,dummy_DASH_loc115391);
++R.GAS;
return $ret92759276;
};
var $Hanf_arg36769281 = function(anf_arg22319280,a_DASH_app198555,anf_arg22292900,dummy_DASH_loc115391) {
var $z92849285 = D;
var $f92909291 = function(_) {
return R.isFunction(a_DASH_app198555.$var)?a_DASH_app198555.$var.app(dummy_DASH_loc115391,anf_arg22292900,anf_arg22319280):R.ffi.throwNonFunApp(L[468],a_DASH_app198555.$var,[dummy_DASH_loc115391,anf_arg22292900,anf_arg22319280]);
};
try {
if(--R.GAS > 0) {
$z92849285 = $f92909291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92909291,
"from":L[468]});
}
} catch($e92829283) {
if(R.isCont($e92829283)) {
var $ss92869287 = {"from":L[468],
"go":function(ann_DASH_check_DASH_temp22289292) {
return $Hann_DASH_check_DASH_temp36759293(ann_DASH_check_DASH_temp22289292);
}};
$e92829283.stack[R.EXN_STACKHEIGHT++] = $ss92869287;
}
if(R.isPyretException($e92829283)) {
$e92829283.pyretStack.push(L[468]);
}
throw $e92829283;
}
var $ret92889289 = $Hann_DASH_check_DASH_temp36759293($z92849285);
++R.GAS;
return $ret92889289;
};
var $Hann_DASH_check_DASH_temp36759293 = function(ann_DASH_check_DASH_temp22289292) {
return ann_DASH_check_DASH_temp22289292;
};
var $Hanf_arg36742916 = function(anf_arg22262915,a_DASH_assign196551,dummy_DASH_loc115391,id5622903) {
var $z92969297 = D;
var $f93029303 = function(_) {
return R.isFunction(a_DASH_assign196551.$var)?a_DASH_assign196551.$var.app(dummy_DASH_loc115391,id5622903,anf_arg22262915):R.ffi.throwNonFunApp(L[471],a_DASH_assign196551.$var,[dummy_DASH_loc115391,id5622903,anf_arg22262915]);
};
try {
if(--R.GAS > 0) {
$z92969297 = $f93029303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93029303,
"from":L[471]});
}
} catch($e92949295) {
if(R.isCont($e92949295)) {
var $ss92989299 = {"from":L[471],
"go":function(ann_DASH_check_DASH_temp22259304) {
return $Hann_DASH_check_DASH_temp36739305(ann_DASH_check_DASH_temp22259304);
}};
$e92949295.stack[R.EXN_STACKHEIGHT++] = $ss92989299;
}
if(R.isPyretException($e92949295)) {
$e92949295.pyretStack.push(L[471]);
}
throw $e92949295;
}
var $ret93009301 = $Hann_DASH_check_DASH_temp36739305($z92969297);
++R.GAS;
return $ret93009301;
};
var $Hann_DASH_check_DASH_temp36739305 = function(ann_DASH_check_DASH_temp22259304) {
return ann_DASH_check_DASH_temp22259304;
};
var $Hanf_arg36722933 = function(anf_arg22152932,A136,a_DASH_module192543,checks5602921,dummy_DASH_loc115391,provides5582919,strip_DASH_loc_DASH_val253665,types5592920) {
var $z93089309 = D;
var $f93149315 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[1341],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[1341],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(provides5582919):R.ffi.throwNonFunApp(L[1342],strip_DASH_loc_DASH_val253665.$var === D?U(L[1341],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[provides5582919]);
};
try {
if(--R.GAS > 0) {
$z93089309 = $f93149315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93149315,
"from":L[1342]});
}
} catch($e93069307) {
if(R.isCont($e93069307)) {
var $ss93109311 = {"from":L[1342],
"go":function(anf_arg22169316) {
return $Hanf_arg36719317(anf_arg22169316,A136,a_DASH_module192543,anf_arg22152932,checks5602921,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665,types5592920);
}};
$e93069307.stack[R.EXN_STACKHEIGHT++] = $ss93109311;
}
if(R.isPyretException($e93069307)) {
$e93069307.pyretStack.push(L[1342]);
}
throw $e93069307;
}
var $ret93129313 = $Hanf_arg36719317($z93089309,A136,a_DASH_module192543,anf_arg22152932,checks5602921,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665,types5592920);
++R.GAS;
return $ret93129313;
};
var $Hanf_arg36719317 = function(anf_arg22169316,A136,a_DASH_module192543,anf_arg22152932,checks5602921,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665,types5592920) {
var anf_fun22179328 = G(types5592920,"map",L[1346]);
var anf_arg22219329 = R.makeFunction(function(recv_DASH_2859332) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1344],1,arguments);
}
var anf_fun22199343 = G(recv_DASH_2859332,"visit",L[1344]);
var anf_arg22209344 = G(A136,"dummy-loc-visitor",L[1345]);
var $z93359336 = D;
var $f93419342 = function(_) {
return R.isFunction(anf_fun22199343)?anf_fun22199343.app(anf_arg22209344):R.ffi.throwNonFunApp(L[1344],anf_fun22199343,[anf_arg22209344]);
};
try {
if(--R.GAS > 0) {
$z93359336 = $f93419342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93419342,
"from":L[1344]});
}
} catch($e93339334) {
if(R.isCont($e93339334)) {
var $ss93379338 = {"from":L[1344],
"go":function(ann_DASH_check_DASH_temp22189345) {
return $Hann_DASH_check_DASH_temp36679346(ann_DASH_check_DASH_temp22189345);
}};
$e93339334.stack[R.EXN_STACKHEIGHT++] = $ss93379338;
}
if(R.isPyretException($e93339334)) {
$e93339334.pyretStack.push(L[1344]);
}
throw $e93339334;
}
var $ret93399340 = $Hann_DASH_check_DASH_temp36679346($z93359336);
++R.GAS;
return $ret93399340;
});
var $z93209321 = D;
var $f93269327 = function(_) {
return R.isFunction(anf_fun22179328)?anf_fun22179328.app(anf_arg22219329):R.ffi.throwNonFunApp(L[1343],anf_fun22179328,[anf_arg22219329]);
};
try {
if(--R.GAS > 0) {
$z93209321 = $f93269327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93269327,
"from":L[1343]});
}
} catch($e93189319) {
if(R.isCont($e93189319)) {
var $ss93229323 = {"from":L[1343],
"go":function(anf_arg22229330) {
return $Hanf_arg36709331(anf_arg22229330,a_DASH_module192543,anf_arg22152932,anf_arg22169316,checks5602921,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665);
}};
$e93189319.stack[R.EXN_STACKHEIGHT++] = $ss93229323;
}
if(R.isPyretException($e93189319)) {
$e93189319.pyretStack.push(L[1343]);
}
throw $e93189319;
}
var $ret93249325 = $Hanf_arg36709331($z93209321,a_DASH_module192543,anf_arg22152932,anf_arg22169316,checks5602921,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665);
++R.GAS;
return $ret93249325;
};
var $Hanf_arg36709331 = function(anf_arg22229330,a_DASH_module192543,anf_arg22152932,anf_arg22169316,checks5602921,dummy_DASH_loc115391,strip_DASH_loc_DASH_val253665) {
var $z93499350 = D;
var $f93559356 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_val253665.$var === D?U(L[1347],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var)?strip_DASH_loc_DASH_val253665.$var === D?U(L[1347],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var.app(checks5602921):R.ffi.throwNonFunApp(L[1348],strip_DASH_loc_DASH_val253665.$var === D?U(L[1347],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var,[checks5602921]);
};
try {
if(--R.GAS > 0) {
$z93499350 = $f93559356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93559356,
"from":L[1348]});
}
} catch($e93479348) {
if(R.isCont($e93479348)) {
var $ss93519352 = {"from":L[1348],
"go":function(anf_arg22239357) {
return $Hanf_arg36699358(anf_arg22239357,a_DASH_module192543,anf_arg22152932,anf_arg22169316,anf_arg22229330,dummy_DASH_loc115391);
}};
$e93479348.stack[R.EXN_STACKHEIGHT++] = $ss93519352;
}
if(R.isPyretException($e93479348)) {
$e93479348.pyretStack.push(L[1348]);
}
throw $e93479348;
}
var $ret93539354 = $Hanf_arg36699358($z93499350,a_DASH_module192543,anf_arg22152932,anf_arg22169316,anf_arg22229330,dummy_DASH_loc115391);
++R.GAS;
return $ret93539354;
};
var $Hanf_arg36699358 = function(anf_arg22239357,a_DASH_module192543,anf_arg22152932,anf_arg22169316,anf_arg22229330,dummy_DASH_loc115391) {
var $z93619362 = D;
var $f93679368 = function(_) {
return R.isFunction(a_DASH_module192543.$var)?a_DASH_module192543.$var.app(dummy_DASH_loc115391,anf_arg22152932,anf_arg22169316,anf_arg22229330,anf_arg22239357):R.ffi.throwNonFunApp(L[474],a_DASH_module192543.$var,[dummy_DASH_loc115391,anf_arg22152932,anf_arg22169316,anf_arg22229330,anf_arg22239357]);
};
try {
if(--R.GAS > 0) {
$z93619362 = $f93679368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93679368,
"from":L[474]});
}
} catch($e93599360) {
if(R.isCont($e93599360)) {
var $ss93639364 = {"from":L[474],
"go":function(ann_DASH_check_DASH_temp22149369) {
return $Hann_DASH_check_DASH_temp36689370(ann_DASH_check_DASH_temp22149369);
}};
$e93599360.stack[R.EXN_STACKHEIGHT++] = $ss93639364;
}
if(R.isPyretException($e93599360)) {
$e93599360.pyretStack.push(L[474]);
}
throw $e93599360;
}
var $ret93659366 = $Hann_DASH_check_DASH_temp36689370($z93619362);
++R.GAS;
return $ret93659366;
};
var $Hann_DASH_check_DASH_temp36689370 = function(ann_DASH_check_DASH_temp22149369) {
return ann_DASH_check_DASH_temp22149369;
};
var $Hann_DASH_check_DASH_temp36679346 = function(ann_DASH_check_DASH_temp22189345) {
return ann_DASH_check_DASH_temp22189345;
};
var $Hann_DASH_check_DASH_temp36662950 = function(ann_DASH_check_DASH_temp22012949) {
return ann_DASH_check_DASH_temp22012949;
};
var $Hanf_arg36652969 = function(anf_arg22062968,a_DASH_bind166491,dummy_DASH_loc115391,id5532954) {
var $z93739374 = D;
var $f93799380 = function(_) {
return R.isFunction(a_DASH_bind166491.$var)?a_DASH_bind166491.$var.app(dummy_DASH_loc115391,id5532954,anf_arg22062968):R.ffi.throwNonFunApp(L[480],a_DASH_bind166491.$var,[dummy_DASH_loc115391,id5532954,anf_arg22062968]);
};
try {
if(--R.GAS > 0) {
$z93739374 = $f93799380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93799380,
"from":L[480]});
}
} catch($e93719372) {
if(R.isCont($e93719372)) {
var $ss93759376 = {"from":L[480],
"go":function(ann_DASH_check_DASH_temp22039381) {
return $Hann_DASH_check_DASH_temp36649382(ann_DASH_check_DASH_temp22039381);
}};
$e93719372.stack[R.EXN_STACKHEIGHT++] = $ss93759376;
}
if(R.isPyretException($e93719372)) {
$e93719372.pyretStack.push(L[480]);
}
throw $e93719372;
}
var $ret93779378 = $Hann_DASH_check_DASH_temp36649382($z93739374);
++R.GAS;
return $ret93779378;
};
var $Hann_DASH_check_DASH_temp36649382 = function(ann_DASH_check_DASH_temp22039381) {
return ann_DASH_check_DASH_temp22039381;
};
var $Hann_DASH_check_DASH_temp36632986 = function(ann_DASH_check_DASH_temp21642985) {
return ann_DASH_check_DASH_temp21642985;
};
var $Hanf_arg36623007 = function(anf_arg21953006,a_DASH_lettable161481) {
var $z93859386 = D;
var $f93919392 = function(_) {
return R.isFunction(a_DASH_lettable161481.$var)?a_DASH_lettable161481.$var.app(anf_arg21953006):R.ffi.throwNonFunApp(L[487],a_DASH_lettable161481.$var,[anf_arg21953006]);
};
try {
if(--R.GAS > 0) {
$z93859386 = $f93919392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93919392,
"from":L[487]});
}
} catch($e93839384) {
if(R.isCont($e93839384)) {
var $ss93879388 = {"from":L[487],
"go":function(ann_DASH_check_DASH_temp21949393) {
return $Hann_DASH_check_DASH_temp36619394(ann_DASH_check_DASH_temp21949393);
}};
$e93839384.stack[R.EXN_STACKHEIGHT++] = $ss93879388;
}
if(R.isPyretException($e93839384)) {
$e93839384.pyretStack.push(L[487]);
}
throw $e93839384;
}
var $ret93899390 = $Hann_DASH_check_DASH_temp36619394($z93859386);
++R.GAS;
return $ret93899390;
};
var $Hann_DASH_check_DASH_temp36619394 = function(ann_DASH_check_DASH_temp21949393) {
return ann_DASH_check_DASH_temp21949393;
};
var $Hanf_arg36603025 = function(anf_arg21883024,a_DASH_split_DASH_app157473,args5473011,dummy_DASH_loc115391,helper_DASH_args5493013,helper5483012,is_DASH_var5453009,strip_DASH_loc_DASH_val253665) {
var anf_fun21899405 = G(args5473011,"map",L[1351]);
var $z93979398 = D;
var $f94039404 = function(_) {
return R.isFunction(anf_fun21899405)?anf_fun21899405.app(strip_DASH_loc_DASH_val253665.$var === D?U(L[1349],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var):R.ffi.throwNonFunApp(L[1350],anf_fun21899405,[strip_DASH_loc_DASH_val253665.$var === D?U(L[1349],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var]);
};
try {
if(--R.GAS > 0) {
$z93979398 = $f94039404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94039404,
"from":L[1350]});
}
} catch($e93959396) {
if(R.isCont($e93959396)) {
var $ss93999400 = {"from":L[1350],
"go":function(anf_arg21909406) {
return $Hanf_arg36599407(anf_arg21909406,a_DASH_split_DASH_app157473,anf_arg21883024,dummy_DASH_loc115391,helper_DASH_args5493013,helper5483012,is_DASH_var5453009,strip_DASH_loc_DASH_val253665);
}};
$e93959396.stack[R.EXN_STACKHEIGHT++] = $ss93999400;
}
if(R.isPyretException($e93959396)) {
$e93959396.pyretStack.push(L[1350]);
}
throw $e93959396;
}
var $ret94019402 = $Hanf_arg36599407($z93979398,a_DASH_split_DASH_app157473,anf_arg21883024,dummy_DASH_loc115391,helper_DASH_args5493013,helper5483012,is_DASH_var5453009,strip_DASH_loc_DASH_val253665);
++R.GAS;
return $ret94019402;
};
var $Hanf_arg36599407 = function(anf_arg21909406,a_DASH_split_DASH_app157473,anf_arg21883024,dummy_DASH_loc115391,helper_DASH_args5493013,helper5483012,is_DASH_var5453009,strip_DASH_loc_DASH_val253665) {
var anf_fun21919418 = G(helper_DASH_args5493013,"map",L[1354]);
var $z94109411 = D;
var $f94169417 = function(_) {
return R.isFunction(anf_fun21919418)?anf_fun21919418.app(strip_DASH_loc_DASH_val253665.$var === D?U(L[1352],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var):R.ffi.throwNonFunApp(L[1353],anf_fun21919418,[strip_DASH_loc_DASH_val253665.$var === D?U(L[1352],"strip-loc-val"):strip_DASH_loc_DASH_val253665.$var]);
};
try {
if(--R.GAS > 0) {
$z94109411 = $f94169417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94169417,
"from":L[1353]});
}
} catch($e94089409) {
if(R.isCont($e94089409)) {
var $ss94129413 = {"from":L[1353],
"go":function(anf_arg21929419) {
return $Hanf_arg36589420(anf_arg21929419,a_DASH_split_DASH_app157473,anf_arg21883024,anf_arg21909406,dummy_DASH_loc115391,helper5483012,is_DASH_var5453009);
}};
$e94089409.stack[R.EXN_STACKHEIGHT++] = $ss94129413;
}
if(R.isPyretException($e94089409)) {
$e94089409.pyretStack.push(L[1353]);
}
throw $e94089409;
}
var $ret94149415 = $Hanf_arg36589420($z94109411,a_DASH_split_DASH_app157473,anf_arg21883024,anf_arg21909406,dummy_DASH_loc115391,helper5483012,is_DASH_var5453009);
++R.GAS;
return $ret94149415;
};
var $Hanf_arg36589420 = function(anf_arg21929419,a_DASH_split_DASH_app157473,anf_arg21883024,anf_arg21909406,dummy_DASH_loc115391,helper5483012,is_DASH_var5453009) {
var $z94239424 = D;
var $f94299430 = function(_) {
return R.isFunction(a_DASH_split_DASH_app157473.$var)?a_DASH_split_DASH_app157473.$var.app(dummy_DASH_loc115391,is_DASH_var5453009,anf_arg21883024,anf_arg21909406,helper5483012,anf_arg21929419):R.ffi.throwNonFunApp(L[490],a_DASH_split_DASH_app157473.$var,[dummy_DASH_loc115391,is_DASH_var5453009,anf_arg21883024,anf_arg21909406,helper5483012,anf_arg21929419]);
};
try {
if(--R.GAS > 0) {
$z94239424 = $f94299430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94299430,
"from":L[490]});
}
} catch($e94219422) {
if(R.isCont($e94219422)) {
var $ss94259426 = {"from":L[490],
"go":function(ann_DASH_check_DASH_temp21879431) {
return $Hann_DASH_check_DASH_temp36579432(ann_DASH_check_DASH_temp21879431);
}};
$e94219422.stack[R.EXN_STACKHEIGHT++] = $ss94259426;
}
if(R.isPyretException($e94219422)) {
$e94219422.pyretStack.push(L[490]);
}
throw $e94219422;
}
var $ret94279428 = $Hann_DASH_check_DASH_temp36579432($z94239424);
++R.GAS;
return $ret94279428;
};
var $Hann_DASH_check_DASH_temp36579432 = function(ann_DASH_check_DASH_temp21879431) {
return ann_DASH_check_DASH_temp21879431;
};
var $Hanf_arg36563041 = function(anf_arg21833040,a_DASH_if159477,dummy_DASH_loc115391,e5433029,strip_DASH_loc_DASH_expr249657,t5423028) {
var $z94359436 = D;
var $f94419442 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_expr249657.$var)?strip_DASH_loc_DASH_expr249657.$var.app(t5423028):R.ffi.throwNonFunApp(L[1355],strip_DASH_loc_DASH_expr249657.$var,[t5423028]);
};
try {
if(--R.GAS > 0) {
$z94359436 = $f94419442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94419442,
"from":L[1355]});
}
} catch($e94339434) {
if(R.isCont($e94339434)) {
var $ss94379438 = {"from":L[1355],
"go":function(anf_arg21849443) {
return $Hanf_arg36559444(anf_arg21849443,a_DASH_if159477,anf_arg21833040,dummy_DASH_loc115391,e5433029,strip_DASH_loc_DASH_expr249657);
}};
$e94339434.stack[R.EXN_STACKHEIGHT++] = $ss94379438;
}
if(R.isPyretException($e94339434)) {
$e94339434.pyretStack.push(L[1355]);
}
throw $e94339434;
}
var $ret94399440 = $Hanf_arg36559444($z94359436,a_DASH_if159477,anf_arg21833040,dummy_DASH_loc115391,e5433029,strip_DASH_loc_DASH_expr249657);
++R.GAS;
return $ret94399440;
};
var $Hanf_arg36559444 = function(anf_arg21849443,a_DASH_if159477,anf_arg21833040,dummy_DASH_loc115391,e5433029,strip_DASH_loc_DASH_expr249657) {
var $z94479448 = D;
var $f94539454 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_expr249657.$var)?strip_DASH_loc_DASH_expr249657.$var.app(e5433029):R.ffi.throwNonFunApp(L[1356],strip_DASH_loc_DASH_expr249657.$var,[e5433029]);
};
try {
if(--R.GAS > 0) {
$z94479448 = $f94539454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94539454,
"from":L[1356]});
}
} catch($e94459446) {
if(R.isCont($e94459446)) {
var $ss94499450 = {"from":L[1356],
"go":function(anf_arg21859455) {
return $Hanf_arg36549456(anf_arg21859455,a_DASH_if159477,anf_arg21833040,anf_arg21849443,dummy_DASH_loc115391);
}};
$e94459446.stack[R.EXN_STACKHEIGHT++] = $ss94499450;
}
if(R.isPyretException($e94459446)) {
$e94459446.pyretStack.push(L[1356]);
}
throw $e94459446;
}
var $ret94519452 = $Hanf_arg36549456($z94479448,a_DASH_if159477,anf_arg21833040,anf_arg21849443,dummy_DASH_loc115391);
++R.GAS;
return $ret94519452;
};
var $Hanf_arg36549456 = function(anf_arg21859455,a_DASH_if159477,anf_arg21833040,anf_arg21849443,dummy_DASH_loc115391) {
var $z94599460 = D;
var $f94659466 = function(_) {
return R.isFunction(a_DASH_if159477.$var)?a_DASH_if159477.$var.app(dummy_DASH_loc115391,anf_arg21833040,anf_arg21849443,anf_arg21859455):R.ffi.throwNonFunApp(L[493],a_DASH_if159477.$var,[dummy_DASH_loc115391,anf_arg21833040,anf_arg21849443,anf_arg21859455]);
};
try {
if(--R.GAS > 0) {
$z94599460 = $f94659466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94659466,
"from":L[493]});
}
} catch($e94579458) {
if(R.isCont($e94579458)) {
var $ss94619462 = {"from":L[493],
"go":function(ann_DASH_check_DASH_temp21829467) {
return $Hann_DASH_check_DASH_temp36539468(ann_DASH_check_DASH_temp21829467);
}};
$e94579458.stack[R.EXN_STACKHEIGHT++] = $ss94619462;
}
if(R.isPyretException($e94579458)) {
$e94579458.pyretStack.push(L[493]);
}
throw $e94579458;
}
var $ret94639464 = $Hann_DASH_check_DASH_temp36539468($z94599460);
++R.GAS;
return $ret94639464;
};
var $Hann_DASH_check_DASH_temp36539468 = function(ann_DASH_check_DASH_temp21829467) {
return ann_DASH_check_DASH_temp21829467;
};
var $Hanf_arg36523056 = function(anf_arg21793055,a_DASH_seq153465,dummy_DASH_loc115391,e25393044,strip_DASH_loc_DASH_expr249657) {
var $z94719472 = D;
var $f94779478 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_expr249657.$var)?strip_DASH_loc_DASH_expr249657.$var.app(e25393044):R.ffi.throwNonFunApp(L[1357],strip_DASH_loc_DASH_expr249657.$var,[e25393044]);
};
try {
if(--R.GAS > 0) {
$z94719472 = $f94779478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94779478,
"from":L[1357]});
}
} catch($e94699470) {
if(R.isCont($e94699470)) {
var $ss94739474 = {"from":L[1357],
"go":function(anf_arg21809479) {
return $Hanf_arg36519480(anf_arg21809479,a_DASH_seq153465,anf_arg21793055,dummy_DASH_loc115391);
}};
$e94699470.stack[R.EXN_STACKHEIGHT++] = $ss94739474;
}
if(R.isPyretException($e94699470)) {
$e94699470.pyretStack.push(L[1357]);
}
throw $e94699470;
}
var $ret94759476 = $Hanf_arg36519480($z94719472,a_DASH_seq153465,anf_arg21793055,dummy_DASH_loc115391);
++R.GAS;
return $ret94759476;
};
var $Hanf_arg36519480 = function(anf_arg21809479,a_DASH_seq153465,anf_arg21793055,dummy_DASH_loc115391) {
var $z94839484 = D;
var $f94899490 = function(_) {
return R.isFunction(a_DASH_seq153465.$var)?a_DASH_seq153465.$var.app(dummy_DASH_loc115391,anf_arg21793055,anf_arg21809479):R.ffi.throwNonFunApp(L[496],a_DASH_seq153465.$var,[dummy_DASH_loc115391,anf_arg21793055,anf_arg21809479]);
};
try {
if(--R.GAS > 0) {
$z94839484 = $f94899490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94899490,
"from":L[496]});
}
} catch($e94819482) {
if(R.isCont($e94819482)) {
var $ss94859486 = {"from":L[496],
"go":function(ann_DASH_check_DASH_temp21789491) {
return $Hann_DASH_check_DASH_temp36509492(ann_DASH_check_DASH_temp21789491);
}};
$e94819482.stack[R.EXN_STACKHEIGHT++] = $ss94859486;
}
if(R.isPyretException($e94819482)) {
$e94819482.pyretStack.push(L[496]);
}
throw $e94819482;
}
var $ret94879488 = $Hann_DASH_check_DASH_temp36509492($z94839484);
++R.GAS;
return $ret94879488;
};
var $Hann_DASH_check_DASH_temp36509492 = function(ann_DASH_check_DASH_temp21789491) {
return ann_DASH_check_DASH_temp21789491;
};
var $Hanf_arg36493072 = function(anf_arg21743071,a_DASH_var151461,body5363060,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_lettable251661,val5353059) {
var $z94959496 = D;
var $f95019502 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_lettable251661.$var === D?U(L[1358],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var)?strip_DASH_loc_DASH_lettable251661.$var === D?U(L[1358],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var.app(val5353059):R.ffi.throwNonFunApp(L[1359],strip_DASH_loc_DASH_lettable251661.$var === D?U(L[1358],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var,[val5353059]);
};
try {
if(--R.GAS > 0) {
$z94959496 = $f95019502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95019502,
"from":L[1359]});
}
} catch($e94939494) {
if(R.isCont($e94939494)) {
var $ss94979498 = {"from":L[1359],
"go":function(anf_arg21759503) {
return $Hanf_arg36489504(anf_arg21759503,a_DASH_var151461,anf_arg21743071,body5363060,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657);
}};
$e94939494.stack[R.EXN_STACKHEIGHT++] = $ss94979498;
}
if(R.isPyretException($e94939494)) {
$e94939494.pyretStack.push(L[1359]);
}
throw $e94939494;
}
var $ret94999500 = $Hanf_arg36489504($z94959496,a_DASH_var151461,anf_arg21743071,body5363060,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657);
++R.GAS;
return $ret94999500;
};
var $Hanf_arg36489504 = function(anf_arg21759503,a_DASH_var151461,anf_arg21743071,body5363060,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657) {
var $z95079508 = D;
var $f95139514 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_expr249657.$var)?strip_DASH_loc_DASH_expr249657.$var.app(body5363060):R.ffi.throwNonFunApp(L[1360],strip_DASH_loc_DASH_expr249657.$var,[body5363060]);
};
try {
if(--R.GAS > 0) {
$z95079508 = $f95139514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95139514,
"from":L[1360]});
}
} catch($e95059506) {
if(R.isCont($e95059506)) {
var $ss95099510 = {"from":L[1360],
"go":function(anf_arg21769515) {
return $Hanf_arg36479516(anf_arg21769515,a_DASH_var151461,anf_arg21743071,anf_arg21759503,dummy_DASH_loc115391);
}};
$e95059506.stack[R.EXN_STACKHEIGHT++] = $ss95099510;
}
if(R.isPyretException($e95059506)) {
$e95059506.pyretStack.push(L[1360]);
}
throw $e95059506;
}
var $ret95119512 = $Hanf_arg36479516($z95079508,a_DASH_var151461,anf_arg21743071,anf_arg21759503,dummy_DASH_loc115391);
++R.GAS;
return $ret95119512;
};
var $Hanf_arg36479516 = function(anf_arg21769515,a_DASH_var151461,anf_arg21743071,anf_arg21759503,dummy_DASH_loc115391) {
var $z95199520 = D;
var $f95259526 = function(_) {
return R.isFunction(a_DASH_var151461.$var)?a_DASH_var151461.$var.app(dummy_DASH_loc115391,anf_arg21743071,anf_arg21759503,anf_arg21769515):R.ffi.throwNonFunApp(L[499],a_DASH_var151461.$var,[dummy_DASH_loc115391,anf_arg21743071,anf_arg21759503,anf_arg21769515]);
};
try {
if(--R.GAS > 0) {
$z95199520 = $f95259526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95259526,
"from":L[499]});
}
} catch($e95179518) {
if(R.isCont($e95179518)) {
var $ss95219522 = {"from":L[499],
"go":function(ann_DASH_check_DASH_temp21739527) {
return $Hann_DASH_check_DASH_temp36469528(ann_DASH_check_DASH_temp21739527);
}};
$e95179518.stack[R.EXN_STACKHEIGHT++] = $ss95219522;
}
if(R.isPyretException($e95179518)) {
$e95179518.pyretStack.push(L[499]);
}
throw $e95179518;
}
var $ret95239524 = $Hann_DASH_check_DASH_temp36469528($z95199520);
++R.GAS;
return $ret95239524;
};
var $Hann_DASH_check_DASH_temp36469528 = function(ann_DASH_check_DASH_temp21739527) {
return ann_DASH_check_DASH_temp21739527;
};
var $Hanf_arg36453088 = function(anf_arg21693087,a_DASH_let149457,body5323076,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657,strip_DASH_loc_DASH_lettable251661,val5313075) {
var $z95319532 = D;
var $f95379538 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_lettable251661.$var === D?U(L[1361],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var)?strip_DASH_loc_DASH_lettable251661.$var === D?U(L[1361],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var.app(val5313075):R.ffi.throwNonFunApp(L[1362],strip_DASH_loc_DASH_lettable251661.$var === D?U(L[1361],"strip-loc-lettable"):strip_DASH_loc_DASH_lettable251661.$var,[val5313075]);
};
try {
if(--R.GAS > 0) {
$z95319532 = $f95379538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95379538,
"from":L[1362]});
}
} catch($e95299530) {
if(R.isCont($e95299530)) {
var $ss95339534 = {"from":L[1362],
"go":function(anf_arg21709539) {
return $Hanf_arg36449540(anf_arg21709539,a_DASH_let149457,anf_arg21693087,body5323076,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657);
}};
$e95299530.stack[R.EXN_STACKHEIGHT++] = $ss95339534;
}
if(R.isPyretException($e95299530)) {
$e95299530.pyretStack.push(L[1362]);
}
throw $e95299530;
}
var $ret95359536 = $Hanf_arg36449540($z95319532,a_DASH_let149457,anf_arg21693087,body5323076,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657);
++R.GAS;
return $ret95359536;
};
var $Hanf_arg36449540 = function(anf_arg21709539,a_DASH_let149457,anf_arg21693087,body5323076,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657) {
var $z95439544 = D;
var $f95499550 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_expr249657.$var)?strip_DASH_loc_DASH_expr249657.$var.app(body5323076):R.ffi.throwNonFunApp(L[1363],strip_DASH_loc_DASH_expr249657.$var,[body5323076]);
};
try {
if(--R.GAS > 0) {
$z95439544 = $f95499550();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95499550,
"from":L[1363]});
}
} catch($e95419542) {
if(R.isCont($e95419542)) {
var $ss95459546 = {"from":L[1363],
"go":function(anf_arg21719551) {
return $Hanf_arg36439552(anf_arg21719551,a_DASH_let149457,anf_arg21693087,anf_arg21709539,dummy_DASH_loc115391);
}};
$e95419542.stack[R.EXN_STACKHEIGHT++] = $ss95459546;
}
if(R.isPyretException($e95419542)) {
$e95419542.pyretStack.push(L[1363]);
}
throw $e95419542;
}
var $ret95479548 = $Hanf_arg36439552($z95439544,a_DASH_let149457,anf_arg21693087,anf_arg21709539,dummy_DASH_loc115391);
++R.GAS;
return $ret95479548;
};
var $Hanf_arg36439552 = function(anf_arg21719551,a_DASH_let149457,anf_arg21693087,anf_arg21709539,dummy_DASH_loc115391) {
var $z95559556 = D;
var $f95619562 = function(_) {
return R.isFunction(a_DASH_let149457.$var)?a_DASH_let149457.$var.app(dummy_DASH_loc115391,anf_arg21693087,anf_arg21709539,anf_arg21719551):R.ffi.throwNonFunApp(L[502],a_DASH_let149457.$var,[dummy_DASH_loc115391,anf_arg21693087,anf_arg21709539,anf_arg21719551]);
};
try {
if(--R.GAS > 0) {
$z95559556 = $f95619562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95619562,
"from":L[502]});
}
} catch($e95539554) {
if(R.isCont($e95539554)) {
var $ss95579558 = {"from":L[502],
"go":function(ann_DASH_check_DASH_temp21689563) {
return $Hann_DASH_check_DASH_temp36429564(ann_DASH_check_DASH_temp21689563);
}};
$e95539554.stack[R.EXN_STACKHEIGHT++] = $ss95579558;
}
if(R.isPyretException($e95539554)) {
$e95539554.pyretStack.push(L[502]);
}
throw $e95539554;
}
var $ret95599560 = $Hann_DASH_check_DASH_temp36429564($z95559556);
++R.GAS;
return $ret95599560;
};
var $Hann_DASH_check_DASH_temp36429564 = function(ann_DASH_check_DASH_temp21689563) {
return ann_DASH_check_DASH_temp21689563;
};
var $Hann_DASH_check_DASH_temp36413103 = function(ann_DASH_check_DASH_temp21663102) {
return ann_DASH_check_DASH_temp21663102;
};
var $Hann_DASH_check_DASH_temp36403120 = function(ann_DASH_check_DASH_temp21543119) {
return ann_DASH_check_DASH_temp21543119;
};
var $Hann_DASH_check_DASH_temp36393138 = function(ann_DASH_check_DASH_temp21583137) {
return ann_DASH_check_DASH_temp21583137;
};
var $Hann_DASH_check_DASH_temp36383153 = function(ann_DASH_check_DASH_temp21563152) {
return ann_DASH_check_DASH_temp21563152;
};
var $Hann_DASH_check_DASH_temp36373170 = function(ann_DASH_check_DASH_temp21333169) {
return ann_DASH_check_DASH_temp21333169;
};
var $Hanf_arg36363189 = function(anf_arg21423188,A136,a_DASH_import_DASH_types135429,dummy_DASH_loc115391,name5163176,types5173177) {
var anf_fun21439575 = G(name5163176,"visit",L[1366]);
var anf_arg21449576 = G(A136,"dummy-loc-visitor",L[1365]);
var $z95679568 = D;
var $f95739574 = function(_) {
return R.isFunction(anf_fun21439575)?anf_fun21439575.app(anf_arg21449576):R.ffi.throwNonFunApp(L[1364],anf_fun21439575,[anf_arg21449576]);
};
try {
if(--R.GAS > 0) {
$z95679568 = $f95739574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95739574,
"from":L[1364]});
}
} catch($e95659566) {
if(R.isCont($e95659566)) {
var $ss95699570 = {"from":L[1364],
"go":function(anf_arg21459577) {
return $Hanf_arg36359578(anf_arg21459577,A136,a_DASH_import_DASH_types135429,anf_arg21423188,dummy_DASH_loc115391,types5173177);
}};
$e95659566.stack[R.EXN_STACKHEIGHT++] = $ss95699570;
}
if(R.isPyretException($e95659566)) {
$e95659566.pyretStack.push(L[1364]);
}
throw $e95659566;
}
var $ret95719572 = $Hanf_arg36359578($z95679568,A136,a_DASH_import_DASH_types135429,anf_arg21423188,dummy_DASH_loc115391,types5173177);
++R.GAS;
return $ret95719572;
};
var $Hanf_arg36359578 = function(anf_arg21459577,A136,a_DASH_import_DASH_types135429,anf_arg21423188,dummy_DASH_loc115391,types5173177) {
var anf_fun21469589 = G(types5173177,"visit",L[1369]);
var anf_arg21479590 = G(A136,"dummy-loc-visitor",L[1368]);
var $z95819582 = D;
var $f95879588 = function(_) {
return R.isFunction(anf_fun21469589)?anf_fun21469589.app(anf_arg21479590):R.ffi.throwNonFunApp(L[1367],anf_fun21469589,[anf_arg21479590]);
};
try {
if(--R.GAS > 0) {
$z95819582 = $f95879588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95879588,
"from":L[1367]});
}
} catch($e95799580) {
if(R.isCont($e95799580)) {
var $ss95839584 = {"from":L[1367],
"go":function(anf_arg21489591) {
return $Hanf_arg36349592(anf_arg21489591,a_DASH_import_DASH_types135429,anf_arg21423188,anf_arg21459577,dummy_DASH_loc115391);
}};
$e95799580.stack[R.EXN_STACKHEIGHT++] = $ss95839584;
}
if(R.isPyretException($e95799580)) {
$e95799580.pyretStack.push(L[1367]);
}
throw $e95799580;
}
var $ret95859586 = $Hanf_arg36349592($z95819582,a_DASH_import_DASH_types135429,anf_arg21423188,anf_arg21459577,dummy_DASH_loc115391);
++R.GAS;
return $ret95859586;
};
var $Hanf_arg36349592 = function(anf_arg21489591,a_DASH_import_DASH_types135429,anf_arg21423188,anf_arg21459577,dummy_DASH_loc115391) {
var $z95959596 = D;
var $f96019602 = function(_) {
return R.isFunction(a_DASH_import_DASH_types135429.$var)?a_DASH_import_DASH_types135429.$var.app(dummy_DASH_loc115391,anf_arg21423188,anf_arg21459577,anf_arg21489591):R.ffi.throwNonFunApp(L[514],a_DASH_import_DASH_types135429.$var,[dummy_DASH_loc115391,anf_arg21423188,anf_arg21459577,anf_arg21489591]);
};
try {
if(--R.GAS > 0) {
$z95959596 = $f96019602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96019602,
"from":L[514]});
}
} catch($e95939594) {
if(R.isCont($e95939594)) {
var $ss95979598 = {"from":L[514],
"go":function(ann_DASH_check_DASH_temp21419603) {
return $Hann_DASH_check_DASH_temp36339604(ann_DASH_check_DASH_temp21419603);
}};
$e95939594.stack[R.EXN_STACKHEIGHT++] = $ss95979598;
}
if(R.isPyretException($e95939594)) {
$e95939594.pyretStack.push(L[514]);
}
throw $e95939594;
}
var $ret95999600 = $Hann_DASH_check_DASH_temp36339604($z95959596);
++R.GAS;
return $ret95999600;
};
var $Hann_DASH_check_DASH_temp36339604 = function(ann_DASH_check_DASH_temp21419603) {
return ann_DASH_check_DASH_temp21419603;
};
var $Hanf_arg36323204 = function(anf_arg21363203,A136,a_DASH_import133425,dummy_DASH_loc115391,name5133192) {
var anf_fun21379615 = G(name5133192,"visit",L[1372]);
var anf_arg21389616 = G(A136,"dummy-loc-visitor",L[1371]);
var $z96079608 = D;
var $f96139614 = function(_) {
return R.isFunction(anf_fun21379615)?anf_fun21379615.app(anf_arg21389616):R.ffi.throwNonFunApp(L[1370],anf_fun21379615,[anf_arg21389616]);
};
try {
if(--R.GAS > 0) {
$z96079608 = $f96139614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96139614,
"from":L[1370]});
}
} catch($e96059606) {
if(R.isCont($e96059606)) {
var $ss96099610 = {"from":L[1370],
"go":function(anf_arg21399617) {
return $Hanf_arg36319618(anf_arg21399617,a_DASH_import133425,anf_arg21363203,dummy_DASH_loc115391);
}};
$e96059606.stack[R.EXN_STACKHEIGHT++] = $ss96099610;
}
if(R.isPyretException($e96059606)) {
$e96059606.pyretStack.push(L[1370]);
}
throw $e96059606;
}
var $ret96119612 = $Hanf_arg36319618($z96079608,a_DASH_import133425,anf_arg21363203,dummy_DASH_loc115391);
++R.GAS;
return $ret96119612;
};
var $Hanf_arg36319618 = function(anf_arg21399617,a_DASH_import133425,anf_arg21363203,dummy_DASH_loc115391) {
var $z96219622 = D;
var $f96279628 = function(_) {
return R.isFunction(a_DASH_import133425.$var)?a_DASH_import133425.$var.app(dummy_DASH_loc115391,anf_arg21363203,anf_arg21399617):R.ffi.throwNonFunApp(L[517],a_DASH_import133425.$var,[dummy_DASH_loc115391,anf_arg21363203,anf_arg21399617]);
};
try {
if(--R.GAS > 0) {
$z96219622 = $f96279628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96279628,
"from":L[517]});
}
} catch($e96199620) {
if(R.isCont($e96199620)) {
var $ss96239624 = {"from":L[517],
"go":function(ann_DASH_check_DASH_temp21359629) {
return $Hann_DASH_check_DASH_temp36309630(ann_DASH_check_DASH_temp21359629);
}};
$e96199620.stack[R.EXN_STACKHEIGHT++] = $ss96239624;
}
if(R.isPyretException($e96199620)) {
$e96199620.pyretStack.push(L[517]);
}
throw $e96199620;
}
var $ret96259626 = $Hann_DASH_check_DASH_temp36309630($z96219622);
++R.GAS;
return $ret96259626;
};
var $Hann_DASH_check_DASH_temp36309630 = function(ann_DASH_check_DASH_temp21359629) {
return ann_DASH_check_DASH_temp21359629;
};
var $Hann_DASH_check_DASH_temp36293221 = function(ann_DASH_check_DASH_temp21223220) {
return ann_DASH_check_DASH_temp21223220;
};
var $Hanf_arg36283239 = function(anf_arg21263238,a_DASH_program121401,body5093226,dummy_DASH_loc115391,strip_DASH_loc_DASH_expr249657) {
var $z96339634 = D;
var $f96399640 = function(_) {
return R.isFunction(strip_DASH_loc_DASH_expr249657.$var === D?U(L[1373],"strip-loc-expr"):strip_DASH_loc_DASH_expr249657.$var)?strip_DASH_loc_DASH_expr249657.$var === D?U(L[1373],"strip-loc-expr"):strip_DASH_loc_DASH_expr249657.$var.app(body5093226):R.ffi.throwNonFunApp(L[1373],strip_DASH_loc_DASH_expr249657.$var === D?U(L[1373],"strip-loc-expr"):strip_DASH_loc_DASH_expr249657.$var,[body5093226]);
};
try {
if(--R.GAS > 0) {
$z96339634 = $f96399640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96399640,
"from":L[1373]});
}
} catch($e96319632) {
if(R.isCont($e96319632)) {
var $ss96359636 = {"from":L[1373],
"go":function(anf_arg21279641) {
return $Hanf_arg36279642(anf_arg21279641,a_DASH_program121401,anf_arg21263238,dummy_DASH_loc115391);
}};
$e96319632.stack[R.EXN_STACKHEIGHT++] = $ss96359636;
}
if(R.isPyretException($e96319632)) {
$e96319632.pyretStack.push(L[1373]);
}
throw $e96319632;
}
var $ret96379638 = $Hanf_arg36279642($z96339634,a_DASH_program121401,anf_arg21263238,dummy_DASH_loc115391);
++R.GAS;
return $ret96379638;
};
var $Hanf_arg36279642 = function(anf_arg21279641,a_DASH_program121401,anf_arg21263238,dummy_DASH_loc115391) {
var $z96459646 = D;
var $f96519652 = function(_) {
return R.isFunction(a_DASH_program121401.$var)?a_DASH_program121401.$var.app(dummy_DASH_loc115391,anf_arg21263238,anf_arg21279641):R.ffi.throwNonFunApp(L[523],a_DASH_program121401.$var,[dummy_DASH_loc115391,anf_arg21263238,anf_arg21279641]);
};
try {
if(--R.GAS > 0) {
$z96459646 = $f96519652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96519652,
"from":L[523]});
}
} catch($e96439644) {
if(R.isCont($e96439644)) {
var $ss96479648 = {"from":L[523],
"go":function(ann_DASH_check_DASH_temp21249653) {
return $Hann_DASH_check_DASH_temp36269654(ann_DASH_check_DASH_temp21249653);
}};
$e96439644.stack[R.EXN_STACKHEIGHT++] = $ss96479648;
}
if(R.isPyretException($e96439644)) {
$e96439644.pyretStack.push(L[523]);
}
throw $e96439644;
}
var $ret96499650 = $Hann_DASH_check_DASH_temp36269654($z96459646);
++R.GAS;
return $ret96499650;
};
var $Hann_DASH_check_DASH_temp36269654 = function(ann_DASH_check_DASH_temp21249653) {
return ann_DASH_check_DASH_temp21249653;
};
var $Hanf_arg36253354 = function(anf_arg20983352,anf_fun20953353,_plus26) {
var $z96579658 = D;
var $f96639664 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("~"),anf_arg20983352):R.ffi.throwNonFunApp(L[1374],_plus26,[("~"),anf_arg20983352]);
};
try {
if(--R.GAS > 0) {
$z96579658 = $f96639664();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96639664,
"from":L[1374]});
}
} catch($e96559656) {
if(R.isCont($e96559656)) {
var $ss96599660 = {"from":L[1374],
"go":function(anf_arg20999665) {
return $Hanf_arg36249666(anf_arg20999665,anf_fun20953353);
}};
$e96559656.stack[R.EXN_STACKHEIGHT++] = $ss96599660;
}
if(R.isPyretException($e96559656)) {
$e96559656.pyretStack.push(L[1374]);
}
throw $e96559656;
}
var $ret96619662 = $Hanf_arg36249666($z96579658,anf_fun20953353);
++R.GAS;
return $ret96619662;
};
var $Hanf_arg36249666 = function(anf_arg20999665,anf_fun20953353) {
var $z96699670 = D;
var $f96759676 = function(_) {
return R.isFunction(anf_fun20953353)?anf_fun20953353.app(anf_arg20999665):R.ffi.throwNonFunApp(L[569],anf_fun20953353,[anf_arg20999665]);
};
try {
if(--R.GAS > 0) {
$z96699670 = $f96759676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96759676,
"from":L[569]});
}
} catch($e96679668) {
if(R.isCont($e96679668)) {
var $ss96719672 = {"from":L[569],
"go":function(ann_DASH_check_DASH_temp20949677) {
return $Hann_DASH_check_DASH_temp36239678(ann_DASH_check_DASH_temp20949677);
}};
$e96679668.stack[R.EXN_STACKHEIGHT++] = $ss96719672;
}
if(R.isPyretException($e96679668)) {
$e96679668.pyretStack.push(L[569]);
}
throw $e96679668;
}
var $ret96739674 = $Hann_DASH_check_DASH_temp36239678($z96699670);
++R.GAS;
return $ret96739674;
};
var $Hann_DASH_check_DASH_temp36239678 = function(ann_DASH_check_DASH_temp20949677) {
return ann_DASH_check_DASH_temp20949677;
};
var $Hanf_arg36223372 = function(anf_arg20803370,self2783371,_plus26,torepr31) {
var anf_arg20819689 = G(self2783371,"id",L[528]);
var $z96819682 = D;
var $f96879688 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg20819689):R.ffi.throwNonFunApp(L[528],torepr31,[anf_arg20819689]);
};
try {
if(--R.GAS > 0) {
$z96819682 = $f96879688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96879688,
"from":L[528]});
}
} catch($e96799680) {
if(R.isCont($e96799680)) {
var $ss96839684 = {"from":L[528],
"go":function(anf_arg20829690) {
return $Hanf_arg36219691(anf_arg20829690,anf_arg20803370,self2783371,_plus26,torepr31);
}};
$e96799680.stack[R.EXN_STACKHEIGHT++] = $ss96839684;
}
if(R.isPyretException($e96799680)) {
$e96799680.pyretStack.push(L[528]);
}
throw $e96799680;
}
var $ret96859686 = $Hanf_arg36219691($z96819682,anf_arg20803370,self2783371,_plus26,torepr31);
++R.GAS;
return $ret96859686;
};
var $Hanf_arg36219691 = function(anf_arg20829690,anf_arg20803370,self2783371,_plus26,torepr31) {
var $z96949695 = D;
var $f97009701 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg20829690):R.ffi.throwNonFunApp(L[528],_plus26,[(", "),anf_arg20829690]);
};
try {
if(--R.GAS > 0) {
$z96949695 = $f97009701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97009701,
"from":L[528]});
}
} catch($e96929693) {
if(R.isCont($e96929693)) {
var $ss96969697 = {"from":L[528],
"go":function(anf_arg20839702) {
return $Hanf_arg36209703(anf_arg20839702,anf_arg20803370,self2783371,_plus26,torepr31);
}};
$e96929693.stack[R.EXN_STACKHEIGHT++] = $ss96969697;
}
if(R.isPyretException($e96929693)) {
$e96929693.pyretStack.push(L[528]);
}
throw $e96929693;
}
var $ret96989699 = $Hanf_arg36209703($z96949695,anf_arg20803370,self2783371,_plus26,torepr31);
++R.GAS;
return $ret96989699;
};
var $Hanf_arg36209703 = function(anf_arg20839702,anf_arg20803370,self2783371,_plus26,torepr31) {
var $z97069707 = D;
var $f97129713 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg20803370,anf_arg20839702):R.ffi.throwNonFunApp(L[528],_plus26,[anf_arg20803370,anf_arg20839702]);
};
try {
if(--R.GAS > 0) {
$z97069707 = $f97129713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97129713,
"from":L[528]});
}
} catch($e97049705) {
if(R.isCont($e97049705)) {
var $ss97089709 = {"from":L[528],
"go":function(anf_arg20849714) {
return $Hanf_arg36199715(anf_arg20849714,self2783371,_plus26,torepr31);
}};
$e97049705.stack[R.EXN_STACKHEIGHT++] = $ss97089709;
}
if(R.isPyretException($e97049705)) {
$e97049705.pyretStack.push(L[528]);
}
throw $e97049705;
}
var $ret97109711 = $Hanf_arg36199715($z97069707,self2783371,_plus26,torepr31);
++R.GAS;
return $ret97109711;
};
var $Hanf_arg36199715 = function(anf_arg20849714,self2783371,_plus26,torepr31) {
var anf_arg20859726 = G(self2783371,"safe",L[528]);
var $z97189719 = D;
var $f97249725 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg20859726):R.ffi.throwNonFunApp(L[528],torepr31,[anf_arg20859726]);
};
try {
if(--R.GAS > 0) {
$z97189719 = $f97249725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97249725,
"from":L[528]});
}
} catch($e97169717) {
if(R.isCont($e97169717)) {
var $ss97209721 = {"from":L[528],
"go":function(anf_arg20869727) {
return $Hanf_arg36189728(anf_arg20869727,anf_arg20849714,_plus26);
}};
$e97169717.stack[R.EXN_STACKHEIGHT++] = $ss97209721;
}
if(R.isPyretException($e97169717)) {
$e97169717.pyretStack.push(L[528]);
}
throw $e97169717;
}
var $ret97229723 = $Hanf_arg36189728($z97189719,anf_arg20849714,_plus26);
++R.GAS;
return $ret97229723;
};
var $Hanf_arg36189728 = function(anf_arg20869727,anf_arg20849714,_plus26) {
var $z97319732 = D;
var $f97379738 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg20869727):R.ffi.throwNonFunApp(L[528],_plus26,[(", "),anf_arg20869727]);
};
try {
if(--R.GAS > 0) {
$z97319732 = $f97379738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97379738,
"from":L[528]});
}
} catch($e97299730) {
if(R.isCont($e97299730)) {
var $ss97339734 = {"from":L[528],
"go":function(anf_arg20879739) {
return $Hanf_arg36179740(anf_arg20879739,anf_arg20849714,_plus26);
}};
$e97299730.stack[R.EXN_STACKHEIGHT++] = $ss97339734;
}
if(R.isPyretException($e97299730)) {
$e97299730.pyretStack.push(L[528]);
}
throw $e97299730;
}
var $ret97359736 = $Hanf_arg36179740($z97319732,anf_arg20849714,_plus26);
++R.GAS;
return $ret97359736;
};
var $Hanf_arg36179740 = function(anf_arg20879739,anf_arg20849714,_plus26) {
var $z97439744 = D;
var $f97499750 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg20849714,anf_arg20879739):R.ffi.throwNonFunApp(L[528],_plus26,[anf_arg20849714,anf_arg20879739]);
};
try {
if(--R.GAS > 0) {
$z97439744 = $f97499750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97499750,
"from":L[528]});
}
} catch($e97419742) {
if(R.isCont($e97419742)) {
var $ss97459746 = {"from":L[528],
"go":function(anf_arg20889751) {
return $Hanf_arg36169752(anf_arg20889751,_plus26);
}};
$e97419742.stack[R.EXN_STACKHEIGHT++] = $ss97459746;
}
if(R.isPyretException($e97419742)) {
$e97419742.pyretStack.push(L[528]);
}
throw $e97419742;
}
var $ret97479748 = $Hanf_arg36169752($z97439744,_plus26);
++R.GAS;
return $ret97479748;
};
var $Hanf_arg36169752 = function(anf_arg20889751,_plus26) {
var $z97559756 = D;
var $f97619762 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg20889751,(")")):R.ffi.throwNonFunApp(L[528],_plus26,[anf_arg20889751,(")")]);
};
try {
if(--R.GAS > 0) {
$z97559756 = $f97619762();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97619762,
"from":L[528]});
}
} catch($e97539754) {
if(R.isCont($e97539754)) {
var $ss97579758 = {"from":L[528],
"go":function(anf_arg20899763) {
return $Hanf_arg36159764(anf_arg20899763,_plus26);
}};
$e97539754.stack[R.EXN_STACKHEIGHT++] = $ss97579758;
}
if(R.isPyretException($e97539754)) {
$e97539754.pyretStack.push(L[528]);
}
throw $e97539754;
}
var $ret97599760 = $Hanf_arg36159764($z97559756,_plus26);
++R.GAS;
return $ret97599760;
};
var $Hanf_arg36159764 = function(anf_arg20899763,_plus26) {
var $z97679768 = D;
var $f97739774 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg20899763):R.ffi.throwNonFunApp(L[528],_plus26,[("("),anf_arg20899763]);
};
try {
if(--R.GAS > 0) {
$z97679768 = $f97739774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97739774,
"from":L[528]});
}
} catch($e97659766) {
if(R.isCont($e97659766)) {
var $ss97699770 = {"from":L[528],
"go":function(anf_arg20909775) {
return $Hanf_arg36149776(anf_arg20909775,_plus26);
}};
$e97659766.stack[R.EXN_STACKHEIGHT++] = $ss97699770;
}
if(R.isPyretException($e97659766)) {
$e97659766.pyretStack.push(L[528]);
}
throw $e97659766;
}
var $ret97719772 = $Hanf_arg36149776($z97679768,_plus26);
++R.GAS;
return $ret97719772;
};
var $Hanf_arg36149776 = function(anf_arg20909775,_plus26) {
var $z97799780 = D;
var $f97859786 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-id-letrec"),anf_arg20909775):R.ffi.throwNonFunApp(L[528],_plus26,[("a-id-letrec"),anf_arg20909775]);
};
try {
if(--R.GAS > 0) {
$z97799780 = $f97859786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97859786,
"from":L[528]});
}
} catch($e97779778) {
if(R.isCont($e97779778)) {
var $ss97819782 = {"from":L[528],
"go":function(ann_DASH_check_DASH_temp20789787) {
return $Hann_DASH_check_DASH_temp36139788(ann_DASH_check_DASH_temp20789787);
}};
$e97779778.stack[R.EXN_STACKHEIGHT++] = $ss97819782;
}
if(R.isPyretException($e97779778)) {
$e97779778.pyretStack.push(L[528]);
}
throw $e97779778;
}
var $ret97839784 = $Hann_DASH_check_DASH_temp36139788($z97799780);
++R.GAS;
return $ret97839784;
};
var $Hann_DASH_check_DASH_temp36139788 = function(ann_DASH_check_DASH_temp20789787) {
return ann_DASH_check_DASH_temp20789787;
};
var $Hcont_tail_arg36113389 = function(cont_tail_arg20753387,if_helper20653388) {
if(--R.GAS > 0) {
$z97899790 = R.isFunction(if_helper20653388)?if_helper20653388.app(cont_tail_arg20753387):R.ffi.throwNonFunApp(L[528],if_helper20653388,[cont_tail_arg20753387]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20653388)?if_helper20653388.app(cont_tail_arg20753387):R.ffi.throwNonFunApp(L[528],if_helper20653388,[cont_tail_arg20753387]);
},
"from":L[528]});
}
++R.GAS;
return $z97899790;
};
var $Hcont_tail_arg36123404 = function(cont_tail_arg20703403,if_helper20653388) {
if(--R.GAS > 0) {
$z97919792 = R.isFunction(if_helper20653388)?if_helper20653388.app(cont_tail_arg20703403):R.ffi.throwNonFunApp(L[528],if_helper20653388,[cont_tail_arg20703403]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20653388)?if_helper20653388.app(cont_tail_arg20703403):R.ffi.throwNonFunApp(L[528],if_helper20653388,[cont_tail_arg20703403]);
},
"from":L[528]});
}
++R.GAS;
return $z97919792;
};
var $Hanf_arg36103426 = function(anf_arg20613424,anf_fun20583425,_plus26) {
var $z97959796 = D;
var $f98019802 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("!"),anf_arg20613424):R.ffi.throwNonFunApp(L[1375],_plus26,[("!"),anf_arg20613424]);
};
try {
if(--R.GAS > 0) {
$z97959796 = $f98019802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98019802,
"from":L[1375]});
}
} catch($e97939794) {
if(R.isCont($e97939794)) {
var $ss97979798 = {"from":L[1375],
"go":function(anf_arg20629803) {
return $Hanf_arg36099804(anf_arg20629803,anf_fun20583425);
}};
$e97939794.stack[R.EXN_STACKHEIGHT++] = $ss97979798;
}
if(R.isPyretException($e97939794)) {
$e97939794.pyretStack.push(L[1375]);
}
throw $e97939794;
}
var $ret97999800 = $Hanf_arg36099804($z97959796,anf_fun20583425);
++R.GAS;
return $ret97999800;
};
var $Hanf_arg36099804 = function(anf_arg20629803,anf_fun20583425) {
var $z98079808 = D;
var $f98139814 = function(_) {
return R.isFunction(anf_fun20583425)?anf_fun20583425.app(anf_arg20629803):R.ffi.throwNonFunApp(L[578],anf_fun20583425,[anf_arg20629803]);
};
try {
if(--R.GAS > 0) {
$z98079808 = $f98139814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98139814,
"from":L[578]});
}
} catch($e98059806) {
if(R.isCont($e98059806)) {
var $ss98099810 = {"from":L[578],
"go":function(ann_DASH_check_DASH_temp20579815) {
return $Hann_DASH_check_DASH_temp36089816(ann_DASH_check_DASH_temp20579815);
}};
$e98059806.stack[R.EXN_STACKHEIGHT++] = $ss98099810;
}
if(R.isPyretException($e98059806)) {
$e98059806.pyretStack.push(L[578]);
}
throw $e98059806;
}
var $ret98119812 = $Hann_DASH_check_DASH_temp36089816($z98079808);
++R.GAS;
return $ret98119812;
};
var $Hann_DASH_check_DASH_temp36089816 = function(ann_DASH_check_DASH_temp20579815) {
return ann_DASH_check_DASH_temp20579815;
};
var $Hanf_arg36073444 = function(anf_arg20473442,self2723443,_plus26,torepr31) {
var anf_arg20489827 = G(self2723443,"id",L[529]);
var $z98199820 = D;
var $f98259826 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg20489827):R.ffi.throwNonFunApp(L[529],torepr31,[anf_arg20489827]);
};
try {
if(--R.GAS > 0) {
$z98199820 = $f98259826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98259826,
"from":L[529]});
}
} catch($e98179818) {
if(R.isCont($e98179818)) {
var $ss98219822 = {"from":L[529],
"go":function(anf_arg20499828) {
return $Hanf_arg36069829(anf_arg20499828,anf_arg20473442,_plus26);
}};
$e98179818.stack[R.EXN_STACKHEIGHT++] = $ss98219822;
}
if(R.isPyretException($e98179818)) {
$e98179818.pyretStack.push(L[529]);
}
throw $e98179818;
}
var $ret98239824 = $Hanf_arg36069829($z98199820,anf_arg20473442,_plus26);
++R.GAS;
return $ret98239824;
};
var $Hanf_arg36069829 = function(anf_arg20499828,anf_arg20473442,_plus26) {
var $z98329833 = D;
var $f98389839 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg20499828):R.ffi.throwNonFunApp(L[529],_plus26,[(", "),anf_arg20499828]);
};
try {
if(--R.GAS > 0) {
$z98329833 = $f98389839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98389839,
"from":L[529]});
}
} catch($e98309831) {
if(R.isCont($e98309831)) {
var $ss98349835 = {"from":L[529],
"go":function(anf_arg20509840) {
return $Hanf_arg36059841(anf_arg20509840,anf_arg20473442,_plus26);
}};
$e98309831.stack[R.EXN_STACKHEIGHT++] = $ss98349835;
}
if(R.isPyretException($e98309831)) {
$e98309831.pyretStack.push(L[529]);
}
throw $e98309831;
}
var $ret98369837 = $Hanf_arg36059841($z98329833,anf_arg20473442,_plus26);
++R.GAS;
return $ret98369837;
};
var $Hanf_arg36059841 = function(anf_arg20509840,anf_arg20473442,_plus26) {
var $z98449845 = D;
var $f98509851 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg20473442,anf_arg20509840):R.ffi.throwNonFunApp(L[529],_plus26,[anf_arg20473442,anf_arg20509840]);
};
try {
if(--R.GAS > 0) {
$z98449845 = $f98509851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98509851,
"from":L[529]});
}
} catch($e98429843) {
if(R.isCont($e98429843)) {
var $ss98469847 = {"from":L[529],
"go":function(anf_arg20519852) {
return $Hanf_arg36049853(anf_arg20519852,_plus26);
}};
$e98429843.stack[R.EXN_STACKHEIGHT++] = $ss98469847;
}
if(R.isPyretException($e98429843)) {
$e98429843.pyretStack.push(L[529]);
}
throw $e98429843;
}
var $ret98489849 = $Hanf_arg36049853($z98449845,_plus26);
++R.GAS;
return $ret98489849;
};
var $Hanf_arg36049853 = function(anf_arg20519852,_plus26) {
var $z98569857 = D;
var $f98629863 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg20519852,(")")):R.ffi.throwNonFunApp(L[529],_plus26,[anf_arg20519852,(")")]);
};
try {
if(--R.GAS > 0) {
$z98569857 = $f98629863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98629863,
"from":L[529]});
}
} catch($e98549855) {
if(R.isCont($e98549855)) {
var $ss98589859 = {"from":L[529],
"go":function(anf_arg20529864) {
return $Hanf_arg36039865(anf_arg20529864,_plus26);
}};
$e98549855.stack[R.EXN_STACKHEIGHT++] = $ss98589859;
}
if(R.isPyretException($e98549855)) {
$e98549855.pyretStack.push(L[529]);
}
throw $e98549855;
}
var $ret98609861 = $Hanf_arg36039865($z98569857,_plus26);
++R.GAS;
return $ret98609861;
};
var $Hanf_arg36039865 = function(anf_arg20529864,_plus26) {
var $z98689869 = D;
var $f98749875 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg20529864):R.ffi.throwNonFunApp(L[529],_plus26,[("("),anf_arg20529864]);
};
try {
if(--R.GAS > 0) {
$z98689869 = $f98749875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98749875,
"from":L[529]});
}
} catch($e98669867) {
if(R.isCont($e98669867)) {
var $ss98709871 = {"from":L[529],
"go":function(anf_arg20539876) {
return $Hanf_arg36029877(anf_arg20539876,_plus26);
}};
$e98669867.stack[R.EXN_STACKHEIGHT++] = $ss98709871;
}
if(R.isPyretException($e98669867)) {
$e98669867.pyretStack.push(L[529]);
}
throw $e98669867;
}
var $ret98729873 = $Hanf_arg36029877($z98689869,_plus26);
++R.GAS;
return $ret98729873;
};
var $Hanf_arg36029877 = function(anf_arg20539876,_plus26) {
var $z98809881 = D;
var $f98869887 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-id-var"),anf_arg20539876):R.ffi.throwNonFunApp(L[529],_plus26,[("a-id-var"),anf_arg20539876]);
};
try {
if(--R.GAS > 0) {
$z98809881 = $f98869887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98869887,
"from":L[529]});
}
} catch($e98789879) {
if(R.isCont($e98789879)) {
var $ss98829883 = {"from":L[529],
"go":function(ann_DASH_check_DASH_temp20459888) {
return $Hann_DASH_check_DASH_temp36019889(ann_DASH_check_DASH_temp20459888);
}};
$e98789879.stack[R.EXN_STACKHEIGHT++] = $ss98829883;
}
if(R.isPyretException($e98789879)) {
$e98789879.pyretStack.push(L[529]);
}
throw $e98789879;
}
var $ret98849885 = $Hann_DASH_check_DASH_temp36019889($z98809881);
++R.GAS;
return $ret98849885;
};
var $Hann_DASH_check_DASH_temp36019889 = function(ann_DASH_check_DASH_temp20459888) {
return ann_DASH_check_DASH_temp20459888;
};
var $Hcont_tail_arg35993460 = function(cont_tail_arg20423458,if_helper20333459) {
if(--R.GAS > 0) {
$z98909891 = R.isFunction(if_helper20333459)?if_helper20333459.app(cont_tail_arg20423458):R.ffi.throwNonFunApp(L[529],if_helper20333459,[cont_tail_arg20423458]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20333459)?if_helper20333459.app(cont_tail_arg20423458):R.ffi.throwNonFunApp(L[529],if_helper20333459,[cont_tail_arg20423458]);
},
"from":L[529]});
}
++R.GAS;
return $z98909891;
};
var $Hcont_tail_arg36003475 = function(cont_tail_arg20383474,if_helper20333459) {
if(--R.GAS > 0) {
$z98929893 = R.isFunction(if_helper20333459)?if_helper20333459.app(cont_tail_arg20383474):R.ffi.throwNonFunApp(L[529],if_helper20333459,[cont_tail_arg20383474]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20333459)?if_helper20333459.app(cont_tail_arg20383474):R.ffi.throwNonFunApp(L[529],if_helper20333459,[cont_tail_arg20383474]);
},
"from":L[529]});
}
++R.GAS;
return $z98929893;
};
var $Hanf_arg35983496 = function(anf_arg20303494,anf_fun20273495) {
var $z98969897 = D;
var $f99029903 = function(_) {
return R.isFunction(anf_fun20273495)?anf_fun20273495.app(anf_arg20303494):R.ffi.throwNonFunApp(L[586],anf_fun20273495,[anf_arg20303494]);
};
try {
if(--R.GAS > 0) {
$z98969897 = $f99029903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99029903,
"from":L[586]});
}
} catch($e98949895) {
if(R.isCont($e98949895)) {
var $ss98989899 = {"from":L[586],
"go":function(ann_DASH_check_DASH_temp20269904) {
return $Hann_DASH_check_DASH_temp35979905(ann_DASH_check_DASH_temp20269904);
}};
$e98949895.stack[R.EXN_STACKHEIGHT++] = $ss98989899;
}
if(R.isPyretException($e98949895)) {
$e98949895.pyretStack.push(L[586]);
}
throw $e98949895;
}
var $ret99009901 = $Hann_DASH_check_DASH_temp35979905($z98969897);
++R.GAS;
return $ret99009901;
};
var $Hann_DASH_check_DASH_temp35979905 = function(ann_DASH_check_DASH_temp20269904) {
return ann_DASH_check_DASH_temp20269904;
};
var $Hanf_arg35963514 = function(anf_arg20163512,self2663513,_plus26,torepr31) {
var anf_arg20179916 = G(self2663513,"id",L[530]);
var $z99089909 = D;
var $f99149915 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg20179916):R.ffi.throwNonFunApp(L[530],torepr31,[anf_arg20179916]);
};
try {
if(--R.GAS > 0) {
$z99089909 = $f99149915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99149915,
"from":L[530]});
}
} catch($e99069907) {
if(R.isCont($e99069907)) {
var $ss99109911 = {"from":L[530],
"go":function(anf_arg20189917) {
return $Hanf_arg35959918(anf_arg20189917,anf_arg20163512,_plus26);
}};
$e99069907.stack[R.EXN_STACKHEIGHT++] = $ss99109911;
}
if(R.isPyretException($e99069907)) {
$e99069907.pyretStack.push(L[530]);
}
throw $e99069907;
}
var $ret99129913 = $Hanf_arg35959918($z99089909,anf_arg20163512,_plus26);
++R.GAS;
return $ret99129913;
};
var $Hanf_arg35959918 = function(anf_arg20189917,anf_arg20163512,_plus26) {
var $z99219922 = D;
var $f99279928 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg20189917):R.ffi.throwNonFunApp(L[530],_plus26,[(", "),anf_arg20189917]);
};
try {
if(--R.GAS > 0) {
$z99219922 = $f99279928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99279928,
"from":L[530]});
}
} catch($e99199920) {
if(R.isCont($e99199920)) {
var $ss99239924 = {"from":L[530],
"go":function(anf_arg20199929) {
return $Hanf_arg35949930(anf_arg20199929,anf_arg20163512,_plus26);
}};
$e99199920.stack[R.EXN_STACKHEIGHT++] = $ss99239924;
}
if(R.isPyretException($e99199920)) {
$e99199920.pyretStack.push(L[530]);
}
throw $e99199920;
}
var $ret99259926 = $Hanf_arg35949930($z99219922,anf_arg20163512,_plus26);
++R.GAS;
return $ret99259926;
};
var $Hanf_arg35949930 = function(anf_arg20199929,anf_arg20163512,_plus26) {
var $z99339934 = D;
var $f99399940 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg20163512,anf_arg20199929):R.ffi.throwNonFunApp(L[530],_plus26,[anf_arg20163512,anf_arg20199929]);
};
try {
if(--R.GAS > 0) {
$z99339934 = $f99399940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99399940,
"from":L[530]});
}
} catch($e99319932) {
if(R.isCont($e99319932)) {
var $ss99359936 = {"from":L[530],
"go":function(anf_arg20209941) {
return $Hanf_arg35939942(anf_arg20209941,_plus26);
}};
$e99319932.stack[R.EXN_STACKHEIGHT++] = $ss99359936;
}
if(R.isPyretException($e99319932)) {
$e99319932.pyretStack.push(L[530]);
}
throw $e99319932;
}
var $ret99379938 = $Hanf_arg35939942($z99339934,_plus26);
++R.GAS;
return $ret99379938;
};
var $Hanf_arg35939942 = function(anf_arg20209941,_plus26) {
var $z99459946 = D;
var $f99519952 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg20209941,(")")):R.ffi.throwNonFunApp(L[530],_plus26,[anf_arg20209941,(")")]);
};
try {
if(--R.GAS > 0) {
$z99459946 = $f99519952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99519952,
"from":L[530]});
}
} catch($e99439944) {
if(R.isCont($e99439944)) {
var $ss99479948 = {"from":L[530],
"go":function(anf_arg20219953) {
return $Hanf_arg35929954(anf_arg20219953,_plus26);
}};
$e99439944.stack[R.EXN_STACKHEIGHT++] = $ss99479948;
}
if(R.isPyretException($e99439944)) {
$e99439944.pyretStack.push(L[530]);
}
throw $e99439944;
}
var $ret99499950 = $Hanf_arg35929954($z99459946,_plus26);
++R.GAS;
return $ret99499950;
};
var $Hanf_arg35929954 = function(anf_arg20219953,_plus26) {
var $z99579958 = D;
var $f99639964 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg20219953):R.ffi.throwNonFunApp(L[530],_plus26,[("("),anf_arg20219953]);
};
try {
if(--R.GAS > 0) {
$z99579958 = $f99639964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99639964,
"from":L[530]});
}
} catch($e99559956) {
if(R.isCont($e99559956)) {
var $ss99599960 = {"from":L[530],
"go":function(anf_arg20229965) {
return $Hanf_arg35919966(anf_arg20229965,_plus26);
}};
$e99559956.stack[R.EXN_STACKHEIGHT++] = $ss99599960;
}
if(R.isPyretException($e99559956)) {
$e99559956.pyretStack.push(L[530]);
}
throw $e99559956;
}
var $ret99619962 = $Hanf_arg35919966($z99579958,_plus26);
++R.GAS;
return $ret99619962;
};
var $Hanf_arg35919966 = function(anf_arg20229965,_plus26) {
var $z99699970 = D;
var $f99759976 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-id"),anf_arg20229965):R.ffi.throwNonFunApp(L[530],_plus26,[("a-id"),anf_arg20229965]);
};
try {
if(--R.GAS > 0) {
$z99699970 = $f99759976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99759976,
"from":L[530]});
}
} catch($e99679968) {
if(R.isCont($e99679968)) {
var $ss99719972 = {"from":L[530],
"go":function(ann_DASH_check_DASH_temp20149977) {
return $Hann_DASH_check_DASH_temp35909978(ann_DASH_check_DASH_temp20149977);
}};
$e99679968.stack[R.EXN_STACKHEIGHT++] = $ss99719972;
}
if(R.isPyretException($e99679968)) {
$e99679968.pyretStack.push(L[530]);
}
throw $e99679968;
}
var $ret99739974 = $Hann_DASH_check_DASH_temp35909978($z99699970);
++R.GAS;
return $ret99739974;
};
var $Hann_DASH_check_DASH_temp35909978 = function(ann_DASH_check_DASH_temp20149977) {
return ann_DASH_check_DASH_temp20149977;
};
var $Hcont_tail_arg35883530 = function(cont_tail_arg20113528,if_helper20023529) {
if(--R.GAS > 0) {
$z99799980 = R.isFunction(if_helper20023529)?if_helper20023529.app(cont_tail_arg20113528):R.ffi.throwNonFunApp(L[530],if_helper20023529,[cont_tail_arg20113528]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20023529)?if_helper20023529.app(cont_tail_arg20113528):R.ffi.throwNonFunApp(L[530],if_helper20023529,[cont_tail_arg20113528]);
},
"from":L[530]});
}
++R.GAS;
return $z99799980;
};
var $Hcont_tail_arg35893545 = function(cont_tail_arg20073544,if_helper20023529) {
if(--R.GAS > 0) {
$z99819982 = R.isFunction(if_helper20023529)?if_helper20023529.app(cont_tail_arg20073544):R.ffi.throwNonFunApp(L[530],if_helper20023529,[cont_tail_arg20073544]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper20023529)?if_helper20023529.app(cont_tail_arg20073544):R.ffi.throwNonFunApp(L[530],if_helper20023529,[cont_tail_arg20073544]);
},
"from":L[530]});
}
++R.GAS;
return $z99819982;
};
var $Hann_DASH_check_DASH_temp35873565 = function(ann_DASH_check_DASH_temp19983564) {
return ann_DASH_check_DASH_temp19983564;
};
var $Hanf_arg35863581 = function(anf_arg19923580,_plus26) {
var $z99859986 = D;
var $f99919992 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg19923580,(")")):R.ffi.throwNonFunApp(L[531],_plus26,[anf_arg19923580,(")")]);
};
try {
if(--R.GAS > 0) {
$z99859986 = $f99919992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99919992,
"from":L[531]});
}
} catch($e99839984) {
if(R.isCont($e99839984)) {
var $ss99879988 = {"from":L[531],
"go":function(anf_arg19939993) {
return $Hanf_arg35859994(anf_arg19939993,_plus26);
}};
$e99839984.stack[R.EXN_STACKHEIGHT++] = $ss99879988;
}
if(R.isPyretException($e99839984)) {
$e99839984.pyretStack.push(L[531]);
}
throw $e99839984;
}
var $ret99899990 = $Hanf_arg35859994($z99859986,_plus26);
++R.GAS;
return $ret99899990;
};
var $Hanf_arg35859994 = function(anf_arg19939993,_plus26) {
var $z99979998 = D;
var $f1000310004 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg19939993):R.ffi.throwNonFunApp(L[531],_plus26,[("("),anf_arg19939993]);
};
try {
if(--R.GAS > 0) {
$z99979998 = $f1000310004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1000310004,
"from":L[531]});
}
} catch($e99959996) {
if(R.isCont($e99959996)) {
var $ss999910000 = {"from":L[531],
"go":function(anf_arg199410005) {
return $Hanf_arg358410006(anf_arg199410005,_plus26);
}};
$e99959996.stack[R.EXN_STACKHEIGHT++] = $ss999910000;
}
if(R.isPyretException($e99959996)) {
$e99959996.pyretStack.push(L[531]);
}
throw $e99959996;
}
var $ret1000110002 = $Hanf_arg358410006($z99979998,_plus26);
++R.GAS;
return $ret1000110002;
};
var $Hanf_arg358410006 = function(anf_arg199410005,_plus26) {
var $z1000910010 = D;
var $f1001510016 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-undefined"),anf_arg199410005):R.ffi.throwNonFunApp(L[531],_plus26,[("a-undefined"),anf_arg199410005]);
};
try {
if(--R.GAS > 0) {
$z1000910010 = $f1001510016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1001510016,
"from":L[531]});
}
} catch($e1000710008) {
if(R.isCont($e1000710008)) {
var $ss1001110012 = {"from":L[531],
"go":function(ann_DASH_check_DASH_temp199010017) {
return $Hann_DASH_check_DASH_temp358310018(ann_DASH_check_DASH_temp199010017);
}};
$e1000710008.stack[R.EXN_STACKHEIGHT++] = $ss1001110012;
}
if(R.isPyretException($e1000710008)) {
$e1000710008.pyretStack.push(L[531]);
}
throw $e1000710008;
}
var $ret1001310014 = $Hann_DASH_check_DASH_temp358310018($z1000910010);
++R.GAS;
return $ret1001310014;
};
var $Hann_DASH_check_DASH_temp358310018 = function(ann_DASH_check_DASH_temp199010017) {
return ann_DASH_check_DASH_temp199010017;
};
var $Hcont_tail_arg35813597 = function(cont_tail_arg19873595,if_helper19793596) {
if(--R.GAS > 0) {
$z1001910020 = R.isFunction(if_helper19793596)?if_helper19793596.app(cont_tail_arg19873595):R.ffi.throwNonFunApp(L[531],if_helper19793596,[cont_tail_arg19873595]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19793596)?if_helper19793596.app(cont_tail_arg19873595):R.ffi.throwNonFunApp(L[531],if_helper19793596,[cont_tail_arg19873595]);
},
"from":L[531]});
}
++R.GAS;
return $z1001910020;
};
var $Hcont_tail_arg35823612 = function(cont_tail_arg19843611,if_helper19793596) {
if(--R.GAS > 0) {
$z1002110022 = R.isFunction(if_helper19793596)?if_helper19793596.app(cont_tail_arg19843611):R.ffi.throwNonFunApp(L[531],if_helper19793596,[cont_tail_arg19843611]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19793596)?if_helper19793596.app(cont_tail_arg19843611):R.ffi.throwNonFunApp(L[531],if_helper19793596,[cont_tail_arg19843611]);
},
"from":L[531]});
}
++R.GAS;
return $z1002110022;
};
var $Hanf_arg35803634 = function(anf_arg19663631,INDENT9187,PP337,anf_fun19643632,self4873633) {
var anf_fun196710033 = G(PP337,"str",L[1377]);
var $z1002510026 = D;
var $f1003110032 = function(_) {
return R.isFunction(anf_fun196710033)?anf_fun196710033.app(("[raw-array: ")):R.ffi.throwNonFunApp(L[1376],anf_fun196710033,[("[raw-array: ")]);
};
try {
if(--R.GAS > 0) {
$z1002510026 = $f1003110032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1003110032,
"from":L[1376]});
}
} catch($e1002310024) {
if(R.isCont($e1002310024)) {
var $ss1002710028 = {"from":L[1376],
"go":function(anf_arg196810034) {
return $Hanf_arg357910035(anf_arg196810034,INDENT9187,PP337,anf_arg19663631,anf_fun19643632,self4873633);
}};
$e1002310024.stack[R.EXN_STACKHEIGHT++] = $ss1002710028;
}
if(R.isPyretException($e1002310024)) {
$e1002310024.pyretStack.push(L[1376]);
}
throw $e1002310024;
}
var $ret1002910030 = $Hanf_arg357910035($z1002510026,INDENT9187,PP337,anf_arg19663631,anf_fun19643632,self4873633);
++R.GAS;
return $ret1002910030;
};
var $Hanf_arg357910035 = function(anf_arg196810034,INDENT9187,PP337,anf_arg19663631,anf_fun19643632,self4873633) {
var anf_arg196910049 = G(PP337,"commabreak",L[1383]);
var anf_arg197010050 = G(PP337,"rbrack",L[1382]);
var anf_bracket197110066 = G(self4873633,"values",L[1381]);
var anf_fun197210046 = G(anf_bracket197110066,"map",L[1380]);
var anf_arg197510047 = R.makeFunction(function(recv_DASH_25510052) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1379],1,arguments);
}
var anf_fun197410063 = G(recv_DASH_25510052,"tosource",L[1379]);
var $z1005510056 = D;
var $f1006110062 = function(_) {
return R.isFunction(anf_fun197410063)?anf_fun197410063.app():R.ffi.throwNonFunApp(L[1379],anf_fun197410063,[]);
};
try {
if(--R.GAS > 0) {
$z1005510056 = $f1006110062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1006110062,
"from":L[1379]});
}
} catch($e1005310054) {
if(R.isCont($e1005310054)) {
var $ss1005710058 = {"from":L[1379],
"go":function(ann_DASH_check_DASH_temp197310064) {
return $Hann_DASH_check_DASH_temp357610065(ann_DASH_check_DASH_temp197310064);
}};
$e1005310054.stack[R.EXN_STACKHEIGHT++] = $ss1005710058;
}
if(R.isPyretException($e1005310054)) {
$e1005310054.pyretStack.push(L[1379]);
}
throw $e1005310054;
}
var $ret1005910060 = $Hann_DASH_check_DASH_temp357610065($z1005510056);
++R.GAS;
return $ret1005910060;
});
var $z1003810039 = D;
var $f1004410045 = function(_) {
return R.isFunction(anf_fun197210046)?anf_fun197210046.app(anf_arg197510047):R.ffi.throwNonFunApp(L[1378],anf_fun197210046,[anf_arg197510047]);
};
try {
if(--R.GAS > 0) {
$z1003810039 = $f1004410045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1004410045,
"from":L[1378]});
}
} catch($e1003610037) {
if(R.isCont($e1003610037)) {
var $ss1004010041 = {"from":L[1378],
"go":function(anf_arg197610048) {
return $Hanf_arg357810051(anf_arg197610048,INDENT9187,anf_arg19663631,anf_arg196810034,anf_arg196910049,anf_arg197010050,anf_fun19643632);
}};
$e1003610037.stack[R.EXN_STACKHEIGHT++] = $ss1004010041;
}
if(R.isPyretException($e1003610037)) {
$e1003610037.pyretStack.push(L[1378]);
}
throw $e1003610037;
}
var $ret1004210043 = $Hanf_arg357810051($z1003810039,INDENT9187,anf_arg19663631,anf_arg196810034,anf_arg196910049,anf_arg197010050,anf_fun19643632);
++R.GAS;
return $ret1004210043;
};
var $Hanf_arg357810051 = function(anf_arg197610048,INDENT9187,anf_arg19663631,anf_arg196810034,anf_arg196910049,anf_arg197010050,anf_fun19643632) {
var $z1006910070 = D;
var $f1007510076 = function(_) {
return R.isFunction(anf_fun19643632)?anf_fun19643632.app(INDENT9187,(0),anf_arg19663631,anf_arg196810034,anf_arg196910049,anf_arg197010050,anf_arg197610048):R.ffi.throwNonFunApp(L[597],anf_fun19643632,[INDENT9187,(0),anf_arg19663631,anf_arg196810034,anf_arg196910049,anf_arg197010050,anf_arg197610048]);
};
try {
if(--R.GAS > 0) {
$z1006910070 = $f1007510076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1007510076,
"from":L[597]});
}
} catch($e1006710068) {
if(R.isCont($e1006710068)) {
var $ss1007110072 = {"from":L[597],
"go":function(ann_DASH_check_DASH_temp196310077) {
return $Hann_DASH_check_DASH_temp357710078(ann_DASH_check_DASH_temp196310077);
}};
$e1006710068.stack[R.EXN_STACKHEIGHT++] = $ss1007110072;
}
if(R.isPyretException($e1006710068)) {
$e1006710068.pyretStack.push(L[597]);
}
throw $e1006710068;
}
var $ret1007310074 = $Hann_DASH_check_DASH_temp357710078($z1006910070);
++R.GAS;
return $ret1007310074;
};
var $Hann_DASH_check_DASH_temp357710078 = function(ann_DASH_check_DASH_temp196310077) {
return ann_DASH_check_DASH_temp196310077;
};
var $Hann_DASH_check_DASH_temp357610065 = function(ann_DASH_check_DASH_temp197310064) {
return ann_DASH_check_DASH_temp197310064;
};
var $Hanf_arg35753650 = function(anf_arg19533648,self2533649,_plus26,torepr31) {
var anf_arg195410089 = G(self2533649,"values",L[532]);
var $z1008110082 = D;
var $f1008710088 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg195410089):R.ffi.throwNonFunApp(L[532],torepr31,[anf_arg195410089]);
};
try {
if(--R.GAS > 0) {
$z1008110082 = $f1008710088();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1008710088,
"from":L[532]});
}
} catch($e1007910080) {
if(R.isCont($e1007910080)) {
var $ss1008310084 = {"from":L[532],
"go":function(anf_arg195510090) {
return $Hanf_arg357410091(anf_arg195510090,anf_arg19533648,_plus26);
}};
$e1007910080.stack[R.EXN_STACKHEIGHT++] = $ss1008310084;
}
if(R.isPyretException($e1007910080)) {
$e1007910080.pyretStack.push(L[532]);
}
throw $e1007910080;
}
var $ret1008510086 = $Hanf_arg357410091($z1008110082,anf_arg19533648,_plus26);
++R.GAS;
return $ret1008510086;
};
var $Hanf_arg357410091 = function(anf_arg195510090,anf_arg19533648,_plus26) {
var $z1009410095 = D;
var $f1010010101 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg195510090):R.ffi.throwNonFunApp(L[532],_plus26,[(", "),anf_arg195510090]);
};
try {
if(--R.GAS > 0) {
$z1009410095 = $f1010010101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1010010101,
"from":L[532]});
}
} catch($e1009210093) {
if(R.isCont($e1009210093)) {
var $ss1009610097 = {"from":L[532],
"go":function(anf_arg195610102) {
return $Hanf_arg357310103(anf_arg195610102,anf_arg19533648,_plus26);
}};
$e1009210093.stack[R.EXN_STACKHEIGHT++] = $ss1009610097;
}
if(R.isPyretException($e1009210093)) {
$e1009210093.pyretStack.push(L[532]);
}
throw $e1009210093;
}
var $ret1009810099 = $Hanf_arg357310103($z1009410095,anf_arg19533648,_plus26);
++R.GAS;
return $ret1009810099;
};
var $Hanf_arg357310103 = function(anf_arg195610102,anf_arg19533648,_plus26) {
var $z1010610107 = D;
var $f1011210113 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg19533648,anf_arg195610102):R.ffi.throwNonFunApp(L[532],_plus26,[anf_arg19533648,anf_arg195610102]);
};
try {
if(--R.GAS > 0) {
$z1010610107 = $f1011210113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1011210113,
"from":L[532]});
}
} catch($e1010410105) {
if(R.isCont($e1010410105)) {
var $ss1010810109 = {"from":L[532],
"go":function(anf_arg195710114) {
return $Hanf_arg357210115(anf_arg195710114,_plus26);
}};
$e1010410105.stack[R.EXN_STACKHEIGHT++] = $ss1010810109;
}
if(R.isPyretException($e1010410105)) {
$e1010410105.pyretStack.push(L[532]);
}
throw $e1010410105;
}
var $ret1011010111 = $Hanf_arg357210115($z1010610107,_plus26);
++R.GAS;
return $ret1011010111;
};
var $Hanf_arg357210115 = function(anf_arg195710114,_plus26) {
var $z1011810119 = D;
var $f1012410125 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg195710114,(")")):R.ffi.throwNonFunApp(L[532],_plus26,[anf_arg195710114,(")")]);
};
try {
if(--R.GAS > 0) {
$z1011810119 = $f1012410125();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1012410125,
"from":L[532]});
}
} catch($e1011610117) {
if(R.isCont($e1011610117)) {
var $ss1012010121 = {"from":L[532],
"go":function(anf_arg195810126) {
return $Hanf_arg357110127(anf_arg195810126,_plus26);
}};
$e1011610117.stack[R.EXN_STACKHEIGHT++] = $ss1012010121;
}
if(R.isPyretException($e1011610117)) {
$e1011610117.pyretStack.push(L[532]);
}
throw $e1011610117;
}
var $ret1012210123 = $Hanf_arg357110127($z1011810119,_plus26);
++R.GAS;
return $ret1012210123;
};
var $Hanf_arg357110127 = function(anf_arg195810126,_plus26) {
var $z1013010131 = D;
var $f1013610137 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg195810126):R.ffi.throwNonFunApp(L[532],_plus26,[("("),anf_arg195810126]);
};
try {
if(--R.GAS > 0) {
$z1013010131 = $f1013610137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1013610137,
"from":L[532]});
}
} catch($e1012810129) {
if(R.isCont($e1012810129)) {
var $ss1013210133 = {"from":L[532],
"go":function(anf_arg195910138) {
return $Hanf_arg357010139(anf_arg195910138,_plus26);
}};
$e1012810129.stack[R.EXN_STACKHEIGHT++] = $ss1013210133;
}
if(R.isPyretException($e1012810129)) {
$e1012810129.pyretStack.push(L[532]);
}
throw $e1012810129;
}
var $ret1013410135 = $Hanf_arg357010139($z1013010131,_plus26);
++R.GAS;
return $ret1013410135;
};
var $Hanf_arg357010139 = function(anf_arg195910138,_plus26) {
var $z1014210143 = D;
var $f1014810149 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-array"),anf_arg195910138):R.ffi.throwNonFunApp(L[532],_plus26,[("a-array"),anf_arg195910138]);
};
try {
if(--R.GAS > 0) {
$z1014210143 = $f1014810149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1014810149,
"from":L[532]});
}
} catch($e1014010141) {
if(R.isCont($e1014010141)) {
var $ss1014410145 = {"from":L[532],
"go":function(ann_DASH_check_DASH_temp195110150) {
return $Hann_DASH_check_DASH_temp356910151(ann_DASH_check_DASH_temp195110150);
}};
$e1014010141.stack[R.EXN_STACKHEIGHT++] = $ss1014410145;
}
if(R.isPyretException($e1014010141)) {
$e1014010141.pyretStack.push(L[532]);
}
throw $e1014010141;
}
var $ret1014610147 = $Hann_DASH_check_DASH_temp356910151($z1014210143);
++R.GAS;
return $ret1014610147;
};
var $Hann_DASH_check_DASH_temp356910151 = function(ann_DASH_check_DASH_temp195110150) {
return ann_DASH_check_DASH_temp195110150;
};
var $Hcont_tail_arg35673666 = function(cont_tail_arg19483664,if_helper19393665) {
if(--R.GAS > 0) {
$z1015210153 = R.isFunction(if_helper19393665)?if_helper19393665.app(cont_tail_arg19483664):R.ffi.throwNonFunApp(L[532],if_helper19393665,[cont_tail_arg19483664]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19393665)?if_helper19393665.app(cont_tail_arg19483664):R.ffi.throwNonFunApp(L[532],if_helper19393665,[cont_tail_arg19483664]);
},
"from":L[532]});
}
++R.GAS;
return $z1015210153;
};
var $Hcont_tail_arg35683681 = function(cont_tail_arg19443680,if_helper19393665) {
if(--R.GAS > 0) {
$z1015410155 = R.isFunction(if_helper19393665)?if_helper19393665.app(cont_tail_arg19443680):R.ffi.throwNonFunApp(L[532],if_helper19393665,[cont_tail_arg19443680]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19393665)?if_helper19393665.app(cont_tail_arg19443680):R.ffi.throwNonFunApp(L[532],if_helper19393665,[cont_tail_arg19443680]);
},
"from":L[532]});
}
++R.GAS;
return $z1015410155;
};
var $Hanf_arg35663702 = function(anf_arg19363700,anf_fun19343701) {
var $z1015810159 = D;
var $f1016410165 = function(_) {
return R.isFunction(anf_fun19343701)?anf_fun19343701.app(anf_arg19363700):R.ffi.throwNonFunApp(L[604],anf_fun19343701,[anf_arg19363700]);
};
try {
if(--R.GAS > 0) {
$z1015810159 = $f1016410165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1016410165,
"from":L[604]});
}
} catch($e1015610157) {
if(R.isCont($e1015610157)) {
var $ss1016010161 = {"from":L[604],
"go":function(ann_DASH_check_DASH_temp193310166) {
return $Hann_DASH_check_DASH_temp356510167(ann_DASH_check_DASH_temp193310166);
}};
$e1015610157.stack[R.EXN_STACKHEIGHT++] = $ss1016010161;
}
if(R.isPyretException($e1015610157)) {
$e1015610157.pyretStack.push(L[604]);
}
throw $e1015610157;
}
var $ret1016210163 = $Hann_DASH_check_DASH_temp356510167($z1015810159);
++R.GAS;
return $ret1016210163;
};
var $Hann_DASH_check_DASH_temp356510167 = function(ann_DASH_check_DASH_temp193310166) {
return ann_DASH_check_DASH_temp193310166;
};
var $Hanf_arg35643719 = function(anf_arg19233717,self2473718,_plus26,torepr31) {
var anf_arg192410178 = G(self2473718,"b",L[533]);
var $z1017010171 = D;
var $f1017610177 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg192410178):R.ffi.throwNonFunApp(L[533],torepr31,[anf_arg192410178]);
};
try {
if(--R.GAS > 0) {
$z1017010171 = $f1017610177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1017610177,
"from":L[533]});
}
} catch($e1016810169) {
if(R.isCont($e1016810169)) {
var $ss1017210173 = {"from":L[533],
"go":function(anf_arg192510179) {
return $Hanf_arg356310180(anf_arg192510179,anf_arg19233717,_plus26);
}};
$e1016810169.stack[R.EXN_STACKHEIGHT++] = $ss1017210173;
}
if(R.isPyretException($e1016810169)) {
$e1016810169.pyretStack.push(L[533]);
}
throw $e1016810169;
}
var $ret1017410175 = $Hanf_arg356310180($z1017010171,anf_arg19233717,_plus26);
++R.GAS;
return $ret1017410175;
};
var $Hanf_arg356310180 = function(anf_arg192510179,anf_arg19233717,_plus26) {
var $z1018310184 = D;
var $f1018910190 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg192510179):R.ffi.throwNonFunApp(L[533],_plus26,[(", "),anf_arg192510179]);
};
try {
if(--R.GAS > 0) {
$z1018310184 = $f1018910190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1018910190,
"from":L[533]});
}
} catch($e1018110182) {
if(R.isCont($e1018110182)) {
var $ss1018510186 = {"from":L[533],
"go":function(anf_arg192610191) {
return $Hanf_arg356210192(anf_arg192610191,anf_arg19233717,_plus26);
}};
$e1018110182.stack[R.EXN_STACKHEIGHT++] = $ss1018510186;
}
if(R.isPyretException($e1018110182)) {
$e1018110182.pyretStack.push(L[533]);
}
throw $e1018110182;
}
var $ret1018710188 = $Hanf_arg356210192($z1018310184,anf_arg19233717,_plus26);
++R.GAS;
return $ret1018710188;
};
var $Hanf_arg356210192 = function(anf_arg192610191,anf_arg19233717,_plus26) {
var $z1019510196 = D;
var $f1020110202 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg19233717,anf_arg192610191):R.ffi.throwNonFunApp(L[533],_plus26,[anf_arg19233717,anf_arg192610191]);
};
try {
if(--R.GAS > 0) {
$z1019510196 = $f1020110202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1020110202,
"from":L[533]});
}
} catch($e1019310194) {
if(R.isCont($e1019310194)) {
var $ss1019710198 = {"from":L[533],
"go":function(anf_arg192710203) {
return $Hanf_arg356110204(anf_arg192710203,_plus26);
}};
$e1019310194.stack[R.EXN_STACKHEIGHT++] = $ss1019710198;
}
if(R.isPyretException($e1019310194)) {
$e1019310194.pyretStack.push(L[533]);
}
throw $e1019310194;
}
var $ret1019910200 = $Hanf_arg356110204($z1019510196,_plus26);
++R.GAS;
return $ret1019910200;
};
var $Hanf_arg356110204 = function(anf_arg192710203,_plus26) {
var $z1020710208 = D;
var $f1021310214 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg192710203,(")")):R.ffi.throwNonFunApp(L[533],_plus26,[anf_arg192710203,(")")]);
};
try {
if(--R.GAS > 0) {
$z1020710208 = $f1021310214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1021310214,
"from":L[533]});
}
} catch($e1020510206) {
if(R.isCont($e1020510206)) {
var $ss1020910210 = {"from":L[533],
"go":function(anf_arg192810215) {
return $Hanf_arg356010216(anf_arg192810215,_plus26);
}};
$e1020510206.stack[R.EXN_STACKHEIGHT++] = $ss1020910210;
}
if(R.isPyretException($e1020510206)) {
$e1020510206.pyretStack.push(L[533]);
}
throw $e1020510206;
}
var $ret1021110212 = $Hanf_arg356010216($z1020710208,_plus26);
++R.GAS;
return $ret1021110212;
};
var $Hanf_arg356010216 = function(anf_arg192810215,_plus26) {
var $z1021910220 = D;
var $f1022510226 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg192810215):R.ffi.throwNonFunApp(L[533],_plus26,[("("),anf_arg192810215]);
};
try {
if(--R.GAS > 0) {
$z1021910220 = $f1022510226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1022510226,
"from":L[533]});
}
} catch($e1021710218) {
if(R.isCont($e1021710218)) {
var $ss1022110222 = {"from":L[533],
"go":function(anf_arg192910227) {
return $Hanf_arg355910228(anf_arg192910227,_plus26);
}};
$e1021710218.stack[R.EXN_STACKHEIGHT++] = $ss1022110222;
}
if(R.isPyretException($e1021710218)) {
$e1021710218.pyretStack.push(L[533]);
}
throw $e1021710218;
}
var $ret1022310224 = $Hanf_arg355910228($z1021910220,_plus26);
++R.GAS;
return $ret1022310224;
};
var $Hanf_arg355910228 = function(anf_arg192910227,_plus26) {
var $z1023110232 = D;
var $f1023710238 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-bool"),anf_arg192910227):R.ffi.throwNonFunApp(L[533],_plus26,[("a-bool"),anf_arg192910227]);
};
try {
if(--R.GAS > 0) {
$z1023110232 = $f1023710238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1023710238,
"from":L[533]});
}
} catch($e1022910230) {
if(R.isCont($e1022910230)) {
var $ss1023310234 = {"from":L[533],
"go":function(ann_DASH_check_DASH_temp192110239) {
return $Hann_DASH_check_DASH_temp355810240(ann_DASH_check_DASH_temp192110239);
}};
$e1022910230.stack[R.EXN_STACKHEIGHT++] = $ss1023310234;
}
if(R.isPyretException($e1022910230)) {
$e1022910230.pyretStack.push(L[533]);
}
throw $e1022910230;
}
var $ret1023510236 = $Hann_DASH_check_DASH_temp355810240($z1023110232);
++R.GAS;
return $ret1023510236;
};
var $Hann_DASH_check_DASH_temp355810240 = function(ann_DASH_check_DASH_temp192110239) {
return ann_DASH_check_DASH_temp192110239;
};
var $Hcont_tail_arg35563735 = function(cont_tail_arg19183733,if_helper19093734) {
if(--R.GAS > 0) {
$z1024110242 = R.isFunction(if_helper19093734)?if_helper19093734.app(cont_tail_arg19183733):R.ffi.throwNonFunApp(L[533],if_helper19093734,[cont_tail_arg19183733]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19093734)?if_helper19093734.app(cont_tail_arg19183733):R.ffi.throwNonFunApp(L[533],if_helper19093734,[cont_tail_arg19183733]);
},
"from":L[533]});
}
++R.GAS;
return $z1024110242;
};
var $Hcont_tail_arg35573750 = function(cont_tail_arg19143749,if_helper19093734) {
if(--R.GAS > 0) {
$z1024310244 = R.isFunction(if_helper19093734)?if_helper19093734.app(cont_tail_arg19143749):R.ffi.throwNonFunApp(L[533],if_helper19093734,[cont_tail_arg19143749]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper19093734)?if_helper19093734.app(cont_tail_arg19143749):R.ffi.throwNonFunApp(L[533],if_helper19093734,[cont_tail_arg19143749]);
},
"from":L[533]});
}
++R.GAS;
return $z1024310244;
};
var $Hanf_arg35553772 = function(anf_arg19063770,anf_fun19033771) {
var $z1024710248 = D;
var $f1025310254 = function(_) {
return R.isFunction(anf_fun19033771)?anf_fun19033771.app(anf_arg19063770):R.ffi.throwNonFunApp(L[612],anf_fun19033771,[anf_arg19063770]);
};
try {
if(--R.GAS > 0) {
$z1024710248 = $f1025310254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1025310254,
"from":L[612]});
}
} catch($e1024510246) {
if(R.isCont($e1024510246)) {
var $ss1024910250 = {"from":L[612],
"go":function(ann_DASH_check_DASH_temp190210255) {
return $Hann_DASH_check_DASH_temp355410256(ann_DASH_check_DASH_temp190210255);
}};
$e1024510246.stack[R.EXN_STACKHEIGHT++] = $ss1024910250;
}
if(R.isPyretException($e1024510246)) {
$e1024510246.pyretStack.push(L[612]);
}
throw $e1024510246;
}
var $ret1025110252 = $Hann_DASH_check_DASH_temp355410256($z1024710248);
++R.GAS;
return $ret1025110252;
};
var $Hann_DASH_check_DASH_temp355410256 = function(ann_DASH_check_DASH_temp190210255) {
return ann_DASH_check_DASH_temp190210255;
};
var $Hanf_arg35533789 = function(anf_arg18923787,self2413788,_plus26,torepr31) {
var anf_arg189310267 = G(self2413788,"s",L[534]);
var $z1025910260 = D;
var $f1026510266 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg189310267):R.ffi.throwNonFunApp(L[534],torepr31,[anf_arg189310267]);
};
try {
if(--R.GAS > 0) {
$z1025910260 = $f1026510266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1026510266,
"from":L[534]});
}
} catch($e1025710258) {
if(R.isCont($e1025710258)) {
var $ss1026110262 = {"from":L[534],
"go":function(anf_arg189410268) {
return $Hanf_arg355210269(anf_arg189410268,anf_arg18923787,_plus26);
}};
$e1025710258.stack[R.EXN_STACKHEIGHT++] = $ss1026110262;
}
if(R.isPyretException($e1025710258)) {
$e1025710258.pyretStack.push(L[534]);
}
throw $e1025710258;
}
var $ret1026310264 = $Hanf_arg355210269($z1025910260,anf_arg18923787,_plus26);
++R.GAS;
return $ret1026310264;
};
var $Hanf_arg355210269 = function(anf_arg189410268,anf_arg18923787,_plus26) {
var $z1027210273 = D;
var $f1027810279 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg189410268):R.ffi.throwNonFunApp(L[534],_plus26,[(", "),anf_arg189410268]);
};
try {
if(--R.GAS > 0) {
$z1027210273 = $f1027810279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1027810279,
"from":L[534]});
}
} catch($e1027010271) {
if(R.isCont($e1027010271)) {
var $ss1027410275 = {"from":L[534],
"go":function(anf_arg189510280) {
return $Hanf_arg355110281(anf_arg189510280,anf_arg18923787,_plus26);
}};
$e1027010271.stack[R.EXN_STACKHEIGHT++] = $ss1027410275;
}
if(R.isPyretException($e1027010271)) {
$e1027010271.pyretStack.push(L[534]);
}
throw $e1027010271;
}
var $ret1027610277 = $Hanf_arg355110281($z1027210273,anf_arg18923787,_plus26);
++R.GAS;
return $ret1027610277;
};
var $Hanf_arg355110281 = function(anf_arg189510280,anf_arg18923787,_plus26) {
var $z1028410285 = D;
var $f1029010291 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg18923787,anf_arg189510280):R.ffi.throwNonFunApp(L[534],_plus26,[anf_arg18923787,anf_arg189510280]);
};
try {
if(--R.GAS > 0) {
$z1028410285 = $f1029010291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1029010291,
"from":L[534]});
}
} catch($e1028210283) {
if(R.isCont($e1028210283)) {
var $ss1028610287 = {"from":L[534],
"go":function(anf_arg189610292) {
return $Hanf_arg355010293(anf_arg189610292,_plus26);
}};
$e1028210283.stack[R.EXN_STACKHEIGHT++] = $ss1028610287;
}
if(R.isPyretException($e1028210283)) {
$e1028210283.pyretStack.push(L[534]);
}
throw $e1028210283;
}
var $ret1028810289 = $Hanf_arg355010293($z1028410285,_plus26);
++R.GAS;
return $ret1028810289;
};
var $Hanf_arg355010293 = function(anf_arg189610292,_plus26) {
var $z1029610297 = D;
var $f1030210303 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg189610292,(")")):R.ffi.throwNonFunApp(L[534],_plus26,[anf_arg189610292,(")")]);
};
try {
if(--R.GAS > 0) {
$z1029610297 = $f1030210303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1030210303,
"from":L[534]});
}
} catch($e1029410295) {
if(R.isCont($e1029410295)) {
var $ss1029810299 = {"from":L[534],
"go":function(anf_arg189710304) {
return $Hanf_arg354910305(anf_arg189710304,_plus26);
}};
$e1029410295.stack[R.EXN_STACKHEIGHT++] = $ss1029810299;
}
if(R.isPyretException($e1029410295)) {
$e1029410295.pyretStack.push(L[534]);
}
throw $e1029410295;
}
var $ret1030010301 = $Hanf_arg354910305($z1029610297,_plus26);
++R.GAS;
return $ret1030010301;
};
var $Hanf_arg354910305 = function(anf_arg189710304,_plus26) {
var $z1030810309 = D;
var $f1031410315 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg189710304):R.ffi.throwNonFunApp(L[534],_plus26,[("("),anf_arg189710304]);
};
try {
if(--R.GAS > 0) {
$z1030810309 = $f1031410315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1031410315,
"from":L[534]});
}
} catch($e1030610307) {
if(R.isCont($e1030610307)) {
var $ss1031010311 = {"from":L[534],
"go":function(anf_arg189810316) {
return $Hanf_arg354810317(anf_arg189810316,_plus26);
}};
$e1030610307.stack[R.EXN_STACKHEIGHT++] = $ss1031010311;
}
if(R.isPyretException($e1030610307)) {
$e1030610307.pyretStack.push(L[534]);
}
throw $e1030610307;
}
var $ret1031210313 = $Hanf_arg354810317($z1030810309,_plus26);
++R.GAS;
return $ret1031210313;
};
var $Hanf_arg354810317 = function(anf_arg189810316,_plus26) {
var $z1032010321 = D;
var $f1032610327 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-str"),anf_arg189810316):R.ffi.throwNonFunApp(L[534],_plus26,[("a-str"),anf_arg189810316]);
};
try {
if(--R.GAS > 0) {
$z1032010321 = $f1032610327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1032610327,
"from":L[534]});
}
} catch($e1031810319) {
if(R.isCont($e1031810319)) {
var $ss1032210323 = {"from":L[534],
"go":function(ann_DASH_check_DASH_temp189010328) {
return $Hann_DASH_check_DASH_temp354710329(ann_DASH_check_DASH_temp189010328);
}};
$e1031810319.stack[R.EXN_STACKHEIGHT++] = $ss1032210323;
}
if(R.isPyretException($e1031810319)) {
$e1031810319.pyretStack.push(L[534]);
}
throw $e1031810319;
}
var $ret1032410325 = $Hann_DASH_check_DASH_temp354710329($z1032010321);
++R.GAS;
return $ret1032410325;
};
var $Hann_DASH_check_DASH_temp354710329 = function(ann_DASH_check_DASH_temp189010328) {
return ann_DASH_check_DASH_temp189010328;
};
var $Hcont_tail_arg35453805 = function(cont_tail_arg18873803,if_helper18783804) {
if(--R.GAS > 0) {
$z1033010331 = R.isFunction(if_helper18783804)?if_helper18783804.app(cont_tail_arg18873803):R.ffi.throwNonFunApp(L[534],if_helper18783804,[cont_tail_arg18873803]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18783804)?if_helper18783804.app(cont_tail_arg18873803):R.ffi.throwNonFunApp(L[534],if_helper18783804,[cont_tail_arg18873803]);
},
"from":L[534]});
}
++R.GAS;
return $z1033010331;
};
var $Hcont_tail_arg35463820 = function(cont_tail_arg18833819,if_helper18783804) {
if(--R.GAS > 0) {
$z1033210333 = R.isFunction(if_helper18783804)?if_helper18783804.app(cont_tail_arg18833819):R.ffi.throwNonFunApp(L[534],if_helper18783804,[cont_tail_arg18833819]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18783804)?if_helper18783804.app(cont_tail_arg18833819):R.ffi.throwNonFunApp(L[534],if_helper18783804,[cont_tail_arg18833819]);
},
"from":L[534]});
}
++R.GAS;
return $z1033210333;
};
var $Hann_DASH_check_DASH_temp35443841 = function(ann_DASH_check_DASH_temp18733840) {
return ann_DASH_check_DASH_temp18733840;
};
var $Hanf_arg35433858 = function(anf_arg18633856,self2353857,_plus26,torepr31) {
var anf_arg186410344 = G(self2353857,"n",L[535]);
var $z1033610337 = D;
var $f1034210343 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg186410344):R.ffi.throwNonFunApp(L[535],torepr31,[anf_arg186410344]);
};
try {
if(--R.GAS > 0) {
$z1033610337 = $f1034210343();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1034210343,
"from":L[535]});
}
} catch($e1033410335) {
if(R.isCont($e1033410335)) {
var $ss1033810339 = {"from":L[535],
"go":function(anf_arg186510345) {
return $Hanf_arg354210346(anf_arg186510345,anf_arg18633856,_plus26);
}};
$e1033410335.stack[R.EXN_STACKHEIGHT++] = $ss1033810339;
}
if(R.isPyretException($e1033410335)) {
$e1033410335.pyretStack.push(L[535]);
}
throw $e1033410335;
}
var $ret1034010341 = $Hanf_arg354210346($z1033610337,anf_arg18633856,_plus26);
++R.GAS;
return $ret1034010341;
};
var $Hanf_arg354210346 = function(anf_arg186510345,anf_arg18633856,_plus26) {
var $z1034910350 = D;
var $f1035510356 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg186510345):R.ffi.throwNonFunApp(L[535],_plus26,[(", "),anf_arg186510345]);
};
try {
if(--R.GAS > 0) {
$z1034910350 = $f1035510356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1035510356,
"from":L[535]});
}
} catch($e1034710348) {
if(R.isCont($e1034710348)) {
var $ss1035110352 = {"from":L[535],
"go":function(anf_arg186610357) {
return $Hanf_arg354110358(anf_arg186610357,anf_arg18633856,_plus26);
}};
$e1034710348.stack[R.EXN_STACKHEIGHT++] = $ss1035110352;
}
if(R.isPyretException($e1034710348)) {
$e1034710348.pyretStack.push(L[535]);
}
throw $e1034710348;
}
var $ret1035310354 = $Hanf_arg354110358($z1034910350,anf_arg18633856,_plus26);
++R.GAS;
return $ret1035310354;
};
var $Hanf_arg354110358 = function(anf_arg186610357,anf_arg18633856,_plus26) {
var $z1036110362 = D;
var $f1036710368 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg18633856,anf_arg186610357):R.ffi.throwNonFunApp(L[535],_plus26,[anf_arg18633856,anf_arg186610357]);
};
try {
if(--R.GAS > 0) {
$z1036110362 = $f1036710368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1036710368,
"from":L[535]});
}
} catch($e1035910360) {
if(R.isCont($e1035910360)) {
var $ss1036310364 = {"from":L[535],
"go":function(anf_arg186710369) {
return $Hanf_arg354010370(anf_arg186710369,_plus26);
}};
$e1035910360.stack[R.EXN_STACKHEIGHT++] = $ss1036310364;
}
if(R.isPyretException($e1035910360)) {
$e1035910360.pyretStack.push(L[535]);
}
throw $e1035910360;
}
var $ret1036510366 = $Hanf_arg354010370($z1036110362,_plus26);
++R.GAS;
return $ret1036510366;
};
var $Hanf_arg354010370 = function(anf_arg186710369,_plus26) {
var $z1037310374 = D;
var $f1037910380 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg186710369,(")")):R.ffi.throwNonFunApp(L[535],_plus26,[anf_arg186710369,(")")]);
};
try {
if(--R.GAS > 0) {
$z1037310374 = $f1037910380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1037910380,
"from":L[535]});
}
} catch($e1037110372) {
if(R.isCont($e1037110372)) {
var $ss1037510376 = {"from":L[535],
"go":function(anf_arg186810381) {
return $Hanf_arg353910382(anf_arg186810381,_plus26);
}};
$e1037110372.stack[R.EXN_STACKHEIGHT++] = $ss1037510376;
}
if(R.isPyretException($e1037110372)) {
$e1037110372.pyretStack.push(L[535]);
}
throw $e1037110372;
}
var $ret1037710378 = $Hanf_arg353910382($z1037310374,_plus26);
++R.GAS;
return $ret1037710378;
};
var $Hanf_arg353910382 = function(anf_arg186810381,_plus26) {
var $z1038510386 = D;
var $f1039110392 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg186810381):R.ffi.throwNonFunApp(L[535],_plus26,[("("),anf_arg186810381]);
};
try {
if(--R.GAS > 0) {
$z1038510386 = $f1039110392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1039110392,
"from":L[535]});
}
} catch($e1038310384) {
if(R.isCont($e1038310384)) {
var $ss1038710388 = {"from":L[535],
"go":function(anf_arg186910393) {
return $Hanf_arg353810394(anf_arg186910393,_plus26);
}};
$e1038310384.stack[R.EXN_STACKHEIGHT++] = $ss1038710388;
}
if(R.isPyretException($e1038310384)) {
$e1038310384.pyretStack.push(L[535]);
}
throw $e1038310384;
}
var $ret1038910390 = $Hanf_arg353810394($z1038510386,_plus26);
++R.GAS;
return $ret1038910390;
};
var $Hanf_arg353810394 = function(anf_arg186910393,_plus26) {
var $z1039710398 = D;
var $f1040310404 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-num"),anf_arg186910393):R.ffi.throwNonFunApp(L[535],_plus26,[("a-num"),anf_arg186910393]);
};
try {
if(--R.GAS > 0) {
$z1039710398 = $f1040310404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1040310404,
"from":L[535]});
}
} catch($e1039510396) {
if(R.isCont($e1039510396)) {
var $ss1039910400 = {"from":L[535],
"go":function(ann_DASH_check_DASH_temp186110405) {
return $Hann_DASH_check_DASH_temp353710406(ann_DASH_check_DASH_temp186110405);
}};
$e1039510396.stack[R.EXN_STACKHEIGHT++] = $ss1039910400;
}
if(R.isPyretException($e1039510396)) {
$e1039510396.pyretStack.push(L[535]);
}
throw $e1039510396;
}
var $ret1040110402 = $Hann_DASH_check_DASH_temp353710406($z1039710398);
++R.GAS;
return $ret1040110402;
};
var $Hann_DASH_check_DASH_temp353710406 = function(ann_DASH_check_DASH_temp186110405) {
return ann_DASH_check_DASH_temp186110405;
};
var $Hcont_tail_arg35353874 = function(cont_tail_arg18583872,if_helper18493873) {
if(--R.GAS > 0) {
$z1040710408 = R.isFunction(if_helper18493873)?if_helper18493873.app(cont_tail_arg18583872):R.ffi.throwNonFunApp(L[535],if_helper18493873,[cont_tail_arg18583872]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18493873)?if_helper18493873.app(cont_tail_arg18583872):R.ffi.throwNonFunApp(L[535],if_helper18493873,[cont_tail_arg18583872]);
},
"from":L[535]});
}
++R.GAS;
return $z1040710408;
};
var $Hcont_tail_arg35363889 = function(cont_tail_arg18543888,if_helper18493873) {
if(--R.GAS > 0) {
$z1040910410 = R.isFunction(if_helper18493873)?if_helper18493873.app(cont_tail_arg18543888):R.ffi.throwNonFunApp(L[535],if_helper18493873,[cont_tail_arg18543888]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18493873)?if_helper18493873.app(cont_tail_arg18543888):R.ffi.throwNonFunApp(L[535],if_helper18493873,[cont_tail_arg18543888]);
},
"from":L[535]});
}
++R.GAS;
return $z1040910410;
};
var $Hanf_arg35343910 = function(anf_arg18463908,anf_fun18443909) {
var $z1041310414 = D;
var $f1041910420 = function(_) {
return R.isFunction(anf_fun18443909)?anf_fun18443909.app(anf_arg18463908):R.ffi.throwNonFunApp(L[625],anf_fun18443909,[anf_arg18463908]);
};
try {
if(--R.GAS > 0) {
$z1041310414 = $f1041910420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1041910420,
"from":L[625]});
}
} catch($e1041110412) {
if(R.isCont($e1041110412)) {
var $ss1041510416 = {"from":L[625],
"go":function(ann_DASH_check_DASH_temp184310421) {
return $Hann_DASH_check_DASH_temp353310422(ann_DASH_check_DASH_temp184310421);
}};
$e1041110412.stack[R.EXN_STACKHEIGHT++] = $ss1041510416;
}
if(R.isPyretException($e1041110412)) {
$e1041110412.pyretStack.push(L[625]);
}
throw $e1041110412;
}
var $ret1041710418 = $Hann_DASH_check_DASH_temp353310422($z1041310414);
++R.GAS;
return $ret1041710418;
};
var $Hann_DASH_check_DASH_temp353310422 = function(ann_DASH_check_DASH_temp184310421) {
return ann_DASH_check_DASH_temp184310421;
};
var $Hanf_arg35323927 = function(anf_arg18333925,self2293926,_plus26,torepr31) {
var anf_arg183410433 = G(self2293926,"loc",L[536]);
var $z1042510426 = D;
var $f1043110432 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg183410433):R.ffi.throwNonFunApp(L[536],torepr31,[anf_arg183410433]);
};
try {
if(--R.GAS > 0) {
$z1042510426 = $f1043110432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1043110432,
"from":L[536]});
}
} catch($e1042310424) {
if(R.isCont($e1042310424)) {
var $ss1042710428 = {"from":L[536],
"go":function(anf_arg183510434) {
return $Hanf_arg353110435(anf_arg183510434,anf_arg18333925,_plus26);
}};
$e1042310424.stack[R.EXN_STACKHEIGHT++] = $ss1042710428;
}
if(R.isPyretException($e1042310424)) {
$e1042310424.pyretStack.push(L[536]);
}
throw $e1042310424;
}
var $ret1042910430 = $Hanf_arg353110435($z1042510426,anf_arg18333925,_plus26);
++R.GAS;
return $ret1042910430;
};
var $Hanf_arg353110435 = function(anf_arg183510434,anf_arg18333925,_plus26) {
var $z1043810439 = D;
var $f1044410445 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg183510434):R.ffi.throwNonFunApp(L[536],_plus26,[(", "),anf_arg183510434]);
};
try {
if(--R.GAS > 0) {
$z1043810439 = $f1044410445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1044410445,
"from":L[536]});
}
} catch($e1043610437) {
if(R.isCont($e1043610437)) {
var $ss1044010441 = {"from":L[536],
"go":function(anf_arg183610446) {
return $Hanf_arg353010447(anf_arg183610446,anf_arg18333925,_plus26);
}};
$e1043610437.stack[R.EXN_STACKHEIGHT++] = $ss1044010441;
}
if(R.isPyretException($e1043610437)) {
$e1043610437.pyretStack.push(L[536]);
}
throw $e1043610437;
}
var $ret1044210443 = $Hanf_arg353010447($z1043810439,anf_arg18333925,_plus26);
++R.GAS;
return $ret1044210443;
};
var $Hanf_arg353010447 = function(anf_arg183610446,anf_arg18333925,_plus26) {
var $z1045010451 = D;
var $f1045610457 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg18333925,anf_arg183610446):R.ffi.throwNonFunApp(L[536],_plus26,[anf_arg18333925,anf_arg183610446]);
};
try {
if(--R.GAS > 0) {
$z1045010451 = $f1045610457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1045610457,
"from":L[536]});
}
} catch($e1044810449) {
if(R.isCont($e1044810449)) {
var $ss1045210453 = {"from":L[536],
"go":function(anf_arg183710458) {
return $Hanf_arg352910459(anf_arg183710458,_plus26);
}};
$e1044810449.stack[R.EXN_STACKHEIGHT++] = $ss1045210453;
}
if(R.isPyretException($e1044810449)) {
$e1044810449.pyretStack.push(L[536]);
}
throw $e1044810449;
}
var $ret1045410455 = $Hanf_arg352910459($z1045010451,_plus26);
++R.GAS;
return $ret1045410455;
};
var $Hanf_arg352910459 = function(anf_arg183710458,_plus26) {
var $z1046210463 = D;
var $f1046810469 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg183710458,(")")):R.ffi.throwNonFunApp(L[536],_plus26,[anf_arg183710458,(")")]);
};
try {
if(--R.GAS > 0) {
$z1046210463 = $f1046810469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1046810469,
"from":L[536]});
}
} catch($e1046010461) {
if(R.isCont($e1046010461)) {
var $ss1046410465 = {"from":L[536],
"go":function(anf_arg183810470) {
return $Hanf_arg352810471(anf_arg183810470,_plus26);
}};
$e1046010461.stack[R.EXN_STACKHEIGHT++] = $ss1046410465;
}
if(R.isPyretException($e1046010461)) {
$e1046010461.pyretStack.push(L[536]);
}
throw $e1046010461;
}
var $ret1046610467 = $Hanf_arg352810471($z1046210463,_plus26);
++R.GAS;
return $ret1046610467;
};
var $Hanf_arg352810471 = function(anf_arg183810470,_plus26) {
var $z1047410475 = D;
var $f1048010481 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg183810470):R.ffi.throwNonFunApp(L[536],_plus26,[("("),anf_arg183810470]);
};
try {
if(--R.GAS > 0) {
$z1047410475 = $f1048010481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1048010481,
"from":L[536]});
}
} catch($e1047210473) {
if(R.isCont($e1047210473)) {
var $ss1047610477 = {"from":L[536],
"go":function(anf_arg183910482) {
return $Hanf_arg352710483(anf_arg183910482,_plus26);
}};
$e1047210473.stack[R.EXN_STACKHEIGHT++] = $ss1047610477;
}
if(R.isPyretException($e1047210473)) {
$e1047210473.pyretStack.push(L[536]);
}
throw $e1047210473;
}
var $ret1047810479 = $Hanf_arg352710483($z1047410475,_plus26);
++R.GAS;
return $ret1047810479;
};
var $Hanf_arg352710483 = function(anf_arg183910482,_plus26) {
var $z1048610487 = D;
var $f1049210493 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-srcloc"),anf_arg183910482):R.ffi.throwNonFunApp(L[536],_plus26,[("a-srcloc"),anf_arg183910482]);
};
try {
if(--R.GAS > 0) {
$z1048610487 = $f1049210493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1049210493,
"from":L[536]});
}
} catch($e1048410485) {
if(R.isCont($e1048410485)) {
var $ss1048810489 = {"from":L[536],
"go":function(ann_DASH_check_DASH_temp183110494) {
return $Hann_DASH_check_DASH_temp352610495(ann_DASH_check_DASH_temp183110494);
}};
$e1048410485.stack[R.EXN_STACKHEIGHT++] = $ss1048810489;
}
if(R.isPyretException($e1048410485)) {
$e1048410485.pyretStack.push(L[536]);
}
throw $e1048410485;
}
var $ret1049010491 = $Hann_DASH_check_DASH_temp352610495($z1048610487);
++R.GAS;
return $ret1049010491;
};
var $Hann_DASH_check_DASH_temp352610495 = function(ann_DASH_check_DASH_temp183110494) {
return ann_DASH_check_DASH_temp183110494;
};
var $Hcont_tail_arg35243943 = function(cont_tail_arg18283941,if_helper18193942) {
if(--R.GAS > 0) {
$z1049610497 = R.isFunction(if_helper18193942)?if_helper18193942.app(cont_tail_arg18283941):R.ffi.throwNonFunApp(L[536],if_helper18193942,[cont_tail_arg18283941]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18193942)?if_helper18193942.app(cont_tail_arg18283941):R.ffi.throwNonFunApp(L[536],if_helper18193942,[cont_tail_arg18283941]);
},
"from":L[536]});
}
++R.GAS;
return $z1049610497;
};
var $Hcont_tail_arg35253958 = function(cont_tail_arg18243957,if_helper18193942) {
if(--R.GAS > 0) {
$z1049810499 = R.isFunction(if_helper18193942)?if_helper18193942.app(cont_tail_arg18243957):R.ffi.throwNonFunApp(L[536],if_helper18193942,[cont_tail_arg18243957]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper18193942)?if_helper18193942.app(cont_tail_arg18243957):R.ffi.throwNonFunApp(L[536],if_helper18193942,[cont_tail_arg18243957]);
},
"from":L[536]});
}
++R.GAS;
return $z1049810499;
};
var $Hann_DASH_check_DASH_temp35233980 = function(ann_DASH_check_DASH_temp18103979) {
return ann_DASH_check_DASH_temp18103979;
};
var $Hanf_arg35223993 = function(anf_arg18143992,_plus26,raise30) {
var $z1050210503 = D;
var $f1050810509 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg18143992):R.ffi.throwNonFunApp(L[1384],_plus26,[("No visitor field for "),anf_arg18143992]);
};
try {
if(--R.GAS > 0) {
$z1050210503 = $f1050810509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1050810509,
"from":L[1384]});
}
} catch($e1050010501) {
if(R.isCont($e1050010501)) {
var $ss1050410505 = {"from":L[1384],
"go":function(anf_arg181510510) {
return $Hanf_arg352110511(anf_arg181510510,raise30);
}};
$e1050010501.stack[R.EXN_STACKHEIGHT++] = $ss1050410505;
}
if(R.isPyretException($e1050010501)) {
$e1050010501.pyretStack.push(L[1384]);
}
throw $e1050010501;
}
var $ret1050610507 = $Hanf_arg352110511($z1050210503,raise30);
++R.GAS;
return $ret1050610507;
};
var $Hanf_arg352110511 = function(anf_arg181510510,raise30) {
var $z1051410515 = D;
var $f1052010521 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg181510510):R.ffi.throwNonFunApp(L[630],raise30,[anf_arg181510510]);
};
try {
if(--R.GAS > 0) {
$z1051410515 = $f1052010521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1052010521,
"from":L[630]});
}
} catch($e1051210513) {
if(R.isCont($e1051210513)) {
var $ss1051610517 = {"from":L[630],
"go":function(ann_DASH_check_DASH_temp181210522) {
return $Hann_DASH_check_DASH_temp352010523(ann_DASH_check_DASH_temp181210522);
}};
$e1051210513.stack[R.EXN_STACKHEIGHT++] = $ss1051610517;
}
if(R.isPyretException($e1051210513)) {
$e1051210513.pyretStack.push(L[630]);
}
throw $e1051210513;
}
var $ret1051810519 = $Hann_DASH_check_DASH_temp352010523($z1051410515);
++R.GAS;
return $ret1051810519;
};
var $Hann_DASH_check_DASH_temp352010523 = function(ann_DASH_check_DASH_temp181210522) {
return ann_DASH_check_DASH_temp181210522;
};
var $Hanf_arg35194023 = function(anf_arg17984020,INDENT9187,anf_fun17954021,self4654022,str_DASH_colonspace100196,_plus26) {
var $z1052610527 = D;
var $f1053210533 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg17984020,str_DASH_colonspace100196):R.ffi.throwNonFunApp(L[1385],_plus26,[anf_arg17984020,str_DASH_colonspace100196]);
};
try {
if(--R.GAS > 0) {
$z1052610527 = $f1053210533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1053210533,
"from":L[1385]});
}
} catch($e1052410525) {
if(R.isCont($e1052410525)) {
var $ss1052810529 = {"from":L[1385],
"go":function(anf_arg179910534) {
return $Hanf_arg351810535(anf_arg179910534,INDENT9187,anf_fun17954021,self4654022,_plus26);
}};
$e1052410525.stack[R.EXN_STACKHEIGHT++] = $ss1052810529;
}
if(R.isPyretException($e1052410525)) {
$e1052410525.pyretStack.push(L[1385]);
}
throw $e1052410525;
}
var $ret1053010531 = $Hanf_arg351810535($z1052610527,INDENT9187,anf_fun17954021,self4654022,_plus26);
++R.GAS;
return $ret1053010531;
};
var $Hanf_arg351810535 = function(anf_arg179910534,INDENT9187,anf_fun17954021,self4654022,_plus26) {
var anf_bracket180010549 = G(self4654022,"value",L[1388]);
var anf_fun180110546 = G(anf_bracket180010549,"tosource",L[1387]);
var $z1053810539 = D;
var $f1054410545 = function(_) {
return R.isFunction(anf_fun180110546)?anf_fun180110546.app():R.ffi.throwNonFunApp(L[1386],anf_fun180110546,[]);
};
try {
if(--R.GAS > 0) {
$z1053810539 = $f1054410545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1054410545,
"from":L[1386]});
}
} catch($e1053610537) {
if(R.isCont($e1053610537)) {
var $ss1054010541 = {"from":L[1386],
"go":function(anf_arg180210547) {
return $Hanf_arg351710548(anf_arg180210547,INDENT9187,anf_arg179910534,anf_fun17954021,_plus26);
}};
$e1053610537.stack[R.EXN_STACKHEIGHT++] = $ss1054010541;
}
if(R.isPyretException($e1053610537)) {
$e1053610537.pyretStack.push(L[1386]);
}
throw $e1053610537;
}
var $ret1054210543 = $Hanf_arg351710548($z1053810539,INDENT9187,anf_arg179910534,anf_fun17954021,_plus26);
++R.GAS;
return $ret1054210543;
};
var $Hanf_arg351710548 = function(anf_arg180210547,INDENT9187,anf_arg179910534,anf_fun17954021,_plus26) {
var $z1055210553 = D;
var $f1055810559 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg179910534,anf_arg180210547):R.ffi.throwNonFunApp(L[1385],_plus26,[anf_arg179910534,anf_arg180210547]);
};
try {
if(--R.GAS > 0) {
$z1055210553 = $f1055810559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1055810559,
"from":L[1385]});
}
} catch($e1055010551) {
if(R.isCont($e1055010551)) {
var $ss1055410555 = {"from":L[1385],
"go":function(anf_arg180310560) {
return $Hanf_arg351610561(anf_arg180310560,INDENT9187,anf_fun17954021);
}};
$e1055010551.stack[R.EXN_STACKHEIGHT++] = $ss1055410555;
}
if(R.isPyretException($e1055010551)) {
$e1055010551.pyretStack.push(L[1385]);
}
throw $e1055010551;
}
var $ret1055610557 = $Hanf_arg351610561($z1055210553,INDENT9187,anf_fun17954021);
++R.GAS;
return $ret1055610557;
};
var $Hanf_arg351610561 = function(anf_arg180310560,INDENT9187,anf_fun17954021) {
var $z1056410565 = D;
var $f1057010571 = function(_) {
return R.isFunction(anf_fun17954021)?anf_fun17954021.app(INDENT9187,anf_arg180310560):R.ffi.throwNonFunApp(L[644],anf_fun17954021,[INDENT9187,anf_arg180310560]);
};
try {
if(--R.GAS > 0) {
$z1056410565 = $f1057010571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1057010571,
"from":L[644]});
}
} catch($e1056210563) {
if(R.isCont($e1056210563)) {
var $ss1056610567 = {"from":L[644],
"go":function(ann_DASH_check_DASH_temp179410572) {
return $Hann_DASH_check_DASH_temp351510573(ann_DASH_check_DASH_temp179410572);
}};
$e1056210563.stack[R.EXN_STACKHEIGHT++] = $ss1056610567;
}
if(R.isPyretException($e1056210563)) {
$e1056210563.pyretStack.push(L[644]);
}
throw $e1056210563;
}
var $ret1056810569 = $Hann_DASH_check_DASH_temp351510573($z1056410565);
++R.GAS;
return $ret1056810569;
};
var $Hann_DASH_check_DASH_temp351510573 = function(ann_DASH_check_DASH_temp179410572) {
return ann_DASH_check_DASH_temp179410572;
};
var $Hanf_arg35144039 = function(anf_arg17804037,self2234038,_plus26,torepr31) {
var anf_arg178110584 = G(self2234038,"name",L[634]);
var $z1057610577 = D;
var $f1058210583 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg178110584):R.ffi.throwNonFunApp(L[634],torepr31,[anf_arg178110584]);
};
try {
if(--R.GAS > 0) {
$z1057610577 = $f1058210583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1058210583,
"from":L[634]});
}
} catch($e1057410575) {
if(R.isCont($e1057410575)) {
var $ss1057810579 = {"from":L[634],
"go":function(anf_arg178210585) {
return $Hanf_arg351310586(anf_arg178210585,anf_arg17804037,self2234038,_plus26,torepr31);
}};
$e1057410575.stack[R.EXN_STACKHEIGHT++] = $ss1057810579;
}
if(R.isPyretException($e1057410575)) {
$e1057410575.pyretStack.push(L[634]);
}
throw $e1057410575;
}
var $ret1058010581 = $Hanf_arg351310586($z1057610577,anf_arg17804037,self2234038,_plus26,torepr31);
++R.GAS;
return $ret1058010581;
};
var $Hanf_arg351310586 = function(anf_arg178210585,anf_arg17804037,self2234038,_plus26,torepr31) {
var $z1058910590 = D;
var $f1059510596 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg178210585):R.ffi.throwNonFunApp(L[634],_plus26,[(", "),anf_arg178210585]);
};
try {
if(--R.GAS > 0) {
$z1058910590 = $f1059510596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1059510596,
"from":L[634]});
}
} catch($e1058710588) {
if(R.isCont($e1058710588)) {
var $ss1059110592 = {"from":L[634],
"go":function(anf_arg178310597) {
return $Hanf_arg351210598(anf_arg178310597,anf_arg17804037,self2234038,_plus26,torepr31);
}};
$e1058710588.stack[R.EXN_STACKHEIGHT++] = $ss1059110592;
}
if(R.isPyretException($e1058710588)) {
$e1058710588.pyretStack.push(L[634]);
}
throw $e1058710588;
}
var $ret1059310594 = $Hanf_arg351210598($z1058910590,anf_arg17804037,self2234038,_plus26,torepr31);
++R.GAS;
return $ret1059310594;
};
var $Hanf_arg351210598 = function(anf_arg178310597,anf_arg17804037,self2234038,_plus26,torepr31) {
var $z1060110602 = D;
var $f1060710608 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg17804037,anf_arg178310597):R.ffi.throwNonFunApp(L[634],_plus26,[anf_arg17804037,anf_arg178310597]);
};
try {
if(--R.GAS > 0) {
$z1060110602 = $f1060710608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1060710608,
"from":L[634]});
}
} catch($e1059910600) {
if(R.isCont($e1059910600)) {
var $ss1060310604 = {"from":L[634],
"go":function(anf_arg178410609) {
return $Hanf_arg351110610(anf_arg178410609,self2234038,_plus26,torepr31);
}};
$e1059910600.stack[R.EXN_STACKHEIGHT++] = $ss1060310604;
}
if(R.isPyretException($e1059910600)) {
$e1059910600.pyretStack.push(L[634]);
}
throw $e1059910600;
}
var $ret1060510606 = $Hanf_arg351110610($z1060110602,self2234038,_plus26,torepr31);
++R.GAS;
return $ret1060510606;
};
var $Hanf_arg351110610 = function(anf_arg178410609,self2234038,_plus26,torepr31) {
var anf_arg178510621 = G(self2234038,"value",L[634]);
var $z1061310614 = D;
var $f1061910620 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg178510621):R.ffi.throwNonFunApp(L[634],torepr31,[anf_arg178510621]);
};
try {
if(--R.GAS > 0) {
$z1061310614 = $f1061910620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1061910620,
"from":L[634]});
}
} catch($e1061110612) {
if(R.isCont($e1061110612)) {
var $ss1061510616 = {"from":L[634],
"go":function(anf_arg178610622) {
return $Hanf_arg351010623(anf_arg178610622,anf_arg178410609,_plus26);
}};
$e1061110612.stack[R.EXN_STACKHEIGHT++] = $ss1061510616;
}
if(R.isPyretException($e1061110612)) {
$e1061110612.pyretStack.push(L[634]);
}
throw $e1061110612;
}
var $ret1061710618 = $Hanf_arg351010623($z1061310614,anf_arg178410609,_plus26);
++R.GAS;
return $ret1061710618;
};
var $Hanf_arg351010623 = function(anf_arg178610622,anf_arg178410609,_plus26) {
var $z1062610627 = D;
var $f1063210633 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg178610622):R.ffi.throwNonFunApp(L[634],_plus26,[(", "),anf_arg178610622]);
};
try {
if(--R.GAS > 0) {
$z1062610627 = $f1063210633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1063210633,
"from":L[634]});
}
} catch($e1062410625) {
if(R.isCont($e1062410625)) {
var $ss1062810629 = {"from":L[634],
"go":function(anf_arg178710634) {
return $Hanf_arg350910635(anf_arg178710634,anf_arg178410609,_plus26);
}};
$e1062410625.stack[R.EXN_STACKHEIGHT++] = $ss1062810629;
}
if(R.isPyretException($e1062410625)) {
$e1062410625.pyretStack.push(L[634]);
}
throw $e1062410625;
}
var $ret1063010631 = $Hanf_arg350910635($z1062610627,anf_arg178410609,_plus26);
++R.GAS;
return $ret1063010631;
};
var $Hanf_arg350910635 = function(anf_arg178710634,anf_arg178410609,_plus26) {
var $z1063810639 = D;
var $f1064410645 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg178410609,anf_arg178710634):R.ffi.throwNonFunApp(L[634],_plus26,[anf_arg178410609,anf_arg178710634]);
};
try {
if(--R.GAS > 0) {
$z1063810639 = $f1064410645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1064410645,
"from":L[634]});
}
} catch($e1063610637) {
if(R.isCont($e1063610637)) {
var $ss1064010641 = {"from":L[634],
"go":function(anf_arg178810646) {
return $Hanf_arg350810647(anf_arg178810646,_plus26);
}};
$e1063610637.stack[R.EXN_STACKHEIGHT++] = $ss1064010641;
}
if(R.isPyretException($e1063610637)) {
$e1063610637.pyretStack.push(L[634]);
}
throw $e1063610637;
}
var $ret1064210643 = $Hanf_arg350810647($z1063810639,_plus26);
++R.GAS;
return $ret1064210643;
};
var $Hanf_arg350810647 = function(anf_arg178810646,_plus26) {
var $z1065010651 = D;
var $f1065610657 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg178810646,(")")):R.ffi.throwNonFunApp(L[634],_plus26,[anf_arg178810646,(")")]);
};
try {
if(--R.GAS > 0) {
$z1065010651 = $f1065610657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1065610657,
"from":L[634]});
}
} catch($e1064810649) {
if(R.isCont($e1064810649)) {
var $ss1065210653 = {"from":L[634],
"go":function(anf_arg178910658) {
return $Hanf_arg350710659(anf_arg178910658,_plus26);
}};
$e1064810649.stack[R.EXN_STACKHEIGHT++] = $ss1065210653;
}
if(R.isPyretException($e1064810649)) {
$e1064810649.pyretStack.push(L[634]);
}
throw $e1064810649;
}
var $ret1065410655 = $Hanf_arg350710659($z1065010651,_plus26);
++R.GAS;
return $ret1065410655;
};
var $Hanf_arg350710659 = function(anf_arg178910658,_plus26) {
var $z1066210663 = D;
var $f1066810669 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg178910658):R.ffi.throwNonFunApp(L[634],_plus26,[("("),anf_arg178910658]);
};
try {
if(--R.GAS > 0) {
$z1066210663 = $f1066810669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1066810669,
"from":L[634]});
}
} catch($e1066010661) {
if(R.isCont($e1066010661)) {
var $ss1066410665 = {"from":L[634],
"go":function(anf_arg179010670) {
return $Hanf_arg350610671(anf_arg179010670,_plus26);
}};
$e1066010661.stack[R.EXN_STACKHEIGHT++] = $ss1066410665;
}
if(R.isPyretException($e1066010661)) {
$e1066010661.pyretStack.push(L[634]);
}
throw $e1066010661;
}
var $ret1066610667 = $Hanf_arg350610671($z1066210663,_plus26);
++R.GAS;
return $ret1066610667;
};
var $Hanf_arg350610671 = function(anf_arg179010670,_plus26) {
var $z1067410675 = D;
var $f1068010681 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-field"),anf_arg179010670):R.ffi.throwNonFunApp(L[634],_plus26,[("a-field"),anf_arg179010670]);
};
try {
if(--R.GAS > 0) {
$z1067410675 = $f1068010681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1068010681,
"from":L[634]});
}
} catch($e1067210673) {
if(R.isCont($e1067210673)) {
var $ss1067610677 = {"from":L[634],
"go":function(ann_DASH_check_DASH_temp177810682) {
return $Hann_DASH_check_DASH_temp350510683(ann_DASH_check_DASH_temp177810682);
}};
$e1067210673.stack[R.EXN_STACKHEIGHT++] = $ss1067610677;
}
if(R.isPyretException($e1067210673)) {
$e1067210673.pyretStack.push(L[634]);
}
throw $e1067210673;
}
var $ret1067810679 = $Hann_DASH_check_DASH_temp350510683($z1067410675);
++R.GAS;
return $ret1067810679;
};
var $Hann_DASH_check_DASH_temp350510683 = function(ann_DASH_check_DASH_temp177810682) {
return ann_DASH_check_DASH_temp177810682;
};
var $Hcont_tail_arg35034056 = function(cont_tail_arg17754054,if_helper17654055) {
if(--R.GAS > 0) {
$z1068410685 = R.isFunction(if_helper17654055)?if_helper17654055.app(cont_tail_arg17754054):R.ffi.throwNonFunApp(L[634],if_helper17654055,[cont_tail_arg17754054]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper17654055)?if_helper17654055.app(cont_tail_arg17754054):R.ffi.throwNonFunApp(L[634],if_helper17654055,[cont_tail_arg17754054]);
},
"from":L[634]});
}
++R.GAS;
return $z1068410685;
};
var $Hcont_tail_arg35044071 = function(cont_tail_arg17704070,if_helper17654055) {
if(--R.GAS > 0) {
$z1068610687 = R.isFunction(if_helper17654055)?if_helper17654055.app(cont_tail_arg17704070):R.ffi.throwNonFunApp(L[634],if_helper17654055,[cont_tail_arg17704070]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper17654055)?if_helper17654055.app(cont_tail_arg17704070):R.ffi.throwNonFunApp(L[634],if_helper17654055,[cont_tail_arg17704070]);
},
"from":L[634]});
}
++R.GAS;
return $z1068610687;
};
var $Hann_DASH_check_DASH_temp35024093 = function(ann_DASH_check_DASH_temp17564092) {
return ann_DASH_check_DASH_temp17564092;
};
var $Hanf_arg35014106 = function(anf_arg17604105,_plus26,raise30) {
var $z1069010691 = D;
var $f1069610697 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg17604105):R.ffi.throwNonFunApp(L[1389],_plus26,[("No visitor field for "),anf_arg17604105]);
};
try {
if(--R.GAS > 0) {
$z1069010691 = $f1069610697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1069610697,
"from":L[1389]});
}
} catch($e1068810689) {
if(R.isCont($e1068810689)) {
var $ss1069210693 = {"from":L[1389],
"go":function(anf_arg176110698) {
return $Hanf_arg350010699(anf_arg176110698,raise30);
}};
$e1068810689.stack[R.EXN_STACKHEIGHT++] = $ss1069210693;
}
if(R.isPyretException($e1068810689)) {
$e1068810689.pyretStack.push(L[1389]);
}
throw $e1068810689;
}
var $ret1069410695 = $Hanf_arg350010699($z1069010691,raise30);
++R.GAS;
return $ret1069410695;
};
var $Hanf_arg350010699 = function(anf_arg176110698,raise30) {
var $z1070210703 = D;
var $f1070810709 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg176110698):R.ffi.throwNonFunApp(L[650],raise30,[anf_arg176110698]);
};
try {
if(--R.GAS > 0) {
$z1070210703 = $f1070810709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1070810709,
"from":L[650]});
}
} catch($e1070010701) {
if(R.isCont($e1070010701)) {
var $ss1070410705 = {"from":L[650],
"go":function(ann_DASH_check_DASH_temp175810710) {
return $Hann_DASH_check_DASH_temp349910711(ann_DASH_check_DASH_temp175810710);
}};
$e1070010701.stack[R.EXN_STACKHEIGHT++] = $ss1070410705;
}
if(R.isPyretException($e1070010701)) {
$e1070010701.pyretStack.push(L[650]);
}
throw $e1070010701;
}
var $ret1070610707 = $Hann_DASH_check_DASH_temp349910711($z1070210703);
++R.GAS;
return $ret1070610707;
};
var $Hann_DASH_check_DASH_temp349910711 = function(ann_DASH_check_DASH_temp175810710) {
return ann_DASH_check_DASH_temp175810710;
};
var $Hanf_arg34984126 = function(anf_arg17394123,INDENT9187,PP337,anf_fun17354124,anf_fun17364125,args4564109,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26) {
var anf_arg174010725 = G(PP337,"lparen",L[1396]);
var anf_arg174110726 = G(PP337,"commabreak",L[1395]);
var anf_arg174210727 = G(PP337,"rparen",L[1394]);
var anf_fun174310722 = G(args4564109,"map",L[1393]);
var anf_arg174610723 = R.makeFunction(function(a45910729) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1391],1,arguments);
}
var anf_fun174510740 = G(a45910729,"tosource",L[1392]);
var $z1073210733 = D;
var $f1073810739 = function(_) {
return R.isFunction(anf_fun174510740)?anf_fun174510740.app():R.ffi.throwNonFunApp(L[1391],anf_fun174510740,[]);
};
try {
if(--R.GAS > 0) {
$z1073210733 = $f1073810739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1073810739,
"from":L[1391]});
}
} catch($e1073010731) {
if(R.isCont($e1073010731)) {
var $ss1073410735 = {"from":L[1391],
"go":function(ann_DASH_check_DASH_temp174410741) {
return $Hann_DASH_check_DASH_temp348910742(ann_DASH_check_DASH_temp174410741);
}};
$e1073010731.stack[R.EXN_STACKHEIGHT++] = $ss1073410735;
}
if(R.isPyretException($e1073010731)) {
$e1073010731.pyretStack.push(L[1391]);
}
throw $e1073010731;
}
var $ret1073610737 = $Hann_DASH_check_DASH_temp348910742($z1073210733);
++R.GAS;
return $ret1073610737;
});
var $z1071410715 = D;
var $f1072010721 = function(_) {
return R.isFunction(anf_fun174310722)?anf_fun174310722.app(anf_arg174610723):R.ffi.throwNonFunApp(L[1390],anf_fun174310722,[anf_arg174610723]);
};
try {
if(--R.GAS > 0) {
$z1071410715 = $f1072010721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1072010721,
"from":L[1390]});
}
} catch($e1071210713) {
if(R.isCont($e1071210713)) {
var $ss1071610717 = {"from":L[1390],
"go":function(anf_arg174710724) {
return $Hanf_arg349710728(anf_arg174710724,INDENT9187,PP337,anf_arg17394123,anf_arg174010725,anf_arg174110726,anf_arg174210727,anf_fun17354124,anf_fun17364125,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26);
}};
$e1071210713.stack[R.EXN_STACKHEIGHT++] = $ss1071610717;
}
if(R.isPyretException($e1071210713)) {
$e1071210713.pyretStack.push(L[1390]);
}
throw $e1071210713;
}
var $ret1071810719 = $Hanf_arg349710728($z1071410715,INDENT9187,PP337,anf_arg17394123,anf_arg174010725,anf_arg174110726,anf_arg174210727,anf_fun17354124,anf_fun17364125,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26);
++R.GAS;
return $ret1071810719;
};
var $Hanf_arg349710728 = function(anf_arg174710724,INDENT9187,PP337,anf_arg17394123,anf_arg174010725,anf_arg174110726,anf_arg174210727,anf_fun17354124,anf_fun17364125,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26) {
var $z1074510746 = D;
var $f1075110752 = function(_) {
return R.isFunction(anf_fun17364125)?anf_fun17364125.app(INDENT9187,(0),anf_arg17394123,anf_arg174010725,anf_arg174110726,anf_arg174210727,anf_arg174710724):R.ffi.throwNonFunApp(L[1397],anf_fun17364125,[INDENT9187,(0),anf_arg17394123,anf_arg174010725,anf_arg174110726,anf_arg174210727,anf_arg174710724]);
};
try {
if(--R.GAS > 0) {
$z1074510746 = $f1075110752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1075110752,
"from":L[1397]});
}
} catch($e1074310744) {
if(R.isCont($e1074310744)) {
var $ss1074710748 = {"from":L[1397],
"go":function(anf_arg174810753) {
return $Hanf_arg349610754(anf_arg174810753,INDENT9187,PP337,anf_fun17354124,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26);
}};
$e1074310744.stack[R.EXN_STACKHEIGHT++] = $ss1074710748;
}
if(R.isPyretException($e1074310744)) {
$e1074310744.pyretStack.push(L[1397]);
}
throw $e1074310744;
}
var $ret1074910750 = $Hanf_arg349610754($z1074510746,INDENT9187,PP337,anf_fun17354124,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26);
++R.GAS;
return $ret1074910750;
};
var $Hanf_arg349610754 = function(anf_arg174810753,INDENT9187,PP337,anf_fun17354124,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26) {
var $z1075710758 = D;
var $f1076310764 = function(_) {
return R.isFunction(anf_fun17354124)?anf_fun17354124.app(INDENT9187,anf_arg174810753):R.ffi.throwNonFunApp(L[1398],anf_fun17354124,[INDENT9187,anf_arg174810753]);
};
try {
if(--R.GAS > 0) {
$z1075710758 = $f1076310764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1076310764,
"from":L[1398]});
}
} catch($e1075510756) {
if(R.isCont($e1075510756)) {
var $ss1075910760 = {"from":L[1398],
"go":function(arg_DASH_list45810765) {
return $Harg_DASH_list349510766(arg_DASH_list45810765,INDENT9187,PP337,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26);
}};
$e1075510756.stack[R.EXN_STACKHEIGHT++] = $ss1075910760;
}
if(R.isPyretException($e1075510756)) {
$e1075510756.pyretStack.push(L[1398]);
}
throw $e1075510756;
}
var $ret1076110762 = $Harg_DASH_list349510766($z1075710758,INDENT9187,PP337,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26);
++R.GAS;
return $ret1076110762;
};
var $Harg_DASH_list349510766 = function(arg_DASH_list45810765,INDENT9187,PP337,body4574110,str_DASH_colon98170,str_DASH_end101209,typ4554108,_plus26) {
var anf_fun174910778 = G(PP337,"group",L[1400]);
var $z1076910770 = D;
var $f1077510776 = function(_) {
return R.isFunction(_plus26)?_plus26.app(typ4554108,arg_DASH_list45810765):R.ffi.throwNonFunApp(L[1399],_plus26,[typ4554108,arg_DASH_list45810765]);
};
try {
if(--R.GAS > 0) {
$z1076910770 = $f1077510776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1077510776,
"from":L[1399]});
}
} catch($e1076710768) {
if(R.isCont($e1076710768)) {
var $ss1077110772 = {"from":L[1399],
"go":function(anf_arg175010777) {
return $Hanf_arg349410779(anf_arg175010777,INDENT9187,PP337,anf_fun174910778,body4574110,str_DASH_colon98170,str_DASH_end101209,_plus26);
}};
$e1076710768.stack[R.EXN_STACKHEIGHT++] = $ss1077110772;
}
if(R.isPyretException($e1076710768)) {
$e1076710768.pyretStack.push(L[1399]);
}
throw $e1076710768;
}
var $ret1077310774 = $Hanf_arg349410779($z1076910770,INDENT9187,PP337,anf_fun174910778,body4574110,str_DASH_colon98170,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1077310774;
};
var $Hanf_arg349410779 = function(anf_arg175010777,INDENT9187,PP337,anf_fun174910778,body4574110,str_DASH_colon98170,str_DASH_end101209,_plus26) {
var $z1078210783 = D;
var $f1078810789 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg175010777,str_DASH_colon98170):R.ffi.throwNonFunApp(L[1399],_plus26,[anf_arg175010777,str_DASH_colon98170]);
};
try {
if(--R.GAS > 0) {
$z1078210783 = $f1078810789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1078810789,
"from":L[1399]});
}
} catch($e1078010781) {
if(R.isCont($e1078010781)) {
var $ss1078410785 = {"from":L[1399],
"go":function(anf_arg175110790) {
return $Hanf_arg349310791(anf_arg175110790,INDENT9187,PP337,anf_fun174910778,body4574110,str_DASH_end101209);
}};
$e1078010781.stack[R.EXN_STACKHEIGHT++] = $ss1078410785;
}
if(R.isPyretException($e1078010781)) {
$e1078010781.pyretStack.push(L[1399]);
}
throw $e1078010781;
}
var $ret1078610787 = $Hanf_arg349310791($z1078210783,INDENT9187,PP337,anf_fun174910778,body4574110,str_DASH_end101209);
++R.GAS;
return $ret1078610787;
};
var $Hanf_arg349310791 = function(anf_arg175110790,INDENT9187,PP337,anf_fun174910778,body4574110,str_DASH_end101209) {
var $z1079410795 = D;
var $f1080010801 = function(_) {
return R.isFunction(anf_fun174910778)?anf_fun174910778.app(anf_arg175110790):R.ffi.throwNonFunApp(L[1401],anf_fun174910778,[anf_arg175110790]);
};
try {
if(--R.GAS > 0) {
$z1079410795 = $f1080010801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1080010801,
"from":L[1401]});
}
} catch($e1079210793) {
if(R.isCont($e1079210793)) {
var $ss1079610797 = {"from":L[1401],
"go":function(header46010802) {
return $Hheader349210803(header46010802,INDENT9187,PP337,body4574110,str_DASH_end101209);
}};
$e1079210793.stack[R.EXN_STACKHEIGHT++] = $ss1079610797;
}
if(R.isPyretException($e1079210793)) {
$e1079210793.pyretStack.push(L[1401]);
}
throw $e1079210793;
}
var $ret1079810799 = $Hheader349210803($z1079410795,INDENT9187,PP337,body4574110,str_DASH_end101209);
++R.GAS;
return $ret1079810799;
};
var $Hheader349210803 = function(header46010802,INDENT9187,PP337,body4574110,str_DASH_end101209) {
var anf_fun175210816 = G(PP337,"surround",L[1404]);
var anf_fun175310814 = G(body4574110,"tosource",L[1403]);
var $z1080610807 = D;
var $f1081210813 = function(_) {
return R.isFunction(anf_fun175310814)?anf_fun175310814.app():R.ffi.throwNonFunApp(L[1402],anf_fun175310814,[]);
};
try {
if(--R.GAS > 0) {
$z1080610807 = $f1081210813();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1081210813,
"from":L[1402]});
}
} catch($e1080410805) {
if(R.isCont($e1080410805)) {
var $ss1080810809 = {"from":L[1402],
"go":function(anf_arg175410815) {
return $Hanf_arg349110817(anf_arg175410815,INDENT9187,anf_fun175210816,header46010802,str_DASH_end101209);
}};
$e1080410805.stack[R.EXN_STACKHEIGHT++] = $ss1080810809;
}
if(R.isPyretException($e1080410805)) {
$e1080410805.pyretStack.push(L[1402]);
}
throw $e1080410805;
}
var $ret1081010811 = $Hanf_arg349110817($z1080610807,INDENT9187,anf_fun175210816,header46010802,str_DASH_end101209);
++R.GAS;
return $ret1081010811;
};
var $Hanf_arg349110817 = function(anf_arg175410815,INDENT9187,anf_fun175210816,header46010802,str_DASH_end101209) {
var $z1082010821 = D;
var $f1082610827 = function(_) {
return R.isFunction(anf_fun175210816)?anf_fun175210816.app(INDENT9187,(1),header46010802,anf_arg175410815,str_DASH_end101209):R.ffi.throwNonFunApp(L[654],anf_fun175210816,[INDENT9187,(1),header46010802,anf_arg175410815,str_DASH_end101209]);
};
try {
if(--R.GAS > 0) {
$z1082010821 = $f1082610827();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1082610827,
"from":L[654]});
}
} catch($e1081810819) {
if(R.isCont($e1081810819)) {
var $ss1082210823 = {"from":L[654],
"go":function(ann_DASH_check_DASH_temp173410828) {
return $Hann_DASH_check_DASH_temp349010829(ann_DASH_check_DASH_temp173410828);
}};
$e1081810819.stack[R.EXN_STACKHEIGHT++] = $ss1082210823;
}
if(R.isPyretException($e1081810819)) {
$e1081810819.pyretStack.push(L[654]);
}
throw $e1081810819;
}
var $ret1082410825 = $Hann_DASH_check_DASH_temp349010829($z1082010821);
++R.GAS;
return $ret1082410825;
};
var $Hann_DASH_check_DASH_temp349010829 = function(ann_DASH_check_DASH_temp173410828) {
return ann_DASH_check_DASH_temp173410828;
};
var $Hann_DASH_check_DASH_temp348910742 = function(ann_DASH_check_DASH_temp174410741) {
return ann_DASH_check_DASH_temp174410741;
};
var $Hann_DASH_check_DASH_temp34884311 = function(ann_DASH_check_DASH_temp16994310) {
return ann_DASH_check_DASH_temp16994310;
};
var $Hanf_arg34874328 = function(anf_arg16934327,_plus26) {
var $z1083210833 = D;
var $f1083810839 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg16934327,(")")):R.ffi.throwNonFunApp(L[660],_plus26,[anf_arg16934327,(")")]);
};
try {
if(--R.GAS > 0) {
$z1083210833 = $f1083810839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1083810839,
"from":L[660]});
}
} catch($e1083010831) {
if(R.isCont($e1083010831)) {
var $ss1083410835 = {"from":L[660],
"go":function(anf_arg169410840) {
return $Hanf_arg348610841(anf_arg169410840,_plus26);
}};
$e1083010831.stack[R.EXN_STACKHEIGHT++] = $ss1083410835;
}
if(R.isPyretException($e1083010831)) {
$e1083010831.pyretStack.push(L[660]);
}
throw $e1083010831;
}
var $ret1083610837 = $Hanf_arg348610841($z1083210833,_plus26);
++R.GAS;
return $ret1083610837;
};
var $Hanf_arg348610841 = function(anf_arg169410840,_plus26) {
var $z1084410845 = D;
var $f1085010851 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg169410840):R.ffi.throwNonFunApp(L[660],_plus26,[("("),anf_arg169410840]);
};
try {
if(--R.GAS > 0) {
$z1084410845 = $f1085010851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1085010851,
"from":L[660]});
}
} catch($e1084210843) {
if(R.isCont($e1084210843)) {
var $ss1084610847 = {"from":L[660],
"go":function(anf_arg169510852) {
return $Hanf_arg348510853(anf_arg169510852,_plus26);
}};
$e1084210843.stack[R.EXN_STACKHEIGHT++] = $ss1084610847;
}
if(R.isPyretException($e1084210843)) {
$e1084210843.pyretStack.push(L[660]);
}
throw $e1084210843;
}
var $ret1084810849 = $Hanf_arg348510853($z1084410845,_plus26);
++R.GAS;
return $ret1084810849;
};
var $Hanf_arg348510853 = function(anf_arg169510852,_plus26) {
var $z1085610857 = D;
var $f1086210863 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-val"),anf_arg169510852):R.ffi.throwNonFunApp(L[660],_plus26,[("a-val"),anf_arg169510852]);
};
try {
if(--R.GAS > 0) {
$z1085610857 = $f1086210863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1086210863,
"from":L[660]});
}
} catch($e1085410855) {
if(R.isCont($e1085410855)) {
var $ss1085810859 = {"from":L[660],
"go":function(ann_DASH_check_DASH_temp169110864) {
return $Hann_DASH_check_DASH_temp348410865(ann_DASH_check_DASH_temp169110864);
}};
$e1085410855.stack[R.EXN_STACKHEIGHT++] = $ss1085810859;
}
if(R.isPyretException($e1085410855)) {
$e1085410855.pyretStack.push(L[660]);
}
throw $e1085410855;
}
var $ret1086010861 = $Hann_DASH_check_DASH_temp348410865($z1085610857);
++R.GAS;
return $ret1086010861;
};
var $Hann_DASH_check_DASH_temp348410865 = function(ann_DASH_check_DASH_temp169110864) {
return ann_DASH_check_DASH_temp169110864;
};
var $Hcont_tail_arg34824344 = function(cont_tail_arg16884342,if_helper16804343) {
if(--R.GAS > 0) {
$z1086610867 = R.isFunction(if_helper16804343)?if_helper16804343.app(cont_tail_arg16884342):R.ffi.throwNonFunApp(L[660],if_helper16804343,[cont_tail_arg16884342]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper16804343)?if_helper16804343.app(cont_tail_arg16884342):R.ffi.throwNonFunApp(L[660],if_helper16804343,[cont_tail_arg16884342]);
},
"from":L[660]});
}
++R.GAS;
return $z1086610867;
};
var $Hcont_tail_arg34834359 = function(cont_tail_arg16854358,if_helper16804343) {
if(--R.GAS > 0) {
$z1086810869 = R.isFunction(if_helper16804343)?if_helper16804343.app(cont_tail_arg16854358):R.ffi.throwNonFunApp(L[660],if_helper16804343,[cont_tail_arg16854358]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper16804343)?if_helper16804343.app(cont_tail_arg16854358):R.ffi.throwNonFunApp(L[660],if_helper16804343,[cont_tail_arg16854358]);
},
"from":L[660]});
}
++R.GAS;
return $z1086810869;
};
var $Hanf_arg34814380 = function(anf_arg16754378,fun_DASH_method_DASH_pretty219597,self4494379) {
var anf_arg167610880 = G(self4494379,"args",L[1407]);
var anf_arg167710881 = G(self4494379,"body",L[1406]);
var $z1087210873 = D;
var $f1087810879 = function(_) {
return R.isFunction(fun_DASH_method_DASH_pretty219597.$var === D?U(L[1405],"fun-method-pretty"):fun_DASH_method_DASH_pretty219597.$var)?fun_DASH_method_DASH_pretty219597.$var === D?U(L[1405],"fun-method-pretty"):fun_DASH_method_DASH_pretty219597.$var.app(anf_arg16754378,anf_arg167610880,anf_arg167710881):R.ffi.throwNonFunApp(L[740],fun_DASH_method_DASH_pretty219597.$var === D?U(L[1405],"fun-method-pretty"):fun_DASH_method_DASH_pretty219597.$var,[anf_arg16754378,anf_arg167610880,anf_arg167710881]);
};
try {
if(--R.GAS > 0) {
$z1087210873 = $f1087810879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1087810879,
"from":L[740]});
}
} catch($e1087010871) {
if(R.isCont($e1087010871)) {
var $ss1087410875 = {"from":L[740],
"go":function(ann_DASH_check_DASH_temp167310882) {
return $Hann_DASH_check_DASH_temp348010883(ann_DASH_check_DASH_temp167310882);
}};
$e1087010871.stack[R.EXN_STACKHEIGHT++] = $ss1087410875;
}
if(R.isPyretException($e1087010871)) {
$e1087010871.pyretStack.push(L[740]);
}
throw $e1087010871;
}
var $ret1087610877 = $Hann_DASH_check_DASH_temp348010883($z1087210873);
++R.GAS;
return $ret1087610877;
};
var $Hann_DASH_check_DASH_temp348010883 = function(ann_DASH_check_DASH_temp167310882) {
return ann_DASH_check_DASH_temp167310882;
};
var $Hanf_arg34794396 = function(anf_arg16554394,self2114395,_plus26,torepr31) {
var anf_arg165610894 = G(self2114395,"args",L[661]);
var $z1088610887 = D;
var $f1089210893 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg165610894):R.ffi.throwNonFunApp(L[661],torepr31,[anf_arg165610894]);
};
try {
if(--R.GAS > 0) {
$z1088610887 = $f1089210893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1089210893,
"from":L[661]});
}
} catch($e1088410885) {
if(R.isCont($e1088410885)) {
var $ss1088810889 = {"from":L[661],
"go":function(anf_arg165710895) {
return $Hanf_arg347810896(anf_arg165710895,anf_arg16554394,self2114395,_plus26,torepr31);
}};
$e1088410885.stack[R.EXN_STACKHEIGHT++] = $ss1088810889;
}
if(R.isPyretException($e1088410885)) {
$e1088410885.pyretStack.push(L[661]);
}
throw $e1088410885;
}
var $ret1089010891 = $Hanf_arg347810896($z1088610887,anf_arg16554394,self2114395,_plus26,torepr31);
++R.GAS;
return $ret1089010891;
};
var $Hanf_arg347810896 = function(anf_arg165710895,anf_arg16554394,self2114395,_plus26,torepr31) {
var $z1089910900 = D;
var $f1090510906 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg165710895):R.ffi.throwNonFunApp(L[661],_plus26,[(", "),anf_arg165710895]);
};
try {
if(--R.GAS > 0) {
$z1089910900 = $f1090510906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1090510906,
"from":L[661]});
}
} catch($e1089710898) {
if(R.isCont($e1089710898)) {
var $ss1090110902 = {"from":L[661],
"go":function(anf_arg165810907) {
return $Hanf_arg347710908(anf_arg165810907,anf_arg16554394,self2114395,_plus26,torepr31);
}};
$e1089710898.stack[R.EXN_STACKHEIGHT++] = $ss1090110902;
}
if(R.isPyretException($e1089710898)) {
$e1089710898.pyretStack.push(L[661]);
}
throw $e1089710898;
}
var $ret1090310904 = $Hanf_arg347710908($z1089910900,anf_arg16554394,self2114395,_plus26,torepr31);
++R.GAS;
return $ret1090310904;
};
var $Hanf_arg347710908 = function(anf_arg165810907,anf_arg16554394,self2114395,_plus26,torepr31) {
var $z1091110912 = D;
var $f1091710918 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg16554394,anf_arg165810907):R.ffi.throwNonFunApp(L[661],_plus26,[anf_arg16554394,anf_arg165810907]);
};
try {
if(--R.GAS > 0) {
$z1091110912 = $f1091710918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1091710918,
"from":L[661]});
}
} catch($e1090910910) {
if(R.isCont($e1090910910)) {
var $ss1091310914 = {"from":L[661],
"go":function(anf_arg165910919) {
return $Hanf_arg347610920(anf_arg165910919,self2114395,_plus26,torepr31);
}};
$e1090910910.stack[R.EXN_STACKHEIGHT++] = $ss1091310914;
}
if(R.isPyretException($e1090910910)) {
$e1090910910.pyretStack.push(L[661]);
}
throw $e1090910910;
}
var $ret1091510916 = $Hanf_arg347610920($z1091110912,self2114395,_plus26,torepr31);
++R.GAS;
return $ret1091510916;
};
var $Hanf_arg347610920 = function(anf_arg165910919,self2114395,_plus26,torepr31) {
var anf_arg166010931 = G(self2114395,"ret",L[661]);
var $z1092310924 = D;
var $f1092910930 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg166010931):R.ffi.throwNonFunApp(L[661],torepr31,[anf_arg166010931]);
};
try {
if(--R.GAS > 0) {
$z1092310924 = $f1092910930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1092910930,
"from":L[661]});
}
} catch($e1092110922) {
if(R.isCont($e1092110922)) {
var $ss1092510926 = {"from":L[661],
"go":function(anf_arg166110932) {
return $Hanf_arg347510933(anf_arg166110932,anf_arg165910919,self2114395,_plus26,torepr31);
}};
$e1092110922.stack[R.EXN_STACKHEIGHT++] = $ss1092510926;
}
if(R.isPyretException($e1092110922)) {
$e1092110922.pyretStack.push(L[661]);
}
throw $e1092110922;
}
var $ret1092710928 = $Hanf_arg347510933($z1092310924,anf_arg165910919,self2114395,_plus26,torepr31);
++R.GAS;
return $ret1092710928;
};
var $Hanf_arg347510933 = function(anf_arg166110932,anf_arg165910919,self2114395,_plus26,torepr31) {
var $z1093610937 = D;
var $f1094210943 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg166110932):R.ffi.throwNonFunApp(L[661],_plus26,[(", "),anf_arg166110932]);
};
try {
if(--R.GAS > 0) {
$z1093610937 = $f1094210943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1094210943,
"from":L[661]});
}
} catch($e1093410935) {
if(R.isCont($e1093410935)) {
var $ss1093810939 = {"from":L[661],
"go":function(anf_arg166210944) {
return $Hanf_arg347410945(anf_arg166210944,anf_arg165910919,self2114395,_plus26,torepr31);
}};
$e1093410935.stack[R.EXN_STACKHEIGHT++] = $ss1093810939;
}
if(R.isPyretException($e1093410935)) {
$e1093410935.pyretStack.push(L[661]);
}
throw $e1093410935;
}
var $ret1094010941 = $Hanf_arg347410945($z1093610937,anf_arg165910919,self2114395,_plus26,torepr31);
++R.GAS;
return $ret1094010941;
};
var $Hanf_arg347410945 = function(anf_arg166210944,anf_arg165910919,self2114395,_plus26,torepr31) {
var $z1094810949 = D;
var $f1095410955 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg165910919,anf_arg166210944):R.ffi.throwNonFunApp(L[661],_plus26,[anf_arg165910919,anf_arg166210944]);
};
try {
if(--R.GAS > 0) {
$z1094810949 = $f1095410955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1095410955,
"from":L[661]});
}
} catch($e1094610947) {
if(R.isCont($e1094610947)) {
var $ss1095010951 = {"from":L[661],
"go":function(anf_arg166310956) {
return $Hanf_arg347310957(anf_arg166310956,self2114395,_plus26,torepr31);
}};
$e1094610947.stack[R.EXN_STACKHEIGHT++] = $ss1095010951;
}
if(R.isPyretException($e1094610947)) {
$e1094610947.pyretStack.push(L[661]);
}
throw $e1094610947;
}
var $ret1095210953 = $Hanf_arg347310957($z1094810949,self2114395,_plus26,torepr31);
++R.GAS;
return $ret1095210953;
};
var $Hanf_arg347310957 = function(anf_arg166310956,self2114395,_plus26,torepr31) {
var anf_arg166410968 = G(self2114395,"body",L[661]);
var $z1096010961 = D;
var $f1096610967 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg166410968):R.ffi.throwNonFunApp(L[661],torepr31,[anf_arg166410968]);
};
try {
if(--R.GAS > 0) {
$z1096010961 = $f1096610967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1096610967,
"from":L[661]});
}
} catch($e1095810959) {
if(R.isCont($e1095810959)) {
var $ss1096210963 = {"from":L[661],
"go":function(anf_arg166510969) {
return $Hanf_arg347210970(anf_arg166510969,anf_arg166310956,_plus26);
}};
$e1095810959.stack[R.EXN_STACKHEIGHT++] = $ss1096210963;
}
if(R.isPyretException($e1095810959)) {
$e1095810959.pyretStack.push(L[661]);
}
throw $e1095810959;
}
var $ret1096410965 = $Hanf_arg347210970($z1096010961,anf_arg166310956,_plus26);
++R.GAS;
return $ret1096410965;
};
var $Hanf_arg347210970 = function(anf_arg166510969,anf_arg166310956,_plus26) {
var $z1097310974 = D;
var $f1097910980 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg166510969):R.ffi.throwNonFunApp(L[661],_plus26,[(", "),anf_arg166510969]);
};
try {
if(--R.GAS > 0) {
$z1097310974 = $f1097910980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1097910980,
"from":L[661]});
}
} catch($e1097110972) {
if(R.isCont($e1097110972)) {
var $ss1097510976 = {"from":L[661],
"go":function(anf_arg166610981) {
return $Hanf_arg347110982(anf_arg166610981,anf_arg166310956,_plus26);
}};
$e1097110972.stack[R.EXN_STACKHEIGHT++] = $ss1097510976;
}
if(R.isPyretException($e1097110972)) {
$e1097110972.pyretStack.push(L[661]);
}
throw $e1097110972;
}
var $ret1097710978 = $Hanf_arg347110982($z1097310974,anf_arg166310956,_plus26);
++R.GAS;
return $ret1097710978;
};
var $Hanf_arg347110982 = function(anf_arg166610981,anf_arg166310956,_plus26) {
var $z1098510986 = D;
var $f1099110992 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg166310956,anf_arg166610981):R.ffi.throwNonFunApp(L[661],_plus26,[anf_arg166310956,anf_arg166610981]);
};
try {
if(--R.GAS > 0) {
$z1098510986 = $f1099110992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1099110992,
"from":L[661]});
}
} catch($e1098310984) {
if(R.isCont($e1098310984)) {
var $ss1098710988 = {"from":L[661],
"go":function(anf_arg166710993) {
return $Hanf_arg347010994(anf_arg166710993,_plus26);
}};
$e1098310984.stack[R.EXN_STACKHEIGHT++] = $ss1098710988;
}
if(R.isPyretException($e1098310984)) {
$e1098310984.pyretStack.push(L[661]);
}
throw $e1098310984;
}
var $ret1098910990 = $Hanf_arg347010994($z1098510986,_plus26);
++R.GAS;
return $ret1098910990;
};
var $Hanf_arg347010994 = function(anf_arg166710993,_plus26) {
var $z1099710998 = D;
var $f1100311004 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg166710993,(")")):R.ffi.throwNonFunApp(L[661],_plus26,[anf_arg166710993,(")")]);
};
try {
if(--R.GAS > 0) {
$z1099710998 = $f1100311004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1100311004,
"from":L[661]});
}
} catch($e1099510996) {
if(R.isCont($e1099510996)) {
var $ss1099911000 = {"from":L[661],
"go":function(anf_arg166811005) {
return $Hanf_arg346911006(anf_arg166811005,_plus26);
}};
$e1099510996.stack[R.EXN_STACKHEIGHT++] = $ss1099911000;
}
if(R.isPyretException($e1099510996)) {
$e1099510996.pyretStack.push(L[661]);
}
throw $e1099510996;
}
var $ret1100111002 = $Hanf_arg346911006($z1099710998,_plus26);
++R.GAS;
return $ret1100111002;
};
var $Hanf_arg346911006 = function(anf_arg166811005,_plus26) {
var $z1100911010 = D;
var $f1101511016 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg166811005):R.ffi.throwNonFunApp(L[661],_plus26,[("("),anf_arg166811005]);
};
try {
if(--R.GAS > 0) {
$z1100911010 = $f1101511016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1101511016,
"from":L[661]});
}
} catch($e1100711008) {
if(R.isCont($e1100711008)) {
var $ss1101111012 = {"from":L[661],
"go":function(anf_arg166911017) {
return $Hanf_arg346811018(anf_arg166911017,_plus26);
}};
$e1100711008.stack[R.EXN_STACKHEIGHT++] = $ss1101111012;
}
if(R.isPyretException($e1100711008)) {
$e1100711008.pyretStack.push(L[661]);
}
throw $e1100711008;
}
var $ret1101311014 = $Hanf_arg346811018($z1100911010,_plus26);
++R.GAS;
return $ret1101311014;
};
var $Hanf_arg346811018 = function(anf_arg166911017,_plus26) {
var $z1102111022 = D;
var $f1102711028 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-method"),anf_arg166911017):R.ffi.throwNonFunApp(L[661],_plus26,[("a-method"),anf_arg166911017]);
};
try {
if(--R.GAS > 0) {
$z1102111022 = $f1102711028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1102711028,
"from":L[661]});
}
} catch($e1101911020) {
if(R.isCont($e1101911020)) {
var $ss1102311024 = {"from":L[661],
"go":function(ann_DASH_check_DASH_temp165311029) {
return $Hann_DASH_check_DASH_temp346711030(ann_DASH_check_DASH_temp165311029);
}};
$e1101911020.stack[R.EXN_STACKHEIGHT++] = $ss1102311024;
}
if(R.isPyretException($e1101911020)) {
$e1101911020.pyretStack.push(L[661]);
}
throw $e1101911020;
}
var $ret1102511026 = $Hann_DASH_check_DASH_temp346711030($z1102111022);
++R.GAS;
return $ret1102511026;
};
var $Hann_DASH_check_DASH_temp346711030 = function(ann_DASH_check_DASH_temp165311029) {
return ann_DASH_check_DASH_temp165311029;
};
var $Hcont_tail_arg34654414 = function(cont_tail_arg16504412,if_helper16394413) {
if(--R.GAS > 0) {
$z1103111032 = R.isFunction(if_helper16394413)?if_helper16394413.app(cont_tail_arg16504412):R.ffi.throwNonFunApp(L[661],if_helper16394413,[cont_tail_arg16504412]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper16394413)?if_helper16394413.app(cont_tail_arg16504412):R.ffi.throwNonFunApp(L[661],if_helper16394413,[cont_tail_arg16504412]);
},
"from":L[661]});
}
++R.GAS;
return $z1103111032;
};
var $Hcont_tail_arg34664429 = function(cont_tail_arg16444428,if_helper16394413) {
if(--R.GAS > 0) {
$z1103311034 = R.isFunction(if_helper16394413)?if_helper16394413.app(cont_tail_arg16444428):R.ffi.throwNonFunApp(L[661],if_helper16394413,[cont_tail_arg16444428]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper16394413)?if_helper16394413.app(cont_tail_arg16444428):R.ffi.throwNonFunApp(L[661],if_helper16394413,[cont_tail_arg16444428]);
},
"from":L[661]});
}
++R.GAS;
return $z1103311034;
};
var $Hanf_arg34644450 = function(anf_arg16344448,fun_DASH_method_DASH_pretty219597,self4434449) {
var anf_arg163511045 = G(self4434449,"args",L[1410]);
var anf_arg163611046 = G(self4434449,"body",L[1409]);
var $z1103711038 = D;
var $f1104311044 = function(_) {
return R.isFunction(fun_DASH_method_DASH_pretty219597.$var === D?U(L[1408],"fun-method-pretty"):fun_DASH_method_DASH_pretty219597.$var)?fun_DASH_method_DASH_pretty219597.$var === D?U(L[1408],"fun-method-pretty"):fun_DASH_method_DASH_pretty219597.$var.app(anf_arg16344448,anf_arg163511045,anf_arg163611046):R.ffi.throwNonFunApp(L[748],fun_DASH_method_DASH_pretty219597.$var === D?U(L[1408],"fun-method-pretty"):fun_DASH_method_DASH_pretty219597.$var,[anf_arg16344448,anf_arg163511045,anf_arg163611046]);
};
try {
if(--R.GAS > 0) {
$z1103711038 = $f1104311044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1104311044,
"from":L[748]});
}
} catch($e1103511036) {
if(R.isCont($e1103511036)) {
var $ss1103911040 = {"from":L[748],
"go":function(ann_DASH_check_DASH_temp163211047) {
return $Hann_DASH_check_DASH_temp346311048(ann_DASH_check_DASH_temp163211047);
}};
$e1103511036.stack[R.EXN_STACKHEIGHT++] = $ss1103911040;
}
if(R.isPyretException($e1103511036)) {
$e1103511036.pyretStack.push(L[748]);
}
throw $e1103511036;
}
var $ret1104111042 = $Hann_DASH_check_DASH_temp346311048($z1103711038);
++R.GAS;
return $ret1104111042;
};
var $Hann_DASH_check_DASH_temp346311048 = function(ann_DASH_check_DASH_temp163211047) {
return ann_DASH_check_DASH_temp163211047;
};
var $Hanf_arg34624466 = function(anf_arg16144464,self2054465,_plus26,torepr31) {
var anf_arg161511059 = G(self2054465,"args",L[662]);
var $z1105111052 = D;
var $f1105711058 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg161511059):R.ffi.throwNonFunApp(L[662],torepr31,[anf_arg161511059]);
};
try {
if(--R.GAS > 0) {
$z1105111052 = $f1105711058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1105711058,
"from":L[662]});
}
} catch($e1104911050) {
if(R.isCont($e1104911050)) {
var $ss1105311054 = {"from":L[662],
"go":function(anf_arg161611060) {
return $Hanf_arg346111061(anf_arg161611060,anf_arg16144464,self2054465,_plus26,torepr31);
}};
$e1104911050.stack[R.EXN_STACKHEIGHT++] = $ss1105311054;
}
if(R.isPyretException($e1104911050)) {
$e1104911050.pyretStack.push(L[662]);
}
throw $e1104911050;
}
var $ret1105511056 = $Hanf_arg346111061($z1105111052,anf_arg16144464,self2054465,_plus26,torepr31);
++R.GAS;
return $ret1105511056;
};
var $Hanf_arg346111061 = function(anf_arg161611060,anf_arg16144464,self2054465,_plus26,torepr31) {
var $z1106411065 = D;
var $f1107011071 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg161611060):R.ffi.throwNonFunApp(L[662],_plus26,[(", "),anf_arg161611060]);
};
try {
if(--R.GAS > 0) {
$z1106411065 = $f1107011071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1107011071,
"from":L[662]});
}
} catch($e1106211063) {
if(R.isCont($e1106211063)) {
var $ss1106611067 = {"from":L[662],
"go":function(anf_arg161711072) {
return $Hanf_arg346011073(anf_arg161711072,anf_arg16144464,self2054465,_plus26,torepr31);
}};
$e1106211063.stack[R.EXN_STACKHEIGHT++] = $ss1106611067;
}
if(R.isPyretException($e1106211063)) {
$e1106211063.pyretStack.push(L[662]);
}
throw $e1106211063;
}
var $ret1106811069 = $Hanf_arg346011073($z1106411065,anf_arg16144464,self2054465,_plus26,torepr31);
++R.GAS;
return $ret1106811069;
};
var $Hanf_arg346011073 = function(anf_arg161711072,anf_arg16144464,self2054465,_plus26,torepr31) {
var $z1107611077 = D;
var $f1108211083 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg16144464,anf_arg161711072):R.ffi.throwNonFunApp(L[662],_plus26,[anf_arg16144464,anf_arg161711072]);
};
try {
if(--R.GAS > 0) {
$z1107611077 = $f1108211083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1108211083,
"from":L[662]});
}
} catch($e1107411075) {
if(R.isCont($e1107411075)) {
var $ss1107811079 = {"from":L[662],
"go":function(anf_arg161811084) {
return $Hanf_arg345911085(anf_arg161811084,self2054465,_plus26,torepr31);
}};
$e1107411075.stack[R.EXN_STACKHEIGHT++] = $ss1107811079;
}
if(R.isPyretException($e1107411075)) {
$e1107411075.pyretStack.push(L[662]);
}
throw $e1107411075;
}
var $ret1108011081 = $Hanf_arg345911085($z1107611077,self2054465,_plus26,torepr31);
++R.GAS;
return $ret1108011081;
};
var $Hanf_arg345911085 = function(anf_arg161811084,self2054465,_plus26,torepr31) {
var anf_arg161911096 = G(self2054465,"ret",L[662]);
var $z1108811089 = D;
var $f1109411095 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg161911096):R.ffi.throwNonFunApp(L[662],torepr31,[anf_arg161911096]);
};
try {
if(--R.GAS > 0) {
$z1108811089 = $f1109411095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1109411095,
"from":L[662]});
}
} catch($e1108611087) {
if(R.isCont($e1108611087)) {
var $ss1109011091 = {"from":L[662],
"go":function(anf_arg162011097) {
return $Hanf_arg345811098(anf_arg162011097,anf_arg161811084,self2054465,_plus26,torepr31);
}};
$e1108611087.stack[R.EXN_STACKHEIGHT++] = $ss1109011091;
}
if(R.isPyretException($e1108611087)) {
$e1108611087.pyretStack.push(L[662]);
}
throw $e1108611087;
}
var $ret1109211093 = $Hanf_arg345811098($z1108811089,anf_arg161811084,self2054465,_plus26,torepr31);
++R.GAS;
return $ret1109211093;
};
var $Hanf_arg345811098 = function(anf_arg162011097,anf_arg161811084,self2054465,_plus26,torepr31) {
var $z1110111102 = D;
var $f1110711108 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg162011097):R.ffi.throwNonFunApp(L[662],_plus26,[(", "),anf_arg162011097]);
};
try {
if(--R.GAS > 0) {
$z1110111102 = $f1110711108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1110711108,
"from":L[662]});
}
} catch($e1109911100) {
if(R.isCont($e1109911100)) {
var $ss1110311104 = {"from":L[662],
"go":function(anf_arg162111109) {
return $Hanf_arg345711110(anf_arg162111109,anf_arg161811084,self2054465,_plus26,torepr31);
}};
$e1109911100.stack[R.EXN_STACKHEIGHT++] = $ss1110311104;
}
if(R.isPyretException($e1109911100)) {
$e1109911100.pyretStack.push(L[662]);
}
throw $e1109911100;
}
var $ret1110511106 = $Hanf_arg345711110($z1110111102,anf_arg161811084,self2054465,_plus26,torepr31);
++R.GAS;
return $ret1110511106;
};
var $Hanf_arg345711110 = function(anf_arg162111109,anf_arg161811084,self2054465,_plus26,torepr31) {
var $z1111311114 = D;
var $f1111911120 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg161811084,anf_arg162111109):R.ffi.throwNonFunApp(L[662],_plus26,[anf_arg161811084,anf_arg162111109]);
};
try {
if(--R.GAS > 0) {
$z1111311114 = $f1111911120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1111911120,
"from":L[662]});
}
} catch($e1111111112) {
if(R.isCont($e1111111112)) {
var $ss1111511116 = {"from":L[662],
"go":function(anf_arg162211121) {
return $Hanf_arg345611122(anf_arg162211121,self2054465,_plus26,torepr31);
}};
$e1111111112.stack[R.EXN_STACKHEIGHT++] = $ss1111511116;
}
if(R.isPyretException($e1111111112)) {
$e1111111112.pyretStack.push(L[662]);
}
throw $e1111111112;
}
var $ret1111711118 = $Hanf_arg345611122($z1111311114,self2054465,_plus26,torepr31);
++R.GAS;
return $ret1111711118;
};
var $Hanf_arg345611122 = function(anf_arg162211121,self2054465,_plus26,torepr31) {
var anf_arg162311133 = G(self2054465,"body",L[662]);
var $z1112511126 = D;
var $f1113111132 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg162311133):R.ffi.throwNonFunApp(L[662],torepr31,[anf_arg162311133]);
};
try {
if(--R.GAS > 0) {
$z1112511126 = $f1113111132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1113111132,
"from":L[662]});
}
} catch($e1112311124) {
if(R.isCont($e1112311124)) {
var $ss1112711128 = {"from":L[662],
"go":function(anf_arg162411134) {
return $Hanf_arg345511135(anf_arg162411134,anf_arg162211121,_plus26);
}};
$e1112311124.stack[R.EXN_STACKHEIGHT++] = $ss1112711128;
}
if(R.isPyretException($e1112311124)) {
$e1112311124.pyretStack.push(L[662]);
}
throw $e1112311124;
}
var $ret1112911130 = $Hanf_arg345511135($z1112511126,anf_arg162211121,_plus26);
++R.GAS;
return $ret1112911130;
};
var $Hanf_arg345511135 = function(anf_arg162411134,anf_arg162211121,_plus26) {
var $z1113811139 = D;
var $f1114411145 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg162411134):R.ffi.throwNonFunApp(L[662],_plus26,[(", "),anf_arg162411134]);
};
try {
if(--R.GAS > 0) {
$z1113811139 = $f1114411145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1114411145,
"from":L[662]});
}
} catch($e1113611137) {
if(R.isCont($e1113611137)) {
var $ss1114011141 = {"from":L[662],
"go":function(anf_arg162511146) {
return $Hanf_arg345411147(anf_arg162511146,anf_arg162211121,_plus26);
}};
$e1113611137.stack[R.EXN_STACKHEIGHT++] = $ss1114011141;
}
if(R.isPyretException($e1113611137)) {
$e1113611137.pyretStack.push(L[662]);
}
throw $e1113611137;
}
var $ret1114211143 = $Hanf_arg345411147($z1113811139,anf_arg162211121,_plus26);
++R.GAS;
return $ret1114211143;
};
var $Hanf_arg345411147 = function(anf_arg162511146,anf_arg162211121,_plus26) {
var $z1115011151 = D;
var $f1115611157 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg162211121,anf_arg162511146):R.ffi.throwNonFunApp(L[662],_plus26,[anf_arg162211121,anf_arg162511146]);
};
try {
if(--R.GAS > 0) {
$z1115011151 = $f1115611157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1115611157,
"from":L[662]});
}
} catch($e1114811149) {
if(R.isCont($e1114811149)) {
var $ss1115211153 = {"from":L[662],
"go":function(anf_arg162611158) {
return $Hanf_arg345311159(anf_arg162611158,_plus26);
}};
$e1114811149.stack[R.EXN_STACKHEIGHT++] = $ss1115211153;
}
if(R.isPyretException($e1114811149)) {
$e1114811149.pyretStack.push(L[662]);
}
throw $e1114811149;
}
var $ret1115411155 = $Hanf_arg345311159($z1115011151,_plus26);
++R.GAS;
return $ret1115411155;
};
var $Hanf_arg345311159 = function(anf_arg162611158,_plus26) {
var $z1116211163 = D;
var $f1116811169 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg162611158,(")")):R.ffi.throwNonFunApp(L[662],_plus26,[anf_arg162611158,(")")]);
};
try {
if(--R.GAS > 0) {
$z1116211163 = $f1116811169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1116811169,
"from":L[662]});
}
} catch($e1116011161) {
if(R.isCont($e1116011161)) {
var $ss1116411165 = {"from":L[662],
"go":function(anf_arg162711170) {
return $Hanf_arg345211171(anf_arg162711170,_plus26);
}};
$e1116011161.stack[R.EXN_STACKHEIGHT++] = $ss1116411165;
}
if(R.isPyretException($e1116011161)) {
$e1116011161.pyretStack.push(L[662]);
}
throw $e1116011161;
}
var $ret1116611167 = $Hanf_arg345211171($z1116211163,_plus26);
++R.GAS;
return $ret1116611167;
};
var $Hanf_arg345211171 = function(anf_arg162711170,_plus26) {
var $z1117411175 = D;
var $f1118011181 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg162711170):R.ffi.throwNonFunApp(L[662],_plus26,[("("),anf_arg162711170]);
};
try {
if(--R.GAS > 0) {
$z1117411175 = $f1118011181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1118011181,
"from":L[662]});
}
} catch($e1117211173) {
if(R.isCont($e1117211173)) {
var $ss1117611177 = {"from":L[662],
"go":function(anf_arg162811182) {
return $Hanf_arg345111183(anf_arg162811182,_plus26);
}};
$e1117211173.stack[R.EXN_STACKHEIGHT++] = $ss1117611177;
}
if(R.isPyretException($e1117211173)) {
$e1117211173.pyretStack.push(L[662]);
}
throw $e1117211173;
}
var $ret1117811179 = $Hanf_arg345111183($z1117411175,_plus26);
++R.GAS;
return $ret1117811179;
};
var $Hanf_arg345111183 = function(anf_arg162811182,_plus26) {
var $z1118611187 = D;
var $f1119211193 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-lam"),anf_arg162811182):R.ffi.throwNonFunApp(L[662],_plus26,[("a-lam"),anf_arg162811182]);
};
try {
if(--R.GAS > 0) {
$z1118611187 = $f1119211193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1119211193,
"from":L[662]});
}
} catch($e1118411185) {
if(R.isCont($e1118411185)) {
var $ss1118811189 = {"from":L[662],
"go":function(ann_DASH_check_DASH_temp161211194) {
return $Hann_DASH_check_DASH_temp345011195(ann_DASH_check_DASH_temp161211194);
}};
$e1118411185.stack[R.EXN_STACKHEIGHT++] = $ss1118811189;
}
if(R.isPyretException($e1118411185)) {
$e1118411185.pyretStack.push(L[662]);
}
throw $e1118411185;
}
var $ret1119011191 = $Hann_DASH_check_DASH_temp345011195($z1118611187);
++R.GAS;
return $ret1119011191;
};
var $Hann_DASH_check_DASH_temp345011195 = function(ann_DASH_check_DASH_temp161211194) {
return ann_DASH_check_DASH_temp161211194;
};
var $Hcont_tail_arg34484484 = function(cont_tail_arg16094482,if_helper15984483) {
if(--R.GAS > 0) {
$z1119611197 = R.isFunction(if_helper15984483)?if_helper15984483.app(cont_tail_arg16094482):R.ffi.throwNonFunApp(L[662],if_helper15984483,[cont_tail_arg16094482]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15984483)?if_helper15984483.app(cont_tail_arg16094482):R.ffi.throwNonFunApp(L[662],if_helper15984483,[cont_tail_arg16094482]);
},
"from":L[662]});
}
++R.GAS;
return $z1119611197;
};
var $Hcont_tail_arg34494499 = function(cont_tail_arg16034498,if_helper15984483) {
if(--R.GAS > 0) {
$z1119811199 = R.isFunction(if_helper15984483)?if_helper15984483.app(cont_tail_arg16034498):R.ffi.throwNonFunApp(L[662],if_helper15984483,[cont_tail_arg16034498]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15984483)?if_helper15984483.app(cont_tail_arg16034498):R.ffi.throwNonFunApp(L[662],if_helper15984483,[cont_tail_arg16034498]);
},
"from":L[662]});
}
++R.GAS;
return $z1119811199;
};
var $Hanf_arg34474521 = function(anf_arg15924518,INDENT9187,PP337,anf_fun15894519,self4374520,str_DASH_bang96144) {
var anf_fun159311210 = G(PP337,"str",L[1413]);
var anf_arg159411211 = G(self4374520,"field",L[1412]);
var $z1120211203 = D;
var $f1120811209 = function(_) {
return R.isFunction(anf_fun159311210)?anf_fun159311210.app(anf_arg159411211):R.ffi.throwNonFunApp(L[1411],anf_fun159311210,[anf_arg159411211]);
};
try {
if(--R.GAS > 0) {
$z1120211203 = $f1120811209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1120811209,
"from":L[1411]});
}
} catch($e1120011201) {
if(R.isCont($e1120011201)) {
var $ss1120411205 = {"from":L[1411],
"go":function(anf_arg159511212) {
return $Hanf_arg344611213(anf_arg159511212,INDENT9187,anf_arg15924518,anf_fun15894519,str_DASH_bang96144);
}};
$e1120011201.stack[R.EXN_STACKHEIGHT++] = $ss1120411205;
}
if(R.isPyretException($e1120011201)) {
$e1120011201.pyretStack.push(L[1411]);
}
throw $e1120011201;
}
var $ret1120611207 = $Hanf_arg344611213($z1120211203,INDENT9187,anf_arg15924518,anf_fun15894519,str_DASH_bang96144);
++R.GAS;
return $ret1120611207;
};
var $Hanf_arg344611213 = function(anf_arg159511212,INDENT9187,anf_arg15924518,anf_fun15894519,str_DASH_bang96144) {
var $z1121611217 = D;
var $f1122211223 = function(_) {
return R.isFunction(anf_fun15894519)?anf_fun15894519.app(INDENT9187,(0),str_DASH_bang96144,anf_arg15924518,anf_arg159511212):R.ffi.throwNonFunApp(L[758],anf_fun15894519,[INDENT9187,(0),str_DASH_bang96144,anf_arg15924518,anf_arg159511212]);
};
try {
if(--R.GAS > 0) {
$z1121611217 = $f1122211223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1122211223,
"from":L[758]});
}
} catch($e1121411215) {
if(R.isCont($e1121411215)) {
var $ss1121811219 = {"from":L[758],
"go":function(ann_DASH_check_DASH_temp158811224) {
return $Hann_DASH_check_DASH_temp344511225(ann_DASH_check_DASH_temp158811224);
}};
$e1121411215.stack[R.EXN_STACKHEIGHT++] = $ss1121811219;
}
if(R.isPyretException($e1121411215)) {
$e1121411215.pyretStack.push(L[758]);
}
throw $e1121411215;
}
var $ret1122011221 = $Hann_DASH_check_DASH_temp344511225($z1121611217);
++R.GAS;
return $ret1122011221;
};
var $Hann_DASH_check_DASH_temp344511225 = function(ann_DASH_check_DASH_temp158811224) {
return ann_DASH_check_DASH_temp158811224;
};
var $Hanf_arg34444538 = function(anf_arg15744536,self1994537,_plus26,torepr31) {
var anf_arg157511236 = G(self1994537,"obj",L[663]);
var $z1122811229 = D;
var $f1123411235 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg157511236):R.ffi.throwNonFunApp(L[663],torepr31,[anf_arg157511236]);
};
try {
if(--R.GAS > 0) {
$z1122811229 = $f1123411235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1123411235,
"from":L[663]});
}
} catch($e1122611227) {
if(R.isCont($e1122611227)) {
var $ss1123011231 = {"from":L[663],
"go":function(anf_arg157611237) {
return $Hanf_arg344311238(anf_arg157611237,anf_arg15744536,self1994537,_plus26,torepr31);
}};
$e1122611227.stack[R.EXN_STACKHEIGHT++] = $ss1123011231;
}
if(R.isPyretException($e1122611227)) {
$e1122611227.pyretStack.push(L[663]);
}
throw $e1122611227;
}
var $ret1123211233 = $Hanf_arg344311238($z1122811229,anf_arg15744536,self1994537,_plus26,torepr31);
++R.GAS;
return $ret1123211233;
};
var $Hanf_arg344311238 = function(anf_arg157611237,anf_arg15744536,self1994537,_plus26,torepr31) {
var $z1124111242 = D;
var $f1124711248 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg157611237):R.ffi.throwNonFunApp(L[663],_plus26,[(", "),anf_arg157611237]);
};
try {
if(--R.GAS > 0) {
$z1124111242 = $f1124711248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1124711248,
"from":L[663]});
}
} catch($e1123911240) {
if(R.isCont($e1123911240)) {
var $ss1124311244 = {"from":L[663],
"go":function(anf_arg157711249) {
return $Hanf_arg344211250(anf_arg157711249,anf_arg15744536,self1994537,_plus26,torepr31);
}};
$e1123911240.stack[R.EXN_STACKHEIGHT++] = $ss1124311244;
}
if(R.isPyretException($e1123911240)) {
$e1123911240.pyretStack.push(L[663]);
}
throw $e1123911240;
}
var $ret1124511246 = $Hanf_arg344211250($z1124111242,anf_arg15744536,self1994537,_plus26,torepr31);
++R.GAS;
return $ret1124511246;
};
var $Hanf_arg344211250 = function(anf_arg157711249,anf_arg15744536,self1994537,_plus26,torepr31) {
var $z1125311254 = D;
var $f1125911260 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg15744536,anf_arg157711249):R.ffi.throwNonFunApp(L[663],_plus26,[anf_arg15744536,anf_arg157711249]);
};
try {
if(--R.GAS > 0) {
$z1125311254 = $f1125911260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1125911260,
"from":L[663]});
}
} catch($e1125111252) {
if(R.isCont($e1125111252)) {
var $ss1125511256 = {"from":L[663],
"go":function(anf_arg157811261) {
return $Hanf_arg344111262(anf_arg157811261,self1994537,_plus26,torepr31);
}};
$e1125111252.stack[R.EXN_STACKHEIGHT++] = $ss1125511256;
}
if(R.isPyretException($e1125111252)) {
$e1125111252.pyretStack.push(L[663]);
}
throw $e1125111252;
}
var $ret1125711258 = $Hanf_arg344111262($z1125311254,self1994537,_plus26,torepr31);
++R.GAS;
return $ret1125711258;
};
var $Hanf_arg344111262 = function(anf_arg157811261,self1994537,_plus26,torepr31) {
var anf_arg157911273 = G(self1994537,"field",L[663]);
var $z1126511266 = D;
var $f1127111272 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg157911273):R.ffi.throwNonFunApp(L[663],torepr31,[anf_arg157911273]);
};
try {
if(--R.GAS > 0) {
$z1126511266 = $f1127111272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1127111272,
"from":L[663]});
}
} catch($e1126311264) {
if(R.isCont($e1126311264)) {
var $ss1126711268 = {"from":L[663],
"go":function(anf_arg158011274) {
return $Hanf_arg344011275(anf_arg158011274,anf_arg157811261,_plus26);
}};
$e1126311264.stack[R.EXN_STACKHEIGHT++] = $ss1126711268;
}
if(R.isPyretException($e1126311264)) {
$e1126311264.pyretStack.push(L[663]);
}
throw $e1126311264;
}
var $ret1126911270 = $Hanf_arg344011275($z1126511266,anf_arg157811261,_plus26);
++R.GAS;
return $ret1126911270;
};
var $Hanf_arg344011275 = function(anf_arg158011274,anf_arg157811261,_plus26) {
var $z1127811279 = D;
var $f1128411285 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg158011274):R.ffi.throwNonFunApp(L[663],_plus26,[(", "),anf_arg158011274]);
};
try {
if(--R.GAS > 0) {
$z1127811279 = $f1128411285();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1128411285,
"from":L[663]});
}
} catch($e1127611277) {
if(R.isCont($e1127611277)) {
var $ss1128011281 = {"from":L[663],
"go":function(anf_arg158111286) {
return $Hanf_arg343911287(anf_arg158111286,anf_arg157811261,_plus26);
}};
$e1127611277.stack[R.EXN_STACKHEIGHT++] = $ss1128011281;
}
if(R.isPyretException($e1127611277)) {
$e1127611277.pyretStack.push(L[663]);
}
throw $e1127611277;
}
var $ret1128211283 = $Hanf_arg343911287($z1127811279,anf_arg157811261,_plus26);
++R.GAS;
return $ret1128211283;
};
var $Hanf_arg343911287 = function(anf_arg158111286,anf_arg157811261,_plus26) {
var $z1129011291 = D;
var $f1129611297 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg157811261,anf_arg158111286):R.ffi.throwNonFunApp(L[663],_plus26,[anf_arg157811261,anf_arg158111286]);
};
try {
if(--R.GAS > 0) {
$z1129011291 = $f1129611297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1129611297,
"from":L[663]});
}
} catch($e1128811289) {
if(R.isCont($e1128811289)) {
var $ss1129211293 = {"from":L[663],
"go":function(anf_arg158211298) {
return $Hanf_arg343811299(anf_arg158211298,_plus26);
}};
$e1128811289.stack[R.EXN_STACKHEIGHT++] = $ss1129211293;
}
if(R.isPyretException($e1128811289)) {
$e1128811289.pyretStack.push(L[663]);
}
throw $e1128811289;
}
var $ret1129411295 = $Hanf_arg343811299($z1129011291,_plus26);
++R.GAS;
return $ret1129411295;
};
var $Hanf_arg343811299 = function(anf_arg158211298,_plus26) {
var $z1130211303 = D;
var $f1130811309 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg158211298,(")")):R.ffi.throwNonFunApp(L[663],_plus26,[anf_arg158211298,(")")]);
};
try {
if(--R.GAS > 0) {
$z1130211303 = $f1130811309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1130811309,
"from":L[663]});
}
} catch($e1130011301) {
if(R.isCont($e1130011301)) {
var $ss1130411305 = {"from":L[663],
"go":function(anf_arg158311310) {
return $Hanf_arg343711311(anf_arg158311310,_plus26);
}};
$e1130011301.stack[R.EXN_STACKHEIGHT++] = $ss1130411305;
}
if(R.isPyretException($e1130011301)) {
$e1130011301.pyretStack.push(L[663]);
}
throw $e1130011301;
}
var $ret1130611307 = $Hanf_arg343711311($z1130211303,_plus26);
++R.GAS;
return $ret1130611307;
};
var $Hanf_arg343711311 = function(anf_arg158311310,_plus26) {
var $z1131411315 = D;
var $f1132011321 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg158311310):R.ffi.throwNonFunApp(L[663],_plus26,[("("),anf_arg158311310]);
};
try {
if(--R.GAS > 0) {
$z1131411315 = $f1132011321();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1132011321,
"from":L[663]});
}
} catch($e1131211313) {
if(R.isCont($e1131211313)) {
var $ss1131611317 = {"from":L[663],
"go":function(anf_arg158411322) {
return $Hanf_arg343611323(anf_arg158411322,_plus26);
}};
$e1131211313.stack[R.EXN_STACKHEIGHT++] = $ss1131611317;
}
if(R.isPyretException($e1131211313)) {
$e1131211313.pyretStack.push(L[663]);
}
throw $e1131211313;
}
var $ret1131811319 = $Hanf_arg343611323($z1131411315,_plus26);
++R.GAS;
return $ret1131811319;
};
var $Hanf_arg343611323 = function(anf_arg158411322,_plus26) {
var $z1132611327 = D;
var $f1133211333 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-get-bang"),anf_arg158411322):R.ffi.throwNonFunApp(L[663],_plus26,[("a-get-bang"),anf_arg158411322]);
};
try {
if(--R.GAS > 0) {
$z1132611327 = $f1133211333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1133211333,
"from":L[663]});
}
} catch($e1132411325) {
if(R.isCont($e1132411325)) {
var $ss1132811329 = {"from":L[663],
"go":function(ann_DASH_check_DASH_temp157211334) {
return $Hann_DASH_check_DASH_temp343511335(ann_DASH_check_DASH_temp157211334);
}};
$e1132411325.stack[R.EXN_STACKHEIGHT++] = $ss1132811329;
}
if(R.isPyretException($e1132411325)) {
$e1132411325.pyretStack.push(L[663]);
}
throw $e1132411325;
}
var $ret1133011331 = $Hann_DASH_check_DASH_temp343511335($z1132611327);
++R.GAS;
return $ret1133011331;
};
var $Hann_DASH_check_DASH_temp343511335 = function(ann_DASH_check_DASH_temp157211334) {
return ann_DASH_check_DASH_temp157211334;
};
var $Hcont_tail_arg34334555 = function(cont_tail_arg15694553,if_helper15594554) {
if(--R.GAS > 0) {
$z1133611337 = R.isFunction(if_helper15594554)?if_helper15594554.app(cont_tail_arg15694553):R.ffi.throwNonFunApp(L[663],if_helper15594554,[cont_tail_arg15694553]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15594554)?if_helper15594554.app(cont_tail_arg15694553):R.ffi.throwNonFunApp(L[663],if_helper15594554,[cont_tail_arg15694553]);
},
"from":L[663]});
}
++R.GAS;
return $z1133611337;
};
var $Hcont_tail_arg34344570 = function(cont_tail_arg15644569,if_helper15594554) {
if(--R.GAS > 0) {
$z1133811339 = R.isFunction(if_helper15594554)?if_helper15594554.app(cont_tail_arg15644569):R.ffi.throwNonFunApp(L[663],if_helper15594554,[cont_tail_arg15644569]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15594554)?if_helper15594554.app(cont_tail_arg15644569):R.ffi.throwNonFunApp(L[663],if_helper15594554,[cont_tail_arg15644569]);
},
"from":L[663]});
}
++R.GAS;
return $z1133811339;
};
var $Hanf_arg34324592 = function(anf_arg15534589,INDENT9187,PP337,anf_fun15504590,self4324591,str_DASH_colon98170) {
var anf_fun155411350 = G(PP337,"str",L[1416]);
var anf_arg155511351 = G(self4324591,"field",L[1415]);
var $z1134211343 = D;
var $f1134811349 = function(_) {
return R.isFunction(anf_fun155411350)?anf_fun155411350.app(anf_arg155511351):R.ffi.throwNonFunApp(L[1414],anf_fun155411350,[anf_arg155511351]);
};
try {
if(--R.GAS > 0) {
$z1134211343 = $f1134811349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1134811349,
"from":L[1414]});
}
} catch($e1134011341) {
if(R.isCont($e1134011341)) {
var $ss1134411345 = {"from":L[1414],
"go":function(anf_arg155611352) {
return $Hanf_arg343111353(anf_arg155611352,INDENT9187,anf_arg15534589,anf_fun15504590,str_DASH_colon98170);
}};
$e1134011341.stack[R.EXN_STACKHEIGHT++] = $ss1134411345;
}
if(R.isPyretException($e1134011341)) {
$e1134011341.pyretStack.push(L[1414]);
}
throw $e1134011341;
}
var $ret1134611347 = $Hanf_arg343111353($z1134211343,INDENT9187,anf_arg15534589,anf_fun15504590,str_DASH_colon98170);
++R.GAS;
return $ret1134611347;
};
var $Hanf_arg343111353 = function(anf_arg155611352,INDENT9187,anf_arg15534589,anf_fun15504590,str_DASH_colon98170) {
var $z1135611357 = D;
var $f1136211363 = function(_) {
return R.isFunction(anf_fun15504590)?anf_fun15504590.app(INDENT9187,(0),str_DASH_colon98170,anf_arg15534589,anf_arg155611352):R.ffi.throwNonFunApp(L[767],anf_fun15504590,[INDENT9187,(0),str_DASH_colon98170,anf_arg15534589,anf_arg155611352]);
};
try {
if(--R.GAS > 0) {
$z1135611357 = $f1136211363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1136211363,
"from":L[767]});
}
} catch($e1135411355) {
if(R.isCont($e1135411355)) {
var $ss1135811359 = {"from":L[767],
"go":function(ann_DASH_check_DASH_temp154911364) {
return $Hann_DASH_check_DASH_temp343011365(ann_DASH_check_DASH_temp154911364);
}};
$e1135411355.stack[R.EXN_STACKHEIGHT++] = $ss1135811359;
}
if(R.isPyretException($e1135411355)) {
$e1135411355.pyretStack.push(L[767]);
}
throw $e1135411355;
}
var $ret1136011361 = $Hann_DASH_check_DASH_temp343011365($z1135611357);
++R.GAS;
return $ret1136011361;
};
var $Hann_DASH_check_DASH_temp343011365 = function(ann_DASH_check_DASH_temp154911364) {
return ann_DASH_check_DASH_temp154911364;
};
var $Hanf_arg34294609 = function(anf_arg15354607,self1934608,_plus26,torepr31) {
var anf_arg153611376 = G(self1934608,"obj",L[664]);
var $z1136811369 = D;
var $f1137411375 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg153611376):R.ffi.throwNonFunApp(L[664],torepr31,[anf_arg153611376]);
};
try {
if(--R.GAS > 0) {
$z1136811369 = $f1137411375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1137411375,
"from":L[664]});
}
} catch($e1136611367) {
if(R.isCont($e1136611367)) {
var $ss1137011371 = {"from":L[664],
"go":function(anf_arg153711377) {
return $Hanf_arg342811378(anf_arg153711377,anf_arg15354607,self1934608,_plus26,torepr31);
}};
$e1136611367.stack[R.EXN_STACKHEIGHT++] = $ss1137011371;
}
if(R.isPyretException($e1136611367)) {
$e1136611367.pyretStack.push(L[664]);
}
throw $e1136611367;
}
var $ret1137211373 = $Hanf_arg342811378($z1136811369,anf_arg15354607,self1934608,_plus26,torepr31);
++R.GAS;
return $ret1137211373;
};
var $Hanf_arg342811378 = function(anf_arg153711377,anf_arg15354607,self1934608,_plus26,torepr31) {
var $z1138111382 = D;
var $f1138711388 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg153711377):R.ffi.throwNonFunApp(L[664],_plus26,[(", "),anf_arg153711377]);
};
try {
if(--R.GAS > 0) {
$z1138111382 = $f1138711388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1138711388,
"from":L[664]});
}
} catch($e1137911380) {
if(R.isCont($e1137911380)) {
var $ss1138311384 = {"from":L[664],
"go":function(anf_arg153811389) {
return $Hanf_arg342711390(anf_arg153811389,anf_arg15354607,self1934608,_plus26,torepr31);
}};
$e1137911380.stack[R.EXN_STACKHEIGHT++] = $ss1138311384;
}
if(R.isPyretException($e1137911380)) {
$e1137911380.pyretStack.push(L[664]);
}
throw $e1137911380;
}
var $ret1138511386 = $Hanf_arg342711390($z1138111382,anf_arg15354607,self1934608,_plus26,torepr31);
++R.GAS;
return $ret1138511386;
};
var $Hanf_arg342711390 = function(anf_arg153811389,anf_arg15354607,self1934608,_plus26,torepr31) {
var $z1139311394 = D;
var $f1139911400 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg15354607,anf_arg153811389):R.ffi.throwNonFunApp(L[664],_plus26,[anf_arg15354607,anf_arg153811389]);
};
try {
if(--R.GAS > 0) {
$z1139311394 = $f1139911400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1139911400,
"from":L[664]});
}
} catch($e1139111392) {
if(R.isCont($e1139111392)) {
var $ss1139511396 = {"from":L[664],
"go":function(anf_arg153911401) {
return $Hanf_arg342611402(anf_arg153911401,self1934608,_plus26,torepr31);
}};
$e1139111392.stack[R.EXN_STACKHEIGHT++] = $ss1139511396;
}
if(R.isPyretException($e1139111392)) {
$e1139111392.pyretStack.push(L[664]);
}
throw $e1139111392;
}
var $ret1139711398 = $Hanf_arg342611402($z1139311394,self1934608,_plus26,torepr31);
++R.GAS;
return $ret1139711398;
};
var $Hanf_arg342611402 = function(anf_arg153911401,self1934608,_plus26,torepr31) {
var anf_arg154011413 = G(self1934608,"field",L[664]);
var $z1140511406 = D;
var $f1141111412 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg154011413):R.ffi.throwNonFunApp(L[664],torepr31,[anf_arg154011413]);
};
try {
if(--R.GAS > 0) {
$z1140511406 = $f1141111412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1141111412,
"from":L[664]});
}
} catch($e1140311404) {
if(R.isCont($e1140311404)) {
var $ss1140711408 = {"from":L[664],
"go":function(anf_arg154111414) {
return $Hanf_arg342511415(anf_arg154111414,anf_arg153911401,_plus26);
}};
$e1140311404.stack[R.EXN_STACKHEIGHT++] = $ss1140711408;
}
if(R.isPyretException($e1140311404)) {
$e1140311404.pyretStack.push(L[664]);
}
throw $e1140311404;
}
var $ret1140911410 = $Hanf_arg342511415($z1140511406,anf_arg153911401,_plus26);
++R.GAS;
return $ret1140911410;
};
var $Hanf_arg342511415 = function(anf_arg154111414,anf_arg153911401,_plus26) {
var $z1141811419 = D;
var $f1142411425 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg154111414):R.ffi.throwNonFunApp(L[664],_plus26,[(", "),anf_arg154111414]);
};
try {
if(--R.GAS > 0) {
$z1141811419 = $f1142411425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1142411425,
"from":L[664]});
}
} catch($e1141611417) {
if(R.isCont($e1141611417)) {
var $ss1142011421 = {"from":L[664],
"go":function(anf_arg154211426) {
return $Hanf_arg342411427(anf_arg154211426,anf_arg153911401,_plus26);
}};
$e1141611417.stack[R.EXN_STACKHEIGHT++] = $ss1142011421;
}
if(R.isPyretException($e1141611417)) {
$e1141611417.pyretStack.push(L[664]);
}
throw $e1141611417;
}
var $ret1142211423 = $Hanf_arg342411427($z1141811419,anf_arg153911401,_plus26);
++R.GAS;
return $ret1142211423;
};
var $Hanf_arg342411427 = function(anf_arg154211426,anf_arg153911401,_plus26) {
var $z1143011431 = D;
var $f1143611437 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg153911401,anf_arg154211426):R.ffi.throwNonFunApp(L[664],_plus26,[anf_arg153911401,anf_arg154211426]);
};
try {
if(--R.GAS > 0) {
$z1143011431 = $f1143611437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1143611437,
"from":L[664]});
}
} catch($e1142811429) {
if(R.isCont($e1142811429)) {
var $ss1143211433 = {"from":L[664],
"go":function(anf_arg154311438) {
return $Hanf_arg342311439(anf_arg154311438,_plus26);
}};
$e1142811429.stack[R.EXN_STACKHEIGHT++] = $ss1143211433;
}
if(R.isPyretException($e1142811429)) {
$e1142811429.pyretStack.push(L[664]);
}
throw $e1142811429;
}
var $ret1143411435 = $Hanf_arg342311439($z1143011431,_plus26);
++R.GAS;
return $ret1143411435;
};
var $Hanf_arg342311439 = function(anf_arg154311438,_plus26) {
var $z1144211443 = D;
var $f1144811449 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg154311438,(")")):R.ffi.throwNonFunApp(L[664],_plus26,[anf_arg154311438,(")")]);
};
try {
if(--R.GAS > 0) {
$z1144211443 = $f1144811449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1144811449,
"from":L[664]});
}
} catch($e1144011441) {
if(R.isCont($e1144011441)) {
var $ss1144411445 = {"from":L[664],
"go":function(anf_arg154411450) {
return $Hanf_arg342211451(anf_arg154411450,_plus26);
}};
$e1144011441.stack[R.EXN_STACKHEIGHT++] = $ss1144411445;
}
if(R.isPyretException($e1144011441)) {
$e1144011441.pyretStack.push(L[664]);
}
throw $e1144011441;
}
var $ret1144611447 = $Hanf_arg342211451($z1144211443,_plus26);
++R.GAS;
return $ret1144611447;
};
var $Hanf_arg342211451 = function(anf_arg154411450,_plus26) {
var $z1145411455 = D;
var $f1146011461 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg154411450):R.ffi.throwNonFunApp(L[664],_plus26,[("("),anf_arg154411450]);
};
try {
if(--R.GAS > 0) {
$z1145411455 = $f1146011461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1146011461,
"from":L[664]});
}
} catch($e1145211453) {
if(R.isCont($e1145211453)) {
var $ss1145611457 = {"from":L[664],
"go":function(anf_arg154511462) {
return $Hanf_arg342111463(anf_arg154511462,_plus26);
}};
$e1145211453.stack[R.EXN_STACKHEIGHT++] = $ss1145611457;
}
if(R.isPyretException($e1145211453)) {
$e1145211453.pyretStack.push(L[664]);
}
throw $e1145211453;
}
var $ret1145811459 = $Hanf_arg342111463($z1145411455,_plus26);
++R.GAS;
return $ret1145811459;
};
var $Hanf_arg342111463 = function(anf_arg154511462,_plus26) {
var $z1146611467 = D;
var $f1147211473 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-colon"),anf_arg154511462):R.ffi.throwNonFunApp(L[664],_plus26,[("a-colon"),anf_arg154511462]);
};
try {
if(--R.GAS > 0) {
$z1146611467 = $f1147211473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1147211473,
"from":L[664]});
}
} catch($e1146411465) {
if(R.isCont($e1146411465)) {
var $ss1146811469 = {"from":L[664],
"go":function(ann_DASH_check_DASH_temp153311474) {
return $Hann_DASH_check_DASH_temp342011475(ann_DASH_check_DASH_temp153311474);
}};
$e1146411465.stack[R.EXN_STACKHEIGHT++] = $ss1146811469;
}
if(R.isPyretException($e1146411465)) {
$e1146411465.pyretStack.push(L[664]);
}
throw $e1146411465;
}
var $ret1147011471 = $Hann_DASH_check_DASH_temp342011475($z1146611467);
++R.GAS;
return $ret1147011471;
};
var $Hann_DASH_check_DASH_temp342011475 = function(ann_DASH_check_DASH_temp153311474) {
return ann_DASH_check_DASH_temp153311474;
};
var $Hcont_tail_arg34184626 = function(cont_tail_arg15304624,if_helper15204625) {
if(--R.GAS > 0) {
$z1147611477 = R.isFunction(if_helper15204625)?if_helper15204625.app(cont_tail_arg15304624):R.ffi.throwNonFunApp(L[664],if_helper15204625,[cont_tail_arg15304624]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15204625)?if_helper15204625.app(cont_tail_arg15304624):R.ffi.throwNonFunApp(L[664],if_helper15204625,[cont_tail_arg15304624]);
},
"from":L[664]});
}
++R.GAS;
return $z1147611477;
};
var $Hcont_tail_arg34194641 = function(cont_tail_arg15254640,if_helper15204625) {
if(--R.GAS > 0) {
$z1147811479 = R.isFunction(if_helper15204625)?if_helper15204625.app(cont_tail_arg15254640):R.ffi.throwNonFunApp(L[664],if_helper15204625,[cont_tail_arg15254640]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper15204625)?if_helper15204625.app(cont_tail_arg15254640):R.ffi.throwNonFunApp(L[664],if_helper15204625,[cont_tail_arg15254640]);
},
"from":L[664]});
}
++R.GAS;
return $z1147811479;
};
var $Hanf_arg34174663 = function(anf_arg15144660,INDENT9187,PP337,anf_fun15114661,self4274662,str_DASH_period95131) {
var anf_fun151511490 = G(PP337,"str",L[1419]);
var anf_arg151611491 = G(self4274662,"field",L[1418]);
var $z1148211483 = D;
var $f1148811489 = function(_) {
return R.isFunction(anf_fun151511490)?anf_fun151511490.app(anf_arg151611491):R.ffi.throwNonFunApp(L[1417],anf_fun151511490,[anf_arg151611491]);
};
try {
if(--R.GAS > 0) {
$z1148211483 = $f1148811489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1148811489,
"from":L[1417]});
}
} catch($e1148011481) {
if(R.isCont($e1148011481)) {
var $ss1148411485 = {"from":L[1417],
"go":function(anf_arg151711492) {
return $Hanf_arg341611493(anf_arg151711492,INDENT9187,anf_arg15144660,anf_fun15114661,str_DASH_period95131);
}};
$e1148011481.stack[R.EXN_STACKHEIGHT++] = $ss1148411485;
}
if(R.isPyretException($e1148011481)) {
$e1148011481.pyretStack.push(L[1417]);
}
throw $e1148011481;
}
var $ret1148611487 = $Hanf_arg341611493($z1148211483,INDENT9187,anf_arg15144660,anf_fun15114661,str_DASH_period95131);
++R.GAS;
return $ret1148611487;
};
var $Hanf_arg341611493 = function(anf_arg151711492,INDENT9187,anf_arg15144660,anf_fun15114661,str_DASH_period95131) {
var $z1149611497 = D;
var $f1150211503 = function(_) {
return R.isFunction(anf_fun15114661)?anf_fun15114661.app(INDENT9187,(0),str_DASH_period95131,anf_arg15144660,anf_arg151711492):R.ffi.throwNonFunApp(L[776],anf_fun15114661,[INDENT9187,(0),str_DASH_period95131,anf_arg15144660,anf_arg151711492]);
};
try {
if(--R.GAS > 0) {
$z1149611497 = $f1150211503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1150211503,
"from":L[776]});
}
} catch($e1149411495) {
if(R.isCont($e1149411495)) {
var $ss1149811499 = {"from":L[776],
"go":function(ann_DASH_check_DASH_temp151011504) {
return $Hann_DASH_check_DASH_temp341511505(ann_DASH_check_DASH_temp151011504);
}};
$e1149411495.stack[R.EXN_STACKHEIGHT++] = $ss1149811499;
}
if(R.isPyretException($e1149411495)) {
$e1149411495.pyretStack.push(L[776]);
}
throw $e1149411495;
}
var $ret1150011501 = $Hann_DASH_check_DASH_temp341511505($z1149611497);
++R.GAS;
return $ret1150011501;
};
var $Hann_DASH_check_DASH_temp341511505 = function(ann_DASH_check_DASH_temp151011504) {
return ann_DASH_check_DASH_temp151011504;
};
var $Hanf_arg34144680 = function(anf_arg14964678,self1874679,_plus26,torepr31) {
var anf_arg149711516 = G(self1874679,"obj",L[665]);
var $z1150811509 = D;
var $f1151411515 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg149711516):R.ffi.throwNonFunApp(L[665],torepr31,[anf_arg149711516]);
};
try {
if(--R.GAS > 0) {
$z1150811509 = $f1151411515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1151411515,
"from":L[665]});
}
} catch($e1150611507) {
if(R.isCont($e1150611507)) {
var $ss1151011511 = {"from":L[665],
"go":function(anf_arg149811517) {
return $Hanf_arg341311518(anf_arg149811517,anf_arg14964678,self1874679,_plus26,torepr31);
}};
$e1150611507.stack[R.EXN_STACKHEIGHT++] = $ss1151011511;
}
if(R.isPyretException($e1150611507)) {
$e1150611507.pyretStack.push(L[665]);
}
throw $e1150611507;
}
var $ret1151211513 = $Hanf_arg341311518($z1150811509,anf_arg14964678,self1874679,_plus26,torepr31);
++R.GAS;
return $ret1151211513;
};
var $Hanf_arg341311518 = function(anf_arg149811517,anf_arg14964678,self1874679,_plus26,torepr31) {
var $z1152111522 = D;
var $f1152711528 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg149811517):R.ffi.throwNonFunApp(L[665],_plus26,[(", "),anf_arg149811517]);
};
try {
if(--R.GAS > 0) {
$z1152111522 = $f1152711528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1152711528,
"from":L[665]});
}
} catch($e1151911520) {
if(R.isCont($e1151911520)) {
var $ss1152311524 = {"from":L[665],
"go":function(anf_arg149911529) {
return $Hanf_arg341211530(anf_arg149911529,anf_arg14964678,self1874679,_plus26,torepr31);
}};
$e1151911520.stack[R.EXN_STACKHEIGHT++] = $ss1152311524;
}
if(R.isPyretException($e1151911520)) {
$e1151911520.pyretStack.push(L[665]);
}
throw $e1151911520;
}
var $ret1152511526 = $Hanf_arg341211530($z1152111522,anf_arg14964678,self1874679,_plus26,torepr31);
++R.GAS;
return $ret1152511526;
};
var $Hanf_arg341211530 = function(anf_arg149911529,anf_arg14964678,self1874679,_plus26,torepr31) {
var $z1153311534 = D;
var $f1153911540 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg14964678,anf_arg149911529):R.ffi.throwNonFunApp(L[665],_plus26,[anf_arg14964678,anf_arg149911529]);
};
try {
if(--R.GAS > 0) {
$z1153311534 = $f1153911540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1153911540,
"from":L[665]});
}
} catch($e1153111532) {
if(R.isCont($e1153111532)) {
var $ss1153511536 = {"from":L[665],
"go":function(anf_arg150011541) {
return $Hanf_arg341111542(anf_arg150011541,self1874679,_plus26,torepr31);
}};
$e1153111532.stack[R.EXN_STACKHEIGHT++] = $ss1153511536;
}
if(R.isPyretException($e1153111532)) {
$e1153111532.pyretStack.push(L[665]);
}
throw $e1153111532;
}
var $ret1153711538 = $Hanf_arg341111542($z1153311534,self1874679,_plus26,torepr31);
++R.GAS;
return $ret1153711538;
};
var $Hanf_arg341111542 = function(anf_arg150011541,self1874679,_plus26,torepr31) {
var anf_arg150111553 = G(self1874679,"field",L[665]);
var $z1154511546 = D;
var $f1155111552 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg150111553):R.ffi.throwNonFunApp(L[665],torepr31,[anf_arg150111553]);
};
try {
if(--R.GAS > 0) {
$z1154511546 = $f1155111552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1155111552,
"from":L[665]});
}
} catch($e1154311544) {
if(R.isCont($e1154311544)) {
var $ss1154711548 = {"from":L[665],
"go":function(anf_arg150211554) {
return $Hanf_arg341011555(anf_arg150211554,anf_arg150011541,_plus26);
}};
$e1154311544.stack[R.EXN_STACKHEIGHT++] = $ss1154711548;
}
if(R.isPyretException($e1154311544)) {
$e1154311544.pyretStack.push(L[665]);
}
throw $e1154311544;
}
var $ret1154911550 = $Hanf_arg341011555($z1154511546,anf_arg150011541,_plus26);
++R.GAS;
return $ret1154911550;
};
var $Hanf_arg341011555 = function(anf_arg150211554,anf_arg150011541,_plus26) {
var $z1155811559 = D;
var $f1156411565 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg150211554):R.ffi.throwNonFunApp(L[665],_plus26,[(", "),anf_arg150211554]);
};
try {
if(--R.GAS > 0) {
$z1155811559 = $f1156411565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1156411565,
"from":L[665]});
}
} catch($e1155611557) {
if(R.isCont($e1155611557)) {
var $ss1156011561 = {"from":L[665],
"go":function(anf_arg150311566) {
return $Hanf_arg340911567(anf_arg150311566,anf_arg150011541,_plus26);
}};
$e1155611557.stack[R.EXN_STACKHEIGHT++] = $ss1156011561;
}
if(R.isPyretException($e1155611557)) {
$e1155611557.pyretStack.push(L[665]);
}
throw $e1155611557;
}
var $ret1156211563 = $Hanf_arg340911567($z1155811559,anf_arg150011541,_plus26);
++R.GAS;
return $ret1156211563;
};
var $Hanf_arg340911567 = function(anf_arg150311566,anf_arg150011541,_plus26) {
var $z1157011571 = D;
var $f1157611577 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg150011541,anf_arg150311566):R.ffi.throwNonFunApp(L[665],_plus26,[anf_arg150011541,anf_arg150311566]);
};
try {
if(--R.GAS > 0) {
$z1157011571 = $f1157611577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1157611577,
"from":L[665]});
}
} catch($e1156811569) {
if(R.isCont($e1156811569)) {
var $ss1157211573 = {"from":L[665],
"go":function(anf_arg150411578) {
return $Hanf_arg340811579(anf_arg150411578,_plus26);
}};
$e1156811569.stack[R.EXN_STACKHEIGHT++] = $ss1157211573;
}
if(R.isPyretException($e1156811569)) {
$e1156811569.pyretStack.push(L[665]);
}
throw $e1156811569;
}
var $ret1157411575 = $Hanf_arg340811579($z1157011571,_plus26);
++R.GAS;
return $ret1157411575;
};
var $Hanf_arg340811579 = function(anf_arg150411578,_plus26) {
var $z1158211583 = D;
var $f1158811589 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg150411578,(")")):R.ffi.throwNonFunApp(L[665],_plus26,[anf_arg150411578,(")")]);
};
try {
if(--R.GAS > 0) {
$z1158211583 = $f1158811589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1158811589,
"from":L[665]});
}
} catch($e1158011581) {
if(R.isCont($e1158011581)) {
var $ss1158411585 = {"from":L[665],
"go":function(anf_arg150511590) {
return $Hanf_arg340711591(anf_arg150511590,_plus26);
}};
$e1158011581.stack[R.EXN_STACKHEIGHT++] = $ss1158411585;
}
if(R.isPyretException($e1158011581)) {
$e1158011581.pyretStack.push(L[665]);
}
throw $e1158011581;
}
var $ret1158611587 = $Hanf_arg340711591($z1158211583,_plus26);
++R.GAS;
return $ret1158611587;
};
var $Hanf_arg340711591 = function(anf_arg150511590,_plus26) {
var $z1159411595 = D;
var $f1160011601 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg150511590):R.ffi.throwNonFunApp(L[665],_plus26,[("("),anf_arg150511590]);
};
try {
if(--R.GAS > 0) {
$z1159411595 = $f1160011601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1160011601,
"from":L[665]});
}
} catch($e1159211593) {
if(R.isCont($e1159211593)) {
var $ss1159611597 = {"from":L[665],
"go":function(anf_arg150611602) {
return $Hanf_arg340611603(anf_arg150611602,_plus26);
}};
$e1159211593.stack[R.EXN_STACKHEIGHT++] = $ss1159611597;
}
if(R.isPyretException($e1159211593)) {
$e1159211593.pyretStack.push(L[665]);
}
throw $e1159211593;
}
var $ret1159811599 = $Hanf_arg340611603($z1159411595,_plus26);
++R.GAS;
return $ret1159811599;
};
var $Hanf_arg340611603 = function(anf_arg150611602,_plus26) {
var $z1160611607 = D;
var $f1161211613 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-dot"),anf_arg150611602):R.ffi.throwNonFunApp(L[665],_plus26,[("a-dot"),anf_arg150611602]);
};
try {
if(--R.GAS > 0) {
$z1160611607 = $f1161211613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1161211613,
"from":L[665]});
}
} catch($e1160411605) {
if(R.isCont($e1160411605)) {
var $ss1160811609 = {"from":L[665],
"go":function(ann_DASH_check_DASH_temp149411614) {
return $Hann_DASH_check_DASH_temp340511615(ann_DASH_check_DASH_temp149411614);
}};
$e1160411605.stack[R.EXN_STACKHEIGHT++] = $ss1160811609;
}
if(R.isPyretException($e1160411605)) {
$e1160411605.pyretStack.push(L[665]);
}
throw $e1160411605;
}
var $ret1161011611 = $Hann_DASH_check_DASH_temp340511615($z1160611607);
++R.GAS;
return $ret1161011611;
};
var $Hann_DASH_check_DASH_temp340511615 = function(ann_DASH_check_DASH_temp149411614) {
return ann_DASH_check_DASH_temp149411614;
};
var $Hcont_tail_arg34034697 = function(cont_tail_arg14914695,if_helper14814696) {
if(--R.GAS > 0) {
$z1161611617 = R.isFunction(if_helper14814696)?if_helper14814696.app(cont_tail_arg14914695):R.ffi.throwNonFunApp(L[665],if_helper14814696,[cont_tail_arg14914695]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14814696)?if_helper14814696.app(cont_tail_arg14914695):R.ffi.throwNonFunApp(L[665],if_helper14814696,[cont_tail_arg14914695]);
},
"from":L[665]});
}
++R.GAS;
return $z1161611617;
};
var $Hcont_tail_arg34044712 = function(cont_tail_arg14864711,if_helper14814696) {
if(--R.GAS > 0) {
$z1161811619 = R.isFunction(if_helper14814696)?if_helper14814696.app(cont_tail_arg14864711):R.ffi.throwNonFunApp(L[665],if_helper14814696,[cont_tail_arg14864711]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14814696)?if_helper14814696.app(cont_tail_arg14864711):R.ffi.throwNonFunApp(L[665],if_helper14814696,[cont_tail_arg14864711]);
},
"from":L[665]});
}
++R.GAS;
return $z1161811619;
};
var $Hann_DASH_check_DASH_temp34024732 = function(ann_DASH_check_DASH_temp14774731) {
return ann_DASH_check_DASH_temp14774731;
};
var $Hanf_arg34014749 = function(anf_arg14634747,self1814748,_plus26,torepr31) {
var anf_arg146411630 = G(self1814748,"supe",L[666]);
var $z1162211623 = D;
var $f1162811629 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg146411630):R.ffi.throwNonFunApp(L[666],torepr31,[anf_arg146411630]);
};
try {
if(--R.GAS > 0) {
$z1162211623 = $f1162811629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1162811629,
"from":L[666]});
}
} catch($e1162011621) {
if(R.isCont($e1162011621)) {
var $ss1162411625 = {"from":L[666],
"go":function(anf_arg146511631) {
return $Hanf_arg340011632(anf_arg146511631,anf_arg14634747,self1814748,_plus26,torepr31);
}};
$e1162011621.stack[R.EXN_STACKHEIGHT++] = $ss1162411625;
}
if(R.isPyretException($e1162011621)) {
$e1162011621.pyretStack.push(L[666]);
}
throw $e1162011621;
}
var $ret1162611627 = $Hanf_arg340011632($z1162211623,anf_arg14634747,self1814748,_plus26,torepr31);
++R.GAS;
return $ret1162611627;
};
var $Hanf_arg340011632 = function(anf_arg146511631,anf_arg14634747,self1814748,_plus26,torepr31) {
var $z1163511636 = D;
var $f1164111642 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg146511631):R.ffi.throwNonFunApp(L[666],_plus26,[(", "),anf_arg146511631]);
};
try {
if(--R.GAS > 0) {
$z1163511636 = $f1164111642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1164111642,
"from":L[666]});
}
} catch($e1163311634) {
if(R.isCont($e1163311634)) {
var $ss1163711638 = {"from":L[666],
"go":function(anf_arg146611643) {
return $Hanf_arg339911644(anf_arg146611643,anf_arg14634747,self1814748,_plus26,torepr31);
}};
$e1163311634.stack[R.EXN_STACKHEIGHT++] = $ss1163711638;
}
if(R.isPyretException($e1163311634)) {
$e1163311634.pyretStack.push(L[666]);
}
throw $e1163311634;
}
var $ret1163911640 = $Hanf_arg339911644($z1163511636,anf_arg14634747,self1814748,_plus26,torepr31);
++R.GAS;
return $ret1163911640;
};
var $Hanf_arg339911644 = function(anf_arg146611643,anf_arg14634747,self1814748,_plus26,torepr31) {
var $z1164711648 = D;
var $f1165311654 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg14634747,anf_arg146611643):R.ffi.throwNonFunApp(L[666],_plus26,[anf_arg14634747,anf_arg146611643]);
};
try {
if(--R.GAS > 0) {
$z1164711648 = $f1165311654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1165311654,
"from":L[666]});
}
} catch($e1164511646) {
if(R.isCont($e1164511646)) {
var $ss1164911650 = {"from":L[666],
"go":function(anf_arg146711655) {
return $Hanf_arg339811656(anf_arg146711655,self1814748,_plus26,torepr31);
}};
$e1164511646.stack[R.EXN_STACKHEIGHT++] = $ss1164911650;
}
if(R.isPyretException($e1164511646)) {
$e1164511646.pyretStack.push(L[666]);
}
throw $e1164511646;
}
var $ret1165111652 = $Hanf_arg339811656($z1164711648,self1814748,_plus26,torepr31);
++R.GAS;
return $ret1165111652;
};
var $Hanf_arg339811656 = function(anf_arg146711655,self1814748,_plus26,torepr31) {
var anf_arg146811667 = G(self1814748,"fields",L[666]);
var $z1165911660 = D;
var $f1166511666 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg146811667):R.ffi.throwNonFunApp(L[666],torepr31,[anf_arg146811667]);
};
try {
if(--R.GAS > 0) {
$z1165911660 = $f1166511666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1166511666,
"from":L[666]});
}
} catch($e1165711658) {
if(R.isCont($e1165711658)) {
var $ss1166111662 = {"from":L[666],
"go":function(anf_arg146911668) {
return $Hanf_arg339711669(anf_arg146911668,anf_arg146711655,_plus26);
}};
$e1165711658.stack[R.EXN_STACKHEIGHT++] = $ss1166111662;
}
if(R.isPyretException($e1165711658)) {
$e1165711658.pyretStack.push(L[666]);
}
throw $e1165711658;
}
var $ret1166311664 = $Hanf_arg339711669($z1165911660,anf_arg146711655,_plus26);
++R.GAS;
return $ret1166311664;
};
var $Hanf_arg339711669 = function(anf_arg146911668,anf_arg146711655,_plus26) {
var $z1167211673 = D;
var $f1167811679 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg146911668):R.ffi.throwNonFunApp(L[666],_plus26,[(", "),anf_arg146911668]);
};
try {
if(--R.GAS > 0) {
$z1167211673 = $f1167811679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1167811679,
"from":L[666]});
}
} catch($e1167011671) {
if(R.isCont($e1167011671)) {
var $ss1167411675 = {"from":L[666],
"go":function(anf_arg147011680) {
return $Hanf_arg339611681(anf_arg147011680,anf_arg146711655,_plus26);
}};
$e1167011671.stack[R.EXN_STACKHEIGHT++] = $ss1167411675;
}
if(R.isPyretException($e1167011671)) {
$e1167011671.pyretStack.push(L[666]);
}
throw $e1167011671;
}
var $ret1167611677 = $Hanf_arg339611681($z1167211673,anf_arg146711655,_plus26);
++R.GAS;
return $ret1167611677;
};
var $Hanf_arg339611681 = function(anf_arg147011680,anf_arg146711655,_plus26) {
var $z1168411685 = D;
var $f1169011691 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg146711655,anf_arg147011680):R.ffi.throwNonFunApp(L[666],_plus26,[anf_arg146711655,anf_arg147011680]);
};
try {
if(--R.GAS > 0) {
$z1168411685 = $f1169011691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1169011691,
"from":L[666]});
}
} catch($e1168211683) {
if(R.isCont($e1168211683)) {
var $ss1168611687 = {"from":L[666],
"go":function(anf_arg147111692) {
return $Hanf_arg339511693(anf_arg147111692,_plus26);
}};
$e1168211683.stack[R.EXN_STACKHEIGHT++] = $ss1168611687;
}
if(R.isPyretException($e1168211683)) {
$e1168211683.pyretStack.push(L[666]);
}
throw $e1168211683;
}
var $ret1168811689 = $Hanf_arg339511693($z1168411685,_plus26);
++R.GAS;
return $ret1168811689;
};
var $Hanf_arg339511693 = function(anf_arg147111692,_plus26) {
var $z1169611697 = D;
var $f1170211703 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg147111692,(")")):R.ffi.throwNonFunApp(L[666],_plus26,[anf_arg147111692,(")")]);
};
try {
if(--R.GAS > 0) {
$z1169611697 = $f1170211703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1170211703,
"from":L[666]});
}
} catch($e1169411695) {
if(R.isCont($e1169411695)) {
var $ss1169811699 = {"from":L[666],
"go":function(anf_arg147211704) {
return $Hanf_arg339411705(anf_arg147211704,_plus26);
}};
$e1169411695.stack[R.EXN_STACKHEIGHT++] = $ss1169811699;
}
if(R.isPyretException($e1169411695)) {
$e1169411695.pyretStack.push(L[666]);
}
throw $e1169411695;
}
var $ret1170011701 = $Hanf_arg339411705($z1169611697,_plus26);
++R.GAS;
return $ret1170011701;
};
var $Hanf_arg339411705 = function(anf_arg147211704,_plus26) {
var $z1170811709 = D;
var $f1171411715 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg147211704):R.ffi.throwNonFunApp(L[666],_plus26,[("("),anf_arg147211704]);
};
try {
if(--R.GAS > 0) {
$z1170811709 = $f1171411715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1171411715,
"from":L[666]});
}
} catch($e1170611707) {
if(R.isCont($e1170611707)) {
var $ss1171011711 = {"from":L[666],
"go":function(anf_arg147311716) {
return $Hanf_arg339311717(anf_arg147311716,_plus26);
}};
$e1170611707.stack[R.EXN_STACKHEIGHT++] = $ss1171011711;
}
if(R.isPyretException($e1170611707)) {
$e1170611707.pyretStack.push(L[666]);
}
throw $e1170611707;
}
var $ret1171211713 = $Hanf_arg339311717($z1170811709,_plus26);
++R.GAS;
return $ret1171211713;
};
var $Hanf_arg339311717 = function(anf_arg147311716,_plus26) {
var $z1172011721 = D;
var $f1172611727 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-extend"),anf_arg147311716):R.ffi.throwNonFunApp(L[666],_plus26,[("a-extend"),anf_arg147311716]);
};
try {
if(--R.GAS > 0) {
$z1172011721 = $f1172611727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1172611727,
"from":L[666]});
}
} catch($e1171811719) {
if(R.isCont($e1171811719)) {
var $ss1172211723 = {"from":L[666],
"go":function(ann_DASH_check_DASH_temp146111728) {
return $Hann_DASH_check_DASH_temp339211729(ann_DASH_check_DASH_temp146111728);
}};
$e1171811719.stack[R.EXN_STACKHEIGHT++] = $ss1172211723;
}
if(R.isPyretException($e1171811719)) {
$e1171811719.pyretStack.push(L[666]);
}
throw $e1171811719;
}
var $ret1172411725 = $Hann_DASH_check_DASH_temp339211729($z1172011721);
++R.GAS;
return $ret1172411725;
};
var $Hann_DASH_check_DASH_temp339211729 = function(ann_DASH_check_DASH_temp146111728) {
return ann_DASH_check_DASH_temp146111728;
};
var $Hcont_tail_arg33904766 = function(cont_tail_arg14584764,if_helper14484765) {
if(--R.GAS > 0) {
$z1173011731 = R.isFunction(if_helper14484765)?if_helper14484765.app(cont_tail_arg14584764):R.ffi.throwNonFunApp(L[666],if_helper14484765,[cont_tail_arg14584764]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14484765)?if_helper14484765.app(cont_tail_arg14584764):R.ffi.throwNonFunApp(L[666],if_helper14484765,[cont_tail_arg14584764]);
},
"from":L[666]});
}
++R.GAS;
return $z1173011731;
};
var $Hcont_tail_arg33914781 = function(cont_tail_arg14534780,if_helper14484765) {
if(--R.GAS > 0) {
$z1173211733 = R.isFunction(if_helper14484765)?if_helper14484765.app(cont_tail_arg14534780):R.ffi.throwNonFunApp(L[666],if_helper14484765,[cont_tail_arg14534780]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14484765)?if_helper14484765.app(cont_tail_arg14534780):R.ffi.throwNonFunApp(L[666],if_helper14484765,[cont_tail_arg14534780]);
},
"from":L[666]});
}
++R.GAS;
return $z1173211733;
};
var $Hann_DASH_check_DASH_temp33894801 = function(ann_DASH_check_DASH_temp14444800) {
return ann_DASH_check_DASH_temp14444800;
};
var $Hanf_arg33884818 = function(anf_arg14304816,self1754817,_plus26,torepr31) {
var anf_arg143111744 = G(self1754817,"supe",L[667]);
var $z1173611737 = D;
var $f1174211743 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg143111744):R.ffi.throwNonFunApp(L[667],torepr31,[anf_arg143111744]);
};
try {
if(--R.GAS > 0) {
$z1173611737 = $f1174211743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1174211743,
"from":L[667]});
}
} catch($e1173411735) {
if(R.isCont($e1173411735)) {
var $ss1173811739 = {"from":L[667],
"go":function(anf_arg143211745) {
return $Hanf_arg338711746(anf_arg143211745,anf_arg14304816,self1754817,_plus26,torepr31);
}};
$e1173411735.stack[R.EXN_STACKHEIGHT++] = $ss1173811739;
}
if(R.isPyretException($e1173411735)) {
$e1173411735.pyretStack.push(L[667]);
}
throw $e1173411735;
}
var $ret1174011741 = $Hanf_arg338711746($z1173611737,anf_arg14304816,self1754817,_plus26,torepr31);
++R.GAS;
return $ret1174011741;
};
var $Hanf_arg338711746 = function(anf_arg143211745,anf_arg14304816,self1754817,_plus26,torepr31) {
var $z1174911750 = D;
var $f1175511756 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg143211745):R.ffi.throwNonFunApp(L[667],_plus26,[(", "),anf_arg143211745]);
};
try {
if(--R.GAS > 0) {
$z1174911750 = $f1175511756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1175511756,
"from":L[667]});
}
} catch($e1174711748) {
if(R.isCont($e1174711748)) {
var $ss1175111752 = {"from":L[667],
"go":function(anf_arg143311757) {
return $Hanf_arg338611758(anf_arg143311757,anf_arg14304816,self1754817,_plus26,torepr31);
}};
$e1174711748.stack[R.EXN_STACKHEIGHT++] = $ss1175111752;
}
if(R.isPyretException($e1174711748)) {
$e1174711748.pyretStack.push(L[667]);
}
throw $e1174711748;
}
var $ret1175311754 = $Hanf_arg338611758($z1174911750,anf_arg14304816,self1754817,_plus26,torepr31);
++R.GAS;
return $ret1175311754;
};
var $Hanf_arg338611758 = function(anf_arg143311757,anf_arg14304816,self1754817,_plus26,torepr31) {
var $z1176111762 = D;
var $f1176711768 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg14304816,anf_arg143311757):R.ffi.throwNonFunApp(L[667],_plus26,[anf_arg14304816,anf_arg143311757]);
};
try {
if(--R.GAS > 0) {
$z1176111762 = $f1176711768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1176711768,
"from":L[667]});
}
} catch($e1175911760) {
if(R.isCont($e1175911760)) {
var $ss1176311764 = {"from":L[667],
"go":function(anf_arg143411769) {
return $Hanf_arg338511770(anf_arg143411769,self1754817,_plus26,torepr31);
}};
$e1175911760.stack[R.EXN_STACKHEIGHT++] = $ss1176311764;
}
if(R.isPyretException($e1175911760)) {
$e1175911760.pyretStack.push(L[667]);
}
throw $e1175911760;
}
var $ret1176511766 = $Hanf_arg338511770($z1176111762,self1754817,_plus26,torepr31);
++R.GAS;
return $ret1176511766;
};
var $Hanf_arg338511770 = function(anf_arg143411769,self1754817,_plus26,torepr31) {
var anf_arg143511781 = G(self1754817,"fields",L[667]);
var $z1177311774 = D;
var $f1177911780 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg143511781):R.ffi.throwNonFunApp(L[667],torepr31,[anf_arg143511781]);
};
try {
if(--R.GAS > 0) {
$z1177311774 = $f1177911780();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1177911780,
"from":L[667]});
}
} catch($e1177111772) {
if(R.isCont($e1177111772)) {
var $ss1177511776 = {"from":L[667],
"go":function(anf_arg143611782) {
return $Hanf_arg338411783(anf_arg143611782,anf_arg143411769,_plus26);
}};
$e1177111772.stack[R.EXN_STACKHEIGHT++] = $ss1177511776;
}
if(R.isPyretException($e1177111772)) {
$e1177111772.pyretStack.push(L[667]);
}
throw $e1177111772;
}
var $ret1177711778 = $Hanf_arg338411783($z1177311774,anf_arg143411769,_plus26);
++R.GAS;
return $ret1177711778;
};
var $Hanf_arg338411783 = function(anf_arg143611782,anf_arg143411769,_plus26) {
var $z1178611787 = D;
var $f1179211793 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg143611782):R.ffi.throwNonFunApp(L[667],_plus26,[(", "),anf_arg143611782]);
};
try {
if(--R.GAS > 0) {
$z1178611787 = $f1179211793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1179211793,
"from":L[667]});
}
} catch($e1178411785) {
if(R.isCont($e1178411785)) {
var $ss1178811789 = {"from":L[667],
"go":function(anf_arg143711794) {
return $Hanf_arg338311795(anf_arg143711794,anf_arg143411769,_plus26);
}};
$e1178411785.stack[R.EXN_STACKHEIGHT++] = $ss1178811789;
}
if(R.isPyretException($e1178411785)) {
$e1178411785.pyretStack.push(L[667]);
}
throw $e1178411785;
}
var $ret1179011791 = $Hanf_arg338311795($z1178611787,anf_arg143411769,_plus26);
++R.GAS;
return $ret1179011791;
};
var $Hanf_arg338311795 = function(anf_arg143711794,anf_arg143411769,_plus26) {
var $z1179811799 = D;
var $f1180411805 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg143411769,anf_arg143711794):R.ffi.throwNonFunApp(L[667],_plus26,[anf_arg143411769,anf_arg143711794]);
};
try {
if(--R.GAS > 0) {
$z1179811799 = $f1180411805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1180411805,
"from":L[667]});
}
} catch($e1179611797) {
if(R.isCont($e1179611797)) {
var $ss1180011801 = {"from":L[667],
"go":function(anf_arg143811806) {
return $Hanf_arg338211807(anf_arg143811806,_plus26);
}};
$e1179611797.stack[R.EXN_STACKHEIGHT++] = $ss1180011801;
}
if(R.isPyretException($e1179611797)) {
$e1179611797.pyretStack.push(L[667]);
}
throw $e1179611797;
}
var $ret1180211803 = $Hanf_arg338211807($z1179811799,_plus26);
++R.GAS;
return $ret1180211803;
};
var $Hanf_arg338211807 = function(anf_arg143811806,_plus26) {
var $z1181011811 = D;
var $f1181611817 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg143811806,(")")):R.ffi.throwNonFunApp(L[667],_plus26,[anf_arg143811806,(")")]);
};
try {
if(--R.GAS > 0) {
$z1181011811 = $f1181611817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1181611817,
"from":L[667]});
}
} catch($e1180811809) {
if(R.isCont($e1180811809)) {
var $ss1181211813 = {"from":L[667],
"go":function(anf_arg143911818) {
return $Hanf_arg338111819(anf_arg143911818,_plus26);
}};
$e1180811809.stack[R.EXN_STACKHEIGHT++] = $ss1181211813;
}
if(R.isPyretException($e1180811809)) {
$e1180811809.pyretStack.push(L[667]);
}
throw $e1180811809;
}
var $ret1181411815 = $Hanf_arg338111819($z1181011811,_plus26);
++R.GAS;
return $ret1181411815;
};
var $Hanf_arg338111819 = function(anf_arg143911818,_plus26) {
var $z1182211823 = D;
var $f1182811829 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg143911818):R.ffi.throwNonFunApp(L[667],_plus26,[("("),anf_arg143911818]);
};
try {
if(--R.GAS > 0) {
$z1182211823 = $f1182811829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1182811829,
"from":L[667]});
}
} catch($e1182011821) {
if(R.isCont($e1182011821)) {
var $ss1182411825 = {"from":L[667],
"go":function(anf_arg144011830) {
return $Hanf_arg338011831(anf_arg144011830,_plus26);
}};
$e1182011821.stack[R.EXN_STACKHEIGHT++] = $ss1182411825;
}
if(R.isPyretException($e1182011821)) {
$e1182011821.pyretStack.push(L[667]);
}
throw $e1182011821;
}
var $ret1182611827 = $Hanf_arg338011831($z1182211823,_plus26);
++R.GAS;
return $ret1182611827;
};
var $Hanf_arg338011831 = function(anf_arg144011830,_plus26) {
var $z1183411835 = D;
var $f1184011841 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-update"),anf_arg144011830):R.ffi.throwNonFunApp(L[667],_plus26,[("a-update"),anf_arg144011830]);
};
try {
if(--R.GAS > 0) {
$z1183411835 = $f1184011841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1184011841,
"from":L[667]});
}
} catch($e1183211833) {
if(R.isCont($e1183211833)) {
var $ss1183611837 = {"from":L[667],
"go":function(ann_DASH_check_DASH_temp142811842) {
return $Hann_DASH_check_DASH_temp337911843(ann_DASH_check_DASH_temp142811842);
}};
$e1183211833.stack[R.EXN_STACKHEIGHT++] = $ss1183611837;
}
if(R.isPyretException($e1183211833)) {
$e1183211833.pyretStack.push(L[667]);
}
throw $e1183211833;
}
var $ret1183811839 = $Hann_DASH_check_DASH_temp337911843($z1183411835);
++R.GAS;
return $ret1183811839;
};
var $Hann_DASH_check_DASH_temp337911843 = function(ann_DASH_check_DASH_temp142811842) {
return ann_DASH_check_DASH_temp142811842;
};
var $Hcont_tail_arg33774835 = function(cont_tail_arg14254833,if_helper14154834) {
if(--R.GAS > 0) {
$z1184411845 = R.isFunction(if_helper14154834)?if_helper14154834.app(cont_tail_arg14254833):R.ffi.throwNonFunApp(L[667],if_helper14154834,[cont_tail_arg14254833]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14154834)?if_helper14154834.app(cont_tail_arg14254833):R.ffi.throwNonFunApp(L[667],if_helper14154834,[cont_tail_arg14254833]);
},
"from":L[667]});
}
++R.GAS;
return $z1184411845;
};
var $Hcont_tail_arg33784850 = function(cont_tail_arg14204849,if_helper14154834) {
if(--R.GAS > 0) {
$z1184611847 = R.isFunction(if_helper14154834)?if_helper14154834.app(cont_tail_arg14204849):R.ffi.throwNonFunApp(L[667],if_helper14154834,[cont_tail_arg14204849]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper14154834)?if_helper14154834.app(cont_tail_arg14204849):R.ffi.throwNonFunApp(L[667],if_helper14154834,[cont_tail_arg14204849]);
},
"from":L[667]});
}
++R.GAS;
return $z1184611847;
};
var $Hanf_arg33764873 = function(anf_arg14034870,INDENT9187,PP337,anf_fun14004871,self4114872) {
var anf_arg140411861 = G(PP337,"lbrace",L[1427]);
var anf_arg140511862 = G(PP337,"commabreak",L[1426]);
var anf_arg140611863 = G(PP337,"rbrace",L[1425]);
var anf_bracket140711879 = G(self4114872,"fields",L[1424]);
var anf_fun140811858 = G(anf_bracket140711879,"map",L[1423]);
var anf_arg141111859 = R.makeFunction(function(f41211865) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1421],1,arguments);
}
var anf_fun141011876 = G(f41211865,"tosource",L[1422]);
var $z1186811869 = D;
var $f1187411875 = function(_) {
return R.isFunction(anf_fun141011876)?anf_fun141011876.app():R.ffi.throwNonFunApp(L[1421],anf_fun141011876,[]);
};
try {
if(--R.GAS > 0) {
$z1186811869 = $f1187411875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1187411875,
"from":L[1421]});
}
} catch($e1186611867) {
if(R.isCont($e1186611867)) {
var $ss1187011871 = {"from":L[1421],
"go":function(ann_DASH_check_DASH_temp140911877) {
return $Hann_DASH_check_DASH_temp337311878(ann_DASH_check_DASH_temp140911877);
}};
$e1186611867.stack[R.EXN_STACKHEIGHT++] = $ss1187011871;
}
if(R.isPyretException($e1186611867)) {
$e1186611867.pyretStack.push(L[1421]);
}
throw $e1186611867;
}
var $ret1187211873 = $Hann_DASH_check_DASH_temp337311878($z1186811869);
++R.GAS;
return $ret1187211873;
});
var $z1185011851 = D;
var $f1185611857 = function(_) {
return R.isFunction(anf_fun140811858)?anf_fun140811858.app(anf_arg141111859):R.ffi.throwNonFunApp(L[1420],anf_fun140811858,[anf_arg141111859]);
};
try {
if(--R.GAS > 0) {
$z1185011851 = $f1185611857();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1185611857,
"from":L[1420]});
}
} catch($e1184811849) {
if(R.isCont($e1184811849)) {
var $ss1185211853 = {"from":L[1420],
"go":function(anf_arg141211860) {
return $Hanf_arg337511864(anf_arg141211860,INDENT9187,anf_arg14034870,anf_arg140411861,anf_arg140511862,anf_arg140611863,anf_fun14004871);
}};
$e1184811849.stack[R.EXN_STACKHEIGHT++] = $ss1185211853;
}
if(R.isPyretException($e1184811849)) {
$e1184811849.pyretStack.push(L[1420]);
}
throw $e1184811849;
}
var $ret1185411855 = $Hanf_arg337511864($z1185011851,INDENT9187,anf_arg14034870,anf_arg140411861,anf_arg140511862,anf_arg140611863,anf_fun14004871);
++R.GAS;
return $ret1185411855;
};
var $Hanf_arg337511864 = function(anf_arg141211860,INDENT9187,anf_arg14034870,anf_arg140411861,anf_arg140511862,anf_arg140611863,anf_fun14004871) {
var $z1188211883 = D;
var $f1188811889 = function(_) {
return R.isFunction(anf_fun14004871)?anf_fun14004871.app(INDENT9187,(1),anf_arg14034870,anf_arg140411861,anf_arg140511862,anf_arg140611863,anf_arg141211860):R.ffi.throwNonFunApp(L[797],anf_fun14004871,[INDENT9187,(1),anf_arg14034870,anf_arg140411861,anf_arg140511862,anf_arg140611863,anf_arg141211860]);
};
try {
if(--R.GAS > 0) {
$z1188211883 = $f1188811889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1188811889,
"from":L[797]});
}
} catch($e1188011881) {
if(R.isCont($e1188011881)) {
var $ss1188411885 = {"from":L[797],
"go":function(ann_DASH_check_DASH_temp139911890) {
return $Hann_DASH_check_DASH_temp337411891(ann_DASH_check_DASH_temp139911890);
}};
$e1188011881.stack[R.EXN_STACKHEIGHT++] = $ss1188411885;
}
if(R.isPyretException($e1188011881)) {
$e1188011881.pyretStack.push(L[797]);
}
throw $e1188011881;
}
var $ret1188611887 = $Hann_DASH_check_DASH_temp337411891($z1188211883);
++R.GAS;
return $ret1188611887;
};
var $Hann_DASH_check_DASH_temp337411891 = function(ann_DASH_check_DASH_temp139911890) {
return ann_DASH_check_DASH_temp139911890;
};
var $Hann_DASH_check_DASH_temp337311878 = function(ann_DASH_check_DASH_temp140911877) {
return ann_DASH_check_DASH_temp140911877;
};
var $Hanf_arg33724889 = function(anf_arg13894887,self1694888,_plus26,torepr31) {
var anf_arg139011902 = G(self1694888,"fields",L[668]);
var $z1189411895 = D;
var $f1190011901 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg139011902):R.ffi.throwNonFunApp(L[668],torepr31,[anf_arg139011902]);
};
try {
if(--R.GAS > 0) {
$z1189411895 = $f1190011901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1190011901,
"from":L[668]});
}
} catch($e1189211893) {
if(R.isCont($e1189211893)) {
var $ss1189611897 = {"from":L[668],
"go":function(anf_arg139111903) {
return $Hanf_arg337111904(anf_arg139111903,anf_arg13894887,_plus26);
}};
$e1189211893.stack[R.EXN_STACKHEIGHT++] = $ss1189611897;
}
if(R.isPyretException($e1189211893)) {
$e1189211893.pyretStack.push(L[668]);
}
throw $e1189211893;
}
var $ret1189811899 = $Hanf_arg337111904($z1189411895,anf_arg13894887,_plus26);
++R.GAS;
return $ret1189811899;
};
var $Hanf_arg337111904 = function(anf_arg139111903,anf_arg13894887,_plus26) {
var $z1190711908 = D;
var $f1191311914 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg139111903):R.ffi.throwNonFunApp(L[668],_plus26,[(", "),anf_arg139111903]);
};
try {
if(--R.GAS > 0) {
$z1190711908 = $f1191311914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1191311914,
"from":L[668]});
}
} catch($e1190511906) {
if(R.isCont($e1190511906)) {
var $ss1190911910 = {"from":L[668],
"go":function(anf_arg139211915) {
return $Hanf_arg337011916(anf_arg139211915,anf_arg13894887,_plus26);
}};
$e1190511906.stack[R.EXN_STACKHEIGHT++] = $ss1190911910;
}
if(R.isPyretException($e1190511906)) {
$e1190511906.pyretStack.push(L[668]);
}
throw $e1190511906;
}
var $ret1191111912 = $Hanf_arg337011916($z1190711908,anf_arg13894887,_plus26);
++R.GAS;
return $ret1191111912;
};
var $Hanf_arg337011916 = function(anf_arg139211915,anf_arg13894887,_plus26) {
var $z1191911920 = D;
var $f1192511926 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg13894887,anf_arg139211915):R.ffi.throwNonFunApp(L[668],_plus26,[anf_arg13894887,anf_arg139211915]);
};
try {
if(--R.GAS > 0) {
$z1191911920 = $f1192511926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1192511926,
"from":L[668]});
}
} catch($e1191711918) {
if(R.isCont($e1191711918)) {
var $ss1192111922 = {"from":L[668],
"go":function(anf_arg139311927) {
return $Hanf_arg336911928(anf_arg139311927,_plus26);
}};
$e1191711918.stack[R.EXN_STACKHEIGHT++] = $ss1192111922;
}
if(R.isPyretException($e1191711918)) {
$e1191711918.pyretStack.push(L[668]);
}
throw $e1191711918;
}
var $ret1192311924 = $Hanf_arg336911928($z1191911920,_plus26);
++R.GAS;
return $ret1192311924;
};
var $Hanf_arg336911928 = function(anf_arg139311927,_plus26) {
var $z1193111932 = D;
var $f1193711938 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg139311927,(")")):R.ffi.throwNonFunApp(L[668],_plus26,[anf_arg139311927,(")")]);
};
try {
if(--R.GAS > 0) {
$z1193111932 = $f1193711938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1193711938,
"from":L[668]});
}
} catch($e1192911930) {
if(R.isCont($e1192911930)) {
var $ss1193311934 = {"from":L[668],
"go":function(anf_arg139411939) {
return $Hanf_arg336811940(anf_arg139411939,_plus26);
}};
$e1192911930.stack[R.EXN_STACKHEIGHT++] = $ss1193311934;
}
if(R.isPyretException($e1192911930)) {
$e1192911930.pyretStack.push(L[668]);
}
throw $e1192911930;
}
var $ret1193511936 = $Hanf_arg336811940($z1193111932,_plus26);
++R.GAS;
return $ret1193511936;
};
var $Hanf_arg336811940 = function(anf_arg139411939,_plus26) {
var $z1194311944 = D;
var $f1194911950 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg139411939):R.ffi.throwNonFunApp(L[668],_plus26,[("("),anf_arg139411939]);
};
try {
if(--R.GAS > 0) {
$z1194311944 = $f1194911950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1194911950,
"from":L[668]});
}
} catch($e1194111942) {
if(R.isCont($e1194111942)) {
var $ss1194511946 = {"from":L[668],
"go":function(anf_arg139511951) {
return $Hanf_arg336711952(anf_arg139511951,_plus26);
}};
$e1194111942.stack[R.EXN_STACKHEIGHT++] = $ss1194511946;
}
if(R.isPyretException($e1194111942)) {
$e1194111942.pyretStack.push(L[668]);
}
throw $e1194111942;
}
var $ret1194711948 = $Hanf_arg336711952($z1194311944,_plus26);
++R.GAS;
return $ret1194711948;
};
var $Hanf_arg336711952 = function(anf_arg139511951,_plus26) {
var $z1195511956 = D;
var $f1196111962 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-obj"),anf_arg139511951):R.ffi.throwNonFunApp(L[668],_plus26,[("a-obj"),anf_arg139511951]);
};
try {
if(--R.GAS > 0) {
$z1195511956 = $f1196111962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1196111962,
"from":L[668]});
}
} catch($e1195311954) {
if(R.isCont($e1195311954)) {
var $ss1195711958 = {"from":L[668],
"go":function(ann_DASH_check_DASH_temp138711963) {
return $Hann_DASH_check_DASH_temp336611964(ann_DASH_check_DASH_temp138711963);
}};
$e1195311954.stack[R.EXN_STACKHEIGHT++] = $ss1195711958;
}
if(R.isPyretException($e1195311954)) {
$e1195311954.pyretStack.push(L[668]);
}
throw $e1195311954;
}
var $ret1195911960 = $Hann_DASH_check_DASH_temp336611964($z1195511956);
++R.GAS;
return $ret1195911960;
};
var $Hann_DASH_check_DASH_temp336611964 = function(ann_DASH_check_DASH_temp138711963) {
return ann_DASH_check_DASH_temp138711963;
};
var $Hcont_tail_arg33644905 = function(cont_tail_arg13844903,if_helper13754904) {
if(--R.GAS > 0) {
$z1196511966 = R.isFunction(if_helper13754904)?if_helper13754904.app(cont_tail_arg13844903):R.ffi.throwNonFunApp(L[668],if_helper13754904,[cont_tail_arg13844903]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper13754904)?if_helper13754904.app(cont_tail_arg13844903):R.ffi.throwNonFunApp(L[668],if_helper13754904,[cont_tail_arg13844903]);
},
"from":L[668]});
}
++R.GAS;
return $z1196511966;
};
var $Hcont_tail_arg33654920 = function(cont_tail_arg13804919,if_helper13754904) {
if(--R.GAS > 0) {
$z1196711968 = R.isFunction(if_helper13754904)?if_helper13754904.app(cont_tail_arg13804919):R.ffi.throwNonFunApp(L[668],if_helper13754904,[cont_tail_arg13804919]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper13754904)?if_helper13754904.app(cont_tail_arg13804919):R.ffi.throwNonFunApp(L[668],if_helper13754904,[cont_tail_arg13804919]);
},
"from":L[668]});
}
++R.GAS;
return $z1196711968;
};
var $Hanf_arg33634943 = function(anf_arg13584940,INDENT9187,PP337,anf_fun13554941,self4064942,_plus26) {
var anf_fun135911983 = G(PP337,"parens",L[1436]);
var anf_fun136011984 = G(PP337,"nest",L[1435]);
var anf_fun136111985 = G(PP337,"separate",L[1434]);
var anf_arg136211982 = G(PP337,"commabreak",L[1433]);
var anf_bracket136312001 = G(self4064942,"args",L[1432]);
var anf_fun136411979 = G(anf_bracket136312001,"map",L[1431]);
var anf_arg136711980 = R.makeFunction(function(f40711987) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1429],1,arguments);
}
var anf_fun136611998 = G(f40711987,"tosource",L[1430]);
var $z1199011991 = D;
var $f1199611997 = function(_) {
return R.isFunction(anf_fun136611998)?anf_fun136611998.app():R.ffi.throwNonFunApp(L[1429],anf_fun136611998,[]);
};
try {
if(--R.GAS > 0) {
$z1199011991 = $f1199611997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1199611997,
"from":L[1429]});
}
} catch($e1198811989) {
if(R.isCont($e1198811989)) {
var $ss1199211993 = {"from":L[1429],
"go":function(ann_DASH_check_DASH_temp136511999) {
return $Hann_DASH_check_DASH_temp335612000(ann_DASH_check_DASH_temp136511999);
}};
$e1198811989.stack[R.EXN_STACKHEIGHT++] = $ss1199211993;
}
if(R.isPyretException($e1198811989)) {
$e1198811989.pyretStack.push(L[1429]);
}
throw $e1198811989;
}
var $ret1199411995 = $Hann_DASH_check_DASH_temp335612000($z1199011991);
++R.GAS;
return $ret1199411995;
});
var $z1197111972 = D;
var $f1197711978 = function(_) {
return R.isFunction(anf_fun136411979)?anf_fun136411979.app(anf_arg136711980):R.ffi.throwNonFunApp(L[1428],anf_fun136411979,[anf_arg136711980]);
};
try {
if(--R.GAS > 0) {
$z1197111972 = $f1197711978();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1197711978,
"from":L[1428]});
}
} catch($e1196911970) {
if(R.isCont($e1196911970)) {
var $ss1197311974 = {"from":L[1428],
"go":function(anf_arg136811981) {
return $Hanf_arg336211986(anf_arg136811981,INDENT9187,anf_arg13584940,anf_arg136211982,anf_fun13554941,anf_fun135911983,anf_fun136011984,anf_fun136111985,_plus26);
}};
$e1196911970.stack[R.EXN_STACKHEIGHT++] = $ss1197311974;
}
if(R.isPyretException($e1196911970)) {
$e1196911970.pyretStack.push(L[1428]);
}
throw $e1196911970;
}
var $ret1197511976 = $Hanf_arg336211986($z1197111972,INDENT9187,anf_arg13584940,anf_arg136211982,anf_fun13554941,anf_fun135911983,anf_fun136011984,anf_fun136111985,_plus26);
++R.GAS;
return $ret1197511976;
};
var $Hanf_arg336211986 = function(anf_arg136811981,INDENT9187,anf_arg13584940,anf_arg136211982,anf_fun13554941,anf_fun135911983,anf_fun136011984,anf_fun136111985,_plus26) {
var $z1200412005 = D;
var $f1201012011 = function(_) {
return R.isFunction(anf_fun136111985)?anf_fun136111985.app(anf_arg136211982,anf_arg136811981):R.ffi.throwNonFunApp(L[1437],anf_fun136111985,[anf_arg136211982,anf_arg136811981]);
};
try {
if(--R.GAS > 0) {
$z1200412005 = $f1201012011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1201012011,
"from":L[1437]});
}
} catch($e1200212003) {
if(R.isCont($e1200212003)) {
var $ss1200612007 = {"from":L[1437],
"go":function(anf_arg136912012) {
return $Hanf_arg336112013(anf_arg136912012,INDENT9187,anf_arg13584940,anf_fun13554941,anf_fun135911983,anf_fun136011984,_plus26);
}};
$e1200212003.stack[R.EXN_STACKHEIGHT++] = $ss1200612007;
}
if(R.isPyretException($e1200212003)) {
$e1200212003.pyretStack.push(L[1437]);
}
throw $e1200212003;
}
var $ret1200812009 = $Hanf_arg336112013($z1200412005,INDENT9187,anf_arg13584940,anf_fun13554941,anf_fun135911983,anf_fun136011984,_plus26);
++R.GAS;
return $ret1200812009;
};
var $Hanf_arg336112013 = function(anf_arg136912012,INDENT9187,anf_arg13584940,anf_fun13554941,anf_fun135911983,anf_fun136011984,_plus26) {
var $z1201612017 = D;
var $f1202212023 = function(_) {
return R.isFunction(anf_fun136011984)?anf_fun136011984.app(INDENT9187,anf_arg136912012):R.ffi.throwNonFunApp(L[1438],anf_fun136011984,[INDENT9187,anf_arg136912012]);
};
try {
if(--R.GAS > 0) {
$z1201612017 = $f1202212023();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1202212023,
"from":L[1438]});
}
} catch($e1201412015) {
if(R.isCont($e1201412015)) {
var $ss1201812019 = {"from":L[1438],
"go":function(anf_arg137012024) {
return $Hanf_arg336012025(anf_arg137012024,anf_arg13584940,anf_fun13554941,anf_fun135911983,_plus26);
}};
$e1201412015.stack[R.EXN_STACKHEIGHT++] = $ss1201812019;
}
if(R.isPyretException($e1201412015)) {
$e1201412015.pyretStack.push(L[1438]);
}
throw $e1201412015;
}
var $ret1202012021 = $Hanf_arg336012025($z1201612017,anf_arg13584940,anf_fun13554941,anf_fun135911983,_plus26);
++R.GAS;
return $ret1202012021;
};
var $Hanf_arg336012025 = function(anf_arg137012024,anf_arg13584940,anf_fun13554941,anf_fun135911983,_plus26) {
var $z1202812029 = D;
var $f1203412035 = function(_) {
return R.isFunction(anf_fun135911983)?anf_fun135911983.app(anf_arg137012024):R.ffi.throwNonFunApp(L[1439],anf_fun135911983,[anf_arg137012024]);
};
try {
if(--R.GAS > 0) {
$z1202812029 = $f1203412035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1203412035,
"from":L[1439]});
}
} catch($e1202612027) {
if(R.isCont($e1202612027)) {
var $ss1203012031 = {"from":L[1439],
"go":function(anf_arg137112036) {
return $Hanf_arg335912037(anf_arg137112036,anf_arg13584940,anf_fun13554941,_plus26);
}};
$e1202612027.stack[R.EXN_STACKHEIGHT++] = $ss1203012031;
}
if(R.isPyretException($e1202612027)) {
$e1202612027.pyretStack.push(L[1439]);
}
throw $e1202612027;
}
var $ret1203212033 = $Hanf_arg335912037($z1202812029,anf_arg13584940,anf_fun13554941,_plus26);
++R.GAS;
return $ret1203212033;
};
var $Hanf_arg335912037 = function(anf_arg137112036,anf_arg13584940,anf_fun13554941,_plus26) {
var $z1204012041 = D;
var $f1204612047 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg13584940,anf_arg137112036):R.ffi.throwNonFunApp(L[1440],_plus26,[anf_arg13584940,anf_arg137112036]);
};
try {
if(--R.GAS > 0) {
$z1204012041 = $f1204612047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1204612047,
"from":L[1440]});
}
} catch($e1203812039) {
if(R.isCont($e1203812039)) {
var $ss1204212043 = {"from":L[1440],
"go":function(anf_arg137212048) {
return $Hanf_arg335812049(anf_arg137212048,anf_fun13554941);
}};
$e1203812039.stack[R.EXN_STACKHEIGHT++] = $ss1204212043;
}
if(R.isPyretException($e1203812039)) {
$e1203812039.pyretStack.push(L[1440]);
}
throw $e1203812039;
}
var $ret1204412045 = $Hanf_arg335812049($z1204012041,anf_fun13554941);
++R.GAS;
return $ret1204412045;
};
var $Hanf_arg335812049 = function(anf_arg137212048,anf_fun13554941) {
var $z1205212053 = D;
var $f1205812059 = function(_) {
return R.isFunction(anf_fun13554941)?anf_fun13554941.app(anf_arg137212048):R.ffi.throwNonFunApp(L[805],anf_fun13554941,[anf_arg137212048]);
};
try {
if(--R.GAS > 0) {
$z1205212053 = $f1205812059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1205812059,
"from":L[805]});
}
} catch($e1205012051) {
if(R.isCont($e1205012051)) {
var $ss1205412055 = {"from":L[805],
"go":function(ann_DASH_check_DASH_temp135412060) {
return $Hann_DASH_check_DASH_temp335712061(ann_DASH_check_DASH_temp135412060);
}};
$e1205012051.stack[R.EXN_STACKHEIGHT++] = $ss1205412055;
}
if(R.isPyretException($e1205012051)) {
$e1205012051.pyretStack.push(L[805]);
}
throw $e1205012051;
}
var $ret1205612057 = $Hann_DASH_check_DASH_temp335712061($z1205212053);
++R.GAS;
return $ret1205612057;
};
var $Hann_DASH_check_DASH_temp335712061 = function(ann_DASH_check_DASH_temp135412060) {
return ann_DASH_check_DASH_temp135412060;
};
var $Hann_DASH_check_DASH_temp335612000 = function(ann_DASH_check_DASH_temp136511999) {
return ann_DASH_check_DASH_temp136511999;
};
var $Hanf_arg33554959 = function(anf_arg13404957,self1634958,_plus26,torepr31) {
var anf_arg134112072 = G(self1634958,"f",L[669]);
var $z1206412065 = D;
var $f1207012071 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg134112072):R.ffi.throwNonFunApp(L[669],torepr31,[anf_arg134112072]);
};
try {
if(--R.GAS > 0) {
$z1206412065 = $f1207012071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1207012071,
"from":L[669]});
}
} catch($e1206212063) {
if(R.isCont($e1206212063)) {
var $ss1206612067 = {"from":L[669],
"go":function(anf_arg134212073) {
return $Hanf_arg335412074(anf_arg134212073,anf_arg13404957,self1634958,_plus26,torepr31);
}};
$e1206212063.stack[R.EXN_STACKHEIGHT++] = $ss1206612067;
}
if(R.isPyretException($e1206212063)) {
$e1206212063.pyretStack.push(L[669]);
}
throw $e1206212063;
}
var $ret1206812069 = $Hanf_arg335412074($z1206412065,anf_arg13404957,self1634958,_plus26,torepr31);
++R.GAS;
return $ret1206812069;
};
var $Hanf_arg335412074 = function(anf_arg134212073,anf_arg13404957,self1634958,_plus26,torepr31) {
var $z1207712078 = D;
var $f1208312084 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg134212073):R.ffi.throwNonFunApp(L[669],_plus26,[(", "),anf_arg134212073]);
};
try {
if(--R.GAS > 0) {
$z1207712078 = $f1208312084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1208312084,
"from":L[669]});
}
} catch($e1207512076) {
if(R.isCont($e1207512076)) {
var $ss1207912080 = {"from":L[669],
"go":function(anf_arg134312085) {
return $Hanf_arg335312086(anf_arg134312085,anf_arg13404957,self1634958,_plus26,torepr31);
}};
$e1207512076.stack[R.EXN_STACKHEIGHT++] = $ss1207912080;
}
if(R.isPyretException($e1207512076)) {
$e1207512076.pyretStack.push(L[669]);
}
throw $e1207512076;
}
var $ret1208112082 = $Hanf_arg335312086($z1207712078,anf_arg13404957,self1634958,_plus26,torepr31);
++R.GAS;
return $ret1208112082;
};
var $Hanf_arg335312086 = function(anf_arg134312085,anf_arg13404957,self1634958,_plus26,torepr31) {
var $z1208912090 = D;
var $f1209512096 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg13404957,anf_arg134312085):R.ffi.throwNonFunApp(L[669],_plus26,[anf_arg13404957,anf_arg134312085]);
};
try {
if(--R.GAS > 0) {
$z1208912090 = $f1209512096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1209512096,
"from":L[669]});
}
} catch($e1208712088) {
if(R.isCont($e1208712088)) {
var $ss1209112092 = {"from":L[669],
"go":function(anf_arg134412097) {
return $Hanf_arg335212098(anf_arg134412097,self1634958,_plus26,torepr31);
}};
$e1208712088.stack[R.EXN_STACKHEIGHT++] = $ss1209112092;
}
if(R.isPyretException($e1208712088)) {
$e1208712088.pyretStack.push(L[669]);
}
throw $e1208712088;
}
var $ret1209312094 = $Hanf_arg335212098($z1208912090,self1634958,_plus26,torepr31);
++R.GAS;
return $ret1209312094;
};
var $Hanf_arg335212098 = function(anf_arg134412097,self1634958,_plus26,torepr31) {
var anf_arg134512109 = G(self1634958,"args",L[669]);
var $z1210112102 = D;
var $f1210712108 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg134512109):R.ffi.throwNonFunApp(L[669],torepr31,[anf_arg134512109]);
};
try {
if(--R.GAS > 0) {
$z1210112102 = $f1210712108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1210712108,
"from":L[669]});
}
} catch($e1209912100) {
if(R.isCont($e1209912100)) {
var $ss1210312104 = {"from":L[669],
"go":function(anf_arg134612110) {
return $Hanf_arg335112111(anf_arg134612110,anf_arg134412097,_plus26);
}};
$e1209912100.stack[R.EXN_STACKHEIGHT++] = $ss1210312104;
}
if(R.isPyretException($e1209912100)) {
$e1209912100.pyretStack.push(L[669]);
}
throw $e1209912100;
}
var $ret1210512106 = $Hanf_arg335112111($z1210112102,anf_arg134412097,_plus26);
++R.GAS;
return $ret1210512106;
};
var $Hanf_arg335112111 = function(anf_arg134612110,anf_arg134412097,_plus26) {
var $z1211412115 = D;
var $f1212012121 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg134612110):R.ffi.throwNonFunApp(L[669],_plus26,[(", "),anf_arg134612110]);
};
try {
if(--R.GAS > 0) {
$z1211412115 = $f1212012121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1212012121,
"from":L[669]});
}
} catch($e1211212113) {
if(R.isCont($e1211212113)) {
var $ss1211612117 = {"from":L[669],
"go":function(anf_arg134712122) {
return $Hanf_arg335012123(anf_arg134712122,anf_arg134412097,_plus26);
}};
$e1211212113.stack[R.EXN_STACKHEIGHT++] = $ss1211612117;
}
if(R.isPyretException($e1211212113)) {
$e1211212113.pyretStack.push(L[669]);
}
throw $e1211212113;
}
var $ret1211812119 = $Hanf_arg335012123($z1211412115,anf_arg134412097,_plus26);
++R.GAS;
return $ret1211812119;
};
var $Hanf_arg335012123 = function(anf_arg134712122,anf_arg134412097,_plus26) {
var $z1212612127 = D;
var $f1213212133 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg134412097,anf_arg134712122):R.ffi.throwNonFunApp(L[669],_plus26,[anf_arg134412097,anf_arg134712122]);
};
try {
if(--R.GAS > 0) {
$z1212612127 = $f1213212133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1213212133,
"from":L[669]});
}
} catch($e1212412125) {
if(R.isCont($e1212412125)) {
var $ss1212812129 = {"from":L[669],
"go":function(anf_arg134812134) {
return $Hanf_arg334912135(anf_arg134812134,_plus26);
}};
$e1212412125.stack[R.EXN_STACKHEIGHT++] = $ss1212812129;
}
if(R.isPyretException($e1212412125)) {
$e1212412125.pyretStack.push(L[669]);
}
throw $e1212412125;
}
var $ret1213012131 = $Hanf_arg334912135($z1212612127,_plus26);
++R.GAS;
return $ret1213012131;
};
var $Hanf_arg334912135 = function(anf_arg134812134,_plus26) {
var $z1213812139 = D;
var $f1214412145 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg134812134,(")")):R.ffi.throwNonFunApp(L[669],_plus26,[anf_arg134812134,(")")]);
};
try {
if(--R.GAS > 0) {
$z1213812139 = $f1214412145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1214412145,
"from":L[669]});
}
} catch($e1213612137) {
if(R.isCont($e1213612137)) {
var $ss1214012141 = {"from":L[669],
"go":function(anf_arg134912146) {
return $Hanf_arg334812147(anf_arg134912146,_plus26);
}};
$e1213612137.stack[R.EXN_STACKHEIGHT++] = $ss1214012141;
}
if(R.isPyretException($e1213612137)) {
$e1213612137.pyretStack.push(L[669]);
}
throw $e1213612137;
}
var $ret1214212143 = $Hanf_arg334812147($z1213812139,_plus26);
++R.GAS;
return $ret1214212143;
};
var $Hanf_arg334812147 = function(anf_arg134912146,_plus26) {
var $z1215012151 = D;
var $f1215612157 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg134912146):R.ffi.throwNonFunApp(L[669],_plus26,[("("),anf_arg134912146]);
};
try {
if(--R.GAS > 0) {
$z1215012151 = $f1215612157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1215612157,
"from":L[669]});
}
} catch($e1214812149) {
if(R.isCont($e1214812149)) {
var $ss1215212153 = {"from":L[669],
"go":function(anf_arg135012158) {
return $Hanf_arg334712159(anf_arg135012158,_plus26);
}};
$e1214812149.stack[R.EXN_STACKHEIGHT++] = $ss1215212153;
}
if(R.isPyretException($e1214812149)) {
$e1214812149.pyretStack.push(L[669]);
}
throw $e1214812149;
}
var $ret1215412155 = $Hanf_arg334712159($z1215012151,_plus26);
++R.GAS;
return $ret1215412155;
};
var $Hanf_arg334712159 = function(anf_arg135012158,_plus26) {
var $z1216212163 = D;
var $f1216812169 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-prim-app"),anf_arg135012158):R.ffi.throwNonFunApp(L[669],_plus26,[("a-prim-app"),anf_arg135012158]);
};
try {
if(--R.GAS > 0) {
$z1216212163 = $f1216812169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1216812169,
"from":L[669]});
}
} catch($e1216012161) {
if(R.isCont($e1216012161)) {
var $ss1216412165 = {"from":L[669],
"go":function(ann_DASH_check_DASH_temp133812170) {
return $Hann_DASH_check_DASH_temp334612171(ann_DASH_check_DASH_temp133812170);
}};
$e1216012161.stack[R.EXN_STACKHEIGHT++] = $ss1216412165;
}
if(R.isPyretException($e1216012161)) {
$e1216012161.pyretStack.push(L[669]);
}
throw $e1216012161;
}
var $ret1216612167 = $Hann_DASH_check_DASH_temp334612171($z1216212163);
++R.GAS;
return $ret1216612167;
};
var $Hann_DASH_check_DASH_temp334612171 = function(ann_DASH_check_DASH_temp133812170) {
return ann_DASH_check_DASH_temp133812170;
};
var $Hcont_tail_arg33444976 = function(cont_tail_arg13354974,if_helper13254975) {
if(--R.GAS > 0) {
$z1217212173 = R.isFunction(if_helper13254975)?if_helper13254975.app(cont_tail_arg13354974):R.ffi.throwNonFunApp(L[669],if_helper13254975,[cont_tail_arg13354974]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper13254975)?if_helper13254975.app(cont_tail_arg13354974):R.ffi.throwNonFunApp(L[669],if_helper13254975,[cont_tail_arg13354974]);
},
"from":L[669]});
}
++R.GAS;
return $z1217212173;
};
var $Hcont_tail_arg33454991 = function(cont_tail_arg13304990,if_helper13254975) {
if(--R.GAS > 0) {
$z1217412175 = R.isFunction(if_helper13254975)?if_helper13254975.app(cont_tail_arg13304990):R.ffi.throwNonFunApp(L[669],if_helper13254975,[cont_tail_arg13304990]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper13254975)?if_helper13254975.app(cont_tail_arg13304990):R.ffi.throwNonFunApp(L[669],if_helper13254975,[cont_tail_arg13304990]);
},
"from":L[669]});
}
++R.GAS;
return $z1217412175;
};
var $Hanf_arg33435013 = function(anf_arg13085010,INDENT9187,PP337,anf_fun13055011,self4005012,_plus26) {
var anf_fun130912190 = G(PP337,"parens",L[1449]);
var anf_fun131012191 = G(PP337,"nest",L[1448]);
var anf_fun131112192 = G(PP337,"separate",L[1447]);
var anf_arg131212189 = G(PP337,"commabreak",L[1446]);
var anf_bracket131312208 = G(self4005012,"args",L[1445]);
var anf_fun131412186 = G(anf_bracket131312208,"map",L[1444]);
var anf_arg131712187 = R.makeFunction(function(f40112194) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1442],1,arguments);
}
var anf_fun131612205 = G(f40112194,"tosource",L[1443]);
var $z1219712198 = D;
var $f1220312204 = function(_) {
return R.isFunction(anf_fun131612205)?anf_fun131612205.app():R.ffi.throwNonFunApp(L[1442],anf_fun131612205,[]);
};
try {
if(--R.GAS > 0) {
$z1219712198 = $f1220312204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1220312204,
"from":L[1442]});
}
} catch($e1219512196) {
if(R.isCont($e1219512196)) {
var $ss1219912200 = {"from":L[1442],
"go":function(ann_DASH_check_DASH_temp131512206) {
return $Hann_DASH_check_DASH_temp333612207(ann_DASH_check_DASH_temp131512206);
}};
$e1219512196.stack[R.EXN_STACKHEIGHT++] = $ss1219912200;
}
if(R.isPyretException($e1219512196)) {
$e1219512196.pyretStack.push(L[1442]);
}
throw $e1219512196;
}
var $ret1220112202 = $Hann_DASH_check_DASH_temp333612207($z1219712198);
++R.GAS;
return $ret1220112202;
});
var $z1217812179 = D;
var $f1218412185 = function(_) {
return R.isFunction(anf_fun131412186)?anf_fun131412186.app(anf_arg131712187):R.ffi.throwNonFunApp(L[1441],anf_fun131412186,[anf_arg131712187]);
};
try {
if(--R.GAS > 0) {
$z1217812179 = $f1218412185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1218412185,
"from":L[1441]});
}
} catch($e1217612177) {
if(R.isCont($e1217612177)) {
var $ss1218012181 = {"from":L[1441],
"go":function(anf_arg131812188) {
return $Hanf_arg334212193(anf_arg131812188,INDENT9187,anf_arg13085010,anf_arg131212189,anf_fun13055011,anf_fun130912190,anf_fun131012191,anf_fun131112192,_plus26);
}};
$e1217612177.stack[R.EXN_STACKHEIGHT++] = $ss1218012181;
}
if(R.isPyretException($e1217612177)) {
$e1217612177.pyretStack.push(L[1441]);
}
throw $e1217612177;
}
var $ret1218212183 = $Hanf_arg334212193($z1217812179,INDENT9187,anf_arg13085010,anf_arg131212189,anf_fun13055011,anf_fun130912190,anf_fun131012191,anf_fun131112192,_plus26);
++R.GAS;
return $ret1218212183;
};
var $Hanf_arg334212193 = function(anf_arg131812188,INDENT9187,anf_arg13085010,anf_arg131212189,anf_fun13055011,anf_fun130912190,anf_fun131012191,anf_fun131112192,_plus26) {
var $z1221112212 = D;
var $f1221712218 = function(_) {
return R.isFunction(anf_fun131112192)?anf_fun131112192.app(anf_arg131212189,anf_arg131812188):R.ffi.throwNonFunApp(L[1450],anf_fun131112192,[anf_arg131212189,anf_arg131812188]);
};
try {
if(--R.GAS > 0) {
$z1221112212 = $f1221712218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1221712218,
"from":L[1450]});
}
} catch($e1220912210) {
if(R.isCont($e1220912210)) {
var $ss1221312214 = {"from":L[1450],
"go":function(anf_arg131912219) {
return $Hanf_arg334112220(anf_arg131912219,INDENT9187,anf_arg13085010,anf_fun13055011,anf_fun130912190,anf_fun131012191,_plus26);
}};
$e1220912210.stack[R.EXN_STACKHEIGHT++] = $ss1221312214;
}
if(R.isPyretException($e1220912210)) {
$e1220912210.pyretStack.push(L[1450]);
}
throw $e1220912210;
}
var $ret1221512216 = $Hanf_arg334112220($z1221112212,INDENT9187,anf_arg13085010,anf_fun13055011,anf_fun130912190,anf_fun131012191,_plus26);
++R.GAS;
return $ret1221512216;
};
var $Hanf_arg334112220 = function(anf_arg131912219,INDENT9187,anf_arg13085010,anf_fun13055011,anf_fun130912190,anf_fun131012191,_plus26) {
var $z1222312224 = D;
var $f1222912230 = function(_) {
return R.isFunction(anf_fun131012191)?anf_fun131012191.app(INDENT9187,anf_arg131912219):R.ffi.throwNonFunApp(L[1451],anf_fun131012191,[INDENT9187,anf_arg131912219]);
};
try {
if(--R.GAS > 0) {
$z1222312224 = $f1222912230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1222912230,
"from":L[1451]});
}
} catch($e1222112222) {
if(R.isCont($e1222112222)) {
var $ss1222512226 = {"from":L[1451],
"go":function(anf_arg132012231) {
return $Hanf_arg334012232(anf_arg132012231,anf_arg13085010,anf_fun13055011,anf_fun130912190,_plus26);
}};
$e1222112222.stack[R.EXN_STACKHEIGHT++] = $ss1222512226;
}
if(R.isPyretException($e1222112222)) {
$e1222112222.pyretStack.push(L[1451]);
}
throw $e1222112222;
}
var $ret1222712228 = $Hanf_arg334012232($z1222312224,anf_arg13085010,anf_fun13055011,anf_fun130912190,_plus26);
++R.GAS;
return $ret1222712228;
};
var $Hanf_arg334012232 = function(anf_arg132012231,anf_arg13085010,anf_fun13055011,anf_fun130912190,_plus26) {
var $z1223512236 = D;
var $f1224112242 = function(_) {
return R.isFunction(anf_fun130912190)?anf_fun130912190.app(anf_arg132012231):R.ffi.throwNonFunApp(L[1452],anf_fun130912190,[anf_arg132012231]);
};
try {
if(--R.GAS > 0) {
$z1223512236 = $f1224112242();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1224112242,
"from":L[1452]});
}
} catch($e1223312234) {
if(R.isCont($e1223312234)) {
var $ss1223712238 = {"from":L[1452],
"go":function(anf_arg132112243) {
return $Hanf_arg333912244(anf_arg132112243,anf_arg13085010,anf_fun13055011,_plus26);
}};
$e1223312234.stack[R.EXN_STACKHEIGHT++] = $ss1223712238;
}
if(R.isPyretException($e1223312234)) {
$e1223312234.pyretStack.push(L[1452]);
}
throw $e1223312234;
}
var $ret1223912240 = $Hanf_arg333912244($z1223512236,anf_arg13085010,anf_fun13055011,_plus26);
++R.GAS;
return $ret1223912240;
};
var $Hanf_arg333912244 = function(anf_arg132112243,anf_arg13085010,anf_fun13055011,_plus26) {
var $z1224712248 = D;
var $f1225312254 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg13085010,anf_arg132112243):R.ffi.throwNonFunApp(L[1453],_plus26,[anf_arg13085010,anf_arg132112243]);
};
try {
if(--R.GAS > 0) {
$z1224712248 = $f1225312254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1225312254,
"from":L[1453]});
}
} catch($e1224512246) {
if(R.isCont($e1224512246)) {
var $ss1224912250 = {"from":L[1453],
"go":function(anf_arg132212255) {
return $Hanf_arg333812256(anf_arg132212255,anf_fun13055011);
}};
$e1224512246.stack[R.EXN_STACKHEIGHT++] = $ss1224912250;
}
if(R.isPyretException($e1224512246)) {
$e1224512246.pyretStack.push(L[1453]);
}
throw $e1224512246;
}
var $ret1225112252 = $Hanf_arg333812256($z1224712248,anf_fun13055011);
++R.GAS;
return $ret1225112252;
};
var $Hanf_arg333812256 = function(anf_arg132212255,anf_fun13055011) {
var $z1225912260 = D;
var $f1226512266 = function(_) {
return R.isFunction(anf_fun13055011)?anf_fun13055011.app(anf_arg132212255):R.ffi.throwNonFunApp(L[814],anf_fun13055011,[anf_arg132212255]);
};
try {
if(--R.GAS > 0) {
$z1225912260 = $f1226512266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1226512266,
"from":L[814]});
}
} catch($e1225712258) {
if(R.isCont($e1225712258)) {
var $ss1226112262 = {"from":L[814],
"go":function(ann_DASH_check_DASH_temp130412267) {
return $Hann_DASH_check_DASH_temp333712268(ann_DASH_check_DASH_temp130412267);
}};
$e1225712258.stack[R.EXN_STACKHEIGHT++] = $ss1226112262;
}
if(R.isPyretException($e1225712258)) {
$e1225712258.pyretStack.push(L[814]);
}
throw $e1225712258;
}
var $ret1226312264 = $Hann_DASH_check_DASH_temp333712268($z1225912260);
++R.GAS;
return $ret1226312264;
};
var $Hann_DASH_check_DASH_temp333712268 = function(ann_DASH_check_DASH_temp130412267) {
return ann_DASH_check_DASH_temp130412267;
};
var $Hann_DASH_check_DASH_temp333612207 = function(ann_DASH_check_DASH_temp131512206) {
return ann_DASH_check_DASH_temp131512206;
};
var $Hanf_arg33355030 = function(anf_arg12905028,self1575029,_plus26,torepr31) {
var anf_arg129112279 = G(self1575029,"_fun",L[670]);
var $z1227112272 = D;
var $f1227712278 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg129112279):R.ffi.throwNonFunApp(L[670],torepr31,[anf_arg129112279]);
};
try {
if(--R.GAS > 0) {
$z1227112272 = $f1227712278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1227712278,
"from":L[670]});
}
} catch($e1226912270) {
if(R.isCont($e1226912270)) {
var $ss1227312274 = {"from":L[670],
"go":function(anf_arg129212280) {
return $Hanf_arg333412281(anf_arg129212280,anf_arg12905028,self1575029,_plus26,torepr31);
}};
$e1226912270.stack[R.EXN_STACKHEIGHT++] = $ss1227312274;
}
if(R.isPyretException($e1226912270)) {
$e1226912270.pyretStack.push(L[670]);
}
throw $e1226912270;
}
var $ret1227512276 = $Hanf_arg333412281($z1227112272,anf_arg12905028,self1575029,_plus26,torepr31);
++R.GAS;
return $ret1227512276;
};
var $Hanf_arg333412281 = function(anf_arg129212280,anf_arg12905028,self1575029,_plus26,torepr31) {
var $z1228412285 = D;
var $f1229012291 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg129212280):R.ffi.throwNonFunApp(L[670],_plus26,[(", "),anf_arg129212280]);
};
try {
if(--R.GAS > 0) {
$z1228412285 = $f1229012291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1229012291,
"from":L[670]});
}
} catch($e1228212283) {
if(R.isCont($e1228212283)) {
var $ss1228612287 = {"from":L[670],
"go":function(anf_arg129312292) {
return $Hanf_arg333312293(anf_arg129312292,anf_arg12905028,self1575029,_plus26,torepr31);
}};
$e1228212283.stack[R.EXN_STACKHEIGHT++] = $ss1228612287;
}
if(R.isPyretException($e1228212283)) {
$e1228212283.pyretStack.push(L[670]);
}
throw $e1228212283;
}
var $ret1228812289 = $Hanf_arg333312293($z1228412285,anf_arg12905028,self1575029,_plus26,torepr31);
++R.GAS;
return $ret1228812289;
};
var $Hanf_arg333312293 = function(anf_arg129312292,anf_arg12905028,self1575029,_plus26,torepr31) {
var $z1229612297 = D;
var $f1230212303 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg12905028,anf_arg129312292):R.ffi.throwNonFunApp(L[670],_plus26,[anf_arg12905028,anf_arg129312292]);
};
try {
if(--R.GAS > 0) {
$z1229612297 = $f1230212303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1230212303,
"from":L[670]});
}
} catch($e1229412295) {
if(R.isCont($e1229412295)) {
var $ss1229812299 = {"from":L[670],
"go":function(anf_arg129412304) {
return $Hanf_arg333212305(anf_arg129412304,self1575029,_plus26,torepr31);
}};
$e1229412295.stack[R.EXN_STACKHEIGHT++] = $ss1229812299;
}
if(R.isPyretException($e1229412295)) {
$e1229412295.pyretStack.push(L[670]);
}
throw $e1229412295;
}
var $ret1230012301 = $Hanf_arg333212305($z1229612297,self1575029,_plus26,torepr31);
++R.GAS;
return $ret1230012301;
};
var $Hanf_arg333212305 = function(anf_arg129412304,self1575029,_plus26,torepr31) {
var anf_arg129512316 = G(self1575029,"args",L[670]);
var $z1230812309 = D;
var $f1231412315 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg129512316):R.ffi.throwNonFunApp(L[670],torepr31,[anf_arg129512316]);
};
try {
if(--R.GAS > 0) {
$z1230812309 = $f1231412315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1231412315,
"from":L[670]});
}
} catch($e1230612307) {
if(R.isCont($e1230612307)) {
var $ss1231012311 = {"from":L[670],
"go":function(anf_arg129612317) {
return $Hanf_arg333112318(anf_arg129612317,anf_arg129412304,_plus26);
}};
$e1230612307.stack[R.EXN_STACKHEIGHT++] = $ss1231012311;
}
if(R.isPyretException($e1230612307)) {
$e1230612307.pyretStack.push(L[670]);
}
throw $e1230612307;
}
var $ret1231212313 = $Hanf_arg333112318($z1230812309,anf_arg129412304,_plus26);
++R.GAS;
return $ret1231212313;
};
var $Hanf_arg333112318 = function(anf_arg129612317,anf_arg129412304,_plus26) {
var $z1232112322 = D;
var $f1232712328 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg129612317):R.ffi.throwNonFunApp(L[670],_plus26,[(", "),anf_arg129612317]);
};
try {
if(--R.GAS > 0) {
$z1232112322 = $f1232712328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1232712328,
"from":L[670]});
}
} catch($e1231912320) {
if(R.isCont($e1231912320)) {
var $ss1232312324 = {"from":L[670],
"go":function(anf_arg129712329) {
return $Hanf_arg333012330(anf_arg129712329,anf_arg129412304,_plus26);
}};
$e1231912320.stack[R.EXN_STACKHEIGHT++] = $ss1232312324;
}
if(R.isPyretException($e1231912320)) {
$e1231912320.pyretStack.push(L[670]);
}
throw $e1231912320;
}
var $ret1232512326 = $Hanf_arg333012330($z1232112322,anf_arg129412304,_plus26);
++R.GAS;
return $ret1232512326;
};
var $Hanf_arg333012330 = function(anf_arg129712329,anf_arg129412304,_plus26) {
var $z1233312334 = D;
var $f1233912340 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg129412304,anf_arg129712329):R.ffi.throwNonFunApp(L[670],_plus26,[anf_arg129412304,anf_arg129712329]);
};
try {
if(--R.GAS > 0) {
$z1233312334 = $f1233912340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1233912340,
"from":L[670]});
}
} catch($e1233112332) {
if(R.isCont($e1233112332)) {
var $ss1233512336 = {"from":L[670],
"go":function(anf_arg129812341) {
return $Hanf_arg332912342(anf_arg129812341,_plus26);
}};
$e1233112332.stack[R.EXN_STACKHEIGHT++] = $ss1233512336;
}
if(R.isPyretException($e1233112332)) {
$e1233112332.pyretStack.push(L[670]);
}
throw $e1233112332;
}
var $ret1233712338 = $Hanf_arg332912342($z1233312334,_plus26);
++R.GAS;
return $ret1233712338;
};
var $Hanf_arg332912342 = function(anf_arg129812341,_plus26) {
var $z1234512346 = D;
var $f1235112352 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg129812341,(")")):R.ffi.throwNonFunApp(L[670],_plus26,[anf_arg129812341,(")")]);
};
try {
if(--R.GAS > 0) {
$z1234512346 = $f1235112352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1235112352,
"from":L[670]});
}
} catch($e1234312344) {
if(R.isCont($e1234312344)) {
var $ss1234712348 = {"from":L[670],
"go":function(anf_arg129912353) {
return $Hanf_arg332812354(anf_arg129912353,_plus26);
}};
$e1234312344.stack[R.EXN_STACKHEIGHT++] = $ss1234712348;
}
if(R.isPyretException($e1234312344)) {
$e1234312344.pyretStack.push(L[670]);
}
throw $e1234312344;
}
var $ret1234912350 = $Hanf_arg332812354($z1234512346,_plus26);
++R.GAS;
return $ret1234912350;
};
var $Hanf_arg332812354 = function(anf_arg129912353,_plus26) {
var $z1235712358 = D;
var $f1236312364 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg129912353):R.ffi.throwNonFunApp(L[670],_plus26,[("("),anf_arg129912353]);
};
try {
if(--R.GAS > 0) {
$z1235712358 = $f1236312364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1236312364,
"from":L[670]});
}
} catch($e1235512356) {
if(R.isCont($e1235512356)) {
var $ss1235912360 = {"from":L[670],
"go":function(anf_arg130012365) {
return $Hanf_arg332712366(anf_arg130012365,_plus26);
}};
$e1235512356.stack[R.EXN_STACKHEIGHT++] = $ss1235912360;
}
if(R.isPyretException($e1235512356)) {
$e1235512356.pyretStack.push(L[670]);
}
throw $e1235512356;
}
var $ret1236112362 = $Hanf_arg332712366($z1235712358,_plus26);
++R.GAS;
return $ret1236112362;
};
var $Hanf_arg332712366 = function(anf_arg130012365,_plus26) {
var $z1236912370 = D;
var $f1237512376 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-app"),anf_arg130012365):R.ffi.throwNonFunApp(L[670],_plus26,[("a-app"),anf_arg130012365]);
};
try {
if(--R.GAS > 0) {
$z1236912370 = $f1237512376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1237512376,
"from":L[670]});
}
} catch($e1236712368) {
if(R.isCont($e1236712368)) {
var $ss1237112372 = {"from":L[670],
"go":function(ann_DASH_check_DASH_temp128812377) {
return $Hann_DASH_check_DASH_temp332612378(ann_DASH_check_DASH_temp128812377);
}};
$e1236712368.stack[R.EXN_STACKHEIGHT++] = $ss1237112372;
}
if(R.isPyretException($e1236712368)) {
$e1236712368.pyretStack.push(L[670]);
}
throw $e1236712368;
}
var $ret1237312374 = $Hann_DASH_check_DASH_temp332612378($z1236912370);
++R.GAS;
return $ret1237312374;
};
var $Hann_DASH_check_DASH_temp332612378 = function(ann_DASH_check_DASH_temp128812377) {
return ann_DASH_check_DASH_temp128812377;
};
var $Hcont_tail_arg33245047 = function(cont_tail_arg12855045,if_helper12755046) {
if(--R.GAS > 0) {
$z1237912380 = R.isFunction(if_helper12755046)?if_helper12755046.app(cont_tail_arg12855045):R.ffi.throwNonFunApp(L[670],if_helper12755046,[cont_tail_arg12855045]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper12755046)?if_helper12755046.app(cont_tail_arg12855045):R.ffi.throwNonFunApp(L[670],if_helper12755046,[cont_tail_arg12855045]);
},
"from":L[670]});
}
++R.GAS;
return $z1237912380;
};
var $Hcont_tail_arg33255062 = function(cont_tail_arg12805061,if_helper12755046) {
if(--R.GAS > 0) {
$z1238112382 = R.isFunction(if_helper12755046)?if_helper12755046.app(cont_tail_arg12805061):R.ffi.throwNonFunApp(L[670],if_helper12755046,[cont_tail_arg12805061]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper12755046)?if_helper12755046.app(cont_tail_arg12805061):R.ffi.throwNonFunApp(L[670],if_helper12755046,[cont_tail_arg12805061]);
},
"from":L[670]});
}
++R.GAS;
return $z1238112382;
};
var $Hanf_arg33235085 = function(anf_arg12655081,INDENT9187,anf_fun12615082,anf_fun12625083,break_DASH_one9262,self3955084,str_DASH_spacecolonequal109313,_plus26) {
var $z1238512386 = D;
var $f1239112392 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg12655081,str_DASH_spacecolonequal109313):R.ffi.throwNonFunApp(L[1454],_plus26,[anf_arg12655081,str_DASH_spacecolonequal109313]);
};
try {
if(--R.GAS > 0) {
$z1238512386 = $f1239112392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1239112392,
"from":L[1454]});
}
} catch($e1238312384) {
if(R.isCont($e1238312384)) {
var $ss1238712388 = {"from":L[1454],
"go":function(anf_arg126612393) {
return $Hanf_arg332212394(anf_arg126612393,INDENT9187,anf_fun12615082,anf_fun12625083,break_DASH_one9262,self3955084,_plus26);
}};
$e1238312384.stack[R.EXN_STACKHEIGHT++] = $ss1238712388;
}
if(R.isPyretException($e1238312384)) {
$e1238312384.pyretStack.push(L[1454]);
}
throw $e1238312384;
}
var $ret1238912390 = $Hanf_arg332212394($z1238512386,INDENT9187,anf_fun12615082,anf_fun12625083,break_DASH_one9262,self3955084,_plus26);
++R.GAS;
return $ret1238912390;
};
var $Hanf_arg332212394 = function(anf_arg126612393,INDENT9187,anf_fun12615082,anf_fun12625083,break_DASH_one9262,self3955084,_plus26) {
var $z1239712398 = D;
var $f1240312404 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg126612393,break_DASH_one9262):R.ffi.throwNonFunApp(L[1454],_plus26,[anf_arg126612393,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1239712398 = $f1240312404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1240312404,
"from":L[1454]});
}
} catch($e1239512396) {
if(R.isCont($e1239512396)) {
var $ss1239912400 = {"from":L[1454],
"go":function(anf_arg126712405) {
return $Hanf_arg332112406(anf_arg126712405,INDENT9187,anf_fun12615082,anf_fun12625083,self3955084,_plus26);
}};
$e1239512396.stack[R.EXN_STACKHEIGHT++] = $ss1239912400;
}
if(R.isPyretException($e1239512396)) {
$e1239512396.pyretStack.push(L[1454]);
}
throw $e1239512396;
}
var $ret1240112402 = $Hanf_arg332112406($z1239712398,INDENT9187,anf_fun12615082,anf_fun12625083,self3955084,_plus26);
++R.GAS;
return $ret1240112402;
};
var $Hanf_arg332112406 = function(anf_arg126712405,INDENT9187,anf_fun12615082,anf_fun12625083,self3955084,_plus26) {
var anf_bracket126812420 = G(self3955084,"value",L[1457]);
var anf_fun126912417 = G(anf_bracket126812420,"tosource",L[1456]);
var $z1240912410 = D;
var $f1241512416 = function(_) {
return R.isFunction(anf_fun126912417)?anf_fun126912417.app():R.ffi.throwNonFunApp(L[1455],anf_fun126912417,[]);
};
try {
if(--R.GAS > 0) {
$z1240912410 = $f1241512416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1241512416,
"from":L[1455]});
}
} catch($e1240712408) {
if(R.isCont($e1240712408)) {
var $ss1241112412 = {"from":L[1455],
"go":function(anf_arg127012418) {
return $Hanf_arg332012419(anf_arg127012418,INDENT9187,anf_arg126712405,anf_fun12615082,anf_fun12625083,_plus26);
}};
$e1240712408.stack[R.EXN_STACKHEIGHT++] = $ss1241112412;
}
if(R.isPyretException($e1240712408)) {
$e1240712408.pyretStack.push(L[1455]);
}
throw $e1240712408;
}
var $ret1241312414 = $Hanf_arg332012419($z1240912410,INDENT9187,anf_arg126712405,anf_fun12615082,anf_fun12625083,_plus26);
++R.GAS;
return $ret1241312414;
};
var $Hanf_arg332012419 = function(anf_arg127012418,INDENT9187,anf_arg126712405,anf_fun12615082,anf_fun12625083,_plus26) {
var $z1242312424 = D;
var $f1242912430 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg126712405,anf_arg127012418):R.ffi.throwNonFunApp(L[1454],_plus26,[anf_arg126712405,anf_arg127012418]);
};
try {
if(--R.GAS > 0) {
$z1242312424 = $f1242912430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1242912430,
"from":L[1454]});
}
} catch($e1242112422) {
if(R.isCont($e1242112422)) {
var $ss1242512426 = {"from":L[1454],
"go":function(anf_arg127112431) {
return $Hanf_arg331912432(anf_arg127112431,INDENT9187,anf_fun12615082,anf_fun12625083);
}};
$e1242112422.stack[R.EXN_STACKHEIGHT++] = $ss1242512426;
}
if(R.isPyretException($e1242112422)) {
$e1242112422.pyretStack.push(L[1454]);
}
throw $e1242112422;
}
var $ret1242712428 = $Hanf_arg331912432($z1242312424,INDENT9187,anf_fun12615082,anf_fun12625083);
++R.GAS;
return $ret1242712428;
};
var $Hanf_arg331912432 = function(anf_arg127112431,INDENT9187,anf_fun12615082,anf_fun12625083) {
var $z1243512436 = D;
var $f1244112442 = function(_) {
return R.isFunction(anf_fun12625083)?anf_fun12625083.app(INDENT9187,anf_arg127112431):R.ffi.throwNonFunApp(L[1458],anf_fun12625083,[INDENT9187,anf_arg127112431]);
};
try {
if(--R.GAS > 0) {
$z1243512436 = $f1244112442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1244112442,
"from":L[1458]});
}
} catch($e1243312434) {
if(R.isCont($e1243312434)) {
var $ss1243712438 = {"from":L[1458],
"go":function(anf_arg127212443) {
return $Hanf_arg331812444(anf_arg127212443,anf_fun12615082);
}};
$e1243312434.stack[R.EXN_STACKHEIGHT++] = $ss1243712438;
}
if(R.isPyretException($e1243312434)) {
$e1243312434.pyretStack.push(L[1458]);
}
throw $e1243312434;
}
var $ret1243912440 = $Hanf_arg331812444($z1243512436,anf_fun12615082);
++R.GAS;
return $ret1243912440;
};
var $Hanf_arg331812444 = function(anf_arg127212443,anf_fun12615082) {
var $z1244712448 = D;
var $f1245312454 = function(_) {
return R.isFunction(anf_fun12615082)?anf_fun12615082.app(anf_arg127212443):R.ffi.throwNonFunApp(L[824],anf_fun12615082,[anf_arg127212443]);
};
try {
if(--R.GAS > 0) {
$z1244712448 = $f1245312454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1245312454,
"from":L[824]});
}
} catch($e1244512446) {
if(R.isCont($e1244512446)) {
var $ss1244912450 = {"from":L[824],
"go":function(ann_DASH_check_DASH_temp126012455) {
return $Hann_DASH_check_DASH_temp331712456(ann_DASH_check_DASH_temp126012455);
}};
$e1244512446.stack[R.EXN_STACKHEIGHT++] = $ss1244912450;
}
if(R.isPyretException($e1244512446)) {
$e1244512446.pyretStack.push(L[824]);
}
throw $e1244512446;
}
var $ret1245112452 = $Hann_DASH_check_DASH_temp331712456($z1244712448);
++R.GAS;
return $ret1245112452;
};
var $Hann_DASH_check_DASH_temp331712456 = function(ann_DASH_check_DASH_temp126012455) {
return ann_DASH_check_DASH_temp126012455;
};
var $Hanf_arg33165102 = function(anf_arg12465100,self1515101,_plus26,torepr31) {
var anf_arg124712467 = G(self1515101,"id",L[671]);
var $z1245912460 = D;
var $f1246512466 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg124712467):R.ffi.throwNonFunApp(L[671],torepr31,[anf_arg124712467]);
};
try {
if(--R.GAS > 0) {
$z1245912460 = $f1246512466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1246512466,
"from":L[671]});
}
} catch($e1245712458) {
if(R.isCont($e1245712458)) {
var $ss1246112462 = {"from":L[671],
"go":function(anf_arg124812468) {
return $Hanf_arg331512469(anf_arg124812468,anf_arg12465100,self1515101,_plus26,torepr31);
}};
$e1245712458.stack[R.EXN_STACKHEIGHT++] = $ss1246112462;
}
if(R.isPyretException($e1245712458)) {
$e1245712458.pyretStack.push(L[671]);
}
throw $e1245712458;
}
var $ret1246312464 = $Hanf_arg331512469($z1245912460,anf_arg12465100,self1515101,_plus26,torepr31);
++R.GAS;
return $ret1246312464;
};
var $Hanf_arg331512469 = function(anf_arg124812468,anf_arg12465100,self1515101,_plus26,torepr31) {
var $z1247212473 = D;
var $f1247812479 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg124812468):R.ffi.throwNonFunApp(L[671],_plus26,[(", "),anf_arg124812468]);
};
try {
if(--R.GAS > 0) {
$z1247212473 = $f1247812479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1247812479,
"from":L[671]});
}
} catch($e1247012471) {
if(R.isCont($e1247012471)) {
var $ss1247412475 = {"from":L[671],
"go":function(anf_arg124912480) {
return $Hanf_arg331412481(anf_arg124912480,anf_arg12465100,self1515101,_plus26,torepr31);
}};
$e1247012471.stack[R.EXN_STACKHEIGHT++] = $ss1247412475;
}
if(R.isPyretException($e1247012471)) {
$e1247012471.pyretStack.push(L[671]);
}
throw $e1247012471;
}
var $ret1247612477 = $Hanf_arg331412481($z1247212473,anf_arg12465100,self1515101,_plus26,torepr31);
++R.GAS;
return $ret1247612477;
};
var $Hanf_arg331412481 = function(anf_arg124912480,anf_arg12465100,self1515101,_plus26,torepr31) {
var $z1248412485 = D;
var $f1249012491 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg12465100,anf_arg124912480):R.ffi.throwNonFunApp(L[671],_plus26,[anf_arg12465100,anf_arg124912480]);
};
try {
if(--R.GAS > 0) {
$z1248412485 = $f1249012491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1249012491,
"from":L[671]});
}
} catch($e1248212483) {
if(R.isCont($e1248212483)) {
var $ss1248612487 = {"from":L[671],
"go":function(anf_arg125012492) {
return $Hanf_arg331312493(anf_arg125012492,self1515101,_plus26,torepr31);
}};
$e1248212483.stack[R.EXN_STACKHEIGHT++] = $ss1248612487;
}
if(R.isPyretException($e1248212483)) {
$e1248212483.pyretStack.push(L[671]);
}
throw $e1248212483;
}
var $ret1248812489 = $Hanf_arg331312493($z1248412485,self1515101,_plus26,torepr31);
++R.GAS;
return $ret1248812489;
};
var $Hanf_arg331312493 = function(anf_arg125012492,self1515101,_plus26,torepr31) {
var anf_arg125112504 = G(self1515101,"value",L[671]);
var $z1249612497 = D;
var $f1250212503 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg125112504):R.ffi.throwNonFunApp(L[671],torepr31,[anf_arg125112504]);
};
try {
if(--R.GAS > 0) {
$z1249612497 = $f1250212503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1250212503,
"from":L[671]});
}
} catch($e1249412495) {
if(R.isCont($e1249412495)) {
var $ss1249812499 = {"from":L[671],
"go":function(anf_arg125212505) {
return $Hanf_arg331212506(anf_arg125212505,anf_arg125012492,_plus26);
}};
$e1249412495.stack[R.EXN_STACKHEIGHT++] = $ss1249812499;
}
if(R.isPyretException($e1249412495)) {
$e1249412495.pyretStack.push(L[671]);
}
throw $e1249412495;
}
var $ret1250012501 = $Hanf_arg331212506($z1249612497,anf_arg125012492,_plus26);
++R.GAS;
return $ret1250012501;
};
var $Hanf_arg331212506 = function(anf_arg125212505,anf_arg125012492,_plus26) {
var $z1250912510 = D;
var $f1251512516 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg125212505):R.ffi.throwNonFunApp(L[671],_plus26,[(", "),anf_arg125212505]);
};
try {
if(--R.GAS > 0) {
$z1250912510 = $f1251512516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1251512516,
"from":L[671]});
}
} catch($e1250712508) {
if(R.isCont($e1250712508)) {
var $ss1251112512 = {"from":L[671],
"go":function(anf_arg125312517) {
return $Hanf_arg331112518(anf_arg125312517,anf_arg125012492,_plus26);
}};
$e1250712508.stack[R.EXN_STACKHEIGHT++] = $ss1251112512;
}
if(R.isPyretException($e1250712508)) {
$e1250712508.pyretStack.push(L[671]);
}
throw $e1250712508;
}
var $ret1251312514 = $Hanf_arg331112518($z1250912510,anf_arg125012492,_plus26);
++R.GAS;
return $ret1251312514;
};
var $Hanf_arg331112518 = function(anf_arg125312517,anf_arg125012492,_plus26) {
var $z1252112522 = D;
var $f1252712528 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg125012492,anf_arg125312517):R.ffi.throwNonFunApp(L[671],_plus26,[anf_arg125012492,anf_arg125312517]);
};
try {
if(--R.GAS > 0) {
$z1252112522 = $f1252712528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1252712528,
"from":L[671]});
}
} catch($e1251912520) {
if(R.isCont($e1251912520)) {
var $ss1252312524 = {"from":L[671],
"go":function(anf_arg125412529) {
return $Hanf_arg331012530(anf_arg125412529,_plus26);
}};
$e1251912520.stack[R.EXN_STACKHEIGHT++] = $ss1252312524;
}
if(R.isPyretException($e1251912520)) {
$e1251912520.pyretStack.push(L[671]);
}
throw $e1251912520;
}
var $ret1252512526 = $Hanf_arg331012530($z1252112522,_plus26);
++R.GAS;
return $ret1252512526;
};
var $Hanf_arg331012530 = function(anf_arg125412529,_plus26) {
var $z1253312534 = D;
var $f1253912540 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg125412529,(")")):R.ffi.throwNonFunApp(L[671],_plus26,[anf_arg125412529,(")")]);
};
try {
if(--R.GAS > 0) {
$z1253312534 = $f1253912540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1253912540,
"from":L[671]});
}
} catch($e1253112532) {
if(R.isCont($e1253112532)) {
var $ss1253512536 = {"from":L[671],
"go":function(anf_arg125512541) {
return $Hanf_arg330912542(anf_arg125512541,_plus26);
}};
$e1253112532.stack[R.EXN_STACKHEIGHT++] = $ss1253512536;
}
if(R.isPyretException($e1253112532)) {
$e1253112532.pyretStack.push(L[671]);
}
throw $e1253112532;
}
var $ret1253712538 = $Hanf_arg330912542($z1253312534,_plus26);
++R.GAS;
return $ret1253712538;
};
var $Hanf_arg330912542 = function(anf_arg125512541,_plus26) {
var $z1254512546 = D;
var $f1255112552 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg125512541):R.ffi.throwNonFunApp(L[671],_plus26,[("("),anf_arg125512541]);
};
try {
if(--R.GAS > 0) {
$z1254512546 = $f1255112552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1255112552,
"from":L[671]});
}
} catch($e1254312544) {
if(R.isCont($e1254312544)) {
var $ss1254712548 = {"from":L[671],
"go":function(anf_arg125612553) {
return $Hanf_arg330812554(anf_arg125612553,_plus26);
}};
$e1254312544.stack[R.EXN_STACKHEIGHT++] = $ss1254712548;
}
if(R.isPyretException($e1254312544)) {
$e1254312544.pyretStack.push(L[671]);
}
throw $e1254312544;
}
var $ret1254912550 = $Hanf_arg330812554($z1254512546,_plus26);
++R.GAS;
return $ret1254912550;
};
var $Hanf_arg330812554 = function(anf_arg125612553,_plus26) {
var $z1255712558 = D;
var $f1256312564 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-assign"),anf_arg125612553):R.ffi.throwNonFunApp(L[671],_plus26,[("a-assign"),anf_arg125612553]);
};
try {
if(--R.GAS > 0) {
$z1255712558 = $f1256312564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1256312564,
"from":L[671]});
}
} catch($e1255512556) {
if(R.isCont($e1255512556)) {
var $ss1255912560 = {"from":L[671],
"go":function(ann_DASH_check_DASH_temp124412565) {
return $Hann_DASH_check_DASH_temp330712566(ann_DASH_check_DASH_temp124412565);
}};
$e1255512556.stack[R.EXN_STACKHEIGHT++] = $ss1255912560;
}
if(R.isPyretException($e1255512556)) {
$e1255512556.pyretStack.push(L[671]);
}
throw $e1255512556;
}
var $ret1256112562 = $Hann_DASH_check_DASH_temp330712566($z1255712558);
++R.GAS;
return $ret1256112562;
};
var $Hann_DASH_check_DASH_temp330712566 = function(ann_DASH_check_DASH_temp124412565) {
return ann_DASH_check_DASH_temp124412565;
};
var $Hcont_tail_arg33055119 = function(cont_tail_arg12415117,if_helper12315118) {
if(--R.GAS > 0) {
$z1256712568 = R.isFunction(if_helper12315118)?if_helper12315118.app(cont_tail_arg12415117):R.ffi.throwNonFunApp(L[671],if_helper12315118,[cont_tail_arg12415117]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper12315118)?if_helper12315118.app(cont_tail_arg12415117):R.ffi.throwNonFunApp(L[671],if_helper12315118,[cont_tail_arg12415117]);
},
"from":L[671]});
}
++R.GAS;
return $z1256712568;
};
var $Hcont_tail_arg33065134 = function(cont_tail_arg12365133,if_helper12315118) {
if(--R.GAS > 0) {
$z1256912570 = R.isFunction(if_helper12315118)?if_helper12315118.app(cont_tail_arg12365133):R.ffi.throwNonFunApp(L[671],if_helper12315118,[cont_tail_arg12365133]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper12315118)?if_helper12315118.app(cont_tail_arg12365133):R.ffi.throwNonFunApp(L[671],if_helper12315118,[cont_tail_arg12365133]);
},
"from":L[671]});
}
++R.GAS;
return $z1256912570;
};
var $Hann_DASH_check_DASH_temp33045154 = function(ann_DASH_check_DASH_temp12275153) {
return ann_DASH_check_DASH_temp12275153;
};
var $Hanf_arg33035171 = function(anf_arg12055169,self1455170,_plus26,torepr31) {
var anf_arg120612581 = G(self1455170,"name",L[672]);
var $z1257312574 = D;
var $f1257912580 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg120612581):R.ffi.throwNonFunApp(L[672],torepr31,[anf_arg120612581]);
};
try {
if(--R.GAS > 0) {
$z1257312574 = $f1257912580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1257912580,
"from":L[672]});
}
} catch($e1257112572) {
if(R.isCont($e1257112572)) {
var $ss1257512576 = {"from":L[672],
"go":function(anf_arg120712582) {
return $Hanf_arg330212583(anf_arg120712582,anf_arg12055169,self1455170,_plus26,torepr31);
}};
$e1257112572.stack[R.EXN_STACKHEIGHT++] = $ss1257512576;
}
if(R.isPyretException($e1257112572)) {
$e1257112572.pyretStack.push(L[672]);
}
throw $e1257112572;
}
var $ret1257712578 = $Hanf_arg330212583($z1257312574,anf_arg12055169,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1257712578;
};
var $Hanf_arg330212583 = function(anf_arg120712582,anf_arg12055169,self1455170,_plus26,torepr31) {
var $z1258612587 = D;
var $f1259212593 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg120712582):R.ffi.throwNonFunApp(L[672],_plus26,[(", "),anf_arg120712582]);
};
try {
if(--R.GAS > 0) {
$z1258612587 = $f1259212593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1259212593,
"from":L[672]});
}
} catch($e1258412585) {
if(R.isCont($e1258412585)) {
var $ss1258812589 = {"from":L[672],
"go":function(anf_arg120812594) {
return $Hanf_arg330112595(anf_arg120812594,anf_arg12055169,self1455170,_plus26,torepr31);
}};
$e1258412585.stack[R.EXN_STACKHEIGHT++] = $ss1258812589;
}
if(R.isPyretException($e1258412585)) {
$e1258412585.pyretStack.push(L[672]);
}
throw $e1258412585;
}
var $ret1259012591 = $Hanf_arg330112595($z1258612587,anf_arg12055169,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1259012591;
};
var $Hanf_arg330112595 = function(anf_arg120812594,anf_arg12055169,self1455170,_plus26,torepr31) {
var $z1259812599 = D;
var $f1260412605 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg12055169,anf_arg120812594):R.ffi.throwNonFunApp(L[672],_plus26,[anf_arg12055169,anf_arg120812594]);
};
try {
if(--R.GAS > 0) {
$z1259812599 = $f1260412605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1260412605,
"from":L[672]});
}
} catch($e1259612597) {
if(R.isCont($e1259612597)) {
var $ss1260012601 = {"from":L[672],
"go":function(anf_arg120912606) {
return $Hanf_arg330012607(anf_arg120912606,self1455170,_plus26,torepr31);
}};
$e1259612597.stack[R.EXN_STACKHEIGHT++] = $ss1260012601;
}
if(R.isPyretException($e1259612597)) {
$e1259612597.pyretStack.push(L[672]);
}
throw $e1259612597;
}
var $ret1260212603 = $Hanf_arg330012607($z1259812599,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1260212603;
};
var $Hanf_arg330012607 = function(anf_arg120912606,self1455170,_plus26,torepr31) {
var anf_arg121012618 = G(self1455170,"namet",L[672]);
var $z1261012611 = D;
var $f1261612617 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg121012618):R.ffi.throwNonFunApp(L[672],torepr31,[anf_arg121012618]);
};
try {
if(--R.GAS > 0) {
$z1261012611 = $f1261612617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1261612617,
"from":L[672]});
}
} catch($e1260812609) {
if(R.isCont($e1260812609)) {
var $ss1261212613 = {"from":L[672],
"go":function(anf_arg121112619) {
return $Hanf_arg329912620(anf_arg121112619,anf_arg120912606,self1455170,_plus26,torepr31);
}};
$e1260812609.stack[R.EXN_STACKHEIGHT++] = $ss1261212613;
}
if(R.isPyretException($e1260812609)) {
$e1260812609.pyretStack.push(L[672]);
}
throw $e1260812609;
}
var $ret1261412615 = $Hanf_arg329912620($z1261012611,anf_arg120912606,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1261412615;
};
var $Hanf_arg329912620 = function(anf_arg121112619,anf_arg120912606,self1455170,_plus26,torepr31) {
var $z1262312624 = D;
var $f1262912630 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg121112619):R.ffi.throwNonFunApp(L[672],_plus26,[(", "),anf_arg121112619]);
};
try {
if(--R.GAS > 0) {
$z1262312624 = $f1262912630();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1262912630,
"from":L[672]});
}
} catch($e1262112622) {
if(R.isCont($e1262112622)) {
var $ss1262512626 = {"from":L[672],
"go":function(anf_arg121212631) {
return $Hanf_arg329812632(anf_arg121212631,anf_arg120912606,self1455170,_plus26,torepr31);
}};
$e1262112622.stack[R.EXN_STACKHEIGHT++] = $ss1262512626;
}
if(R.isPyretException($e1262112622)) {
$e1262112622.pyretStack.push(L[672]);
}
throw $e1262112622;
}
var $ret1262712628 = $Hanf_arg329812632($z1262312624,anf_arg120912606,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1262712628;
};
var $Hanf_arg329812632 = function(anf_arg121212631,anf_arg120912606,self1455170,_plus26,torepr31) {
var $z1263512636 = D;
var $f1264112642 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg120912606,anf_arg121212631):R.ffi.throwNonFunApp(L[672],_plus26,[anf_arg120912606,anf_arg121212631]);
};
try {
if(--R.GAS > 0) {
$z1263512636 = $f1264112642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1264112642,
"from":L[672]});
}
} catch($e1263312634) {
if(R.isCont($e1263312634)) {
var $ss1263712638 = {"from":L[672],
"go":function(anf_arg121312643) {
return $Hanf_arg329712644(anf_arg121312643,self1455170,_plus26,torepr31);
}};
$e1263312634.stack[R.EXN_STACKHEIGHT++] = $ss1263712638;
}
if(R.isPyretException($e1263312634)) {
$e1263312634.pyretStack.push(L[672]);
}
throw $e1263312634;
}
var $ret1263912640 = $Hanf_arg329712644($z1263512636,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1263912640;
};
var $Hanf_arg329712644 = function(anf_arg121312643,self1455170,_plus26,torepr31) {
var anf_arg121412655 = G(self1455170,"variants",L[672]);
var $z1264712648 = D;
var $f1265312654 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg121412655):R.ffi.throwNonFunApp(L[672],torepr31,[anf_arg121412655]);
};
try {
if(--R.GAS > 0) {
$z1264712648 = $f1265312654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1265312654,
"from":L[672]});
}
} catch($e1264512646) {
if(R.isCont($e1264512646)) {
var $ss1264912650 = {"from":L[672],
"go":function(anf_arg121512656) {
return $Hanf_arg329612657(anf_arg121512656,anf_arg121312643,self1455170,_plus26,torepr31);
}};
$e1264512646.stack[R.EXN_STACKHEIGHT++] = $ss1264912650;
}
if(R.isPyretException($e1264512646)) {
$e1264512646.pyretStack.push(L[672]);
}
throw $e1264512646;
}
var $ret1265112652 = $Hanf_arg329612657($z1264712648,anf_arg121312643,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1265112652;
};
var $Hanf_arg329612657 = function(anf_arg121512656,anf_arg121312643,self1455170,_plus26,torepr31) {
var $z1266012661 = D;
var $f1266612667 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg121512656):R.ffi.throwNonFunApp(L[672],_plus26,[(", "),anf_arg121512656]);
};
try {
if(--R.GAS > 0) {
$z1266012661 = $f1266612667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1266612667,
"from":L[672]});
}
} catch($e1265812659) {
if(R.isCont($e1265812659)) {
var $ss1266212663 = {"from":L[672],
"go":function(anf_arg121612668) {
return $Hanf_arg329512669(anf_arg121612668,anf_arg121312643,self1455170,_plus26,torepr31);
}};
$e1265812659.stack[R.EXN_STACKHEIGHT++] = $ss1266212663;
}
if(R.isPyretException($e1265812659)) {
$e1265812659.pyretStack.push(L[672]);
}
throw $e1265812659;
}
var $ret1266412665 = $Hanf_arg329512669($z1266012661,anf_arg121312643,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1266412665;
};
var $Hanf_arg329512669 = function(anf_arg121612668,anf_arg121312643,self1455170,_plus26,torepr31) {
var $z1267212673 = D;
var $f1267812679 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg121312643,anf_arg121612668):R.ffi.throwNonFunApp(L[672],_plus26,[anf_arg121312643,anf_arg121612668]);
};
try {
if(--R.GAS > 0) {
$z1267212673 = $f1267812679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1267812679,
"from":L[672]});
}
} catch($e1267012671) {
if(R.isCont($e1267012671)) {
var $ss1267412675 = {"from":L[672],
"go":function(anf_arg121712680) {
return $Hanf_arg329412681(anf_arg121712680,self1455170,_plus26,torepr31);
}};
$e1267012671.stack[R.EXN_STACKHEIGHT++] = $ss1267412675;
}
if(R.isPyretException($e1267012671)) {
$e1267012671.pyretStack.push(L[672]);
}
throw $e1267012671;
}
var $ret1267612677 = $Hanf_arg329412681($z1267212673,self1455170,_plus26,torepr31);
++R.GAS;
return $ret1267612677;
};
var $Hanf_arg329412681 = function(anf_arg121712680,self1455170,_plus26,torepr31) {
var anf_arg121812692 = G(self1455170,"shared",L[672]);
var $z1268412685 = D;
var $f1269012691 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg121812692):R.ffi.throwNonFunApp(L[672],torepr31,[anf_arg121812692]);
};
try {
if(--R.GAS > 0) {
$z1268412685 = $f1269012691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1269012691,
"from":L[672]});
}
} catch($e1268212683) {
if(R.isCont($e1268212683)) {
var $ss1268612687 = {"from":L[672],
"go":function(anf_arg121912693) {
return $Hanf_arg329312694(anf_arg121912693,anf_arg121712680,_plus26);
}};
$e1268212683.stack[R.EXN_STACKHEIGHT++] = $ss1268612687;
}
if(R.isPyretException($e1268212683)) {
$e1268212683.pyretStack.push(L[672]);
}
throw $e1268212683;
}
var $ret1268812689 = $Hanf_arg329312694($z1268412685,anf_arg121712680,_plus26);
++R.GAS;
return $ret1268812689;
};
var $Hanf_arg329312694 = function(anf_arg121912693,anf_arg121712680,_plus26) {
var $z1269712698 = D;
var $f1270312704 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg121912693):R.ffi.throwNonFunApp(L[672],_plus26,[(", "),anf_arg121912693]);
};
try {
if(--R.GAS > 0) {
$z1269712698 = $f1270312704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1270312704,
"from":L[672]});
}
} catch($e1269512696) {
if(R.isCont($e1269512696)) {
var $ss1269912700 = {"from":L[672],
"go":function(anf_arg122012705) {
return $Hanf_arg329212706(anf_arg122012705,anf_arg121712680,_plus26);
}};
$e1269512696.stack[R.EXN_STACKHEIGHT++] = $ss1269912700;
}
if(R.isPyretException($e1269512696)) {
$e1269512696.pyretStack.push(L[672]);
}
throw $e1269512696;
}
var $ret1270112702 = $Hanf_arg329212706($z1269712698,anf_arg121712680,_plus26);
++R.GAS;
return $ret1270112702;
};
var $Hanf_arg329212706 = function(anf_arg122012705,anf_arg121712680,_plus26) {
var $z1270912710 = D;
var $f1271512716 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg121712680,anf_arg122012705):R.ffi.throwNonFunApp(L[672],_plus26,[anf_arg121712680,anf_arg122012705]);
};
try {
if(--R.GAS > 0) {
$z1270912710 = $f1271512716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1271512716,
"from":L[672]});
}
} catch($e1270712708) {
if(R.isCont($e1270712708)) {
var $ss1271112712 = {"from":L[672],
"go":function(anf_arg122112717) {
return $Hanf_arg329112718(anf_arg122112717,_plus26);
}};
$e1270712708.stack[R.EXN_STACKHEIGHT++] = $ss1271112712;
}
if(R.isPyretException($e1270712708)) {
$e1270712708.pyretStack.push(L[672]);
}
throw $e1270712708;
}
var $ret1271312714 = $Hanf_arg329112718($z1270912710,_plus26);
++R.GAS;
return $ret1271312714;
};
var $Hanf_arg329112718 = function(anf_arg122112717,_plus26) {
var $z1272112722 = D;
var $f1272712728 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg122112717,(")")):R.ffi.throwNonFunApp(L[672],_plus26,[anf_arg122112717,(")")]);
};
try {
if(--R.GAS > 0) {
$z1272112722 = $f1272712728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1272712728,
"from":L[672]});
}
} catch($e1271912720) {
if(R.isCont($e1271912720)) {
var $ss1272312724 = {"from":L[672],
"go":function(anf_arg122212729) {
return $Hanf_arg329012730(anf_arg122212729,_plus26);
}};
$e1271912720.stack[R.EXN_STACKHEIGHT++] = $ss1272312724;
}
if(R.isPyretException($e1271912720)) {
$e1271912720.pyretStack.push(L[672]);
}
throw $e1271912720;
}
var $ret1272512726 = $Hanf_arg329012730($z1272112722,_plus26);
++R.GAS;
return $ret1272512726;
};
var $Hanf_arg329012730 = function(anf_arg122212729,_plus26) {
var $z1273312734 = D;
var $f1273912740 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg122212729):R.ffi.throwNonFunApp(L[672],_plus26,[("("),anf_arg122212729]);
};
try {
if(--R.GAS > 0) {
$z1273312734 = $f1273912740();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1273912740,
"from":L[672]});
}
} catch($e1273112732) {
if(R.isCont($e1273112732)) {
var $ss1273512736 = {"from":L[672],
"go":function(anf_arg122312741) {
return $Hanf_arg328912742(anf_arg122312741,_plus26);
}};
$e1273112732.stack[R.EXN_STACKHEIGHT++] = $ss1273512736;
}
if(R.isPyretException($e1273112732)) {
$e1273112732.pyretStack.push(L[672]);
}
throw $e1273112732;
}
var $ret1273712738 = $Hanf_arg328912742($z1273312734,_plus26);
++R.GAS;
return $ret1273712738;
};
var $Hanf_arg328912742 = function(anf_arg122312741,_plus26) {
var $z1274512746 = D;
var $f1275112752 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-data-expr"),anf_arg122312741):R.ffi.throwNonFunApp(L[672],_plus26,[("a-data-expr"),anf_arg122312741]);
};
try {
if(--R.GAS > 0) {
$z1274512746 = $f1275112752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1275112752,
"from":L[672]});
}
} catch($e1274312744) {
if(R.isCont($e1274312744)) {
var $ss1274712748 = {"from":L[672],
"go":function(ann_DASH_check_DASH_temp120312753) {
return $Hann_DASH_check_DASH_temp328812754(ann_DASH_check_DASH_temp120312753);
}};
$e1274312744.stack[R.EXN_STACKHEIGHT++] = $ss1274712748;
}
if(R.isPyretException($e1274312744)) {
$e1274312744.pyretStack.push(L[672]);
}
throw $e1274312744;
}
var $ret1274912750 = $Hann_DASH_check_DASH_temp328812754($z1274512746);
++R.GAS;
return $ret1274912750;
};
var $Hann_DASH_check_DASH_temp328812754 = function(ann_DASH_check_DASH_temp120312753) {
return ann_DASH_check_DASH_temp120312753;
};
var $Hcont_tail_arg32865190 = function(cont_tail_arg12005188,if_helper11885189) {
if(--R.GAS > 0) {
$z1275512756 = R.isFunction(if_helper11885189)?if_helper11885189.app(cont_tail_arg12005188):R.ffi.throwNonFunApp(L[672],if_helper11885189,[cont_tail_arg12005188]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper11885189)?if_helper11885189.app(cont_tail_arg12005188):R.ffi.throwNonFunApp(L[672],if_helper11885189,[cont_tail_arg12005188]);
},
"from":L[672]});
}
++R.GAS;
return $z1275512756;
};
var $Hcont_tail_arg32875205 = function(cont_tail_arg11935204,if_helper11885189) {
if(--R.GAS > 0) {
$z1275712758 = R.isFunction(if_helper11885189)?if_helper11885189.app(cont_tail_arg11935204):R.ffi.throwNonFunApp(L[672],if_helper11885189,[cont_tail_arg11935204]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper11885189)?if_helper11885189.app(cont_tail_arg11935204):R.ffi.throwNonFunApp(L[672],if_helper11885189,[cont_tail_arg11935204]);
},
"from":L[672]});
}
++R.GAS;
return $z1275712758;
};
var $Hanf_arg32855226 = function(anf_arg11425224,INDENT9187,PP337,list2593,self3825225,str_DASH_colon98170,_plus26) {
var anf_fun114312773 = G(PP337,"parens",L[1466]);
var anf_fun114412774 = G(PP337,"flow-map",L[1465]);
var anf_arg114512771 = G(PP337,"commabreak",L[1464]);
var anf_arg114712772 = R.makeFunction(function(x38312778) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1463],1,arguments);
}
var ann_DASH_check_DASH_temp114612779 = x38312778;
return ann_DASH_check_DASH_temp114612779;
});
var anf_fun114812775 = G(list2593,"make",L[1462]);
var anf_fun114912776 = G(PP337,"infix",L[1461]);
var anf_fun115012769 = G(PP337,"str",L[1460]);
var $z1276112762 = D;
var $f1276712768 = function(_) {
return R.isFunction(anf_fun115012769)?anf_fun115012769.app(("Answer")):R.ffi.throwNonFunApp(L[1459],anf_fun115012769,[("Answer")]);
};
try {
if(--R.GAS > 0) {
$z1276112762 = $f1276712768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1276712768,
"from":L[1459]});
}
} catch($e1275912760) {
if(R.isCont($e1275912760)) {
var $ss1276312764 = {"from":L[1459],
"go":function(anf_arg115112770) {
return $Hanf_arg328412777(anf_arg115112770,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun114912776,self3825225,str_DASH_colon98170,_plus26);
}};
$e1275912760.stack[R.EXN_STACKHEIGHT++] = $ss1276312764;
}
if(R.isPyretException($e1275912760)) {
$e1275912760.pyretStack.push(L[1459]);
}
throw $e1275912760;
}
var $ret1276512766 = $Hanf_arg328412777($z1276112762,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun114912776,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1276512766;
};
var $Hanf_arg328412777 = function(anf_arg115112770,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun114912776,self3825225,str_DASH_colon98170,_plus26) {
var anf_bracket115212793 = G(self3825225,"answer",L[1469]);
var anf_fun115312790 = G(anf_bracket115212793,"tosource",L[1468]);
var $z1278212783 = D;
var $f1278812789 = function(_) {
return R.isFunction(anf_fun115312790)?anf_fun115312790.app():R.ffi.throwNonFunApp(L[1467],anf_fun115312790,[]);
};
try {
if(--R.GAS > 0) {
$z1278212783 = $f1278812789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1278812789,
"from":L[1467]});
}
} catch($e1278012781) {
if(R.isCont($e1278012781)) {
var $ss1278412785 = {"from":L[1467],
"go":function(anf_arg115412791) {
return $Hanf_arg328312792(anf_arg115412791,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg115112770,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun114912776,self3825225,str_DASH_colon98170,_plus26);
}};
$e1278012781.stack[R.EXN_STACKHEIGHT++] = $ss1278412785;
}
if(R.isPyretException($e1278012781)) {
$e1278012781.pyretStack.push(L[1467]);
}
throw $e1278012781;
}
var $ret1278612787 = $Hanf_arg328312792($z1278212783,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg115112770,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun114912776,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1278612787;
};
var $Hanf_arg328312792 = function(anf_arg115412791,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg115112770,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun114912776,self3825225,str_DASH_colon98170,_plus26) {
var $z1279612797 = D;
var $f1280212803 = function(_) {
return R.isFunction(anf_fun114912776)?anf_fun114912776.app(INDENT9187,(1),str_DASH_colon98170,anf_arg115112770,anf_arg115412791):R.ffi.throwNonFunApp(L[1470],anf_fun114912776,[INDENT9187,(1),str_DASH_colon98170,anf_arg115112770,anf_arg115412791]);
};
try {
if(--R.GAS > 0) {
$z1279612797 = $f1280212803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1280212803,
"from":L[1470]});
}
} catch($e1279412795) {
if(R.isCont($e1279412795)) {
var $ss1279812799 = {"from":L[1470],
"go":function(anf_array_val115512804) {
return $Hanf_array_val328212805(anf_array_val115512804,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26);
}};
$e1279412795.stack[R.EXN_STACKHEIGHT++] = $ss1279812799;
}
if(R.isPyretException($e1279412795)) {
$e1279412795.pyretStack.push(L[1470]);
}
throw $e1279412795;
}
var $ret1280012801 = $Hanf_array_val328212805($z1279612797,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1280012801;
};
var $Hanf_array_val328212805 = function(anf_array_val115512804,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26) {
var anf_fun115612818 = G(PP337,"infix",L[1473]);
var anf_fun115712816 = G(PP337,"str",L[1472]);
var $z1280812809 = D;
var $f1281412815 = function(_) {
return R.isFunction(anf_fun115712816)?anf_fun115712816.app(("Provides")):R.ffi.throwNonFunApp(L[1471],anf_fun115712816,[("Provides")]);
};
try {
if(--R.GAS > 0) {
$z1280812809 = $f1281412815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1281412815,
"from":L[1471]});
}
} catch($e1280612807) {
if(R.isCont($e1280612807)) {
var $ss1281012811 = {"from":L[1471],
"go":function(anf_arg115812817) {
return $Hanf_arg328112819(anf_arg115812817,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun115612818,self3825225,str_DASH_colon98170,_plus26);
}};
$e1280612807.stack[R.EXN_STACKHEIGHT++] = $ss1281012811;
}
if(R.isPyretException($e1280612807)) {
$e1280612807.pyretStack.push(L[1471]);
}
throw $e1280612807;
}
var $ret1281212813 = $Hanf_arg328112819($z1280812809,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun115612818,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1281212813;
};
var $Hanf_arg328112819 = function(anf_arg115812817,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun115612818,self3825225,str_DASH_colon98170,_plus26) {
var anf_bracket115912833 = G(self3825225,"provides",L[1476]);
var anf_fun116012830 = G(anf_bracket115912833,"tosource",L[1475]);
var $z1282212823 = D;
var $f1282812829 = function(_) {
return R.isFunction(anf_fun116012830)?anf_fun116012830.app():R.ffi.throwNonFunApp(L[1474],anf_fun116012830,[]);
};
try {
if(--R.GAS > 0) {
$z1282212823 = $f1282812829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1282812829,
"from":L[1474]});
}
} catch($e1282012821) {
if(R.isCont($e1282012821)) {
var $ss1282412825 = {"from":L[1474],
"go":function(anf_arg116112831) {
return $Hanf_arg328012832(anf_arg116112831,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg115812817,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun115612818,self3825225,str_DASH_colon98170,_plus26);
}};
$e1282012821.stack[R.EXN_STACKHEIGHT++] = $ss1282412825;
}
if(R.isPyretException($e1282012821)) {
$e1282012821.pyretStack.push(L[1474]);
}
throw $e1282012821;
}
var $ret1282612827 = $Hanf_arg328012832($z1282212823,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg115812817,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun115612818,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1282612827;
};
var $Hanf_arg328012832 = function(anf_arg116112831,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg115812817,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun115612818,self3825225,str_DASH_colon98170,_plus26) {
var $z1283612837 = D;
var $f1284212843 = function(_) {
return R.isFunction(anf_fun115612818)?anf_fun115612818.app(INDENT9187,(1),str_DASH_colon98170,anf_arg115812817,anf_arg116112831):R.ffi.throwNonFunApp(L[1477],anf_fun115612818,[INDENT9187,(1),str_DASH_colon98170,anf_arg115812817,anf_arg116112831]);
};
try {
if(--R.GAS > 0) {
$z1283612837 = $f1284212843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1284212843,
"from":L[1477]});
}
} catch($e1283412835) {
if(R.isCont($e1283412835)) {
var $ss1283812839 = {"from":L[1477],
"go":function(anf_array_val116212844) {
return $Hanf_array_val327912845(anf_array_val116212844,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26);
}};
$e1283412835.stack[R.EXN_STACKHEIGHT++] = $ss1283812839;
}
if(R.isPyretException($e1283412835)) {
$e1283412835.pyretStack.push(L[1477]);
}
throw $e1283412835;
}
var $ret1284012841 = $Hanf_array_val327912845($z1283612837,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1284012841;
};
var $Hanf_array_val327912845 = function(anf_array_val116212844,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26) {
var anf_fun116312858 = G(PP337,"infix",L[1480]);
var anf_fun116412856 = G(PP337,"str",L[1479]);
var $z1284812849 = D;
var $f1285412855 = function(_) {
return R.isFunction(anf_fun116412856)?anf_fun116412856.app(("Types")):R.ffi.throwNonFunApp(L[1478],anf_fun116412856,[("Types")]);
};
try {
if(--R.GAS > 0) {
$z1284812849 = $f1285412855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1285412855,
"from":L[1478]});
}
} catch($e1284612847) {
if(R.isCont($e1284612847)) {
var $ss1285012851 = {"from":L[1478],
"go":function(anf_arg116512857) {
return $Hanf_arg327812859(anf_arg116512857,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,self3825225,str_DASH_colon98170,_plus26);
}};
$e1284612847.stack[R.EXN_STACKHEIGHT++] = $ss1285012851;
}
if(R.isPyretException($e1284612847)) {
$e1284612847.pyretStack.push(L[1478]);
}
throw $e1284612847;
}
var $ret1285212853 = $Hanf_arg327812859($z1284812849,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1285212853;
};
var $Hanf_arg327812859 = function(anf_arg116512857,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,self3825225,str_DASH_colon98170,_plus26) {
var anf_fun116612875 = G(PP337,"brackets",L[1486]);
var anf_fun116712870 = G(PP337,"flow-map",L[1485]);
var anf_arg116812871 = G(PP337,"commabreak",L[1484]);
var anf_arg117112872 = R.makeFunction(function(recv_DASH_14012877) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1483],1,arguments);
}
var anf_fun117012888 = G(recv_DASH_14012877,"tosource",L[1483]);
var $z1288012881 = D;
var $f1288612887 = function(_) {
return R.isFunction(anf_fun117012888)?anf_fun117012888.app():R.ffi.throwNonFunApp(L[1483],anf_fun117012888,[]);
};
try {
if(--R.GAS > 0) {
$z1288012881 = $f1288612887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1288612887,
"from":L[1483]});
}
} catch($e1287812879) {
if(R.isCont($e1287812879)) {
var $ss1288212883 = {"from":L[1483],
"go":function(ann_DASH_check_DASH_temp116912889) {
return $Hann_DASH_check_DASH_temp326712890(ann_DASH_check_DASH_temp116912889);
}};
$e1287812879.stack[R.EXN_STACKHEIGHT++] = $ss1288212883;
}
if(R.isPyretException($e1287812879)) {
$e1287812879.pyretStack.push(L[1483]);
}
throw $e1287812879;
}
var $ret1288412885 = $Hann_DASH_check_DASH_temp326712890($z1288012881);
++R.GAS;
return $ret1288412885;
});
var anf_arg117212873 = G(self3825225,"types",L[1482]);
var $z1286212863 = D;
var $f1286812869 = function(_) {
return R.isFunction(anf_fun116712870)?anf_fun116712870.app(anf_arg116812871,anf_arg117112872,anf_arg117212873):R.ffi.throwNonFunApp(L[1481],anf_fun116712870,[anf_arg116812871,anf_arg117112872,anf_arg117212873]);
};
try {
if(--R.GAS > 0) {
$z1286212863 = $f1286812869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1286812869,
"from":L[1481]});
}
} catch($e1286012861) {
if(R.isCont($e1286012861)) {
var $ss1286412865 = {"from":L[1481],
"go":function(anf_arg117312874) {
return $Hanf_arg327712876(anf_arg117312874,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg116512857,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,anf_fun116612875,self3825225,str_DASH_colon98170,_plus26);
}};
$e1286012861.stack[R.EXN_STACKHEIGHT++] = $ss1286412865;
}
if(R.isPyretException($e1286012861)) {
$e1286012861.pyretStack.push(L[1481]);
}
throw $e1286012861;
}
var $ret1286612867 = $Hanf_arg327712876($z1286212863,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg116512857,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,anf_fun116612875,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1286612867;
};
var $Hanf_arg327712876 = function(anf_arg117312874,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg116512857,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,anf_fun116612875,self3825225,str_DASH_colon98170,_plus26) {
var $z1289312894 = D;
var $f1289912900 = function(_) {
return R.isFunction(anf_fun116612875)?anf_fun116612875.app(anf_arg117312874):R.ffi.throwNonFunApp(L[1487],anf_fun116612875,[anf_arg117312874]);
};
try {
if(--R.GAS > 0) {
$z1289312894 = $f1289912900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1289912900,
"from":L[1487]});
}
} catch($e1289112892) {
if(R.isCont($e1289112892)) {
var $ss1289512896 = {"from":L[1487],
"go":function(anf_arg117412901) {
return $Hanf_arg327612902(anf_arg117412901,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg116512857,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,self3825225,str_DASH_colon98170,_plus26);
}};
$e1289112892.stack[R.EXN_STACKHEIGHT++] = $ss1289512896;
}
if(R.isPyretException($e1289112892)) {
$e1289112892.pyretStack.push(L[1487]);
}
throw $e1289112892;
}
var $ret1289712898 = $Hanf_arg327612902($z1289312894,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg116512857,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1289712898;
};
var $Hanf_arg327612902 = function(anf_arg117412901,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg116512857,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun116312858,self3825225,str_DASH_colon98170,_plus26) {
var $z1290512906 = D;
var $f1291112912 = function(_) {
return R.isFunction(anf_fun116312858)?anf_fun116312858.app(INDENT9187,(1),str_DASH_colon98170,anf_arg116512857,anf_arg117412901):R.ffi.throwNonFunApp(L[1488],anf_fun116312858,[INDENT9187,(1),str_DASH_colon98170,anf_arg116512857,anf_arg117412901]);
};
try {
if(--R.GAS > 0) {
$z1290512906 = $f1291112912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1291112912,
"from":L[1488]});
}
} catch($e1290312904) {
if(R.isCont($e1290312904)) {
var $ss1290712908 = {"from":L[1488],
"go":function(anf_array_val117512913) {
return $Hanf_array_val327512914(anf_array_val117512913,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26);
}};
$e1290312904.stack[R.EXN_STACKHEIGHT++] = $ss1290712908;
}
if(R.isPyretException($e1290312904)) {
$e1290312904.pyretStack.push(L[1488]);
}
throw $e1290312904;
}
var $ret1290912910 = $Hanf_array_val327512914($z1290512906,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1290912910;
};
var $Hanf_array_val327512914 = function(anf_array_val117512913,INDENT9187,PP337,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_fun114312773,anf_fun114412774,anf_fun114812775,self3825225,str_DASH_colon98170,_plus26) {
var anf_fun117612927 = G(PP337,"infix",L[1491]);
var anf_fun117712925 = G(PP337,"str",L[1490]);
var $z1291712918 = D;
var $f1292312924 = function(_) {
return R.isFunction(anf_fun117712925)?anf_fun117712925.app(("checks")):R.ffi.throwNonFunApp(L[1489],anf_fun117712925,[("checks")]);
};
try {
if(--R.GAS > 0) {
$z1291712918 = $f1292312924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1292312924,
"from":L[1489]});
}
} catch($e1291512916) {
if(R.isCont($e1291512916)) {
var $ss1291912920 = {"from":L[1489],
"go":function(anf_arg117812926) {
return $Hanf_arg327412928(anf_arg117812926,INDENT9187,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun117612927,self3825225,str_DASH_colon98170,_plus26);
}};
$e1291512916.stack[R.EXN_STACKHEIGHT++] = $ss1291912920;
}
if(R.isPyretException($e1291512916)) {
$e1291512916.pyretStack.push(L[1489]);
}
throw $e1291512916;
}
var $ret1292112922 = $Hanf_arg327412928($z1291712918,INDENT9187,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun117612927,self3825225,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1292112922;
};
var $Hanf_arg327412928 = function(anf_arg117812926,INDENT9187,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun117612927,self3825225,str_DASH_colon98170,_plus26) {
var anf_bracket117912942 = G(self3825225,"checks",L[1494]);
var anf_fun118012939 = G(anf_bracket117912942,"tosource",L[1493]);
var $z1293112932 = D;
var $f1293712938 = function(_) {
return R.isFunction(anf_fun118012939)?anf_fun118012939.app():R.ffi.throwNonFunApp(L[1492],anf_fun118012939,[]);
};
try {
if(--R.GAS > 0) {
$z1293112932 = $f1293712938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1293712938,
"from":L[1492]});
}
} catch($e1292912930) {
if(R.isCont($e1292912930)) {
var $ss1293312934 = {"from":L[1492],
"go":function(anf_arg118112940) {
return $Hanf_arg327312941(anf_arg118112940,INDENT9187,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg117812926,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun117612927,str_DASH_colon98170,_plus26);
}};
$e1292912930.stack[R.EXN_STACKHEIGHT++] = $ss1293312934;
}
if(R.isPyretException($e1292912930)) {
$e1292912930.pyretStack.push(L[1492]);
}
throw $e1292912930;
}
var $ret1293512936 = $Hanf_arg327312941($z1293112932,INDENT9187,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg117812926,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun117612927,str_DASH_colon98170,_plus26);
++R.GAS;
return $ret1293512936;
};
var $Hanf_arg327312941 = function(anf_arg118112940,INDENT9187,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_arg117812926,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,anf_fun117612927,str_DASH_colon98170,_plus26) {
var $z1294512946 = D;
var $f1295112952 = function(_) {
return R.isFunction(anf_fun117612927)?anf_fun117612927.app(INDENT9187,(1),str_DASH_colon98170,anf_arg117812926,anf_arg118112940):R.ffi.throwNonFunApp(L[1495],anf_fun117612927,[INDENT9187,(1),str_DASH_colon98170,anf_arg117812926,anf_arg118112940]);
};
try {
if(--R.GAS > 0) {
$z1294512946 = $f1295112952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1295112952,
"from":L[1495]});
}
} catch($e1294312944) {
if(R.isCont($e1294312944)) {
var $ss1294712948 = {"from":L[1495],
"go":function(anf_array_val118212953) {
return $Hanf_array_val327212954(anf_array_val118212953,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,_plus26);
}};
$e1294312944.stack[R.EXN_STACKHEIGHT++] = $ss1294712948;
}
if(R.isPyretException($e1294312944)) {
$e1294312944.pyretStack.push(L[1495]);
}
throw $e1294312944;
}
var $ret1294912950 = $Hanf_array_val327212954($z1294512946,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,_plus26);
++R.GAS;
return $ret1294912950;
};
var $Hanf_array_val327212954 = function(anf_array_val118212953,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_fun114312773,anf_fun114412774,anf_fun114812775,_plus26) {
var $z1295712958 = D;
var $f1296312964 = function(_) {
return R.isFunction(anf_fun114812775)?anf_fun114812775.app([anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_array_val118212953]):R.ffi.throwNonFunApp(L[1462],anf_fun114812775,[[anf_array_val115512804,anf_array_val116212844,anf_array_val117512913,anf_array_val118212953]]);
};
try {
if(--R.GAS > 0) {
$z1295712958 = $f1296312964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1296312964,
"from":L[1462]});
}
} catch($e1295512956) {
if(R.isCont($e1295512956)) {
var $ss1295912960 = {"from":L[1462],
"go":function(anf_arg118312965) {
return $Hanf_arg327112966(anf_arg118312965,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,_plus26);
}};
$e1295512956.stack[R.EXN_STACKHEIGHT++] = $ss1295912960;
}
if(R.isPyretException($e1295512956)) {
$e1295512956.pyretStack.push(L[1462]);
}
throw $e1295512956;
}
var $ret1296112962 = $Hanf_arg327112966($z1295712958,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,_plus26);
++R.GAS;
return $ret1296112962;
};
var $Hanf_arg327112966 = function(anf_arg118312965,anf_arg11425224,anf_arg114512771,anf_arg114712772,anf_fun114312773,anf_fun114412774,_plus26) {
var $z1296912970 = D;
var $f1297512976 = function(_) {
return R.isFunction(anf_fun114412774)?anf_fun114412774.app(anf_arg114512771,anf_arg114712772,anf_arg118312965):R.ffi.throwNonFunApp(L[1496],anf_fun114412774,[anf_arg114512771,anf_arg114712772,anf_arg118312965]);
};
try {
if(--R.GAS > 0) {
$z1296912970 = $f1297512976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1297512976,
"from":L[1496]});
}
} catch($e1296712968) {
if(R.isCont($e1296712968)) {
var $ss1297112972 = {"from":L[1496],
"go":function(anf_arg118412977) {
return $Hanf_arg327012978(anf_arg118412977,anf_arg11425224,anf_fun114312773,_plus26);
}};
$e1296712968.stack[R.EXN_STACKHEIGHT++] = $ss1297112972;
}
if(R.isPyretException($e1296712968)) {
$e1296712968.pyretStack.push(L[1496]);
}
throw $e1296712968;
}
var $ret1297312974 = $Hanf_arg327012978($z1296912970,anf_arg11425224,anf_fun114312773,_plus26);
++R.GAS;
return $ret1297312974;
};
var $Hanf_arg327012978 = function(anf_arg118412977,anf_arg11425224,anf_fun114312773,_plus26) {
var $z1298112982 = D;
var $f1298712988 = function(_) {
return R.isFunction(anf_fun114312773)?anf_fun114312773.app(anf_arg118412977):R.ffi.throwNonFunApp(L[1497],anf_fun114312773,[anf_arg118412977]);
};
try {
if(--R.GAS > 0) {
$z1298112982 = $f1298712988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1298712988,
"from":L[1497]});
}
} catch($e1297912980) {
if(R.isCont($e1297912980)) {
var $ss1298312984 = {"from":L[1497],
"go":function(anf_arg118512989) {
return $Hanf_arg326912990(anf_arg118512989,anf_arg11425224,_plus26);
}};
$e1297912980.stack[R.EXN_STACKHEIGHT++] = $ss1298312984;
}
if(R.isPyretException($e1297912980)) {
$e1297912980.pyretStack.push(L[1497]);
}
throw $e1297912980;
}
var $ret1298512986 = $Hanf_arg326912990($z1298112982,anf_arg11425224,_plus26);
++R.GAS;
return $ret1298512986;
};
var $Hanf_arg326912990 = function(anf_arg118512989,anf_arg11425224,_plus26) {
var $z1299312994 = D;
var $f1299913000 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg11425224,anf_arg118512989):R.ffi.throwNonFunApp(L[839],_plus26,[anf_arg11425224,anf_arg118512989]);
};
try {
if(--R.GAS > 0) {
$z1299312994 = $f1299913000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1299913000,
"from":L[839]});
}
} catch($e1299112992) {
if(R.isCont($e1299112992)) {
var $ss1299512996 = {"from":L[839],
"go":function(ann_DASH_check_DASH_temp114013001) {
return $Hann_DASH_check_DASH_temp326813002(ann_DASH_check_DASH_temp114013001);
}};
$e1299112992.stack[R.EXN_STACKHEIGHT++] = $ss1299512996;
}
if(R.isPyretException($e1299112992)) {
$e1299112992.pyretStack.push(L[839]);
}
throw $e1299112992;
}
var $ret1299712998 = $Hann_DASH_check_DASH_temp326813002($z1299312994);
++R.GAS;
return $ret1299712998;
};
var $Hann_DASH_check_DASH_temp326813002 = function(ann_DASH_check_DASH_temp114013001) {
return ann_DASH_check_DASH_temp114013001;
};
var $Hann_DASH_check_DASH_temp326712890 = function(ann_DASH_check_DASH_temp116912889) {
return ann_DASH_check_DASH_temp116912889;
};
var $Hanf_arg32665242 = function(anf_arg11185240,self1385241,_plus26,torepr31) {
var anf_arg111913013 = G(self1385241,"answer",L[673]);
var $z1300513006 = D;
var $f1301113012 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg111913013):R.ffi.throwNonFunApp(L[673],torepr31,[anf_arg111913013]);
};
try {
if(--R.GAS > 0) {
$z1300513006 = $f1301113012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1301113012,
"from":L[673]});
}
} catch($e1300313004) {
if(R.isCont($e1300313004)) {
var $ss1300713008 = {"from":L[673],
"go":function(anf_arg112013014) {
return $Hanf_arg326513015(anf_arg112013014,anf_arg11185240,self1385241,_plus26,torepr31);
}};
$e1300313004.stack[R.EXN_STACKHEIGHT++] = $ss1300713008;
}
if(R.isPyretException($e1300313004)) {
$e1300313004.pyretStack.push(L[673]);
}
throw $e1300313004;
}
var $ret1300913010 = $Hanf_arg326513015($z1300513006,anf_arg11185240,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1300913010;
};
var $Hanf_arg326513015 = function(anf_arg112013014,anf_arg11185240,self1385241,_plus26,torepr31) {
var $z1301813019 = D;
var $f1302413025 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg112013014):R.ffi.throwNonFunApp(L[673],_plus26,[(", "),anf_arg112013014]);
};
try {
if(--R.GAS > 0) {
$z1301813019 = $f1302413025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1302413025,
"from":L[673]});
}
} catch($e1301613017) {
if(R.isCont($e1301613017)) {
var $ss1302013021 = {"from":L[673],
"go":function(anf_arg112113026) {
return $Hanf_arg326413027(anf_arg112113026,anf_arg11185240,self1385241,_plus26,torepr31);
}};
$e1301613017.stack[R.EXN_STACKHEIGHT++] = $ss1302013021;
}
if(R.isPyretException($e1301613017)) {
$e1301613017.pyretStack.push(L[673]);
}
throw $e1301613017;
}
var $ret1302213023 = $Hanf_arg326413027($z1301813019,anf_arg11185240,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1302213023;
};
var $Hanf_arg326413027 = function(anf_arg112113026,anf_arg11185240,self1385241,_plus26,torepr31) {
var $z1303013031 = D;
var $f1303613037 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg11185240,anf_arg112113026):R.ffi.throwNonFunApp(L[673],_plus26,[anf_arg11185240,anf_arg112113026]);
};
try {
if(--R.GAS > 0) {
$z1303013031 = $f1303613037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1303613037,
"from":L[673]});
}
} catch($e1302813029) {
if(R.isCont($e1302813029)) {
var $ss1303213033 = {"from":L[673],
"go":function(anf_arg112213038) {
return $Hanf_arg326313039(anf_arg112213038,self1385241,_plus26,torepr31);
}};
$e1302813029.stack[R.EXN_STACKHEIGHT++] = $ss1303213033;
}
if(R.isPyretException($e1302813029)) {
$e1302813029.pyretStack.push(L[673]);
}
throw $e1302813029;
}
var $ret1303413035 = $Hanf_arg326313039($z1303013031,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1303413035;
};
var $Hanf_arg326313039 = function(anf_arg112213038,self1385241,_plus26,torepr31) {
var anf_arg112313050 = G(self1385241,"provides",L[673]);
var $z1304213043 = D;
var $f1304813049 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg112313050):R.ffi.throwNonFunApp(L[673],torepr31,[anf_arg112313050]);
};
try {
if(--R.GAS > 0) {
$z1304213043 = $f1304813049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1304813049,
"from":L[673]});
}
} catch($e1304013041) {
if(R.isCont($e1304013041)) {
var $ss1304413045 = {"from":L[673],
"go":function(anf_arg112413051) {
return $Hanf_arg326213052(anf_arg112413051,anf_arg112213038,self1385241,_plus26,torepr31);
}};
$e1304013041.stack[R.EXN_STACKHEIGHT++] = $ss1304413045;
}
if(R.isPyretException($e1304013041)) {
$e1304013041.pyretStack.push(L[673]);
}
throw $e1304013041;
}
var $ret1304613047 = $Hanf_arg326213052($z1304213043,anf_arg112213038,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1304613047;
};
var $Hanf_arg326213052 = function(anf_arg112413051,anf_arg112213038,self1385241,_plus26,torepr31) {
var $z1305513056 = D;
var $f1306113062 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg112413051):R.ffi.throwNonFunApp(L[673],_plus26,[(", "),anf_arg112413051]);
};
try {
if(--R.GAS > 0) {
$z1305513056 = $f1306113062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1306113062,
"from":L[673]});
}
} catch($e1305313054) {
if(R.isCont($e1305313054)) {
var $ss1305713058 = {"from":L[673],
"go":function(anf_arg112513063) {
return $Hanf_arg326113064(anf_arg112513063,anf_arg112213038,self1385241,_plus26,torepr31);
}};
$e1305313054.stack[R.EXN_STACKHEIGHT++] = $ss1305713058;
}
if(R.isPyretException($e1305313054)) {
$e1305313054.pyretStack.push(L[673]);
}
throw $e1305313054;
}
var $ret1305913060 = $Hanf_arg326113064($z1305513056,anf_arg112213038,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1305913060;
};
var $Hanf_arg326113064 = function(anf_arg112513063,anf_arg112213038,self1385241,_plus26,torepr31) {
var $z1306713068 = D;
var $f1307313074 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg112213038,anf_arg112513063):R.ffi.throwNonFunApp(L[673],_plus26,[anf_arg112213038,anf_arg112513063]);
};
try {
if(--R.GAS > 0) {
$z1306713068 = $f1307313074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1307313074,
"from":L[673]});
}
} catch($e1306513066) {
if(R.isCont($e1306513066)) {
var $ss1306913070 = {"from":L[673],
"go":function(anf_arg112613075) {
return $Hanf_arg326013076(anf_arg112613075,self1385241,_plus26,torepr31);
}};
$e1306513066.stack[R.EXN_STACKHEIGHT++] = $ss1306913070;
}
if(R.isPyretException($e1306513066)) {
$e1306513066.pyretStack.push(L[673]);
}
throw $e1306513066;
}
var $ret1307113072 = $Hanf_arg326013076($z1306713068,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1307113072;
};
var $Hanf_arg326013076 = function(anf_arg112613075,self1385241,_plus26,torepr31) {
var anf_arg112713087 = G(self1385241,"types",L[673]);
var $z1307913080 = D;
var $f1308513086 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg112713087):R.ffi.throwNonFunApp(L[673],torepr31,[anf_arg112713087]);
};
try {
if(--R.GAS > 0) {
$z1307913080 = $f1308513086();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1308513086,
"from":L[673]});
}
} catch($e1307713078) {
if(R.isCont($e1307713078)) {
var $ss1308113082 = {"from":L[673],
"go":function(anf_arg112813088) {
return $Hanf_arg325913089(anf_arg112813088,anf_arg112613075,self1385241,_plus26,torepr31);
}};
$e1307713078.stack[R.EXN_STACKHEIGHT++] = $ss1308113082;
}
if(R.isPyretException($e1307713078)) {
$e1307713078.pyretStack.push(L[673]);
}
throw $e1307713078;
}
var $ret1308313084 = $Hanf_arg325913089($z1307913080,anf_arg112613075,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1308313084;
};
var $Hanf_arg325913089 = function(anf_arg112813088,anf_arg112613075,self1385241,_plus26,torepr31) {
var $z1309213093 = D;
var $f1309813099 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg112813088):R.ffi.throwNonFunApp(L[673],_plus26,[(", "),anf_arg112813088]);
};
try {
if(--R.GAS > 0) {
$z1309213093 = $f1309813099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1309813099,
"from":L[673]});
}
} catch($e1309013091) {
if(R.isCont($e1309013091)) {
var $ss1309413095 = {"from":L[673],
"go":function(anf_arg112913100) {
return $Hanf_arg325813101(anf_arg112913100,anf_arg112613075,self1385241,_plus26,torepr31);
}};
$e1309013091.stack[R.EXN_STACKHEIGHT++] = $ss1309413095;
}
if(R.isPyretException($e1309013091)) {
$e1309013091.pyretStack.push(L[673]);
}
throw $e1309013091;
}
var $ret1309613097 = $Hanf_arg325813101($z1309213093,anf_arg112613075,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1309613097;
};
var $Hanf_arg325813101 = function(anf_arg112913100,anf_arg112613075,self1385241,_plus26,torepr31) {
var $z1310413105 = D;
var $f1311013111 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg112613075,anf_arg112913100):R.ffi.throwNonFunApp(L[673],_plus26,[anf_arg112613075,anf_arg112913100]);
};
try {
if(--R.GAS > 0) {
$z1310413105 = $f1311013111();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1311013111,
"from":L[673]});
}
} catch($e1310213103) {
if(R.isCont($e1310213103)) {
var $ss1310613107 = {"from":L[673],
"go":function(anf_arg113013112) {
return $Hanf_arg325713113(anf_arg113013112,self1385241,_plus26,torepr31);
}};
$e1310213103.stack[R.EXN_STACKHEIGHT++] = $ss1310613107;
}
if(R.isPyretException($e1310213103)) {
$e1310213103.pyretStack.push(L[673]);
}
throw $e1310213103;
}
var $ret1310813109 = $Hanf_arg325713113($z1310413105,self1385241,_plus26,torepr31);
++R.GAS;
return $ret1310813109;
};
var $Hanf_arg325713113 = function(anf_arg113013112,self1385241,_plus26,torepr31) {
var anf_arg113113124 = G(self1385241,"checks",L[673]);
var $z1311613117 = D;
var $f1312213123 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg113113124):R.ffi.throwNonFunApp(L[673],torepr31,[anf_arg113113124]);
};
try {
if(--R.GAS > 0) {
$z1311613117 = $f1312213123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1312213123,
"from":L[673]});
}
} catch($e1311413115) {
if(R.isCont($e1311413115)) {
var $ss1311813119 = {"from":L[673],
"go":function(anf_arg113213125) {
return $Hanf_arg325613126(anf_arg113213125,anf_arg113013112,_plus26);
}};
$e1311413115.stack[R.EXN_STACKHEIGHT++] = $ss1311813119;
}
if(R.isPyretException($e1311413115)) {
$e1311413115.pyretStack.push(L[673]);
}
throw $e1311413115;
}
var $ret1312013121 = $Hanf_arg325613126($z1311613117,anf_arg113013112,_plus26);
++R.GAS;
return $ret1312013121;
};
var $Hanf_arg325613126 = function(anf_arg113213125,anf_arg113013112,_plus26) {
var $z1312913130 = D;
var $f1313513136 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg113213125):R.ffi.throwNonFunApp(L[673],_plus26,[(", "),anf_arg113213125]);
};
try {
if(--R.GAS > 0) {
$z1312913130 = $f1313513136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1313513136,
"from":L[673]});
}
} catch($e1312713128) {
if(R.isCont($e1312713128)) {
var $ss1313113132 = {"from":L[673],
"go":function(anf_arg113313137) {
return $Hanf_arg325513138(anf_arg113313137,anf_arg113013112,_plus26);
}};
$e1312713128.stack[R.EXN_STACKHEIGHT++] = $ss1313113132;
}
if(R.isPyretException($e1312713128)) {
$e1312713128.pyretStack.push(L[673]);
}
throw $e1312713128;
}
var $ret1313313134 = $Hanf_arg325513138($z1312913130,anf_arg113013112,_plus26);
++R.GAS;
return $ret1313313134;
};
var $Hanf_arg325513138 = function(anf_arg113313137,anf_arg113013112,_plus26) {
var $z1314113142 = D;
var $f1314713148 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg113013112,anf_arg113313137):R.ffi.throwNonFunApp(L[673],_plus26,[anf_arg113013112,anf_arg113313137]);
};
try {
if(--R.GAS > 0) {
$z1314113142 = $f1314713148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1314713148,
"from":L[673]});
}
} catch($e1313913140) {
if(R.isCont($e1313913140)) {
var $ss1314313144 = {"from":L[673],
"go":function(anf_arg113413149) {
return $Hanf_arg325413150(anf_arg113413149,_plus26);
}};
$e1313913140.stack[R.EXN_STACKHEIGHT++] = $ss1314313144;
}
if(R.isPyretException($e1313913140)) {
$e1313913140.pyretStack.push(L[673]);
}
throw $e1313913140;
}
var $ret1314513146 = $Hanf_arg325413150($z1314113142,_plus26);
++R.GAS;
return $ret1314513146;
};
var $Hanf_arg325413150 = function(anf_arg113413149,_plus26) {
var $z1315313154 = D;
var $f1315913160 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg113413149,(")")):R.ffi.throwNonFunApp(L[673],_plus26,[anf_arg113413149,(")")]);
};
try {
if(--R.GAS > 0) {
$z1315313154 = $f1315913160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1315913160,
"from":L[673]});
}
} catch($e1315113152) {
if(R.isCont($e1315113152)) {
var $ss1315513156 = {"from":L[673],
"go":function(anf_arg113513161) {
return $Hanf_arg325313162(anf_arg113513161,_plus26);
}};
$e1315113152.stack[R.EXN_STACKHEIGHT++] = $ss1315513156;
}
if(R.isPyretException($e1315113152)) {
$e1315113152.pyretStack.push(L[673]);
}
throw $e1315113152;
}
var $ret1315713158 = $Hanf_arg325313162($z1315313154,_plus26);
++R.GAS;
return $ret1315713158;
};
var $Hanf_arg325313162 = function(anf_arg113513161,_plus26) {
var $z1316513166 = D;
var $f1317113172 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg113513161):R.ffi.throwNonFunApp(L[673],_plus26,[("("),anf_arg113513161]);
};
try {
if(--R.GAS > 0) {
$z1316513166 = $f1317113172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1317113172,
"from":L[673]});
}
} catch($e1316313164) {
if(R.isCont($e1316313164)) {
var $ss1316713168 = {"from":L[673],
"go":function(anf_arg113613173) {
return $Hanf_arg325213174(anf_arg113613173,_plus26);
}};
$e1316313164.stack[R.EXN_STACKHEIGHT++] = $ss1316713168;
}
if(R.isPyretException($e1316313164)) {
$e1316313164.pyretStack.push(L[673]);
}
throw $e1316313164;
}
var $ret1316913170 = $Hanf_arg325213174($z1316513166,_plus26);
++R.GAS;
return $ret1316913170;
};
var $Hanf_arg325213174 = function(anf_arg113613173,_plus26) {
var $z1317713178 = D;
var $f1318313184 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-module"),anf_arg113613173):R.ffi.throwNonFunApp(L[673],_plus26,[("a-module"),anf_arg113613173]);
};
try {
if(--R.GAS > 0) {
$z1317713178 = $f1318313184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1318313184,
"from":L[673]});
}
} catch($e1317513176) {
if(R.isCont($e1317513176)) {
var $ss1317913180 = {"from":L[673],
"go":function(ann_DASH_check_DASH_temp111613185) {
return $Hann_DASH_check_DASH_temp325113186(ann_DASH_check_DASH_temp111613185);
}};
$e1317513176.stack[R.EXN_STACKHEIGHT++] = $ss1317913180;
}
if(R.isPyretException($e1317513176)) {
$e1317513176.pyretStack.push(L[673]);
}
throw $e1317513176;
}
var $ret1318113182 = $Hann_DASH_check_DASH_temp325113186($z1317713178);
++R.GAS;
return $ret1318113182;
};
var $Hann_DASH_check_DASH_temp325113186 = function(ann_DASH_check_DASH_temp111613185) {
return ann_DASH_check_DASH_temp111613185;
};
var $Hcont_tail_arg32495261 = function(cont_tail_arg11135259,if_helper11015260) {
if(--R.GAS > 0) {
$z1318713188 = R.isFunction(if_helper11015260)?if_helper11015260.app(cont_tail_arg11135259):R.ffi.throwNonFunApp(L[673],if_helper11015260,[cont_tail_arg11135259]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper11015260)?if_helper11015260.app(cont_tail_arg11135259):R.ffi.throwNonFunApp(L[673],if_helper11015260,[cont_tail_arg11135259]);
},
"from":L[673]});
}
++R.GAS;
return $z1318713188;
};
var $Hcont_tail_arg32505276 = function(cont_tail_arg11065275,if_helper11015260) {
if(--R.GAS > 0) {
$z1318913190 = R.isFunction(if_helper11015260)?if_helper11015260.app(cont_tail_arg11065275):R.ffi.throwNonFunApp(L[673],if_helper11015260,[cont_tail_arg11065275]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper11015260)?if_helper11015260.app(cont_tail_arg11065275):R.ffi.throwNonFunApp(L[673],if_helper11015260,[cont_tail_arg11065275]);
},
"from":L[673]});
}
++R.GAS;
return $z1318913190;
};
var $Hann_DASH_check_DASH_temp32485298 = function(ann_DASH_check_DASH_temp10925297) {
return ann_DASH_check_DASH_temp10925297;
};
var $Hanf_arg32475311 = function(anf_arg10965310,_plus26,raise30) {
var $z1319313194 = D;
var $f1319913200 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg10965310):R.ffi.throwNonFunApp(L[1498],_plus26,[("No visitor field for "),anf_arg10965310]);
};
try {
if(--R.GAS > 0) {
$z1319313194 = $f1319913200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1319913200,
"from":L[1498]});
}
} catch($e1319113192) {
if(R.isCont($e1319113192)) {
var $ss1319513196 = {"from":L[1498],
"go":function(anf_arg109713201) {
return $Hanf_arg324613202(anf_arg109713201,raise30);
}};
$e1319113192.stack[R.EXN_STACKHEIGHT++] = $ss1319513196;
}
if(R.isPyretException($e1319113192)) {
$e1319113192.pyretStack.push(L[1498]);
}
throw $e1319113192;
}
var $ret1319713198 = $Hanf_arg324613202($z1319313194,raise30);
++R.GAS;
return $ret1319713198;
};
var $Hanf_arg324613202 = function(anf_arg109713201,raise30) {
var $z1320513206 = D;
var $f1321113212 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg109713201):R.ffi.throwNonFunApp(L[847],raise30,[anf_arg109713201]);
};
try {
if(--R.GAS > 0) {
$z1320513206 = $f1321113212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1321113212,
"from":L[847]});
}
} catch($e1320313204) {
if(R.isCont($e1320313204)) {
var $ss1320713208 = {"from":L[847],
"go":function(ann_DASH_check_DASH_temp109413213) {
return $Hann_DASH_check_DASH_temp324513214(ann_DASH_check_DASH_temp109413213);
}};
$e1320313204.stack[R.EXN_STACKHEIGHT++] = $ss1320713208;
}
if(R.isPyretException($e1320313204)) {
$e1320313204.pyretStack.push(L[847]);
}
throw $e1320313204;
}
var $ret1320913210 = $Hann_DASH_check_DASH_temp324513214($z1320513206);
++R.GAS;
return $ret1320913210;
};
var $Hann_DASH_check_DASH_temp324513214 = function(ann_DASH_check_DASH_temp109413213) {
return ann_DASH_check_DASH_temp109413213;
};
var $Hanf_arg32445339 = function(anf_arg10825337,self3735338,_plus26) {
var anf_bracket108313228 = G(self3735338,"bind",L[1501]);
var anf_fun108413225 = G(anf_bracket108313228,"tosource",L[1500]);
var $z1321713218 = D;
var $f1322313224 = function(_) {
return R.isFunction(anf_fun108413225)?anf_fun108413225.app():R.ffi.throwNonFunApp(L[1499],anf_fun108413225,[]);
};
try {
if(--R.GAS > 0) {
$z1321713218 = $f1322313224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1322313224,
"from":L[1499]});
}
} catch($e1321513216) {
if(R.isCont($e1321513216)) {
var $ss1321913220 = {"from":L[1499],
"go":function(anf_arg108513226) {
return $Hanf_arg324313227(anf_arg108513226,anf_arg10825337,_plus26);
}};
$e1321513216.stack[R.EXN_STACKHEIGHT++] = $ss1321913220;
}
if(R.isPyretException($e1321513216)) {
$e1321513216.pyretStack.push(L[1499]);
}
throw $e1321513216;
}
var $ret1322113222 = $Hanf_arg324313227($z1321713218,anf_arg10825337,_plus26);
++R.GAS;
return $ret1322113222;
};
var $Hanf_arg324313227 = function(anf_arg108513226,anf_arg10825337,_plus26) {
var $z1323113232 = D;
var $f1323713238 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg10825337,anf_arg108513226):R.ffi.throwNonFunApp(L[860],_plus26,[anf_arg10825337,anf_arg108513226]);
};
try {
if(--R.GAS > 0) {
$z1323113232 = $f1323713238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1323713238,
"from":L[860]});
}
} catch($e1322913230) {
if(R.isCont($e1322913230)) {
var $ss1323313234 = {"from":L[860],
"go":function(ann_DASH_check_DASH_temp107913239) {
return $Hann_DASH_check_DASH_temp324213240(ann_DASH_check_DASH_temp107913239);
}};
$e1322913230.stack[R.EXN_STACKHEIGHT++] = $ss1323313234;
}
if(R.isPyretException($e1322913230)) {
$e1322913230.pyretStack.push(L[860]);
}
throw $e1322913230;
}
var $ret1323513236 = $Hann_DASH_check_DASH_temp324213240($z1323113232);
++R.GAS;
return $ret1323513236;
};
var $Hann_DASH_check_DASH_temp324213240 = function(ann_DASH_check_DASH_temp107913239) {
return ann_DASH_check_DASH_temp107913239;
};
var $Hanf_arg32415356 = function(anf_arg10655354,self1325355,_plus26,torepr31) {
var anf_arg106613251 = G(self1325355,"member-type",L[851]);
var $z1324313244 = D;
var $f1324913250 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg106613251):R.ffi.throwNonFunApp(L[851],torepr31,[anf_arg106613251]);
};
try {
if(--R.GAS > 0) {
$z1324313244 = $f1324913250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1324913250,
"from":L[851]});
}
} catch($e1324113242) {
if(R.isCont($e1324113242)) {
var $ss1324513246 = {"from":L[851],
"go":function(anf_arg106713252) {
return $Hanf_arg324013253(anf_arg106713252,anf_arg10655354,self1325355,_plus26,torepr31);
}};
$e1324113242.stack[R.EXN_STACKHEIGHT++] = $ss1324513246;
}
if(R.isPyretException($e1324113242)) {
$e1324113242.pyretStack.push(L[851]);
}
throw $e1324113242;
}
var $ret1324713248 = $Hanf_arg324013253($z1324313244,anf_arg10655354,self1325355,_plus26,torepr31);
++R.GAS;
return $ret1324713248;
};
var $Hanf_arg324013253 = function(anf_arg106713252,anf_arg10655354,self1325355,_plus26,torepr31) {
var $z1325613257 = D;
var $f1326213263 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg106713252):R.ffi.throwNonFunApp(L[851],_plus26,[(", "),anf_arg106713252]);
};
try {
if(--R.GAS > 0) {
$z1325613257 = $f1326213263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1326213263,
"from":L[851]});
}
} catch($e1325413255) {
if(R.isCont($e1325413255)) {
var $ss1325813259 = {"from":L[851],
"go":function(anf_arg106813264) {
return $Hanf_arg323913265(anf_arg106813264,anf_arg10655354,self1325355,_plus26,torepr31);
}};
$e1325413255.stack[R.EXN_STACKHEIGHT++] = $ss1325813259;
}
if(R.isPyretException($e1325413255)) {
$e1325413255.pyretStack.push(L[851]);
}
throw $e1325413255;
}
var $ret1326013261 = $Hanf_arg323913265($z1325613257,anf_arg10655354,self1325355,_plus26,torepr31);
++R.GAS;
return $ret1326013261;
};
var $Hanf_arg323913265 = function(anf_arg106813264,anf_arg10655354,self1325355,_plus26,torepr31) {
var $z1326813269 = D;
var $f1327413275 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg10655354,anf_arg106813264):R.ffi.throwNonFunApp(L[851],_plus26,[anf_arg10655354,anf_arg106813264]);
};
try {
if(--R.GAS > 0) {
$z1326813269 = $f1327413275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1327413275,
"from":L[851]});
}
} catch($e1326613267) {
if(R.isCont($e1326613267)) {
var $ss1327013271 = {"from":L[851],
"go":function(anf_arg106913276) {
return $Hanf_arg323813277(anf_arg106913276,self1325355,_plus26,torepr31);
}};
$e1326613267.stack[R.EXN_STACKHEIGHT++] = $ss1327013271;
}
if(R.isPyretException($e1326613267)) {
$e1326613267.pyretStack.push(L[851]);
}
throw $e1326613267;
}
var $ret1327213273 = $Hanf_arg323813277($z1326813269,self1325355,_plus26,torepr31);
++R.GAS;
return $ret1327213273;
};
var $Hanf_arg323813277 = function(anf_arg106913276,self1325355,_plus26,torepr31) {
var anf_arg107013288 = G(self1325355,"bind",L[851]);
var $z1328013281 = D;
var $f1328613287 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg107013288):R.ffi.throwNonFunApp(L[851],torepr31,[anf_arg107013288]);
};
try {
if(--R.GAS > 0) {
$z1328013281 = $f1328613287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1328613287,
"from":L[851]});
}
} catch($e1327813279) {
if(R.isCont($e1327813279)) {
var $ss1328213283 = {"from":L[851],
"go":function(anf_arg107113289) {
return $Hanf_arg323713290(anf_arg107113289,anf_arg106913276,_plus26);
}};
$e1327813279.stack[R.EXN_STACKHEIGHT++] = $ss1328213283;
}
if(R.isPyretException($e1327813279)) {
$e1327813279.pyretStack.push(L[851]);
}
throw $e1327813279;
}
var $ret1328413285 = $Hanf_arg323713290($z1328013281,anf_arg106913276,_plus26);
++R.GAS;
return $ret1328413285;
};
var $Hanf_arg323713290 = function(anf_arg107113289,anf_arg106913276,_plus26) {
var $z1329313294 = D;
var $f1329913300 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg107113289):R.ffi.throwNonFunApp(L[851],_plus26,[(", "),anf_arg107113289]);
};
try {
if(--R.GAS > 0) {
$z1329313294 = $f1329913300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1329913300,
"from":L[851]});
}
} catch($e1329113292) {
if(R.isCont($e1329113292)) {
var $ss1329513296 = {"from":L[851],
"go":function(anf_arg107213301) {
return $Hanf_arg323613302(anf_arg107213301,anf_arg106913276,_plus26);
}};
$e1329113292.stack[R.EXN_STACKHEIGHT++] = $ss1329513296;
}
if(R.isPyretException($e1329113292)) {
$e1329113292.pyretStack.push(L[851]);
}
throw $e1329113292;
}
var $ret1329713298 = $Hanf_arg323613302($z1329313294,anf_arg106913276,_plus26);
++R.GAS;
return $ret1329713298;
};
var $Hanf_arg323613302 = function(anf_arg107213301,anf_arg106913276,_plus26) {
var $z1330513306 = D;
var $f1331113312 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg106913276,anf_arg107213301):R.ffi.throwNonFunApp(L[851],_plus26,[anf_arg106913276,anf_arg107213301]);
};
try {
if(--R.GAS > 0) {
$z1330513306 = $f1331113312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1331113312,
"from":L[851]});
}
} catch($e1330313304) {
if(R.isCont($e1330313304)) {
var $ss1330713308 = {"from":L[851],
"go":function(anf_arg107313313) {
return $Hanf_arg323513314(anf_arg107313313,_plus26);
}};
$e1330313304.stack[R.EXN_STACKHEIGHT++] = $ss1330713308;
}
if(R.isPyretException($e1330313304)) {
$e1330313304.pyretStack.push(L[851]);
}
throw $e1330313304;
}
var $ret1330913310 = $Hanf_arg323513314($z1330513306,_plus26);
++R.GAS;
return $ret1330913310;
};
var $Hanf_arg323513314 = function(anf_arg107313313,_plus26) {
var $z1331713318 = D;
var $f1332313324 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg107313313,(")")):R.ffi.throwNonFunApp(L[851],_plus26,[anf_arg107313313,(")")]);
};
try {
if(--R.GAS > 0) {
$z1331713318 = $f1332313324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1332313324,
"from":L[851]});
}
} catch($e1331513316) {
if(R.isCont($e1331513316)) {
var $ss1331913320 = {"from":L[851],
"go":function(anf_arg107413325) {
return $Hanf_arg323413326(anf_arg107413325,_plus26);
}};
$e1331513316.stack[R.EXN_STACKHEIGHT++] = $ss1331913320;
}
if(R.isPyretException($e1331513316)) {
$e1331513316.pyretStack.push(L[851]);
}
throw $e1331513316;
}
var $ret1332113322 = $Hanf_arg323413326($z1331713318,_plus26);
++R.GAS;
return $ret1332113322;
};
var $Hanf_arg323413326 = function(anf_arg107413325,_plus26) {
var $z1332913330 = D;
var $f1333513336 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg107413325):R.ffi.throwNonFunApp(L[851],_plus26,[("("),anf_arg107413325]);
};
try {
if(--R.GAS > 0) {
$z1332913330 = $f1333513336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1333513336,
"from":L[851]});
}
} catch($e1332713328) {
if(R.isCont($e1332713328)) {
var $ss1333113332 = {"from":L[851],
"go":function(anf_arg107513337) {
return $Hanf_arg323313338(anf_arg107513337,_plus26);
}};
$e1332713328.stack[R.EXN_STACKHEIGHT++] = $ss1333113332;
}
if(R.isPyretException($e1332713328)) {
$e1332713328.pyretStack.push(L[851]);
}
throw $e1332713328;
}
var $ret1333313334 = $Hanf_arg323313338($z1332913330,_plus26);
++R.GAS;
return $ret1333313334;
};
var $Hanf_arg323313338 = function(anf_arg107513337,_plus26) {
var $z1334113342 = D;
var $f1334713348 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-variant-member"),anf_arg107513337):R.ffi.throwNonFunApp(L[851],_plus26,[("a-variant-member"),anf_arg107513337]);
};
try {
if(--R.GAS > 0) {
$z1334113342 = $f1334713348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1334713348,
"from":L[851]});
}
} catch($e1333913340) {
if(R.isCont($e1333913340)) {
var $ss1334313344 = {"from":L[851],
"go":function(ann_DASH_check_DASH_temp106313349) {
return $Hann_DASH_check_DASH_temp323213350(ann_DASH_check_DASH_temp106313349);
}};
$e1333913340.stack[R.EXN_STACKHEIGHT++] = $ss1334313344;
}
if(R.isPyretException($e1333913340)) {
$e1333913340.pyretStack.push(L[851]);
}
throw $e1333913340;
}
var $ret1334513346 = $Hann_DASH_check_DASH_temp323213350($z1334113342);
++R.GAS;
return $ret1334513346;
};
var $Hann_DASH_check_DASH_temp323213350 = function(ann_DASH_check_DASH_temp106313349) {
return ann_DASH_check_DASH_temp106313349;
};
var $Hcont_tail_arg32305373 = function(cont_tail_arg10605371,if_helper10505372) {
if(--R.GAS > 0) {
$z1335113352 = R.isFunction(if_helper10505372)?if_helper10505372.app(cont_tail_arg10605371):R.ffi.throwNonFunApp(L[851],if_helper10505372,[cont_tail_arg10605371]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper10505372)?if_helper10505372.app(cont_tail_arg10605371):R.ffi.throwNonFunApp(L[851],if_helper10505372,[cont_tail_arg10605371]);
},
"from":L[851]});
}
++R.GAS;
return $z1335113352;
};
var $Hcont_tail_arg32315388 = function(cont_tail_arg10555387,if_helper10505372) {
if(--R.GAS > 0) {
$z1335313354 = R.isFunction(if_helper10505372)?if_helper10505372.app(cont_tail_arg10555387):R.ffi.throwNonFunApp(L[851],if_helper10505372,[cont_tail_arg10555387]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper10505372)?if_helper10505372.app(cont_tail_arg10555387):R.ffi.throwNonFunApp(L[851],if_helper10505372,[cont_tail_arg10555387]);
},
"from":L[851]});
}
++R.GAS;
return $z1335313354;
};
var $Hann_DASH_check_DASH_temp32295410 = function(ann_DASH_check_DASH_temp10415409) {
return ann_DASH_check_DASH_temp10415409;
};
var $Hanf_arg32285423 = function(anf_arg10455422,_plus26,raise30) {
var $z1335713358 = D;
var $f1336313364 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg10455422):R.ffi.throwNonFunApp(L[1502],_plus26,[("No visitor field for "),anf_arg10455422]);
};
try {
if(--R.GAS > 0) {
$z1335713358 = $f1336313364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1336313364,
"from":L[1502]});
}
} catch($e1335513356) {
if(R.isCont($e1335513356)) {
var $ss1335913360 = {"from":L[1502],
"go":function(anf_arg104613365) {
return $Hanf_arg322713366(anf_arg104613365,raise30);
}};
$e1335513356.stack[R.EXN_STACKHEIGHT++] = $ss1335913360;
}
if(R.isPyretException($e1335513356)) {
$e1335513356.pyretStack.push(L[1502]);
}
throw $e1335513356;
}
var $ret1336113362 = $Hanf_arg322713366($z1335713358,raise30);
++R.GAS;
return $ret1336113362;
};
var $Hanf_arg322713366 = function(anf_arg104613365,raise30) {
var $z1336913370 = D;
var $f1337513376 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg104613365):R.ffi.throwNonFunApp(L[866],raise30,[anf_arg104613365]);
};
try {
if(--R.GAS > 0) {
$z1336913370 = $f1337513376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1337513376,
"from":L[866]});
}
} catch($e1336713368) {
if(R.isCont($e1336713368)) {
var $ss1337113372 = {"from":L[866],
"go":function(ann_DASH_check_DASH_temp104313377) {
return $Hann_DASH_check_DASH_temp322613378(ann_DASH_check_DASH_temp104313377);
}};
$e1336713368.stack[R.EXN_STACKHEIGHT++] = $ss1337113372;
}
if(R.isPyretException($e1336713368)) {
$e1336713368.pyretStack.push(L[866]);
}
throw $e1336713368;
}
var $ret1337313374 = $Hann_DASH_check_DASH_temp322613378($z1336913370);
++R.GAS;
return $ret1337313374;
};
var $Hann_DASH_check_DASH_temp322613378 = function(ann_DASH_check_DASH_temp104313377) {
return ann_DASH_check_DASH_temp104313377;
};
var $Hann_DASH_check_DASH_temp32255464 = function(ann_DASH_check_DASH_temp10295463) {
return ann_DASH_check_DASH_temp10295463;
};
var $Hcont_tail_arg32235483 = function(cont_tail_arg10225481,if_helper10155482) {
if(--R.GAS > 0) {
$z1337913380 = R.isFunction(if_helper10155482)?if_helper10155482.app(cont_tail_arg10225481):R.ffi.throwNonFunApp(L[870],if_helper10155482,[cont_tail_arg10225481]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper10155482)?if_helper10155482.app(cont_tail_arg10225481):R.ffi.throwNonFunApp(L[870],if_helper10155482,[cont_tail_arg10225481]);
},
"from":L[870]});
}
++R.GAS;
return $z1337913380;
};
var $Hcont_tail_arg32245497 = function(cont_tail_arg10205496,if_helper10155482) {
if(--R.GAS > 0) {
$z1338113382 = R.isFunction(if_helper10155482)?if_helper10155482.app(cont_tail_arg10205496):R.ffi.throwNonFunApp(L[870],if_helper10155482,[cont_tail_arg10205496]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper10155482)?if_helper10155482.app(cont_tail_arg10205496):R.ffi.throwNonFunApp(L[870],if_helper10155482,[cont_tail_arg10205496]);
},
"from":L[870]});
}
++R.GAS;
return $z1338113382;
};
var $Hann_DASH_check_DASH_temp32225518 = function(ann_DASH_check_DASH_temp10115517) {
return ann_DASH_check_DASH_temp10115517;
};
var $Hcont_tail_arg32205537 = function(cont_tail_arg10045535,if_helper9975536) {
if(--R.GAS > 0) {
$z1338313384 = R.isFunction(if_helper9975536)?if_helper9975536.app(cont_tail_arg10045535):R.ffi.throwNonFunApp(L[871],if_helper9975536,[cont_tail_arg10045535]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9975536)?if_helper9975536.app(cont_tail_arg10045535):R.ffi.throwNonFunApp(L[871],if_helper9975536,[cont_tail_arg10045535]);
},
"from":L[871]});
}
++R.GAS;
return $z1338313384;
};
var $Hcont_tail_arg32215551 = function(cont_tail_arg10025550,if_helper9975536) {
if(--R.GAS > 0) {
$z1338513386 = R.isFunction(if_helper9975536)?if_helper9975536.app(cont_tail_arg10025550):R.ffi.throwNonFunApp(L[871],if_helper9975536,[cont_tail_arg10025550]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9975536)?if_helper9975536.app(cont_tail_arg10025550):R.ffi.throwNonFunApp(L[871],if_helper9975536,[cont_tail_arg10025550]);
},
"from":L[871]});
}
++R.GAS;
return $z1338513386;
};
var $Hann_DASH_check_DASH_temp32195572 = function(ann_DASH_check_DASH_temp9935571) {
return ann_DASH_check_DASH_temp9935571;
};
var $Hcont_tail_arg32175591 = function(cont_tail_arg9865589,if_helper9795590) {
if(--R.GAS > 0) {
$z1338713388 = R.isFunction(if_helper9795590)?if_helper9795590.app(cont_tail_arg9865589):R.ffi.throwNonFunApp(L[872],if_helper9795590,[cont_tail_arg9865589]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9795590)?if_helper9795590.app(cont_tail_arg9865589):R.ffi.throwNonFunApp(L[872],if_helper9795590,[cont_tail_arg9865589]);
},
"from":L[872]});
}
++R.GAS;
return $z1338713388;
};
var $Hcont_tail_arg32185605 = function(cont_tail_arg9845604,if_helper9795590) {
if(--R.GAS > 0) {
$z1338913390 = R.isFunction(if_helper9795590)?if_helper9795590.app(cont_tail_arg9845604):R.ffi.throwNonFunApp(L[872],if_helper9795590,[cont_tail_arg9845604]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9795590)?if_helper9795590.app(cont_tail_arg9845604):R.ffi.throwNonFunApp(L[872],if_helper9795590,[cont_tail_arg9845604]);
},
"from":L[872]});
}
++R.GAS;
return $z1338913390;
};
var $Hann_DASH_check_DASH_temp32165653 = function(ann_DASH_check_DASH_temp9685652) {
return ann_DASH_check_DASH_temp9685652;
};
var $Hanf_arg32155670 = function(anf_arg9545668,self1085669,_plus26,torepr31) {
var anf_arg95513401 = G(self1085669,"name",L[883]);
var $z1339313394 = D;
var $f1339913400 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg95513401):R.ffi.throwNonFunApp(L[883],torepr31,[anf_arg95513401]);
};
try {
if(--R.GAS > 0) {
$z1339313394 = $f1339913400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1339913400,
"from":L[883]});
}
} catch($e1339113392) {
if(R.isCont($e1339113392)) {
var $ss1339513396 = {"from":L[883],
"go":function(anf_arg95613402) {
return $Hanf_arg321413403(anf_arg95613402,anf_arg9545668,self1085669,_plus26,torepr31);
}};
$e1339113392.stack[R.EXN_STACKHEIGHT++] = $ss1339513396;
}
if(R.isPyretException($e1339113392)) {
$e1339113392.pyretStack.push(L[883]);
}
throw $e1339113392;
}
var $ret1339713398 = $Hanf_arg321413403($z1339313394,anf_arg9545668,self1085669,_plus26,torepr31);
++R.GAS;
return $ret1339713398;
};
var $Hanf_arg321413403 = function(anf_arg95613402,anf_arg9545668,self1085669,_plus26,torepr31) {
var $z1340613407 = D;
var $f1341213413 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg95613402):R.ffi.throwNonFunApp(L[883],_plus26,[(", "),anf_arg95613402]);
};
try {
if(--R.GAS > 0) {
$z1340613407 = $f1341213413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1341213413,
"from":L[883]});
}
} catch($e1340413405) {
if(R.isCont($e1340413405)) {
var $ss1340813409 = {"from":L[883],
"go":function(anf_arg95713414) {
return $Hanf_arg321313415(anf_arg95713414,anf_arg9545668,self1085669,_plus26,torepr31);
}};
$e1340413405.stack[R.EXN_STACKHEIGHT++] = $ss1340813409;
}
if(R.isPyretException($e1340413405)) {
$e1340413405.pyretStack.push(L[883]);
}
throw $e1340413405;
}
var $ret1341013411 = $Hanf_arg321313415($z1340613407,anf_arg9545668,self1085669,_plus26,torepr31);
++R.GAS;
return $ret1341013411;
};
var $Hanf_arg321313415 = function(anf_arg95713414,anf_arg9545668,self1085669,_plus26,torepr31) {
var $z1341813419 = D;
var $f1342413425 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg9545668,anf_arg95713414):R.ffi.throwNonFunApp(L[883],_plus26,[anf_arg9545668,anf_arg95713414]);
};
try {
if(--R.GAS > 0) {
$z1341813419 = $f1342413425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1342413425,
"from":L[883]});
}
} catch($e1341613417) {
if(R.isCont($e1341613417)) {
var $ss1342013421 = {"from":L[883],
"go":function(anf_arg95813426) {
return $Hanf_arg321213427(anf_arg95813426,self1085669,_plus26,torepr31);
}};
$e1341613417.stack[R.EXN_STACKHEIGHT++] = $ss1342013421;
}
if(R.isPyretException($e1341613417)) {
$e1341613417.pyretStack.push(L[883]);
}
throw $e1341613417;
}
var $ret1342213423 = $Hanf_arg321213427($z1341813419,self1085669,_plus26,torepr31);
++R.GAS;
return $ret1342213423;
};
var $Hanf_arg321213427 = function(anf_arg95813426,self1085669,_plus26,torepr31) {
var anf_arg95913438 = G(self1085669,"with-members",L[883]);
var $z1343013431 = D;
var $f1343613437 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg95913438):R.ffi.throwNonFunApp(L[883],torepr31,[anf_arg95913438]);
};
try {
if(--R.GAS > 0) {
$z1343013431 = $f1343613437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1343613437,
"from":L[883]});
}
} catch($e1342813429) {
if(R.isCont($e1342813429)) {
var $ss1343213433 = {"from":L[883],
"go":function(anf_arg96013439) {
return $Hanf_arg321113440(anf_arg96013439,anf_arg95813426,_plus26);
}};
$e1342813429.stack[R.EXN_STACKHEIGHT++] = $ss1343213433;
}
if(R.isPyretException($e1342813429)) {
$e1342813429.pyretStack.push(L[883]);
}
throw $e1342813429;
}
var $ret1343413435 = $Hanf_arg321113440($z1343013431,anf_arg95813426,_plus26);
++R.GAS;
return $ret1343413435;
};
var $Hanf_arg321113440 = function(anf_arg96013439,anf_arg95813426,_plus26) {
var $z1344313444 = D;
var $f1344913450 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg96013439):R.ffi.throwNonFunApp(L[883],_plus26,[(", "),anf_arg96013439]);
};
try {
if(--R.GAS > 0) {
$z1344313444 = $f1344913450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1344913450,
"from":L[883]});
}
} catch($e1344113442) {
if(R.isCont($e1344113442)) {
var $ss1344513446 = {"from":L[883],
"go":function(anf_arg96113451) {
return $Hanf_arg321013452(anf_arg96113451,anf_arg95813426,_plus26);
}};
$e1344113442.stack[R.EXN_STACKHEIGHT++] = $ss1344513446;
}
if(R.isPyretException($e1344113442)) {
$e1344113442.pyretStack.push(L[883]);
}
throw $e1344113442;
}
var $ret1344713448 = $Hanf_arg321013452($z1344313444,anf_arg95813426,_plus26);
++R.GAS;
return $ret1344713448;
};
var $Hanf_arg321013452 = function(anf_arg96113451,anf_arg95813426,_plus26) {
var $z1345513456 = D;
var $f1346113462 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg95813426,anf_arg96113451):R.ffi.throwNonFunApp(L[883],_plus26,[anf_arg95813426,anf_arg96113451]);
};
try {
if(--R.GAS > 0) {
$z1345513456 = $f1346113462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1346113462,
"from":L[883]});
}
} catch($e1345313454) {
if(R.isCont($e1345313454)) {
var $ss1345713458 = {"from":L[883],
"go":function(anf_arg96213463) {
return $Hanf_arg320913464(anf_arg96213463,_plus26);
}};
$e1345313454.stack[R.EXN_STACKHEIGHT++] = $ss1345713458;
}
if(R.isPyretException($e1345313454)) {
$e1345313454.pyretStack.push(L[883]);
}
throw $e1345313454;
}
var $ret1345913460 = $Hanf_arg320913464($z1345513456,_plus26);
++R.GAS;
return $ret1345913460;
};
var $Hanf_arg320913464 = function(anf_arg96213463,_plus26) {
var $z1346713468 = D;
var $f1347313474 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg96213463,(")")):R.ffi.throwNonFunApp(L[883],_plus26,[anf_arg96213463,(")")]);
};
try {
if(--R.GAS > 0) {
$z1346713468 = $f1347313474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1347313474,
"from":L[883]});
}
} catch($e1346513466) {
if(R.isCont($e1346513466)) {
var $ss1346913470 = {"from":L[883],
"go":function(anf_arg96313475) {
return $Hanf_arg320813476(anf_arg96313475,_plus26);
}};
$e1346513466.stack[R.EXN_STACKHEIGHT++] = $ss1346913470;
}
if(R.isPyretException($e1346513466)) {
$e1346513466.pyretStack.push(L[883]);
}
throw $e1346513466;
}
var $ret1347113472 = $Hanf_arg320813476($z1346713468,_plus26);
++R.GAS;
return $ret1347113472;
};
var $Hanf_arg320813476 = function(anf_arg96313475,_plus26) {
var $z1347913480 = D;
var $f1348513486 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg96313475):R.ffi.throwNonFunApp(L[883],_plus26,[("("),anf_arg96313475]);
};
try {
if(--R.GAS > 0) {
$z1347913480 = $f1348513486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1348513486,
"from":L[883]});
}
} catch($e1347713478) {
if(R.isCont($e1347713478)) {
var $ss1348113482 = {"from":L[883],
"go":function(anf_arg96413487) {
return $Hanf_arg320713488(anf_arg96413487,_plus26);
}};
$e1347713478.stack[R.EXN_STACKHEIGHT++] = $ss1348113482;
}
if(R.isPyretException($e1347713478)) {
$e1347713478.pyretStack.push(L[883]);
}
throw $e1347713478;
}
var $ret1348313484 = $Hanf_arg320713488($z1347913480,_plus26);
++R.GAS;
return $ret1348313484;
};
var $Hanf_arg320713488 = function(anf_arg96413487,_plus26) {
var $z1349113492 = D;
var $f1349713498 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-singleton-variant"),anf_arg96413487):R.ffi.throwNonFunApp(L[883],_plus26,[("a-singleton-variant"),anf_arg96413487]);
};
try {
if(--R.GAS > 0) {
$z1349113492 = $f1349713498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1349713498,
"from":L[883]});
}
} catch($e1348913490) {
if(R.isCont($e1348913490)) {
var $ss1349313494 = {"from":L[883],
"go":function(ann_DASH_check_DASH_temp95213499) {
return $Hann_DASH_check_DASH_temp320613500(ann_DASH_check_DASH_temp95213499);
}};
$e1348913490.stack[R.EXN_STACKHEIGHT++] = $ss1349313494;
}
if(R.isPyretException($e1348913490)) {
$e1348913490.pyretStack.push(L[883]);
}
throw $e1348913490;
}
var $ret1349513496 = $Hann_DASH_check_DASH_temp320613500($z1349113492);
++R.GAS;
return $ret1349513496;
};
var $Hann_DASH_check_DASH_temp320613500 = function(ann_DASH_check_DASH_temp95213499) {
return ann_DASH_check_DASH_temp95213499;
};
var $Hcont_tail_arg32045687 = function(cont_tail_arg9495685,if_helper9395686) {
if(--R.GAS > 0) {
$z1350113502 = R.isFunction(if_helper9395686)?if_helper9395686.app(cont_tail_arg9495685):R.ffi.throwNonFunApp(L[883],if_helper9395686,[cont_tail_arg9495685]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9395686)?if_helper9395686.app(cont_tail_arg9495685):R.ffi.throwNonFunApp(L[883],if_helper9395686,[cont_tail_arg9495685]);
},
"from":L[883]});
}
++R.GAS;
return $z1350113502;
};
var $Hcont_tail_arg32055702 = function(cont_tail_arg9445701,if_helper9395686) {
if(--R.GAS > 0) {
$z1350313504 = R.isFunction(if_helper9395686)?if_helper9395686.app(cont_tail_arg9445701):R.ffi.throwNonFunApp(L[883],if_helper9395686,[cont_tail_arg9445701]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper9395686)?if_helper9395686.app(cont_tail_arg9445701):R.ffi.throwNonFunApp(L[883],if_helper9395686,[cont_tail_arg9445701]);
},
"from":L[883]});
}
++R.GAS;
return $z1350313504;
};
var $Hann_DASH_check_DASH_temp32035722 = function(ann_DASH_check_DASH_temp9355721) {
return ann_DASH_check_DASH_temp9355721;
};
var $Hanf_arg32025739 = function(anf_arg9135737,self1025738,_plus26,torepr31) {
var anf_arg91413515 = G(self1025738,"constr-loc",L[884]);
var $z1350713508 = D;
var $f1351313514 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg91413515):R.ffi.throwNonFunApp(L[884],torepr31,[anf_arg91413515]);
};
try {
if(--R.GAS > 0) {
$z1350713508 = $f1351313514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1351313514,
"from":L[884]});
}
} catch($e1350513506) {
if(R.isCont($e1350513506)) {
var $ss1350913510 = {"from":L[884],
"go":function(anf_arg91513516) {
return $Hanf_arg320113517(anf_arg91513516,anf_arg9135737,self1025738,_plus26,torepr31);
}};
$e1350513506.stack[R.EXN_STACKHEIGHT++] = $ss1350913510;
}
if(R.isPyretException($e1350513506)) {
$e1350513506.pyretStack.push(L[884]);
}
throw $e1350513506;
}
var $ret1351113512 = $Hanf_arg320113517($z1350713508,anf_arg9135737,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1351113512;
};
var $Hanf_arg320113517 = function(anf_arg91513516,anf_arg9135737,self1025738,_plus26,torepr31) {
var $z1352013521 = D;
var $f1352613527 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg91513516):R.ffi.throwNonFunApp(L[884],_plus26,[(", "),anf_arg91513516]);
};
try {
if(--R.GAS > 0) {
$z1352013521 = $f1352613527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1352613527,
"from":L[884]});
}
} catch($e1351813519) {
if(R.isCont($e1351813519)) {
var $ss1352213523 = {"from":L[884],
"go":function(anf_arg91613528) {
return $Hanf_arg320013529(anf_arg91613528,anf_arg9135737,self1025738,_plus26,torepr31);
}};
$e1351813519.stack[R.EXN_STACKHEIGHT++] = $ss1352213523;
}
if(R.isPyretException($e1351813519)) {
$e1351813519.pyretStack.push(L[884]);
}
throw $e1351813519;
}
var $ret1352413525 = $Hanf_arg320013529($z1352013521,anf_arg9135737,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1352413525;
};
var $Hanf_arg320013529 = function(anf_arg91613528,anf_arg9135737,self1025738,_plus26,torepr31) {
var $z1353213533 = D;
var $f1353813539 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg9135737,anf_arg91613528):R.ffi.throwNonFunApp(L[884],_plus26,[anf_arg9135737,anf_arg91613528]);
};
try {
if(--R.GAS > 0) {
$z1353213533 = $f1353813539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1353813539,
"from":L[884]});
}
} catch($e1353013531) {
if(R.isCont($e1353013531)) {
var $ss1353413535 = {"from":L[884],
"go":function(anf_arg91713540) {
return $Hanf_arg319913541(anf_arg91713540,self1025738,_plus26,torepr31);
}};
$e1353013531.stack[R.EXN_STACKHEIGHT++] = $ss1353413535;
}
if(R.isPyretException($e1353013531)) {
$e1353013531.pyretStack.push(L[884]);
}
throw $e1353013531;
}
var $ret1353613537 = $Hanf_arg319913541($z1353213533,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1353613537;
};
var $Hanf_arg319913541 = function(anf_arg91713540,self1025738,_plus26,torepr31) {
var anf_arg91813552 = G(self1025738,"name",L[884]);
var $z1354413545 = D;
var $f1355013551 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg91813552):R.ffi.throwNonFunApp(L[884],torepr31,[anf_arg91813552]);
};
try {
if(--R.GAS > 0) {
$z1354413545 = $f1355013551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1355013551,
"from":L[884]});
}
} catch($e1354213543) {
if(R.isCont($e1354213543)) {
var $ss1354613547 = {"from":L[884],
"go":function(anf_arg91913553) {
return $Hanf_arg319813554(anf_arg91913553,anf_arg91713540,self1025738,_plus26,torepr31);
}};
$e1354213543.stack[R.EXN_STACKHEIGHT++] = $ss1354613547;
}
if(R.isPyretException($e1354213543)) {
$e1354213543.pyretStack.push(L[884]);
}
throw $e1354213543;
}
var $ret1354813549 = $Hanf_arg319813554($z1354413545,anf_arg91713540,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1354813549;
};
var $Hanf_arg319813554 = function(anf_arg91913553,anf_arg91713540,self1025738,_plus26,torepr31) {
var $z1355713558 = D;
var $f1356313564 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg91913553):R.ffi.throwNonFunApp(L[884],_plus26,[(", "),anf_arg91913553]);
};
try {
if(--R.GAS > 0) {
$z1355713558 = $f1356313564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1356313564,
"from":L[884]});
}
} catch($e1355513556) {
if(R.isCont($e1355513556)) {
var $ss1355913560 = {"from":L[884],
"go":function(anf_arg92013565) {
return $Hanf_arg319713566(anf_arg92013565,anf_arg91713540,self1025738,_plus26,torepr31);
}};
$e1355513556.stack[R.EXN_STACKHEIGHT++] = $ss1355913560;
}
if(R.isPyretException($e1355513556)) {
$e1355513556.pyretStack.push(L[884]);
}
throw $e1355513556;
}
var $ret1356113562 = $Hanf_arg319713566($z1355713558,anf_arg91713540,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1356113562;
};
var $Hanf_arg319713566 = function(anf_arg92013565,anf_arg91713540,self1025738,_plus26,torepr31) {
var $z1356913570 = D;
var $f1357513576 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg91713540,anf_arg92013565):R.ffi.throwNonFunApp(L[884],_plus26,[anf_arg91713540,anf_arg92013565]);
};
try {
if(--R.GAS > 0) {
$z1356913570 = $f1357513576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1357513576,
"from":L[884]});
}
} catch($e1356713568) {
if(R.isCont($e1356713568)) {
var $ss1357113572 = {"from":L[884],
"go":function(anf_arg92113577) {
return $Hanf_arg319613578(anf_arg92113577,self1025738,_plus26,torepr31);
}};
$e1356713568.stack[R.EXN_STACKHEIGHT++] = $ss1357113572;
}
if(R.isPyretException($e1356713568)) {
$e1356713568.pyretStack.push(L[884]);
}
throw $e1356713568;
}
var $ret1357313574 = $Hanf_arg319613578($z1356913570,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1357313574;
};
var $Hanf_arg319613578 = function(anf_arg92113577,self1025738,_plus26,torepr31) {
var anf_arg92213589 = G(self1025738,"members",L[884]);
var $z1358113582 = D;
var $f1358713588 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg92213589):R.ffi.throwNonFunApp(L[884],torepr31,[anf_arg92213589]);
};
try {
if(--R.GAS > 0) {
$z1358113582 = $f1358713588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1358713588,
"from":L[884]});
}
} catch($e1357913580) {
if(R.isCont($e1357913580)) {
var $ss1358313584 = {"from":L[884],
"go":function(anf_arg92313590) {
return $Hanf_arg319513591(anf_arg92313590,anf_arg92113577,self1025738,_plus26,torepr31);
}};
$e1357913580.stack[R.EXN_STACKHEIGHT++] = $ss1358313584;
}
if(R.isPyretException($e1357913580)) {
$e1357913580.pyretStack.push(L[884]);
}
throw $e1357913580;
}
var $ret1358513586 = $Hanf_arg319513591($z1358113582,anf_arg92113577,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1358513586;
};
var $Hanf_arg319513591 = function(anf_arg92313590,anf_arg92113577,self1025738,_plus26,torepr31) {
var $z1359413595 = D;
var $f1360013601 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg92313590):R.ffi.throwNonFunApp(L[884],_plus26,[(", "),anf_arg92313590]);
};
try {
if(--R.GAS > 0) {
$z1359413595 = $f1360013601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1360013601,
"from":L[884]});
}
} catch($e1359213593) {
if(R.isCont($e1359213593)) {
var $ss1359613597 = {"from":L[884],
"go":function(anf_arg92413602) {
return $Hanf_arg319413603(anf_arg92413602,anf_arg92113577,self1025738,_plus26,torepr31);
}};
$e1359213593.stack[R.EXN_STACKHEIGHT++] = $ss1359613597;
}
if(R.isPyretException($e1359213593)) {
$e1359213593.pyretStack.push(L[884]);
}
throw $e1359213593;
}
var $ret1359813599 = $Hanf_arg319413603($z1359413595,anf_arg92113577,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1359813599;
};
var $Hanf_arg319413603 = function(anf_arg92413602,anf_arg92113577,self1025738,_plus26,torepr31) {
var $z1360613607 = D;
var $f1361213613 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg92113577,anf_arg92413602):R.ffi.throwNonFunApp(L[884],_plus26,[anf_arg92113577,anf_arg92413602]);
};
try {
if(--R.GAS > 0) {
$z1360613607 = $f1361213613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1361213613,
"from":L[884]});
}
} catch($e1360413605) {
if(R.isCont($e1360413605)) {
var $ss1360813609 = {"from":L[884],
"go":function(anf_arg92513614) {
return $Hanf_arg319313615(anf_arg92513614,self1025738,_plus26,torepr31);
}};
$e1360413605.stack[R.EXN_STACKHEIGHT++] = $ss1360813609;
}
if(R.isPyretException($e1360413605)) {
$e1360413605.pyretStack.push(L[884]);
}
throw $e1360413605;
}
var $ret1361013611 = $Hanf_arg319313615($z1360613607,self1025738,_plus26,torepr31);
++R.GAS;
return $ret1361013611;
};
var $Hanf_arg319313615 = function(anf_arg92513614,self1025738,_plus26,torepr31) {
var anf_arg92613626 = G(self1025738,"with-members",L[884]);
var $z1361813619 = D;
var $f1362413625 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg92613626):R.ffi.throwNonFunApp(L[884],torepr31,[anf_arg92613626]);
};
try {
if(--R.GAS > 0) {
$z1361813619 = $f1362413625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1362413625,
"from":L[884]});
}
} catch($e1361613617) {
if(R.isCont($e1361613617)) {
var $ss1362013621 = {"from":L[884],
"go":function(anf_arg92713627) {
return $Hanf_arg319213628(anf_arg92713627,anf_arg92513614,_plus26);
}};
$e1361613617.stack[R.EXN_STACKHEIGHT++] = $ss1362013621;
}
if(R.isPyretException($e1361613617)) {
$e1361613617.pyretStack.push(L[884]);
}
throw $e1361613617;
}
var $ret1362213623 = $Hanf_arg319213628($z1361813619,anf_arg92513614,_plus26);
++R.GAS;
return $ret1362213623;
};
var $Hanf_arg319213628 = function(anf_arg92713627,anf_arg92513614,_plus26) {
var $z1363113632 = D;
var $f1363713638 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg92713627):R.ffi.throwNonFunApp(L[884],_plus26,[(", "),anf_arg92713627]);
};
try {
if(--R.GAS > 0) {
$z1363113632 = $f1363713638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1363713638,
"from":L[884]});
}
} catch($e1362913630) {
if(R.isCont($e1362913630)) {
var $ss1363313634 = {"from":L[884],
"go":function(anf_arg92813639) {
return $Hanf_arg319113640(anf_arg92813639,anf_arg92513614,_plus26);
}};
$e1362913630.stack[R.EXN_STACKHEIGHT++] = $ss1363313634;
}
if(R.isPyretException($e1362913630)) {
$e1362913630.pyretStack.push(L[884]);
}
throw $e1362913630;
}
var $ret1363513636 = $Hanf_arg319113640($z1363113632,anf_arg92513614,_plus26);
++R.GAS;
return $ret1363513636;
};
var $Hanf_arg319113640 = function(anf_arg92813639,anf_arg92513614,_plus26) {
var $z1364313644 = D;
var $f1364913650 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg92513614,anf_arg92813639):R.ffi.throwNonFunApp(L[884],_plus26,[anf_arg92513614,anf_arg92813639]);
};
try {
if(--R.GAS > 0) {
$z1364313644 = $f1364913650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1364913650,
"from":L[884]});
}
} catch($e1364113642) {
if(R.isCont($e1364113642)) {
var $ss1364513646 = {"from":L[884],
"go":function(anf_arg92913651) {
return $Hanf_arg319013652(anf_arg92913651,_plus26);
}};
$e1364113642.stack[R.EXN_STACKHEIGHT++] = $ss1364513646;
}
if(R.isPyretException($e1364113642)) {
$e1364113642.pyretStack.push(L[884]);
}
throw $e1364113642;
}
var $ret1364713648 = $Hanf_arg319013652($z1364313644,_plus26);
++R.GAS;
return $ret1364713648;
};
var $Hanf_arg319013652 = function(anf_arg92913651,_plus26) {
var $z1365513656 = D;
var $f1366113662 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg92913651,(")")):R.ffi.throwNonFunApp(L[884],_plus26,[anf_arg92913651,(")")]);
};
try {
if(--R.GAS > 0) {
$z1365513656 = $f1366113662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1366113662,
"from":L[884]});
}
} catch($e1365313654) {
if(R.isCont($e1365313654)) {
var $ss1365713658 = {"from":L[884],
"go":function(anf_arg93013663) {
return $Hanf_arg318913664(anf_arg93013663,_plus26);
}};
$e1365313654.stack[R.EXN_STACKHEIGHT++] = $ss1365713658;
}
if(R.isPyretException($e1365313654)) {
$e1365313654.pyretStack.push(L[884]);
}
throw $e1365313654;
}
var $ret1365913660 = $Hanf_arg318913664($z1365513656,_plus26);
++R.GAS;
return $ret1365913660;
};
var $Hanf_arg318913664 = function(anf_arg93013663,_plus26) {
var $z1366713668 = D;
var $f1367313674 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg93013663):R.ffi.throwNonFunApp(L[884],_plus26,[("("),anf_arg93013663]);
};
try {
if(--R.GAS > 0) {
$z1366713668 = $f1367313674();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1367313674,
"from":L[884]});
}
} catch($e1366513666) {
if(R.isCont($e1366513666)) {
var $ss1366913670 = {"from":L[884],
"go":function(anf_arg93113675) {
return $Hanf_arg318813676(anf_arg93113675,_plus26);
}};
$e1366513666.stack[R.EXN_STACKHEIGHT++] = $ss1366913670;
}
if(R.isPyretException($e1366513666)) {
$e1366513666.pyretStack.push(L[884]);
}
throw $e1366513666;
}
var $ret1367113672 = $Hanf_arg318813676($z1366713668,_plus26);
++R.GAS;
return $ret1367113672;
};
var $Hanf_arg318813676 = function(anf_arg93113675,_plus26) {
var $z1367913680 = D;
var $f1368513686 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-variant"),anf_arg93113675):R.ffi.throwNonFunApp(L[884],_plus26,[("a-variant"),anf_arg93113675]);
};
try {
if(--R.GAS > 0) {
$z1367913680 = $f1368513686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1368513686,
"from":L[884]});
}
} catch($e1367713678) {
if(R.isCont($e1367713678)) {
var $ss1368113682 = {"from":L[884],
"go":function(ann_DASH_check_DASH_temp91113687) {
return $Hann_DASH_check_DASH_temp318713688(ann_DASH_check_DASH_temp91113687);
}};
$e1367713678.stack[R.EXN_STACKHEIGHT++] = $ss1368113682;
}
if(R.isPyretException($e1367713678)) {
$e1367713678.pyretStack.push(L[884]);
}
throw $e1367713678;
}
var $ret1368313684 = $Hann_DASH_check_DASH_temp318713688($z1367913680);
++R.GAS;
return $ret1368313684;
};
var $Hann_DASH_check_DASH_temp318713688 = function(ann_DASH_check_DASH_temp91113687) {
return ann_DASH_check_DASH_temp91113687;
};
var $Hcont_tail_arg31855758 = function(cont_tail_arg9085756,if_helper8965757) {
if(--R.GAS > 0) {
$z1368913690 = R.isFunction(if_helper8965757)?if_helper8965757.app(cont_tail_arg9085756):R.ffi.throwNonFunApp(L[884],if_helper8965757,[cont_tail_arg9085756]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper8965757)?if_helper8965757.app(cont_tail_arg9085756):R.ffi.throwNonFunApp(L[884],if_helper8965757,[cont_tail_arg9085756]);
},
"from":L[884]});
}
++R.GAS;
return $z1368913690;
};
var $Hcont_tail_arg31865773 = function(cont_tail_arg9015772,if_helper8965757) {
if(--R.GAS > 0) {
$z1369113692 = R.isFunction(if_helper8965757)?if_helper8965757.app(cont_tail_arg9015772):R.ffi.throwNonFunApp(L[884],if_helper8965757,[cont_tail_arg9015772]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper8965757)?if_helper8965757.app(cont_tail_arg9015772):R.ffi.throwNonFunApp(L[884],if_helper8965757,[cont_tail_arg9015772]);
},
"from":L[884]});
}
++R.GAS;
return $z1369113692;
};
var $Hann_DASH_check_DASH_temp31845795 = function(ann_DASH_check_DASH_temp8875794) {
return ann_DASH_check_DASH_temp8875794;
};
var $Hanf_arg31835808 = function(anf_arg8915807,_plus26,raise30) {
var $z1369513696 = D;
var $f1370113702 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg8915807):R.ffi.throwNonFunApp(L[1503],_plus26,[("No visitor field for "),anf_arg8915807]);
};
try {
if(--R.GAS > 0) {
$z1369513696 = $f1370113702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1370113702,
"from":L[1503]});
}
} catch($e1369313694) {
if(R.isCont($e1369313694)) {
var $ss1369713698 = {"from":L[1503],
"go":function(anf_arg89213703) {
return $Hanf_arg318213704(anf_arg89213703,raise30);
}};
$e1369313694.stack[R.EXN_STACKHEIGHT++] = $ss1369713698;
}
if(R.isPyretException($e1369313694)) {
$e1369313694.pyretStack.push(L[1503]);
}
throw $e1369313694;
}
var $ret1369913700 = $Hanf_arg318213704($z1369513696,raise30);
++R.GAS;
return $ret1369913700;
};
var $Hanf_arg318213704 = function(anf_arg89213703,raise30) {
var $z1370713708 = D;
var $f1371313714 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg89213703):R.ffi.throwNonFunApp(L[911],raise30,[anf_arg89213703]);
};
try {
if(--R.GAS > 0) {
$z1370713708 = $f1371313714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1371313714,
"from":L[911]});
}
} catch($e1370513706) {
if(R.isCont($e1370513706)) {
var $ss1370913710 = {"from":L[911],
"go":function(ann_DASH_check_DASH_temp88913715) {
return $Hann_DASH_check_DASH_temp318113716(ann_DASH_check_DASH_temp88913715);
}};
$e1370513706.stack[R.EXN_STACKHEIGHT++] = $ss1370913710;
}
if(R.isPyretException($e1370513706)) {
$e1370513706.pyretStack.push(L[911]);
}
throw $e1370513706;
}
var $ret1371113712 = $Hann_DASH_check_DASH_temp318113716($z1370713708);
++R.GAS;
return $ret1371113712;
};
var $Hann_DASH_check_DASH_temp318113716 = function(ann_DASH_check_DASH_temp88913715) {
return ann_DASH_check_DASH_temp88913715;
};
var $Hif_DASH_31805837 = function(if_DASH_975835,INDENT9187,PP337,self3465836,str_DASH_coloncolon99183) {
var if_helper86313729 = R.makeFunction(function(if_helper_arg86413751) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[921],1,arguments);
}
var ann_DASH_check_DASH_temp86013752 = if_helper_arg86413751;
return ann_DASH_check_DASH_temp86013752;
});
var anf_if86713750 = R.isBoolean(if_DASH_975835);
if(R.isPyretTrue(anf_if86713750)) {
if(R.isPyretTrue(if_DASH_975835)) {
var anf_bracket87713731 = G(self3465836,"id",L[1506]);
var anf_fun87813727 = G(anf_bracket87713731,"tosource",L[1505]);
var $z1371913720 = D;
var $f1372513726 = function(_) {
return R.isFunction(anf_fun87813727)?anf_fun87813727.app():R.ffi.throwNonFunApp(L[1504],anf_fun87813727,[]);
};
try {
if(--R.GAS > 0) {
$z1371913720 = $f1372513726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1372513726,
"from":L[1504]});
}
} catch($e1371713718) {
if(R.isCont($e1371713718)) {
var $ss1372113722 = {"from":L[1504],
"go":function(cont_tail_arg87913728) {
return $Hcont_tail_arg317613730(cont_tail_arg87913728,if_helper86313729);
}};
$e1371713718.stack[R.EXN_STACKHEIGHT++] = $ss1372113722;
}
if(R.isPyretException($e1371713718)) {
$e1371713718.pyretStack.push(L[1504]);
}
throw $e1371713718;
}
var $ret1372313724 = $Hcont_tail_arg317613730($z1371913720,if_helper86313729);
++R.GAS;
return $ret1372313724;
} else {
var anf_fun86813744 = G(PP337,"infix",L[1510]);
var anf_bracket86913746 = G(self3465836,"id",L[1509]);
var anf_fun87013742 = G(anf_bracket86913746,"tosource",L[1508]);
var $z1373413735 = D;
var $f1374013741 = function(_) {
return R.isFunction(anf_fun87013742)?anf_fun87013742.app():R.ffi.throwNonFunApp(L[1507],anf_fun87013742,[]);
};
try {
if(--R.GAS > 0) {
$z1373413735 = $f1374013741();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1374013741,
"from":L[1507]});
}
} catch($e1373213733) {
if(R.isCont($e1373213733)) {
var $ss1373613737 = {"from":L[1507],
"go":function(anf_arg87113743) {
return $Hanf_arg317913745(anf_arg87113743,INDENT9187,anf_fun86813744,if_helper86313729,self3465836,str_DASH_coloncolon99183);
}};
$e1373213733.stack[R.EXN_STACKHEIGHT++] = $ss1373613737;
}
if(R.isPyretException($e1373213733)) {
$e1373213733.pyretStack.push(L[1507]);
}
throw $e1373213733;
}
var $ret1373813739 = $Hanf_arg317913745($z1373413735,INDENT9187,anf_fun86813744,if_helper86313729,self3465836,str_DASH_coloncolon99183);
++R.GAS;
return $ret1373813739;
}
} else {
var cont_tail_arg86513749 = R.throwNonBooleanCondition(L[921],("if"),if_DASH_975835);
if(--R.GAS > 0) {
$z1374713748 = R.isFunction(if_helper86313729)?if_helper86313729.app(cont_tail_arg86513749):R.ffi.throwNonFunApp(L[921],if_helper86313729,[cont_tail_arg86513749]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper86313729)?if_helper86313729.app(cont_tail_arg86513749):R.ffi.throwNonFunApp(L[921],if_helper86313729,[cont_tail_arg86513749]);
},
"from":L[921]});
}
++R.GAS;
return $z1374713748;
}
};
var $Hcont_tail_arg317613730 = function(cont_tail_arg87913728,if_helper86313729) {
if(--R.GAS > 0) {
$z1375313754 = R.isFunction(if_helper86313729)?if_helper86313729.app(cont_tail_arg87913728):R.ffi.throwNonFunApp(L[1504],if_helper86313729,[cont_tail_arg87913728]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper86313729)?if_helper86313729.app(cont_tail_arg87913728):R.ffi.throwNonFunApp(L[1504],if_helper86313729,[cont_tail_arg87913728]);
},
"from":L[1504]});
}
++R.GAS;
return $z1375313754;
};
var $Hanf_arg317913745 = function(anf_arg87113743,INDENT9187,anf_fun86813744,if_helper86313729,self3465836,str_DASH_coloncolon99183) {
var anf_bracket87213768 = G(self3465836,"ann",L[1513]);
var anf_fun87313765 = G(anf_bracket87213768,"tosource",L[1512]);
var $z1375713758 = D;
var $f1376313764 = function(_) {
return R.isFunction(anf_fun87313765)?anf_fun87313765.app():R.ffi.throwNonFunApp(L[1511],anf_fun87313765,[]);
};
try {
if(--R.GAS > 0) {
$z1375713758 = $f1376313764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1376313764,
"from":L[1511]});
}
} catch($e1375513756) {
if(R.isCont($e1375513756)) {
var $ss1375913760 = {"from":L[1511],
"go":function(anf_arg87413766) {
return $Hanf_arg317813767(anf_arg87413766,INDENT9187,anf_arg87113743,anf_fun86813744,if_helper86313729,str_DASH_coloncolon99183);
}};
$e1375513756.stack[R.EXN_STACKHEIGHT++] = $ss1375913760;
}
if(R.isPyretException($e1375513756)) {
$e1375513756.pyretStack.push(L[1511]);
}
throw $e1375513756;
}
var $ret1376113762 = $Hanf_arg317813767($z1375713758,INDENT9187,anf_arg87113743,anf_fun86813744,if_helper86313729,str_DASH_coloncolon99183);
++R.GAS;
return $ret1376113762;
};
var $Hanf_arg317813767 = function(anf_arg87413766,INDENT9187,anf_arg87113743,anf_fun86813744,if_helper86313729,str_DASH_coloncolon99183) {
var $z1377113772 = D;
var $f1377713778 = function(_) {
return R.isFunction(anf_fun86813744)?anf_fun86813744.app(INDENT9187,(1),str_DASH_coloncolon99183,anf_arg87113743,anf_arg87413766):R.ffi.throwNonFunApp(L[1514],anf_fun86813744,[INDENT9187,(1),str_DASH_coloncolon99183,anf_arg87113743,anf_arg87413766]);
};
try {
if(--R.GAS > 0) {
$z1377113772 = $f1377713778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1377713778,
"from":L[1514]});
}
} catch($e1376913770) {
if(R.isCont($e1376913770)) {
var $ss1377313774 = {"from":L[1514],
"go":function(cont_tail_arg87513779) {
return $Hcont_tail_arg317713780(cont_tail_arg87513779,if_helper86313729);
}};
$e1376913770.stack[R.EXN_STACKHEIGHT++] = $ss1377313774;
}
if(R.isPyretException($e1376913770)) {
$e1376913770.pyretStack.push(L[1514]);
}
throw $e1376913770;
}
var $ret1377513776 = $Hcont_tail_arg317713780($z1377113772,if_helper86313729);
++R.GAS;
return $ret1377513776;
};
var $Hcont_tail_arg317713780 = function(cont_tail_arg87513779,if_helper86313729) {
if(--R.GAS > 0) {
$z1378113782 = R.isFunction(if_helper86313729)?if_helper86313729.app(cont_tail_arg87513779):R.ffi.throwNonFunApp(L[1514],if_helper86313729,[cont_tail_arg87513779]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper86313729)?if_helper86313729.app(cont_tail_arg87513779):R.ffi.throwNonFunApp(L[1514],if_helper86313729,[cont_tail_arg87513779]);
},
"from":L[1514]});
}
++R.GAS;
return $z1378113782;
};
var $Hanf_arg31755853 = function(anf_arg8465851,self955852,_plus26,torepr31) {
var anf_arg84713793 = G(self955852,"id",L[915]);
var $z1378513786 = D;
var $f1379113792 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg84713793):R.ffi.throwNonFunApp(L[915],torepr31,[anf_arg84713793]);
};
try {
if(--R.GAS > 0) {
$z1378513786 = $f1379113792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1379113792,
"from":L[915]});
}
} catch($e1378313784) {
if(R.isCont($e1378313784)) {
var $ss1378713788 = {"from":L[915],
"go":function(anf_arg84813794) {
return $Hanf_arg317413795(anf_arg84813794,anf_arg8465851,self955852,_plus26,torepr31);
}};
$e1378313784.stack[R.EXN_STACKHEIGHT++] = $ss1378713788;
}
if(R.isPyretException($e1378313784)) {
$e1378313784.pyretStack.push(L[915]);
}
throw $e1378313784;
}
var $ret1378913790 = $Hanf_arg317413795($z1378513786,anf_arg8465851,self955852,_plus26,torepr31);
++R.GAS;
return $ret1378913790;
};
var $Hanf_arg317413795 = function(anf_arg84813794,anf_arg8465851,self955852,_plus26,torepr31) {
var $z1379813799 = D;
var $f1380413805 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg84813794):R.ffi.throwNonFunApp(L[915],_plus26,[(", "),anf_arg84813794]);
};
try {
if(--R.GAS > 0) {
$z1379813799 = $f1380413805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1380413805,
"from":L[915]});
}
} catch($e1379613797) {
if(R.isCont($e1379613797)) {
var $ss1380013801 = {"from":L[915],
"go":function(anf_arg84913806) {
return $Hanf_arg317313807(anf_arg84913806,anf_arg8465851,self955852,_plus26,torepr31);
}};
$e1379613797.stack[R.EXN_STACKHEIGHT++] = $ss1380013801;
}
if(R.isPyretException($e1379613797)) {
$e1379613797.pyretStack.push(L[915]);
}
throw $e1379613797;
}
var $ret1380213803 = $Hanf_arg317313807($z1379813799,anf_arg8465851,self955852,_plus26,torepr31);
++R.GAS;
return $ret1380213803;
};
var $Hanf_arg317313807 = function(anf_arg84913806,anf_arg8465851,self955852,_plus26,torepr31) {
var $z1381013811 = D;
var $f1381613817 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg8465851,anf_arg84913806):R.ffi.throwNonFunApp(L[915],_plus26,[anf_arg8465851,anf_arg84913806]);
};
try {
if(--R.GAS > 0) {
$z1381013811 = $f1381613817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1381613817,
"from":L[915]});
}
} catch($e1380813809) {
if(R.isCont($e1380813809)) {
var $ss1381213813 = {"from":L[915],
"go":function(anf_arg85013818) {
return $Hanf_arg317213819(anf_arg85013818,self955852,_plus26,torepr31);
}};
$e1380813809.stack[R.EXN_STACKHEIGHT++] = $ss1381213813;
}
if(R.isPyretException($e1380813809)) {
$e1380813809.pyretStack.push(L[915]);
}
throw $e1380813809;
}
var $ret1381413815 = $Hanf_arg317213819($z1381013811,self955852,_plus26,torepr31);
++R.GAS;
return $ret1381413815;
};
var $Hanf_arg317213819 = function(anf_arg85013818,self955852,_plus26,torepr31) {
var anf_arg85113830 = G(self955852,"ann",L[915]);
var $z1382213823 = D;
var $f1382813829 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg85113830):R.ffi.throwNonFunApp(L[915],torepr31,[anf_arg85113830]);
};
try {
if(--R.GAS > 0) {
$z1382213823 = $f1382813829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1382813829,
"from":L[915]});
}
} catch($e1382013821) {
if(R.isCont($e1382013821)) {
var $ss1382413825 = {"from":L[915],
"go":function(anf_arg85213831) {
return $Hanf_arg317113832(anf_arg85213831,anf_arg85013818,_plus26);
}};
$e1382013821.stack[R.EXN_STACKHEIGHT++] = $ss1382413825;
}
if(R.isPyretException($e1382013821)) {
$e1382013821.pyretStack.push(L[915]);
}
throw $e1382013821;
}
var $ret1382613827 = $Hanf_arg317113832($z1382213823,anf_arg85013818,_plus26);
++R.GAS;
return $ret1382613827;
};
var $Hanf_arg317113832 = function(anf_arg85213831,anf_arg85013818,_plus26) {
var $z1383513836 = D;
var $f1384113842 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg85213831):R.ffi.throwNonFunApp(L[915],_plus26,[(", "),anf_arg85213831]);
};
try {
if(--R.GAS > 0) {
$z1383513836 = $f1384113842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1384113842,
"from":L[915]});
}
} catch($e1383313834) {
if(R.isCont($e1383313834)) {
var $ss1383713838 = {"from":L[915],
"go":function(anf_arg85313843) {
return $Hanf_arg317013844(anf_arg85313843,anf_arg85013818,_plus26);
}};
$e1383313834.stack[R.EXN_STACKHEIGHT++] = $ss1383713838;
}
if(R.isPyretException($e1383313834)) {
$e1383313834.pyretStack.push(L[915]);
}
throw $e1383313834;
}
var $ret1383913840 = $Hanf_arg317013844($z1383513836,anf_arg85013818,_plus26);
++R.GAS;
return $ret1383913840;
};
var $Hanf_arg317013844 = function(anf_arg85313843,anf_arg85013818,_plus26) {
var $z1384713848 = D;
var $f1385313854 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg85013818,anf_arg85313843):R.ffi.throwNonFunApp(L[915],_plus26,[anf_arg85013818,anf_arg85313843]);
};
try {
if(--R.GAS > 0) {
$z1384713848 = $f1385313854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1385313854,
"from":L[915]});
}
} catch($e1384513846) {
if(R.isCont($e1384513846)) {
var $ss1384913850 = {"from":L[915],
"go":function(anf_arg85413855) {
return $Hanf_arg316913856(anf_arg85413855,_plus26);
}};
$e1384513846.stack[R.EXN_STACKHEIGHT++] = $ss1384913850;
}
if(R.isPyretException($e1384513846)) {
$e1384513846.pyretStack.push(L[915]);
}
throw $e1384513846;
}
var $ret1385113852 = $Hanf_arg316913856($z1384713848,_plus26);
++R.GAS;
return $ret1385113852;
};
var $Hanf_arg316913856 = function(anf_arg85413855,_plus26) {
var $z1385913860 = D;
var $f1386513866 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg85413855,(")")):R.ffi.throwNonFunApp(L[915],_plus26,[anf_arg85413855,(")")]);
};
try {
if(--R.GAS > 0) {
$z1385913860 = $f1386513866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1386513866,
"from":L[915]});
}
} catch($e1385713858) {
if(R.isCont($e1385713858)) {
var $ss1386113862 = {"from":L[915],
"go":function(anf_arg85513867) {
return $Hanf_arg316813868(anf_arg85513867,_plus26);
}};
$e1385713858.stack[R.EXN_STACKHEIGHT++] = $ss1386113862;
}
if(R.isPyretException($e1385713858)) {
$e1385713858.pyretStack.push(L[915]);
}
throw $e1385713858;
}
var $ret1386313864 = $Hanf_arg316813868($z1385913860,_plus26);
++R.GAS;
return $ret1386313864;
};
var $Hanf_arg316813868 = function(anf_arg85513867,_plus26) {
var $z1387113872 = D;
var $f1387713878 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg85513867):R.ffi.throwNonFunApp(L[915],_plus26,[("("),anf_arg85513867]);
};
try {
if(--R.GAS > 0) {
$z1387113872 = $f1387713878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1387713878,
"from":L[915]});
}
} catch($e1386913870) {
if(R.isCont($e1386913870)) {
var $ss1387313874 = {"from":L[915],
"go":function(anf_arg85613879) {
return $Hanf_arg316713880(anf_arg85613879,_plus26);
}};
$e1386913870.stack[R.EXN_STACKHEIGHT++] = $ss1387313874;
}
if(R.isPyretException($e1386913870)) {
$e1386913870.pyretStack.push(L[915]);
}
throw $e1386913870;
}
var $ret1387513876 = $Hanf_arg316713880($z1387113872,_plus26);
++R.GAS;
return $ret1387513876;
};
var $Hanf_arg316713880 = function(anf_arg85613879,_plus26) {
var $z1388313884 = D;
var $f1388913890 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-bind"),anf_arg85613879):R.ffi.throwNonFunApp(L[915],_plus26,[("a-bind"),anf_arg85613879]);
};
try {
if(--R.GAS > 0) {
$z1388313884 = $f1388913890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1388913890,
"from":L[915]});
}
} catch($e1388113882) {
if(R.isCont($e1388113882)) {
var $ss1388513886 = {"from":L[915],
"go":function(ann_DASH_check_DASH_temp84413891) {
return $Hann_DASH_check_DASH_temp316613892(ann_DASH_check_DASH_temp84413891);
}};
$e1388113882.stack[R.EXN_STACKHEIGHT++] = $ss1388513886;
}
if(R.isPyretException($e1388113882)) {
$e1388113882.pyretStack.push(L[915]);
}
throw $e1388113882;
}
var $ret1388713888 = $Hann_DASH_check_DASH_temp316613892($z1388313884);
++R.GAS;
return $ret1388713888;
};
var $Hann_DASH_check_DASH_temp316613892 = function(ann_DASH_check_DASH_temp84413891) {
return ann_DASH_check_DASH_temp84413891;
};
var $Hcont_tail_arg31645870 = function(cont_tail_arg8415868,if_helper8315869) {
if(--R.GAS > 0) {
$z1389313894 = R.isFunction(if_helper8315869)?if_helper8315869.app(cont_tail_arg8415868):R.ffi.throwNonFunApp(L[915],if_helper8315869,[cont_tail_arg8415868]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper8315869)?if_helper8315869.app(cont_tail_arg8415868):R.ffi.throwNonFunApp(L[915],if_helper8315869,[cont_tail_arg8415868]);
},
"from":L[915]});
}
++R.GAS;
return $z1389313894;
};
var $Hcont_tail_arg31655885 = function(cont_tail_arg8365884,if_helper8315869) {
if(--R.GAS > 0) {
$z1389513896 = R.isFunction(if_helper8315869)?if_helper8315869.app(cont_tail_arg8365884):R.ffi.throwNonFunApp(L[915],if_helper8315869,[cont_tail_arg8365884]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper8315869)?if_helper8315869.app(cont_tail_arg8365884):R.ffi.throwNonFunApp(L[915],if_helper8315869,[cont_tail_arg8365884]);
},
"from":L[915]});
}
++R.GAS;
return $z1389513896;
};
var $Hann_DASH_check_DASH_temp31635907 = function(ann_DASH_check_DASH_temp8225906) {
return ann_DASH_check_DASH_temp8225906;
};
var $Hanf_arg31625920 = function(anf_arg8265919,_plus26,raise30) {
var $z1389913900 = D;
var $f1390513906 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg8265919):R.ffi.throwNonFunApp(L[1515],_plus26,[("No visitor field for "),anf_arg8265919]);
};
try {
if(--R.GAS > 0) {
$z1389913900 = $f1390513906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1390513906,
"from":L[1515]});
}
} catch($e1389713898) {
if(R.isCont($e1389713898)) {
var $ss1390113902 = {"from":L[1515],
"go":function(anf_arg82713907) {
return $Hanf_arg316113908(anf_arg82713907,raise30);
}};
$e1389713898.stack[R.EXN_STACKHEIGHT++] = $ss1390113902;
}
if(R.isPyretException($e1389713898)) {
$e1389713898.pyretStack.push(L[1515]);
}
throw $e1389713898;
}
var $ret1390313904 = $Hanf_arg316113908($z1389913900,raise30);
++R.GAS;
return $ret1390313904;
};
var $Hanf_arg316113908 = function(anf_arg82713907,raise30) {
var $z1391113912 = D;
var $f1391713918 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg82713907):R.ffi.throwNonFunApp(L[930],raise30,[anf_arg82713907]);
};
try {
if(--R.GAS > 0) {
$z1391113912 = $f1391713918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1391713918,
"from":L[930]});
}
} catch($e1390913910) {
if(R.isCont($e1390913910)) {
var $ss1391313914 = {"from":L[930],
"go":function(ann_DASH_check_DASH_temp82413919) {
return $Hann_DASH_check_DASH_temp316013920(ann_DASH_check_DASH_temp82413919);
}};
$e1390913910.stack[R.EXN_STACKHEIGHT++] = $ss1391313914;
}
if(R.isPyretException($e1390913910)) {
$e1390913910.pyretStack.push(L[930]);
}
throw $e1390913910;
}
var $ret1391513916 = $Hann_DASH_check_DASH_temp316013920($z1391113912);
++R.GAS;
return $ret1391513916;
};
var $Hann_DASH_check_DASH_temp316013920 = function(ann_DASH_check_DASH_temp82413919) {
return ann_DASH_check_DASH_temp82413919;
};
var $Hann_DASH_check_DASH_temp31596035 = function(ann_DASH_check_DASH_temp7996034) {
return ann_DASH_check_DASH_temp7996034;
};
var $Hanf_arg31586052 = function(anf_arg7936051,_plus26) {
var $z1392313924 = D;
var $f1392913930 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg7936051,(")")):R.ffi.throwNonFunApp(L[934],_plus26,[anf_arg7936051,(")")]);
};
try {
if(--R.GAS > 0) {
$z1392313924 = $f1392913930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1392913930,
"from":L[934]});
}
} catch($e1392113922) {
if(R.isCont($e1392113922)) {
var $ss1392513926 = {"from":L[934],
"go":function(anf_arg79413931) {
return $Hanf_arg315713932(anf_arg79413931,_plus26);
}};
$e1392113922.stack[R.EXN_STACKHEIGHT++] = $ss1392513926;
}
if(R.isPyretException($e1392113922)) {
$e1392113922.pyretStack.push(L[934]);
}
throw $e1392113922;
}
var $ret1392713928 = $Hanf_arg315713932($z1392313924,_plus26);
++R.GAS;
return $ret1392713928;
};
var $Hanf_arg315713932 = function(anf_arg79413931,_plus26) {
var $z1393513936 = D;
var $f1394113942 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg79413931):R.ffi.throwNonFunApp(L[934],_plus26,[("("),anf_arg79413931]);
};
try {
if(--R.GAS > 0) {
$z1393513936 = $f1394113942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1394113942,
"from":L[934]});
}
} catch($e1393313934) {
if(R.isCont($e1393313934)) {
var $ss1393713938 = {"from":L[934],
"go":function(anf_arg79513943) {
return $Hanf_arg315613944(anf_arg79513943,_plus26);
}};
$e1393313934.stack[R.EXN_STACKHEIGHT++] = $ss1393713938;
}
if(R.isPyretException($e1393313934)) {
$e1393313934.pyretStack.push(L[934]);
}
throw $e1393313934;
}
var $ret1393913940 = $Hanf_arg315613944($z1393513936,_plus26);
++R.GAS;
return $ret1393913940;
};
var $Hanf_arg315613944 = function(anf_arg79513943,_plus26) {
var $z1394713948 = D;
var $f1395313954 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-lettable"),anf_arg79513943):R.ffi.throwNonFunApp(L[934],_plus26,[("a-lettable"),anf_arg79513943]);
};
try {
if(--R.GAS > 0) {
$z1394713948 = $f1395313954();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1395313954,
"from":L[934]});
}
} catch($e1394513946) {
if(R.isCont($e1394513946)) {
var $ss1394913950 = {"from":L[934],
"go":function(ann_DASH_check_DASH_temp79113955) {
return $Hann_DASH_check_DASH_temp315513956(ann_DASH_check_DASH_temp79113955);
}};
$e1394513946.stack[R.EXN_STACKHEIGHT++] = $ss1394913950;
}
if(R.isPyretException($e1394513946)) {
$e1394513946.pyretStack.push(L[934]);
}
throw $e1394513946;
}
var $ret1395113952 = $Hann_DASH_check_DASH_temp315513956($z1394713948);
++R.GAS;
return $ret1395113952;
};
var $Hann_DASH_check_DASH_temp315513956 = function(ann_DASH_check_DASH_temp79113955) {
return ann_DASH_check_DASH_temp79113955;
};
var $Hcont_tail_arg31536068 = function(cont_tail_arg7886066,if_helper7806067) {
if(--R.GAS > 0) {
$z1395713958 = R.isFunction(if_helper7806067)?if_helper7806067.app(cont_tail_arg7886066):R.ffi.throwNonFunApp(L[934],if_helper7806067,[cont_tail_arg7886066]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper7806067)?if_helper7806067.app(cont_tail_arg7886066):R.ffi.throwNonFunApp(L[934],if_helper7806067,[cont_tail_arg7886066]);
},
"from":L[934]});
}
++R.GAS;
return $z1395713958;
};
var $Hcont_tail_arg31546083 = function(cont_tail_arg7856082,if_helper7806067) {
if(--R.GAS > 0) {
$z1395913960 = R.isFunction(if_helper7806067)?if_helper7806067.app(cont_tail_arg7856082):R.ffi.throwNonFunApp(L[934],if_helper7806067,[cont_tail_arg7856082]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper7806067)?if_helper7806067.app(cont_tail_arg7856082):R.ffi.throwNonFunApp(L[934],if_helper7806067,[cont_tail_arg7856082]);
},
"from":L[934]});
}
++R.GAS;
return $z1395913960;
};
var $Hanf_arg31526105 = function(anf_arg7536101,INDENT9187,PP337,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_colon98170,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26) {
var anf_bracket75413974 = G(self3366104,"c",L[1518]);
var anf_fun75513971 = G(anf_bracket75413974,"tosource",L[1517]);
var $z1396313964 = D;
var $f1396913970 = function(_) {
return R.isFunction(anf_fun75513971)?anf_fun75513971.app():R.ffi.throwNonFunApp(L[1516],anf_fun75513971,[]);
};
try {
if(--R.GAS > 0) {
$z1396313964 = $f1396913970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1396913970,
"from":L[1516]});
}
} catch($e1396113962) {
if(R.isCont($e1396113962)) {
var $ss1396513966 = {"from":L[1516],
"go":function(anf_arg75613972) {
return $Hanf_arg315113973(anf_arg75613972,INDENT9187,PP337,anf_arg7536101,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_colon98170,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26);
}};
$e1396113962.stack[R.EXN_STACKHEIGHT++] = $ss1396513966;
}
if(R.isPyretException($e1396113962)) {
$e1396113962.pyretStack.push(L[1516]);
}
throw $e1396113962;
}
var $ret1396713968 = $Hanf_arg315113973($z1396313964,INDENT9187,PP337,anf_arg7536101,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_colon98170,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26);
++R.GAS;
return $ret1396713968;
};
var $Hanf_arg315113973 = function(anf_arg75613972,INDENT9187,PP337,anf_arg7536101,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_colon98170,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26) {
var $z1397713978 = D;
var $f1398313984 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg75613972,str_DASH_colon98170):R.ffi.throwNonFunApp(L[1519],_plus26,[anf_arg75613972,str_DASH_colon98170]);
};
try {
if(--R.GAS > 0) {
$z1397713978 = $f1398313984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1398313984,
"from":L[1519]});
}
} catch($e1397513976) {
if(R.isCont($e1397513976)) {
var $ss1397913980 = {"from":L[1519],
"go":function(anf_arg75713985) {
return $Hanf_arg315013986(anf_arg75713985,INDENT9187,PP337,anf_arg7536101,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26);
}};
$e1397513976.stack[R.EXN_STACKHEIGHT++] = $ss1397913980;
}
if(R.isPyretException($e1397513976)) {
$e1397513976.pyretStack.push(L[1519]);
}
throw $e1397513976;
}
var $ret1398113982 = $Hanf_arg315013986($z1397713978,INDENT9187,PP337,anf_arg7536101,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26);
++R.GAS;
return $ret1398113982;
};
var $Hanf_arg315013986 = function(anf_arg75713985,INDENT9187,PP337,anf_arg7536101,anf_fun7516102,anf_fun7526103,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26) {
var $z1398913990 = D;
var $f1399513996 = function(_) {
return R.isFunction(anf_fun7526103)?anf_fun7526103.app(anf_arg7536101,anf_arg75713985):R.ffi.throwNonFunApp(L[1520],anf_fun7526103,[anf_arg7536101,anf_arg75713985]);
};
try {
if(--R.GAS > 0) {
$z1398913990 = $f1399513996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1399513996,
"from":L[1520]});
}
} catch($e1398713988) {
if(R.isCont($e1398713988)) {
var $ss1399113992 = {"from":L[1520],
"go":function(anf_arg75813997) {
return $Hanf_arg314913998(anf_arg75813997,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26);
}};
$e1398713988.stack[R.EXN_STACKHEIGHT++] = $ss1399113992;
}
if(R.isPyretException($e1398713988)) {
$e1398713988.pyretStack.push(L[1520]);
}
throw $e1398713988;
}
var $ret1399313994 = $Hanf_arg314913998($z1398913990,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26);
++R.GAS;
return $ret1399313994;
};
var $Hanf_arg314913998 = function(anf_arg75813997,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,str_DASH_if105261,_plus26) {
var $z1400114002 = D;
var $f1400714008 = function(_) {
return R.isFunction(_plus26)?_plus26.app(str_DASH_if105261,anf_arg75813997):R.ffi.throwNonFunApp(L[1521],_plus26,[str_DASH_if105261,anf_arg75813997]);
};
try {
if(--R.GAS > 0) {
$z1400114002 = $f1400714008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1400714008,
"from":L[1521]});
}
} catch($e1399914000) {
if(R.isCont($e1399914000)) {
var $ss1400314004 = {"from":L[1521],
"go":function(anf_arg75914009) {
return $Hanf_arg314814010(anf_arg75914009,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
}};
$e1399914000.stack[R.EXN_STACKHEIGHT++] = $ss1400314004;
}
if(R.isPyretException($e1399914000)) {
$e1399914000.pyretStack.push(L[1521]);
}
throw $e1399914000;
}
var $ret1400514006 = $Hanf_arg314814010($z1400114002,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1400514006;
};
var $Hanf_arg314814010 = function(anf_arg75914009,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26) {
var anf_fun76014023 = G(PP337,"nest",L[1525]);
var anf_bracket76114025 = G(self3366104,"t",L[1524]);
var anf_fun76214021 = G(anf_bracket76114025,"tosource",L[1523]);
var $z1401314014 = D;
var $f1401914020 = function(_) {
return R.isFunction(anf_fun76214021)?anf_fun76214021.app():R.ffi.throwNonFunApp(L[1522],anf_fun76214021,[]);
};
try {
if(--R.GAS > 0) {
$z1401314014 = $f1401914020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1401914020,
"from":L[1522]});
}
} catch($e1401114012) {
if(R.isCont($e1401114012)) {
var $ss1401514016 = {"from":L[1522],
"go":function(anf_arg76314022) {
return $Hanf_arg314714024(anf_arg76314022,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,anf_fun76014023,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
}};
$e1401114012.stack[R.EXN_STACKHEIGHT++] = $ss1401514016;
}
if(R.isPyretException($e1401114012)) {
$e1401114012.pyretStack.push(L[1522]);
}
throw $e1401114012;
}
var $ret1401714018 = $Hanf_arg314714024($z1401314014,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,anf_fun76014023,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1401714018;
};
var $Hanf_arg314714024 = function(anf_arg76314022,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,anf_fun76014023,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26) {
var $z1402814029 = D;
var $f1403414035 = function(_) {
return R.isFunction(_plus26)?_plus26.app(break_DASH_one9262,anf_arg76314022):R.ffi.throwNonFunApp(L[1526],_plus26,[break_DASH_one9262,anf_arg76314022]);
};
try {
if(--R.GAS > 0) {
$z1402814029 = $f1403414035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1403414035,
"from":L[1526]});
}
} catch($e1402614027) {
if(R.isCont($e1402614027)) {
var $ss1403014031 = {"from":L[1526],
"go":function(anf_arg76414036) {
return $Hanf_arg314614037(anf_arg76414036,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,anf_fun76014023,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
}};
$e1402614027.stack[R.EXN_STACKHEIGHT++] = $ss1403014031;
}
if(R.isPyretException($e1402614027)) {
$e1402614027.pyretStack.push(L[1526]);
}
throw $e1402614027;
}
var $ret1403214033 = $Hanf_arg314614037($z1402814029,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,anf_fun76014023,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1403214033;
};
var $Hanf_arg314614037 = function(anf_arg76414036,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,anf_fun76014023,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26) {
var $z1404014041 = D;
var $f1404614047 = function(_) {
return R.isFunction(anf_fun76014023)?anf_fun76014023.app(INDENT9187,anf_arg76414036):R.ffi.throwNonFunApp(L[1527],anf_fun76014023,[INDENT9187,anf_arg76414036]);
};
try {
if(--R.GAS > 0) {
$z1404014041 = $f1404614047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1404614047,
"from":L[1527]});
}
} catch($e1403814039) {
if(R.isCont($e1403814039)) {
var $ss1404214043 = {"from":L[1527],
"go":function(anf_arg76514048) {
return $Hanf_arg314514049(anf_arg76514048,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
}};
$e1403814039.stack[R.EXN_STACKHEIGHT++] = $ss1404214043;
}
if(R.isPyretException($e1403814039)) {
$e1403814039.pyretStack.push(L[1527]);
}
throw $e1403814039;
}
var $ret1404414045 = $Hanf_arg314514049($z1404014041,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1404414045;
};
var $Hanf_arg314514049 = function(anf_arg76514048,INDENT9187,PP337,anf_arg75914009,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26) {
var $z1405214053 = D;
var $f1405814059 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg75914009,anf_arg76514048):R.ffi.throwNonFunApp(L[1521],_plus26,[anf_arg75914009,anf_arg76514048]);
};
try {
if(--R.GAS > 0) {
$z1405214053 = $f1405814059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1405814059,
"from":L[1521]});
}
} catch($e1405014051) {
if(R.isCont($e1405014051)) {
var $ss1405414055 = {"from":L[1521],
"go":function(anf_arg76614060) {
return $Hanf_arg314414061(anf_arg76614060,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
}};
$e1405014051.stack[R.EXN_STACKHEIGHT++] = $ss1405414055;
}
if(R.isPyretException($e1405014051)) {
$e1405014051.pyretStack.push(L[1521]);
}
throw $e1405014051;
}
var $ret1405614057 = $Hanf_arg314414061($z1405214053,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1405614057;
};
var $Hanf_arg314414061 = function(anf_arg76614060,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26) {
var $z1406414065 = D;
var $f1407014071 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg76614060,break_DASH_one9262):R.ffi.throwNonFunApp(L[1521],_plus26,[anf_arg76614060,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1406414065 = $f1407014071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1407014071,
"from":L[1521]});
}
} catch($e1406214063) {
if(R.isCont($e1406214063)) {
var $ss1406614067 = {"from":L[1521],
"go":function(anf_arg76714072) {
return $Hanf_arg314314073(anf_arg76714072,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
}};
$e1406214063.stack[R.EXN_STACKHEIGHT++] = $ss1406614067;
}
if(R.isPyretException($e1406214063)) {
$e1406214063.pyretStack.push(L[1521]);
}
throw $e1406214063;
}
var $ret1406814069 = $Hanf_arg314314073($z1406414065,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1406814069;
};
var $Hanf_arg314314073 = function(anf_arg76714072,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_elsecolon106274,str_DASH_end101209,_plus26) {
var $z1407614077 = D;
var $f1408214083 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg76714072,str_DASH_elsecolon106274):R.ffi.throwNonFunApp(L[1521],_plus26,[anf_arg76714072,str_DASH_elsecolon106274]);
};
try {
if(--R.GAS > 0) {
$z1407614077 = $f1408214083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1408214083,
"from":L[1521]});
}
} catch($e1407414075) {
if(R.isCont($e1407414075)) {
var $ss1407814079 = {"from":L[1521],
"go":function(anf_arg76814084) {
return $Hanf_arg314214085(anf_arg76814084,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_end101209,_plus26);
}};
$e1407414075.stack[R.EXN_STACKHEIGHT++] = $ss1407814079;
}
if(R.isPyretException($e1407414075)) {
$e1407414075.pyretStack.push(L[1521]);
}
throw $e1407414075;
}
var $ret1408014081 = $Hanf_arg314214085($z1407614077,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1408014081;
};
var $Hanf_arg314214085 = function(anf_arg76814084,INDENT9187,PP337,anf_fun7516102,break_DASH_one9262,self3366104,str_DASH_end101209,_plus26) {
var anf_fun76914098 = G(PP337,"nest",L[1531]);
var anf_bracket77014100 = G(self3366104,"e",L[1530]);
var anf_fun77114096 = G(anf_bracket77014100,"tosource",L[1529]);
var $z1408814089 = D;
var $f1409414095 = function(_) {
return R.isFunction(anf_fun77114096)?anf_fun77114096.app():R.ffi.throwNonFunApp(L[1528],anf_fun77114096,[]);
};
try {
if(--R.GAS > 0) {
$z1408814089 = $f1409414095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1409414095,
"from":L[1528]});
}
} catch($e1408614087) {
if(R.isCont($e1408614087)) {
var $ss1409014091 = {"from":L[1528],
"go":function(anf_arg77214097) {
return $Hanf_arg314114099(anf_arg77214097,INDENT9187,anf_arg76814084,anf_fun7516102,anf_fun76914098,break_DASH_one9262,str_DASH_end101209,_plus26);
}};
$e1408614087.stack[R.EXN_STACKHEIGHT++] = $ss1409014091;
}
if(R.isPyretException($e1408614087)) {
$e1408614087.pyretStack.push(L[1528]);
}
throw $e1408614087;
}
var $ret1409214093 = $Hanf_arg314114099($z1408814089,INDENT9187,anf_arg76814084,anf_fun7516102,anf_fun76914098,break_DASH_one9262,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1409214093;
};
var $Hanf_arg314114099 = function(anf_arg77214097,INDENT9187,anf_arg76814084,anf_fun7516102,anf_fun76914098,break_DASH_one9262,str_DASH_end101209,_plus26) {
var $z1410314104 = D;
var $f1410914110 = function(_) {
return R.isFunction(_plus26)?_plus26.app(break_DASH_one9262,anf_arg77214097):R.ffi.throwNonFunApp(L[1532],_plus26,[break_DASH_one9262,anf_arg77214097]);
};
try {
if(--R.GAS > 0) {
$z1410314104 = $f1410914110();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1410914110,
"from":L[1532]});
}
} catch($e1410114102) {
if(R.isCont($e1410114102)) {
var $ss1410514106 = {"from":L[1532],
"go":function(anf_arg77314111) {
return $Hanf_arg314014112(anf_arg77314111,INDENT9187,anf_arg76814084,anf_fun7516102,anf_fun76914098,break_DASH_one9262,str_DASH_end101209,_plus26);
}};
$e1410114102.stack[R.EXN_STACKHEIGHT++] = $ss1410514106;
}
if(R.isPyretException($e1410114102)) {
$e1410114102.pyretStack.push(L[1532]);
}
throw $e1410114102;
}
var $ret1410714108 = $Hanf_arg314014112($z1410314104,INDENT9187,anf_arg76814084,anf_fun7516102,anf_fun76914098,break_DASH_one9262,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1410714108;
};
var $Hanf_arg314014112 = function(anf_arg77314111,INDENT9187,anf_arg76814084,anf_fun7516102,anf_fun76914098,break_DASH_one9262,str_DASH_end101209,_plus26) {
var $z1411514116 = D;
var $f1412114122 = function(_) {
return R.isFunction(anf_fun76914098)?anf_fun76914098.app(INDENT9187,anf_arg77314111):R.ffi.throwNonFunApp(L[1533],anf_fun76914098,[INDENT9187,anf_arg77314111]);
};
try {
if(--R.GAS > 0) {
$z1411514116 = $f1412114122();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1412114122,
"from":L[1533]});
}
} catch($e1411314114) {
if(R.isCont($e1411314114)) {
var $ss1411714118 = {"from":L[1533],
"go":function(anf_arg77414123) {
return $Hanf_arg313914124(anf_arg77414123,anf_arg76814084,anf_fun7516102,break_DASH_one9262,str_DASH_end101209,_plus26);
}};
$e1411314114.stack[R.EXN_STACKHEIGHT++] = $ss1411714118;
}
if(R.isPyretException($e1411314114)) {
$e1411314114.pyretStack.push(L[1533]);
}
throw $e1411314114;
}
var $ret1411914120 = $Hanf_arg313914124($z1411514116,anf_arg76814084,anf_fun7516102,break_DASH_one9262,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1411914120;
};
var $Hanf_arg313914124 = function(anf_arg77414123,anf_arg76814084,anf_fun7516102,break_DASH_one9262,str_DASH_end101209,_plus26) {
var $z1412714128 = D;
var $f1413314134 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg76814084,anf_arg77414123):R.ffi.throwNonFunApp(L[1521],_plus26,[anf_arg76814084,anf_arg77414123]);
};
try {
if(--R.GAS > 0) {
$z1412714128 = $f1413314134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1413314134,
"from":L[1521]});
}
} catch($e1412514126) {
if(R.isCont($e1412514126)) {
var $ss1412914130 = {"from":L[1521],
"go":function(anf_arg77514135) {
return $Hanf_arg313814136(anf_arg77514135,anf_fun7516102,break_DASH_one9262,str_DASH_end101209,_plus26);
}};
$e1412514126.stack[R.EXN_STACKHEIGHT++] = $ss1412914130;
}
if(R.isPyretException($e1412514126)) {
$e1412514126.pyretStack.push(L[1521]);
}
throw $e1412514126;
}
var $ret1413114132 = $Hanf_arg313814136($z1412714128,anf_fun7516102,break_DASH_one9262,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1413114132;
};
var $Hanf_arg313814136 = function(anf_arg77514135,anf_fun7516102,break_DASH_one9262,str_DASH_end101209,_plus26) {
var $z1413914140 = D;
var $f1414514146 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg77514135,break_DASH_one9262):R.ffi.throwNonFunApp(L[1521],_plus26,[anf_arg77514135,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1413914140 = $f1414514146();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1414514146,
"from":L[1521]});
}
} catch($e1413714138) {
if(R.isCont($e1413714138)) {
var $ss1414114142 = {"from":L[1521],
"go":function(anf_arg77614147) {
return $Hanf_arg313714148(anf_arg77614147,anf_fun7516102,str_DASH_end101209,_plus26);
}};
$e1413714138.stack[R.EXN_STACKHEIGHT++] = $ss1414114142;
}
if(R.isPyretException($e1413714138)) {
$e1413714138.pyretStack.push(L[1521]);
}
throw $e1413714138;
}
var $ret1414314144 = $Hanf_arg313714148($z1413914140,anf_fun7516102,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1414314144;
};
var $Hanf_arg313714148 = function(anf_arg77614147,anf_fun7516102,str_DASH_end101209,_plus26) {
var $z1415114152 = D;
var $f1415714158 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg77614147,str_DASH_end101209):R.ffi.throwNonFunApp(L[1521],_plus26,[anf_arg77614147,str_DASH_end101209]);
};
try {
if(--R.GAS > 0) {
$z1415114152 = $f1415714158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1415714158,
"from":L[1521]});
}
} catch($e1414914150) {
if(R.isCont($e1414914150)) {
var $ss1415314154 = {"from":L[1521],
"go":function(anf_arg77714159) {
return $Hanf_arg313614160(anf_arg77714159,anf_fun7516102);
}};
$e1414914150.stack[R.EXN_STACKHEIGHT++] = $ss1415314154;
}
if(R.isPyretException($e1414914150)) {
$e1414914150.pyretStack.push(L[1521]);
}
throw $e1414914150;
}
var $ret1415514156 = $Hanf_arg313614160($z1415114152,anf_fun7516102);
++R.GAS;
return $ret1415514156;
};
var $Hanf_arg313614160 = function(anf_arg77714159,anf_fun7516102) {
var $z1416314164 = D;
var $f1416914170 = function(_) {
return R.isFunction(anf_fun7516102)?anf_fun7516102.app(anf_arg77714159):R.ffi.throwNonFunApp(L[987],anf_fun7516102,[anf_arg77714159]);
};
try {
if(--R.GAS > 0) {
$z1416314164 = $f1416914170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1416914170,
"from":L[987]});
}
} catch($e1416114162) {
if(R.isCont($e1416114162)) {
var $ss1416514166 = {"from":L[987],
"go":function(ann_DASH_check_DASH_temp75014171) {
return $Hann_DASH_check_DASH_temp313514172(ann_DASH_check_DASH_temp75014171);
}};
$e1416114162.stack[R.EXN_STACKHEIGHT++] = $ss1416514166;
}
if(R.isPyretException($e1416114162)) {
$e1416114162.pyretStack.push(L[987]);
}
throw $e1416114162;
}
var $ret1416714168 = $Hann_DASH_check_DASH_temp313514172($z1416314164);
++R.GAS;
return $ret1416714168;
};
var $Hann_DASH_check_DASH_temp313514172 = function(ann_DASH_check_DASH_temp75014171) {
return ann_DASH_check_DASH_temp75014171;
};
var $Hanf_arg31346121 = function(anf_arg7326119,self836120,_plus26,torepr31) {
var anf_arg73314183 = G(self836120,"c",L[935]);
var $z1417514176 = D;
var $f1418114182 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg73314183):R.ffi.throwNonFunApp(L[935],torepr31,[anf_arg73314183]);
};
try {
if(--R.GAS > 0) {
$z1417514176 = $f1418114182();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1418114182,
"from":L[935]});
}
} catch($e1417314174) {
if(R.isCont($e1417314174)) {
var $ss1417714178 = {"from":L[935],
"go":function(anf_arg73414184) {
return $Hanf_arg313314185(anf_arg73414184,anf_arg7326119,self836120,_plus26,torepr31);
}};
$e1417314174.stack[R.EXN_STACKHEIGHT++] = $ss1417714178;
}
if(R.isPyretException($e1417314174)) {
$e1417314174.pyretStack.push(L[935]);
}
throw $e1417314174;
}
var $ret1417914180 = $Hanf_arg313314185($z1417514176,anf_arg7326119,self836120,_plus26,torepr31);
++R.GAS;
return $ret1417914180;
};
var $Hanf_arg313314185 = function(anf_arg73414184,anf_arg7326119,self836120,_plus26,torepr31) {
var $z1418814189 = D;
var $f1419414195 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg73414184):R.ffi.throwNonFunApp(L[935],_plus26,[(", "),anf_arg73414184]);
};
try {
if(--R.GAS > 0) {
$z1418814189 = $f1419414195();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1419414195,
"from":L[935]});
}
} catch($e1418614187) {
if(R.isCont($e1418614187)) {
var $ss1419014191 = {"from":L[935],
"go":function(anf_arg73514196) {
return $Hanf_arg313214197(anf_arg73514196,anf_arg7326119,self836120,_plus26,torepr31);
}};
$e1418614187.stack[R.EXN_STACKHEIGHT++] = $ss1419014191;
}
if(R.isPyretException($e1418614187)) {
$e1418614187.pyretStack.push(L[935]);
}
throw $e1418614187;
}
var $ret1419214193 = $Hanf_arg313214197($z1418814189,anf_arg7326119,self836120,_plus26,torepr31);
++R.GAS;
return $ret1419214193;
};
var $Hanf_arg313214197 = function(anf_arg73514196,anf_arg7326119,self836120,_plus26,torepr31) {
var $z1420014201 = D;
var $f1420614207 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg7326119,anf_arg73514196):R.ffi.throwNonFunApp(L[935],_plus26,[anf_arg7326119,anf_arg73514196]);
};
try {
if(--R.GAS > 0) {
$z1420014201 = $f1420614207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1420614207,
"from":L[935]});
}
} catch($e1419814199) {
if(R.isCont($e1419814199)) {
var $ss1420214203 = {"from":L[935],
"go":function(anf_arg73614208) {
return $Hanf_arg313114209(anf_arg73614208,self836120,_plus26,torepr31);
}};
$e1419814199.stack[R.EXN_STACKHEIGHT++] = $ss1420214203;
}
if(R.isPyretException($e1419814199)) {
$e1419814199.pyretStack.push(L[935]);
}
throw $e1419814199;
}
var $ret1420414205 = $Hanf_arg313114209($z1420014201,self836120,_plus26,torepr31);
++R.GAS;
return $ret1420414205;
};
var $Hanf_arg313114209 = function(anf_arg73614208,self836120,_plus26,torepr31) {
var anf_arg73714220 = G(self836120,"t",L[935]);
var $z1421214213 = D;
var $f1421814219 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg73714220):R.ffi.throwNonFunApp(L[935],torepr31,[anf_arg73714220]);
};
try {
if(--R.GAS > 0) {
$z1421214213 = $f1421814219();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1421814219,
"from":L[935]});
}
} catch($e1421014211) {
if(R.isCont($e1421014211)) {
var $ss1421414215 = {"from":L[935],
"go":function(anf_arg73814221) {
return $Hanf_arg313014222(anf_arg73814221,anf_arg73614208,self836120,_plus26,torepr31);
}};
$e1421014211.stack[R.EXN_STACKHEIGHT++] = $ss1421414215;
}
if(R.isPyretException($e1421014211)) {
$e1421014211.pyretStack.push(L[935]);
}
throw $e1421014211;
}
var $ret1421614217 = $Hanf_arg313014222($z1421214213,anf_arg73614208,self836120,_plus26,torepr31);
++R.GAS;
return $ret1421614217;
};
var $Hanf_arg313014222 = function(anf_arg73814221,anf_arg73614208,self836120,_plus26,torepr31) {
var $z1422514226 = D;
var $f1423114232 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg73814221):R.ffi.throwNonFunApp(L[935],_plus26,[(", "),anf_arg73814221]);
};
try {
if(--R.GAS > 0) {
$z1422514226 = $f1423114232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1423114232,
"from":L[935]});
}
} catch($e1422314224) {
if(R.isCont($e1422314224)) {
var $ss1422714228 = {"from":L[935],
"go":function(anf_arg73914233) {
return $Hanf_arg312914234(anf_arg73914233,anf_arg73614208,self836120,_plus26,torepr31);
}};
$e1422314224.stack[R.EXN_STACKHEIGHT++] = $ss1422714228;
}
if(R.isPyretException($e1422314224)) {
$e1422314224.pyretStack.push(L[935]);
}
throw $e1422314224;
}
var $ret1422914230 = $Hanf_arg312914234($z1422514226,anf_arg73614208,self836120,_plus26,torepr31);
++R.GAS;
return $ret1422914230;
};
var $Hanf_arg312914234 = function(anf_arg73914233,anf_arg73614208,self836120,_plus26,torepr31) {
var $z1423714238 = D;
var $f1424314244 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg73614208,anf_arg73914233):R.ffi.throwNonFunApp(L[935],_plus26,[anf_arg73614208,anf_arg73914233]);
};
try {
if(--R.GAS > 0) {
$z1423714238 = $f1424314244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1424314244,
"from":L[935]});
}
} catch($e1423514236) {
if(R.isCont($e1423514236)) {
var $ss1423914240 = {"from":L[935],
"go":function(anf_arg74014245) {
return $Hanf_arg312814246(anf_arg74014245,self836120,_plus26,torepr31);
}};
$e1423514236.stack[R.EXN_STACKHEIGHT++] = $ss1423914240;
}
if(R.isPyretException($e1423514236)) {
$e1423514236.pyretStack.push(L[935]);
}
throw $e1423514236;
}
var $ret1424114242 = $Hanf_arg312814246($z1423714238,self836120,_plus26,torepr31);
++R.GAS;
return $ret1424114242;
};
var $Hanf_arg312814246 = function(anf_arg74014245,self836120,_plus26,torepr31) {
var anf_arg74114257 = G(self836120,"e",L[935]);
var $z1424914250 = D;
var $f1425514256 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg74114257):R.ffi.throwNonFunApp(L[935],torepr31,[anf_arg74114257]);
};
try {
if(--R.GAS > 0) {
$z1424914250 = $f1425514256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1425514256,
"from":L[935]});
}
} catch($e1424714248) {
if(R.isCont($e1424714248)) {
var $ss1425114252 = {"from":L[935],
"go":function(anf_arg74214258) {
return $Hanf_arg312714259(anf_arg74214258,anf_arg74014245,_plus26);
}};
$e1424714248.stack[R.EXN_STACKHEIGHT++] = $ss1425114252;
}
if(R.isPyretException($e1424714248)) {
$e1424714248.pyretStack.push(L[935]);
}
throw $e1424714248;
}
var $ret1425314254 = $Hanf_arg312714259($z1424914250,anf_arg74014245,_plus26);
++R.GAS;
return $ret1425314254;
};
var $Hanf_arg312714259 = function(anf_arg74214258,anf_arg74014245,_plus26) {
var $z1426214263 = D;
var $f1426814269 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg74214258):R.ffi.throwNonFunApp(L[935],_plus26,[(", "),anf_arg74214258]);
};
try {
if(--R.GAS > 0) {
$z1426214263 = $f1426814269();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1426814269,
"from":L[935]});
}
} catch($e1426014261) {
if(R.isCont($e1426014261)) {
var $ss1426414265 = {"from":L[935],
"go":function(anf_arg74314270) {
return $Hanf_arg312614271(anf_arg74314270,anf_arg74014245,_plus26);
}};
$e1426014261.stack[R.EXN_STACKHEIGHT++] = $ss1426414265;
}
if(R.isPyretException($e1426014261)) {
$e1426014261.pyretStack.push(L[935]);
}
throw $e1426014261;
}
var $ret1426614267 = $Hanf_arg312614271($z1426214263,anf_arg74014245,_plus26);
++R.GAS;
return $ret1426614267;
};
var $Hanf_arg312614271 = function(anf_arg74314270,anf_arg74014245,_plus26) {
var $z1427414275 = D;
var $f1428014281 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg74014245,anf_arg74314270):R.ffi.throwNonFunApp(L[935],_plus26,[anf_arg74014245,anf_arg74314270]);
};
try {
if(--R.GAS > 0) {
$z1427414275 = $f1428014281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1428014281,
"from":L[935]});
}
} catch($e1427214273) {
if(R.isCont($e1427214273)) {
var $ss1427614277 = {"from":L[935],
"go":function(anf_arg74414282) {
return $Hanf_arg312514283(anf_arg74414282,_plus26);
}};
$e1427214273.stack[R.EXN_STACKHEIGHT++] = $ss1427614277;
}
if(R.isPyretException($e1427214273)) {
$e1427214273.pyretStack.push(L[935]);
}
throw $e1427214273;
}
var $ret1427814279 = $Hanf_arg312514283($z1427414275,_plus26);
++R.GAS;
return $ret1427814279;
};
var $Hanf_arg312514283 = function(anf_arg74414282,_plus26) {
var $z1428614287 = D;
var $f1429214293 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg74414282,(")")):R.ffi.throwNonFunApp(L[935],_plus26,[anf_arg74414282,(")")]);
};
try {
if(--R.GAS > 0) {
$z1428614287 = $f1429214293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1429214293,
"from":L[935]});
}
} catch($e1428414285) {
if(R.isCont($e1428414285)) {
var $ss1428814289 = {"from":L[935],
"go":function(anf_arg74514294) {
return $Hanf_arg312414295(anf_arg74514294,_plus26);
}};
$e1428414285.stack[R.EXN_STACKHEIGHT++] = $ss1428814289;
}
if(R.isPyretException($e1428414285)) {
$e1428414285.pyretStack.push(L[935]);
}
throw $e1428414285;
}
var $ret1429014291 = $Hanf_arg312414295($z1428614287,_plus26);
++R.GAS;
return $ret1429014291;
};
var $Hanf_arg312414295 = function(anf_arg74514294,_plus26) {
var $z1429814299 = D;
var $f1430414305 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg74514294):R.ffi.throwNonFunApp(L[935],_plus26,[("("),anf_arg74514294]);
};
try {
if(--R.GAS > 0) {
$z1429814299 = $f1430414305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1430414305,
"from":L[935]});
}
} catch($e1429614297) {
if(R.isCont($e1429614297)) {
var $ss1430014301 = {"from":L[935],
"go":function(anf_arg74614306) {
return $Hanf_arg312314307(anf_arg74614306,_plus26);
}};
$e1429614297.stack[R.EXN_STACKHEIGHT++] = $ss1430014301;
}
if(R.isPyretException($e1429614297)) {
$e1429614297.pyretStack.push(L[935]);
}
throw $e1429614297;
}
var $ret1430214303 = $Hanf_arg312314307($z1429814299,_plus26);
++R.GAS;
return $ret1430214303;
};
var $Hanf_arg312314307 = function(anf_arg74614306,_plus26) {
var $z1431014311 = D;
var $f1431614317 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-if"),anf_arg74614306):R.ffi.throwNonFunApp(L[935],_plus26,[("a-if"),anf_arg74614306]);
};
try {
if(--R.GAS > 0) {
$z1431014311 = $f1431614317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1431614317,
"from":L[935]});
}
} catch($e1430814309) {
if(R.isCont($e1430814309)) {
var $ss1431214313 = {"from":L[935],
"go":function(ann_DASH_check_DASH_temp73014318) {
return $Hann_DASH_check_DASH_temp312214319(ann_DASH_check_DASH_temp73014318);
}};
$e1430814309.stack[R.EXN_STACKHEIGHT++] = $ss1431214313;
}
if(R.isPyretException($e1430814309)) {
$e1430814309.pyretStack.push(L[935]);
}
throw $e1430814309;
}
var $ret1431414315 = $Hann_DASH_check_DASH_temp312214319($z1431014311);
++R.GAS;
return $ret1431414315;
};
var $Hann_DASH_check_DASH_temp312214319 = function(ann_DASH_check_DASH_temp73014318) {
return ann_DASH_check_DASH_temp73014318;
};
var $Hcont_tail_arg31206139 = function(cont_tail_arg7276137,if_helper7166138) {
if(--R.GAS > 0) {
$z1432014321 = R.isFunction(if_helper7166138)?if_helper7166138.app(cont_tail_arg7276137):R.ffi.throwNonFunApp(L[935],if_helper7166138,[cont_tail_arg7276137]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper7166138)?if_helper7166138.app(cont_tail_arg7276137):R.ffi.throwNonFunApp(L[935],if_helper7166138,[cont_tail_arg7276137]);
},
"from":L[935]});
}
++R.GAS;
return $z1432014321;
};
var $Hcont_tail_arg31216154 = function(cont_tail_arg7216153,if_helper7166138) {
if(--R.GAS > 0) {
$z1432214323 = R.isFunction(if_helper7166138)?if_helper7166138.app(cont_tail_arg7216153):R.ffi.throwNonFunApp(L[935],if_helper7166138,[cont_tail_arg7216153]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper7166138)?if_helper7166138.app(cont_tail_arg7216153):R.ffi.throwNonFunApp(L[935],if_helper7166138,[cont_tail_arg7216153]);
},
"from":L[935]});
}
++R.GAS;
return $z1432214323;
};
var $Hanf_arg31196178 = function(anf_arg6566173,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26) {
var anf_fun65714336 = G(PP337,"group",L[1538]);
var anf_bracket65814339 = G(self3286177,"helper-args",L[1537]);
var anf_bracket65914338 = G(anf_bracket65814339,"first",L[1536]);
var anf_fun66014334 = G(anf_bracket65914338,"tosource",L[1535]);
var $z1432614327 = D;
var $f1433214333 = function(_) {
return R.isFunction(anf_fun66014334)?anf_fun66014334.app():R.ffi.throwNonFunApp(L[1534],anf_fun66014334,[]);
};
try {
if(--R.GAS > 0) {
$z1432614327 = $f1433214333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1433214333,
"from":L[1534]});
}
} catch($e1432414325) {
if(R.isCont($e1432414325)) {
var $ss1432814329 = {"from":L[1534],
"go":function(anf_arg66114335) {
return $Hanf_arg311814337(anf_arg66114335,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
}};
$e1432414325.stack[R.EXN_STACKHEIGHT++] = $ss1432814329;
}
if(R.isPyretException($e1432414325)) {
$e1432414325.pyretStack.push(L[1534]);
}
throw $e1432414325;
}
var $ret1433014331 = $Hanf_arg311814337($z1432614327,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1433014331;
};
var $Hanf_arg311814337 = function(anf_arg66114335,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26) {
var anf_fun66214350 = G(PP337,"str",L[1540]);
var $z1434214343 = D;
var $f1434814349 = function(_) {
return R.isFunction(anf_fun66214350)?anf_fun66214350.app((" <== ")):R.ffi.throwNonFunApp(L[1539],anf_fun66214350,[(" <== ")]);
};
try {
if(--R.GAS > 0) {
$z1434214343 = $f1434814349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1434814349,
"from":L[1539]});
}
} catch($e1434014341) {
if(R.isCont($e1434014341)) {
var $ss1434414345 = {"from":L[1539],
"go":function(anf_arg66314351) {
return $Hanf_arg311714352(anf_arg66314351,INDENT9187,PP337,anf_arg6566173,anf_arg66114335,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
}};
$e1434014341.stack[R.EXN_STACKHEIGHT++] = $ss1434414345;
}
if(R.isPyretException($e1434014341)) {
$e1434014341.pyretStack.push(L[1539]);
}
throw $e1434014341;
}
var $ret1434614347 = $Hanf_arg311714352($z1434214343,INDENT9187,PP337,anf_arg6566173,anf_arg66114335,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1434614347;
};
var $Hanf_arg311714352 = function(anf_arg66314351,INDENT9187,PP337,anf_arg6566173,anf_arg66114335,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26) {
var $z1435514356 = D;
var $f1436114362 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg66114335,anf_arg66314351):R.ffi.throwNonFunApp(L[1541],_plus26,[anf_arg66114335,anf_arg66314351]);
};
try {
if(--R.GAS > 0) {
$z1435514356 = $f1436114362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1436114362,
"from":L[1541]});
}
} catch($e1435314354) {
if(R.isCont($e1435314354)) {
var $ss1435714358 = {"from":L[1541],
"go":function(anf_arg66414363) {
return $Hanf_arg311614364(anf_arg66414363,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
}};
$e1435314354.stack[R.EXN_STACKHEIGHT++] = $ss1435714358;
}
if(R.isPyretException($e1435314354)) {
$e1435314354.pyretStack.push(L[1541]);
}
throw $e1435314354;
}
var $ret1435914360 = $Hanf_arg311614364($z1435514356,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1435914360;
};
var $Hanf_arg311614364 = function(anf_arg66414363,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26) {
var anf_bracket66514378 = G(self3286177,"f",L[1544]);
var anf_fun66614375 = G(anf_bracket66514378,"tosource",L[1543]);
var $z1436714368 = D;
var $f1437314374 = function(_) {
return R.isFunction(anf_fun66614375)?anf_fun66614375.app():R.ffi.throwNonFunApp(L[1542],anf_fun66614375,[]);
};
try {
if(--R.GAS > 0) {
$z1436714368 = $f1437314374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1437314374,
"from":L[1542]});
}
} catch($e1436514366) {
if(R.isCont($e1436514366)) {
var $ss1436914370 = {"from":L[1542],
"go":function(anf_arg66714376) {
return $Hanf_arg311514377(anf_arg66714376,INDENT9187,PP337,anf_arg6566173,anf_arg66414363,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
}};
$e1436514366.stack[R.EXN_STACKHEIGHT++] = $ss1436914370;
}
if(R.isPyretException($e1436514366)) {
$e1436514366.pyretStack.push(L[1542]);
}
throw $e1436514366;
}
var $ret1437114372 = $Hanf_arg311514377($z1436714368,INDENT9187,PP337,anf_arg6566173,anf_arg66414363,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1437114372;
};
var $Hanf_arg311514377 = function(anf_arg66714376,INDENT9187,PP337,anf_arg6566173,anf_arg66414363,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26) {
var $z1438114382 = D;
var $f1438714388 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg66414363,anf_arg66714376):R.ffi.throwNonFunApp(L[1541],_plus26,[anf_arg66414363,anf_arg66714376]);
};
try {
if(--R.GAS > 0) {
$z1438114382 = $f1438714388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1438714388,
"from":L[1541]});
}
} catch($e1437914380) {
if(R.isCont($e1437914380)) {
var $ss1438314384 = {"from":L[1541],
"go":function(anf_arg66814389) {
return $Hanf_arg311414390(anf_arg66814389,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
}};
$e1437914380.stack[R.EXN_STACKHEIGHT++] = $ss1438314384;
}
if(R.isPyretException($e1437914380)) {
$e1437914380.pyretStack.push(L[1541]);
}
throw $e1437914380;
}
var $ret1438514386 = $Hanf_arg311414390($z1438114382,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1438514386;
};
var $Hanf_arg311414390 = function(anf_arg66814389,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26) {
var anf_fun66914405 = G(PP337,"parens",L[1553]);
var anf_fun67014406 = G(PP337,"nest",L[1552]);
var anf_fun67114407 = G(PP337,"separate",L[1551]);
var anf_arg67214404 = G(PP337,"commabreak",L[1550]);
var anf_bracket67314423 = G(self3286177,"args",L[1549]);
var anf_fun67414401 = G(anf_bracket67314423,"map",L[1548]);
var anf_arg67714402 = R.makeFunction(function(f32914409) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1546],1,arguments);
}
var anf_fun67614420 = G(f32914409,"tosource",L[1547]);
var $z1441214413 = D;
var $f1441814419 = function(_) {
return R.isFunction(anf_fun67614420)?anf_fun67614420.app():R.ffi.throwNonFunApp(L[1546],anf_fun67614420,[]);
};
try {
if(--R.GAS > 0) {
$z1441214413 = $f1441814419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1441814419,
"from":L[1546]});
}
} catch($e1441014411) {
if(R.isCont($e1441014411)) {
var $ss1441414415 = {"from":L[1546],
"go":function(ann_DASH_check_DASH_temp67514421) {
return $Hann_DASH_check_DASH_temp308914422(ann_DASH_check_DASH_temp67514421);
}};
$e1441014411.stack[R.EXN_STACKHEIGHT++] = $ss1441414415;
}
if(R.isPyretException($e1441014411)) {
$e1441014411.pyretStack.push(L[1546]);
}
throw $e1441014411;
}
var $ret1441614417 = $Hann_DASH_check_DASH_temp308914422($z1441214413);
++R.GAS;
return $ret1441614417;
});
var $z1439314394 = D;
var $f1439914400 = function(_) {
return R.isFunction(anf_fun67414401)?anf_fun67414401.app(anf_arg67714402):R.ffi.throwNonFunApp(L[1545],anf_fun67414401,[anf_arg67714402]);
};
try {
if(--R.GAS > 0) {
$z1439314394 = $f1439914400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1439914400,
"from":L[1545]});
}
} catch($e1439114392) {
if(R.isCont($e1439114392)) {
var $ss1439514396 = {"from":L[1545],
"go":function(anf_arg67814403) {
return $Hanf_arg311314408(anf_arg67814403,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_arg67214404,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,anf_fun67014406,anf_fun67114407,break_DASH_one9262,self3286177,_plus26);
}};
$e1439114392.stack[R.EXN_STACKHEIGHT++] = $ss1439514396;
}
if(R.isPyretException($e1439114392)) {
$e1439114392.pyretStack.push(L[1545]);
}
throw $e1439114392;
}
var $ret1439714398 = $Hanf_arg311314408($z1439314394,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_arg67214404,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,anf_fun67014406,anf_fun67114407,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1439714398;
};
var $Hanf_arg311314408 = function(anf_arg67814403,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_arg67214404,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,anf_fun67014406,anf_fun67114407,break_DASH_one9262,self3286177,_plus26) {
var $z1442614427 = D;
var $f1443214433 = function(_) {
return R.isFunction(anf_fun67114407)?anf_fun67114407.app(anf_arg67214404,anf_arg67814403):R.ffi.throwNonFunApp(L[1554],anf_fun67114407,[anf_arg67214404,anf_arg67814403]);
};
try {
if(--R.GAS > 0) {
$z1442614427 = $f1443214433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1443214433,
"from":L[1554]});
}
} catch($e1442414425) {
if(R.isCont($e1442414425)) {
var $ss1442814429 = {"from":L[1554],
"go":function(anf_arg67914434) {
return $Hanf_arg311214435(anf_arg67914434,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,anf_fun67014406,break_DASH_one9262,self3286177,_plus26);
}};
$e1442414425.stack[R.EXN_STACKHEIGHT++] = $ss1442814429;
}
if(R.isPyretException($e1442414425)) {
$e1442414425.pyretStack.push(L[1554]);
}
throw $e1442414425;
}
var $ret1443014431 = $Hanf_arg311214435($z1442614427,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,anf_fun67014406,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1443014431;
};
var $Hanf_arg311214435 = function(anf_arg67914434,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,anf_fun67014406,break_DASH_one9262,self3286177,_plus26) {
var $z1443814439 = D;
var $f1444414445 = function(_) {
return R.isFunction(anf_fun67014406)?anf_fun67014406.app(INDENT9187,anf_arg67914434):R.ffi.throwNonFunApp(L[1555],anf_fun67014406,[INDENT9187,anf_arg67914434]);
};
try {
if(--R.GAS > 0) {
$z1443814439 = $f1444414445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1444414445,
"from":L[1555]});
}
} catch($e1443614437) {
if(R.isCont($e1443614437)) {
var $ss1444014441 = {"from":L[1555],
"go":function(anf_arg68014446) {
return $Hanf_arg311114447(anf_arg68014446,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,break_DASH_one9262,self3286177,_plus26);
}};
$e1443614437.stack[R.EXN_STACKHEIGHT++] = $ss1444014441;
}
if(R.isPyretException($e1443614437)) {
$e1443614437.pyretStack.push(L[1555]);
}
throw $e1443614437;
}
var $ret1444214443 = $Hanf_arg311114447($z1443814439,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1444214443;
};
var $Hanf_arg311114447 = function(anf_arg68014446,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,anf_fun66914405,break_DASH_one9262,self3286177,_plus26) {
var $z1445014451 = D;
var $f1445614457 = function(_) {
return R.isFunction(anf_fun66914405)?anf_fun66914405.app(anf_arg68014446):R.ffi.throwNonFunApp(L[1556],anf_fun66914405,[anf_arg68014446]);
};
try {
if(--R.GAS > 0) {
$z1445014451 = $f1445614457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1445614457,
"from":L[1556]});
}
} catch($e1444814449) {
if(R.isCont($e1444814449)) {
var $ss1445214453 = {"from":L[1556],
"go":function(anf_arg68114458) {
return $Hanf_arg311014459(anf_arg68114458,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
}};
$e1444814449.stack[R.EXN_STACKHEIGHT++] = $ss1445214453;
}
if(R.isPyretException($e1444814449)) {
$e1444814449.pyretStack.push(L[1556]);
}
throw $e1444814449;
}
var $ret1445414455 = $Hanf_arg311014459($z1445014451,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1445414455;
};
var $Hanf_arg311014459 = function(anf_arg68114458,INDENT9187,PP337,anf_arg6566173,anf_arg66814389,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26) {
var $z1446214463 = D;
var $f1446814469 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg66814389,anf_arg68114458):R.ffi.throwNonFunApp(L[1541],_plus26,[anf_arg66814389,anf_arg68114458]);
};
try {
if(--R.GAS > 0) {
$z1446214463 = $f1446814469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1446814469,
"from":L[1541]});
}
} catch($e1446014461) {
if(R.isCont($e1446014461)) {
var $ss1446414465 = {"from":L[1541],
"go":function(anf_arg68214470) {
return $Hanf_arg310914471(anf_arg68214470,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
}};
$e1446014461.stack[R.EXN_STACKHEIGHT++] = $ss1446414465;
}
if(R.isPyretException($e1446014461)) {
$e1446014461.pyretStack.push(L[1541]);
}
throw $e1446014461;
}
var $ret1446614467 = $Hanf_arg310914471($z1446214463,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1446614467;
};
var $Hanf_arg310914471 = function(anf_arg68214470,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,anf_fun65714336,break_DASH_one9262,self3286177,_plus26) {
var $z1447414475 = D;
var $f1448014481 = function(_) {
return R.isFunction(anf_fun65714336)?anf_fun65714336.app(anf_arg68214470):R.ffi.throwNonFunApp(L[1557],anf_fun65714336,[anf_arg68214470]);
};
try {
if(--R.GAS > 0) {
$z1447414475 = $f1448014481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1448014481,
"from":L[1557]});
}
} catch($e1447214473) {
if(R.isCont($e1447214473)) {
var $ss1447614477 = {"from":L[1557],
"go":function(anf_arg68314482) {
return $Hanf_arg310814483(anf_arg68314482,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26);
}};
$e1447214473.stack[R.EXN_STACKHEIGHT++] = $ss1447614477;
}
if(R.isPyretException($e1447214473)) {
$e1447214473.pyretStack.push(L[1557]);
}
throw $e1447214473;
}
var $ret1447814479 = $Hanf_arg310814483($z1447414475,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1447814479;
};
var $Hanf_arg310814483 = function(anf_arg68314482,INDENT9187,PP337,anf_arg6566173,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26) {
var $z1448614487 = D;
var $f1449214493 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg6566173,anf_arg68314482):R.ffi.throwNonFunApp(L[1558],_plus26,[anf_arg6566173,anf_arg68314482]);
};
try {
if(--R.GAS > 0) {
$z1448614487 = $f1449214493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1449214493,
"from":L[1558]});
}
} catch($e1448414485) {
if(R.isCont($e1448414485)) {
var $ss1448814489 = {"from":L[1558],
"go":function(anf_arg68414494) {
return $Hanf_arg310714495(anf_arg68414494,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26);
}};
$e1448414485.stack[R.EXN_STACKHEIGHT++] = $ss1448814489;
}
if(R.isPyretException($e1448414485)) {
$e1448414485.pyretStack.push(L[1558]);
}
throw $e1448414485;
}
var $ret1449014491 = $Hanf_arg310714495($z1448614487,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1449014491;
};
var $Hanf_arg310714495 = function(anf_arg68414494,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,anf_fun6546176,break_DASH_one9262,self3286177,_plus26) {
var $z1449814499 = D;
var $f1450414505 = function(_) {
return R.isFunction(anf_fun6546176)?anf_fun6546176.app(INDENT9187,anf_arg68414494):R.ffi.throwNonFunApp(L[1559],anf_fun6546176,[INDENT9187,anf_arg68414494]);
};
try {
if(--R.GAS > 0) {
$z1449814499 = $f1450414505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1450414505,
"from":L[1559]});
}
} catch($e1449614497) {
if(R.isCont($e1449614497)) {
var $ss1450014501 = {"from":L[1559],
"go":function(anf_arg68514506) {
return $Hanf_arg310614507(anf_arg68514506,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,break_DASH_one9262,self3286177,_plus26);
}};
$e1449614497.stack[R.EXN_STACKHEIGHT++] = $ss1450014501;
}
if(R.isPyretException($e1449614497)) {
$e1449614497.pyretStack.push(L[1559]);
}
throw $e1449614497;
}
var $ret1450214503 = $Hanf_arg310614507($z1449814499,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1450214503;
};
var $Hanf_arg310614507 = function(anf_arg68514506,INDENT9187,PP337,anf_fun6526174,anf_fun6536175,break_DASH_one9262,self3286177,_plus26) {
var $z1451014511 = D;
var $f1451614517 = function(_) {
return R.isFunction(anf_fun6536175)?anf_fun6536175.app(anf_arg68514506):R.ffi.throwNonFunApp(L[1560],anf_fun6536175,[anf_arg68514506]);
};
try {
if(--R.GAS > 0) {
$z1451014511 = $f1451614517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1451614517,
"from":L[1560]});
}
} catch($e1450814509) {
if(R.isCont($e1450814509)) {
var $ss1451214513 = {"from":L[1560],
"go":function(anf_arg68614518) {
return $Hanf_arg310514519(anf_arg68614518,INDENT9187,PP337,anf_fun6526174,break_DASH_one9262,self3286177,_plus26);
}};
$e1450814509.stack[R.EXN_STACKHEIGHT++] = $ss1451214513;
}
if(R.isPyretException($e1450814509)) {
$e1450814509.pyretStack.push(L[1560]);
}
throw $e1450814509;
}
var $ret1451414515 = $Hanf_arg310514519($z1451014511,INDENT9187,PP337,anf_fun6526174,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1451414515;
};
var $Hanf_arg310514519 = function(anf_arg68614518,INDENT9187,PP337,anf_fun6526174,break_DASH_one9262,self3286177,_plus26) {
var $z1452214523 = D;
var $f1452814529 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg68614518,break_DASH_one9262):R.ffi.throwNonFunApp(L[1561],_plus26,[anf_arg68614518,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1452214523 = $f1452814529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1452814529,
"from":L[1561]});
}
} catch($e1452014521) {
if(R.isCont($e1452014521)) {
var $ss1452414525 = {"from":L[1561],
"go":function(anf_arg68714530) {
return $Hanf_arg310414531(anf_arg68714530,INDENT9187,PP337,anf_fun6526174,break_DASH_one9262,self3286177,_plus26);
}};
$e1452014521.stack[R.EXN_STACKHEIGHT++] = $ss1452414525;
}
if(R.isPyretException($e1452014521)) {
$e1452014521.pyretStack.push(L[1561]);
}
throw $e1452014521;
}
var $ret1452614527 = $Hanf_arg310414531($z1452214523,INDENT9187,PP337,anf_fun6526174,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1452614527;
};
var $Hanf_arg310414531 = function(anf_arg68714530,INDENT9187,PP337,anf_fun6526174,break_DASH_one9262,self3286177,_plus26) {
var anf_fun68814544 = G(PP337,"group",L[1565]);
var anf_fun68914545 = G(PP337,"nest",L[1564]);
var anf_fun69014542 = G(PP337,"str",L[1563]);
var $z1453414535 = D;
var $f1454014541 = function(_) {
return R.isFunction(anf_fun69014542)?anf_fun69014542.app(("and then")):R.ffi.throwNonFunApp(L[1562],anf_fun69014542,[("and then")]);
};
try {
if(--R.GAS > 0) {
$z1453414535 = $f1454014541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1454014541,
"from":L[1562]});
}
} catch($e1453214533) {
if(R.isCont($e1453214533)) {
var $ss1453614537 = {"from":L[1562],
"go":function(anf_arg69114543) {
return $Hanf_arg310314546(anf_arg69114543,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,break_DASH_one9262,self3286177,_plus26);
}};
$e1453214533.stack[R.EXN_STACKHEIGHT++] = $ss1453614537;
}
if(R.isPyretException($e1453214533)) {
$e1453214533.pyretStack.push(L[1562]);
}
throw $e1453214533;
}
var $ret1453814539 = $Hanf_arg310314546($z1453414535,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,break_DASH_one9262,self3286177,_plus26);
++R.GAS;
return $ret1453814539;
};
var $Hanf_arg310314546 = function(anf_arg69114543,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,break_DASH_one9262,self3286177,_plus26) {
var $z1454914550 = D;
var $f1455514556 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg69114543,break_DASH_one9262):R.ffi.throwNonFunApp(L[1566],_plus26,[anf_arg69114543,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1454914550 = $f1455514556();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1455514556,
"from":L[1566]});
}
} catch($e1454714548) {
if(R.isCont($e1454714548)) {
var $ss1455114552 = {"from":L[1566],
"go":function(anf_arg69214557) {
return $Hanf_arg310214558(anf_arg69214557,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26);
}};
$e1454714548.stack[R.EXN_STACKHEIGHT++] = $ss1455114552;
}
if(R.isPyretException($e1454714548)) {
$e1454714548.pyretStack.push(L[1566]);
}
throw $e1454714548;
}
var $ret1455314554 = $Hanf_arg310214558($z1454914550,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26);
++R.GAS;
return $ret1455314554;
};
var $Hanf_arg310214558 = function(anf_arg69214557,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26) {
var anf_bracket69314572 = G(self3286177,"helper",L[1569]);
var anf_fun69414569 = G(anf_bracket69314572,"tosource",L[1568]);
var $z1456114562 = D;
var $f1456714568 = function(_) {
return R.isFunction(anf_fun69414569)?anf_fun69414569.app():R.ffi.throwNonFunApp(L[1567],anf_fun69414569,[]);
};
try {
if(--R.GAS > 0) {
$z1456114562 = $f1456714568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1456714568,
"from":L[1567]});
}
} catch($e1455914560) {
if(R.isCont($e1455914560)) {
var $ss1456314564 = {"from":L[1567],
"go":function(anf_arg69514570) {
return $Hanf_arg310114571(anf_arg69514570,INDENT9187,PP337,anf_arg68714530,anf_arg69214557,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26);
}};
$e1455914560.stack[R.EXN_STACKHEIGHT++] = $ss1456314564;
}
if(R.isPyretException($e1455914560)) {
$e1455914560.pyretStack.push(L[1567]);
}
throw $e1455914560;
}
var $ret1456514566 = $Hanf_arg310114571($z1456114562,INDENT9187,PP337,anf_arg68714530,anf_arg69214557,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26);
++R.GAS;
return $ret1456514566;
};
var $Hanf_arg310114571 = function(anf_arg69514570,INDENT9187,PP337,anf_arg68714530,anf_arg69214557,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26) {
var $z1457514576 = D;
var $f1458114582 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg69214557,anf_arg69514570):R.ffi.throwNonFunApp(L[1566],_plus26,[anf_arg69214557,anf_arg69514570]);
};
try {
if(--R.GAS > 0) {
$z1457514576 = $f1458114582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1458114582,
"from":L[1566]});
}
} catch($e1457314574) {
if(R.isCont($e1457314574)) {
var $ss1457714578 = {"from":L[1566],
"go":function(anf_arg69614583) {
return $Hanf_arg310014584(anf_arg69614583,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26);
}};
$e1457314574.stack[R.EXN_STACKHEIGHT++] = $ss1457714578;
}
if(R.isPyretException($e1457314574)) {
$e1457314574.pyretStack.push(L[1566]);
}
throw $e1457314574;
}
var $ret1457914580 = $Hanf_arg310014584($z1457514576,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26);
++R.GAS;
return $ret1457914580;
};
var $Hanf_arg310014584 = function(anf_arg69614583,INDENT9187,PP337,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,self3286177,_plus26) {
var anf_fun69714599 = G(PP337,"parens",L[1578]);
var anf_fun69814600 = G(PP337,"nest",L[1577]);
var anf_fun69914601 = G(PP337,"separate",L[1576]);
var anf_arg70014598 = G(PP337,"commabreak",L[1575]);
var anf_bracket70114617 = G(self3286177,"helper-args",L[1574]);
var anf_fun70214595 = G(anf_bracket70114617,"map",L[1573]);
var anf_arg70514596 = R.makeFunction(function(f33014603) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1571],1,arguments);
}
var anf_fun70414614 = G(f33014603,"tosource",L[1572]);
var $z1460614607 = D;
var $f1461214613 = function(_) {
return R.isFunction(anf_fun70414614)?anf_fun70414614.app():R.ffi.throwNonFunApp(L[1571],anf_fun70414614,[]);
};
try {
if(--R.GAS > 0) {
$z1460614607 = $f1461214613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1461214613,
"from":L[1571]});
}
} catch($e1460414605) {
if(R.isCont($e1460414605)) {
var $ss1460814609 = {"from":L[1571],
"go":function(ann_DASH_check_DASH_temp70314615) {
return $Hann_DASH_check_DASH_temp309014616(ann_DASH_check_DASH_temp70314615);
}};
$e1460414605.stack[R.EXN_STACKHEIGHT++] = $ss1460814609;
}
if(R.isPyretException($e1460414605)) {
$e1460414605.pyretStack.push(L[1571]);
}
throw $e1460414605;
}
var $ret1461014611 = $Hann_DASH_check_DASH_temp309014616($z1460614607);
++R.GAS;
return $ret1461014611;
});
var $z1458714588 = D;
var $f1459314594 = function(_) {
return R.isFunction(anf_fun70214595)?anf_fun70214595.app(anf_arg70514596):R.ffi.throwNonFunApp(L[1570],anf_fun70214595,[anf_arg70514596]);
};
try {
if(--R.GAS > 0) {
$z1458714588 = $f1459314594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1459314594,
"from":L[1570]});
}
} catch($e1458514586) {
if(R.isCont($e1458514586)) {
var $ss1458914590 = {"from":L[1570],
"go":function(anf_arg70614597) {
return $Hanf_arg309914602(anf_arg70614597,INDENT9187,anf_arg68714530,anf_arg69614583,anf_arg70014598,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,anf_fun69814600,anf_fun69914601,_plus26);
}};
$e1458514586.stack[R.EXN_STACKHEIGHT++] = $ss1458914590;
}
if(R.isPyretException($e1458514586)) {
$e1458514586.pyretStack.push(L[1570]);
}
throw $e1458514586;
}
var $ret1459114592 = $Hanf_arg309914602($z1458714588,INDENT9187,anf_arg68714530,anf_arg69614583,anf_arg70014598,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,anf_fun69814600,anf_fun69914601,_plus26);
++R.GAS;
return $ret1459114592;
};
var $Hanf_arg309914602 = function(anf_arg70614597,INDENT9187,anf_arg68714530,anf_arg69614583,anf_arg70014598,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,anf_fun69814600,anf_fun69914601,_plus26) {
var $z1462014621 = D;
var $f1462614627 = function(_) {
return R.isFunction(anf_fun69914601)?anf_fun69914601.app(anf_arg70014598,anf_arg70614597):R.ffi.throwNonFunApp(L[1579],anf_fun69914601,[anf_arg70014598,anf_arg70614597]);
};
try {
if(--R.GAS > 0) {
$z1462014621 = $f1462614627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1462614627,
"from":L[1579]});
}
} catch($e1461814619) {
if(R.isCont($e1461814619)) {
var $ss1462214623 = {"from":L[1579],
"go":function(anf_arg70714628) {
return $Hanf_arg309814629(anf_arg70714628,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,anf_fun69814600,_plus26);
}};
$e1461814619.stack[R.EXN_STACKHEIGHT++] = $ss1462214623;
}
if(R.isPyretException($e1461814619)) {
$e1461814619.pyretStack.push(L[1579]);
}
throw $e1461814619;
}
var $ret1462414625 = $Hanf_arg309814629($z1462014621,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,anf_fun69814600,_plus26);
++R.GAS;
return $ret1462414625;
};
var $Hanf_arg309814629 = function(anf_arg70714628,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,anf_fun69814600,_plus26) {
var $z1463214633 = D;
var $f1463814639 = function(_) {
return R.isFunction(anf_fun69814600)?anf_fun69814600.app(INDENT9187,anf_arg70714628):R.ffi.throwNonFunApp(L[1580],anf_fun69814600,[INDENT9187,anf_arg70714628]);
};
try {
if(--R.GAS > 0) {
$z1463214633 = $f1463814639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1463814639,
"from":L[1580]});
}
} catch($e1463014631) {
if(R.isCont($e1463014631)) {
var $ss1463414635 = {"from":L[1580],
"go":function(anf_arg70814640) {
return $Hanf_arg309714641(anf_arg70814640,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,_plus26);
}};
$e1463014631.stack[R.EXN_STACKHEIGHT++] = $ss1463414635;
}
if(R.isPyretException($e1463014631)) {
$e1463014631.pyretStack.push(L[1580]);
}
throw $e1463014631;
}
var $ret1463614637 = $Hanf_arg309714641($z1463214633,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,_plus26);
++R.GAS;
return $ret1463614637;
};
var $Hanf_arg309714641 = function(anf_arg70814640,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,anf_fun69714599,_plus26) {
var $z1464414645 = D;
var $f1465014651 = function(_) {
return R.isFunction(anf_fun69714599)?anf_fun69714599.app(anf_arg70814640):R.ffi.throwNonFunApp(L[1581],anf_fun69714599,[anf_arg70814640]);
};
try {
if(--R.GAS > 0) {
$z1464414645 = $f1465014651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1465014651,
"from":L[1581]});
}
} catch($e1464214643) {
if(R.isCont($e1464214643)) {
var $ss1464614647 = {"from":L[1581],
"go":function(anf_arg70914652) {
return $Hanf_arg309614653(anf_arg70914652,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,_plus26);
}};
$e1464214643.stack[R.EXN_STACKHEIGHT++] = $ss1464614647;
}
if(R.isPyretException($e1464214643)) {
$e1464214643.pyretStack.push(L[1581]);
}
throw $e1464214643;
}
var $ret1464814649 = $Hanf_arg309614653($z1464414645,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,_plus26);
++R.GAS;
return $ret1464814649;
};
var $Hanf_arg309614653 = function(anf_arg70914652,INDENT9187,anf_arg68714530,anf_arg69614583,anf_fun6526174,anf_fun68814544,anf_fun68914545,_plus26) {
var $z1465614657 = D;
var $f1466214663 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg69614583,anf_arg70914652):R.ffi.throwNonFunApp(L[1566],_plus26,[anf_arg69614583,anf_arg70914652]);
};
try {
if(--R.GAS > 0) {
$z1465614657 = $f1466214663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1466214663,
"from":L[1566]});
}
} catch($e1465414655) {
if(R.isCont($e1465414655)) {
var $ss1465814659 = {"from":L[1566],
"go":function(anf_arg71014664) {
return $Hanf_arg309514665(anf_arg71014664,INDENT9187,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,_plus26);
}};
$e1465414655.stack[R.EXN_STACKHEIGHT++] = $ss1465814659;
}
if(R.isPyretException($e1465414655)) {
$e1465414655.pyretStack.push(L[1566]);
}
throw $e1465414655;
}
var $ret1466014661 = $Hanf_arg309514665($z1465614657,INDENT9187,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,_plus26);
++R.GAS;
return $ret1466014661;
};
var $Hanf_arg309514665 = function(anf_arg71014664,INDENT9187,anf_arg68714530,anf_fun6526174,anf_fun68814544,anf_fun68914545,_plus26) {
var $z1466814669 = D;
var $f1467414675 = function(_) {
return R.isFunction(anf_fun68914545)?anf_fun68914545.app(INDENT9187,anf_arg71014664):R.ffi.throwNonFunApp(L[1582],anf_fun68914545,[INDENT9187,anf_arg71014664]);
};
try {
if(--R.GAS > 0) {
$z1466814669 = $f1467414675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1467414675,
"from":L[1582]});
}
} catch($e1466614667) {
if(R.isCont($e1466614667)) {
var $ss1467014671 = {"from":L[1582],
"go":function(anf_arg71114676) {
return $Hanf_arg309414677(anf_arg71114676,anf_arg68714530,anf_fun6526174,anf_fun68814544,_plus26);
}};
$e1466614667.stack[R.EXN_STACKHEIGHT++] = $ss1467014671;
}
if(R.isPyretException($e1466614667)) {
$e1466614667.pyretStack.push(L[1582]);
}
throw $e1466614667;
}
var $ret1467214673 = $Hanf_arg309414677($z1466814669,anf_arg68714530,anf_fun6526174,anf_fun68814544,_plus26);
++R.GAS;
return $ret1467214673;
};
var $Hanf_arg309414677 = function(anf_arg71114676,anf_arg68714530,anf_fun6526174,anf_fun68814544,_plus26) {
var $z1468014681 = D;
var $f1468614687 = function(_) {
return R.isFunction(anf_fun68814544)?anf_fun68814544.app(anf_arg71114676):R.ffi.throwNonFunApp(L[1583],anf_fun68814544,[anf_arg71114676]);
};
try {
if(--R.GAS > 0) {
$z1468014681 = $f1468614687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1468614687,
"from":L[1583]});
}
} catch($e1467814679) {
if(R.isCont($e1467814679)) {
var $ss1468214683 = {"from":L[1583],
"go":function(anf_arg71214688) {
return $Hanf_arg309314689(anf_arg71214688,anf_arg68714530,anf_fun6526174,_plus26);
}};
$e1467814679.stack[R.EXN_STACKHEIGHT++] = $ss1468214683;
}
if(R.isPyretException($e1467814679)) {
$e1467814679.pyretStack.push(L[1583]);
}
throw $e1467814679;
}
var $ret1468414685 = $Hanf_arg309314689($z1468014681,anf_arg68714530,anf_fun6526174,_plus26);
++R.GAS;
return $ret1468414685;
};
var $Hanf_arg309314689 = function(anf_arg71214688,anf_arg68714530,anf_fun6526174,_plus26) {
var $z1469214693 = D;
var $f1469814699 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg68714530,anf_arg71214688):R.ffi.throwNonFunApp(L[1561],_plus26,[anf_arg68714530,anf_arg71214688]);
};
try {
if(--R.GAS > 0) {
$z1469214693 = $f1469814699();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1469814699,
"from":L[1561]});
}
} catch($e1469014691) {
if(R.isCont($e1469014691)) {
var $ss1469414695 = {"from":L[1561],
"go":function(anf_arg71314700) {
return $Hanf_arg309214701(anf_arg71314700,anf_fun6526174);
}};
$e1469014691.stack[R.EXN_STACKHEIGHT++] = $ss1469414695;
}
if(R.isPyretException($e1469014691)) {
$e1469014691.pyretStack.push(L[1561]);
}
throw $e1469014691;
}
var $ret1469614697 = $Hanf_arg309214701($z1469214693,anf_fun6526174);
++R.GAS;
return $ret1469614697;
};
var $Hanf_arg309214701 = function(anf_arg71314700,anf_fun6526174) {
var $z1470414705 = D;
var $f1471014711 = function(_) {
return R.isFunction(anf_fun6526174)?anf_fun6526174.app(anf_arg71314700):R.ffi.throwNonFunApp(L[998],anf_fun6526174,[anf_arg71314700]);
};
try {
if(--R.GAS > 0) {
$z1470414705 = $f1471014711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1471014711,
"from":L[998]});
}
} catch($e1470214703) {
if(R.isCont($e1470214703)) {
var $ss1470614707 = {"from":L[998],
"go":function(ann_DASH_check_DASH_temp65114712) {
return $Hann_DASH_check_DASH_temp309114713(ann_DASH_check_DASH_temp65114712);
}};
$e1470214703.stack[R.EXN_STACKHEIGHT++] = $ss1470614707;
}
if(R.isPyretException($e1470214703)) {
$e1470214703.pyretStack.push(L[998]);
}
throw $e1470214703;
}
var $ret1470814709 = $Hann_DASH_check_DASH_temp309114713($z1470414705);
++R.GAS;
return $ret1470814709;
};
var $Hann_DASH_check_DASH_temp309114713 = function(ann_DASH_check_DASH_temp65114712) {
return ann_DASH_check_DASH_temp65114712;
};
var $Hann_DASH_check_DASH_temp309014616 = function(ann_DASH_check_DASH_temp70314615) {
return ann_DASH_check_DASH_temp70314615;
};
var $Hann_DASH_check_DASH_temp308914422 = function(ann_DASH_check_DASH_temp67514421) {
return ann_DASH_check_DASH_temp67514421;
};
var $Hanf_arg30886194 = function(anf_arg6256192,self776193,_plus26,torepr31) {
var anf_arg62614724 = G(self776193,"is-var",L[936]);
var $z1471614717 = D;
var $f1472214723 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg62614724):R.ffi.throwNonFunApp(L[936],torepr31,[anf_arg62614724]);
};
try {
if(--R.GAS > 0) {
$z1471614717 = $f1472214723();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1472214723,
"from":L[936]});
}
} catch($e1471414715) {
if(R.isCont($e1471414715)) {
var $ss1471814719 = {"from":L[936],
"go":function(anf_arg62714725) {
return $Hanf_arg308714726(anf_arg62714725,anf_arg6256192,self776193,_plus26,torepr31);
}};
$e1471414715.stack[R.EXN_STACKHEIGHT++] = $ss1471814719;
}
if(R.isPyretException($e1471414715)) {
$e1471414715.pyretStack.push(L[936]);
}
throw $e1471414715;
}
var $ret1472014721 = $Hanf_arg308714726($z1471614717,anf_arg6256192,self776193,_plus26,torepr31);
++R.GAS;
return $ret1472014721;
};
var $Hanf_arg308714726 = function(anf_arg62714725,anf_arg6256192,self776193,_plus26,torepr31) {
var $z1472914730 = D;
var $f1473514736 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg62714725):R.ffi.throwNonFunApp(L[936],_plus26,[(", "),anf_arg62714725]);
};
try {
if(--R.GAS > 0) {
$z1472914730 = $f1473514736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1473514736,
"from":L[936]});
}
} catch($e1472714728) {
if(R.isCont($e1472714728)) {
var $ss1473114732 = {"from":L[936],
"go":function(anf_arg62814737) {
return $Hanf_arg308614738(anf_arg62814737,anf_arg6256192,self776193,_plus26,torepr31);
}};
$e1472714728.stack[R.EXN_STACKHEIGHT++] = $ss1473114732;
}
if(R.isPyretException($e1472714728)) {
$e1472714728.pyretStack.push(L[936]);
}
throw $e1472714728;
}
var $ret1473314734 = $Hanf_arg308614738($z1472914730,anf_arg6256192,self776193,_plus26,torepr31);
++R.GAS;
return $ret1473314734;
};
var $Hanf_arg308614738 = function(anf_arg62814737,anf_arg6256192,self776193,_plus26,torepr31) {
var $z1474114742 = D;
var $f1474714748 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg6256192,anf_arg62814737):R.ffi.throwNonFunApp(L[936],_plus26,[anf_arg6256192,anf_arg62814737]);
};
try {
if(--R.GAS > 0) {
$z1474114742 = $f1474714748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1474714748,
"from":L[936]});
}
} catch($e1473914740) {
if(R.isCont($e1473914740)) {
var $ss1474314744 = {"from":L[936],
"go":function(anf_arg62914749) {
return $Hanf_arg308514750(anf_arg62914749,self776193,_plus26,torepr31);
}};
$e1473914740.stack[R.EXN_STACKHEIGHT++] = $ss1474314744;
}
if(R.isPyretException($e1473914740)) {
$e1473914740.pyretStack.push(L[936]);
}
throw $e1473914740;
}
var $ret1474514746 = $Hanf_arg308514750($z1474114742,self776193,_plus26,torepr31);
++R.GAS;
return $ret1474514746;
};
var $Hanf_arg308514750 = function(anf_arg62914749,self776193,_plus26,torepr31) {
var anf_arg63014761 = G(self776193,"f",L[936]);
var $z1475314754 = D;
var $f1475914760 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg63014761):R.ffi.throwNonFunApp(L[936],torepr31,[anf_arg63014761]);
};
try {
if(--R.GAS > 0) {
$z1475314754 = $f1475914760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1475914760,
"from":L[936]});
}
} catch($e1475114752) {
if(R.isCont($e1475114752)) {
var $ss1475514756 = {"from":L[936],
"go":function(anf_arg63114762) {
return $Hanf_arg308414763(anf_arg63114762,anf_arg62914749,self776193,_plus26,torepr31);
}};
$e1475114752.stack[R.EXN_STACKHEIGHT++] = $ss1475514756;
}
if(R.isPyretException($e1475114752)) {
$e1475114752.pyretStack.push(L[936]);
}
throw $e1475114752;
}
var $ret1475714758 = $Hanf_arg308414763($z1475314754,anf_arg62914749,self776193,_plus26,torepr31);
++R.GAS;
return $ret1475714758;
};
var $Hanf_arg308414763 = function(anf_arg63114762,anf_arg62914749,self776193,_plus26,torepr31) {
var $z1476614767 = D;
var $f1477214773 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg63114762):R.ffi.throwNonFunApp(L[936],_plus26,[(", "),anf_arg63114762]);
};
try {
if(--R.GAS > 0) {
$z1476614767 = $f1477214773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1477214773,
"from":L[936]});
}
} catch($e1476414765) {
if(R.isCont($e1476414765)) {
var $ss1476814769 = {"from":L[936],
"go":function(anf_arg63214774) {
return $Hanf_arg308314775(anf_arg63214774,anf_arg62914749,self776193,_plus26,torepr31);
}};
$e1476414765.stack[R.EXN_STACKHEIGHT++] = $ss1476814769;
}
if(R.isPyretException($e1476414765)) {
$e1476414765.pyretStack.push(L[936]);
}
throw $e1476414765;
}
var $ret1477014771 = $Hanf_arg308314775($z1476614767,anf_arg62914749,self776193,_plus26,torepr31);
++R.GAS;
return $ret1477014771;
};
var $Hanf_arg308314775 = function(anf_arg63214774,anf_arg62914749,self776193,_plus26,torepr31) {
var $z1477814779 = D;
var $f1478414785 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg62914749,anf_arg63214774):R.ffi.throwNonFunApp(L[936],_plus26,[anf_arg62914749,anf_arg63214774]);
};
try {
if(--R.GAS > 0) {
$z1477814779 = $f1478414785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1478414785,
"from":L[936]});
}
} catch($e1477614777) {
if(R.isCont($e1477614777)) {
var $ss1478014781 = {"from":L[936],
"go":function(anf_arg63314786) {
return $Hanf_arg308214787(anf_arg63314786,self776193,_plus26,torepr31);
}};
$e1477614777.stack[R.EXN_STACKHEIGHT++] = $ss1478014781;
}
if(R.isPyretException($e1477614777)) {
$e1477614777.pyretStack.push(L[936]);
}
throw $e1477614777;
}
var $ret1478214783 = $Hanf_arg308214787($z1477814779,self776193,_plus26,torepr31);
++R.GAS;
return $ret1478214783;
};
var $Hanf_arg308214787 = function(anf_arg63314786,self776193,_plus26,torepr31) {
var anf_arg63414798 = G(self776193,"args",L[936]);
var $z1479014791 = D;
var $f1479614797 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg63414798):R.ffi.throwNonFunApp(L[936],torepr31,[anf_arg63414798]);
};
try {
if(--R.GAS > 0) {
$z1479014791 = $f1479614797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1479614797,
"from":L[936]});
}
} catch($e1478814789) {
if(R.isCont($e1478814789)) {
var $ss1479214793 = {"from":L[936],
"go":function(anf_arg63514799) {
return $Hanf_arg308114800(anf_arg63514799,anf_arg63314786,self776193,_plus26,torepr31);
}};
$e1478814789.stack[R.EXN_STACKHEIGHT++] = $ss1479214793;
}
if(R.isPyretException($e1478814789)) {
$e1478814789.pyretStack.push(L[936]);
}
throw $e1478814789;
}
var $ret1479414795 = $Hanf_arg308114800($z1479014791,anf_arg63314786,self776193,_plus26,torepr31);
++R.GAS;
return $ret1479414795;
};
var $Hanf_arg308114800 = function(anf_arg63514799,anf_arg63314786,self776193,_plus26,torepr31) {
var $z1480314804 = D;
var $f1480914810 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg63514799):R.ffi.throwNonFunApp(L[936],_plus26,[(", "),anf_arg63514799]);
};
try {
if(--R.GAS > 0) {
$z1480314804 = $f1480914810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1480914810,
"from":L[936]});
}
} catch($e1480114802) {
if(R.isCont($e1480114802)) {
var $ss1480514806 = {"from":L[936],
"go":function(anf_arg63614811) {
return $Hanf_arg308014812(anf_arg63614811,anf_arg63314786,self776193,_plus26,torepr31);
}};
$e1480114802.stack[R.EXN_STACKHEIGHT++] = $ss1480514806;
}
if(R.isPyretException($e1480114802)) {
$e1480114802.pyretStack.push(L[936]);
}
throw $e1480114802;
}
var $ret1480714808 = $Hanf_arg308014812($z1480314804,anf_arg63314786,self776193,_plus26,torepr31);
++R.GAS;
return $ret1480714808;
};
var $Hanf_arg308014812 = function(anf_arg63614811,anf_arg63314786,self776193,_plus26,torepr31) {
var $z1481514816 = D;
var $f1482114822 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg63314786,anf_arg63614811):R.ffi.throwNonFunApp(L[936],_plus26,[anf_arg63314786,anf_arg63614811]);
};
try {
if(--R.GAS > 0) {
$z1481514816 = $f1482114822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1482114822,
"from":L[936]});
}
} catch($e1481314814) {
if(R.isCont($e1481314814)) {
var $ss1481714818 = {"from":L[936],
"go":function(anf_arg63714823) {
return $Hanf_arg307914824(anf_arg63714823,self776193,_plus26,torepr31);
}};
$e1481314814.stack[R.EXN_STACKHEIGHT++] = $ss1481714818;
}
if(R.isPyretException($e1481314814)) {
$e1481314814.pyretStack.push(L[936]);
}
throw $e1481314814;
}
var $ret1481914820 = $Hanf_arg307914824($z1481514816,self776193,_plus26,torepr31);
++R.GAS;
return $ret1481914820;
};
var $Hanf_arg307914824 = function(anf_arg63714823,self776193,_plus26,torepr31) {
var anf_arg63814835 = G(self776193,"helper",L[936]);
var $z1482714828 = D;
var $f1483314834 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg63814835):R.ffi.throwNonFunApp(L[936],torepr31,[anf_arg63814835]);
};
try {
if(--R.GAS > 0) {
$z1482714828 = $f1483314834();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1483314834,
"from":L[936]});
}
} catch($e1482514826) {
if(R.isCont($e1482514826)) {
var $ss1482914830 = {"from":L[936],
"go":function(anf_arg63914836) {
return $Hanf_arg307814837(anf_arg63914836,anf_arg63714823,self776193,_plus26,torepr31);
}};
$e1482514826.stack[R.EXN_STACKHEIGHT++] = $ss1482914830;
}
if(R.isPyretException($e1482514826)) {
$e1482514826.pyretStack.push(L[936]);
}
throw $e1482514826;
}
var $ret1483114832 = $Hanf_arg307814837($z1482714828,anf_arg63714823,self776193,_plus26,torepr31);
++R.GAS;
return $ret1483114832;
};
var $Hanf_arg307814837 = function(anf_arg63914836,anf_arg63714823,self776193,_plus26,torepr31) {
var $z1484014841 = D;
var $f1484614847 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg63914836):R.ffi.throwNonFunApp(L[936],_plus26,[(", "),anf_arg63914836]);
};
try {
if(--R.GAS > 0) {
$z1484014841 = $f1484614847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1484614847,
"from":L[936]});
}
} catch($e1483814839) {
if(R.isCont($e1483814839)) {
var $ss1484214843 = {"from":L[936],
"go":function(anf_arg64014848) {
return $Hanf_arg307714849(anf_arg64014848,anf_arg63714823,self776193,_plus26,torepr31);
}};
$e1483814839.stack[R.EXN_STACKHEIGHT++] = $ss1484214843;
}
if(R.isPyretException($e1483814839)) {
$e1483814839.pyretStack.push(L[936]);
}
throw $e1483814839;
}
var $ret1484414845 = $Hanf_arg307714849($z1484014841,anf_arg63714823,self776193,_plus26,torepr31);
++R.GAS;
return $ret1484414845;
};
var $Hanf_arg307714849 = function(anf_arg64014848,anf_arg63714823,self776193,_plus26,torepr31) {
var $z1485214853 = D;
var $f1485814859 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg63714823,anf_arg64014848):R.ffi.throwNonFunApp(L[936],_plus26,[anf_arg63714823,anf_arg64014848]);
};
try {
if(--R.GAS > 0) {
$z1485214853 = $f1485814859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1485814859,
"from":L[936]});
}
} catch($e1485014851) {
if(R.isCont($e1485014851)) {
var $ss1485414855 = {"from":L[936],
"go":function(anf_arg64114860) {
return $Hanf_arg307614861(anf_arg64114860,self776193,_plus26,torepr31);
}};
$e1485014851.stack[R.EXN_STACKHEIGHT++] = $ss1485414855;
}
if(R.isPyretException($e1485014851)) {
$e1485014851.pyretStack.push(L[936]);
}
throw $e1485014851;
}
var $ret1485614857 = $Hanf_arg307614861($z1485214853,self776193,_plus26,torepr31);
++R.GAS;
return $ret1485614857;
};
var $Hanf_arg307614861 = function(anf_arg64114860,self776193,_plus26,torepr31) {
var anf_arg64214872 = G(self776193,"helper-args",L[936]);
var $z1486414865 = D;
var $f1487014871 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg64214872):R.ffi.throwNonFunApp(L[936],torepr31,[anf_arg64214872]);
};
try {
if(--R.GAS > 0) {
$z1486414865 = $f1487014871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1487014871,
"from":L[936]});
}
} catch($e1486214863) {
if(R.isCont($e1486214863)) {
var $ss1486614867 = {"from":L[936],
"go":function(anf_arg64314873) {
return $Hanf_arg307514874(anf_arg64314873,anf_arg64114860,_plus26);
}};
$e1486214863.stack[R.EXN_STACKHEIGHT++] = $ss1486614867;
}
if(R.isPyretException($e1486214863)) {
$e1486214863.pyretStack.push(L[936]);
}
throw $e1486214863;
}
var $ret1486814869 = $Hanf_arg307514874($z1486414865,anf_arg64114860,_plus26);
++R.GAS;
return $ret1486814869;
};
var $Hanf_arg307514874 = function(anf_arg64314873,anf_arg64114860,_plus26) {
var $z1487714878 = D;
var $f1488314884 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg64314873):R.ffi.throwNonFunApp(L[936],_plus26,[(", "),anf_arg64314873]);
};
try {
if(--R.GAS > 0) {
$z1487714878 = $f1488314884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1488314884,
"from":L[936]});
}
} catch($e1487514876) {
if(R.isCont($e1487514876)) {
var $ss1487914880 = {"from":L[936],
"go":function(anf_arg64414885) {
return $Hanf_arg307414886(anf_arg64414885,anf_arg64114860,_plus26);
}};
$e1487514876.stack[R.EXN_STACKHEIGHT++] = $ss1487914880;
}
if(R.isPyretException($e1487514876)) {
$e1487514876.pyretStack.push(L[936]);
}
throw $e1487514876;
}
var $ret1488114882 = $Hanf_arg307414886($z1487714878,anf_arg64114860,_plus26);
++R.GAS;
return $ret1488114882;
};
var $Hanf_arg307414886 = function(anf_arg64414885,anf_arg64114860,_plus26) {
var $z1488914890 = D;
var $f1489514896 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg64114860,anf_arg64414885):R.ffi.throwNonFunApp(L[936],_plus26,[anf_arg64114860,anf_arg64414885]);
};
try {
if(--R.GAS > 0) {
$z1488914890 = $f1489514896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1489514896,
"from":L[936]});
}
} catch($e1488714888) {
if(R.isCont($e1488714888)) {
var $ss1489114892 = {"from":L[936],
"go":function(anf_arg64514897) {
return $Hanf_arg307314898(anf_arg64514897,_plus26);
}};
$e1488714888.stack[R.EXN_STACKHEIGHT++] = $ss1489114892;
}
if(R.isPyretException($e1488714888)) {
$e1488714888.pyretStack.push(L[936]);
}
throw $e1488714888;
}
var $ret1489314894 = $Hanf_arg307314898($z1488914890,_plus26);
++R.GAS;
return $ret1489314894;
};
var $Hanf_arg307314898 = function(anf_arg64514897,_plus26) {
var $z1490114902 = D;
var $f1490714908 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg64514897,(")")):R.ffi.throwNonFunApp(L[936],_plus26,[anf_arg64514897,(")")]);
};
try {
if(--R.GAS > 0) {
$z1490114902 = $f1490714908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1490714908,
"from":L[936]});
}
} catch($e1489914900) {
if(R.isCont($e1489914900)) {
var $ss1490314904 = {"from":L[936],
"go":function(anf_arg64614909) {
return $Hanf_arg307214910(anf_arg64614909,_plus26);
}};
$e1489914900.stack[R.EXN_STACKHEIGHT++] = $ss1490314904;
}
if(R.isPyretException($e1489914900)) {
$e1489914900.pyretStack.push(L[936]);
}
throw $e1489914900;
}
var $ret1490514906 = $Hanf_arg307214910($z1490114902,_plus26);
++R.GAS;
return $ret1490514906;
};
var $Hanf_arg307214910 = function(anf_arg64614909,_plus26) {
var $z1491314914 = D;
var $f1491914920 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg64614909):R.ffi.throwNonFunApp(L[936],_plus26,[("("),anf_arg64614909]);
};
try {
if(--R.GAS > 0) {
$z1491314914 = $f1491914920();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1491914920,
"from":L[936]});
}
} catch($e1491114912) {
if(R.isCont($e1491114912)) {
var $ss1491514916 = {"from":L[936],
"go":function(anf_arg64714921) {
return $Hanf_arg307114922(anf_arg64714921,_plus26);
}};
$e1491114912.stack[R.EXN_STACKHEIGHT++] = $ss1491514916;
}
if(R.isPyretException($e1491114912)) {
$e1491114912.pyretStack.push(L[936]);
}
throw $e1491114912;
}
var $ret1491714918 = $Hanf_arg307114922($z1491314914,_plus26);
++R.GAS;
return $ret1491714918;
};
var $Hanf_arg307114922 = function(anf_arg64714921,_plus26) {
var $z1492514926 = D;
var $f1493114932 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-split-app"),anf_arg64714921):R.ffi.throwNonFunApp(L[936],_plus26,[("a-split-app"),anf_arg64714921]);
};
try {
if(--R.GAS > 0) {
$z1492514926 = $f1493114932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1493114932,
"from":L[936]});
}
} catch($e1492314924) {
if(R.isCont($e1492314924)) {
var $ss1492714928 = {"from":L[936],
"go":function(ann_DASH_check_DASH_temp62314933) {
return $Hann_DASH_check_DASH_temp307014934(ann_DASH_check_DASH_temp62314933);
}};
$e1492314924.stack[R.EXN_STACKHEIGHT++] = $ss1492714928;
}
if(R.isPyretException($e1492314924)) {
$e1492314924.pyretStack.push(L[936]);
}
throw $e1492314924;
}
var $ret1492914930 = $Hann_DASH_check_DASH_temp307014934($z1492514926);
++R.GAS;
return $ret1492914930;
};
var $Hann_DASH_check_DASH_temp307014934 = function(ann_DASH_check_DASH_temp62314933) {
return ann_DASH_check_DASH_temp62314933;
};
var $Hcont_tail_arg30686214 = function(cont_tail_arg6206212,if_helper6076213) {
if(--R.GAS > 0) {
$z1493514936 = R.isFunction(if_helper6076213)?if_helper6076213.app(cont_tail_arg6206212):R.ffi.throwNonFunApp(L[936],if_helper6076213,[cont_tail_arg6206212]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper6076213)?if_helper6076213.app(cont_tail_arg6206212):R.ffi.throwNonFunApp(L[936],if_helper6076213,[cont_tail_arg6206212]);
},
"from":L[936]});
}
++R.GAS;
return $z1493514936;
};
var $Hcont_tail_arg30696229 = function(cont_tail_arg6126228,if_helper6076213) {
if(--R.GAS > 0) {
$z1493714938 = R.isFunction(if_helper6076213)?if_helper6076213.app(cont_tail_arg6126228):R.ffi.throwNonFunApp(L[936],if_helper6076213,[cont_tail_arg6126228]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper6076213)?if_helper6076213.app(cont_tail_arg6126228):R.ffi.throwNonFunApp(L[936],if_helper6076213,[cont_tail_arg6126228]);
},
"from":L[936]});
}
++R.GAS;
return $z1493714938;
};
var $Hanf_arg30676251 = function(anf_arg5906248,INDENT9187,PP337,anf_fun5876249,self3196250,_plus26) {
var anf_fun59114953 = G(PP337,"parens",L[1592]);
var anf_fun59214954 = G(PP337,"nest",L[1591]);
var anf_fun59314955 = G(PP337,"separate",L[1590]);
var anf_arg59414952 = G(PP337,"commabreak",L[1589]);
var anf_bracket59514971 = G(self3196250,"args",L[1588]);
var anf_fun59614949 = G(anf_bracket59514971,"map",L[1587]);
var anf_arg59914950 = R.makeFunction(function(f32014957) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1585],1,arguments);
}
var anf_fun59814968 = G(f32014957,"tosource",L[1586]);
var $z1496014961 = D;
var $f1496614967 = function(_) {
return R.isFunction(anf_fun59814968)?anf_fun59814968.app():R.ffi.throwNonFunApp(L[1585],anf_fun59814968,[]);
};
try {
if(--R.GAS > 0) {
$z1496014961 = $f1496614967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1496614967,
"from":L[1585]});
}
} catch($e1495814959) {
if(R.isCont($e1495814959)) {
var $ss1496214963 = {"from":L[1585],
"go":function(ann_DASH_check_DASH_temp59714969) {
return $Hann_DASH_check_DASH_temp306014970(ann_DASH_check_DASH_temp59714969);
}};
$e1495814959.stack[R.EXN_STACKHEIGHT++] = $ss1496214963;
}
if(R.isPyretException($e1495814959)) {
$e1495814959.pyretStack.push(L[1585]);
}
throw $e1495814959;
}
var $ret1496414965 = $Hann_DASH_check_DASH_temp306014970($z1496014961);
++R.GAS;
return $ret1496414965;
});
var $z1494114942 = D;
var $f1494714948 = function(_) {
return R.isFunction(anf_fun59614949)?anf_fun59614949.app(anf_arg59914950):R.ffi.throwNonFunApp(L[1584],anf_fun59614949,[anf_arg59914950]);
};
try {
if(--R.GAS > 0) {
$z1494114942 = $f1494714948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1494714948,
"from":L[1584]});
}
} catch($e1493914940) {
if(R.isCont($e1493914940)) {
var $ss1494314944 = {"from":L[1584],
"go":function(anf_arg60014951) {
return $Hanf_arg306614956(anf_arg60014951,INDENT9187,anf_arg5906248,anf_arg59414952,anf_fun5876249,anf_fun59114953,anf_fun59214954,anf_fun59314955,_plus26);
}};
$e1493914940.stack[R.EXN_STACKHEIGHT++] = $ss1494314944;
}
if(R.isPyretException($e1493914940)) {
$e1493914940.pyretStack.push(L[1584]);
}
throw $e1493914940;
}
var $ret1494514946 = $Hanf_arg306614956($z1494114942,INDENT9187,anf_arg5906248,anf_arg59414952,anf_fun5876249,anf_fun59114953,anf_fun59214954,anf_fun59314955,_plus26);
++R.GAS;
return $ret1494514946;
};
var $Hanf_arg306614956 = function(anf_arg60014951,INDENT9187,anf_arg5906248,anf_arg59414952,anf_fun5876249,anf_fun59114953,anf_fun59214954,anf_fun59314955,_plus26) {
var $z1497414975 = D;
var $f1498014981 = function(_) {
return R.isFunction(anf_fun59314955)?anf_fun59314955.app(anf_arg59414952,anf_arg60014951):R.ffi.throwNonFunApp(L[1593],anf_fun59314955,[anf_arg59414952,anf_arg60014951]);
};
try {
if(--R.GAS > 0) {
$z1497414975 = $f1498014981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1498014981,
"from":L[1593]});
}
} catch($e1497214973) {
if(R.isCont($e1497214973)) {
var $ss1497614977 = {"from":L[1593],
"go":function(anf_arg60114982) {
return $Hanf_arg306514983(anf_arg60114982,INDENT9187,anf_arg5906248,anf_fun5876249,anf_fun59114953,anf_fun59214954,_plus26);
}};
$e1497214973.stack[R.EXN_STACKHEIGHT++] = $ss1497614977;
}
if(R.isPyretException($e1497214973)) {
$e1497214973.pyretStack.push(L[1593]);
}
throw $e1497214973;
}
var $ret1497814979 = $Hanf_arg306514983($z1497414975,INDENT9187,anf_arg5906248,anf_fun5876249,anf_fun59114953,anf_fun59214954,_plus26);
++R.GAS;
return $ret1497814979;
};
var $Hanf_arg306514983 = function(anf_arg60114982,INDENT9187,anf_arg5906248,anf_fun5876249,anf_fun59114953,anf_fun59214954,_plus26) {
var $z1498614987 = D;
var $f1499214993 = function(_) {
return R.isFunction(anf_fun59214954)?anf_fun59214954.app(INDENT9187,anf_arg60114982):R.ffi.throwNonFunApp(L[1594],anf_fun59214954,[INDENT9187,anf_arg60114982]);
};
try {
if(--R.GAS > 0) {
$z1498614987 = $f1499214993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1499214993,
"from":L[1594]});
}
} catch($e1498414985) {
if(R.isCont($e1498414985)) {
var $ss1498814989 = {"from":L[1594],
"go":function(anf_arg60214994) {
return $Hanf_arg306414995(anf_arg60214994,anf_arg5906248,anf_fun5876249,anf_fun59114953,_plus26);
}};
$e1498414985.stack[R.EXN_STACKHEIGHT++] = $ss1498814989;
}
if(R.isPyretException($e1498414985)) {
$e1498414985.pyretStack.push(L[1594]);
}
throw $e1498414985;
}
var $ret1499014991 = $Hanf_arg306414995($z1498614987,anf_arg5906248,anf_fun5876249,anf_fun59114953,_plus26);
++R.GAS;
return $ret1499014991;
};
var $Hanf_arg306414995 = function(anf_arg60214994,anf_arg5906248,anf_fun5876249,anf_fun59114953,_plus26) {
var $z1499814999 = D;
var $f1500415005 = function(_) {
return R.isFunction(anf_fun59114953)?anf_fun59114953.app(anf_arg60214994):R.ffi.throwNonFunApp(L[1595],anf_fun59114953,[anf_arg60214994]);
};
try {
if(--R.GAS > 0) {
$z1499814999 = $f1500415005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1500415005,
"from":L[1595]});
}
} catch($e1499614997) {
if(R.isCont($e1499614997)) {
var $ss1500015001 = {"from":L[1595],
"go":function(anf_arg60315006) {
return $Hanf_arg306315007(anf_arg60315006,anf_arg5906248,anf_fun5876249,_plus26);
}};
$e1499614997.stack[R.EXN_STACKHEIGHT++] = $ss1500015001;
}
if(R.isPyretException($e1499614997)) {
$e1499614997.pyretStack.push(L[1595]);
}
throw $e1499614997;
}
var $ret1500215003 = $Hanf_arg306315007($z1499814999,anf_arg5906248,anf_fun5876249,_plus26);
++R.GAS;
return $ret1500215003;
};
var $Hanf_arg306315007 = function(anf_arg60315006,anf_arg5906248,anf_fun5876249,_plus26) {
var $z1501015011 = D;
var $f1501615017 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg5906248,anf_arg60315006):R.ffi.throwNonFunApp(L[1596],_plus26,[anf_arg5906248,anf_arg60315006]);
};
try {
if(--R.GAS > 0) {
$z1501015011 = $f1501615017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1501615017,
"from":L[1596]});
}
} catch($e1500815009) {
if(R.isCont($e1500815009)) {
var $ss1501215013 = {"from":L[1596],
"go":function(anf_arg60415018) {
return $Hanf_arg306215019(anf_arg60415018,anf_fun5876249);
}};
$e1500815009.stack[R.EXN_STACKHEIGHT++] = $ss1501215013;
}
if(R.isPyretException($e1500815009)) {
$e1500815009.pyretStack.push(L[1596]);
}
throw $e1500815009;
}
var $ret1501415015 = $Hanf_arg306215019($z1501015011,anf_fun5876249);
++R.GAS;
return $ret1501415015;
};
var $Hanf_arg306215019 = function(anf_arg60415018,anf_fun5876249) {
var $z1502215023 = D;
var $f1502815029 = function(_) {
return R.isFunction(anf_fun5876249)?anf_fun5876249.app(anf_arg60415018):R.ffi.throwNonFunApp(L[1010],anf_fun5876249,[anf_arg60415018]);
};
try {
if(--R.GAS > 0) {
$z1502215023 = $f1502815029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1502815029,
"from":L[1010]});
}
} catch($e1502015021) {
if(R.isCont($e1502015021)) {
var $ss1502415025 = {"from":L[1010],
"go":function(ann_DASH_check_DASH_temp58615030) {
return $Hann_DASH_check_DASH_temp306115031(ann_DASH_check_DASH_temp58615030);
}};
$e1502015021.stack[R.EXN_STACKHEIGHT++] = $ss1502415025;
}
if(R.isPyretException($e1502015021)) {
$e1502015021.pyretStack.push(L[1010]);
}
throw $e1502015021;
}
var $ret1502615027 = $Hann_DASH_check_DASH_temp306115031($z1502215023);
++R.GAS;
return $ret1502615027;
};
var $Hann_DASH_check_DASH_temp306115031 = function(ann_DASH_check_DASH_temp58615030) {
return ann_DASH_check_DASH_temp58615030;
};
var $Hann_DASH_check_DASH_temp306014970 = function(ann_DASH_check_DASH_temp59714969) {
return ann_DASH_check_DASH_temp59714969;
};
var $Hanf_arg30596268 = function(anf_arg5726266,self716267,_plus26,torepr31) {
var anf_arg57315042 = G(self716267,"f",L[937]);
var $z1503415035 = D;
var $f1504015041 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg57315042):R.ffi.throwNonFunApp(L[937],torepr31,[anf_arg57315042]);
};
try {
if(--R.GAS > 0) {
$z1503415035 = $f1504015041();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1504015041,
"from":L[937]});
}
} catch($e1503215033) {
if(R.isCont($e1503215033)) {
var $ss1503615037 = {"from":L[937],
"go":function(anf_arg57415043) {
return $Hanf_arg305815044(anf_arg57415043,anf_arg5726266,self716267,_plus26,torepr31);
}};
$e1503215033.stack[R.EXN_STACKHEIGHT++] = $ss1503615037;
}
if(R.isPyretException($e1503215033)) {
$e1503215033.pyretStack.push(L[937]);
}
throw $e1503215033;
}
var $ret1503815039 = $Hanf_arg305815044($z1503415035,anf_arg5726266,self716267,_plus26,torepr31);
++R.GAS;
return $ret1503815039;
};
var $Hanf_arg305815044 = function(anf_arg57415043,anf_arg5726266,self716267,_plus26,torepr31) {
var $z1504715048 = D;
var $f1505315054 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg57415043):R.ffi.throwNonFunApp(L[937],_plus26,[(", "),anf_arg57415043]);
};
try {
if(--R.GAS > 0) {
$z1504715048 = $f1505315054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1505315054,
"from":L[937]});
}
} catch($e1504515046) {
if(R.isCont($e1504515046)) {
var $ss1504915050 = {"from":L[937],
"go":function(anf_arg57515055) {
return $Hanf_arg305715056(anf_arg57515055,anf_arg5726266,self716267,_plus26,torepr31);
}};
$e1504515046.stack[R.EXN_STACKHEIGHT++] = $ss1504915050;
}
if(R.isPyretException($e1504515046)) {
$e1504515046.pyretStack.push(L[937]);
}
throw $e1504515046;
}
var $ret1505115052 = $Hanf_arg305715056($z1504715048,anf_arg5726266,self716267,_plus26,torepr31);
++R.GAS;
return $ret1505115052;
};
var $Hanf_arg305715056 = function(anf_arg57515055,anf_arg5726266,self716267,_plus26,torepr31) {
var $z1505915060 = D;
var $f1506515066 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg5726266,anf_arg57515055):R.ffi.throwNonFunApp(L[937],_plus26,[anf_arg5726266,anf_arg57515055]);
};
try {
if(--R.GAS > 0) {
$z1505915060 = $f1506515066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1506515066,
"from":L[937]});
}
} catch($e1505715058) {
if(R.isCont($e1505715058)) {
var $ss1506115062 = {"from":L[937],
"go":function(anf_arg57615067) {
return $Hanf_arg305615068(anf_arg57615067,self716267,_plus26,torepr31);
}};
$e1505715058.stack[R.EXN_STACKHEIGHT++] = $ss1506115062;
}
if(R.isPyretException($e1505715058)) {
$e1505715058.pyretStack.push(L[937]);
}
throw $e1505715058;
}
var $ret1506315064 = $Hanf_arg305615068($z1505915060,self716267,_plus26,torepr31);
++R.GAS;
return $ret1506315064;
};
var $Hanf_arg305615068 = function(anf_arg57615067,self716267,_plus26,torepr31) {
var anf_arg57715079 = G(self716267,"args",L[937]);
var $z1507115072 = D;
var $f1507715078 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg57715079):R.ffi.throwNonFunApp(L[937],torepr31,[anf_arg57715079]);
};
try {
if(--R.GAS > 0) {
$z1507115072 = $f1507715078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1507715078,
"from":L[937]});
}
} catch($e1506915070) {
if(R.isCont($e1506915070)) {
var $ss1507315074 = {"from":L[937],
"go":function(anf_arg57815080) {
return $Hanf_arg305515081(anf_arg57815080,anf_arg57615067,_plus26);
}};
$e1506915070.stack[R.EXN_STACKHEIGHT++] = $ss1507315074;
}
if(R.isPyretException($e1506915070)) {
$e1506915070.pyretStack.push(L[937]);
}
throw $e1506915070;
}
var $ret1507515076 = $Hanf_arg305515081($z1507115072,anf_arg57615067,_plus26);
++R.GAS;
return $ret1507515076;
};
var $Hanf_arg305515081 = function(anf_arg57815080,anf_arg57615067,_plus26) {
var $z1508415085 = D;
var $f1509015091 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg57815080):R.ffi.throwNonFunApp(L[937],_plus26,[(", "),anf_arg57815080]);
};
try {
if(--R.GAS > 0) {
$z1508415085 = $f1509015091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1509015091,
"from":L[937]});
}
} catch($e1508215083) {
if(R.isCont($e1508215083)) {
var $ss1508615087 = {"from":L[937],
"go":function(anf_arg57915092) {
return $Hanf_arg305415093(anf_arg57915092,anf_arg57615067,_plus26);
}};
$e1508215083.stack[R.EXN_STACKHEIGHT++] = $ss1508615087;
}
if(R.isPyretException($e1508215083)) {
$e1508215083.pyretStack.push(L[937]);
}
throw $e1508215083;
}
var $ret1508815089 = $Hanf_arg305415093($z1508415085,anf_arg57615067,_plus26);
++R.GAS;
return $ret1508815089;
};
var $Hanf_arg305415093 = function(anf_arg57915092,anf_arg57615067,_plus26) {
var $z1509615097 = D;
var $f1510215103 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg57615067,anf_arg57915092):R.ffi.throwNonFunApp(L[937],_plus26,[anf_arg57615067,anf_arg57915092]);
};
try {
if(--R.GAS > 0) {
$z1509615097 = $f1510215103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1510215103,
"from":L[937]});
}
} catch($e1509415095) {
if(R.isCont($e1509415095)) {
var $ss1509815099 = {"from":L[937],
"go":function(anf_arg58015104) {
return $Hanf_arg305315105(anf_arg58015104,_plus26);
}};
$e1509415095.stack[R.EXN_STACKHEIGHT++] = $ss1509815099;
}
if(R.isPyretException($e1509415095)) {
$e1509415095.pyretStack.push(L[937]);
}
throw $e1509415095;
}
var $ret1510015101 = $Hanf_arg305315105($z1509615097,_plus26);
++R.GAS;
return $ret1510015101;
};
var $Hanf_arg305315105 = function(anf_arg58015104,_plus26) {
var $z1510815109 = D;
var $f1511415115 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg58015104,(")")):R.ffi.throwNonFunApp(L[937],_plus26,[anf_arg58015104,(")")]);
};
try {
if(--R.GAS > 0) {
$z1510815109 = $f1511415115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1511415115,
"from":L[937]});
}
} catch($e1510615107) {
if(R.isCont($e1510615107)) {
var $ss1511015111 = {"from":L[937],
"go":function(anf_arg58115116) {
return $Hanf_arg305215117(anf_arg58115116,_plus26);
}};
$e1510615107.stack[R.EXN_STACKHEIGHT++] = $ss1511015111;
}
if(R.isPyretException($e1510615107)) {
$e1510615107.pyretStack.push(L[937]);
}
throw $e1510615107;
}
var $ret1511215113 = $Hanf_arg305215117($z1510815109,_plus26);
++R.GAS;
return $ret1511215113;
};
var $Hanf_arg305215117 = function(anf_arg58115116,_plus26) {
var $z1512015121 = D;
var $f1512615127 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg58115116):R.ffi.throwNonFunApp(L[937],_plus26,[("("),anf_arg58115116]);
};
try {
if(--R.GAS > 0) {
$z1512015121 = $f1512615127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1512615127,
"from":L[937]});
}
} catch($e1511815119) {
if(R.isCont($e1511815119)) {
var $ss1512215123 = {"from":L[937],
"go":function(anf_arg58215128) {
return $Hanf_arg305115129(anf_arg58215128,_plus26);
}};
$e1511815119.stack[R.EXN_STACKHEIGHT++] = $ss1512215123;
}
if(R.isPyretException($e1511815119)) {
$e1511815119.pyretStack.push(L[937]);
}
throw $e1511815119;
}
var $ret1512415125 = $Hanf_arg305115129($z1512015121,_plus26);
++R.GAS;
return $ret1512415125;
};
var $Hanf_arg305115129 = function(anf_arg58215128,_plus26) {
var $z1513215133 = D;
var $f1513815139 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-tail-app"),anf_arg58215128):R.ffi.throwNonFunApp(L[937],_plus26,[("a-tail-app"),anf_arg58215128]);
};
try {
if(--R.GAS > 0) {
$z1513215133 = $f1513815139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1513815139,
"from":L[937]});
}
} catch($e1513015131) {
if(R.isCont($e1513015131)) {
var $ss1513415135 = {"from":L[937],
"go":function(ann_DASH_check_DASH_temp57015140) {
return $Hann_DASH_check_DASH_temp305015141(ann_DASH_check_DASH_temp57015140);
}};
$e1513015131.stack[R.EXN_STACKHEIGHT++] = $ss1513415135;
}
if(R.isPyretException($e1513015131)) {
$e1513015131.pyretStack.push(L[937]);
}
throw $e1513015131;
}
var $ret1513615137 = $Hann_DASH_check_DASH_temp305015141($z1513215133);
++R.GAS;
return $ret1513615137;
};
var $Hann_DASH_check_DASH_temp305015141 = function(ann_DASH_check_DASH_temp57015140) {
return ann_DASH_check_DASH_temp57015140;
};
var $Hcont_tail_arg30486285 = function(cont_tail_arg5676283,if_helper5576284) {
if(--R.GAS > 0) {
$z1514215143 = R.isFunction(if_helper5576284)?if_helper5576284.app(cont_tail_arg5676283):R.ffi.throwNonFunApp(L[937],if_helper5576284,[cont_tail_arg5676283]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper5576284)?if_helper5576284.app(cont_tail_arg5676283):R.ffi.throwNonFunApp(L[937],if_helper5576284,[cont_tail_arg5676283]);
},
"from":L[937]});
}
++R.GAS;
return $z1514215143;
};
var $Hcont_tail_arg30496300 = function(cont_tail_arg5626299,if_helper5576284) {
if(--R.GAS > 0) {
$z1514415145 = R.isFunction(if_helper5576284)?if_helper5576284.app(cont_tail_arg5626299):R.ffi.throwNonFunApp(L[937],if_helper5576284,[cont_tail_arg5626299]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper5576284)?if_helper5576284.app(cont_tail_arg5626299):R.ffi.throwNonFunApp(L[937],if_helper5576284,[cont_tail_arg5626299]);
},
"from":L[937]});
}
++R.GAS;
return $z1514415145;
};
var $Hanf_arg30476321 = function(anf_arg5496319,PP337,self3146320,_plus26) {
var anf_arg55015156 = G(PP337,"hardline",L[1598]);
var $z1514815149 = D;
var $f1515415155 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg5496319,anf_arg55015156):R.ffi.throwNonFunApp(L[1597],_plus26,[anf_arg5496319,anf_arg55015156]);
};
try {
if(--R.GAS > 0) {
$z1514815149 = $f1515415155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1515415155,
"from":L[1597]});
}
} catch($e1514615147) {
if(R.isCont($e1514615147)) {
var $ss1515015151 = {"from":L[1597],
"go":function(anf_arg55115157) {
return $Hanf_arg304615158(anf_arg55115157,self3146320,_plus26);
}};
$e1514615147.stack[R.EXN_STACKHEIGHT++] = $ss1515015151;
}
if(R.isPyretException($e1514615147)) {
$e1514615147.pyretStack.push(L[1597]);
}
throw $e1514615147;
}
var $ret1515215153 = $Hanf_arg304615158($z1514815149,self3146320,_plus26);
++R.GAS;
return $ret1515215153;
};
var $Hanf_arg304615158 = function(anf_arg55115157,self3146320,_plus26) {
var anf_bracket55215172 = G(self3146320,"e2",L[1601]);
var anf_fun55315169 = G(anf_bracket55215172,"tosource",L[1600]);
var $z1516115162 = D;
var $f1516715168 = function(_) {
return R.isFunction(anf_fun55315169)?anf_fun55315169.app():R.ffi.throwNonFunApp(L[1599],anf_fun55315169,[]);
};
try {
if(--R.GAS > 0) {
$z1516115162 = $f1516715168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1516715168,
"from":L[1599]});
}
} catch($e1515915160) {
if(R.isCont($e1515915160)) {
var $ss1516315164 = {"from":L[1599],
"go":function(anf_arg55415170) {
return $Hanf_arg304515171(anf_arg55415170,anf_arg55115157,_plus26);
}};
$e1515915160.stack[R.EXN_STACKHEIGHT++] = $ss1516315164;
}
if(R.isPyretException($e1515915160)) {
$e1515915160.pyretStack.push(L[1599]);
}
throw $e1515915160;
}
var $ret1516515166 = $Hanf_arg304515171($z1516115162,anf_arg55115157,_plus26);
++R.GAS;
return $ret1516515166;
};
var $Hanf_arg304515171 = function(anf_arg55415170,anf_arg55115157,_plus26) {
var $z1517515176 = D;
var $f1518115182 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg55115157,anf_arg55415170):R.ffi.throwNonFunApp(L[1018],_plus26,[anf_arg55115157,anf_arg55415170]);
};
try {
if(--R.GAS > 0) {
$z1517515176 = $f1518115182();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1518115182,
"from":L[1018]});
}
} catch($e1517315174) {
if(R.isCont($e1517315174)) {
var $ss1517715178 = {"from":L[1018],
"go":function(ann_DASH_check_DASH_temp54615183) {
return $Hann_DASH_check_DASH_temp304415184(ann_DASH_check_DASH_temp54615183);
}};
$e1517315174.stack[R.EXN_STACKHEIGHT++] = $ss1517715178;
}
if(R.isPyretException($e1517315174)) {
$e1517315174.pyretStack.push(L[1018]);
}
throw $e1517315174;
}
var $ret1517915180 = $Hann_DASH_check_DASH_temp304415184($z1517515176);
++R.GAS;
return $ret1517915180;
};
var $Hann_DASH_check_DASH_temp304415184 = function(ann_DASH_check_DASH_temp54615183) {
return ann_DASH_check_DASH_temp54615183;
};
var $Hanf_arg30436338 = function(anf_arg5326336,self656337,_plus26,torepr31) {
var anf_arg53315195 = G(self656337,"e1",L[938]);
var $z1518715188 = D;
var $f1519315194 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg53315195):R.ffi.throwNonFunApp(L[938],torepr31,[anf_arg53315195]);
};
try {
if(--R.GAS > 0) {
$z1518715188 = $f1519315194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1519315194,
"from":L[938]});
}
} catch($e1518515186) {
if(R.isCont($e1518515186)) {
var $ss1518915190 = {"from":L[938],
"go":function(anf_arg53415196) {
return $Hanf_arg304215197(anf_arg53415196,anf_arg5326336,self656337,_plus26,torepr31);
}};
$e1518515186.stack[R.EXN_STACKHEIGHT++] = $ss1518915190;
}
if(R.isPyretException($e1518515186)) {
$e1518515186.pyretStack.push(L[938]);
}
throw $e1518515186;
}
var $ret1519115192 = $Hanf_arg304215197($z1518715188,anf_arg5326336,self656337,_plus26,torepr31);
++R.GAS;
return $ret1519115192;
};
var $Hanf_arg304215197 = function(anf_arg53415196,anf_arg5326336,self656337,_plus26,torepr31) {
var $z1520015201 = D;
var $f1520615207 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg53415196):R.ffi.throwNonFunApp(L[938],_plus26,[(", "),anf_arg53415196]);
};
try {
if(--R.GAS > 0) {
$z1520015201 = $f1520615207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1520615207,
"from":L[938]});
}
} catch($e1519815199) {
if(R.isCont($e1519815199)) {
var $ss1520215203 = {"from":L[938],
"go":function(anf_arg53515208) {
return $Hanf_arg304115209(anf_arg53515208,anf_arg5326336,self656337,_plus26,torepr31);
}};
$e1519815199.stack[R.EXN_STACKHEIGHT++] = $ss1520215203;
}
if(R.isPyretException($e1519815199)) {
$e1519815199.pyretStack.push(L[938]);
}
throw $e1519815199;
}
var $ret1520415205 = $Hanf_arg304115209($z1520015201,anf_arg5326336,self656337,_plus26,torepr31);
++R.GAS;
return $ret1520415205;
};
var $Hanf_arg304115209 = function(anf_arg53515208,anf_arg5326336,self656337,_plus26,torepr31) {
var $z1521215213 = D;
var $f1521815219 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg5326336,anf_arg53515208):R.ffi.throwNonFunApp(L[938],_plus26,[anf_arg5326336,anf_arg53515208]);
};
try {
if(--R.GAS > 0) {
$z1521215213 = $f1521815219();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1521815219,
"from":L[938]});
}
} catch($e1521015211) {
if(R.isCont($e1521015211)) {
var $ss1521415215 = {"from":L[938],
"go":function(anf_arg53615220) {
return $Hanf_arg304015221(anf_arg53615220,self656337,_plus26,torepr31);
}};
$e1521015211.stack[R.EXN_STACKHEIGHT++] = $ss1521415215;
}
if(R.isPyretException($e1521015211)) {
$e1521015211.pyretStack.push(L[938]);
}
throw $e1521015211;
}
var $ret1521615217 = $Hanf_arg304015221($z1521215213,self656337,_plus26,torepr31);
++R.GAS;
return $ret1521615217;
};
var $Hanf_arg304015221 = function(anf_arg53615220,self656337,_plus26,torepr31) {
var anf_arg53715232 = G(self656337,"e2",L[938]);
var $z1522415225 = D;
var $f1523015231 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg53715232):R.ffi.throwNonFunApp(L[938],torepr31,[anf_arg53715232]);
};
try {
if(--R.GAS > 0) {
$z1522415225 = $f1523015231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1523015231,
"from":L[938]});
}
} catch($e1522215223) {
if(R.isCont($e1522215223)) {
var $ss1522615227 = {"from":L[938],
"go":function(anf_arg53815233) {
return $Hanf_arg303915234(anf_arg53815233,anf_arg53615220,_plus26);
}};
$e1522215223.stack[R.EXN_STACKHEIGHT++] = $ss1522615227;
}
if(R.isPyretException($e1522215223)) {
$e1522215223.pyretStack.push(L[938]);
}
throw $e1522215223;
}
var $ret1522815229 = $Hanf_arg303915234($z1522415225,anf_arg53615220,_plus26);
++R.GAS;
return $ret1522815229;
};
var $Hanf_arg303915234 = function(anf_arg53815233,anf_arg53615220,_plus26) {
var $z1523715238 = D;
var $f1524315244 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg53815233):R.ffi.throwNonFunApp(L[938],_plus26,[(", "),anf_arg53815233]);
};
try {
if(--R.GAS > 0) {
$z1523715238 = $f1524315244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1524315244,
"from":L[938]});
}
} catch($e1523515236) {
if(R.isCont($e1523515236)) {
var $ss1523915240 = {"from":L[938],
"go":function(anf_arg53915245) {
return $Hanf_arg303815246(anf_arg53915245,anf_arg53615220,_plus26);
}};
$e1523515236.stack[R.EXN_STACKHEIGHT++] = $ss1523915240;
}
if(R.isPyretException($e1523515236)) {
$e1523515236.pyretStack.push(L[938]);
}
throw $e1523515236;
}
var $ret1524115242 = $Hanf_arg303815246($z1523715238,anf_arg53615220,_plus26);
++R.GAS;
return $ret1524115242;
};
var $Hanf_arg303815246 = function(anf_arg53915245,anf_arg53615220,_plus26) {
var $z1524915250 = D;
var $f1525515256 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg53615220,anf_arg53915245):R.ffi.throwNonFunApp(L[938],_plus26,[anf_arg53615220,anf_arg53915245]);
};
try {
if(--R.GAS > 0) {
$z1524915250 = $f1525515256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1525515256,
"from":L[938]});
}
} catch($e1524715248) {
if(R.isCont($e1524715248)) {
var $ss1525115252 = {"from":L[938],
"go":function(anf_arg54015257) {
return $Hanf_arg303715258(anf_arg54015257,_plus26);
}};
$e1524715248.stack[R.EXN_STACKHEIGHT++] = $ss1525115252;
}
if(R.isPyretException($e1524715248)) {
$e1524715248.pyretStack.push(L[938]);
}
throw $e1524715248;
}
var $ret1525315254 = $Hanf_arg303715258($z1524915250,_plus26);
++R.GAS;
return $ret1525315254;
};
var $Hanf_arg303715258 = function(anf_arg54015257,_plus26) {
var $z1526115262 = D;
var $f1526715268 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg54015257,(")")):R.ffi.throwNonFunApp(L[938],_plus26,[anf_arg54015257,(")")]);
};
try {
if(--R.GAS > 0) {
$z1526115262 = $f1526715268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1526715268,
"from":L[938]});
}
} catch($e1525915260) {
if(R.isCont($e1525915260)) {
var $ss1526315264 = {"from":L[938],
"go":function(anf_arg54115269) {
return $Hanf_arg303615270(anf_arg54115269,_plus26);
}};
$e1525915260.stack[R.EXN_STACKHEIGHT++] = $ss1526315264;
}
if(R.isPyretException($e1525915260)) {
$e1525915260.pyretStack.push(L[938]);
}
throw $e1525915260;
}
var $ret1526515266 = $Hanf_arg303615270($z1526115262,_plus26);
++R.GAS;
return $ret1526515266;
};
var $Hanf_arg303615270 = function(anf_arg54115269,_plus26) {
var $z1527315274 = D;
var $f1527915280 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg54115269):R.ffi.throwNonFunApp(L[938],_plus26,[("("),anf_arg54115269]);
};
try {
if(--R.GAS > 0) {
$z1527315274 = $f1527915280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1527915280,
"from":L[938]});
}
} catch($e1527115272) {
if(R.isCont($e1527115272)) {
var $ss1527515276 = {"from":L[938],
"go":function(anf_arg54215281) {
return $Hanf_arg303515282(anf_arg54215281,_plus26);
}};
$e1527115272.stack[R.EXN_STACKHEIGHT++] = $ss1527515276;
}
if(R.isPyretException($e1527115272)) {
$e1527115272.pyretStack.push(L[938]);
}
throw $e1527115272;
}
var $ret1527715278 = $Hanf_arg303515282($z1527315274,_plus26);
++R.GAS;
return $ret1527715278;
};
var $Hanf_arg303515282 = function(anf_arg54215281,_plus26) {
var $z1528515286 = D;
var $f1529115292 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-seq"),anf_arg54215281):R.ffi.throwNonFunApp(L[938],_plus26,[("a-seq"),anf_arg54215281]);
};
try {
if(--R.GAS > 0) {
$z1528515286 = $f1529115292();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1529115292,
"from":L[938]});
}
} catch($e1528315284) {
if(R.isCont($e1528315284)) {
var $ss1528715288 = {"from":L[938],
"go":function(ann_DASH_check_DASH_temp53015293) {
return $Hann_DASH_check_DASH_temp303415294(ann_DASH_check_DASH_temp53015293);
}};
$e1528315284.stack[R.EXN_STACKHEIGHT++] = $ss1528715288;
}
if(R.isPyretException($e1528315284)) {
$e1528315284.pyretStack.push(L[938]);
}
throw $e1528315284;
}
var $ret1528915290 = $Hann_DASH_check_DASH_temp303415294($z1528515286);
++R.GAS;
return $ret1528915290;
};
var $Hann_DASH_check_DASH_temp303415294 = function(ann_DASH_check_DASH_temp53015293) {
return ann_DASH_check_DASH_temp53015293;
};
var $Hcont_tail_arg30326355 = function(cont_tail_arg5276353,if_helper5176354) {
if(--R.GAS > 0) {
$z1529515296 = R.isFunction(if_helper5176354)?if_helper5176354.app(cont_tail_arg5276353):R.ffi.throwNonFunApp(L[938],if_helper5176354,[cont_tail_arg5276353]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper5176354)?if_helper5176354.app(cont_tail_arg5276353):R.ffi.throwNonFunApp(L[938],if_helper5176354,[cont_tail_arg5276353]);
},
"from":L[938]});
}
++R.GAS;
return $z1529515296;
};
var $Hcont_tail_arg30336370 = function(cont_tail_arg5226369,if_helper5176354) {
if(--R.GAS > 0) {
$z1529715298 = R.isFunction(if_helper5176354)?if_helper5176354.app(cont_tail_arg5226369):R.ffi.throwNonFunApp(L[938],if_helper5176354,[cont_tail_arg5226369]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper5176354)?if_helper5176354.app(cont_tail_arg5226369):R.ffi.throwNonFunApp(L[938],if_helper5176354,[cont_tail_arg5226369]);
},
"from":L[938]});
}
++R.GAS;
return $z1529715298;
};
var $Hanf_arg30316394 = function(anf_arg5016389,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,break_DASH_one9262,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_spaceequal110326,str_DASH_var104248,_plus26) {
var $z1530115302 = D;
var $f1530715308 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg5016389,str_DASH_spaceequal110326):R.ffi.throwNonFunApp(L[1602],_plus26,[anf_arg5016389,str_DASH_spaceequal110326]);
};
try {
if(--R.GAS > 0) {
$z1530115302 = $f1530715308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1530715308,
"from":L[1602]});
}
} catch($e1529915300) {
if(R.isCont($e1529915300)) {
var $ss1530315304 = {"from":L[1602],
"go":function(anf_arg50215309) {
return $Hanf_arg303015310(anf_arg50215309,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,break_DASH_one9262,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
}};
$e1529915300.stack[R.EXN_STACKHEIGHT++] = $ss1530315304;
}
if(R.isPyretException($e1529915300)) {
$e1529915300.pyretStack.push(L[1602]);
}
throw $e1529915300;
}
var $ret1530515306 = $Hanf_arg303015310($z1530115302,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,break_DASH_one9262,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
++R.GAS;
return $ret1530515306;
};
var $Hanf_arg303015310 = function(anf_arg50215309,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,break_DASH_one9262,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26) {
var $z1531315314 = D;
var $f1531915320 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg50215309,break_DASH_one9262):R.ffi.throwNonFunApp(L[1602],_plus26,[anf_arg50215309,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1531315314 = $f1531915320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1531915320,
"from":L[1602]});
}
} catch($e1531115312) {
if(R.isCont($e1531115312)) {
var $ss1531515316 = {"from":L[1602],
"go":function(anf_arg50315321) {
return $Hanf_arg302915322(anf_arg50315321,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
}};
$e1531115312.stack[R.EXN_STACKHEIGHT++] = $ss1531515316;
}
if(R.isPyretException($e1531115312)) {
$e1531115312.pyretStack.push(L[1602]);
}
throw $e1531115312;
}
var $ret1531715318 = $Hanf_arg302915322($z1531315314,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
++R.GAS;
return $ret1531715318;
};
var $Hanf_arg302915322 = function(anf_arg50315321,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26) {
var anf_bracket50415336 = G(self3096393,"e",L[1605]);
var anf_fun50515333 = G(anf_bracket50415336,"tosource",L[1604]);
var $z1532515326 = D;
var $f1533115332 = function(_) {
return R.isFunction(anf_fun50515333)?anf_fun50515333.app():R.ffi.throwNonFunApp(L[1603],anf_fun50515333,[]);
};
try {
if(--R.GAS > 0) {
$z1532515326 = $f1533115332();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1533115332,
"from":L[1603]});
}
} catch($e1532315324) {
if(R.isCont($e1532315324)) {
var $ss1532715328 = {"from":L[1603],
"go":function(anf_arg50615334) {
return $Hanf_arg302815335(anf_arg50615334,INDENT9187,anf_arg50315321,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
}};
$e1532315324.stack[R.EXN_STACKHEIGHT++] = $ss1532715328;
}
if(R.isPyretException($e1532315324)) {
$e1532315324.pyretStack.push(L[1603]);
}
throw $e1532315324;
}
var $ret1532915330 = $Hanf_arg302815335($z1532515326,INDENT9187,anf_arg50315321,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
++R.GAS;
return $ret1532915330;
};
var $Hanf_arg302815335 = function(anf_arg50615334,INDENT9187,anf_arg50315321,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26) {
var $z1533915340 = D;
var $f1534515346 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg50315321,anf_arg50615334):R.ffi.throwNonFunApp(L[1602],_plus26,[anf_arg50315321,anf_arg50615334]);
};
try {
if(--R.GAS > 0) {
$z1533915340 = $f1534515346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1534515346,
"from":L[1602]});
}
} catch($e1533715338) {
if(R.isCont($e1533715338)) {
var $ss1534115342 = {"from":L[1602],
"go":function(anf_arg50715347) {
return $Hanf_arg302715348(anf_arg50715347,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
}};
$e1533715338.stack[R.EXN_STACKHEIGHT++] = $ss1534115342;
}
if(R.isPyretException($e1533715338)) {
$e1533715338.pyretStack.push(L[1602]);
}
throw $e1533715338;
}
var $ret1534315344 = $Hanf_arg302715348($z1533915340,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
++R.GAS;
return $ret1534315344;
};
var $Hanf_arg302715348 = function(anf_arg50715347,INDENT9187,anf_fun4966390,anf_fun4976391,anf_fun4986392,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26) {
var $z1535115352 = D;
var $f1535715358 = function(_) {
return R.isFunction(anf_fun4986392)?anf_fun4986392.app(INDENT9187,anf_arg50715347):R.ffi.throwNonFunApp(L[1606],anf_fun4986392,[INDENT9187,anf_arg50715347]);
};
try {
if(--R.GAS > 0) {
$z1535115352 = $f1535715358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1535715358,
"from":L[1606]});
}
} catch($e1534915350) {
if(R.isCont($e1534915350)) {
var $ss1535315354 = {"from":L[1606],
"go":function(anf_arg50815359) {
return $Hanf_arg302615360(anf_arg50815359,INDENT9187,anf_fun4966390,anf_fun4976391,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
}};
$e1534915350.stack[R.EXN_STACKHEIGHT++] = $ss1535315354;
}
if(R.isPyretException($e1534915350)) {
$e1534915350.pyretStack.push(L[1606]);
}
throw $e1534915350;
}
var $ret1535515356 = $Hanf_arg302615360($z1535115352,INDENT9187,anf_fun4966390,anf_fun4976391,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
++R.GAS;
return $ret1535515356;
};
var $Hanf_arg302615360 = function(anf_arg50815359,INDENT9187,anf_fun4966390,anf_fun4976391,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26) {
var $z1536315364 = D;
var $f1536915370 = function(_) {
return R.isFunction(anf_fun4976391)?anf_fun4976391.app(anf_arg50815359):R.ffi.throwNonFunApp(L[1607],anf_fun4976391,[anf_arg50815359]);
};
try {
if(--R.GAS > 0) {
$z1536315364 = $f1536915370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1536915370,
"from":L[1607]});
}
} catch($e1536115362) {
if(R.isCont($e1536115362)) {
var $ss1536515366 = {"from":L[1607],
"go":function(anf_arg50915371) {
return $Hanf_arg302515372(anf_arg50915371,INDENT9187,anf_fun4966390,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
}};
$e1536115362.stack[R.EXN_STACKHEIGHT++] = $ss1536515366;
}
if(R.isPyretException($e1536115362)) {
$e1536115362.pyretStack.push(L[1607]);
}
throw $e1536115362;
}
var $ret1536715368 = $Hanf_arg302515372($z1536315364,INDENT9187,anf_fun4966390,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26);
++R.GAS;
return $ret1536715368;
};
var $Hanf_arg302515372 = function(anf_arg50915371,INDENT9187,anf_fun4966390,self3096393,str_DASH_colon98170,str_DASH_end101209,str_DASH_var104248,_plus26) {
var $z1537515376 = D;
var $f1538115382 = function(_) {
return R.isFunction(_plus26)?_plus26.app(str_DASH_var104248,anf_arg50915371):R.ffi.throwNonFunApp(L[1608],_plus26,[str_DASH_var104248,anf_arg50915371]);
};
try {
if(--R.GAS > 0) {
$z1537515376 = $f1538115382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1538115382,
"from":L[1608]});
}
} catch($e1537315374) {
if(R.isCont($e1537315374)) {
var $ss1537715378 = {"from":L[1608],
"go":function(anf_arg51015383) {
return $Hanf_arg302415384(anf_arg51015383,INDENT9187,anf_fun4966390,self3096393,str_DASH_colon98170,str_DASH_end101209,_plus26);
}};
$e1537315374.stack[R.EXN_STACKHEIGHT++] = $ss1537715378;
}
if(R.isPyretException($e1537315374)) {
$e1537315374.pyretStack.push(L[1608]);
}
throw $e1537315374;
}
var $ret1537915380 = $Hanf_arg302415384($z1537515376,INDENT9187,anf_fun4966390,self3096393,str_DASH_colon98170,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1537915380;
};
var $Hanf_arg302415384 = function(anf_arg51015383,INDENT9187,anf_fun4966390,self3096393,str_DASH_colon98170,str_DASH_end101209,_plus26) {
var $z1538715388 = D;
var $f1539315394 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg51015383,str_DASH_colon98170):R.ffi.throwNonFunApp(L[1608],_plus26,[anf_arg51015383,str_DASH_colon98170]);
};
try {
if(--R.GAS > 0) {
$z1538715388 = $f1539315394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1539315394,
"from":L[1608]});
}
} catch($e1538515386) {
if(R.isCont($e1538515386)) {
var $ss1538915390 = {"from":L[1608],
"go":function(anf_arg51115395) {
return $Hanf_arg302315396(anf_arg51115395,INDENT9187,anf_fun4966390,self3096393,str_DASH_end101209);
}};
$e1538515386.stack[R.EXN_STACKHEIGHT++] = $ss1538915390;
}
if(R.isPyretException($e1538515386)) {
$e1538515386.pyretStack.push(L[1608]);
}
throw $e1538515386;
}
var $ret1539115392 = $Hanf_arg302315396($z1538715388,INDENT9187,anf_fun4966390,self3096393,str_DASH_end101209);
++R.GAS;
return $ret1539115392;
};
var $Hanf_arg302315396 = function(anf_arg51115395,INDENT9187,anf_fun4966390,self3096393,str_DASH_end101209) {
var anf_bracket51215410 = G(self3096393,"body",L[1611]);
var anf_fun51315407 = G(anf_bracket51215410,"tosource",L[1610]);
var $z1539915400 = D;
var $f1540515406 = function(_) {
return R.isFunction(anf_fun51315407)?anf_fun51315407.app():R.ffi.throwNonFunApp(L[1609],anf_fun51315407,[]);
};
try {
if(--R.GAS > 0) {
$z1539915400 = $f1540515406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1540515406,
"from":L[1609]});
}
} catch($e1539715398) {
if(R.isCont($e1539715398)) {
var $ss1540115402 = {"from":L[1609],
"go":function(anf_arg51415408) {
return $Hanf_arg302215409(anf_arg51415408,INDENT9187,anf_arg51115395,anf_fun4966390,str_DASH_end101209);
}};
$e1539715398.stack[R.EXN_STACKHEIGHT++] = $ss1540115402;
}
if(R.isPyretException($e1539715398)) {
$e1539715398.pyretStack.push(L[1609]);
}
throw $e1539715398;
}
var $ret1540315404 = $Hanf_arg302215409($z1539915400,INDENT9187,anf_arg51115395,anf_fun4966390,str_DASH_end101209);
++R.GAS;
return $ret1540315404;
};
var $Hanf_arg302215409 = function(anf_arg51415408,INDENT9187,anf_arg51115395,anf_fun4966390,str_DASH_end101209) {
var $z1541315414 = D;
var $f1541915420 = function(_) {
return R.isFunction(anf_fun4966390)?anf_fun4966390.app(INDENT9187,(1),anf_arg51115395,anf_arg51415408,str_DASH_end101209):R.ffi.throwNonFunApp(L[1029],anf_fun4966390,[INDENT9187,(1),anf_arg51115395,anf_arg51415408,str_DASH_end101209]);
};
try {
if(--R.GAS > 0) {
$z1541315414 = $f1541915420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1541915420,
"from":L[1029]});
}
} catch($e1541115412) {
if(R.isCont($e1541115412)) {
var $ss1541515416 = {"from":L[1029],
"go":function(ann_DASH_check_DASH_temp49515421) {
return $Hann_DASH_check_DASH_temp302115422(ann_DASH_check_DASH_temp49515421);
}};
$e1541115412.stack[R.EXN_STACKHEIGHT++] = $ss1541515416;
}
if(R.isPyretException($e1541115412)) {
$e1541115412.pyretStack.push(L[1029]);
}
throw $e1541115412;
}
var $ret1541715418 = $Hann_DASH_check_DASH_temp302115422($z1541315414);
++R.GAS;
return $ret1541715418;
};
var $Hann_DASH_check_DASH_temp302115422 = function(ann_DASH_check_DASH_temp49515421) {
return ann_DASH_check_DASH_temp49515421;
};
var $Hanf_arg30206411 = function(anf_arg4776409,self596410,_plus26,torepr31) {
var anf_arg47815433 = G(self596410,"bind",L[939]);
var $z1542515426 = D;
var $f1543115432 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg47815433):R.ffi.throwNonFunApp(L[939],torepr31,[anf_arg47815433]);
};
try {
if(--R.GAS > 0) {
$z1542515426 = $f1543115432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1543115432,
"from":L[939]});
}
} catch($e1542315424) {
if(R.isCont($e1542315424)) {
var $ss1542715428 = {"from":L[939],
"go":function(anf_arg47915434) {
return $Hanf_arg301915435(anf_arg47915434,anf_arg4776409,self596410,_plus26,torepr31);
}};
$e1542315424.stack[R.EXN_STACKHEIGHT++] = $ss1542715428;
}
if(R.isPyretException($e1542315424)) {
$e1542315424.pyretStack.push(L[939]);
}
throw $e1542315424;
}
var $ret1542915430 = $Hanf_arg301915435($z1542515426,anf_arg4776409,self596410,_plus26,torepr31);
++R.GAS;
return $ret1542915430;
};
var $Hanf_arg301915435 = function(anf_arg47915434,anf_arg4776409,self596410,_plus26,torepr31) {
var $z1543815439 = D;
var $f1544415445 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg47915434):R.ffi.throwNonFunApp(L[939],_plus26,[(", "),anf_arg47915434]);
};
try {
if(--R.GAS > 0) {
$z1543815439 = $f1544415445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1544415445,
"from":L[939]});
}
} catch($e1543615437) {
if(R.isCont($e1543615437)) {
var $ss1544015441 = {"from":L[939],
"go":function(anf_arg48015446) {
return $Hanf_arg301815447(anf_arg48015446,anf_arg4776409,self596410,_plus26,torepr31);
}};
$e1543615437.stack[R.EXN_STACKHEIGHT++] = $ss1544015441;
}
if(R.isPyretException($e1543615437)) {
$e1543615437.pyretStack.push(L[939]);
}
throw $e1543615437;
}
var $ret1544215443 = $Hanf_arg301815447($z1543815439,anf_arg4776409,self596410,_plus26,torepr31);
++R.GAS;
return $ret1544215443;
};
var $Hanf_arg301815447 = function(anf_arg48015446,anf_arg4776409,self596410,_plus26,torepr31) {
var $z1545015451 = D;
var $f1545615457 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg4776409,anf_arg48015446):R.ffi.throwNonFunApp(L[939],_plus26,[anf_arg4776409,anf_arg48015446]);
};
try {
if(--R.GAS > 0) {
$z1545015451 = $f1545615457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1545615457,
"from":L[939]});
}
} catch($e1544815449) {
if(R.isCont($e1544815449)) {
var $ss1545215453 = {"from":L[939],
"go":function(anf_arg48115458) {
return $Hanf_arg301715459(anf_arg48115458,self596410,_plus26,torepr31);
}};
$e1544815449.stack[R.EXN_STACKHEIGHT++] = $ss1545215453;
}
if(R.isPyretException($e1544815449)) {
$e1544815449.pyretStack.push(L[939]);
}
throw $e1544815449;
}
var $ret1545415455 = $Hanf_arg301715459($z1545015451,self596410,_plus26,torepr31);
++R.GAS;
return $ret1545415455;
};
var $Hanf_arg301715459 = function(anf_arg48115458,self596410,_plus26,torepr31) {
var anf_arg48215470 = G(self596410,"e",L[939]);
var $z1546215463 = D;
var $f1546815469 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg48215470):R.ffi.throwNonFunApp(L[939],torepr31,[anf_arg48215470]);
};
try {
if(--R.GAS > 0) {
$z1546215463 = $f1546815469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1546815469,
"from":L[939]});
}
} catch($e1546015461) {
if(R.isCont($e1546015461)) {
var $ss1546415465 = {"from":L[939],
"go":function(anf_arg48315471) {
return $Hanf_arg301615472(anf_arg48315471,anf_arg48115458,self596410,_plus26,torepr31);
}};
$e1546015461.stack[R.EXN_STACKHEIGHT++] = $ss1546415465;
}
if(R.isPyretException($e1546015461)) {
$e1546015461.pyretStack.push(L[939]);
}
throw $e1546015461;
}
var $ret1546615467 = $Hanf_arg301615472($z1546215463,anf_arg48115458,self596410,_plus26,torepr31);
++R.GAS;
return $ret1546615467;
};
var $Hanf_arg301615472 = function(anf_arg48315471,anf_arg48115458,self596410,_plus26,torepr31) {
var $z1547515476 = D;
var $f1548115482 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg48315471):R.ffi.throwNonFunApp(L[939],_plus26,[(", "),anf_arg48315471]);
};
try {
if(--R.GAS > 0) {
$z1547515476 = $f1548115482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1548115482,
"from":L[939]});
}
} catch($e1547315474) {
if(R.isCont($e1547315474)) {
var $ss1547715478 = {"from":L[939],
"go":function(anf_arg48415483) {
return $Hanf_arg301515484(anf_arg48415483,anf_arg48115458,self596410,_plus26,torepr31);
}};
$e1547315474.stack[R.EXN_STACKHEIGHT++] = $ss1547715478;
}
if(R.isPyretException($e1547315474)) {
$e1547315474.pyretStack.push(L[939]);
}
throw $e1547315474;
}
var $ret1547915480 = $Hanf_arg301515484($z1547515476,anf_arg48115458,self596410,_plus26,torepr31);
++R.GAS;
return $ret1547915480;
};
var $Hanf_arg301515484 = function(anf_arg48415483,anf_arg48115458,self596410,_plus26,torepr31) {
var $z1548715488 = D;
var $f1549315494 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg48115458,anf_arg48415483):R.ffi.throwNonFunApp(L[939],_plus26,[anf_arg48115458,anf_arg48415483]);
};
try {
if(--R.GAS > 0) {
$z1548715488 = $f1549315494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1549315494,
"from":L[939]});
}
} catch($e1548515486) {
if(R.isCont($e1548515486)) {
var $ss1548915490 = {"from":L[939],
"go":function(anf_arg48515495) {
return $Hanf_arg301415496(anf_arg48515495,self596410,_plus26,torepr31);
}};
$e1548515486.stack[R.EXN_STACKHEIGHT++] = $ss1548915490;
}
if(R.isPyretException($e1548515486)) {
$e1548515486.pyretStack.push(L[939]);
}
throw $e1548515486;
}
var $ret1549115492 = $Hanf_arg301415496($z1548715488,self596410,_plus26,torepr31);
++R.GAS;
return $ret1549115492;
};
var $Hanf_arg301415496 = function(anf_arg48515495,self596410,_plus26,torepr31) {
var anf_arg48615507 = G(self596410,"body",L[939]);
var $z1549915500 = D;
var $f1550515506 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg48615507):R.ffi.throwNonFunApp(L[939],torepr31,[anf_arg48615507]);
};
try {
if(--R.GAS > 0) {
$z1549915500 = $f1550515506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1550515506,
"from":L[939]});
}
} catch($e1549715498) {
if(R.isCont($e1549715498)) {
var $ss1550115502 = {"from":L[939],
"go":function(anf_arg48715508) {
return $Hanf_arg301315509(anf_arg48715508,anf_arg48515495,_plus26);
}};
$e1549715498.stack[R.EXN_STACKHEIGHT++] = $ss1550115502;
}
if(R.isPyretException($e1549715498)) {
$e1549715498.pyretStack.push(L[939]);
}
throw $e1549715498;
}
var $ret1550315504 = $Hanf_arg301315509($z1549915500,anf_arg48515495,_plus26);
++R.GAS;
return $ret1550315504;
};
var $Hanf_arg301315509 = function(anf_arg48715508,anf_arg48515495,_plus26) {
var $z1551215513 = D;
var $f1551815519 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg48715508):R.ffi.throwNonFunApp(L[939],_plus26,[(", "),anf_arg48715508]);
};
try {
if(--R.GAS > 0) {
$z1551215513 = $f1551815519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1551815519,
"from":L[939]});
}
} catch($e1551015511) {
if(R.isCont($e1551015511)) {
var $ss1551415515 = {"from":L[939],
"go":function(anf_arg48815520) {
return $Hanf_arg301215521(anf_arg48815520,anf_arg48515495,_plus26);
}};
$e1551015511.stack[R.EXN_STACKHEIGHT++] = $ss1551415515;
}
if(R.isPyretException($e1551015511)) {
$e1551015511.pyretStack.push(L[939]);
}
throw $e1551015511;
}
var $ret1551615517 = $Hanf_arg301215521($z1551215513,anf_arg48515495,_plus26);
++R.GAS;
return $ret1551615517;
};
var $Hanf_arg301215521 = function(anf_arg48815520,anf_arg48515495,_plus26) {
var $z1552415525 = D;
var $f1553015531 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg48515495,anf_arg48815520):R.ffi.throwNonFunApp(L[939],_plus26,[anf_arg48515495,anf_arg48815520]);
};
try {
if(--R.GAS > 0) {
$z1552415525 = $f1553015531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1553015531,
"from":L[939]});
}
} catch($e1552215523) {
if(R.isCont($e1552215523)) {
var $ss1552615527 = {"from":L[939],
"go":function(anf_arg48915532) {
return $Hanf_arg301115533(anf_arg48915532,_plus26);
}};
$e1552215523.stack[R.EXN_STACKHEIGHT++] = $ss1552615527;
}
if(R.isPyretException($e1552215523)) {
$e1552215523.pyretStack.push(L[939]);
}
throw $e1552215523;
}
var $ret1552815529 = $Hanf_arg301115533($z1552415525,_plus26);
++R.GAS;
return $ret1552815529;
};
var $Hanf_arg301115533 = function(anf_arg48915532,_plus26) {
var $z1553615537 = D;
var $f1554215543 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg48915532,(")")):R.ffi.throwNonFunApp(L[939],_plus26,[anf_arg48915532,(")")]);
};
try {
if(--R.GAS > 0) {
$z1553615537 = $f1554215543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1554215543,
"from":L[939]});
}
} catch($e1553415535) {
if(R.isCont($e1553415535)) {
var $ss1553815539 = {"from":L[939],
"go":function(anf_arg49015544) {
return $Hanf_arg301015545(anf_arg49015544,_plus26);
}};
$e1553415535.stack[R.EXN_STACKHEIGHT++] = $ss1553815539;
}
if(R.isPyretException($e1553415535)) {
$e1553415535.pyretStack.push(L[939]);
}
throw $e1553415535;
}
var $ret1554015541 = $Hanf_arg301015545($z1553615537,_plus26);
++R.GAS;
return $ret1554015541;
};
var $Hanf_arg301015545 = function(anf_arg49015544,_plus26) {
var $z1554815549 = D;
var $f1555415555 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg49015544):R.ffi.throwNonFunApp(L[939],_plus26,[("("),anf_arg49015544]);
};
try {
if(--R.GAS > 0) {
$z1554815549 = $f1555415555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1555415555,
"from":L[939]});
}
} catch($e1554615547) {
if(R.isCont($e1554615547)) {
var $ss1555015551 = {"from":L[939],
"go":function(anf_arg49115556) {
return $Hanf_arg300915557(anf_arg49115556,_plus26);
}};
$e1554615547.stack[R.EXN_STACKHEIGHT++] = $ss1555015551;
}
if(R.isPyretException($e1554615547)) {
$e1554615547.pyretStack.push(L[939]);
}
throw $e1554615547;
}
var $ret1555215553 = $Hanf_arg300915557($z1554815549,_plus26);
++R.GAS;
return $ret1555215553;
};
var $Hanf_arg300915557 = function(anf_arg49115556,_plus26) {
var $z1556015561 = D;
var $f1556615567 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-var"),anf_arg49115556):R.ffi.throwNonFunApp(L[939],_plus26,[("a-var"),anf_arg49115556]);
};
try {
if(--R.GAS > 0) {
$z1556015561 = $f1556615567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1556615567,
"from":L[939]});
}
} catch($e1555815559) {
if(R.isCont($e1555815559)) {
var $ss1556215563 = {"from":L[939],
"go":function(ann_DASH_check_DASH_temp47515568) {
return $Hann_DASH_check_DASH_temp300815569(ann_DASH_check_DASH_temp47515568);
}};
$e1555815559.stack[R.EXN_STACKHEIGHT++] = $ss1556215563;
}
if(R.isPyretException($e1555815559)) {
$e1555815559.pyretStack.push(L[939]);
}
throw $e1555815559;
}
var $ret1556415565 = $Hann_DASH_check_DASH_temp300815569($z1556015561);
++R.GAS;
return $ret1556415565;
};
var $Hann_DASH_check_DASH_temp300815569 = function(ann_DASH_check_DASH_temp47515568) {
return ann_DASH_check_DASH_temp47515568;
};
var $Hcont_tail_arg30066429 = function(cont_tail_arg4726427,if_helper4616428) {
if(--R.GAS > 0) {
$z1557015571 = R.isFunction(if_helper4616428)?if_helper4616428.app(cont_tail_arg4726427):R.ffi.throwNonFunApp(L[939],if_helper4616428,[cont_tail_arg4726427]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper4616428)?if_helper4616428.app(cont_tail_arg4726427):R.ffi.throwNonFunApp(L[939],if_helper4616428,[cont_tail_arg4726427]);
},
"from":L[939]});
}
++R.GAS;
return $z1557015571;
};
var $Hcont_tail_arg30076444 = function(cont_tail_arg4666443,if_helper4616428) {
if(--R.GAS > 0) {
$z1557215573 = R.isFunction(if_helper4616428)?if_helper4616428.app(cont_tail_arg4666443):R.ffi.throwNonFunApp(L[939],if_helper4616428,[cont_tail_arg4666443]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper4616428)?if_helper4616428.app(cont_tail_arg4666443):R.ffi.throwNonFunApp(L[939],if_helper4616428,[cont_tail_arg4666443]);
},
"from":L[939]});
}
++R.GAS;
return $z1557215573;
};
var $Hanf_arg30056468 = function(anf_arg4456463,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,break_DASH_one9262,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,str_DASH_spaceequal110326,_plus26) {
var $z1557615577 = D;
var $f1558215583 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg4456463,str_DASH_spaceequal110326):R.ffi.throwNonFunApp(L[1612],_plus26,[anf_arg4456463,str_DASH_spaceequal110326]);
};
try {
if(--R.GAS > 0) {
$z1557615577 = $f1558215583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1558215583,
"from":L[1612]});
}
} catch($e1557415575) {
if(R.isCont($e1557415575)) {
var $ss1557815579 = {"from":L[1612],
"go":function(anf_arg44615584) {
return $Hanf_arg300415585(anf_arg44615584,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,break_DASH_one9262,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
}};
$e1557415575.stack[R.EXN_STACKHEIGHT++] = $ss1557815579;
}
if(R.isPyretException($e1557415575)) {
$e1557415575.pyretStack.push(L[1612]);
}
throw $e1557415575;
}
var $ret1558015581 = $Hanf_arg300415585($z1557615577,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,break_DASH_one9262,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
++R.GAS;
return $ret1558015581;
};
var $Hanf_arg300415585 = function(anf_arg44615584,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,break_DASH_one9262,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26) {
var $z1558815589 = D;
var $f1559415595 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg44615584,break_DASH_one9262):R.ffi.throwNonFunApp(L[1612],_plus26,[anf_arg44615584,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1558815589 = $f1559415595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1559415595,
"from":L[1612]});
}
} catch($e1558615587) {
if(R.isCont($e1558615587)) {
var $ss1559015591 = {"from":L[1612],
"go":function(anf_arg44715596) {
return $Hanf_arg300315597(anf_arg44715596,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
}};
$e1558615587.stack[R.EXN_STACKHEIGHT++] = $ss1559015591;
}
if(R.isPyretException($e1558615587)) {
$e1558615587.pyretStack.push(L[1612]);
}
throw $e1558615587;
}
var $ret1559215593 = $Hanf_arg300315597($z1558815589,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
++R.GAS;
return $ret1559215593;
};
var $Hanf_arg300315597 = function(anf_arg44715596,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26) {
var anf_bracket44815611 = G(self3036467,"e",L[1615]);
var anf_fun44915608 = G(anf_bracket44815611,"tosource",L[1614]);
var $z1560015601 = D;
var $f1560615607 = function(_) {
return R.isFunction(anf_fun44915608)?anf_fun44915608.app():R.ffi.throwNonFunApp(L[1613],anf_fun44915608,[]);
};
try {
if(--R.GAS > 0) {
$z1560015601 = $f1560615607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1560615607,
"from":L[1613]});
}
} catch($e1559815599) {
if(R.isCont($e1559815599)) {
var $ss1560215603 = {"from":L[1613],
"go":function(anf_arg45015609) {
return $Hanf_arg300215610(anf_arg45015609,INDENT9187,anf_arg44715596,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
}};
$e1559815599.stack[R.EXN_STACKHEIGHT++] = $ss1560215603;
}
if(R.isPyretException($e1559815599)) {
$e1559815599.pyretStack.push(L[1613]);
}
throw $e1559815599;
}
var $ret1560415605 = $Hanf_arg300215610($z1560015601,INDENT9187,anf_arg44715596,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
++R.GAS;
return $ret1560415605;
};
var $Hanf_arg300215610 = function(anf_arg45015609,INDENT9187,anf_arg44715596,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26) {
var $z1561415615 = D;
var $f1562015621 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg44715596,anf_arg45015609):R.ffi.throwNonFunApp(L[1612],_plus26,[anf_arg44715596,anf_arg45015609]);
};
try {
if(--R.GAS > 0) {
$z1561415615 = $f1562015621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1562015621,
"from":L[1612]});
}
} catch($e1561215613) {
if(R.isCont($e1561215613)) {
var $ss1561615617 = {"from":L[1612],
"go":function(anf_arg45115622) {
return $Hanf_arg300115623(anf_arg45115622,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
}};
$e1561215613.stack[R.EXN_STACKHEIGHT++] = $ss1561615617;
}
if(R.isPyretException($e1561215613)) {
$e1561215613.pyretStack.push(L[1612]);
}
throw $e1561215613;
}
var $ret1561815619 = $Hanf_arg300115623($z1561415615,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
++R.GAS;
return $ret1561815619;
};
var $Hanf_arg300115623 = function(anf_arg45115622,INDENT9187,anf_fun4406464,anf_fun4416465,anf_fun4426466,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26) {
var $z1562615627 = D;
var $f1563215633 = function(_) {
return R.isFunction(anf_fun4426466)?anf_fun4426466.app(INDENT9187,anf_arg45115622):R.ffi.throwNonFunApp(L[1616],anf_fun4426466,[INDENT9187,anf_arg45115622]);
};
try {
if(--R.GAS > 0) {
$z1562615627 = $f1563215633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1563215633,
"from":L[1616]});
}
} catch($e1562415625) {
if(R.isCont($e1562415625)) {
var $ss1562815629 = {"from":L[1616],
"go":function(anf_arg45215634) {
return $Hanf_arg300015635(anf_arg45215634,INDENT9187,anf_fun4406464,anf_fun4416465,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
}};
$e1562415625.stack[R.EXN_STACKHEIGHT++] = $ss1562815629;
}
if(R.isPyretException($e1562415625)) {
$e1562415625.pyretStack.push(L[1616]);
}
throw $e1562415625;
}
var $ret1563015631 = $Hanf_arg300015635($z1562615627,INDENT9187,anf_fun4406464,anf_fun4416465,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
++R.GAS;
return $ret1563015631;
};
var $Hanf_arg300015635 = function(anf_arg45215634,INDENT9187,anf_fun4406464,anf_fun4416465,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26) {
var $z1563815639 = D;
var $f1564415645 = function(_) {
return R.isFunction(anf_fun4416465)?anf_fun4416465.app(anf_arg45215634):R.ffi.throwNonFunApp(L[1617],anf_fun4416465,[anf_arg45215634]);
};
try {
if(--R.GAS > 0) {
$z1563815639 = $f1564415645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1564415645,
"from":L[1617]});
}
} catch($e1563615637) {
if(R.isCont($e1563615637)) {
var $ss1564015641 = {"from":L[1617],
"go":function(anf_arg45315646) {
return $Hanf_arg299915647(anf_arg45315646,INDENT9187,anf_fun4406464,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
}};
$e1563615637.stack[R.EXN_STACKHEIGHT++] = $ss1564015641;
}
if(R.isPyretException($e1563615637)) {
$e1563615637.pyretStack.push(L[1617]);
}
throw $e1563615637;
}
var $ret1564215643 = $Hanf_arg299915647($z1563815639,INDENT9187,anf_fun4406464,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26);
++R.GAS;
return $ret1564215643;
};
var $Hanf_arg299915647 = function(anf_arg45315646,INDENT9187,anf_fun4406464,self3036467,str_DASH_colon98170,str_DASH_end101209,str_DASH_let103235,_plus26) {
var $z1565015651 = D;
var $f1565615657 = function(_) {
return R.isFunction(_plus26)?_plus26.app(str_DASH_let103235,anf_arg45315646):R.ffi.throwNonFunApp(L[1618],_plus26,[str_DASH_let103235,anf_arg45315646]);
};
try {
if(--R.GAS > 0) {
$z1565015651 = $f1565615657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1565615657,
"from":L[1618]});
}
} catch($e1564815649) {
if(R.isCont($e1564815649)) {
var $ss1565215653 = {"from":L[1618],
"go":function(anf_arg45415658) {
return $Hanf_arg299815659(anf_arg45415658,INDENT9187,anf_fun4406464,self3036467,str_DASH_colon98170,str_DASH_end101209,_plus26);
}};
$e1564815649.stack[R.EXN_STACKHEIGHT++] = $ss1565215653;
}
if(R.isPyretException($e1564815649)) {
$e1564815649.pyretStack.push(L[1618]);
}
throw $e1564815649;
}
var $ret1565415655 = $Hanf_arg299815659($z1565015651,INDENT9187,anf_fun4406464,self3036467,str_DASH_colon98170,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1565415655;
};
var $Hanf_arg299815659 = function(anf_arg45415658,INDENT9187,anf_fun4406464,self3036467,str_DASH_colon98170,str_DASH_end101209,_plus26) {
var $z1566215663 = D;
var $f1566815669 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg45415658,str_DASH_colon98170):R.ffi.throwNonFunApp(L[1618],_plus26,[anf_arg45415658,str_DASH_colon98170]);
};
try {
if(--R.GAS > 0) {
$z1566215663 = $f1566815669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1566815669,
"from":L[1618]});
}
} catch($e1566015661) {
if(R.isCont($e1566015661)) {
var $ss1566415665 = {"from":L[1618],
"go":function(anf_arg45515670) {
return $Hanf_arg299715671(anf_arg45515670,INDENT9187,anf_fun4406464,self3036467,str_DASH_end101209);
}};
$e1566015661.stack[R.EXN_STACKHEIGHT++] = $ss1566415665;
}
if(R.isPyretException($e1566015661)) {
$e1566015661.pyretStack.push(L[1618]);
}
throw $e1566015661;
}
var $ret1566615667 = $Hanf_arg299715671($z1566215663,INDENT9187,anf_fun4406464,self3036467,str_DASH_end101209);
++R.GAS;
return $ret1566615667;
};
var $Hanf_arg299715671 = function(anf_arg45515670,INDENT9187,anf_fun4406464,self3036467,str_DASH_end101209) {
var anf_bracket45615685 = G(self3036467,"body",L[1621]);
var anf_fun45715682 = G(anf_bracket45615685,"tosource",L[1620]);
var $z1567415675 = D;
var $f1568015681 = function(_) {
return R.isFunction(anf_fun45715682)?anf_fun45715682.app():R.ffi.throwNonFunApp(L[1619],anf_fun45715682,[]);
};
try {
if(--R.GAS > 0) {
$z1567415675 = $f1568015681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1568015681,
"from":L[1619]});
}
} catch($e1567215673) {
if(R.isCont($e1567215673)) {
var $ss1567615677 = {"from":L[1619],
"go":function(anf_arg45815683) {
return $Hanf_arg299615684(anf_arg45815683,INDENT9187,anf_arg45515670,anf_fun4406464,str_DASH_end101209);
}};
$e1567215673.stack[R.EXN_STACKHEIGHT++] = $ss1567615677;
}
if(R.isPyretException($e1567215673)) {
$e1567215673.pyretStack.push(L[1619]);
}
throw $e1567215673;
}
var $ret1567815679 = $Hanf_arg299615684($z1567415675,INDENT9187,anf_arg45515670,anf_fun4406464,str_DASH_end101209);
++R.GAS;
return $ret1567815679;
};
var $Hanf_arg299615684 = function(anf_arg45815683,INDENT9187,anf_arg45515670,anf_fun4406464,str_DASH_end101209) {
var $z1568815689 = D;
var $f1569415695 = function(_) {
return R.isFunction(anf_fun4406464)?anf_fun4406464.app(INDENT9187,(1),anf_arg45515670,anf_arg45815683,str_DASH_end101209):R.ffi.throwNonFunApp(L[1041],anf_fun4406464,[INDENT9187,(1),anf_arg45515670,anf_arg45815683,str_DASH_end101209]);
};
try {
if(--R.GAS > 0) {
$z1568815689 = $f1569415695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1569415695,
"from":L[1041]});
}
} catch($e1568615687) {
if(R.isCont($e1568615687)) {
var $ss1569015691 = {"from":L[1041],
"go":function(ann_DASH_check_DASH_temp43915696) {
return $Hann_DASH_check_DASH_temp299515697(ann_DASH_check_DASH_temp43915696);
}};
$e1568615687.stack[R.EXN_STACKHEIGHT++] = $ss1569015691;
}
if(R.isPyretException($e1568615687)) {
$e1568615687.pyretStack.push(L[1041]);
}
throw $e1568615687;
}
var $ret1569215693 = $Hann_DASH_check_DASH_temp299515697($z1568815689);
++R.GAS;
return $ret1569215693;
};
var $Hann_DASH_check_DASH_temp299515697 = function(ann_DASH_check_DASH_temp43915696) {
return ann_DASH_check_DASH_temp43915696;
};
var $Hanf_arg29946485 = function(anf_arg4216483,self536484,_plus26,torepr31) {
var anf_arg42215708 = G(self536484,"bind",L[940]);
var $z1570015701 = D;
var $f1570615707 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg42215708):R.ffi.throwNonFunApp(L[940],torepr31,[anf_arg42215708]);
};
try {
if(--R.GAS > 0) {
$z1570015701 = $f1570615707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1570615707,
"from":L[940]});
}
} catch($e1569815699) {
if(R.isCont($e1569815699)) {
var $ss1570215703 = {"from":L[940],
"go":function(anf_arg42315709) {
return $Hanf_arg299315710(anf_arg42315709,anf_arg4216483,self536484,_plus26,torepr31);
}};
$e1569815699.stack[R.EXN_STACKHEIGHT++] = $ss1570215703;
}
if(R.isPyretException($e1569815699)) {
$e1569815699.pyretStack.push(L[940]);
}
throw $e1569815699;
}
var $ret1570415705 = $Hanf_arg299315710($z1570015701,anf_arg4216483,self536484,_plus26,torepr31);
++R.GAS;
return $ret1570415705;
};
var $Hanf_arg299315710 = function(anf_arg42315709,anf_arg4216483,self536484,_plus26,torepr31) {
var $z1571315714 = D;
var $f1571915720 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg42315709):R.ffi.throwNonFunApp(L[940],_plus26,[(", "),anf_arg42315709]);
};
try {
if(--R.GAS > 0) {
$z1571315714 = $f1571915720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1571915720,
"from":L[940]});
}
} catch($e1571115712) {
if(R.isCont($e1571115712)) {
var $ss1571515716 = {"from":L[940],
"go":function(anf_arg42415721) {
return $Hanf_arg299215722(anf_arg42415721,anf_arg4216483,self536484,_plus26,torepr31);
}};
$e1571115712.stack[R.EXN_STACKHEIGHT++] = $ss1571515716;
}
if(R.isPyretException($e1571115712)) {
$e1571115712.pyretStack.push(L[940]);
}
throw $e1571115712;
}
var $ret1571715718 = $Hanf_arg299215722($z1571315714,anf_arg4216483,self536484,_plus26,torepr31);
++R.GAS;
return $ret1571715718;
};
var $Hanf_arg299215722 = function(anf_arg42415721,anf_arg4216483,self536484,_plus26,torepr31) {
var $z1572515726 = D;
var $f1573115732 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg4216483,anf_arg42415721):R.ffi.throwNonFunApp(L[940],_plus26,[anf_arg4216483,anf_arg42415721]);
};
try {
if(--R.GAS > 0) {
$z1572515726 = $f1573115732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1573115732,
"from":L[940]});
}
} catch($e1572315724) {
if(R.isCont($e1572315724)) {
var $ss1572715728 = {"from":L[940],
"go":function(anf_arg42515733) {
return $Hanf_arg299115734(anf_arg42515733,self536484,_plus26,torepr31);
}};
$e1572315724.stack[R.EXN_STACKHEIGHT++] = $ss1572715728;
}
if(R.isPyretException($e1572315724)) {
$e1572315724.pyretStack.push(L[940]);
}
throw $e1572315724;
}
var $ret1572915730 = $Hanf_arg299115734($z1572515726,self536484,_plus26,torepr31);
++R.GAS;
return $ret1572915730;
};
var $Hanf_arg299115734 = function(anf_arg42515733,self536484,_plus26,torepr31) {
var anf_arg42615745 = G(self536484,"e",L[940]);
var $z1573715738 = D;
var $f1574315744 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg42615745):R.ffi.throwNonFunApp(L[940],torepr31,[anf_arg42615745]);
};
try {
if(--R.GAS > 0) {
$z1573715738 = $f1574315744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1574315744,
"from":L[940]});
}
} catch($e1573515736) {
if(R.isCont($e1573515736)) {
var $ss1573915740 = {"from":L[940],
"go":function(anf_arg42715746) {
return $Hanf_arg299015747(anf_arg42715746,anf_arg42515733,self536484,_plus26,torepr31);
}};
$e1573515736.stack[R.EXN_STACKHEIGHT++] = $ss1573915740;
}
if(R.isPyretException($e1573515736)) {
$e1573515736.pyretStack.push(L[940]);
}
throw $e1573515736;
}
var $ret1574115742 = $Hanf_arg299015747($z1573715738,anf_arg42515733,self536484,_plus26,torepr31);
++R.GAS;
return $ret1574115742;
};
var $Hanf_arg299015747 = function(anf_arg42715746,anf_arg42515733,self536484,_plus26,torepr31) {
var $z1575015751 = D;
var $f1575615757 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg42715746):R.ffi.throwNonFunApp(L[940],_plus26,[(", "),anf_arg42715746]);
};
try {
if(--R.GAS > 0) {
$z1575015751 = $f1575615757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1575615757,
"from":L[940]});
}
} catch($e1574815749) {
if(R.isCont($e1574815749)) {
var $ss1575215753 = {"from":L[940],
"go":function(anf_arg42815758) {
return $Hanf_arg298915759(anf_arg42815758,anf_arg42515733,self536484,_plus26,torepr31);
}};
$e1574815749.stack[R.EXN_STACKHEIGHT++] = $ss1575215753;
}
if(R.isPyretException($e1574815749)) {
$e1574815749.pyretStack.push(L[940]);
}
throw $e1574815749;
}
var $ret1575415755 = $Hanf_arg298915759($z1575015751,anf_arg42515733,self536484,_plus26,torepr31);
++R.GAS;
return $ret1575415755;
};
var $Hanf_arg298915759 = function(anf_arg42815758,anf_arg42515733,self536484,_plus26,torepr31) {
var $z1576215763 = D;
var $f1576815769 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg42515733,anf_arg42815758):R.ffi.throwNonFunApp(L[940],_plus26,[anf_arg42515733,anf_arg42815758]);
};
try {
if(--R.GAS > 0) {
$z1576215763 = $f1576815769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1576815769,
"from":L[940]});
}
} catch($e1576015761) {
if(R.isCont($e1576015761)) {
var $ss1576415765 = {"from":L[940],
"go":function(anf_arg42915770) {
return $Hanf_arg298815771(anf_arg42915770,self536484,_plus26,torepr31);
}};
$e1576015761.stack[R.EXN_STACKHEIGHT++] = $ss1576415765;
}
if(R.isPyretException($e1576015761)) {
$e1576015761.pyretStack.push(L[940]);
}
throw $e1576015761;
}
var $ret1576615767 = $Hanf_arg298815771($z1576215763,self536484,_plus26,torepr31);
++R.GAS;
return $ret1576615767;
};
var $Hanf_arg298815771 = function(anf_arg42915770,self536484,_plus26,torepr31) {
var anf_arg43015782 = G(self536484,"body",L[940]);
var $z1577415775 = D;
var $f1578015781 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg43015782):R.ffi.throwNonFunApp(L[940],torepr31,[anf_arg43015782]);
};
try {
if(--R.GAS > 0) {
$z1577415775 = $f1578015781();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1578015781,
"from":L[940]});
}
} catch($e1577215773) {
if(R.isCont($e1577215773)) {
var $ss1577615777 = {"from":L[940],
"go":function(anf_arg43115783) {
return $Hanf_arg298715784(anf_arg43115783,anf_arg42915770,_plus26);
}};
$e1577215773.stack[R.EXN_STACKHEIGHT++] = $ss1577615777;
}
if(R.isPyretException($e1577215773)) {
$e1577215773.pyretStack.push(L[940]);
}
throw $e1577215773;
}
var $ret1577815779 = $Hanf_arg298715784($z1577415775,anf_arg42915770,_plus26);
++R.GAS;
return $ret1577815779;
};
var $Hanf_arg298715784 = function(anf_arg43115783,anf_arg42915770,_plus26) {
var $z1578715788 = D;
var $f1579315794 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg43115783):R.ffi.throwNonFunApp(L[940],_plus26,[(", "),anf_arg43115783]);
};
try {
if(--R.GAS > 0) {
$z1578715788 = $f1579315794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1579315794,
"from":L[940]});
}
} catch($e1578515786) {
if(R.isCont($e1578515786)) {
var $ss1578915790 = {"from":L[940],
"go":function(anf_arg43215795) {
return $Hanf_arg298615796(anf_arg43215795,anf_arg42915770,_plus26);
}};
$e1578515786.stack[R.EXN_STACKHEIGHT++] = $ss1578915790;
}
if(R.isPyretException($e1578515786)) {
$e1578515786.pyretStack.push(L[940]);
}
throw $e1578515786;
}
var $ret1579115792 = $Hanf_arg298615796($z1578715788,anf_arg42915770,_plus26);
++R.GAS;
return $ret1579115792;
};
var $Hanf_arg298615796 = function(anf_arg43215795,anf_arg42915770,_plus26) {
var $z1579915800 = D;
var $f1580515806 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg42915770,anf_arg43215795):R.ffi.throwNonFunApp(L[940],_plus26,[anf_arg42915770,anf_arg43215795]);
};
try {
if(--R.GAS > 0) {
$z1579915800 = $f1580515806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1580515806,
"from":L[940]});
}
} catch($e1579715798) {
if(R.isCont($e1579715798)) {
var $ss1580115802 = {"from":L[940],
"go":function(anf_arg43315807) {
return $Hanf_arg298515808(anf_arg43315807,_plus26);
}};
$e1579715798.stack[R.EXN_STACKHEIGHT++] = $ss1580115802;
}
if(R.isPyretException($e1579715798)) {
$e1579715798.pyretStack.push(L[940]);
}
throw $e1579715798;
}
var $ret1580315804 = $Hanf_arg298515808($z1579915800,_plus26);
++R.GAS;
return $ret1580315804;
};
var $Hanf_arg298515808 = function(anf_arg43315807,_plus26) {
var $z1581115812 = D;
var $f1581715818 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg43315807,(")")):R.ffi.throwNonFunApp(L[940],_plus26,[anf_arg43315807,(")")]);
};
try {
if(--R.GAS > 0) {
$z1581115812 = $f1581715818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1581715818,
"from":L[940]});
}
} catch($e1580915810) {
if(R.isCont($e1580915810)) {
var $ss1581315814 = {"from":L[940],
"go":function(anf_arg43415819) {
return $Hanf_arg298415820(anf_arg43415819,_plus26);
}};
$e1580915810.stack[R.EXN_STACKHEIGHT++] = $ss1581315814;
}
if(R.isPyretException($e1580915810)) {
$e1580915810.pyretStack.push(L[940]);
}
throw $e1580915810;
}
var $ret1581515816 = $Hanf_arg298415820($z1581115812,_plus26);
++R.GAS;
return $ret1581515816;
};
var $Hanf_arg298415820 = function(anf_arg43415819,_plus26) {
var $z1582315824 = D;
var $f1582915830 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg43415819):R.ffi.throwNonFunApp(L[940],_plus26,[("("),anf_arg43415819]);
};
try {
if(--R.GAS > 0) {
$z1582315824 = $f1582915830();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1582915830,
"from":L[940]});
}
} catch($e1582115822) {
if(R.isCont($e1582115822)) {
var $ss1582515826 = {"from":L[940],
"go":function(anf_arg43515831) {
return $Hanf_arg298315832(anf_arg43515831,_plus26);
}};
$e1582115822.stack[R.EXN_STACKHEIGHT++] = $ss1582515826;
}
if(R.isPyretException($e1582115822)) {
$e1582115822.pyretStack.push(L[940]);
}
throw $e1582115822;
}
var $ret1582715828 = $Hanf_arg298315832($z1582315824,_plus26);
++R.GAS;
return $ret1582715828;
};
var $Hanf_arg298315832 = function(anf_arg43515831,_plus26) {
var $z1583515836 = D;
var $f1584115842 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-let"),anf_arg43515831):R.ffi.throwNonFunApp(L[940],_plus26,[("a-let"),anf_arg43515831]);
};
try {
if(--R.GAS > 0) {
$z1583515836 = $f1584115842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1584115842,
"from":L[940]});
}
} catch($e1583315834) {
if(R.isCont($e1583315834)) {
var $ss1583715838 = {"from":L[940],
"go":function(ann_DASH_check_DASH_temp41915843) {
return $Hann_DASH_check_DASH_temp298215844(ann_DASH_check_DASH_temp41915843);
}};
$e1583315834.stack[R.EXN_STACKHEIGHT++] = $ss1583715838;
}
if(R.isPyretException($e1583315834)) {
$e1583315834.pyretStack.push(L[940]);
}
throw $e1583315834;
}
var $ret1583915840 = $Hann_DASH_check_DASH_temp298215844($z1583515836);
++R.GAS;
return $ret1583915840;
};
var $Hann_DASH_check_DASH_temp298215844 = function(ann_DASH_check_DASH_temp41915843) {
return ann_DASH_check_DASH_temp41915843;
};
var $Hcont_tail_arg29806503 = function(cont_tail_arg4166501,if_helper4056502) {
if(--R.GAS > 0) {
$z1584515846 = R.isFunction(if_helper4056502)?if_helper4056502.app(cont_tail_arg4166501):R.ffi.throwNonFunApp(L[940],if_helper4056502,[cont_tail_arg4166501]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper4056502)?if_helper4056502.app(cont_tail_arg4166501):R.ffi.throwNonFunApp(L[940],if_helper4056502,[cont_tail_arg4166501]);
},
"from":L[940]});
}
++R.GAS;
return $z1584515846;
};
var $Hcont_tail_arg29816518 = function(cont_tail_arg4106517,if_helper4056502) {
if(--R.GAS > 0) {
$z1584715848 = R.isFunction(if_helper4056502)?if_helper4056502.app(cont_tail_arg4106517):R.ffi.throwNonFunApp(L[940],if_helper4056502,[cont_tail_arg4106517]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper4056502)?if_helper4056502.app(cont_tail_arg4106517):R.ffi.throwNonFunApp(L[940],if_helper4056502,[cont_tail_arg4106517]);
},
"from":L[940]});
}
++R.GAS;
return $z1584715848;
};
var $Hanf_arg29796542 = function(anf_arg3956537,INDENT9187,anf_fun3906538,anf_fun3916539,anf_fun3926540,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26) {
var $z1585115852 = D;
var $f1585715858 = function(_) {
return R.isFunction(anf_fun3926540)?anf_fun3926540.app(INDENT9187,anf_arg3956537):R.ffi.throwNonFunApp(L[1622],anf_fun3926540,[INDENT9187,anf_arg3956537]);
};
try {
if(--R.GAS > 0) {
$z1585115852 = $f1585715858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1585715858,
"from":L[1622]});
}
} catch($e1584915850) {
if(R.isCont($e1584915850)) {
var $ss1585315854 = {"from":L[1622],
"go":function(anf_arg39615859) {
return $Hanf_arg297815860(anf_arg39615859,INDENT9187,anf_fun3906538,anf_fun3916539,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26);
}};
$e1584915850.stack[R.EXN_STACKHEIGHT++] = $ss1585315854;
}
if(R.isPyretException($e1584915850)) {
$e1584915850.pyretStack.push(L[1622]);
}
throw $e1584915850;
}
var $ret1585515856 = $Hanf_arg297815860($z1585115852,INDENT9187,anf_fun3906538,anf_fun3916539,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26);
++R.GAS;
return $ret1585515856;
};
var $Hanf_arg297815860 = function(anf_arg39615859,INDENT9187,anf_fun3906538,anf_fun3916539,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26) {
var $z1586315864 = D;
var $f1586915870 = function(_) {
return R.isFunction(anf_fun3916539)?anf_fun3916539.app(anf_arg39615859):R.ffi.throwNonFunApp(L[1623],anf_fun3916539,[anf_arg39615859]);
};
try {
if(--R.GAS > 0) {
$z1586315864 = $f1586915870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1586915870,
"from":L[1623]});
}
} catch($e1586115862) {
if(R.isCont($e1586115862)) {
var $ss1586515866 = {"from":L[1623],
"go":function(anf_arg39715871) {
return $Hanf_arg297715872(anf_arg39715871,INDENT9187,anf_fun3906538,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26);
}};
$e1586115862.stack[R.EXN_STACKHEIGHT++] = $ss1586515866;
}
if(R.isPyretException($e1586115862)) {
$e1586115862.pyretStack.push(L[1623]);
}
throw $e1586115862;
}
var $ret1586715868 = $Hanf_arg297715872($z1586315864,INDENT9187,anf_fun3906538,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26);
++R.GAS;
return $ret1586715868;
};
var $Hanf_arg297715872 = function(anf_arg39715871,INDENT9187,anf_fun3906538,self2976541,str_DASH_colon98170,str_DASH_end101209,str_DASH_type_DASH_let102222,_plus26) {
var $z1587515876 = D;
var $f1588115882 = function(_) {
return R.isFunction(_plus26)?_plus26.app(str_DASH_type_DASH_let102222,anf_arg39715871):R.ffi.throwNonFunApp(L[1624],_plus26,[str_DASH_type_DASH_let102222,anf_arg39715871]);
};
try {
if(--R.GAS > 0) {
$z1587515876 = $f1588115882();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1588115882,
"from":L[1624]});
}
} catch($e1587315874) {
if(R.isCont($e1587315874)) {
var $ss1587715878 = {"from":L[1624],
"go":function(anf_arg39815883) {
return $Hanf_arg297615884(anf_arg39815883,INDENT9187,anf_fun3906538,self2976541,str_DASH_colon98170,str_DASH_end101209,_plus26);
}};
$e1587315874.stack[R.EXN_STACKHEIGHT++] = $ss1587715878;
}
if(R.isPyretException($e1587315874)) {
$e1587315874.pyretStack.push(L[1624]);
}
throw $e1587315874;
}
var $ret1587915880 = $Hanf_arg297615884($z1587515876,INDENT9187,anf_fun3906538,self2976541,str_DASH_colon98170,str_DASH_end101209,_plus26);
++R.GAS;
return $ret1587915880;
};
var $Hanf_arg297615884 = function(anf_arg39815883,INDENT9187,anf_fun3906538,self2976541,str_DASH_colon98170,str_DASH_end101209,_plus26) {
var $z1588715888 = D;
var $f1589315894 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg39815883,str_DASH_colon98170):R.ffi.throwNonFunApp(L[1624],_plus26,[anf_arg39815883,str_DASH_colon98170]);
};
try {
if(--R.GAS > 0) {
$z1588715888 = $f1589315894();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1589315894,
"from":L[1624]});
}
} catch($e1588515886) {
if(R.isCont($e1588515886)) {
var $ss1588915890 = {"from":L[1624],
"go":function(anf_arg39915895) {
return $Hanf_arg297515896(anf_arg39915895,INDENT9187,anf_fun3906538,self2976541,str_DASH_end101209);
}};
$e1588515886.stack[R.EXN_STACKHEIGHT++] = $ss1588915890;
}
if(R.isPyretException($e1588515886)) {
$e1588515886.pyretStack.push(L[1624]);
}
throw $e1588515886;
}
var $ret1589115892 = $Hanf_arg297515896($z1588715888,INDENT9187,anf_fun3906538,self2976541,str_DASH_end101209);
++R.GAS;
return $ret1589115892;
};
var $Hanf_arg297515896 = function(anf_arg39915895,INDENT9187,anf_fun3906538,self2976541,str_DASH_end101209) {
var anf_bracket40015910 = G(self2976541,"body",L[1627]);
var anf_fun40115907 = G(anf_bracket40015910,"tosource",L[1626]);
var $z1589915900 = D;
var $f1590515906 = function(_) {
return R.isFunction(anf_fun40115907)?anf_fun40115907.app():R.ffi.throwNonFunApp(L[1625],anf_fun40115907,[]);
};
try {
if(--R.GAS > 0) {
$z1589915900 = $f1590515906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1590515906,
"from":L[1625]});
}
} catch($e1589715898) {
if(R.isCont($e1589715898)) {
var $ss1590115902 = {"from":L[1625],
"go":function(anf_arg40215908) {
return $Hanf_arg297415909(anf_arg40215908,INDENT9187,anf_arg39915895,anf_fun3906538,str_DASH_end101209);
}};
$e1589715898.stack[R.EXN_STACKHEIGHT++] = $ss1590115902;
}
if(R.isPyretException($e1589715898)) {
$e1589715898.pyretStack.push(L[1625]);
}
throw $e1589715898;
}
var $ret1590315904 = $Hanf_arg297415909($z1589915900,INDENT9187,anf_arg39915895,anf_fun3906538,str_DASH_end101209);
++R.GAS;
return $ret1590315904;
};
var $Hanf_arg297415909 = function(anf_arg40215908,INDENT9187,anf_arg39915895,anf_fun3906538,str_DASH_end101209) {
var $z1591315914 = D;
var $f1591915920 = function(_) {
return R.isFunction(anf_fun3906538)?anf_fun3906538.app(INDENT9187,(1),anf_arg39915895,anf_arg40215908,str_DASH_end101209):R.ffi.throwNonFunApp(L[1053],anf_fun3906538,[INDENT9187,(1),anf_arg39915895,anf_arg40215908,str_DASH_end101209]);
};
try {
if(--R.GAS > 0) {
$z1591315914 = $f1591915920();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1591915920,
"from":L[1053]});
}
} catch($e1591115912) {
if(R.isCont($e1591115912)) {
var $ss1591515916 = {"from":L[1053],
"go":function(ann_DASH_check_DASH_temp38915921) {
return $Hann_DASH_check_DASH_temp297315922(ann_DASH_check_DASH_temp38915921);
}};
$e1591115912.stack[R.EXN_STACKHEIGHT++] = $ss1591515916;
}
if(R.isPyretException($e1591115912)) {
$e1591115912.pyretStack.push(L[1053]);
}
throw $e1591115912;
}
var $ret1591715918 = $Hann_DASH_check_DASH_temp297315922($z1591315914);
++R.GAS;
return $ret1591715918;
};
var $Hann_DASH_check_DASH_temp297315922 = function(ann_DASH_check_DASH_temp38915921) {
return ann_DASH_check_DASH_temp38915921;
};
var $Hanf_arg29726559 = function(anf_arg3756557,self476558,_plus26,torepr31) {
var anf_arg37615933 = G(self476558,"bind",L[941]);
var $z1592515926 = D;
var $f1593115932 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg37615933):R.ffi.throwNonFunApp(L[941],torepr31,[anf_arg37615933]);
};
try {
if(--R.GAS > 0) {
$z1592515926 = $f1593115932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1593115932,
"from":L[941]});
}
} catch($e1592315924) {
if(R.isCont($e1592315924)) {
var $ss1592715928 = {"from":L[941],
"go":function(anf_arg37715934) {
return $Hanf_arg297115935(anf_arg37715934,anf_arg3756557,self476558,_plus26,torepr31);
}};
$e1592315924.stack[R.EXN_STACKHEIGHT++] = $ss1592715928;
}
if(R.isPyretException($e1592315924)) {
$e1592315924.pyretStack.push(L[941]);
}
throw $e1592315924;
}
var $ret1592915930 = $Hanf_arg297115935($z1592515926,anf_arg3756557,self476558,_plus26,torepr31);
++R.GAS;
return $ret1592915930;
};
var $Hanf_arg297115935 = function(anf_arg37715934,anf_arg3756557,self476558,_plus26,torepr31) {
var $z1593815939 = D;
var $f1594415945 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg37715934):R.ffi.throwNonFunApp(L[941],_plus26,[(", "),anf_arg37715934]);
};
try {
if(--R.GAS > 0) {
$z1593815939 = $f1594415945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1594415945,
"from":L[941]});
}
} catch($e1593615937) {
if(R.isCont($e1593615937)) {
var $ss1594015941 = {"from":L[941],
"go":function(anf_arg37815946) {
return $Hanf_arg297015947(anf_arg37815946,anf_arg3756557,self476558,_plus26,torepr31);
}};
$e1593615937.stack[R.EXN_STACKHEIGHT++] = $ss1594015941;
}
if(R.isPyretException($e1593615937)) {
$e1593615937.pyretStack.push(L[941]);
}
throw $e1593615937;
}
var $ret1594215943 = $Hanf_arg297015947($z1593815939,anf_arg3756557,self476558,_plus26,torepr31);
++R.GAS;
return $ret1594215943;
};
var $Hanf_arg297015947 = function(anf_arg37815946,anf_arg3756557,self476558,_plus26,torepr31) {
var $z1595015951 = D;
var $f1595615957 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg3756557,anf_arg37815946):R.ffi.throwNonFunApp(L[941],_plus26,[anf_arg3756557,anf_arg37815946]);
};
try {
if(--R.GAS > 0) {
$z1595015951 = $f1595615957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1595615957,
"from":L[941]});
}
} catch($e1594815949) {
if(R.isCont($e1594815949)) {
var $ss1595215953 = {"from":L[941],
"go":function(anf_arg37915958) {
return $Hanf_arg296915959(anf_arg37915958,self476558,_plus26,torepr31);
}};
$e1594815949.stack[R.EXN_STACKHEIGHT++] = $ss1595215953;
}
if(R.isPyretException($e1594815949)) {
$e1594815949.pyretStack.push(L[941]);
}
throw $e1594815949;
}
var $ret1595415955 = $Hanf_arg296915959($z1595015951,self476558,_plus26,torepr31);
++R.GAS;
return $ret1595415955;
};
var $Hanf_arg296915959 = function(anf_arg37915958,self476558,_plus26,torepr31) {
var anf_arg38015970 = G(self476558,"body",L[941]);
var $z1596215963 = D;
var $f1596815969 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg38015970):R.ffi.throwNonFunApp(L[941],torepr31,[anf_arg38015970]);
};
try {
if(--R.GAS > 0) {
$z1596215963 = $f1596815969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1596815969,
"from":L[941]});
}
} catch($e1596015961) {
if(R.isCont($e1596015961)) {
var $ss1596415965 = {"from":L[941],
"go":function(anf_arg38115971) {
return $Hanf_arg296815972(anf_arg38115971,anf_arg37915958,_plus26);
}};
$e1596015961.stack[R.EXN_STACKHEIGHT++] = $ss1596415965;
}
if(R.isPyretException($e1596015961)) {
$e1596015961.pyretStack.push(L[941]);
}
throw $e1596015961;
}
var $ret1596615967 = $Hanf_arg296815972($z1596215963,anf_arg37915958,_plus26);
++R.GAS;
return $ret1596615967;
};
var $Hanf_arg296815972 = function(anf_arg38115971,anf_arg37915958,_plus26) {
var $z1597515976 = D;
var $f1598115982 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg38115971):R.ffi.throwNonFunApp(L[941],_plus26,[(", "),anf_arg38115971]);
};
try {
if(--R.GAS > 0) {
$z1597515976 = $f1598115982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1598115982,
"from":L[941]});
}
} catch($e1597315974) {
if(R.isCont($e1597315974)) {
var $ss1597715978 = {"from":L[941],
"go":function(anf_arg38215983) {
return $Hanf_arg296715984(anf_arg38215983,anf_arg37915958,_plus26);
}};
$e1597315974.stack[R.EXN_STACKHEIGHT++] = $ss1597715978;
}
if(R.isPyretException($e1597315974)) {
$e1597315974.pyretStack.push(L[941]);
}
throw $e1597315974;
}
var $ret1597915980 = $Hanf_arg296715984($z1597515976,anf_arg37915958,_plus26);
++R.GAS;
return $ret1597915980;
};
var $Hanf_arg296715984 = function(anf_arg38215983,anf_arg37915958,_plus26) {
var $z1598715988 = D;
var $f1599315994 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg37915958,anf_arg38215983):R.ffi.throwNonFunApp(L[941],_plus26,[anf_arg37915958,anf_arg38215983]);
};
try {
if(--R.GAS > 0) {
$z1598715988 = $f1599315994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1599315994,
"from":L[941]});
}
} catch($e1598515986) {
if(R.isCont($e1598515986)) {
var $ss1598915990 = {"from":L[941],
"go":function(anf_arg38315995) {
return $Hanf_arg296615996(anf_arg38315995,_plus26);
}};
$e1598515986.stack[R.EXN_STACKHEIGHT++] = $ss1598915990;
}
if(R.isPyretException($e1598515986)) {
$e1598515986.pyretStack.push(L[941]);
}
throw $e1598515986;
}
var $ret1599115992 = $Hanf_arg296615996($z1598715988,_plus26);
++R.GAS;
return $ret1599115992;
};
var $Hanf_arg296615996 = function(anf_arg38315995,_plus26) {
var $z1599916000 = D;
var $f1600516006 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg38315995,(")")):R.ffi.throwNonFunApp(L[941],_plus26,[anf_arg38315995,(")")]);
};
try {
if(--R.GAS > 0) {
$z1599916000 = $f1600516006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1600516006,
"from":L[941]});
}
} catch($e1599715998) {
if(R.isCont($e1599715998)) {
var $ss1600116002 = {"from":L[941],
"go":function(anf_arg38416007) {
return $Hanf_arg296516008(anf_arg38416007,_plus26);
}};
$e1599715998.stack[R.EXN_STACKHEIGHT++] = $ss1600116002;
}
if(R.isPyretException($e1599715998)) {
$e1599715998.pyretStack.push(L[941]);
}
throw $e1599715998;
}
var $ret1600316004 = $Hanf_arg296516008($z1599916000,_plus26);
++R.GAS;
return $ret1600316004;
};
var $Hanf_arg296516008 = function(anf_arg38416007,_plus26) {
var $z1601116012 = D;
var $f1601716018 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg38416007):R.ffi.throwNonFunApp(L[941],_plus26,[("("),anf_arg38416007]);
};
try {
if(--R.GAS > 0) {
$z1601116012 = $f1601716018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1601716018,
"from":L[941]});
}
} catch($e1600916010) {
if(R.isCont($e1600916010)) {
var $ss1601316014 = {"from":L[941],
"go":function(anf_arg38516019) {
return $Hanf_arg296416020(anf_arg38516019,_plus26);
}};
$e1600916010.stack[R.EXN_STACKHEIGHT++] = $ss1601316014;
}
if(R.isPyretException($e1600916010)) {
$e1600916010.pyretStack.push(L[941]);
}
throw $e1600916010;
}
var $ret1601516016 = $Hanf_arg296416020($z1601116012,_plus26);
++R.GAS;
return $ret1601516016;
};
var $Hanf_arg296416020 = function(anf_arg38516019,_plus26) {
var $z1602316024 = D;
var $f1602916030 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-type-let"),anf_arg38516019):R.ffi.throwNonFunApp(L[941],_plus26,[("a-type-let"),anf_arg38516019]);
};
try {
if(--R.GAS > 0) {
$z1602316024 = $f1602916030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1602916030,
"from":L[941]});
}
} catch($e1602116022) {
if(R.isCont($e1602116022)) {
var $ss1602516026 = {"from":L[941],
"go":function(ann_DASH_check_DASH_temp37316031) {
return $Hann_DASH_check_DASH_temp296316032(ann_DASH_check_DASH_temp37316031);
}};
$e1602116022.stack[R.EXN_STACKHEIGHT++] = $ss1602516026;
}
if(R.isPyretException($e1602116022)) {
$e1602116022.pyretStack.push(L[941]);
}
throw $e1602116022;
}
var $ret1602716028 = $Hann_DASH_check_DASH_temp296316032($z1602316024);
++R.GAS;
return $ret1602716028;
};
var $Hann_DASH_check_DASH_temp296316032 = function(ann_DASH_check_DASH_temp37316031) {
return ann_DASH_check_DASH_temp37316031;
};
var $Hcont_tail_arg29616576 = function(cont_tail_arg3706574,if_helper3606575) {
if(--R.GAS > 0) {
$z1603316034 = R.isFunction(if_helper3606575)?if_helper3606575.app(cont_tail_arg3706574):R.ffi.throwNonFunApp(L[941],if_helper3606575,[cont_tail_arg3706574]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper3606575)?if_helper3606575.app(cont_tail_arg3706574):R.ffi.throwNonFunApp(L[941],if_helper3606575,[cont_tail_arg3706574]);
},
"from":L[941]});
}
++R.GAS;
return $z1603316034;
};
var $Hcont_tail_arg29626591 = function(cont_tail_arg3656590,if_helper3606575) {
if(--R.GAS > 0) {
$z1603516036 = R.isFunction(if_helper3606575)?if_helper3606575.app(cont_tail_arg3656590):R.ffi.throwNonFunApp(L[941],if_helper3606575,[cont_tail_arg3656590]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper3606575)?if_helper3606575.app(cont_tail_arg3656590):R.ffi.throwNonFunApp(L[941],if_helper3606575,[cont_tail_arg3656590]);
},
"from":L[941]});
}
++R.GAS;
return $z1603516036;
};
var $Hann_DASH_check_DASH_temp29606613 = function(ann_DASH_check_DASH_temp3516612) {
return ann_DASH_check_DASH_temp3516612;
};
var $Hanf_arg29596626 = function(anf_arg3556625,_plus26,raise30) {
var $z1603916040 = D;
var $f1604516046 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg3556625):R.ffi.throwNonFunApp(L[1628],_plus26,[("No visitor field for "),anf_arg3556625]);
};
try {
if(--R.GAS > 0) {
$z1603916040 = $f1604516046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1604516046,
"from":L[1628]});
}
} catch($e1603716038) {
if(R.isCont($e1603716038)) {
var $ss1604116042 = {"from":L[1628],
"go":function(anf_arg35616047) {
return $Hanf_arg295816048(anf_arg35616047,raise30);
}};
$e1603716038.stack[R.EXN_STACKHEIGHT++] = $ss1604116042;
}
if(R.isPyretException($e1603716038)) {
$e1603716038.pyretStack.push(L[1628]);
}
throw $e1603716038;
}
var $ret1604316044 = $Hanf_arg295816048($z1603916040,raise30);
++R.GAS;
return $ret1604316044;
};
var $Hanf_arg295816048 = function(anf_arg35616047,raise30) {
var $z1605116052 = D;
var $f1605716058 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg35616047):R.ffi.throwNonFunApp(L[1059],raise30,[anf_arg35616047]);
};
try {
if(--R.GAS > 0) {
$z1605116052 = $f1605716058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1605716058,
"from":L[1059]});
}
} catch($e1604916050) {
if(R.isCont($e1604916050)) {
var $ss1605316054 = {"from":L[1059],
"go":function(ann_DASH_check_DASH_temp35316059) {
return $Hann_DASH_check_DASH_temp295716060(ann_DASH_check_DASH_temp35316059);
}};
$e1604916050.stack[R.EXN_STACKHEIGHT++] = $ss1605316054;
}
if(R.isPyretException($e1604916050)) {
$e1604916050.pyretStack.push(L[1059]);
}
throw $e1604916050;
}
var $ret1605516056 = $Hann_DASH_check_DASH_temp295716060($z1605116052);
++R.GAS;
return $ret1605516056;
};
var $Hann_DASH_check_DASH_temp295716060 = function(ann_DASH_check_DASH_temp35316059) {
return ann_DASH_check_DASH_temp35316059;
};
var $Hanf_arg29566667 = function(anf_arg3346664,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,str_DASH_newtype114378,_plus26) {
var $z1606316064 = D;
var $f1606916070 = function(_) {
return R.isFunction(_plus26)?_plus26.app(str_DASH_newtype114378,anf_arg3346664):R.ffi.throwNonFunApp(L[1629],_plus26,[str_DASH_newtype114378,anf_arg3346664]);
};
try {
if(--R.GAS > 0) {
$z1606316064 = $f1606916070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1606916070,
"from":L[1629]});
}
} catch($e1606116062) {
if(R.isCont($e1606116062)) {
var $ss1606516066 = {"from":L[1629],
"go":function(anf_arg33516071) {
return $Hanf_arg295516072(anf_arg33516071,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,_plus26);
}};
$e1606116062.stack[R.EXN_STACKHEIGHT++] = $ss1606516066;
}
if(R.isPyretException($e1606116062)) {
$e1606116062.pyretStack.push(L[1629]);
}
throw $e1606116062;
}
var $ret1606716068 = $Hanf_arg295516072($z1606316064,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,_plus26);
++R.GAS;
return $ret1606716068;
};
var $Hanf_arg295516072 = function(anf_arg33516071,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,_plus26) {
var $z1607516076 = D;
var $f1608116082 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg33516071,break_DASH_one9262):R.ffi.throwNonFunApp(L[1629],_plus26,[anf_arg33516071,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1607516076 = $f1608116082();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1608116082,
"from":L[1629]});
}
} catch($e1607316074) {
if(R.isCont($e1607316074)) {
var $ss1607716078 = {"from":L[1629],
"go":function(anf_arg33616083) {
return $Hanf_arg295416084(anf_arg33616083,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,_plus26);
}};
$e1607316074.stack[R.EXN_STACKHEIGHT++] = $ss1607716078;
}
if(R.isPyretException($e1607316074)) {
$e1607316074.pyretStack.push(L[1629]);
}
throw $e1607316074;
}
var $ret1607916080 = $Hanf_arg295416084($z1607516076,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,_plus26);
++R.GAS;
return $ret1607916080;
};
var $Hanf_arg295416084 = function(anf_arg33616083,anf_fun3316665,break_DASH_one9262,self2906666,str_DASH_as113365,_plus26) {
var $z1608716088 = D;
var $f1609316094 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg33616083,str_DASH_as113365):R.ffi.throwNonFunApp(L[1629],_plus26,[anf_arg33616083,str_DASH_as113365]);
};
try {
if(--R.GAS > 0) {
$z1608716088 = $f1609316094();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1609316094,
"from":L[1629]});
}
} catch($e1608516086) {
if(R.isCont($e1608516086)) {
var $ss1608916090 = {"from":L[1629],
"go":function(anf_arg33716095) {
return $Hanf_arg295316096(anf_arg33716095,anf_fun3316665,break_DASH_one9262,self2906666,_plus26);
}};
$e1608516086.stack[R.EXN_STACKHEIGHT++] = $ss1608916090;
}
if(R.isPyretException($e1608516086)) {
$e1608516086.pyretStack.push(L[1629]);
}
throw $e1608516086;
}
var $ret1609116092 = $Hanf_arg295316096($z1608716088,anf_fun3316665,break_DASH_one9262,self2906666,_plus26);
++R.GAS;
return $ret1609116092;
};
var $Hanf_arg295316096 = function(anf_arg33716095,anf_fun3316665,break_DASH_one9262,self2906666,_plus26) {
var $z1609916100 = D;
var $f1610516106 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg33716095,break_DASH_one9262):R.ffi.throwNonFunApp(L[1629],_plus26,[anf_arg33716095,break_DASH_one9262]);
};
try {
if(--R.GAS > 0) {
$z1609916100 = $f1610516106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1610516106,
"from":L[1629]});
}
} catch($e1609716098) {
if(R.isCont($e1609716098)) {
var $ss1610116102 = {"from":L[1629],
"go":function(anf_arg33816107) {
return $Hanf_arg295216108(anf_arg33816107,anf_fun3316665,self2906666,_plus26);
}};
$e1609716098.stack[R.EXN_STACKHEIGHT++] = $ss1610116102;
}
if(R.isPyretException($e1609716098)) {
$e1609716098.pyretStack.push(L[1629]);
}
throw $e1609716098;
}
var $ret1610316104 = $Hanf_arg295216108($z1609916100,anf_fun3316665,self2906666,_plus26);
++R.GAS;
return $ret1610316104;
};
var $Hanf_arg295216108 = function(anf_arg33816107,anf_fun3316665,self2906666,_plus26) {
var anf_bracket33916122 = G(self2906666,"namet",L[1632]);
var anf_fun34016119 = G(anf_bracket33916122,"tosource",L[1631]);
var $z1611116112 = D;
var $f1611716118 = function(_) {
return R.isFunction(anf_fun34016119)?anf_fun34016119.app():R.ffi.throwNonFunApp(L[1630],anf_fun34016119,[]);
};
try {
if(--R.GAS > 0) {
$z1611116112 = $f1611716118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1611716118,
"from":L[1630]});
}
} catch($e1610916110) {
if(R.isCont($e1610916110)) {
var $ss1611316114 = {"from":L[1630],
"go":function(anf_arg34116120) {
return $Hanf_arg295116121(anf_arg34116120,anf_arg33816107,anf_fun3316665,_plus26);
}};
$e1610916110.stack[R.EXN_STACKHEIGHT++] = $ss1611316114;
}
if(R.isPyretException($e1610916110)) {
$e1610916110.pyretStack.push(L[1630]);
}
throw $e1610916110;
}
var $ret1611516116 = $Hanf_arg295116121($z1611116112,anf_arg33816107,anf_fun3316665,_plus26);
++R.GAS;
return $ret1611516116;
};
var $Hanf_arg295116121 = function(anf_arg34116120,anf_arg33816107,anf_fun3316665,_plus26) {
var $z1612516126 = D;
var $f1613116132 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg33816107,anf_arg34116120):R.ffi.throwNonFunApp(L[1629],_plus26,[anf_arg33816107,anf_arg34116120]);
};
try {
if(--R.GAS > 0) {
$z1612516126 = $f1613116132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1613116132,
"from":L[1629]});
}
} catch($e1612316124) {
if(R.isCont($e1612316124)) {
var $ss1612716128 = {"from":L[1629],
"go":function(anf_arg34216133) {
return $Hanf_arg295016134(anf_arg34216133,anf_fun3316665);
}};
$e1612316124.stack[R.EXN_STACKHEIGHT++] = $ss1612716128;
}
if(R.isPyretException($e1612316124)) {
$e1612316124.pyretStack.push(L[1629]);
}
throw $e1612316124;
}
var $ret1612916130 = $Hanf_arg295016134($z1612516126,anf_fun3316665);
++R.GAS;
return $ret1612916130;
};
var $Hanf_arg295016134 = function(anf_arg34216133,anf_fun3316665) {
var $z1613716138 = D;
var $f1614316144 = function(_) {
return R.isFunction(anf_fun3316665)?anf_fun3316665.app(anf_arg34216133):R.ffi.throwNonFunApp(L[1078],anf_fun3316665,[anf_arg34216133]);
};
try {
if(--R.GAS > 0) {
$z1613716138 = $f1614316144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1614316144,
"from":L[1078]});
}
} catch($e1613516136) {
if(R.isCont($e1613516136)) {
var $ss1613916140 = {"from":L[1078],
"go":function(ann_DASH_check_DASH_temp33016145) {
return $Hann_DASH_check_DASH_temp294916146(ann_DASH_check_DASH_temp33016145);
}};
$e1613516136.stack[R.EXN_STACKHEIGHT++] = $ss1613916140;
}
if(R.isPyretException($e1613516136)) {
$e1613516136.pyretStack.push(L[1078]);
}
throw $e1613516136;
}
var $ret1614116142 = $Hann_DASH_check_DASH_temp294916146($z1613716138);
++R.GAS;
return $ret1614116142;
};
var $Hann_DASH_check_DASH_temp294916146 = function(ann_DASH_check_DASH_temp33016145) {
return ann_DASH_check_DASH_temp33016145;
};
var $Hanf_arg29486684 = function(anf_arg3166682,self416683,_plus26,torepr31) {
var anf_arg31716157 = G(self416683,"name",L[1063]);
var $z1614916150 = D;
var $f1615516156 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg31716157):R.ffi.throwNonFunApp(L[1063],torepr31,[anf_arg31716157]);
};
try {
if(--R.GAS > 0) {
$z1614916150 = $f1615516156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1615516156,
"from":L[1063]});
}
} catch($e1614716148) {
if(R.isCont($e1614716148)) {
var $ss1615116152 = {"from":L[1063],
"go":function(anf_arg31816158) {
return $Hanf_arg294716159(anf_arg31816158,anf_arg3166682,self416683,_plus26,torepr31);
}};
$e1614716148.stack[R.EXN_STACKHEIGHT++] = $ss1615116152;
}
if(R.isPyretException($e1614716148)) {
$e1614716148.pyretStack.push(L[1063]);
}
throw $e1614716148;
}
var $ret1615316154 = $Hanf_arg294716159($z1614916150,anf_arg3166682,self416683,_plus26,torepr31);
++R.GAS;
return $ret1615316154;
};
var $Hanf_arg294716159 = function(anf_arg31816158,anf_arg3166682,self416683,_plus26,torepr31) {
var $z1616216163 = D;
var $f1616816169 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg31816158):R.ffi.throwNonFunApp(L[1063],_plus26,[(", "),anf_arg31816158]);
};
try {
if(--R.GAS > 0) {
$z1616216163 = $f1616816169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1616816169,
"from":L[1063]});
}
} catch($e1616016161) {
if(R.isCont($e1616016161)) {
var $ss1616416165 = {"from":L[1063],
"go":function(anf_arg31916170) {
return $Hanf_arg294616171(anf_arg31916170,anf_arg3166682,self416683,_plus26,torepr31);
}};
$e1616016161.stack[R.EXN_STACKHEIGHT++] = $ss1616416165;
}
if(R.isPyretException($e1616016161)) {
$e1616016161.pyretStack.push(L[1063]);
}
throw $e1616016161;
}
var $ret1616616167 = $Hanf_arg294616171($z1616216163,anf_arg3166682,self416683,_plus26,torepr31);
++R.GAS;
return $ret1616616167;
};
var $Hanf_arg294616171 = function(anf_arg31916170,anf_arg3166682,self416683,_plus26,torepr31) {
var $z1617416175 = D;
var $f1618016181 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg3166682,anf_arg31916170):R.ffi.throwNonFunApp(L[1063],_plus26,[anf_arg3166682,anf_arg31916170]);
};
try {
if(--R.GAS > 0) {
$z1617416175 = $f1618016181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1618016181,
"from":L[1063]});
}
} catch($e1617216173) {
if(R.isCont($e1617216173)) {
var $ss1617616177 = {"from":L[1063],
"go":function(anf_arg32016182) {
return $Hanf_arg294516183(anf_arg32016182,self416683,_plus26,torepr31);
}};
$e1617216173.stack[R.EXN_STACKHEIGHT++] = $ss1617616177;
}
if(R.isPyretException($e1617216173)) {
$e1617216173.pyretStack.push(L[1063]);
}
throw $e1617216173;
}
var $ret1617816179 = $Hanf_arg294516183($z1617416175,self416683,_plus26,torepr31);
++R.GAS;
return $ret1617816179;
};
var $Hanf_arg294516183 = function(anf_arg32016182,self416683,_plus26,torepr31) {
var anf_arg32116194 = G(self416683,"namet",L[1063]);
var $z1618616187 = D;
var $f1619216193 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg32116194):R.ffi.throwNonFunApp(L[1063],torepr31,[anf_arg32116194]);
};
try {
if(--R.GAS > 0) {
$z1618616187 = $f1619216193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1619216193,
"from":L[1063]});
}
} catch($e1618416185) {
if(R.isCont($e1618416185)) {
var $ss1618816189 = {"from":L[1063],
"go":function(anf_arg32216195) {
return $Hanf_arg294416196(anf_arg32216195,anf_arg32016182,_plus26);
}};
$e1618416185.stack[R.EXN_STACKHEIGHT++] = $ss1618816189;
}
if(R.isPyretException($e1618416185)) {
$e1618416185.pyretStack.push(L[1063]);
}
throw $e1618416185;
}
var $ret1619016191 = $Hanf_arg294416196($z1618616187,anf_arg32016182,_plus26);
++R.GAS;
return $ret1619016191;
};
var $Hanf_arg294416196 = function(anf_arg32216195,anf_arg32016182,_plus26) {
var $z1619916200 = D;
var $f1620516206 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg32216195):R.ffi.throwNonFunApp(L[1063],_plus26,[(", "),anf_arg32216195]);
};
try {
if(--R.GAS > 0) {
$z1619916200 = $f1620516206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1620516206,
"from":L[1063]});
}
} catch($e1619716198) {
if(R.isCont($e1619716198)) {
var $ss1620116202 = {"from":L[1063],
"go":function(anf_arg32316207) {
return $Hanf_arg294316208(anf_arg32316207,anf_arg32016182,_plus26);
}};
$e1619716198.stack[R.EXN_STACKHEIGHT++] = $ss1620116202;
}
if(R.isPyretException($e1619716198)) {
$e1619716198.pyretStack.push(L[1063]);
}
throw $e1619716198;
}
var $ret1620316204 = $Hanf_arg294316208($z1619916200,anf_arg32016182,_plus26);
++R.GAS;
return $ret1620316204;
};
var $Hanf_arg294316208 = function(anf_arg32316207,anf_arg32016182,_plus26) {
var $z1621116212 = D;
var $f1621716218 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg32016182,anf_arg32316207):R.ffi.throwNonFunApp(L[1063],_plus26,[anf_arg32016182,anf_arg32316207]);
};
try {
if(--R.GAS > 0) {
$z1621116212 = $f1621716218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1621716218,
"from":L[1063]});
}
} catch($e1620916210) {
if(R.isCont($e1620916210)) {
var $ss1621316214 = {"from":L[1063],
"go":function(anf_arg32416219) {
return $Hanf_arg294216220(anf_arg32416219,_plus26);
}};
$e1620916210.stack[R.EXN_STACKHEIGHT++] = $ss1621316214;
}
if(R.isPyretException($e1620916210)) {
$e1620916210.pyretStack.push(L[1063]);
}
throw $e1620916210;
}
var $ret1621516216 = $Hanf_arg294216220($z1621116212,_plus26);
++R.GAS;
return $ret1621516216;
};
var $Hanf_arg294216220 = function(anf_arg32416219,_plus26) {
var $z1622316224 = D;
var $f1622916230 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg32416219,(")")):R.ffi.throwNonFunApp(L[1063],_plus26,[anf_arg32416219,(")")]);
};
try {
if(--R.GAS > 0) {
$z1622316224 = $f1622916230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1622916230,
"from":L[1063]});
}
} catch($e1622116222) {
if(R.isCont($e1622116222)) {
var $ss1622516226 = {"from":L[1063],
"go":function(anf_arg32516231) {
return $Hanf_arg294116232(anf_arg32516231,_plus26);
}};
$e1622116222.stack[R.EXN_STACKHEIGHT++] = $ss1622516226;
}
if(R.isPyretException($e1622116222)) {
$e1622116222.pyretStack.push(L[1063]);
}
throw $e1622116222;
}
var $ret1622716228 = $Hanf_arg294116232($z1622316224,_plus26);
++R.GAS;
return $ret1622716228;
};
var $Hanf_arg294116232 = function(anf_arg32516231,_plus26) {
var $z1623516236 = D;
var $f1624116242 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg32516231):R.ffi.throwNonFunApp(L[1063],_plus26,[("("),anf_arg32516231]);
};
try {
if(--R.GAS > 0) {
$z1623516236 = $f1624116242();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1624116242,
"from":L[1063]});
}
} catch($e1623316234) {
if(R.isCont($e1623316234)) {
var $ss1623716238 = {"from":L[1063],
"go":function(anf_arg32616243) {
return $Hanf_arg294016244(anf_arg32616243,_plus26);
}};
$e1623316234.stack[R.EXN_STACKHEIGHT++] = $ss1623716238;
}
if(R.isPyretException($e1623316234)) {
$e1623316234.pyretStack.push(L[1063]);
}
throw $e1623316234;
}
var $ret1623916240 = $Hanf_arg294016244($z1623516236,_plus26);
++R.GAS;
return $ret1623916240;
};
var $Hanf_arg294016244 = function(anf_arg32616243,_plus26) {
var $z1624716248 = D;
var $f1625316254 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-newtype-bind"),anf_arg32616243):R.ffi.throwNonFunApp(L[1063],_plus26,[("a-newtype-bind"),anf_arg32616243]);
};
try {
if(--R.GAS > 0) {
$z1624716248 = $f1625316254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1625316254,
"from":L[1063]});
}
} catch($e1624516246) {
if(R.isCont($e1624516246)) {
var $ss1624916250 = {"from":L[1063],
"go":function(ann_DASH_check_DASH_temp31416255) {
return $Hann_DASH_check_DASH_temp293916256(ann_DASH_check_DASH_temp31416255);
}};
$e1624516246.stack[R.EXN_STACKHEIGHT++] = $ss1624916250;
}
if(R.isPyretException($e1624516246)) {
$e1624516246.pyretStack.push(L[1063]);
}
throw $e1624516246;
}
var $ret1625116252 = $Hann_DASH_check_DASH_temp293916256($z1624716248);
++R.GAS;
return $ret1625116252;
};
var $Hann_DASH_check_DASH_temp293916256 = function(ann_DASH_check_DASH_temp31416255) {
return ann_DASH_check_DASH_temp31416255;
};
var $Hcont_tail_arg29376701 = function(cont_tail_arg3116699,if_helper3016700) {
if(--R.GAS > 0) {
$z1625716258 = R.isFunction(if_helper3016700)?if_helper3016700.app(cont_tail_arg3116699):R.ffi.throwNonFunApp(L[1063],if_helper3016700,[cont_tail_arg3116699]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper3016700)?if_helper3016700.app(cont_tail_arg3116699):R.ffi.throwNonFunApp(L[1063],if_helper3016700,[cont_tail_arg3116699]);
},
"from":L[1063]});
}
++R.GAS;
return $z1625716258;
};
var $Hcont_tail_arg29386716 = function(cont_tail_arg3066715,if_helper3016700) {
if(--R.GAS > 0) {
$z1625916260 = R.isFunction(if_helper3016700)?if_helper3016700.app(cont_tail_arg3066715):R.ffi.throwNonFunApp(L[1063],if_helper3016700,[cont_tail_arg3066715]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper3016700)?if_helper3016700.app(cont_tail_arg3066715):R.ffi.throwNonFunApp(L[1063],if_helper3016700,[cont_tail_arg3066715]);
},
"from":L[1063]});
}
++R.GAS;
return $z1625916260;
};
var $Hanf_arg29366738 = function(anf_arg2956735,INDENT9187,anf_fun2926736,self2856737,str_DASH_coloncolon99183) {
var anf_bracket29616274 = G(self2856737,"ann",L[1635]);
var anf_fun29716271 = G(anf_bracket29616274,"tosource",L[1634]);
var $z1626316264 = D;
var $f1626916270 = function(_) {
return R.isFunction(anf_fun29716271)?anf_fun29716271.app():R.ffi.throwNonFunApp(L[1633],anf_fun29716271,[]);
};
try {
if(--R.GAS > 0) {
$z1626316264 = $f1626916270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1626916270,
"from":L[1633]});
}
} catch($e1626116262) {
if(R.isCont($e1626116262)) {
var $ss1626516266 = {"from":L[1633],
"go":function(anf_arg29816272) {
return $Hanf_arg293516273(anf_arg29816272,INDENT9187,anf_arg2956735,anf_fun2926736,str_DASH_coloncolon99183);
}};
$e1626116262.stack[R.EXN_STACKHEIGHT++] = $ss1626516266;
}
if(R.isPyretException($e1626116262)) {
$e1626116262.pyretStack.push(L[1633]);
}
throw $e1626116262;
}
var $ret1626716268 = $Hanf_arg293516273($z1626316264,INDENT9187,anf_arg2956735,anf_fun2926736,str_DASH_coloncolon99183);
++R.GAS;
return $ret1626716268;
};
var $Hanf_arg293516273 = function(anf_arg29816272,INDENT9187,anf_arg2956735,anf_fun2926736,str_DASH_coloncolon99183) {
var $z1627716278 = D;
var $f1628316284 = function(_) {
return R.isFunction(anf_fun2926736)?anf_fun2926736.app(INDENT9187,(1),str_DASH_coloncolon99183,anf_arg2956735,anf_arg29816272):R.ffi.throwNonFunApp(L[1087],anf_fun2926736,[INDENT9187,(1),str_DASH_coloncolon99183,anf_arg2956735,anf_arg29816272]);
};
try {
if(--R.GAS > 0) {
$z1627716278 = $f1628316284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1628316284,
"from":L[1087]});
}
} catch($e1627516276) {
if(R.isCont($e1627516276)) {
var $ss1627916280 = {"from":L[1087],
"go":function(ann_DASH_check_DASH_temp29116285) {
return $Hann_DASH_check_DASH_temp293416286(ann_DASH_check_DASH_temp29116285);
}};
$e1627516276.stack[R.EXN_STACKHEIGHT++] = $ss1627916280;
}
if(R.isPyretException($e1627516276)) {
$e1627516276.pyretStack.push(L[1087]);
}
throw $e1627516276;
}
var $ret1628116282 = $Hann_DASH_check_DASH_temp293416286($z1627716278);
++R.GAS;
return $ret1628116282;
};
var $Hann_DASH_check_DASH_temp293416286 = function(ann_DASH_check_DASH_temp29116285) {
return ann_DASH_check_DASH_temp29116285;
};
var $Hanf_arg29336755 = function(anf_arg2776753,self356754,_plus26,torepr31) {
var anf_arg27816297 = G(self356754,"name",L[1064]);
var $z1628916290 = D;
var $f1629516296 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg27816297):R.ffi.throwNonFunApp(L[1064],torepr31,[anf_arg27816297]);
};
try {
if(--R.GAS > 0) {
$z1628916290 = $f1629516296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1629516296,
"from":L[1064]});
}
} catch($e1628716288) {
if(R.isCont($e1628716288)) {
var $ss1629116292 = {"from":L[1064],
"go":function(anf_arg27916298) {
return $Hanf_arg293216299(anf_arg27916298,anf_arg2776753,self356754,_plus26,torepr31);
}};
$e1628716288.stack[R.EXN_STACKHEIGHT++] = $ss1629116292;
}
if(R.isPyretException($e1628716288)) {
$e1628716288.pyretStack.push(L[1064]);
}
throw $e1628716288;
}
var $ret1629316294 = $Hanf_arg293216299($z1628916290,anf_arg2776753,self356754,_plus26,torepr31);
++R.GAS;
return $ret1629316294;
};
var $Hanf_arg293216299 = function(anf_arg27916298,anf_arg2776753,self356754,_plus26,torepr31) {
var $z1630216303 = D;
var $f1630816309 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg27916298):R.ffi.throwNonFunApp(L[1064],_plus26,[(", "),anf_arg27916298]);
};
try {
if(--R.GAS > 0) {
$z1630216303 = $f1630816309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1630816309,
"from":L[1064]});
}
} catch($e1630016301) {
if(R.isCont($e1630016301)) {
var $ss1630416305 = {"from":L[1064],
"go":function(anf_arg28016310) {
return $Hanf_arg293116311(anf_arg28016310,anf_arg2776753,self356754,_plus26,torepr31);
}};
$e1630016301.stack[R.EXN_STACKHEIGHT++] = $ss1630416305;
}
if(R.isPyretException($e1630016301)) {
$e1630016301.pyretStack.push(L[1064]);
}
throw $e1630016301;
}
var $ret1630616307 = $Hanf_arg293116311($z1630216303,anf_arg2776753,self356754,_plus26,torepr31);
++R.GAS;
return $ret1630616307;
};
var $Hanf_arg293116311 = function(anf_arg28016310,anf_arg2776753,self356754,_plus26,torepr31) {
var $z1631416315 = D;
var $f1632016321 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg2776753,anf_arg28016310):R.ffi.throwNonFunApp(L[1064],_plus26,[anf_arg2776753,anf_arg28016310]);
};
try {
if(--R.GAS > 0) {
$z1631416315 = $f1632016321();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1632016321,
"from":L[1064]});
}
} catch($e1631216313) {
if(R.isCont($e1631216313)) {
var $ss1631616317 = {"from":L[1064],
"go":function(anf_arg28116322) {
return $Hanf_arg293016323(anf_arg28116322,self356754,_plus26,torepr31);
}};
$e1631216313.stack[R.EXN_STACKHEIGHT++] = $ss1631616317;
}
if(R.isPyretException($e1631216313)) {
$e1631216313.pyretStack.push(L[1064]);
}
throw $e1631216313;
}
var $ret1631816319 = $Hanf_arg293016323($z1631416315,self356754,_plus26,torepr31);
++R.GAS;
return $ret1631816319;
};
var $Hanf_arg293016323 = function(anf_arg28116322,self356754,_plus26,torepr31) {
var anf_arg28216334 = G(self356754,"ann",L[1064]);
var $z1632616327 = D;
var $f1633216333 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg28216334):R.ffi.throwNonFunApp(L[1064],torepr31,[anf_arg28216334]);
};
try {
if(--R.GAS > 0) {
$z1632616327 = $f1633216333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1633216333,
"from":L[1064]});
}
} catch($e1632416325) {
if(R.isCont($e1632416325)) {
var $ss1632816329 = {"from":L[1064],
"go":function(anf_arg28316335) {
return $Hanf_arg292916336(anf_arg28316335,anf_arg28116322,_plus26);
}};
$e1632416325.stack[R.EXN_STACKHEIGHT++] = $ss1632816329;
}
if(R.isPyretException($e1632416325)) {
$e1632416325.pyretStack.push(L[1064]);
}
throw $e1632416325;
}
var $ret1633016331 = $Hanf_arg292916336($z1632616327,anf_arg28116322,_plus26);
++R.GAS;
return $ret1633016331;
};
var $Hanf_arg292916336 = function(anf_arg28316335,anf_arg28116322,_plus26) {
var $z1633916340 = D;
var $f1634516346 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg28316335):R.ffi.throwNonFunApp(L[1064],_plus26,[(", "),anf_arg28316335]);
};
try {
if(--R.GAS > 0) {
$z1633916340 = $f1634516346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1634516346,
"from":L[1064]});
}
} catch($e1633716338) {
if(R.isCont($e1633716338)) {
var $ss1634116342 = {"from":L[1064],
"go":function(anf_arg28416347) {
return $Hanf_arg292816348(anf_arg28416347,anf_arg28116322,_plus26);
}};
$e1633716338.stack[R.EXN_STACKHEIGHT++] = $ss1634116342;
}
if(R.isPyretException($e1633716338)) {
$e1633716338.pyretStack.push(L[1064]);
}
throw $e1633716338;
}
var $ret1634316344 = $Hanf_arg292816348($z1633916340,anf_arg28116322,_plus26);
++R.GAS;
return $ret1634316344;
};
var $Hanf_arg292816348 = function(anf_arg28416347,anf_arg28116322,_plus26) {
var $z1635116352 = D;
var $f1635716358 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg28116322,anf_arg28416347):R.ffi.throwNonFunApp(L[1064],_plus26,[anf_arg28116322,anf_arg28416347]);
};
try {
if(--R.GAS > 0) {
$z1635116352 = $f1635716358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1635716358,
"from":L[1064]});
}
} catch($e1634916350) {
if(R.isCont($e1634916350)) {
var $ss1635316354 = {"from":L[1064],
"go":function(anf_arg28516359) {
return $Hanf_arg292716360(anf_arg28516359,_plus26);
}};
$e1634916350.stack[R.EXN_STACKHEIGHT++] = $ss1635316354;
}
if(R.isPyretException($e1634916350)) {
$e1634916350.pyretStack.push(L[1064]);
}
throw $e1634916350;
}
var $ret1635516356 = $Hanf_arg292716360($z1635116352,_plus26);
++R.GAS;
return $ret1635516356;
};
var $Hanf_arg292716360 = function(anf_arg28516359,_plus26) {
var $z1636316364 = D;
var $f1636916370 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg28516359,(")")):R.ffi.throwNonFunApp(L[1064],_plus26,[anf_arg28516359,(")")]);
};
try {
if(--R.GAS > 0) {
$z1636316364 = $f1636916370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1636916370,
"from":L[1064]});
}
} catch($e1636116362) {
if(R.isCont($e1636116362)) {
var $ss1636516366 = {"from":L[1064],
"go":function(anf_arg28616371) {
return $Hanf_arg292616372(anf_arg28616371,_plus26);
}};
$e1636116362.stack[R.EXN_STACKHEIGHT++] = $ss1636516366;
}
if(R.isPyretException($e1636116362)) {
$e1636116362.pyretStack.push(L[1064]);
}
throw $e1636116362;
}
var $ret1636716368 = $Hanf_arg292616372($z1636316364,_plus26);
++R.GAS;
return $ret1636716368;
};
var $Hanf_arg292616372 = function(anf_arg28616371,_plus26) {
var $z1637516376 = D;
var $f1638116382 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg28616371):R.ffi.throwNonFunApp(L[1064],_plus26,[("("),anf_arg28616371]);
};
try {
if(--R.GAS > 0) {
$z1637516376 = $f1638116382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1638116382,
"from":L[1064]});
}
} catch($e1637316374) {
if(R.isCont($e1637316374)) {
var $ss1637716378 = {"from":L[1064],
"go":function(anf_arg28716383) {
return $Hanf_arg292516384(anf_arg28716383,_plus26);
}};
$e1637316374.stack[R.EXN_STACKHEIGHT++] = $ss1637716378;
}
if(R.isPyretException($e1637316374)) {
$e1637316374.pyretStack.push(L[1064]);
}
throw $e1637316374;
}
var $ret1637916380 = $Hanf_arg292516384($z1637516376,_plus26);
++R.GAS;
return $ret1637916380;
};
var $Hanf_arg292516384 = function(anf_arg28716383,_plus26) {
var $z1638716388 = D;
var $f1639316394 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-type-bind"),anf_arg28716383):R.ffi.throwNonFunApp(L[1064],_plus26,[("a-type-bind"),anf_arg28716383]);
};
try {
if(--R.GAS > 0) {
$z1638716388 = $f1639316394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1639316394,
"from":L[1064]});
}
} catch($e1638516386) {
if(R.isCont($e1638516386)) {
var $ss1638916390 = {"from":L[1064],
"go":function(ann_DASH_check_DASH_temp27516395) {
return $Hann_DASH_check_DASH_temp292416396(ann_DASH_check_DASH_temp27516395);
}};
$e1638516386.stack[R.EXN_STACKHEIGHT++] = $ss1638916390;
}
if(R.isPyretException($e1638516386)) {
$e1638516386.pyretStack.push(L[1064]);
}
throw $e1638516386;
}
var $ret1639116392 = $Hann_DASH_check_DASH_temp292416396($z1638716388);
++R.GAS;
return $ret1639116392;
};
var $Hann_DASH_check_DASH_temp292416396 = function(ann_DASH_check_DASH_temp27516395) {
return ann_DASH_check_DASH_temp27516395;
};
var $Hcont_tail_arg29226772 = function(cont_tail_arg2726770,if_helper2626771) {
if(--R.GAS > 0) {
$z1639716398 = R.isFunction(if_helper2626771)?if_helper2626771.app(cont_tail_arg2726770):R.ffi.throwNonFunApp(L[1064],if_helper2626771,[cont_tail_arg2726770]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper2626771)?if_helper2626771.app(cont_tail_arg2726770):R.ffi.throwNonFunApp(L[1064],if_helper2626771,[cont_tail_arg2726770]);
},
"from":L[1064]});
}
++R.GAS;
return $z1639716398;
};
var $Hcont_tail_arg29236787 = function(cont_tail_arg2676786,if_helper2626771) {
if(--R.GAS > 0) {
$z1639916400 = R.isFunction(if_helper2626771)?if_helper2626771.app(cont_tail_arg2676786):R.ffi.throwNonFunApp(L[1064],if_helper2626771,[cont_tail_arg2676786]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper2626771)?if_helper2626771.app(cont_tail_arg2676786):R.ffi.throwNonFunApp(L[1064],if_helper2626771,[cont_tail_arg2676786]);
},
"from":L[1064]});
}
++R.GAS;
return $z1639916400;
};
var $Hann_DASH_check_DASH_temp29216809 = function(ann_DASH_check_DASH_temp2536808) {
return ann_DASH_check_DASH_temp2536808;
};
var $Hanf_arg29206822 = function(anf_arg2576821,_plus26,raise30) {
var $z1640316404 = D;
var $f1640916410 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg2576821):R.ffi.throwNonFunApp(L[1636],_plus26,[("No visitor field for "),anf_arg2576821]);
};
try {
if(--R.GAS > 0) {
$z1640316404 = $f1640916410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1640916410,
"from":L[1636]});
}
} catch($e1640116402) {
if(R.isCont($e1640116402)) {
var $ss1640516406 = {"from":L[1636],
"go":function(anf_arg25816411) {
return $Hanf_arg291916412(anf_arg25816411,raise30);
}};
$e1640116402.stack[R.EXN_STACKHEIGHT++] = $ss1640516406;
}
if(R.isPyretException($e1640116402)) {
$e1640116402.pyretStack.push(L[1636]);
}
throw $e1640116402;
}
var $ret1640716408 = $Hanf_arg291916412($z1640316404,raise30);
++R.GAS;
return $ret1640716408;
};
var $Hanf_arg291916412 = function(anf_arg25816411,raise30) {
var $z1641516416 = D;
var $f1642116422 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg25816411):R.ffi.throwNonFunApp(L[1093],raise30,[anf_arg25816411]);
};
try {
if(--R.GAS > 0) {
$z1641516416 = $f1642116422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1642116422,
"from":L[1093]});
}
} catch($e1641316414) {
if(R.isCont($e1641316414)) {
var $ss1641716418 = {"from":L[1093],
"go":function(ann_DASH_check_DASH_temp25516423) {
return $Hann_DASH_check_DASH_temp291816424(ann_DASH_check_DASH_temp25516423);
}};
$e1641316414.stack[R.EXN_STACKHEIGHT++] = $ss1641716418;
}
if(R.isPyretException($e1641316414)) {
$e1641316414.pyretStack.push(L[1093]);
}
throw $e1641316414;
}
var $ret1641916420 = $Hann_DASH_check_DASH_temp291816424($z1641516416);
++R.GAS;
return $ret1641916420;
};
var $Hann_DASH_check_DASH_temp291816424 = function(ann_DASH_check_DASH_temp25516423) {
return ann_DASH_check_DASH_temp25516423;
};
var $Hanf_array_val29176864 = function(anf_array_val2366861,PP337,anf_fun2326862,anf_fun2336863,self2783371,str_DASH_as113365,str_DASH_import111339) {
var anf_bracket23716438 = G(self2783371,"name",L[1639]);
var anf_fun23816435 = G(anf_bracket23716438,"tosource",L[1638]);
var $z1642716428 = D;
var $f1643316434 = function(_) {
return R.isFunction(anf_fun23816435)?anf_fun23816435.app():R.ffi.throwNonFunApp(L[1637],anf_fun23816435,[]);
};
try {
if(--R.GAS > 0) {
$z1642716428 = $f1643316434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1643316434,
"from":L[1637]});
}
} catch($e1642516426) {
if(R.isCont($e1642516426)) {
var $ss1642916430 = {"from":L[1637],
"go":function(anf_array_val23916436) {
return $Hanf_array_val291616437(anf_array_val23916436,PP337,anf_array_val2366861,anf_fun2326862,anf_fun2336863,self2783371,str_DASH_as113365,str_DASH_import111339);
}};
$e1642516426.stack[R.EXN_STACKHEIGHT++] = $ss1642916430;
}
if(R.isPyretException($e1642516426)) {
$e1642516426.pyretStack.push(L[1637]);
}
throw $e1642516426;
}
var $ret1643116432 = $Hanf_array_val291616437($z1642716428,PP337,anf_array_val2366861,anf_fun2326862,anf_fun2336863,self2783371,str_DASH_as113365,str_DASH_import111339);
++R.GAS;
return $ret1643116432;
};
var $Hanf_array_val291616437 = function(anf_array_val23916436,PP337,anf_array_val2366861,anf_fun2326862,anf_fun2336863,self2783371,str_DASH_as113365,str_DASH_import111339) {
var anf_array_val24016451 = G(PP337,"commabreak",L[1643]);
var anf_bracket24116453 = G(self2783371,"types",L[1642]);
var anf_fun24216449 = G(anf_bracket24116453,"tosource",L[1641]);
var $z1644116442 = D;
var $f1644716448 = function(_) {
return R.isFunction(anf_fun24216449)?anf_fun24216449.app():R.ffi.throwNonFunApp(L[1640],anf_fun24216449,[]);
};
try {
if(--R.GAS > 0) {
$z1644116442 = $f1644716448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1644716448,
"from":L[1640]});
}
} catch($e1643916440) {
if(R.isCont($e1643916440)) {
var $ss1644316444 = {"from":L[1640],
"go":function(anf_array_val24316450) {
return $Hanf_array_val291516452(anf_array_val24316450,anf_array_val2366861,anf_array_val23916436,anf_array_val24016451,anf_fun2326862,anf_fun2336863,str_DASH_as113365,str_DASH_import111339);
}};
$e1643916440.stack[R.EXN_STACKHEIGHT++] = $ss1644316444;
}
if(R.isPyretException($e1643916440)) {
$e1643916440.pyretStack.push(L[1640]);
}
throw $e1643916440;
}
var $ret1644516446 = $Hanf_array_val291516452($z1644116442,anf_array_val2366861,anf_array_val23916436,anf_array_val24016451,anf_fun2326862,anf_fun2336863,str_DASH_as113365,str_DASH_import111339);
++R.GAS;
return $ret1644516446;
};
var $Hanf_array_val291516452 = function(anf_array_val24316450,anf_array_val2366861,anf_array_val23916436,anf_array_val24016451,anf_fun2326862,anf_fun2336863,str_DASH_as113365,str_DASH_import111339) {
var $z1645616457 = D;
var $f1646216463 = function(_) {
return R.isFunction(anf_fun2336863)?anf_fun2336863.app([str_DASH_import111339,anf_array_val2366861,str_DASH_as113365,anf_array_val23916436,anf_array_val24016451,anf_array_val24316450]):R.ffi.throwNonFunApp(L[1112],anf_fun2336863,[[str_DASH_import111339,anf_array_val2366861,str_DASH_as113365,anf_array_val23916436,anf_array_val24016451,anf_array_val24316450]]);
};
try {
if(--R.GAS > 0) {
$z1645616457 = $f1646216463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1646216463,
"from":L[1112]});
}
} catch($e1645416455) {
if(R.isCont($e1645416455)) {
var $ss1645816459 = {"from":L[1112],
"go":function(anf_arg24416464) {
return $Hanf_arg291416465(anf_arg24416464,anf_fun2326862);
}};
$e1645416455.stack[R.EXN_STACKHEIGHT++] = $ss1645816459;
}
if(R.isPyretException($e1645416455)) {
$e1645416455.pyretStack.push(L[1112]);
}
throw $e1645416455;
}
var $ret1646016461 = $Hanf_arg291416465($z1645616457,anf_fun2326862);
++R.GAS;
return $ret1646016461;
};
var $Hanf_arg291416465 = function(anf_arg24416464,anf_fun2326862) {
var $z1646816469 = D;
var $f1647416475 = function(_) {
return R.isFunction(anf_fun2326862)?anf_fun2326862.app(anf_arg24416464):R.ffi.throwNonFunApp(L[1114],anf_fun2326862,[anf_arg24416464]);
};
try {
if(--R.GAS > 0) {
$z1646816469 = $f1647416475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1647416475,
"from":L[1114]});
}
} catch($e1646616467) {
if(R.isCont($e1646616467)) {
var $ss1647016471 = {"from":L[1114],
"go":function(ann_DASH_check_DASH_temp23116476) {
return $Hann_DASH_check_DASH_temp291316477(ann_DASH_check_DASH_temp23116476);
}};
$e1646616467.stack[R.EXN_STACKHEIGHT++] = $ss1647016471;
}
if(R.isPyretException($e1646616467)) {
$e1646616467.pyretStack.push(L[1114]);
}
throw $e1646616467;
}
var $ret1647216473 = $Hann_DASH_check_DASH_temp291316477($z1646816469);
++R.GAS;
return $ret1647216473;
};
var $Hann_DASH_check_DASH_temp291316477 = function(ann_DASH_check_DASH_temp23116476) {
return ann_DASH_check_DASH_temp23116476;
};
var $Hanf_arg29126881 = function(anf_arg2136879,self296880,_plus26,torepr31) {
var anf_arg21416488 = G(self296880,"import-type",L[1097]);
var $z1648016481 = D;
var $f1648616487 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg21416488):R.ffi.throwNonFunApp(L[1097],torepr31,[anf_arg21416488]);
};
try {
if(--R.GAS > 0) {
$z1648016481 = $f1648616487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1648616487,
"from":L[1097]});
}
} catch($e1647816479) {
if(R.isCont($e1647816479)) {
var $ss1648216483 = {"from":L[1097],
"go":function(anf_arg21516489) {
return $Hanf_arg291116490(anf_arg21516489,anf_arg2136879,self296880,_plus26,torepr31);
}};
$e1647816479.stack[R.EXN_STACKHEIGHT++] = $ss1648216483;
}
if(R.isPyretException($e1647816479)) {
$e1647816479.pyretStack.push(L[1097]);
}
throw $e1647816479;
}
var $ret1648416485 = $Hanf_arg291116490($z1648016481,anf_arg2136879,self296880,_plus26,torepr31);
++R.GAS;
return $ret1648416485;
};
var $Hanf_arg291116490 = function(anf_arg21516489,anf_arg2136879,self296880,_plus26,torepr31) {
var $z1649316494 = D;
var $f1649916500 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg21516489):R.ffi.throwNonFunApp(L[1097],_plus26,[(", "),anf_arg21516489]);
};
try {
if(--R.GAS > 0) {
$z1649316494 = $f1649916500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1649916500,
"from":L[1097]});
}
} catch($e1649116492) {
if(R.isCont($e1649116492)) {
var $ss1649516496 = {"from":L[1097],
"go":function(anf_arg21616501) {
return $Hanf_arg291016502(anf_arg21616501,anf_arg2136879,self296880,_plus26,torepr31);
}};
$e1649116492.stack[R.EXN_STACKHEIGHT++] = $ss1649516496;
}
if(R.isPyretException($e1649116492)) {
$e1649116492.pyretStack.push(L[1097]);
}
throw $e1649116492;
}
var $ret1649716498 = $Hanf_arg291016502($z1649316494,anf_arg2136879,self296880,_plus26,torepr31);
++R.GAS;
return $ret1649716498;
};
var $Hanf_arg291016502 = function(anf_arg21616501,anf_arg2136879,self296880,_plus26,torepr31) {
var $z1650516506 = D;
var $f1651116512 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg2136879,anf_arg21616501):R.ffi.throwNonFunApp(L[1097],_plus26,[anf_arg2136879,anf_arg21616501]);
};
try {
if(--R.GAS > 0) {
$z1650516506 = $f1651116512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1651116512,
"from":L[1097]});
}
} catch($e1650316504) {
if(R.isCont($e1650316504)) {
var $ss1650716508 = {"from":L[1097],
"go":function(anf_arg21716513) {
return $Hanf_arg290916514(anf_arg21716513,self296880,_plus26,torepr31);
}};
$e1650316504.stack[R.EXN_STACKHEIGHT++] = $ss1650716508;
}
if(R.isPyretException($e1650316504)) {
$e1650316504.pyretStack.push(L[1097]);
}
throw $e1650316504;
}
var $ret1650916510 = $Hanf_arg290916514($z1650516506,self296880,_plus26,torepr31);
++R.GAS;
return $ret1650916510;
};
var $Hanf_arg290916514 = function(anf_arg21716513,self296880,_plus26,torepr31) {
var anf_arg21816525 = G(self296880,"name",L[1097]);
var $z1651716518 = D;
var $f1652316524 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg21816525):R.ffi.throwNonFunApp(L[1097],torepr31,[anf_arg21816525]);
};
try {
if(--R.GAS > 0) {
$z1651716518 = $f1652316524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1652316524,
"from":L[1097]});
}
} catch($e1651516516) {
if(R.isCont($e1651516516)) {
var $ss1651916520 = {"from":L[1097],
"go":function(anf_arg21916526) {
return $Hanf_arg290816527(anf_arg21916526,anf_arg21716513,self296880,_plus26,torepr31);
}};
$e1651516516.stack[R.EXN_STACKHEIGHT++] = $ss1651916520;
}
if(R.isPyretException($e1651516516)) {
$e1651516516.pyretStack.push(L[1097]);
}
throw $e1651516516;
}
var $ret1652116522 = $Hanf_arg290816527($z1651716518,anf_arg21716513,self296880,_plus26,torepr31);
++R.GAS;
return $ret1652116522;
};
var $Hanf_arg290816527 = function(anf_arg21916526,anf_arg21716513,self296880,_plus26,torepr31) {
var $z1653016531 = D;
var $f1653616537 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg21916526):R.ffi.throwNonFunApp(L[1097],_plus26,[(", "),anf_arg21916526]);
};
try {
if(--R.GAS > 0) {
$z1653016531 = $f1653616537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1653616537,
"from":L[1097]});
}
} catch($e1652816529) {
if(R.isCont($e1652816529)) {
var $ss1653216533 = {"from":L[1097],
"go":function(anf_arg22016538) {
return $Hanf_arg290716539(anf_arg22016538,anf_arg21716513,self296880,_plus26,torepr31);
}};
$e1652816529.stack[R.EXN_STACKHEIGHT++] = $ss1653216533;
}
if(R.isPyretException($e1652816529)) {
$e1652816529.pyretStack.push(L[1097]);
}
throw $e1652816529;
}
var $ret1653416535 = $Hanf_arg290716539($z1653016531,anf_arg21716513,self296880,_plus26,torepr31);
++R.GAS;
return $ret1653416535;
};
var $Hanf_arg290716539 = function(anf_arg22016538,anf_arg21716513,self296880,_plus26,torepr31) {
var $z1654216543 = D;
var $f1654816549 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg21716513,anf_arg22016538):R.ffi.throwNonFunApp(L[1097],_plus26,[anf_arg21716513,anf_arg22016538]);
};
try {
if(--R.GAS > 0) {
$z1654216543 = $f1654816549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1654816549,
"from":L[1097]});
}
} catch($e1654016541) {
if(R.isCont($e1654016541)) {
var $ss1654416545 = {"from":L[1097],
"go":function(anf_arg22116550) {
return $Hanf_arg290616551(anf_arg22116550,self296880,_plus26,torepr31);
}};
$e1654016541.stack[R.EXN_STACKHEIGHT++] = $ss1654416545;
}
if(R.isPyretException($e1654016541)) {
$e1654016541.pyretStack.push(L[1097]);
}
throw $e1654016541;
}
var $ret1654616547 = $Hanf_arg290616551($z1654216543,self296880,_plus26,torepr31);
++R.GAS;
return $ret1654616547;
};
var $Hanf_arg290616551 = function(anf_arg22116550,self296880,_plus26,torepr31) {
var anf_arg22216562 = G(self296880,"types",L[1097]);
var $z1655416555 = D;
var $f1656016561 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg22216562):R.ffi.throwNonFunApp(L[1097],torepr31,[anf_arg22216562]);
};
try {
if(--R.GAS > 0) {
$z1655416555 = $f1656016561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1656016561,
"from":L[1097]});
}
} catch($e1655216553) {
if(R.isCont($e1655216553)) {
var $ss1655616557 = {"from":L[1097],
"go":function(anf_arg22316563) {
return $Hanf_arg290516564(anf_arg22316563,anf_arg22116550,_plus26);
}};
$e1655216553.stack[R.EXN_STACKHEIGHT++] = $ss1655616557;
}
if(R.isPyretException($e1655216553)) {
$e1655216553.pyretStack.push(L[1097]);
}
throw $e1655216553;
}
var $ret1655816559 = $Hanf_arg290516564($z1655416555,anf_arg22116550,_plus26);
++R.GAS;
return $ret1655816559;
};
var $Hanf_arg290516564 = function(anf_arg22316563,anf_arg22116550,_plus26) {
var $z1656716568 = D;
var $f1657316574 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg22316563):R.ffi.throwNonFunApp(L[1097],_plus26,[(", "),anf_arg22316563]);
};
try {
if(--R.GAS > 0) {
$z1656716568 = $f1657316574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1657316574,
"from":L[1097]});
}
} catch($e1656516566) {
if(R.isCont($e1656516566)) {
var $ss1656916570 = {"from":L[1097],
"go":function(anf_arg22416575) {
return $Hanf_arg290416576(anf_arg22416575,anf_arg22116550,_plus26);
}};
$e1656516566.stack[R.EXN_STACKHEIGHT++] = $ss1656916570;
}
if(R.isPyretException($e1656516566)) {
$e1656516566.pyretStack.push(L[1097]);
}
throw $e1656516566;
}
var $ret1657116572 = $Hanf_arg290416576($z1656716568,anf_arg22116550,_plus26);
++R.GAS;
return $ret1657116572;
};
var $Hanf_arg290416576 = function(anf_arg22416575,anf_arg22116550,_plus26) {
var $z1657916580 = D;
var $f1658516586 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg22116550,anf_arg22416575):R.ffi.throwNonFunApp(L[1097],_plus26,[anf_arg22116550,anf_arg22416575]);
};
try {
if(--R.GAS > 0) {
$z1657916580 = $f1658516586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1658516586,
"from":L[1097]});
}
} catch($e1657716578) {
if(R.isCont($e1657716578)) {
var $ss1658116582 = {"from":L[1097],
"go":function(anf_arg22516587) {
return $Hanf_arg290316588(anf_arg22516587,_plus26);
}};
$e1657716578.stack[R.EXN_STACKHEIGHT++] = $ss1658116582;
}
if(R.isPyretException($e1657716578)) {
$e1657716578.pyretStack.push(L[1097]);
}
throw $e1657716578;
}
var $ret1658316584 = $Hanf_arg290316588($z1657916580,_plus26);
++R.GAS;
return $ret1658316584;
};
var $Hanf_arg290316588 = function(anf_arg22516587,_plus26) {
var $z1659116592 = D;
var $f1659716598 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg22516587,(")")):R.ffi.throwNonFunApp(L[1097],_plus26,[anf_arg22516587,(")")]);
};
try {
if(--R.GAS > 0) {
$z1659116592 = $f1659716598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1659716598,
"from":L[1097]});
}
} catch($e1658916590) {
if(R.isCont($e1658916590)) {
var $ss1659316594 = {"from":L[1097],
"go":function(anf_arg22616599) {
return $Hanf_arg290216600(anf_arg22616599,_plus26);
}};
$e1658916590.stack[R.EXN_STACKHEIGHT++] = $ss1659316594;
}
if(R.isPyretException($e1658916590)) {
$e1658916590.pyretStack.push(L[1097]);
}
throw $e1658916590;
}
var $ret1659516596 = $Hanf_arg290216600($z1659116592,_plus26);
++R.GAS;
return $ret1659516596;
};
var $Hanf_arg290216600 = function(anf_arg22616599,_plus26) {
var $z1660316604 = D;
var $f1660916610 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg22616599):R.ffi.throwNonFunApp(L[1097],_plus26,[("("),anf_arg22616599]);
};
try {
if(--R.GAS > 0) {
$z1660316604 = $f1660916610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1660916610,
"from":L[1097]});
}
} catch($e1660116602) {
if(R.isCont($e1660116602)) {
var $ss1660516606 = {"from":L[1097],
"go":function(anf_arg22716611) {
return $Hanf_arg290116612(anf_arg22716611,_plus26);
}};
$e1660116602.stack[R.EXN_STACKHEIGHT++] = $ss1660516606;
}
if(R.isPyretException($e1660116602)) {
$e1660116602.pyretStack.push(L[1097]);
}
throw $e1660116602;
}
var $ret1660716608 = $Hanf_arg290116612($z1660316604,_plus26);
++R.GAS;
return $ret1660716608;
};
var $Hanf_arg290116612 = function(anf_arg22716611,_plus26) {
var $z1661516616 = D;
var $f1662116622 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-import-types"),anf_arg22716611):R.ffi.throwNonFunApp(L[1097],_plus26,[("a-import-types"),anf_arg22716611]);
};
try {
if(--R.GAS > 0) {
$z1661516616 = $f1662116622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1662116622,
"from":L[1097]});
}
} catch($e1661316614) {
if(R.isCont($e1661316614)) {
var $ss1661716618 = {"from":L[1097],
"go":function(ann_DASH_check_DASH_temp21116623) {
return $Hann_DASH_check_DASH_temp290016624(ann_DASH_check_DASH_temp21116623);
}};
$e1661316614.stack[R.EXN_STACKHEIGHT++] = $ss1661716618;
}
if(R.isPyretException($e1661316614)) {
$e1661316614.pyretStack.push(L[1097]);
}
throw $e1661316614;
}
var $ret1661916620 = $Hann_DASH_check_DASH_temp290016624($z1661516616);
++R.GAS;
return $ret1661916620;
};
var $Hann_DASH_check_DASH_temp290016624 = function(ann_DASH_check_DASH_temp21116623) {
return ann_DASH_check_DASH_temp21116623;
};
var $Hcont_tail_arg28986899 = function(cont_tail_arg2086897,if_helper1976898) {
if(--R.GAS > 0) {
$z1662516626 = R.isFunction(if_helper1976898)?if_helper1976898.app(cont_tail_arg2086897):R.ffi.throwNonFunApp(L[1097],if_helper1976898,[cont_tail_arg2086897]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1976898)?if_helper1976898.app(cont_tail_arg2086897):R.ffi.throwNonFunApp(L[1097],if_helper1976898,[cont_tail_arg2086897]);
},
"from":L[1097]});
}
++R.GAS;
return $z1662516626;
};
var $Hcont_tail_arg28996914 = function(cont_tail_arg2026913,if_helper1976898) {
if(--R.GAS > 0) {
$z1662716628 = R.isFunction(if_helper1976898)?if_helper1976898.app(cont_tail_arg2026913):R.ffi.throwNonFunApp(L[1097],if_helper1976898,[cont_tail_arg2026913]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1976898)?if_helper1976898.app(cont_tail_arg2026913):R.ffi.throwNonFunApp(L[1097],if_helper1976898,[cont_tail_arg2026913]);
},
"from":L[1097]});
}
++R.GAS;
return $z1662716628;
};
var $Hanf_array_val28976936 = function(anf_array_val1906933,anf_fun1866934,anf_fun1876935,self2723443,str_DASH_as113365,str_DASH_import111339) {
var anf_bracket19116642 = G(self2723443,"name",L[1646]);
var anf_fun19216639 = G(anf_bracket19116642,"tosource",L[1645]);
var $z1663116632 = D;
var $f1663716638 = function(_) {
return R.isFunction(anf_fun19216639)?anf_fun19216639.app():R.ffi.throwNonFunApp(L[1644],anf_fun19216639,[]);
};
try {
if(--R.GAS > 0) {
$z1663116632 = $f1663716638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1663716638,
"from":L[1644]});
}
} catch($e1662916630) {
if(R.isCont($e1662916630)) {
var $ss1663316634 = {"from":L[1644],
"go":function(anf_array_val19316640) {
return $Hanf_array_val289616641(anf_array_val19316640,anf_array_val1906933,anf_fun1866934,anf_fun1876935,str_DASH_as113365,str_DASH_import111339);
}};
$e1662916630.stack[R.EXN_STACKHEIGHT++] = $ss1663316634;
}
if(R.isPyretException($e1662916630)) {
$e1662916630.pyretStack.push(L[1644]);
}
throw $e1662916630;
}
var $ret1663516636 = $Hanf_array_val289616641($z1663116632,anf_array_val1906933,anf_fun1866934,anf_fun1876935,str_DASH_as113365,str_DASH_import111339);
++R.GAS;
return $ret1663516636;
};
var $Hanf_array_val289616641 = function(anf_array_val19316640,anf_array_val1906933,anf_fun1866934,anf_fun1876935,str_DASH_as113365,str_DASH_import111339) {
var $z1664516646 = D;
var $f1665116652 = function(_) {
return R.isFunction(anf_fun1876935)?anf_fun1876935.app([str_DASH_import111339,anf_array_val1906933,str_DASH_as113365,anf_array_val19316640]):R.ffi.throwNonFunApp(L[1123],anf_fun1876935,[[str_DASH_import111339,anf_array_val1906933,str_DASH_as113365,anf_array_val19316640]]);
};
try {
if(--R.GAS > 0) {
$z1664516646 = $f1665116652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1665116652,
"from":L[1123]});
}
} catch($e1664316644) {
if(R.isCont($e1664316644)) {
var $ss1664716648 = {"from":L[1123],
"go":function(anf_arg19416653) {
return $Hanf_arg289516654(anf_arg19416653,anf_fun1866934);
}};
$e1664316644.stack[R.EXN_STACKHEIGHT++] = $ss1664716648;
}
if(R.isPyretException($e1664316644)) {
$e1664316644.pyretStack.push(L[1123]);
}
throw $e1664316644;
}
var $ret1664916650 = $Hanf_arg289516654($z1664516646,anf_fun1866934);
++R.GAS;
return $ret1664916650;
};
var $Hanf_arg289516654 = function(anf_arg19416653,anf_fun1866934) {
var $z1665716658 = D;
var $f1666316664 = function(_) {
return R.isFunction(anf_fun1866934)?anf_fun1866934.app(anf_arg19416653):R.ffi.throwNonFunApp(L[1125],anf_fun1866934,[anf_arg19416653]);
};
try {
if(--R.GAS > 0) {
$z1665716658 = $f1666316664();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1666316664,
"from":L[1125]});
}
} catch($e1665516656) {
if(R.isCont($e1665516656)) {
var $ss1665916660 = {"from":L[1125],
"go":function(ann_DASH_check_DASH_temp18516665) {
return $Hann_DASH_check_DASH_temp289416666(ann_DASH_check_DASH_temp18516665);
}};
$e1665516656.stack[R.EXN_STACKHEIGHT++] = $ss1665916660;
}
if(R.isPyretException($e1665516656)) {
$e1665516656.pyretStack.push(L[1125]);
}
throw $e1665516656;
}
var $ret1666116662 = $Hann_DASH_check_DASH_temp289416666($z1665716658);
++R.GAS;
return $ret1666116662;
};
var $Hann_DASH_check_DASH_temp289416666 = function(ann_DASH_check_DASH_temp18516665) {
return ann_DASH_check_DASH_temp18516665;
};
var $Hanf_arg28936953 = function(anf_arg1716951,self236952,_plus26,torepr31) {
var anf_arg17216677 = G(self236952,"import-type",L[1098]);
var $z1666916670 = D;
var $f1667516676 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg17216677):R.ffi.throwNonFunApp(L[1098],torepr31,[anf_arg17216677]);
};
try {
if(--R.GAS > 0) {
$z1666916670 = $f1667516676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1667516676,
"from":L[1098]});
}
} catch($e1666716668) {
if(R.isCont($e1666716668)) {
var $ss1667116672 = {"from":L[1098],
"go":function(anf_arg17316678) {
return $Hanf_arg289216679(anf_arg17316678,anf_arg1716951,self236952,_plus26,torepr31);
}};
$e1666716668.stack[R.EXN_STACKHEIGHT++] = $ss1667116672;
}
if(R.isPyretException($e1666716668)) {
$e1666716668.pyretStack.push(L[1098]);
}
throw $e1666716668;
}
var $ret1667316674 = $Hanf_arg289216679($z1666916670,anf_arg1716951,self236952,_plus26,torepr31);
++R.GAS;
return $ret1667316674;
};
var $Hanf_arg289216679 = function(anf_arg17316678,anf_arg1716951,self236952,_plus26,torepr31) {
var $z1668216683 = D;
var $f1668816689 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg17316678):R.ffi.throwNonFunApp(L[1098],_plus26,[(", "),anf_arg17316678]);
};
try {
if(--R.GAS > 0) {
$z1668216683 = $f1668816689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1668816689,
"from":L[1098]});
}
} catch($e1668016681) {
if(R.isCont($e1668016681)) {
var $ss1668416685 = {"from":L[1098],
"go":function(anf_arg17416690) {
return $Hanf_arg289116691(anf_arg17416690,anf_arg1716951,self236952,_plus26,torepr31);
}};
$e1668016681.stack[R.EXN_STACKHEIGHT++] = $ss1668416685;
}
if(R.isPyretException($e1668016681)) {
$e1668016681.pyretStack.push(L[1098]);
}
throw $e1668016681;
}
var $ret1668616687 = $Hanf_arg289116691($z1668216683,anf_arg1716951,self236952,_plus26,torepr31);
++R.GAS;
return $ret1668616687;
};
var $Hanf_arg289116691 = function(anf_arg17416690,anf_arg1716951,self236952,_plus26,torepr31) {
var $z1669416695 = D;
var $f1670016701 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg1716951,anf_arg17416690):R.ffi.throwNonFunApp(L[1098],_plus26,[anf_arg1716951,anf_arg17416690]);
};
try {
if(--R.GAS > 0) {
$z1669416695 = $f1670016701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1670016701,
"from":L[1098]});
}
} catch($e1669216693) {
if(R.isCont($e1669216693)) {
var $ss1669616697 = {"from":L[1098],
"go":function(anf_arg17516702) {
return $Hanf_arg289016703(anf_arg17516702,self236952,_plus26,torepr31);
}};
$e1669216693.stack[R.EXN_STACKHEIGHT++] = $ss1669616697;
}
if(R.isPyretException($e1669216693)) {
$e1669216693.pyretStack.push(L[1098]);
}
throw $e1669216693;
}
var $ret1669816699 = $Hanf_arg289016703($z1669416695,self236952,_plus26,torepr31);
++R.GAS;
return $ret1669816699;
};
var $Hanf_arg289016703 = function(anf_arg17516702,self236952,_plus26,torepr31) {
var anf_arg17616714 = G(self236952,"name",L[1098]);
var $z1670616707 = D;
var $f1671216713 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg17616714):R.ffi.throwNonFunApp(L[1098],torepr31,[anf_arg17616714]);
};
try {
if(--R.GAS > 0) {
$z1670616707 = $f1671216713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1671216713,
"from":L[1098]});
}
} catch($e1670416705) {
if(R.isCont($e1670416705)) {
var $ss1670816709 = {"from":L[1098],
"go":function(anf_arg17716715) {
return $Hanf_arg288916716(anf_arg17716715,anf_arg17516702,_plus26);
}};
$e1670416705.stack[R.EXN_STACKHEIGHT++] = $ss1670816709;
}
if(R.isPyretException($e1670416705)) {
$e1670416705.pyretStack.push(L[1098]);
}
throw $e1670416705;
}
var $ret1671016711 = $Hanf_arg288916716($z1670616707,anf_arg17516702,_plus26);
++R.GAS;
return $ret1671016711;
};
var $Hanf_arg288916716 = function(anf_arg17716715,anf_arg17516702,_plus26) {
var $z1671916720 = D;
var $f1672516726 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg17716715):R.ffi.throwNonFunApp(L[1098],_plus26,[(", "),anf_arg17716715]);
};
try {
if(--R.GAS > 0) {
$z1671916720 = $f1672516726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1672516726,
"from":L[1098]});
}
} catch($e1671716718) {
if(R.isCont($e1671716718)) {
var $ss1672116722 = {"from":L[1098],
"go":function(anf_arg17816727) {
return $Hanf_arg288816728(anf_arg17816727,anf_arg17516702,_plus26);
}};
$e1671716718.stack[R.EXN_STACKHEIGHT++] = $ss1672116722;
}
if(R.isPyretException($e1671716718)) {
$e1671716718.pyretStack.push(L[1098]);
}
throw $e1671716718;
}
var $ret1672316724 = $Hanf_arg288816728($z1671916720,anf_arg17516702,_plus26);
++R.GAS;
return $ret1672316724;
};
var $Hanf_arg288816728 = function(anf_arg17816727,anf_arg17516702,_plus26) {
var $z1673116732 = D;
var $f1673716738 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg17516702,anf_arg17816727):R.ffi.throwNonFunApp(L[1098],_plus26,[anf_arg17516702,anf_arg17816727]);
};
try {
if(--R.GAS > 0) {
$z1673116732 = $f1673716738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1673716738,
"from":L[1098]});
}
} catch($e1672916730) {
if(R.isCont($e1672916730)) {
var $ss1673316734 = {"from":L[1098],
"go":function(anf_arg17916739) {
return $Hanf_arg288716740(anf_arg17916739,_plus26);
}};
$e1672916730.stack[R.EXN_STACKHEIGHT++] = $ss1673316734;
}
if(R.isPyretException($e1672916730)) {
$e1672916730.pyretStack.push(L[1098]);
}
throw $e1672916730;
}
var $ret1673516736 = $Hanf_arg288716740($z1673116732,_plus26);
++R.GAS;
return $ret1673516736;
};
var $Hanf_arg288716740 = function(anf_arg17916739,_plus26) {
var $z1674316744 = D;
var $f1674916750 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg17916739,(")")):R.ffi.throwNonFunApp(L[1098],_plus26,[anf_arg17916739,(")")]);
};
try {
if(--R.GAS > 0) {
$z1674316744 = $f1674916750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1674916750,
"from":L[1098]});
}
} catch($e1674116742) {
if(R.isCont($e1674116742)) {
var $ss1674516746 = {"from":L[1098],
"go":function(anf_arg18016751) {
return $Hanf_arg288616752(anf_arg18016751,_plus26);
}};
$e1674116742.stack[R.EXN_STACKHEIGHT++] = $ss1674516746;
}
if(R.isPyretException($e1674116742)) {
$e1674116742.pyretStack.push(L[1098]);
}
throw $e1674116742;
}
var $ret1674716748 = $Hanf_arg288616752($z1674316744,_plus26);
++R.GAS;
return $ret1674716748;
};
var $Hanf_arg288616752 = function(anf_arg18016751,_plus26) {
var $z1675516756 = D;
var $f1676116762 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg18016751):R.ffi.throwNonFunApp(L[1098],_plus26,[("("),anf_arg18016751]);
};
try {
if(--R.GAS > 0) {
$z1675516756 = $f1676116762();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1676116762,
"from":L[1098]});
}
} catch($e1675316754) {
if(R.isCont($e1675316754)) {
var $ss1675716758 = {"from":L[1098],
"go":function(anf_arg18116763) {
return $Hanf_arg288516764(anf_arg18116763,_plus26);
}};
$e1675316754.stack[R.EXN_STACKHEIGHT++] = $ss1675716758;
}
if(R.isPyretException($e1675316754)) {
$e1675316754.pyretStack.push(L[1098]);
}
throw $e1675316754;
}
var $ret1675916760 = $Hanf_arg288516764($z1675516756,_plus26);
++R.GAS;
return $ret1675916760;
};
var $Hanf_arg288516764 = function(anf_arg18116763,_plus26) {
var $z1676716768 = D;
var $f1677316774 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-import"),anf_arg18116763):R.ffi.throwNonFunApp(L[1098],_plus26,[("a-import"),anf_arg18116763]);
};
try {
if(--R.GAS > 0) {
$z1676716768 = $f1677316774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1677316774,
"from":L[1098]});
}
} catch($e1676516766) {
if(R.isCont($e1676516766)) {
var $ss1676916770 = {"from":L[1098],
"go":function(ann_DASH_check_DASH_temp16916775) {
return $Hann_DASH_check_DASH_temp288416776(ann_DASH_check_DASH_temp16916775);
}};
$e1676516766.stack[R.EXN_STACKHEIGHT++] = $ss1676916770;
}
if(R.isPyretException($e1676516766)) {
$e1676516766.pyretStack.push(L[1098]);
}
throw $e1676516766;
}
var $ret1677116772 = $Hann_DASH_check_DASH_temp288416776($z1676716768);
++R.GAS;
return $ret1677116772;
};
var $Hann_DASH_check_DASH_temp288416776 = function(ann_DASH_check_DASH_temp16916775) {
return ann_DASH_check_DASH_temp16916775;
};
var $Hcont_tail_arg28826970 = function(cont_tail_arg1666968,if_helper1566969) {
if(--R.GAS > 0) {
$z1677716778 = R.isFunction(if_helper1566969)?if_helper1566969.app(cont_tail_arg1666968):R.ffi.throwNonFunApp(L[1098],if_helper1566969,[cont_tail_arg1666968]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1566969)?if_helper1566969.app(cont_tail_arg1666968):R.ffi.throwNonFunApp(L[1098],if_helper1566969,[cont_tail_arg1666968]);
},
"from":L[1098]});
}
++R.GAS;
return $z1677716778;
};
var $Hcont_tail_arg28836985 = function(cont_tail_arg1616984,if_helper1566969) {
if(--R.GAS > 0) {
$z1677916780 = R.isFunction(if_helper1566969)?if_helper1566969.app(cont_tail_arg1616984):R.ffi.throwNonFunApp(L[1098],if_helper1566969,[cont_tail_arg1616984]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1566969)?if_helper1566969.app(cont_tail_arg1616984):R.ffi.throwNonFunApp(L[1098],if_helper1566969,[cont_tail_arg1616984]);
},
"from":L[1098]});
}
++R.GAS;
return $z1677916780;
};
var $Hann_DASH_check_DASH_temp28817007 = function(ann_DASH_check_DASH_temp1477006) {
return ann_DASH_check_DASH_temp1477006;
};
var $Hanf_arg28807020 = function(anf_arg1517019,_plus26,raise30) {
var $z1678316784 = D;
var $f1678916790 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg1517019):R.ffi.throwNonFunApp(L[1647],_plus26,[("No visitor field for "),anf_arg1517019]);
};
try {
if(--R.GAS > 0) {
$z1678316784 = $f1678916790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1678916790,
"from":L[1647]});
}
} catch($e1678116782) {
if(R.isCont($e1678116782)) {
var $ss1678516786 = {"from":L[1647],
"go":function(anf_arg15216791) {
return $Hanf_arg287916792(anf_arg15216791,raise30);
}};
$e1678116782.stack[R.EXN_STACKHEIGHT++] = $ss1678516786;
}
if(R.isPyretException($e1678116782)) {
$e1678116782.pyretStack.push(L[1647]);
}
throw $e1678116782;
}
var $ret1678716788 = $Hanf_arg287916792($z1678316784,raise30);
++R.GAS;
return $ret1678716788;
};
var $Hanf_arg287916792 = function(anf_arg15216791,raise30) {
var $z1679516796 = D;
var $f1680116802 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg15216791):R.ffi.throwNonFunApp(L[1131],raise30,[anf_arg15216791]);
};
try {
if(--R.GAS > 0) {
$z1679516796 = $f1680116802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1680116802,
"from":L[1131]});
}
} catch($e1679316794) {
if(R.isCont($e1679316794)) {
var $ss1679716798 = {"from":L[1131],
"go":function(ann_DASH_check_DASH_temp14916803) {
return $Hann_DASH_check_DASH_temp287816804(ann_DASH_check_DASH_temp14916803);
}};
$e1679316794.stack[R.EXN_STACKHEIGHT++] = $ss1679716798;
}
if(R.isPyretException($e1679316794)) {
$e1679316794.pyretStack.push(L[1131]);
}
throw $e1679316794;
}
var $ret1679916800 = $Hann_DASH_check_DASH_temp287816804($z1679516796);
++R.GAS;
return $ret1679916800;
};
var $Hann_DASH_check_DASH_temp287816804 = function(ann_DASH_check_DASH_temp14916803) {
return ann_DASH_check_DASH_temp14916803;
};
var $Hanf_arg28777056 = function(anf_arg1387054,anf_fun1357055) {
var $z1680716808 = D;
var $f1681316814 = function(_) {
return R.isFunction(anf_fun1357055)?anf_fun1357055.app(anf_arg1387054):R.ffi.throwNonFunApp(L[1148],anf_fun1357055,[anf_arg1387054]);
};
try {
if(--R.GAS > 0) {
$z1680716808 = $f1681316814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1681316814,
"from":L[1148]});
}
} catch($e1680516806) {
if(R.isCont($e1680516806)) {
var $ss1680916810 = {"from":L[1148],
"go":function(ann_DASH_check_DASH_temp13416815) {
return $Hann_DASH_check_DASH_temp287616816(ann_DASH_check_DASH_temp13416815);
}};
$e1680516806.stack[R.EXN_STACKHEIGHT++] = $ss1680916810;
}
if(R.isPyretException($e1680516806)) {
$e1680516806.pyretStack.push(L[1148]);
}
throw $e1680516806;
}
var $ret1681116812 = $Hann_DASH_check_DASH_temp287616816($z1680716808);
++R.GAS;
return $ret1681116812;
};
var $Hann_DASH_check_DASH_temp287616816 = function(ann_DASH_check_DASH_temp13416815) {
return ann_DASH_check_DASH_temp13416815;
};
var $Hanf_arg28757071 = function(anf_arg1267069,self177070,_plus26,torepr31) {
var anf_arg12716827 = G(self177070,"file",L[1135]);
var $z1681916820 = D;
var $f1682516826 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg12716827):R.ffi.throwNonFunApp(L[1135],torepr31,[anf_arg12716827]);
};
try {
if(--R.GAS > 0) {
$z1681916820 = $f1682516826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1682516826,
"from":L[1135]});
}
} catch($e1681716818) {
if(R.isCont($e1681716818)) {
var $ss1682116822 = {"from":L[1135],
"go":function(anf_arg12816828) {
return $Hanf_arg287416829(anf_arg12816828,anf_arg1267069,_plus26);
}};
$e1681716818.stack[R.EXN_STACKHEIGHT++] = $ss1682116822;
}
if(R.isPyretException($e1681716818)) {
$e1681716818.pyretStack.push(L[1135]);
}
throw $e1681716818;
}
var $ret1682316824 = $Hanf_arg287416829($z1681916820,anf_arg1267069,_plus26);
++R.GAS;
return $ret1682316824;
};
var $Hanf_arg287416829 = function(anf_arg12816828,anf_arg1267069,_plus26) {
var $z1683216833 = D;
var $f1683816839 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg12816828):R.ffi.throwNonFunApp(L[1135],_plus26,[(", "),anf_arg12816828]);
};
try {
if(--R.GAS > 0) {
$z1683216833 = $f1683816839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1683816839,
"from":L[1135]});
}
} catch($e1683016831) {
if(R.isCont($e1683016831)) {
var $ss1683416835 = {"from":L[1135],
"go":function(anf_arg12916840) {
return $Hanf_arg287316841(anf_arg12916840,anf_arg1267069,_plus26);
}};
$e1683016831.stack[R.EXN_STACKHEIGHT++] = $ss1683416835;
}
if(R.isPyretException($e1683016831)) {
$e1683016831.pyretStack.push(L[1135]);
}
throw $e1683016831;
}
var $ret1683616837 = $Hanf_arg287316841($z1683216833,anf_arg1267069,_plus26);
++R.GAS;
return $ret1683616837;
};
var $Hanf_arg287316841 = function(anf_arg12916840,anf_arg1267069,_plus26) {
var $z1684416845 = D;
var $f1685016851 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg1267069,anf_arg12916840):R.ffi.throwNonFunApp(L[1135],_plus26,[anf_arg1267069,anf_arg12916840]);
};
try {
if(--R.GAS > 0) {
$z1684416845 = $f1685016851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1685016851,
"from":L[1135]});
}
} catch($e1684216843) {
if(R.isCont($e1684216843)) {
var $ss1684616847 = {"from":L[1135],
"go":function(anf_arg13016852) {
return $Hanf_arg287216853(anf_arg13016852,_plus26);
}};
$e1684216843.stack[R.EXN_STACKHEIGHT++] = $ss1684616847;
}
if(R.isPyretException($e1684216843)) {
$e1684216843.pyretStack.push(L[1135]);
}
throw $e1684216843;
}
var $ret1684816849 = $Hanf_arg287216853($z1684416845,_plus26);
++R.GAS;
return $ret1684816849;
};
var $Hanf_arg287216853 = function(anf_arg13016852,_plus26) {
var $z1685616857 = D;
var $f1686216863 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg13016852,(")")):R.ffi.throwNonFunApp(L[1135],_plus26,[anf_arg13016852,(")")]);
};
try {
if(--R.GAS > 0) {
$z1685616857 = $f1686216863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1686216863,
"from":L[1135]});
}
} catch($e1685416855) {
if(R.isCont($e1685416855)) {
var $ss1685816859 = {"from":L[1135],
"go":function(anf_arg13116864) {
return $Hanf_arg287116865(anf_arg13116864,_plus26);
}};
$e1685416855.stack[R.EXN_STACKHEIGHT++] = $ss1685816859;
}
if(R.isPyretException($e1685416855)) {
$e1685416855.pyretStack.push(L[1135]);
}
throw $e1685416855;
}
var $ret1686016861 = $Hanf_arg287116865($z1685616857,_plus26);
++R.GAS;
return $ret1686016861;
};
var $Hanf_arg287116865 = function(anf_arg13116864,_plus26) {
var $z1686816869 = D;
var $f1687416875 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg13116864):R.ffi.throwNonFunApp(L[1135],_plus26,[("("),anf_arg13116864]);
};
try {
if(--R.GAS > 0) {
$z1686816869 = $f1687416875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1687416875,
"from":L[1135]});
}
} catch($e1686616867) {
if(R.isCont($e1686616867)) {
var $ss1687016871 = {"from":L[1135],
"go":function(anf_arg13216876) {
return $Hanf_arg287016877(anf_arg13216876,_plus26);
}};
$e1686616867.stack[R.EXN_STACKHEIGHT++] = $ss1687016871;
}
if(R.isPyretException($e1686616867)) {
$e1686616867.pyretStack.push(L[1135]);
}
throw $e1686616867;
}
var $ret1687216873 = $Hanf_arg287016877($z1686816869,_plus26);
++R.GAS;
return $ret1687216873;
};
var $Hanf_arg287016877 = function(anf_arg13216876,_plus26) {
var $z1688016881 = D;
var $f1688616887 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-import-file"),anf_arg13216876):R.ffi.throwNonFunApp(L[1135],_plus26,[("a-import-file"),anf_arg13216876]);
};
try {
if(--R.GAS > 0) {
$z1688016881 = $f1688616887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1688616887,
"from":L[1135]});
}
} catch($e1687816879) {
if(R.isCont($e1687816879)) {
var $ss1688216883 = {"from":L[1135],
"go":function(ann_DASH_check_DASH_temp12416888) {
return $Hann_DASH_check_DASH_temp286916889(ann_DASH_check_DASH_temp12416888);
}};
$e1687816879.stack[R.EXN_STACKHEIGHT++] = $ss1688216883;
}
if(R.isPyretException($e1687816879)) {
$e1687816879.pyretStack.push(L[1135]);
}
throw $e1687816879;
}
var $ret1688416885 = $Hann_DASH_check_DASH_temp286916889($z1688016881);
++R.GAS;
return $ret1688416885;
};
var $Hann_DASH_check_DASH_temp286916889 = function(ann_DASH_check_DASH_temp12416888) {
return ann_DASH_check_DASH_temp12416888;
};
var $Hcont_tail_arg28677087 = function(cont_tail_arg1217085,if_helper1127086) {
if(--R.GAS > 0) {
$z1689016891 = R.isFunction(if_helper1127086)?if_helper1127086.app(cont_tail_arg1217085):R.ffi.throwNonFunApp(L[1135],if_helper1127086,[cont_tail_arg1217085]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1127086)?if_helper1127086.app(cont_tail_arg1217085):R.ffi.throwNonFunApp(L[1135],if_helper1127086,[cont_tail_arg1217085]);
},
"from":L[1135]});
}
++R.GAS;
return $z1689016891;
};
var $Hcont_tail_arg28687102 = function(cont_tail_arg1177101,if_helper1127086) {
if(--R.GAS > 0) {
$z1689216893 = R.isFunction(if_helper1127086)?if_helper1127086.app(cont_tail_arg1177101):R.ffi.throwNonFunApp(L[1135],if_helper1127086,[cont_tail_arg1177101]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper1127086)?if_helper1127086.app(cont_tail_arg1177101):R.ffi.throwNonFunApp(L[1135],if_helper1127086,[cont_tail_arg1177101]);
},
"from":L[1135]});
}
++R.GAS;
return $z1689216893;
};
var $Hann_DASH_check_DASH_temp28667123 = function(ann_DASH_check_DASH_temp1077122) {
return ann_DASH_check_DASH_temp1077122;
};
var $Hanf_arg28657138 = function(anf_arg997136,self117137,_plus26,torepr31) {
var anf_arg10016904 = G(self117137,"lib",L[1136]);
var $z1689616897 = D;
var $f1690216903 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg10016904):R.ffi.throwNonFunApp(L[1136],torepr31,[anf_arg10016904]);
};
try {
if(--R.GAS > 0) {
$z1689616897 = $f1690216903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1690216903,
"from":L[1136]});
}
} catch($e1689416895) {
if(R.isCont($e1689416895)) {
var $ss1689816899 = {"from":L[1136],
"go":function(anf_arg10116905) {
return $Hanf_arg286416906(anf_arg10116905,anf_arg997136,_plus26);
}};
$e1689416895.stack[R.EXN_STACKHEIGHT++] = $ss1689816899;
}
if(R.isPyretException($e1689416895)) {
$e1689416895.pyretStack.push(L[1136]);
}
throw $e1689416895;
}
var $ret1690016901 = $Hanf_arg286416906($z1689616897,anf_arg997136,_plus26);
++R.GAS;
return $ret1690016901;
};
var $Hanf_arg286416906 = function(anf_arg10116905,anf_arg997136,_plus26) {
var $z1690916910 = D;
var $f1691516916 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg10116905):R.ffi.throwNonFunApp(L[1136],_plus26,[(", "),anf_arg10116905]);
};
try {
if(--R.GAS > 0) {
$z1690916910 = $f1691516916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1691516916,
"from":L[1136]});
}
} catch($e1690716908) {
if(R.isCont($e1690716908)) {
var $ss1691116912 = {"from":L[1136],
"go":function(anf_arg10216917) {
return $Hanf_arg286316918(anf_arg10216917,anf_arg997136,_plus26);
}};
$e1690716908.stack[R.EXN_STACKHEIGHT++] = $ss1691116912;
}
if(R.isPyretException($e1690716908)) {
$e1690716908.pyretStack.push(L[1136]);
}
throw $e1690716908;
}
var $ret1691316914 = $Hanf_arg286316918($z1690916910,anf_arg997136,_plus26);
++R.GAS;
return $ret1691316914;
};
var $Hanf_arg286316918 = function(anf_arg10216917,anf_arg997136,_plus26) {
var $z1692116922 = D;
var $f1692716928 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg997136,anf_arg10216917):R.ffi.throwNonFunApp(L[1136],_plus26,[anf_arg997136,anf_arg10216917]);
};
try {
if(--R.GAS > 0) {
$z1692116922 = $f1692716928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1692716928,
"from":L[1136]});
}
} catch($e1691916920) {
if(R.isCont($e1691916920)) {
var $ss1692316924 = {"from":L[1136],
"go":function(anf_arg10316929) {
return $Hanf_arg286216930(anf_arg10316929,_plus26);
}};
$e1691916920.stack[R.EXN_STACKHEIGHT++] = $ss1692316924;
}
if(R.isPyretException($e1691916920)) {
$e1691916920.pyretStack.push(L[1136]);
}
throw $e1691916920;
}
var $ret1692516926 = $Hanf_arg286216930($z1692116922,_plus26);
++R.GAS;
return $ret1692516926;
};
var $Hanf_arg286216930 = function(anf_arg10316929,_plus26) {
var $z1693316934 = D;
var $f1693916940 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg10316929,(")")):R.ffi.throwNonFunApp(L[1136],_plus26,[anf_arg10316929,(")")]);
};
try {
if(--R.GAS > 0) {
$z1693316934 = $f1693916940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1693916940,
"from":L[1136]});
}
} catch($e1693116932) {
if(R.isCont($e1693116932)) {
var $ss1693516936 = {"from":L[1136],
"go":function(anf_arg10416941) {
return $Hanf_arg286116942(anf_arg10416941,_plus26);
}};
$e1693116932.stack[R.EXN_STACKHEIGHT++] = $ss1693516936;
}
if(R.isPyretException($e1693116932)) {
$e1693116932.pyretStack.push(L[1136]);
}
throw $e1693116932;
}
var $ret1693716938 = $Hanf_arg286116942($z1693316934,_plus26);
++R.GAS;
return $ret1693716938;
};
var $Hanf_arg286116942 = function(anf_arg10416941,_plus26) {
var $z1694516946 = D;
var $f1695116952 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg10416941):R.ffi.throwNonFunApp(L[1136],_plus26,[("("),anf_arg10416941]);
};
try {
if(--R.GAS > 0) {
$z1694516946 = $f1695116952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1695116952,
"from":L[1136]});
}
} catch($e1694316944) {
if(R.isCont($e1694316944)) {
var $ss1694716948 = {"from":L[1136],
"go":function(anf_arg10516953) {
return $Hanf_arg286016954(anf_arg10516953,_plus26);
}};
$e1694316944.stack[R.EXN_STACKHEIGHT++] = $ss1694716948;
}
if(R.isPyretException($e1694316944)) {
$e1694316944.pyretStack.push(L[1136]);
}
throw $e1694316944;
}
var $ret1694916950 = $Hanf_arg286016954($z1694516946,_plus26);
++R.GAS;
return $ret1694916950;
};
var $Hanf_arg286016954 = function(anf_arg10516953,_plus26) {
var $z1695716958 = D;
var $f1696316964 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-import-builtin"),anf_arg10516953):R.ffi.throwNonFunApp(L[1136],_plus26,[("a-import-builtin"),anf_arg10516953]);
};
try {
if(--R.GAS > 0) {
$z1695716958 = $f1696316964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1696316964,
"from":L[1136]});
}
} catch($e1695516956) {
if(R.isCont($e1695516956)) {
var $ss1695916960 = {"from":L[1136],
"go":function(ann_DASH_check_DASH_temp9716965) {
return $Hann_DASH_check_DASH_temp285916966(ann_DASH_check_DASH_temp9716965);
}};
$e1695516956.stack[R.EXN_STACKHEIGHT++] = $ss1695916960;
}
if(R.isPyretException($e1695516956)) {
$e1695516956.pyretStack.push(L[1136]);
}
throw $e1695516956;
}
var $ret1696116962 = $Hann_DASH_check_DASH_temp285916966($z1695716958);
++R.GAS;
return $ret1696116962;
};
var $Hann_DASH_check_DASH_temp285916966 = function(ann_DASH_check_DASH_temp9716965) {
return ann_DASH_check_DASH_temp9716965;
};
var $Hcont_tail_arg28577154 = function(cont_tail_arg947152,if_helper857153) {
if(--R.GAS > 0) {
$z1696716968 = R.isFunction(if_helper857153)?if_helper857153.app(cont_tail_arg947152):R.ffi.throwNonFunApp(L[1136],if_helper857153,[cont_tail_arg947152]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper857153)?if_helper857153.app(cont_tail_arg947152):R.ffi.throwNonFunApp(L[1136],if_helper857153,[cont_tail_arg947152]);
},
"from":L[1136]});
}
++R.GAS;
return $z1696716968;
};
var $Hcont_tail_arg28587169 = function(cont_tail_arg907168,if_helper857153) {
if(--R.GAS > 0) {
$z1696916970 = R.isFunction(if_helper857153)?if_helper857153.app(cont_tail_arg907168):R.ffi.throwNonFunApp(L[1136],if_helper857153,[cont_tail_arg907168]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper857153)?if_helper857153.app(cont_tail_arg907168):R.ffi.throwNonFunApp(L[1136],if_helper857153,[cont_tail_arg907168]);
},
"from":L[1136]});
}
++R.GAS;
return $z1696916970;
};
var $Hanf_arg28567207 = function(anf_arg717204,PP337,anf_fun647205,self2587206,_plus26) {
var anf_arg7216981 = G(PP337,"hardline",L[1649]);
var $z1697316974 = D;
var $f1697916980 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg717204,anf_arg7216981):R.ffi.throwNonFunApp(L[1648],_plus26,[anf_arg717204,anf_arg7216981]);
};
try {
if(--R.GAS > 0) {
$z1697316974 = $f1697916980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1697916980,
"from":L[1648]});
}
} catch($e1697116972) {
if(R.isCont($e1697116972)) {
var $ss1697516976 = {"from":L[1648],
"go":function(anf_arg7316982) {
return $Hanf_arg285516983(anf_arg7316982,anf_fun647205,self2587206,_plus26);
}};
$e1697116972.stack[R.EXN_STACKHEIGHT++] = $ss1697516976;
}
if(R.isPyretException($e1697116972)) {
$e1697116972.pyretStack.push(L[1648]);
}
throw $e1697116972;
}
var $ret1697716978 = $Hanf_arg285516983($z1697316974,anf_fun647205,self2587206,_plus26);
++R.GAS;
return $ret1697716978;
};
var $Hanf_arg285516983 = function(anf_arg7316982,anf_fun647205,self2587206,_plus26) {
var anf_bracket7416997 = G(self2587206,"body",L[1652]);
var anf_fun7516994 = G(anf_bracket7416997,"tosource",L[1651]);
var $z1698616987 = D;
var $f1699216993 = function(_) {
return R.isFunction(anf_fun7516994)?anf_fun7516994.app():R.ffi.throwNonFunApp(L[1650],anf_fun7516994,[]);
};
try {
if(--R.GAS > 0) {
$z1698616987 = $f1699216993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1699216993,
"from":L[1650]});
}
} catch($e1698416985) {
if(R.isCont($e1698416985)) {
var $ss1698816989 = {"from":L[1650],
"go":function(anf_arg7616995) {
return $Hanf_arg285416996(anf_arg7616995,anf_arg7316982,anf_fun647205,_plus26);
}};
$e1698416985.stack[R.EXN_STACKHEIGHT++] = $ss1698816989;
}
if(R.isPyretException($e1698416985)) {
$e1698416985.pyretStack.push(L[1650]);
}
throw $e1698416985;
}
var $ret1699016991 = $Hanf_arg285416996($z1698616987,anf_arg7316982,anf_fun647205,_plus26);
++R.GAS;
return $ret1699016991;
};
var $Hanf_arg285416996 = function(anf_arg7616995,anf_arg7316982,anf_fun647205,_plus26) {
var $z1700017001 = D;
var $f1700617007 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg7316982,anf_arg7616995):R.ffi.throwNonFunApp(L[1648],_plus26,[anf_arg7316982,anf_arg7616995]);
};
try {
if(--R.GAS > 0) {
$z1700017001 = $f1700617007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1700617007,
"from":L[1648]});
}
} catch($e1699816999) {
if(R.isCont($e1699816999)) {
var $ss1700217003 = {"from":L[1648],
"go":function(anf_arg7717008) {
return $Hanf_arg285317009(anf_arg7717008,anf_fun647205);
}};
$e1699816999.stack[R.EXN_STACKHEIGHT++] = $ss1700217003;
}
if(R.isPyretException($e1699816999)) {
$e1699816999.pyretStack.push(L[1648]);
}
throw $e1699816999;
}
var $ret1700417005 = $Hanf_arg285317009($z1700017001,anf_fun647205);
++R.GAS;
return $ret1700417005;
};
var $Hanf_arg285317009 = function(anf_arg7717008,anf_fun647205) {
var $z1701217013 = D;
var $f1701817019 = function(_) {
return R.isFunction(anf_fun647205)?anf_fun647205.app(anf_arg7717008):R.ffi.throwNonFunApp(L[1169],anf_fun647205,[anf_arg7717008]);
};
try {
if(--R.GAS > 0) {
$z1701217013 = $f1701817019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1701817019,
"from":L[1169]});
}
} catch($e1701017011) {
if(R.isCont($e1701017011)) {
var $ss1701417015 = {"from":L[1169],
"go":function(ann_DASH_check_DASH_temp6317020) {
return $Hann_DASH_check_DASH_temp285217021(ann_DASH_check_DASH_temp6317020);
}};
$e1701017011.stack[R.EXN_STACKHEIGHT++] = $ss1701417015;
}
if(R.isPyretException($e1701017011)) {
$e1701017011.pyretStack.push(L[1169]);
}
throw $e1701017011;
}
var $ret1701617017 = $Hann_DASH_check_DASH_temp285217021($z1701217013);
++R.GAS;
return $ret1701617017;
};
var $Hann_DASH_check_DASH_temp285217021 = function(ann_DASH_check_DASH_temp6317020) {
return ann_DASH_check_DASH_temp6317020;
};
var $Hann_DASH_check_DASH_temp28517221 = function(ann_DASH_check_DASH_temp677220) {
return ann_DASH_check_DASH_temp677220;
};
var $Hanf_arg28507236 = function(anf_arg497234,self57235,_plus26,torepr31) {
var anf_arg5017032 = G(self57235,"imports",L[1156]);
var $z1702417025 = D;
var $f1703017031 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg5017032):R.ffi.throwNonFunApp(L[1156],torepr31,[anf_arg5017032]);
};
try {
if(--R.GAS > 0) {
$z1702417025 = $f1703017031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1703017031,
"from":L[1156]});
}
} catch($e1702217023) {
if(R.isCont($e1702217023)) {
var $ss1702617027 = {"from":L[1156],
"go":function(anf_arg5117033) {
return $Hanf_arg284917034(anf_arg5117033,anf_arg497234,self57235,_plus26,torepr31);
}};
$e1702217023.stack[R.EXN_STACKHEIGHT++] = $ss1702617027;
}
if(R.isPyretException($e1702217023)) {
$e1702217023.pyretStack.push(L[1156]);
}
throw $e1702217023;
}
var $ret1702817029 = $Hanf_arg284917034($z1702417025,anf_arg497234,self57235,_plus26,torepr31);
++R.GAS;
return $ret1702817029;
};
var $Hanf_arg284917034 = function(anf_arg5117033,anf_arg497234,self57235,_plus26,torepr31) {
var $z1703717038 = D;
var $f1704317044 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg5117033):R.ffi.throwNonFunApp(L[1156],_plus26,[(", "),anf_arg5117033]);
};
try {
if(--R.GAS > 0) {
$z1703717038 = $f1704317044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1704317044,
"from":L[1156]});
}
} catch($e1703517036) {
if(R.isCont($e1703517036)) {
var $ss1703917040 = {"from":L[1156],
"go":function(anf_arg5217045) {
return $Hanf_arg284817046(anf_arg5217045,anf_arg497234,self57235,_plus26,torepr31);
}};
$e1703517036.stack[R.EXN_STACKHEIGHT++] = $ss1703917040;
}
if(R.isPyretException($e1703517036)) {
$e1703517036.pyretStack.push(L[1156]);
}
throw $e1703517036;
}
var $ret1704117042 = $Hanf_arg284817046($z1703717038,anf_arg497234,self57235,_plus26,torepr31);
++R.GAS;
return $ret1704117042;
};
var $Hanf_arg284817046 = function(anf_arg5217045,anf_arg497234,self57235,_plus26,torepr31) {
var $z1704917050 = D;
var $f1705517056 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg497234,anf_arg5217045):R.ffi.throwNonFunApp(L[1156],_plus26,[anf_arg497234,anf_arg5217045]);
};
try {
if(--R.GAS > 0) {
$z1704917050 = $f1705517056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1705517056,
"from":L[1156]});
}
} catch($e1704717048) {
if(R.isCont($e1704717048)) {
var $ss1705117052 = {"from":L[1156],
"go":function(anf_arg5317057) {
return $Hanf_arg284717058(anf_arg5317057,self57235,_plus26,torepr31);
}};
$e1704717048.stack[R.EXN_STACKHEIGHT++] = $ss1705117052;
}
if(R.isPyretException($e1704717048)) {
$e1704717048.pyretStack.push(L[1156]);
}
throw $e1704717048;
}
var $ret1705317054 = $Hanf_arg284717058($z1704917050,self57235,_plus26,torepr31);
++R.GAS;
return $ret1705317054;
};
var $Hanf_arg284717058 = function(anf_arg5317057,self57235,_plus26,torepr31) {
var anf_arg5417069 = G(self57235,"body",L[1156]);
var $z1706117062 = D;
var $f1706717068 = function(_) {
return R.isFunction(torepr31)?torepr31.app(anf_arg5417069):R.ffi.throwNonFunApp(L[1156],torepr31,[anf_arg5417069]);
};
try {
if(--R.GAS > 0) {
$z1706117062 = $f1706717068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1706717068,
"from":L[1156]});
}
} catch($e1705917060) {
if(R.isCont($e1705917060)) {
var $ss1706317064 = {"from":L[1156],
"go":function(anf_arg5517070) {
return $Hanf_arg284617071(anf_arg5517070,anf_arg5317057,_plus26);
}};
$e1705917060.stack[R.EXN_STACKHEIGHT++] = $ss1706317064;
}
if(R.isPyretException($e1705917060)) {
$e1705917060.pyretStack.push(L[1156]);
}
throw $e1705917060;
}
var $ret1706517066 = $Hanf_arg284617071($z1706117062,anf_arg5317057,_plus26);
++R.GAS;
return $ret1706517066;
};
var $Hanf_arg284617071 = function(anf_arg5517070,anf_arg5317057,_plus26) {
var $z1707417075 = D;
var $f1708017081 = function(_) {
return R.isFunction(_plus26)?_plus26.app((", "),anf_arg5517070):R.ffi.throwNonFunApp(L[1156],_plus26,[(", "),anf_arg5517070]);
};
try {
if(--R.GAS > 0) {
$z1707417075 = $f1708017081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1708017081,
"from":L[1156]});
}
} catch($e1707217073) {
if(R.isCont($e1707217073)) {
var $ss1707617077 = {"from":L[1156],
"go":function(anf_arg5617082) {
return $Hanf_arg284517083(anf_arg5617082,anf_arg5317057,_plus26);
}};
$e1707217073.stack[R.EXN_STACKHEIGHT++] = $ss1707617077;
}
if(R.isPyretException($e1707217073)) {
$e1707217073.pyretStack.push(L[1156]);
}
throw $e1707217073;
}
var $ret1707817079 = $Hanf_arg284517083($z1707417075,anf_arg5317057,_plus26);
++R.GAS;
return $ret1707817079;
};
var $Hanf_arg284517083 = function(anf_arg5617082,anf_arg5317057,_plus26) {
var $z1708617087 = D;
var $f1709217093 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg5317057,anf_arg5617082):R.ffi.throwNonFunApp(L[1156],_plus26,[anf_arg5317057,anf_arg5617082]);
};
try {
if(--R.GAS > 0) {
$z1708617087 = $f1709217093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1709217093,
"from":L[1156]});
}
} catch($e1708417085) {
if(R.isCont($e1708417085)) {
var $ss1708817089 = {"from":L[1156],
"go":function(anf_arg5717094) {
return $Hanf_arg284417095(anf_arg5717094,_plus26);
}};
$e1708417085.stack[R.EXN_STACKHEIGHT++] = $ss1708817089;
}
if(R.isPyretException($e1708417085)) {
$e1708417085.pyretStack.push(L[1156]);
}
throw $e1708417085;
}
var $ret1709017091 = $Hanf_arg284417095($z1708617087,_plus26);
++R.GAS;
return $ret1709017091;
};
var $Hanf_arg284417095 = function(anf_arg5717094,_plus26) {
var $z1709817099 = D;
var $f1710417105 = function(_) {
return R.isFunction(_plus26)?_plus26.app(anf_arg5717094,(")")):R.ffi.throwNonFunApp(L[1156],_plus26,[anf_arg5717094,(")")]);
};
try {
if(--R.GAS > 0) {
$z1709817099 = $f1710417105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1710417105,
"from":L[1156]});
}
} catch($e1709617097) {
if(R.isCont($e1709617097)) {
var $ss1710017101 = {"from":L[1156],
"go":function(anf_arg5817106) {
return $Hanf_arg284317107(anf_arg5817106,_plus26);
}};
$e1709617097.stack[R.EXN_STACKHEIGHT++] = $ss1710017101;
}
if(R.isPyretException($e1709617097)) {
$e1709617097.pyretStack.push(L[1156]);
}
throw $e1709617097;
}
var $ret1710217103 = $Hanf_arg284317107($z1709817099,_plus26);
++R.GAS;
return $ret1710217103;
};
var $Hanf_arg284317107 = function(anf_arg5817106,_plus26) {
var $z1711017111 = D;
var $f1711617117 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("("),anf_arg5817106):R.ffi.throwNonFunApp(L[1156],_plus26,[("("),anf_arg5817106]);
};
try {
if(--R.GAS > 0) {
$z1711017111 = $f1711617117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1711617117,
"from":L[1156]});
}
} catch($e1710817109) {
if(R.isCont($e1710817109)) {
var $ss1711217113 = {"from":L[1156],
"go":function(anf_arg5917118) {
return $Hanf_arg284217119(anf_arg5917118,_plus26);
}};
$e1710817109.stack[R.EXN_STACKHEIGHT++] = $ss1711217113;
}
if(R.isPyretException($e1710817109)) {
$e1710817109.pyretStack.push(L[1156]);
}
throw $e1710817109;
}
var $ret1711417115 = $Hanf_arg284217119($z1711017111,_plus26);
++R.GAS;
return $ret1711417115;
};
var $Hanf_arg284217119 = function(anf_arg5917118,_plus26) {
var $z1712217123 = D;
var $f1712817129 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("a-program"),anf_arg5917118):R.ffi.throwNonFunApp(L[1156],_plus26,[("a-program"),anf_arg5917118]);
};
try {
if(--R.GAS > 0) {
$z1712217123 = $f1712817129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1712817129,
"from":L[1156]});
}
} catch($e1712017121) {
if(R.isCont($e1712017121)) {
var $ss1712417125 = {"from":L[1156],
"go":function(ann_DASH_check_DASH_temp4717130) {
return $Hann_DASH_check_DASH_temp284117131(ann_DASH_check_DASH_temp4717130);
}};
$e1712017121.stack[R.EXN_STACKHEIGHT++] = $ss1712417125;
}
if(R.isPyretException($e1712017121)) {
$e1712017121.pyretStack.push(L[1156]);
}
throw $e1712017121;
}
var $ret1712617127 = $Hann_DASH_check_DASH_temp284117131($z1712217123);
++R.GAS;
return $ret1712617127;
};
var $Hann_DASH_check_DASH_temp284117131 = function(ann_DASH_check_DASH_temp4717130) {
return ann_DASH_check_DASH_temp4717130;
};
var $Hcont_tail_arg28397253 = function(cont_tail_arg447251,if_helper347252) {
if(--R.GAS > 0) {
$z1713217133 = R.isFunction(if_helper347252)?if_helper347252.app(cont_tail_arg447251):R.ffi.throwNonFunApp(L[1156],if_helper347252,[cont_tail_arg447251]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper347252)?if_helper347252.app(cont_tail_arg447251):R.ffi.throwNonFunApp(L[1156],if_helper347252,[cont_tail_arg447251]);
},
"from":L[1156]});
}
++R.GAS;
return $z1713217133;
};
var $Hcont_tail_arg28407268 = function(cont_tail_arg397267,if_helper347252) {
if(--R.GAS > 0) {
$z1713417135 = R.isFunction(if_helper347252)?if_helper347252.app(cont_tail_arg397267):R.ffi.throwNonFunApp(L[1156],if_helper347252,[cont_tail_arg397267]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored3409) {
return R.isFunction(if_helper347252)?if_helper347252.app(cont_tail_arg397267):R.ffi.throwNonFunApp(L[1156],if_helper347252,[cont_tail_arg397267]);
},
"from":L[1156]});
}
++R.GAS;
return $z1713417135;
};
var $Hann_DASH_check_DASH_temp28387290 = function(ann_DASH_check_DASH_temp257289) {
return ann_DASH_check_DASH_temp257289;
};
var $Hanf_arg28377303 = function(anf_arg297302,_plus26,raise30) {
var $z1713817139 = D;
var $f1714417145 = function(_) {
return R.isFunction(_plus26)?_plus26.app(("No visitor field for "),anf_arg297302):R.ffi.throwNonFunApp(L[1653],_plus26,[("No visitor field for "),anf_arg297302]);
};
try {
if(--R.GAS > 0) {
$z1713817139 = $f1714417145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1714417145,
"from":L[1653]});
}
} catch($e1713617137) {
if(R.isCont($e1713617137)) {
var $ss1714017141 = {"from":L[1653],
"go":function(anf_arg3017146) {
return $Hanf_arg283617147(anf_arg3017146,raise30);
}};
$e1713617137.stack[R.EXN_STACKHEIGHT++] = $ss1714017141;
}
if(R.isPyretException($e1713617137)) {
$e1713617137.pyretStack.push(L[1653]);
}
throw $e1713617137;
}
var $ret1714217143 = $Hanf_arg283617147($z1713817139,raise30);
++R.GAS;
return $ret1714217143;
};
var $Hanf_arg283617147 = function(anf_arg3017146,raise30) {
var $z1715017151 = D;
var $f1715617157 = function(_) {
return R.isFunction(raise30)?raise30.app(anf_arg3017146):R.ffi.throwNonFunApp(L[1175],raise30,[anf_arg3017146]);
};
try {
if(--R.GAS > 0) {
$z1715017151 = $f1715617157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1715617157,
"from":L[1175]});
}
} catch($e1714817149) {
if(R.isCont($e1714817149)) {
var $ss1715217153 = {"from":L[1175],
"go":function(ann_DASH_check_DASH_temp2717158) {
return $Hann_DASH_check_DASH_temp283517159(ann_DASH_check_DASH_temp2717158);
}};
$e1714817149.stack[R.EXN_STACKHEIGHT++] = $ss1715217153;
}
if(R.isPyretException($e1714817149)) {
$e1714817149.pyretStack.push(L[1175]);
}
throw $e1714817149;
}
var $ret1715417155 = $Hann_DASH_check_DASH_temp283517159($z1715017151);
++R.GAS;
return $ret1715417155;
};
var $Hann_DASH_check_DASH_temp283517159 = function(ann_DASH_check_DASH_temp2717158) {
return ann_DASH_check_DASH_temp2717158;
};
return R.loadModulesNew(NAMESPACE,[$A13653,$PP33754,$SL53855,$arrays73956,$lists94057,$option114158,$error134259,$sets154360],function($A13653,$PP33754,$SL53855,$arrays73956,$lists94057,$option114158,$error134259,$sets154360) {
var A136 = R.getField($A13653,"values");
var PP337 = R.getField($PP33754,"values");
var SL538 = R.getField($SL53855,"values");
var arrays739 = R.getField($arrays73956,"values");
var lists940 = R.getField($lists94057,"values");
var option1141 = R.getField($option114158,"values");
var error1342 = R.getField($error134259,"values");
var sets1543 = R.getField($sets154360,"values");
var A244 = R.getField($A13653,"types");
var PP445 = R.getField($PP33754,"types");
var SL646 = R.getField($SL53855,"types");
var arrays847 = R.getField($arrays73956,"types");
var lists1048 = R.getField($lists94057,"types");
var option1249 = R.getField($option114158,"types");
var error1450 = R.getField($error134259,"types");
var sets1651 = R.getField($sets154360,"types");
return R.safeCall(function() {
var List1788 = R.getDotAnn(L[1654],"lists",lists1048,"List");
var Option1817160 = R.getDotAnn(L[1654],"option",option1249,"Option");
var Array1917161 = R.getDotAnn(L[1654],"arrays",arrays847,"Array");
var Set2090 = R.getDotAnn(L[1654],"sets",sets1651,"Set");
var array2117214 = G(arrays739,"array",L[1654]);
var build_DASH_array2217213 = G(arrays739,"build-array",L[1654]);
var array_DASH_from_DASH_list2317212 = G(arrays739,"array-from-list",L[1654]);
var is_DASH_array2417211 = G(arrays739,"is-array",L[1654]);
var list2593 = G(lists940,"list",L[1654]);
var is_DASH_empty2617210 = G(lists940,"is-empty",L[1654]);
var is_DASH_link2717209 = G(lists940,"is-link",L[1654]);
var empty2817208 = G(lists940,"empty",L[1654]);
var link2992 = G(lists940,"link",L[1654]);
var range3017207 = G(lists940,"range",L[1654]);
var repeat3117206 = G(lists940,"repeat",L[1654]);
var filter3217205 = G(lists940,"filter",L[1654]);
var partition3317204 = G(lists940,"partition",L[1654]);
var split_DASH_at3417203 = G(lists940,"split-at",L[1654]);
var any3517202 = G(lists940,"any",L[1654]);
var find3617201 = G(lists940,"find",L[1654]);
var map3717200 = G(lists940,"map",L[1654]);
var map23817199 = G(lists940,"map2",L[1654]);
var map33917198 = G(lists940,"map3",L[1654]);
var map44017197 = G(lists940,"map4",L[1654]);
var map_n4117196 = G(lists940,"map_n",L[1654]);
var map2_n4217195 = G(lists940,"map2_n",L[1654]);
var map3_n4317194 = G(lists940,"map3_n",L[1654]);
var map4_n4417193 = G(lists940,"map4_n",L[1654]);
var each4517192 = G(lists940,"each",L[1654]);
var each24617191 = G(lists940,"each2",L[1654]);
var each34717190 = G(lists940,"each3",L[1654]);
var each44817189 = G(lists940,"each4",L[1654]);
var each_n4917188 = G(lists940,"each_n",L[1654]);
var each2_n5017187 = G(lists940,"each2_n",L[1654]);
var each3_n5117186 = G(lists940,"each3_n",L[1654]);
var each4_n5217185 = G(lists940,"each4_n",L[1654]);
var fold5391 = G(lists940,"fold",L[1654]);
var fold25417184 = G(lists940,"fold2",L[1654]);
var fold35517183 = G(lists940,"fold3",L[1654]);
var fold45617182 = G(lists940,"fold4",L[1654]);
var index5717181 = G(lists940,"index",L[1654]);
var Option5817180 = G(option1141,"Option",L[1654]);
var is_DASH_none5917179 = G(option1141,"is-none",L[1654]);
var is_DASH_some6017178 = G(option1141,"is-some",L[1654]);
var none6117177 = G(option1141,"none",L[1654]);
var some6217176 = G(option1141,"some",L[1654]);
var set6317175 = G(sets1543,"set",L[1654]);
var tree_DASH_set6417174 = G(sets1543,"tree-set",L[1654]);
var list_DASH_set6517173 = G(sets1543,"list-set",L[1654]);
var AProgT26778 = R.namedBrander("AProg");
var AProg6677 = R.makeBranderAnn(AProgT26778,"AProg");
var AImportTypeT36972 = R.namedBrander("AImportType");
var AImportType6871 = R.makeBranderAnn(AImportTypeT36972,"AImportType");
var AImportT47170 = R.namedBrander("AImport");
var AImport7069 = R.makeBranderAnn(AImportT47170,"AImport");
var ATypeBindT57380 = R.namedBrander("ATypeBind");
var ATypeBind7279 = R.makeBranderAnn(ATypeBindT57380,"ATypeBind");
var AExprT67566 = R.namedBrander("AExpr");
var AExpr7465 = R.makeBranderAnn(AExprT67566,"AExpr");
var ABindT77764 = R.namedBrander("ABind");
var ABind7663 = R.makeBranderAnn(ABindT77764,"ABind");
var AVariantT87986 = R.namedBrander("AVariant");
var AVariant7883 = R.makeBranderAnn(AVariantT87986,"AVariant");
var AMemberTypeT98176 = R.namedBrander("AMemberType");
var AMemberType8075 = R.makeBranderAnn(AMemberTypeT98176,"AMemberType");
var AVariantMemberT108385 = R.namedBrander("AVariantMember");
var AVariantMember8284 = R.makeBranderAnn(AVariantMemberT108385,"AVariantMember");
var ALettableT118574 = R.namedBrander("ALettable");
var ALettable8473 = R.makeBranderAnn(ALettableT118574,"ALettable");
var AFieldT128768 = R.namedBrander("AField");
var AField8667 = R.makeBranderAnn(AFieldT128768,"AField");
var AValT138982 = R.namedBrander("AVal");
var AVal8881 = R.makeBranderAnn(AValT138982,"AVal");
var Loc9089 = R.getDotAnn(L[1655],"SL",SL646,"Srcloc");
var INDENT9187 = (2);
var anf_fun117172 = G(PP337,"sbreak",L[1657]);
var $z1716417165 = D;
var $f1717017171 = function(_) {
return R.isFunction(anf_fun117172)?anf_fun117172.app((1)):R.ffi.throwNonFunApp(L[1656],anf_fun117172,[(1)]);
};
try {
if(--R.GAS > 0) {
$z1716417165 = $f1717017171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1717017171,
"from":L[1656]});
}
} catch($e1716217163) {
if(R.isCont($e1716217163)) {
var $ss1716617167 = {"from":L[1656],
"go":function(break_DASH_one9262) {
return $Hbreak_DASH_one398461(break_DASH_one9262,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,fold5391,link2992,list2593,sets1543,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
}};
$e1716217163.stack[R.EXN_STACKHEIGHT++] = $ss1716617167;
}
if(R.isPyretException($e1716217163)) {
$e1716217163.pyretStack.push(L[1656]);
}
throw $e1716217163;
}
var $ret1716817169 = $Hbreak_DASH_one398461($z1716417165,A136,A244,ABind7663,ABindT77764,AExpr7465,AExprT67566,AField8667,AFieldT128768,AImport7069,AImportT47170,AImportType6871,AImportTypeT36972,ALettable8473,ALettableT118574,AMemberType8075,AMemberTypeT98176,AProg6677,AProgT26778,ATypeBind7279,ATypeBindT57380,AVal8881,AValT138982,AVariant7883,AVariantMember8284,AVariantMemberT108385,AVariantT87986,INDENT9187,List1788,Loc9089,PP337,SL538,Set2090,fold5391,link2992,list2593,sets1543,_plus26,_times27,builtins28,nothing29,raise30,torepr31,tostring32,$type$Boolean33,$type$Number34,$type$String35);
++R.GAS;
return $ret1716817169;
},function(moduleVal) {
R.modules["$src/arr/compiler/ast-anf.arr52"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/anf.arr',["trove/ast",
"trove/srcloc",
"compiler/ast-anf.arr",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($A11027,$SL31128,$N51229,$arrays71330,$lists91431,$option111532,$error131633,$sets151734) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/anf.arr26"]) {
return R.modules["$src/arr/compiler/anf.arr26"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/anf.arr";
var D = R.undefined;
var L = [[M,19,0,267,36,3,940],
[M,332,20,11638,332,55,11673],
[M,130,2,3480,333,5,11679],
[M,331,30,11564,331,83,11617],
[M,331,4,11538,331,83,11617],
[M,330,30,11480,330,83,11533],
[M,330,4,11454,330,83,11533],
[M,318,4,11075,328,12,11448],
[M,321,34,11174,328,11,11447],
[M,322,44,11226,327,15,11434],
[M,323,14,11249,325,19,11363],
[M,323,27,11262,325,19,11363],
[M,324,33,11331,324,41,11339],
[M,324,33,11331,324,39,11337],
[M,324,28,11326,324,31,11329],
[M,324,18,11316,324,27,11325],
[M,326,25,11389,326,53,11417],
[M,326,25,11389,326,35,11399],
[M,326,14,11378,326,21,11385],
[M,308,4,10792,316,12,11069],
[M,311,37,10886,316,11,11068],
[M,312,10,10905,314,15,11011],
[M,312,23,10918,314,15,11011],
[M,313,29,10983,313,37,10991],
[M,313,29,10983,313,35,10989],
[M,313,24,10978,313,27,10981],
[M,313,14,10968,313,23,10977],
[M,315,21,11033,315,43,11055],
[M,315,21,11033,315,28,11040],
[M,315,10,11022,315,17,11029],
[M,306,36,10741,306,80,10785],
[M,303,36,10621,303,85,10670],
[M,295,4,10290,300,88,10548],
[M,300,35,10495,300,87,10547],
[M,300,58,10518,300,82,10542],
[M,300,58,10518,300,65,10525],
[M,300,47,10507,300,54,10514],
[M,298,26,10410,298,63,10447],
[M,296,14,10334,299,11,10459],
[M,293,35,10231,293,87,10283],
[M,288,36,10098,290,11,10163],
[M,282,40,9946,284,15,10014],
[M,277,19,9803,277,44,9828],
[M,276,44,9775,278,9,9839],
[M,270,31,9479,270,76,9524],
[M,270,40,9488,270,75,9523],
[M,270,68,9516,270,73,9521],
[M,270,62,9510,270,66,9514],
[M,270,57,9505,270,60,9508],
[M,270,48,9496,270,56,9504],
[M,270,31,9479,270,39,9487],
[M,270,17,9465,270,27,9475],
[M,270,6,9454,270,13,9461],
[M,272,43,9617,272,75,9649],
[M,272,62,9636,272,69,9643],
[M,272,43,9617,272,51,9625],
[M,272,27,9601,272,39,9613],
[M,272,20,9594,272,83,9657],
[M,271,27,9558,271,39,9570],
[M,272,27,9601,272,82,9656],
[M,273,20,9679,273,38,9697],
[M,273,30,9689,273,37,9696],
[M,273,20,9679,273,26,9685],
[M,271,27,9558,273,39,9698],
[M,271,18,9549,273,40,9699],
[M,270,17,9465,273,41,9700],
[M,268,4,9366,273,42,9701],
[M,264,28,9139,264,73,9184],
[M,264,37,9148,264,72,9183],
[M,264,65,9176,264,70,9181],
[M,264,59,9170,264,63,9174],
[M,264,54,9165,264,57,9168],
[M,264,45,9156,264,53,9164],
[M,264,28,9139,264,36,9147],
[M,264,17,9128,264,24,9135],
[M,264,6,9117,264,13,9124],
[M,266,43,9277,266,75,9309],
[M,266,62,9296,266,69,9303],
[M,266,43,9277,266,51,9285],
[M,266,27,9261,266,39,9273],
[M,266,20,9254,266,83,9317],
[M,265,27,9218,265,39,9230],
[M,266,27,9261,266,82,9316],
[M,267,20,9339,267,38,9357],
[M,267,30,9349,267,37,9356],
[M,267,20,9339,267,26,9345],
[M,265,27,9218,267,39,9358],
[M,265,18,9209,267,40,9359],
[M,264,17,9128,267,41,9360],
[M,262,4,9024,267,42,9361],
[M,257,37,8908,257,54,8925],
[M,256,4,8838,257,55,8926],
[M,249,10,8443,249,41,8474],
[M,250,45,8520,250,61,8536],
[M,250,52,8527,250,60,8535],
[M,250,34,8509,250,41,8516],
[M,250,21,8496,250,32,8507],
[M,250,10,8485,250,17,8492],
[M,250,85,8560,250,102,8577],
[M,250,93,8568,250,101,8576],
[M,250,85,8560,250,92,8567],
[M,250,74,8549,250,81,8556],
[M,250,63,8538,250,72,8547],
[M,250,74,8549,250,103,8578],
[M,250,34,8509,250,104,8579],
[M,251,41,8622,251,56,8637],
[M,251,46,8627,251,55,8636],
[M,251,12,8593,254,15,8822],
[M,253,16,8735,253,86,8805],
[M,253,60,8779,253,75,8794],
[M,253,65,8784,253,74,8793],
[M,253,47,8766,253,58,8777],
[M,253,27,8746,253,33,8752],
[M,252,23,8696,252,34,8707],
[M,251,30,8611,251,57,8638],
[M,251,71,8652,251,89,8670],
[M,251,71,8652,251,87,8668],
[M,247,8,8377,254,16,8823],
[M,253,43,8762,253,76,8795],
[M,243,55,8218,243,73,8236],
[M,243,55,8218,243,71,8234],
[M,242,8,8150,246,13,8368],
[M,245,14,8297,245,70,8353],
[M,186,4,5810,238,12,8077],
[M,231,40,7777,238,11,8076],
[M,232,10,7796,234,15,7902],
[M,232,23,7809,234,15,7902],
[M,233,29,7874,233,37,7882],
[M,233,29,7874,233,35,7880],
[M,233,24,7869,233,27,7872],
[M,233,14,7859,233,23,7868],
[M,235,33,7936,237,15,8063],
[M,236,25,7980,236,91,8046],
[M,236,25,7980,236,38,7993],
[M,236,14,7969,236,21,7976],
[M,226,68,7655,226,88,7675],
[M,226,51,7638,226,89,7676],
[M,224,10,7537,224,33,7560],
[M,212,10,6987,219,18,7390],
[M,214,69,7157,219,17,7389],
[M,215,16,7182,217,21,7306],
[M,215,29,7195,217,21,7306],
[M,216,35,7272,216,43,7280],
[M,216,35,7272,216,41,7278],
[M,216,30,7267,216,33,7270],
[M,216,20,7257,216,29,7266],
[M,218,19,7326,218,63,7370],
[M,218,19,7326,218,40,7347],
[M,204,10,6545,211,18,6976],
[M,206,59,6716,211,17,6975],
[M,207,16,6741,209,21,6865],
[M,207,29,6754,209,21,6865],
[M,208,35,6831,208,43,6839],
[M,208,35,6831,208,41,6837],
[M,208,30,6826,208,33,6829],
[M,208,20,6816,208,29,6825],
[M,210,54,6920,210,77,6943],
[M,210,54,6920,210,65,6931],
[M,210,19,6885,210,30,6896],
[M,210,19,6885,210,90,6956],
[M,195,12,6228,198,15,6361],
[M,195,23,6239,198,15,6361],
[M,196,14,6270,197,39,6345],
[M,197,16,6322,197,24,6330],
[M,189,10,5994,199,52,6414],
[M,199,12,6374,199,30,6392],
[M,181,6,5642,183,9,5725],
[M,181,16,5652,183,9,5725],
[M,182,32,5707,182,39,5714],
[M,182,24,5699,182,30,5705],
[M,182,24,5699,182,27,5702],
[M,182,19,5694,182,22,5697],
[M,182,8,5683,182,18,5693],
[M,184,60,5786,184,72,5798],
[M,184,37,5763,184,46,5772],
[M,184,10,5736,184,22,5748],
[M,184,50,5776,184,73,5799],
[M,184,37,5763,184,73,5799],
[M,184,10,5736,184,74,5800],
[M,177,4,5506,184,78,5804],
[M,178,18,5554,180,9,5635],
[M,170,12,5269,173,23,5476],
[M,172,26,5423,172,50,5447],
[M,172,26,5423,172,38,5435],
[M,172,22,5419,172,54,5451],
[M,170,56,5313,173,21,5474],
[M,166,12,5049,169,23,5256],
[M,168,26,5203,168,50,5227],
[M,168,26,5203,168,38,5215],
[M,168,22,5199,168,54,5231],
[M,166,56,5093,169,21,5254],
[M,159,40,4845,159,69,4874],
[M,159,40,4845,159,57,4862],
[M,159,10,4815,159,22,4827],
[M,159,36,4841,159,73,4878],
[M,152,8,4546,159,74,4879],
[M,148,37,4411,148,64,4438],
[M,148,4,4378,148,65,4439],
[M,147,17,4337,147,52,4372],
[M,146,4,4290,147,53,4373],
[M,145,36,4258,145,62,4284],
[M,145,4,4226,145,63,4285],
[M,144,32,4198,144,54,4220],
[M,144,4,4170,144,55,4221],
[M,143,33,4141,143,56,4164],
[M,143,4,4112,143,57,4165],
[M,142,35,4081,142,60,4106],
[M,142,4,4050,142,61,4107],
[M,141,32,4022,141,54,4044],
[M,141,4,3994,141,55,4045],
[M,140,48,3923,140,69,3944],
[M,140,40,3915,140,70,3945],
[M,140,4,3879,141,0,3990],
[M,139,32,3851,139,54,3873],
[M,139,4,3823,139,55,3874],
[M,134,41,3688,136,19,3787],
[M,116,10,3172,116,13,3175],
[M,116,10,3172,116,19,3181],
[M,118,10,3206,122,13,3373],
[M,119,29,3252,121,22,3358],
[M,119,36,3259,121,21,3357],
[M,120,43,3317,120,60,3334],
[M,120,28,3302,120,31,3305],
[M,120,20,3294,120,27,3301],
[M,115,11,3145,115,27,3161],
[M,119,22,3245,119,25,3248],
[M,100,4,2632,105,45,2889],
[M,105,6,2850,105,22,2866],
[M,94,4,2396,99,32,2627],
[M,99,6,2601,99,16,2611],
[M,88,46,2312,88,61,2327],
[M,86,4,2143,88,62,2328],
[M,79,48,2042,79,63,2057],
[M,79,37,2031,79,64,2058],
[M,76,4,1914,76,26,1936],
[M,60,2,1517,60,5,1520],
[M,59,0,1427,68,3,1760],
[M,65,46,1722,65,55,1731],
[M,65,48,1724,65,54,1730],
[M,65,28,1704,65,34,1710],
[M,65,20,1696,65,26,1702],
[M,65,12,1688,65,19,1695],
[M,61,8,1557,66,11,1744],
[M,39,2,982,39,5,985],
[M,38,0,942,49,3,1274],
[M,44,50,1185,44,68,1203],
[M,44,58,1193,44,67,1202],
[M,44,50,1185,44,57,1192],
[M,44,37,1172,44,49,1184],
[M,44,23,1158,44,32,1167],
[M,44,12,1147,44,19,1154],
[M,44,37,1172,44,69,1204],
[M,42,10,1068,44,70,1205],
[M,31,10,765,31,42,797],
[M,33,36,874,33,56,894],
[M,33,46,884,33,55,893],
[M,33,36,874,33,42,880],
[M,33,25,863,33,32,870],
[M,33,12,850,33,24,862],
[M,32,21,819,32,32,830],
[M,32,10,808,32,17,815],
[M,33,58,896,33,77,915],
[M,33,65,903,33,76,914],
[M,33,25,863,33,78,916],
[M,33,12,850,33,79,917],
[M,24,6,479,34,9,928],
[M,27,43,612,27,63,632],
[M,27,53,622,27,62,631],
[M,27,43,612,27,49,618],
[M,27,32,601,27,39,608],
[M,27,21,590,27,30,599],
[M,27,10,579,27,17,586],
[M,27,65,634,27,74,643],
[M,27,32,601,27,75,644],
[M,28,25,671,28,43,689],
[M,28,33,679,28,42,688],
[M,28,25,671,28,32,678],
[M,28,12,658,28,24,670],
[M,28,12,658,28,44,690],
[M,25,8,512,28,45,691],
[M,22,2,396,35,7,936],
[M,20,2,283,21,64,393],
[M,16,17,225,16,21,229],
[M,16,17,225,16,29,237],
[M,16,37,245,16,51,259],
[M,16,37,245,16,43,251],
[M,3,0,13,334,3,11683],
[M,10,11,123,10,20,132],
[M,129,0,3431,334,3,11683],
[M,332,45,11663,332,54,11672],
[M,331,73,11607,331,82,11616],
[M,330,73,11523,330,82,11532],
[M,319,6,11111,319,33,11138],
[M,319,25,11130,319,32,11137],
[M,319,14,11119,319,24,11129],
[M,309,6,10820,309,33,10847],
[M,309,25,10839,309,32,10846],
[M,309,14,10828,309,24,10838],
[M,305,4,10677,306,81,10786],
[M,306,55,10760,306,75,10780],
[M,306,55,10760,306,65,10770],
[M,306,44,10749,306,51,10756],
[M,302,4,10554,303,86,10671],
[M,303,55,10640,303,80,10665],
[M,303,55,10640,303,67,10652],
[M,303,44,10629,303,51,10636],
[M,296,6,10326,299,11,10459],
[M,298,49,10433,298,62,10446],
[M,297,10,10365,297,28,10383],
[M,292,4,10170,293,88,10284],
[M,293,58,10254,293,82,10278],
[M,293,58,10254,293,65,10261],
[M,293,47,10243,293,54,10250],
[M,287,4,10034,290,12,10164],
[M,289,21,10128,289,43,10150],
[M,289,21,10128,289,33,10140],
[M,289,10,10117,289,17,10124],
[M,280,4,9846,285,12,10028],
[M,281,29,9898,285,11,10027],
[M,283,25,9980,283,42,9997],
[M,283,25,9980,283,32,9987],
[M,283,14,9969,283,21,9976],
[M,275,4,9707,278,10,9840],
[M,277,27,9811,277,43,9827],
[M,277,27,9811,277,36,9820],
[M,277,19,9803,277,26,9810],
[M,277,8,9792,277,15,9799],
[M,269,6,9414,269,39,9447],
[M,263,6,9077,263,39,9110],
[M,260,4,8979,260,43,9018],
[M,259,4,8932,259,46,8974],
[M,257,17,8888,257,31,8902],
[M,257,6,8877,257,13,8884],
[M,240,4,8083,255,9,8833],
[M,241,6,8124,255,9,8833],
[M,248,10,8402,248,40,8432],
[M,243,28,8191,243,41,8204],
[M,243,10,8173,246,13,8368],
[M,245,41,8324,245,60,8343],
[M,245,45,8328,245,56,8339],
[M,245,25,8308,245,31,8314],
[M,244,21,8260,244,32,8271],
[M,229,6,7708,229,33,7735],
[M,229,25,7727,229,32,7734],
[M,229,14,7716,229,24,7726],
[M,222,6,7419,228,9,7701],
[M,223,8,7511,227,11,7691],
[M,225,10,7571,226,92,7679],
[M,226,27,7614,226,91,7678],
[M,226,68,7655,226,77,7664],
[M,224,24,7551,224,32,7559],
[M,222,29,7442,222,39,7452],
[M,222,29,7442,222,50,7463],
[M,222,57,7470,222,87,7500],
[M,202,6,6443,221,9,7412],
[M,203,8,6515,220,11,7402],
[M,213,12,7049,213,50,7087],
[M,213,42,7079,213,49,7086],
[M,213,25,7062,213,41,7078],
[M,205,12,6618,205,50,6656],
[M,205,42,6648,205,49,6655],
[M,205,25,6631,205,41,6647],
[M,202,27,6464,202,36,6473],
[M,202,43,6480,202,67,6504],
[M,187,6,5902,201,9,6436],
[M,188,8,5953,200,11,6426],
[M,190,12,6040,194,15,6215],
[M,190,21,6049,194,15,6215],
[M,193,14,6173,193,40,6199],
[M,193,29,6188,193,40,6199],
[M,192,14,6134,192,38,6158],
[M,192,28,6148,192,38,6158],
[M,191,14,6095,191,38,6119],
[M,191,28,6109,191,38,6119],
[M,187,31,5927,187,46,5942],
[M,178,6,5542,180,9,5635],
[M,179,31,5608,179,47,5624],
[M,179,31,5608,179,44,5621],
[M,179,26,5603,179,29,5606],
[M,179,21,5598,179,24,5601],
[M,179,8,5585,179,20,5597],
[M,161,4,4894,175,9,5500],
[M,162,6,4932,175,9,5500],
[M,164,8,4991,174,13,5490],
[M,165,10,5017,174,13,5490],
[M,170,49,5306,173,22,5475],
[M,171,32,5360,171,57,5385],
[M,171,51,5379,171,56,5384],
[M,171,45,5373,171,49,5377],
[M,171,32,5360,171,40,5368],
[M,171,20,5348,171,27,5355],
[M,166,49,5086,169,22,5255],
[M,167,32,5140,167,57,5165],
[M,167,51,5159,167,56,5164],
[M,167,45,5153,167,49,5157],
[M,167,32,5140,167,40,5148],
[M,167,20,5128,167,27,5135],
[M,163,8,4959,163,31,4982],
[M,149,4,4444,160,9,4889],
[M,150,6,4487,160,9,4889],
[M,153,10,4572,158,13,4804],
[M,153,21,4583,158,13,4804],
[M,156,12,4706,157,47,4790],
[M,157,14,4757,157,30,4773],
[M,154,12,4619,155,42,4693],
[M,155,14,4665,155,27,4678],
[M,151,8,4514,151,31,4537],
[M,148,45,4419,148,63,4437],
[M,148,45,4419,148,55,4429],
[M,148,37,4411,148,44,4418],
[M,148,26,4400,148,33,4407],
[M,147,25,4345,147,51,4371],
[M,147,25,4345,147,38,4358],
[M,147,17,4337,147,24,4344],
[M,147,6,4326,147,13,4333],
[M,145,44,4266,145,61,4283],
[M,145,44,4266,145,54,4276],
[M,145,36,4258,145,43,4265],
[M,145,25,4247,145,32,4254],
[M,144,40,4206,144,53,4219],
[M,144,40,4206,144,46,4212],
[M,144,32,4198,144,39,4205],
[M,144,21,4187,144,28,4194],
[M,143,41,4149,143,55,4163],
[M,143,41,4149,143,49,4157],
[M,143,33,4141,143,40,4148],
[M,143,22,4130,143,29,4137],
[M,142,43,4089,142,59,4105],
[M,142,43,4089,142,56,4102],
[M,142,35,4081,142,42,4088],
[M,142,24,4070,142,31,4077],
[M,141,40,4030,141,53,4043],
[M,141,40,4030,141,47,4037],
[M,141,32,4022,141,39,4029],
[M,141,21,4011,141,28,4018],
[M,140,59,3934,140,69,3944],
[M,140,48,3923,140,55,3930],
[M,140,40,3915,140,47,3922],
[M,140,29,3904,140,36,3911],
[M,139,40,3859,139,53,3872],
[M,139,40,3859,139,47,3866],
[M,139,32,3851,139,39,3858],
[M,139,21,3840,139,28,3847],
[M,131,4,3501,138,12,3818],
[M,132,33,3584,138,11,3817],
[M,133,41,3635,137,15,3804],
[M,135,29,3728,135,67,3766],
[M,135,29,3728,135,39,3738],
[M,135,18,3717,135,25,3724],
[M,129,13,3444,129,19,3450],
[M,129,26,3457,129,33,3464],
[M,109,0,2901,127,3,3429],
[M,110,2,2963,125,5,3399],
[M,111,4,2991,124,7,3393],
[M,113,6,3060,123,11,3385],
[M,115,11,3145,115,21,3155],
[M,115,11,3145,115,19,3153],
[M,112,6,3022,112,37,3053],
[M,109,25,2926,109,35,2936],
[M,109,25,2926,109,43,2944],
[M,109,50,2951,109,57,2958],
[M,92,0,2340,107,3,2899],
[M,93,2,2373,106,5,2895],
[M,101,6,2677,104,9,2843],
[M,101,14,2685,104,9,2843],
[M,103,8,2779,103,62,2833],
[M,103,36,2807,103,54,2825],
[M,102,8,2716,102,62,2770],
[M,102,37,2745,102,52,2760],
[M,95,6,2428,98,9,2594],
[M,95,14,2436,98,9,2594],
[M,97,8,2530,97,62,2584],
[M,97,36,2558,97,54,2576],
[M,96,8,2467,96,62,2521],
[M,96,37,2496,96,52,2511],
[M,92,20,2360,92,28,2368],
[M,84,0,2084,90,3,2338],
[M,85,2,2119,89,5,2334],
[M,88,33,2299,88,43,2309],
[M,88,21,2287,88,44,2310],
[M,88,21,2287,88,32,2298],
[M,88,6,2272,88,17,2283],
[M,84,21,2105,84,30,2114],
[M,70,0,1762,82,3,2082],
[M,75,2,1891,81,5,2078],
[M,77,4,1941,80,12,2072],
[M,78,29,1986,80,11,2071],
[M,79,48,2042,79,57,2051],
[M,76,17,1927,76,25,1935],
[M,71,13,1793,71,23,1803],
[M,71,13,1793,71,31,1811],
[M,72,17,1830,72,23,1836],
[M,73,8,1846,73,34,1872],
[M,60,12,1527,67,10,1755],
[M,60,19,1534,67,9,1754],
[M,64,12,1647,64,40,1675],
[M,64,22,1657,64,28,1663],
[M,62,10,1596,62,28,1614],
[M,59,21,1448,59,27,1454],
[M,59,42,1469,59,48,1475],
[M,59,54,1481,59,74,1501],
[M,53,0,1322,57,3,1425],
[M,54,2,1341,56,5,1421],
[M,55,4,1362,55,57,1415],
[M,55,37,1395,55,45,1403],
[M,51,0,1276,51,44,1320],
[M,51,33,1309,51,42,1318],
[M,51,17,1293,51,25,1301],
[M,39,9,989,47,10,1264],
[M,39,16,996,47,9,1263],
[M,40,8,1012,46,11,1253],
[M,45,20,1226,45,32,1238],
[M,43,12,1103,43,43,1134],
[M,38,18,960,38,24,966],
[M,20,4,285,20,41,322],
[M,20,15,296,20,40,321],
[M,22,4,398,22,24,418],
[M,22,17,411,22,23,417],
[M,23,4,429,35,7,936],
[M,30,10,720,30,44,754],
[M,26,10,536,26,42,568],
[M,23,34,459,23,45,470],
[M,23,21,446,23,24,449],
[M,22,9,403,22,23,417],
[M,21,4,333,21,64,393],
[M,21,48,377,21,54,383],
[M,21,34,363,21,45,374],
[M,21,21,350,21,24,353],
[M,20,11,292,20,40,321],
[M,14,0,158,17,3,265],
[M,15,2,182,15,27,207],
[M,15,6,186,15,21,201],
[M,12,8,142,12,22,156]];
var _divide3 = NAMESPACE.get("_divide");
var _plus4 = NAMESPACE.get("_plus");
var builtins5 = NAMESPACE.get("builtins");
var nothing6 = NAMESPACE.get("nothing");
var raise7 = NAMESPACE.get("raise");
var torepr8 = NAMESPACE.get("torepr");
var $type$String9 = NAMESPACE.get("$type$String");
var $Hanf_bracket100235 = function(anf_bracket71936,ANFCont6637,Loc6838,provides71739,nothing6) {
var anf_fun72050 = G(anf_bracket71936,"results",L[0]);
var $z4243 = D;
var $f4849 = function(_) {
return R.isFunction(anf_fun72050)?anf_fun72050.app():R.ffi.throwNonFunApp(L[0],anf_fun72050,[]);
};
try {
if(--R.GAS > 0) {
$z4243 = $f4849();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4849,
"from":L[0]});
}
} catch($e4041) {
if(R.isCont($e4041)) {
var $ss4445 = {"from":L[0],
"go":function(checks72151) {
return $Hchecks100152(checks72151,ANFCont6637,Loc6838,provides71739,nothing6);
}};
$e4041.stack[R.EXN_STACKHEIGHT++] = $ss4445;
}
if(R.isPyretException($e4041)) {
$e4041.pyretStack.push(L[0]);
}
throw $e4041;
}
var $ret4647 = $Hchecks100152($z4243,ANFCont6637,Loc6838,provides71739,nothing6);
++R.GAS;
return $ret4647;
};
var $Hchecks100152 = function(checks72151,ANFCont6637,Loc6838,provides71739,nothing6) {
return R.makeObject({"answer":nothing6,
"provide-plus-types":R.makeObject({"values":provides71739,
"types":{"Loc":Loc6838,
"ANFCont":ANFCont6637}}),
"checks":checks72151});
};
var $Hann_DASH_check_DASH_temp100053 = function(ann_DASH_check_DASH_temp23254,N620) {
return ann_DASH_check_DASH_temp23254;
};
var $Hanf_arg99955 = function(anf_arg71356,_plus4,raise7) {
var $z5960 = D;
var $f6566 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("Missed case in anf: "),anf_arg71356):R.ffi.throwNonFunApp(L[1],_plus4,[("Missed case in anf: "),anf_arg71356]);
};
try {
if(--R.GAS > 0) {
$z5960 = $f6566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6566,
"from":L[1]});
}
} catch($e5758) {
if(R.isCont($e5758)) {
var $ss6162 = {"from":L[1],
"go":function(anf_arg71467) {
return $Hanf_arg99868(anf_arg71467,raise7);
}};
$e5758.stack[R.EXN_STACKHEIGHT++] = $ss6162;
}
if(R.isPyretException($e5758)) {
$e5758.pyretStack.push(L[1]);
}
throw $e5758;
}
var $ret6364 = $Hanf_arg99868($z5960,raise7);
++R.GAS;
return $ret6364;
};
var $Hanf_arg99868 = function(anf_arg71467,raise7) {
var $z7172 = D;
var $f7778 = function(_) {
return R.isFunction(raise7)?raise7.app(anf_arg71467):R.ffi.throwNonFunApp(L[2],raise7,[anf_arg71467]);
};
try {
if(--R.GAS > 0) {
$z7172 = $f7778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7778,
"from":L[2]});
}
} catch($e6970) {
if(R.isCont($e6970)) {
var $ss7374 = {"from":L[2],
"go":function(ann_DASH_check_DASH_temp71279) {
return $Hann_DASH_check_DASH_temp99780(ann_DASH_check_DASH_temp71279);
}};
$e6970.stack[R.EXN_STACKHEIGHT++] = $ss7374;
}
if(R.isPyretException($e6970)) {
$e6970.pyretStack.push(L[2]);
}
throw $e6970;
}
var $ret7576 = $Hann_DASH_check_DASH_temp99780($z7172);
++R.GAS;
return $ret7576;
};
var $Hann_DASH_check_DASH_temp99780 = function(ann_DASH_check_DASH_temp71279) {
return ann_DASH_check_DASH_temp71279;
};
var $Hanf_arg99681 = function(anf_arg70882,_plus4,raise7) {
var $z8586 = D;
var $f9192 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("s-var should be handled by anf-block: "),anf_arg70882):R.ffi.throwNonFunApp(L[3],_plus4,[("s-var should be handled by anf-block: "),anf_arg70882]);
};
try {
if(--R.GAS > 0) {
$z8586 = $f9192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9192,
"from":L[3]});
}
} catch($e8384) {
if(R.isCont($e8384)) {
var $ss8788 = {"from":L[3],
"go":function(anf_arg70993) {
return $Hanf_arg99594(anf_arg70993,raise7);
}};
$e8384.stack[R.EXN_STACKHEIGHT++] = $ss8788;
}
if(R.isPyretException($e8384)) {
$e8384.pyretStack.push(L[3]);
}
throw $e8384;
}
var $ret8990 = $Hanf_arg99594($z8586,raise7);
++R.GAS;
return $ret8990;
};
var $Hanf_arg99594 = function(anf_arg70993,raise7) {
var $z9798 = D;
var $f103104 = function(_) {
return R.isFunction(raise7)?raise7.app(anf_arg70993):R.ffi.throwNonFunApp(L[4],raise7,[anf_arg70993]);
};
try {
if(--R.GAS > 0) {
$z9798 = $f103104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f103104,
"from":L[4]});
}
} catch($e9596) {
if(R.isCont($e9596)) {
var $ss99100 = {"from":L[4],
"go":function(ann_DASH_check_DASH_temp707105) {
return $Hann_DASH_check_DASH_temp994106(ann_DASH_check_DASH_temp707105);
}};
$e9596.stack[R.EXN_STACKHEIGHT++] = $ss99100;
}
if(R.isPyretException($e9596)) {
$e9596.pyretStack.push(L[4]);
}
throw $e9596;
}
var $ret101102 = $Hann_DASH_check_DASH_temp994106($z9798);
++R.GAS;
return $ret101102;
};
var $Hann_DASH_check_DASH_temp994106 = function(ann_DASH_check_DASH_temp707105) {
return ann_DASH_check_DASH_temp707105;
};
var $Hanf_arg993107 = function(anf_arg704108,_plus4,raise7) {
var $z111112 = D;
var $f117118 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("s-let should be handled by anf-block: "),anf_arg704108):R.ffi.throwNonFunApp(L[5],_plus4,[("s-let should be handled by anf-block: "),anf_arg704108]);
};
try {
if(--R.GAS > 0) {
$z111112 = $f117118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f117118,
"from":L[5]});
}
} catch($e109110) {
if(R.isCont($e109110)) {
var $ss113114 = {"from":L[5],
"go":function(anf_arg705119) {
return $Hanf_arg992120(anf_arg705119,raise7);
}};
$e109110.stack[R.EXN_STACKHEIGHT++] = $ss113114;
}
if(R.isPyretException($e109110)) {
$e109110.pyretStack.push(L[5]);
}
throw $e109110;
}
var $ret115116 = $Hanf_arg992120($z111112,raise7);
++R.GAS;
return $ret115116;
};
var $Hanf_arg992120 = function(anf_arg705119,raise7) {
var $z123124 = D;
var $f129130 = function(_) {
return R.isFunction(raise7)?raise7.app(anf_arg705119):R.ffi.throwNonFunApp(L[6],raise7,[anf_arg705119]);
};
try {
if(--R.GAS > 0) {
$z123124 = $f129130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f129130,
"from":L[6]});
}
} catch($e121122) {
if(R.isCont($e121122)) {
var $ss125126 = {"from":L[6],
"go":function(ann_DASH_check_DASH_temp703131) {
return $Hann_DASH_check_DASH_temp991132(ann_DASH_check_DASH_temp703131);
}};
$e121122.stack[R.EXN_STACKHEIGHT++] = $ss125126;
}
if(R.isPyretException($e121122)) {
$e121122.pyretStack.push(L[6]);
}
throw $e121122;
}
var $ret127128 = $Hann_DASH_check_DASH_temp991132($z123124);
++R.GAS;
return $ret127128;
};
var $Hann_DASH_check_DASH_temp991132 = function(ann_DASH_check_DASH_temp703131) {
return ann_DASH_check_DASH_temp703131;
};
var $Hexprs990133 = function(exprs352134,N512,anf_DASH_name_DASH_rec82135,anf_DASH_name81136,fields351137,k160138,l349139,map238140,obj350141) {
var anf_arg701152 = R.makeFunction(function(o353155) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
var anf_arg700166 = R.makeFunction(function(ts354169) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[9],1,arguments);
}
var anf_arg696180 = R.makeFunction(function(f356183,t357184) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[11],2,arguments);
}
var anf_fun692195 = G(N512,"a-field",L[15]);
var anf_arg693196 = G(f356183,"l",L[14]);
var anf_bracket694200 = G(f356183,"name",L[13]);
var anf_arg695197 = G(anf_bracket694200,"s",L[12]);
var $z187188 = D;
var $f193194 = function(_) {
return R.isFunction(anf_fun692195)?anf_fun692195.app(anf_arg693196,anf_arg695197,t357184):R.ffi.throwNonFunApp(L[11],anf_fun692195,[anf_arg693196,anf_arg695197,t357184]);
};
try {
if(--R.GAS > 0) {
$z187188 = $f193194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f193194,
"from":L[11]});
}
} catch($e185186) {
if(R.isCont($e185186)) {
var $ss189190 = {"from":L[11],
"go":function(ann_DASH_check_DASH_temp691198) {
return $Hann_DASH_check_DASH_temp984199(ann_DASH_check_DASH_temp691198);
}};
$e185186.stack[R.EXN_STACKHEIGHT++] = $ss189190;
}
if(R.isPyretException($e185186)) {
$e185186.pyretStack.push(L[11]);
}
throw $e185186;
}
var $ret191192 = $Hann_DASH_check_DASH_temp984199($z187188);
++R.GAS;
return $ret191192;
});
var $z172173 = D;
var $f178179 = function(_) {
return R.isFunction(map238140)?map238140.app(anf_arg696180,fields351137,ts354169):R.ffi.throwNonFunApp(L[10],map238140,[anf_arg696180,fields351137,ts354169]);
};
try {
if(--R.GAS > 0) {
$z172173 = $f178179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f178179,
"from":L[10]});
}
} catch($e170171) {
if(R.isCont($e170171)) {
var $ss174175 = {"from":L[10],
"go":function(new_DASH_fields355181) {
return $Hnew_DASH_fields987182(new_DASH_fields355181,N512,k160138,l349139,o353155);
}};
$e170171.stack[R.EXN_STACKHEIGHT++] = $ss174175;
}
if(R.isPyretException($e170171)) {
$e170171.pyretStack.push(L[10]);
}
throw $e170171;
}
var $ret176177 = $Hnew_DASH_fields987182($z172173,N512,k160138,l349139,o353155);
++R.GAS;
return $ret176177;
});
var $z158159 = D;
var $f164165 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(exprs352134,("anf_extend"),anf_arg700166):R.ffi.throwNonFunApp(L[8],anf_DASH_name_DASH_rec82135.$var,[exprs352134,("anf_extend"),anf_arg700166]);
};
try {
if(--R.GAS > 0) {
$z158159 = $f164165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f164165,
"from":L[8]});
}
} catch($e156157) {
if(R.isCont($e156157)) {
var $ss160161 = {"from":L[8],
"go":function(ann_DASH_check_DASH_temp689167) {
return $Hann_DASH_check_DASH_temp988168(ann_DASH_check_DASH_temp689167);
}};
$e156157.stack[R.EXN_STACKHEIGHT++] = $ss160161;
}
if(R.isPyretException($e156157)) {
$e156157.pyretStack.push(L[8]);
}
throw $e156157;
}
var $ret162163 = $Hann_DASH_check_DASH_temp988168($z158159);
++R.GAS;
return $ret162163;
});
var $z144145 = D;
var $f150151 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(obj350141,("anf_extend"),anf_arg701152):R.ffi.throwNonFunApp(L[7],anf_DASH_name81136.$var,[obj350141,("anf_extend"),anf_arg701152]);
};
try {
if(--R.GAS > 0) {
$z144145 = $f150151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f150151,
"from":L[7]});
}
} catch($e142143) {
if(R.isCont($e142143)) {
var $ss146147 = {"from":L[7],
"go":function(ann_DASH_check_DASH_temp685153) {
return $Hann_DASH_check_DASH_temp989154(ann_DASH_check_DASH_temp685153);
}};
$e142143.stack[R.EXN_STACKHEIGHT++] = $ss146147;
}
if(R.isPyretException($e142143)) {
$e142143.pyretStack.push(L[7]);
}
throw $e142143;
}
var $ret148149 = $Hann_DASH_check_DASH_temp989154($z144145);
++R.GAS;
return $ret148149;
};
var $Hann_DASH_check_DASH_temp989154 = function(ann_DASH_check_DASH_temp685153) {
return ann_DASH_check_DASH_temp685153;
};
var $Hann_DASH_check_DASH_temp988168 = function(ann_DASH_check_DASH_temp689167) {
return ann_DASH_check_DASH_temp689167;
};
var $Hnew_DASH_fields987182 = function(new_DASH_fields355181,N512,k160138,l349139,o353155) {
var anf_fun697213 = G(k160138,"apply",L[18]);
var anf_fun698211 = G(N512,"a-extend",L[17]);
var $z203204 = D;
var $f209210 = function(_) {
return R.isFunction(anf_fun698211)?anf_fun698211.app(l349139,o353155,new_DASH_fields355181):R.ffi.throwNonFunApp(L[16],anf_fun698211,[l349139,o353155,new_DASH_fields355181]);
};
try {
if(--R.GAS > 0) {
$z203204 = $f209210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f209210,
"from":L[16]});
}
} catch($e201202) {
if(R.isCont($e201202)) {
var $ss205206 = {"from":L[16],
"go":function(anf_arg699212) {
return $Hanf_arg986214(anf_arg699212,anf_fun697213,l349139);
}};
$e201202.stack[R.EXN_STACKHEIGHT++] = $ss205206;
}
if(R.isPyretException($e201202)) {
$e201202.pyretStack.push(L[16]);
}
throw $e201202;
}
var $ret207208 = $Hanf_arg986214($z203204,anf_fun697213,l349139);
++R.GAS;
return $ret207208;
};
var $Hanf_arg986214 = function(anf_arg699212,anf_fun697213,l349139) {
var $z217218 = D;
var $f223224 = function(_) {
return R.isFunction(anf_fun697213)?anf_fun697213.app(l349139,anf_arg699212):R.ffi.throwNonFunApp(L[9],anf_fun697213,[l349139,anf_arg699212]);
};
try {
if(--R.GAS > 0) {
$z217218 = $f223224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f223224,
"from":L[9]});
}
} catch($e215216) {
if(R.isCont($e215216)) {
var $ss219220 = {"from":L[9],
"go":function(ann_DASH_check_DASH_temp690225) {
return $Hann_DASH_check_DASH_temp985226(ann_DASH_check_DASH_temp690225);
}};
$e215216.stack[R.EXN_STACKHEIGHT++] = $ss219220;
}
if(R.isPyretException($e215216)) {
$e215216.pyretStack.push(L[9]);
}
throw $e215216;
}
var $ret221222 = $Hann_DASH_check_DASH_temp985226($z217218);
++R.GAS;
return $ret221222;
};
var $Hann_DASH_check_DASH_temp985226 = function(ann_DASH_check_DASH_temp690225) {
return ann_DASH_check_DASH_temp690225;
};
var $Hann_DASH_check_DASH_temp984199 = function(ann_DASH_check_DASH_temp691198) {
return ann_DASH_check_DASH_temp691198;
};
var $Hexprs983227 = function(exprs344228,N512,anf_DASH_name_DASH_rec82135,fields343229,k160138,l342230,map238140) {
var anf_arg683241 = R.makeFunction(function(ts345244) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[20],1,arguments);
}
var anf_arg679255 = R.makeFunction(function(f347258,t348259) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[22],2,arguments);
}
var anf_fun675270 = G(N512,"a-field",L[26]);
var anf_arg676271 = G(f347258,"l",L[25]);
var anf_bracket677275 = G(f347258,"name",L[24]);
var anf_arg678272 = G(anf_bracket677275,"s",L[23]);
var $z262263 = D;
var $f268269 = function(_) {
return R.isFunction(anf_fun675270)?anf_fun675270.app(anf_arg676271,anf_arg678272,t348259):R.ffi.throwNonFunApp(L[22],anf_fun675270,[anf_arg676271,anf_arg678272,t348259]);
};
try {
if(--R.GAS > 0) {
$z262263 = $f268269();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f268269,
"from":L[22]});
}
} catch($e260261) {
if(R.isCont($e260261)) {
var $ss264265 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp674273) {
return $Hann_DASH_check_DASH_temp978274(ann_DASH_check_DASH_temp674273);
}};
$e260261.stack[R.EXN_STACKHEIGHT++] = $ss264265;
}
if(R.isPyretException($e260261)) {
$e260261.pyretStack.push(L[22]);
}
throw $e260261;
}
var $ret266267 = $Hann_DASH_check_DASH_temp978274($z262263);
++R.GAS;
return $ret266267;
});
var $z247248 = D;
var $f253254 = function(_) {
return R.isFunction(map238140)?map238140.app(anf_arg679255,fields343229,ts345244):R.ffi.throwNonFunApp(L[21],map238140,[anf_arg679255,fields343229,ts345244]);
};
try {
if(--R.GAS > 0) {
$z247248 = $f253254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f253254,
"from":L[21]});
}
} catch($e245246) {
if(R.isCont($e245246)) {
var $ss249250 = {"from":L[21],
"go":function(new_DASH_fields346256) {
return $Hnew_DASH_fields981257(new_DASH_fields346256,N512,k160138,l342230);
}};
$e245246.stack[R.EXN_STACKHEIGHT++] = $ss249250;
}
if(R.isPyretException($e245246)) {
$e245246.pyretStack.push(L[21]);
}
throw $e245246;
}
var $ret251252 = $Hnew_DASH_fields981257($z247248,N512,k160138,l342230);
++R.GAS;
return $ret251252;
});
var $z233234 = D;
var $f239240 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(exprs344228,("anf_obj"),anf_arg683241):R.ffi.throwNonFunApp(L[19],anf_DASH_name_DASH_rec82135.$var,[exprs344228,("anf_obj"),anf_arg683241]);
};
try {
if(--R.GAS > 0) {
$z233234 = $f239240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f239240,
"from":L[19]});
}
} catch($e231232) {
if(R.isCont($e231232)) {
var $ss235236 = {"from":L[19],
"go":function(ann_DASH_check_DASH_temp669242) {
return $Hann_DASH_check_DASH_temp982243(ann_DASH_check_DASH_temp669242);
}};
$e231232.stack[R.EXN_STACKHEIGHT++] = $ss235236;
}
if(R.isPyretException($e231232)) {
$e231232.pyretStack.push(L[19]);
}
throw $e231232;
}
var $ret237238 = $Hann_DASH_check_DASH_temp982243($z233234);
++R.GAS;
return $ret237238;
};
var $Hann_DASH_check_DASH_temp982243 = function(ann_DASH_check_DASH_temp669242) {
return ann_DASH_check_DASH_temp669242;
};
var $Hnew_DASH_fields981257 = function(new_DASH_fields346256,N512,k160138,l342230) {
var anf_fun680288 = G(k160138,"apply",L[29]);
var anf_fun681286 = G(N512,"a-obj",L[28]);
var $z278279 = D;
var $f284285 = function(_) {
return R.isFunction(anf_fun681286)?anf_fun681286.app(l342230,new_DASH_fields346256):R.ffi.throwNonFunApp(L[27],anf_fun681286,[l342230,new_DASH_fields346256]);
};
try {
if(--R.GAS > 0) {
$z278279 = $f284285();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f284285,
"from":L[27]});
}
} catch($e276277) {
if(R.isCont($e276277)) {
var $ss280281 = {"from":L[27],
"go":function(anf_arg682287) {
return $Hanf_arg980289(anf_arg682287,anf_fun680288,l342230);
}};
$e276277.stack[R.EXN_STACKHEIGHT++] = $ss280281;
}
if(R.isPyretException($e276277)) {
$e276277.pyretStack.push(L[27]);
}
throw $e276277;
}
var $ret282283 = $Hanf_arg980289($z278279,anf_fun680288,l342230);
++R.GAS;
return $ret282283;
};
var $Hanf_arg980289 = function(anf_arg682287,anf_fun680288,l342230) {
var $z292293 = D;
var $f298299 = function(_) {
return R.isFunction(anf_fun680288)?anf_fun680288.app(l342230,anf_arg682287):R.ffi.throwNonFunApp(L[20],anf_fun680288,[l342230,anf_arg682287]);
};
try {
if(--R.GAS > 0) {
$z292293 = $f298299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f298299,
"from":L[20]});
}
} catch($e290291) {
if(R.isCont($e290291)) {
var $ss294295 = {"from":L[20],
"go":function(ann_DASH_check_DASH_temp673300) {
return $Hann_DASH_check_DASH_temp979301(ann_DASH_check_DASH_temp673300);
}};
$e290291.stack[R.EXN_STACKHEIGHT++] = $ss294295;
}
if(R.isPyretException($e290291)) {
$e290291.pyretStack.push(L[20]);
}
throw $e290291;
}
var $ret296297 = $Hann_DASH_check_DASH_temp979301($z292293);
++R.GAS;
return $ret296297;
};
var $Hann_DASH_check_DASH_temp979301 = function(ann_DASH_check_DASH_temp673300) {
return ann_DASH_check_DASH_temp673300;
};
var $Hann_DASH_check_DASH_temp978274 = function(ann_DASH_check_DASH_temp674273) {
return ann_DASH_check_DASH_temp674273;
};
var $Hann_DASH_check_DASH_temp977302 = function(ann_DASH_check_DASH_temp662303) {
return ann_DASH_check_DASH_temp662303;
};
var $Hanf_arg976304 = function(anf_arg666305,anf_fun664306,l338307) {
var $z310311 = D;
var $f316317 = function(_) {
return R.isFunction(anf_fun664306)?anf_fun664306.app(l338307,anf_arg666305):R.ffi.throwNonFunApp(L[30],anf_fun664306,[l338307,anf_arg666305]);
};
try {
if(--R.GAS > 0) {
$z310311 = $f316317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f316317,
"from":L[30]});
}
} catch($e308309) {
if(R.isCont($e308309)) {
var $ss312313 = {"from":L[30],
"go":function(ann_DASH_check_DASH_temp663318) {
return $Hann_DASH_check_DASH_temp975319(ann_DASH_check_DASH_temp663318);
}};
$e308309.stack[R.EXN_STACKHEIGHT++] = $ss312313;
}
if(R.isPyretException($e308309)) {
$e308309.pyretStack.push(L[30]);
}
throw $e308309;
}
var $ret314315 = $Hann_DASH_check_DASH_temp975319($z310311);
++R.GAS;
return $ret314315;
};
var $Hann_DASH_check_DASH_temp975319 = function(ann_DASH_check_DASH_temp663318) {
return ann_DASH_check_DASH_temp663318;
};
var $Hann_DASH_check_DASH_temp974320 = function(ann_DASH_check_DASH_temp655321) {
return ann_DASH_check_DASH_temp655321;
};
var $Hanf_arg973322 = function(anf_arg659323,anf_fun657324,l334325) {
var $z328329 = D;
var $f334335 = function(_) {
return R.isFunction(anf_fun657324)?anf_fun657324.app(l334325,anf_arg659323):R.ffi.throwNonFunApp(L[31],anf_fun657324,[l334325,anf_arg659323]);
};
try {
if(--R.GAS > 0) {
$z328329 = $f334335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f334335,
"from":L[31]});
}
} catch($e326327) {
if(R.isCont($e326327)) {
var $ss330331 = {"from":L[31],
"go":function(ann_DASH_check_DASH_temp656336) {
return $Hann_DASH_check_DASH_temp972337(ann_DASH_check_DASH_temp656336);
}};
$e326327.stack[R.EXN_STACKHEIGHT++] = $ss330331;
}
if(R.isPyretException($e326327)) {
$e326327.pyretStack.push(L[31]);
}
throw $e326327;
}
var $ret332333 = $Hann_DASH_check_DASH_temp972337($z328329);
++R.GAS;
return $ret332333;
};
var $Hann_DASH_check_DASH_temp972337 = function(ann_DASH_check_DASH_temp656336) {
return ann_DASH_check_DASH_temp656336;
};
var $Hfname971338 = function(fname330339,N512,anf_DASH_name81136,k160138,l327340,obj328341) {
var anf_arg653352 = R.makeFunction(function(t_DASH_obj333355) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[33],1,arguments);
}
var anf_fun650368 = G(k160138,"apply",L[36]);
var anf_fun651366 = G(N512,"a-dot",L[35]);
var $z358359 = D;
var $f364365 = function(_) {
return R.isFunction(anf_fun651366)?anf_fun651366.app(l327340,t_DASH_obj333355,fname330339):R.ffi.throwNonFunApp(L[34],anf_fun651366,[l327340,t_DASH_obj333355,fname330339]);
};
try {
if(--R.GAS > 0) {
$z358359 = $f364365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f364365,
"from":L[34]});
}
} catch($e356357) {
if(R.isCont($e356357)) {
var $ss360361 = {"from":L[34],
"go":function(anf_arg652367) {
return $Hanf_arg969369(anf_arg652367,anf_fun650368,l327340);
}};
$e356357.stack[R.EXN_STACKHEIGHT++] = $ss360361;
}
if(R.isPyretException($e356357)) {
$e356357.pyretStack.push(L[34]);
}
throw $e356357;
}
var $ret362363 = $Hanf_arg969369($z358359,anf_fun650368,l327340);
++R.GAS;
return $ret362363;
});
var $z344345 = D;
var $f350351 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(obj328341,("anf_bracket"),anf_arg653352):R.ffi.throwNonFunApp(L[32],anf_DASH_name81136.$var,[obj328341,("anf_bracket"),anf_arg653352]);
};
try {
if(--R.GAS > 0) {
$z344345 = $f350351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f350351,
"from":L[32]});
}
} catch($e342343) {
if(R.isCont($e342343)) {
var $ss346347 = {"from":L[32],
"go":function(ann_DASH_check_DASH_temp640353) {
return $Hann_DASH_check_DASH_temp970354(ann_DASH_check_DASH_temp640353);
}};
$e342343.stack[R.EXN_STACKHEIGHT++] = $ss346347;
}
if(R.isPyretException($e342343)) {
$e342343.pyretStack.push(L[32]);
}
throw $e342343;
}
var $ret348349 = $Hann_DASH_check_DASH_temp970354($z344345);
++R.GAS;
return $ret348349;
};
var $Hann_DASH_check_DASH_temp970354 = function(ann_DASH_check_DASH_temp640353) {
return ann_DASH_check_DASH_temp640353;
};
var $Hanf_arg969369 = function(anf_arg652367,anf_fun650368,l327340) {
var $z372373 = D;
var $f378379 = function(_) {
return R.isFunction(anf_fun650368)?anf_fun650368.app(l327340,anf_arg652367):R.ffi.throwNonFunApp(L[33],anf_fun650368,[l327340,anf_arg652367]);
};
try {
if(--R.GAS > 0) {
$z372373 = $f378379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f378379,
"from":L[33]});
}
} catch($e370371) {
if(R.isCont($e370371)) {
var $ss374375 = {"from":L[33],
"go":function(ann_DASH_check_DASH_temp649380) {
return $Hann_DASH_check_DASH_temp968381(ann_DASH_check_DASH_temp649380);
}};
$e370371.stack[R.EXN_STACKHEIGHT++] = $ss374375;
}
if(R.isPyretException($e370371)) {
$e370371.pyretStack.push(L[33]);
}
throw $e370371;
}
var $ret376377 = $Hann_DASH_check_DASH_temp968381($z372373);
++R.GAS;
return $ret376377;
};
var $Hann_DASH_check_DASH_temp968381 = function(ann_DASH_check_DASH_temp649380) {
return ann_DASH_check_DASH_temp649380;
};
var $Hanf_arg967382 = function(anf_arg646383,_plus4,raise7) {
var $z386387 = D;
var $f392393 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("Non-string field: "),anf_arg646383):R.ffi.throwNonFunApp(L[37],_plus4,[("Non-string field: "),anf_arg646383]);
};
try {
if(--R.GAS > 0) {
$z386387 = $f392393();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f392393,
"from":L[37]});
}
} catch($e384385) {
if(R.isCont($e384385)) {
var $ss388389 = {"from":L[37],
"go":function(anf_arg647394) {
return $Hanf_arg966395(anf_arg647394,raise7);
}};
$e384385.stack[R.EXN_STACKHEIGHT++] = $ss388389;
}
if(R.isPyretException($e384385)) {
$e384385.pyretStack.push(L[37]);
}
throw $e384385;
}
var $ret390391 = $Hanf_arg966395($z386387,raise7);
++R.GAS;
return $ret390391;
};
var $Hanf_arg966395 = function(anf_arg647394,raise7) {
var $z398399 = D;
var $f404405 = function(_) {
return R.isFunction(raise7)?raise7.app(anf_arg647394):R.ffi.throwNonFunApp(L[38],raise7,[anf_arg647394]);
};
try {
if(--R.GAS > 0) {
$z398399 = $f404405();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f404405,
"from":L[38]});
}
} catch($e396397) {
if(R.isCont($e396397)) {
var $ss400401 = {"from":L[38],
"go":function(ann_DASH_check_DASH_temp645406) {
return $Hann_DASH_check_DASH_temp965407(ann_DASH_check_DASH_temp645406);
}};
$e396397.stack[R.EXN_STACKHEIGHT++] = $ss400401;
}
if(R.isPyretException($e396397)) {
$e396397.pyretStack.push(L[38]);
}
throw $e396397;
}
var $ret402403 = $Hann_DASH_check_DASH_temp965407($z398399);
++R.GAS;
return $ret402403;
};
var $Hann_DASH_check_DASH_temp965407 = function(ann_DASH_check_DASH_temp645406) {
return ann_DASH_check_DASH_temp645406;
};
var $Hann_DASH_check_DASH_temp964408 = function(ann_DASH_check_DASH_temp633409) {
return ann_DASH_check_DASH_temp633409;
};
var $Hanf_arg963410 = function(anf_arg637411,anf_fun635412,l323413) {
var $z416417 = D;
var $f422423 = function(_) {
return R.isFunction(anf_fun635412)?anf_fun635412.app(l323413,anf_arg637411):R.ffi.throwNonFunApp(L[39],anf_fun635412,[l323413,anf_arg637411]);
};
try {
if(--R.GAS > 0) {
$z416417 = $f422423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f422423,
"from":L[39]});
}
} catch($e414415) {
if(R.isCont($e414415)) {
var $ss418419 = {"from":L[39],
"go":function(ann_DASH_check_DASH_temp634424) {
return $Hann_DASH_check_DASH_temp962425(ann_DASH_check_DASH_temp634424);
}};
$e414415.stack[R.EXN_STACKHEIGHT++] = $ss418419;
}
if(R.isPyretException($e414415)) {
$e414415.pyretStack.push(L[39]);
}
throw $e414415;
}
var $ret420421 = $Hann_DASH_check_DASH_temp962425($z416417);
++R.GAS;
return $ret420421;
};
var $Hann_DASH_check_DASH_temp962425 = function(ann_DASH_check_DASH_temp634424) {
return ann_DASH_check_DASH_temp634424;
};
var $Hann_DASH_check_DASH_temp961426 = function(ann_DASH_check_DASH_temp626427) {
return ann_DASH_check_DASH_temp626427;
};
var $Hanf_arg960428 = function(anf_arg630429,anf_fun628430,l319431) {
var $z434435 = D;
var $f440441 = function(_) {
return R.isFunction(anf_fun628430)?anf_fun628430.app(l319431,anf_arg630429):R.ffi.throwNonFunApp(L[40],anf_fun628430,[l319431,anf_arg630429]);
};
try {
if(--R.GAS > 0) {
$z434435 = $f440441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f440441,
"from":L[40]});
}
} catch($e432433) {
if(R.isCont($e432433)) {
var $ss436437 = {"from":L[40],
"go":function(ann_DASH_check_DASH_temp627442) {
return $Hann_DASH_check_DASH_temp959443(ann_DASH_check_DASH_temp627442);
}};
$e432433.stack[R.EXN_STACKHEIGHT++] = $ss436437;
}
if(R.isPyretException($e432433)) {
$e432433.pyretStack.push(L[40]);
}
throw $e432433;
}
var $ret438439 = $Hann_DASH_check_DASH_temp959443($z434435);
++R.GAS;
return $ret438439;
};
var $Hann_DASH_check_DASH_temp959443 = function(ann_DASH_check_DASH_temp627442) {
return ann_DASH_check_DASH_temp627442;
};
var $Hann_DASH_check_DASH_temp958444 = function(ann_DASH_check_DASH_temp617445) {
return ann_DASH_check_DASH_temp617445;
};
var $Hann_DASH_check_DASH_temp957446 = function(ann_DASH_check_DASH_temp618447) {
return ann_DASH_check_DASH_temp618447;
};
var $Hanf_arg956448 = function(anf_arg622449,anf_fun620450,l314451) {
var $z454455 = D;
var $f460461 = function(_) {
return R.isFunction(anf_fun620450)?anf_fun620450.app(l314451,anf_arg622449):R.ffi.throwNonFunApp(L[41],anf_fun620450,[l314451,anf_arg622449]);
};
try {
if(--R.GAS > 0) {
$z454455 = $f460461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f460461,
"from":L[41]});
}
} catch($e452453) {
if(R.isCont($e452453)) {
var $ss456457 = {"from":L[41],
"go":function(ann_DASH_check_DASH_temp619462) {
return $Hann_DASH_check_DASH_temp955463(ann_DASH_check_DASH_temp619462);
}};
$e452453.stack[R.EXN_STACKHEIGHT++] = $ss456457;
}
if(R.isPyretException($e452453)) {
$e452453.pyretStack.push(L[41]);
}
throw $e452453;
}
var $ret458459 = $Hann_DASH_check_DASH_temp955463($z454455);
++R.GAS;
return $ret458459;
};
var $Hann_DASH_check_DASH_temp955463 = function(ann_DASH_check_DASH_temp619462) {
return ann_DASH_check_DASH_temp619462;
};
var $Hann_DASH_check_DASH_temp954464 = function(ann_DASH_check_DASH_temp608465) {
return ann_DASH_check_DASH_temp608465;
};
var $Hanf_arg953466 = function(anf_arg613467,anf_fun610468,anf_fun611469,l311470) {
var $z473474 = D;
var $f479480 = function(_) {
return R.isFunction(anf_fun611469)?anf_fun611469.app(anf_arg613467):R.ffi.throwNonFunApp(L[42],anf_fun611469,[anf_arg613467]);
};
try {
if(--R.GAS > 0) {
$z473474 = $f479480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f479480,
"from":L[42]});
}
} catch($e471472) {
if(R.isCont($e471472)) {
var $ss475476 = {"from":L[42],
"go":function(anf_arg614481) {
return $Hanf_arg952482(anf_arg614481,anf_fun610468,l311470);
}};
$e471472.stack[R.EXN_STACKHEIGHT++] = $ss475476;
}
if(R.isPyretException($e471472)) {
$e471472.pyretStack.push(L[42]);
}
throw $e471472;
}
var $ret477478 = $Hanf_arg952482($z473474,anf_fun610468,l311470);
++R.GAS;
return $ret477478;
};
var $Hanf_arg952482 = function(anf_arg614481,anf_fun610468,l311470) {
var $z485486 = D;
var $f491492 = function(_) {
return R.isFunction(anf_fun610468)?anf_fun610468.app(l311470,anf_arg614481):R.ffi.throwNonFunApp(L[43],anf_fun610468,[l311470,anf_arg614481]);
};
try {
if(--R.GAS > 0) {
$z485486 = $f491492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f491492,
"from":L[43]});
}
} catch($e483484) {
if(R.isCont($e483484)) {
var $ss487488 = {"from":L[43],
"go":function(ann_DASH_check_DASH_temp609493) {
return $Hann_DASH_check_DASH_temp951494(ann_DASH_check_DASH_temp609493);
}};
$e483484.stack[R.EXN_STACKHEIGHT++] = $ss487488;
}
if(R.isPyretException($e483484)) {
$e483484.pyretStack.push(L[43]);
}
throw $e483484;
}
var $ret489490 = $Hann_DASH_check_DASH_temp951494($z485486);
++R.GAS;
return $ret489490;
};
var $Hann_DASH_check_DASH_temp951494 = function(ann_DASH_check_DASH_temp609493) {
return ann_DASH_check_DASH_temp609493;
};
var $Hname950495 = function(name309496,A110,N512,anf_DASH_term78497,args304498,body307499,k160138,l303500,list25501,ret305502) {
var anf_fun583516 = G(k160138,"apply",L[52]);
var anf_fun584517 = G(N512,"a-method",L[51]);
var anf_fun585513 = G(args304498,"map",L[50]);
var anf_arg591514 = R.makeFunction(function(a310519) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[45],1,arguments);
}
var anf_fun587530 = G(N512,"a-bind",L[49]);
var anf_arg588531 = G(a310519,"l",L[48]);
var anf_arg589532 = G(a310519,"id",L[47]);
var anf_arg590533 = G(a310519,"ann",L[46]);
var $z522523 = D;
var $f528529 = function(_) {
return R.isFunction(anf_fun587530)?anf_fun587530.app(anf_arg588531,anf_arg589532,anf_arg590533):R.ffi.throwNonFunApp(L[45],anf_fun587530,[anf_arg588531,anf_arg589532,anf_arg590533]);
};
try {
if(--R.GAS > 0) {
$z522523 = $f528529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f528529,
"from":L[45]});
}
} catch($e520521) {
if(R.isCont($e520521)) {
var $ss524525 = {"from":L[45],
"go":function(ann_DASH_check_DASH_temp586534) {
return $Hann_DASH_check_DASH_temp940535(ann_DASH_check_DASH_temp586534);
}};
$e520521.stack[R.EXN_STACKHEIGHT++] = $ss524525;
}
if(R.isPyretException($e520521)) {
$e520521.pyretStack.push(L[45]);
}
throw $e520521;
}
var $ret526527 = $Hann_DASH_check_DASH_temp940535($z522523);
++R.GAS;
return $ret526527;
});
var $z505506 = D;
var $f511512 = function(_) {
return R.isFunction(anf_fun585513)?anf_fun585513.app(anf_arg591514):R.ffi.throwNonFunApp(L[44],anf_fun585513,[anf_arg591514]);
};
try {
if(--R.GAS > 0) {
$z505506 = $f511512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f511512,
"from":L[44]});
}
} catch($e503504) {
if(R.isCont($e503504)) {
var $ss507508 = {"from":L[44],
"go":function(anf_arg592515) {
return $Hanf_arg949518(anf_arg592515,A110,anf_DASH_term78497,anf_fun583516,anf_fun584517,body307499,l303500,list25501,name309496,ret305502);
}};
$e503504.stack[R.EXN_STACKHEIGHT++] = $ss507508;
}
if(R.isPyretException($e503504)) {
$e503504.pyretStack.push(L[44]);
}
throw $e503504;
}
var $ret509510 = $Hanf_arg949518($z505506,A110,anf_DASH_term78497,anf_fun583516,anf_fun584517,body307499,l303500,list25501,name309496,ret305502);
++R.GAS;
return $ret509510;
};
var $Hanf_arg949518 = function(anf_arg592515,A110,anf_DASH_term78497,anf_fun583516,anf_fun584517,body307499,l303500,list25501,name309496,ret305502) {
var anf_fun593549 = G(A110,"s-let-expr",L[58]);
var anf_fun594550 = G(list25501,"make",L[57]);
var anf_fun595551 = G(A110,"s-let-bind",L[56]);
var anf_fun596546 = G(A110,"s-bind",L[55]);
var anf_arg597547 = G(name309496,"id",L[54]);
var $z538539 = D;
var $f544545 = function(_) {
return R.isFunction(anf_fun596546)?anf_fun596546.app(l303500,(false),anf_arg597547,ret305502):R.ffi.throwNonFunApp(L[53],anf_fun596546,[l303500,(false),anf_arg597547,ret305502]);
};
try {
if(--R.GAS > 0) {
$z538539 = $f544545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f544545,
"from":L[53]});
}
} catch($e536537) {
if(R.isCont($e536537)) {
var $ss540541 = {"from":L[53],
"go":function(anf_arg598548) {
return $Hanf_arg948552(anf_arg598548,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,anf_fun594550,anf_fun595551,body307499,l303500,name309496,ret305502);
}};
$e536537.stack[R.EXN_STACKHEIGHT++] = $ss540541;
}
if(R.isPyretException($e536537)) {
$e536537.pyretStack.push(L[53]);
}
throw $e536537;
}
var $ret542543 = $Hanf_arg948552($z538539,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,anf_fun594550,anf_fun595551,body307499,l303500,name309496,ret305502);
++R.GAS;
return $ret542543;
};
var $Hanf_arg948552 = function(anf_arg598548,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,anf_fun594550,anf_fun595551,body307499,l303500,name309496,ret305502) {
var $z555556 = D;
var $f561562 = function(_) {
return R.isFunction(anf_fun595551)?anf_fun595551.app(l303500,anf_arg598548,body307499):R.ffi.throwNonFunApp(L[59],anf_fun595551,[l303500,anf_arg598548,body307499]);
};
try {
if(--R.GAS > 0) {
$z555556 = $f561562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f561562,
"from":L[59]});
}
} catch($e553554) {
if(R.isCont($e553554)) {
var $ss557558 = {"from":L[59],
"go":function(anf_array_val599563) {
return $Hanf_array_val947564(anf_array_val599563,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,anf_fun594550,l303500,name309496,ret305502);
}};
$e553554.stack[R.EXN_STACKHEIGHT++] = $ss557558;
}
if(R.isPyretException($e553554)) {
$e553554.pyretStack.push(L[59]);
}
throw $e553554;
}
var $ret559560 = $Hanf_array_val947564($z555556,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,anf_fun594550,l303500,name309496,ret305502);
++R.GAS;
return $ret559560;
};
var $Hanf_array_val947564 = function(anf_array_val599563,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,anf_fun594550,l303500,name309496,ret305502) {
var $z567568 = D;
var $f573574 = function(_) {
return R.isFunction(anf_fun594550)?anf_fun594550.app([anf_array_val599563]):R.ffi.throwNonFunApp(L[57],anf_fun594550,[[anf_array_val599563]]);
};
try {
if(--R.GAS > 0) {
$z567568 = $f573574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f573574,
"from":L[57]});
}
} catch($e565566) {
if(R.isCont($e565566)) {
var $ss569570 = {"from":L[57],
"go":function(anf_arg600575) {
return $Hanf_arg946576(anf_arg600575,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,l303500,name309496,ret305502);
}};
$e565566.stack[R.EXN_STACKHEIGHT++] = $ss569570;
}
if(R.isPyretException($e565566)) {
$e565566.pyretStack.push(L[57]);
}
throw $e565566;
}
var $ret571572 = $Hanf_arg946576($z567568,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,l303500,name309496,ret305502);
++R.GAS;
return $ret571572;
};
var $Hanf_arg946576 = function(anf_arg600575,A110,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,anf_fun593549,l303500,name309496,ret305502) {
var anf_fun601587 = G(A110,"s-id",L[62]);
var anf_arg602588 = G(name309496,"id",L[61]);
var $z579580 = D;
var $f585586 = function(_) {
return R.isFunction(anf_fun601587)?anf_fun601587.app(l303500,anf_arg602588):R.ffi.throwNonFunApp(L[60],anf_fun601587,[l303500,anf_arg602588]);
};
try {
if(--R.GAS > 0) {
$z579580 = $f585586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f585586,
"from":L[60]});
}
} catch($e577578) {
if(R.isCont($e577578)) {
var $ss581582 = {"from":L[60],
"go":function(anf_arg603589) {
return $Hanf_arg945590(anf_arg603589,anf_DASH_term78497,anf_arg592515,anf_arg600575,anf_fun583516,anf_fun584517,anf_fun593549,l303500,ret305502);
}};
$e577578.stack[R.EXN_STACKHEIGHT++] = $ss581582;
}
if(R.isPyretException($e577578)) {
$e577578.pyretStack.push(L[60]);
}
throw $e577578;
}
var $ret583584 = $Hanf_arg945590($z579580,anf_DASH_term78497,anf_arg592515,anf_arg600575,anf_fun583516,anf_fun584517,anf_fun593549,l303500,ret305502);
++R.GAS;
return $ret583584;
};
var $Hanf_arg945590 = function(anf_arg603589,anf_DASH_term78497,anf_arg592515,anf_arg600575,anf_fun583516,anf_fun584517,anf_fun593549,l303500,ret305502) {
var $z593594 = D;
var $f599600 = function(_) {
return R.isFunction(anf_fun593549)?anf_fun593549.app(l303500,anf_arg600575,anf_arg603589):R.ffi.throwNonFunApp(L[63],anf_fun593549,[l303500,anf_arg600575,anf_arg603589]);
};
try {
if(--R.GAS > 0) {
$z593594 = $f599600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f599600,
"from":L[63]});
}
} catch($e591592) {
if(R.isCont($e591592)) {
var $ss595596 = {"from":L[63],
"go":function(anf_arg604601) {
return $Hanf_arg944602(anf_arg604601,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,l303500,ret305502);
}};
$e591592.stack[R.EXN_STACKHEIGHT++] = $ss595596;
}
if(R.isPyretException($e591592)) {
$e591592.pyretStack.push(L[63]);
}
throw $e591592;
}
var $ret597598 = $Hanf_arg944602($z593594,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,l303500,ret305502);
++R.GAS;
return $ret597598;
};
var $Hanf_arg944602 = function(anf_arg604601,anf_DASH_term78497,anf_arg592515,anf_fun583516,anf_fun584517,l303500,ret305502) {
var $z605606 = D;
var $f611612 = function(_) {
return R.isFunction(anf_DASH_term78497.$var)?anf_DASH_term78497.$var.app(anf_arg604601):R.ffi.throwNonFunApp(L[64],anf_DASH_term78497.$var,[anf_arg604601]);
};
try {
if(--R.GAS > 0) {
$z605606 = $f611612();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f611612,
"from":L[64]});
}
} catch($e603604) {
if(R.isCont($e603604)) {
var $ss607608 = {"from":L[64],
"go":function(anf_arg605613) {
return $Hanf_arg943614(anf_arg605613,anf_arg592515,anf_fun583516,anf_fun584517,l303500,ret305502);
}};
$e603604.stack[R.EXN_STACKHEIGHT++] = $ss607608;
}
if(R.isPyretException($e603604)) {
$e603604.pyretStack.push(L[64]);
}
throw $e603604;
}
var $ret609610 = $Hanf_arg943614($z605606,anf_arg592515,anf_fun583516,anf_fun584517,l303500,ret305502);
++R.GAS;
return $ret609610;
};
var $Hanf_arg943614 = function(anf_arg605613,anf_arg592515,anf_fun583516,anf_fun584517,l303500,ret305502) {
var $z617618 = D;
var $f623624 = function(_) {
return R.isFunction(anf_fun584517)?anf_fun584517.app(l303500,anf_arg592515,ret305502,anf_arg605613):R.ffi.throwNonFunApp(L[65],anf_fun584517,[l303500,anf_arg592515,ret305502,anf_arg605613]);
};
try {
if(--R.GAS > 0) {
$z617618 = $f623624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f623624,
"from":L[65]});
}
} catch($e615616) {
if(R.isCont($e615616)) {
var $ss619620 = {"from":L[65],
"go":function(anf_arg606625) {
return $Hanf_arg942626(anf_arg606625,anf_fun583516,l303500);
}};
$e615616.stack[R.EXN_STACKHEIGHT++] = $ss619620;
}
if(R.isPyretException($e615616)) {
$e615616.pyretStack.push(L[65]);
}
throw $e615616;
}
var $ret621622 = $Hanf_arg942626($z617618,anf_fun583516,l303500);
++R.GAS;
return $ret621622;
};
var $Hanf_arg942626 = function(anf_arg606625,anf_fun583516,l303500) {
var $z629630 = D;
var $f635636 = function(_) {
return R.isFunction(anf_fun583516)?anf_fun583516.app(l303500,anf_arg606625):R.ffi.throwNonFunApp(L[66],anf_fun583516,[l303500,anf_arg606625]);
};
try {
if(--R.GAS > 0) {
$z629630 = $f635636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f635636,
"from":L[66]});
}
} catch($e627628) {
if(R.isCont($e627628)) {
var $ss631632 = {"from":L[66],
"go":function(ann_DASH_check_DASH_temp582637) {
return $Hann_DASH_check_DASH_temp941638(ann_DASH_check_DASH_temp582637);
}};
$e627628.stack[R.EXN_STACKHEIGHT++] = $ss631632;
}
if(R.isPyretException($e627628)) {
$e627628.pyretStack.push(L[66]);
}
throw $e627628;
}
var $ret633634 = $Hann_DASH_check_DASH_temp941638($z629630);
++R.GAS;
return $ret633634;
};
var $Hann_DASH_check_DASH_temp941638 = function(ann_DASH_check_DASH_temp582637) {
return ann_DASH_check_DASH_temp582637;
};
var $Hann_DASH_check_DASH_temp940535 = function(ann_DASH_check_DASH_temp586534) {
return ann_DASH_check_DASH_temp586534;
};
var $Hname939639 = function(name301640,A110,N512,anf_DASH_term78497,args296641,body299642,k160138,l294643,list25501,ret297644) {
var anf_fun557658 = G(k160138,"apply",L[75]);
var anf_fun558659 = G(N512,"a-lam",L[74]);
var anf_fun559655 = G(args296641,"map",L[73]);
var anf_arg565656 = R.makeFunction(function(a302661) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[68],1,arguments);
}
var anf_fun561672 = G(N512,"a-bind",L[72]);
var anf_arg562673 = G(a302661,"l",L[71]);
var anf_arg563674 = G(a302661,"id",L[70]);
var anf_arg564675 = G(a302661,"ann",L[69]);
var $z664665 = D;
var $f670671 = function(_) {
return R.isFunction(anf_fun561672)?anf_fun561672.app(anf_arg562673,anf_arg563674,anf_arg564675):R.ffi.throwNonFunApp(L[68],anf_fun561672,[anf_arg562673,anf_arg563674,anf_arg564675]);
};
try {
if(--R.GAS > 0) {
$z664665 = $f670671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f670671,
"from":L[68]});
}
} catch($e662663) {
if(R.isCont($e662663)) {
var $ss666667 = {"from":L[68],
"go":function(ann_DASH_check_DASH_temp560676) {
return $Hann_DASH_check_DASH_temp929677(ann_DASH_check_DASH_temp560676);
}};
$e662663.stack[R.EXN_STACKHEIGHT++] = $ss666667;
}
if(R.isPyretException($e662663)) {
$e662663.pyretStack.push(L[68]);
}
throw $e662663;
}
var $ret668669 = $Hann_DASH_check_DASH_temp929677($z664665);
++R.GAS;
return $ret668669;
});
var $z647648 = D;
var $f653654 = function(_) {
return R.isFunction(anf_fun559655)?anf_fun559655.app(anf_arg565656):R.ffi.throwNonFunApp(L[67],anf_fun559655,[anf_arg565656]);
};
try {
if(--R.GAS > 0) {
$z647648 = $f653654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f653654,
"from":L[67]});
}
} catch($e645646) {
if(R.isCont($e645646)) {
var $ss649650 = {"from":L[67],
"go":function(anf_arg566657) {
return $Hanf_arg938660(anf_arg566657,A110,anf_DASH_term78497,anf_fun557658,anf_fun558659,body299642,l294643,list25501,name301640,ret297644);
}};
$e645646.stack[R.EXN_STACKHEIGHT++] = $ss649650;
}
if(R.isPyretException($e645646)) {
$e645646.pyretStack.push(L[67]);
}
throw $e645646;
}
var $ret651652 = $Hanf_arg938660($z647648,A110,anf_DASH_term78497,anf_fun557658,anf_fun558659,body299642,l294643,list25501,name301640,ret297644);
++R.GAS;
return $ret651652;
};
var $Hanf_arg938660 = function(anf_arg566657,A110,anf_DASH_term78497,anf_fun557658,anf_fun558659,body299642,l294643,list25501,name301640,ret297644) {
var anf_fun567691 = G(A110,"s-let-expr",L[81]);
var anf_fun568692 = G(list25501,"make",L[80]);
var anf_fun569693 = G(A110,"s-let-bind",L[79]);
var anf_fun570688 = G(A110,"s-bind",L[78]);
var anf_arg571689 = G(name301640,"id",L[77]);
var $z680681 = D;
var $f686687 = function(_) {
return R.isFunction(anf_fun570688)?anf_fun570688.app(l294643,(false),anf_arg571689,ret297644):R.ffi.throwNonFunApp(L[76],anf_fun570688,[l294643,(false),anf_arg571689,ret297644]);
};
try {
if(--R.GAS > 0) {
$z680681 = $f686687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f686687,
"from":L[76]});
}
} catch($e678679) {
if(R.isCont($e678679)) {
var $ss682683 = {"from":L[76],
"go":function(anf_arg572690) {
return $Hanf_arg937694(anf_arg572690,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,anf_fun568692,anf_fun569693,body299642,l294643,name301640,ret297644);
}};
$e678679.stack[R.EXN_STACKHEIGHT++] = $ss682683;
}
if(R.isPyretException($e678679)) {
$e678679.pyretStack.push(L[76]);
}
throw $e678679;
}
var $ret684685 = $Hanf_arg937694($z680681,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,anf_fun568692,anf_fun569693,body299642,l294643,name301640,ret297644);
++R.GAS;
return $ret684685;
};
var $Hanf_arg937694 = function(anf_arg572690,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,anf_fun568692,anf_fun569693,body299642,l294643,name301640,ret297644) {
var $z697698 = D;
var $f703704 = function(_) {
return R.isFunction(anf_fun569693)?anf_fun569693.app(l294643,anf_arg572690,body299642):R.ffi.throwNonFunApp(L[82],anf_fun569693,[l294643,anf_arg572690,body299642]);
};
try {
if(--R.GAS > 0) {
$z697698 = $f703704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f703704,
"from":L[82]});
}
} catch($e695696) {
if(R.isCont($e695696)) {
var $ss699700 = {"from":L[82],
"go":function(anf_array_val573705) {
return $Hanf_array_val936706(anf_array_val573705,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,anf_fun568692,l294643,name301640,ret297644);
}};
$e695696.stack[R.EXN_STACKHEIGHT++] = $ss699700;
}
if(R.isPyretException($e695696)) {
$e695696.pyretStack.push(L[82]);
}
throw $e695696;
}
var $ret701702 = $Hanf_array_val936706($z697698,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,anf_fun568692,l294643,name301640,ret297644);
++R.GAS;
return $ret701702;
};
var $Hanf_array_val936706 = function(anf_array_val573705,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,anf_fun568692,l294643,name301640,ret297644) {
var $z709710 = D;
var $f715716 = function(_) {
return R.isFunction(anf_fun568692)?anf_fun568692.app([anf_array_val573705]):R.ffi.throwNonFunApp(L[80],anf_fun568692,[[anf_array_val573705]]);
};
try {
if(--R.GAS > 0) {
$z709710 = $f715716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f715716,
"from":L[80]});
}
} catch($e707708) {
if(R.isCont($e707708)) {
var $ss711712 = {"from":L[80],
"go":function(anf_arg574717) {
return $Hanf_arg935718(anf_arg574717,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,l294643,name301640,ret297644);
}};
$e707708.stack[R.EXN_STACKHEIGHT++] = $ss711712;
}
if(R.isPyretException($e707708)) {
$e707708.pyretStack.push(L[80]);
}
throw $e707708;
}
var $ret713714 = $Hanf_arg935718($z709710,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,l294643,name301640,ret297644);
++R.GAS;
return $ret713714;
};
var $Hanf_arg935718 = function(anf_arg574717,A110,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,anf_fun567691,l294643,name301640,ret297644) {
var anf_fun575729 = G(A110,"s-id",L[85]);
var anf_arg576730 = G(name301640,"id",L[84]);
var $z721722 = D;
var $f727728 = function(_) {
return R.isFunction(anf_fun575729)?anf_fun575729.app(l294643,anf_arg576730):R.ffi.throwNonFunApp(L[83],anf_fun575729,[l294643,anf_arg576730]);
};
try {
if(--R.GAS > 0) {
$z721722 = $f727728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f727728,
"from":L[83]});
}
} catch($e719720) {
if(R.isCont($e719720)) {
var $ss723724 = {"from":L[83],
"go":function(anf_arg577731) {
return $Hanf_arg934732(anf_arg577731,anf_DASH_term78497,anf_arg566657,anf_arg574717,anf_fun557658,anf_fun558659,anf_fun567691,l294643,ret297644);
}};
$e719720.stack[R.EXN_STACKHEIGHT++] = $ss723724;
}
if(R.isPyretException($e719720)) {
$e719720.pyretStack.push(L[83]);
}
throw $e719720;
}
var $ret725726 = $Hanf_arg934732($z721722,anf_DASH_term78497,anf_arg566657,anf_arg574717,anf_fun557658,anf_fun558659,anf_fun567691,l294643,ret297644);
++R.GAS;
return $ret725726;
};
var $Hanf_arg934732 = function(anf_arg577731,anf_DASH_term78497,anf_arg566657,anf_arg574717,anf_fun557658,anf_fun558659,anf_fun567691,l294643,ret297644) {
var $z735736 = D;
var $f741742 = function(_) {
return R.isFunction(anf_fun567691)?anf_fun567691.app(l294643,anf_arg574717,anf_arg577731):R.ffi.throwNonFunApp(L[86],anf_fun567691,[l294643,anf_arg574717,anf_arg577731]);
};
try {
if(--R.GAS > 0) {
$z735736 = $f741742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f741742,
"from":L[86]});
}
} catch($e733734) {
if(R.isCont($e733734)) {
var $ss737738 = {"from":L[86],
"go":function(anf_arg578743) {
return $Hanf_arg933744(anf_arg578743,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,l294643,ret297644);
}};
$e733734.stack[R.EXN_STACKHEIGHT++] = $ss737738;
}
if(R.isPyretException($e733734)) {
$e733734.pyretStack.push(L[86]);
}
throw $e733734;
}
var $ret739740 = $Hanf_arg933744($z735736,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,l294643,ret297644);
++R.GAS;
return $ret739740;
};
var $Hanf_arg933744 = function(anf_arg578743,anf_DASH_term78497,anf_arg566657,anf_fun557658,anf_fun558659,l294643,ret297644) {
var $z747748 = D;
var $f753754 = function(_) {
return R.isFunction(anf_DASH_term78497.$var)?anf_DASH_term78497.$var.app(anf_arg578743):R.ffi.throwNonFunApp(L[87],anf_DASH_term78497.$var,[anf_arg578743]);
};
try {
if(--R.GAS > 0) {
$z747748 = $f753754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f753754,
"from":L[87]});
}
} catch($e745746) {
if(R.isCont($e745746)) {
var $ss749750 = {"from":L[87],
"go":function(anf_arg579755) {
return $Hanf_arg932756(anf_arg579755,anf_arg566657,anf_fun557658,anf_fun558659,l294643,ret297644);
}};
$e745746.stack[R.EXN_STACKHEIGHT++] = $ss749750;
}
if(R.isPyretException($e745746)) {
$e745746.pyretStack.push(L[87]);
}
throw $e745746;
}
var $ret751752 = $Hanf_arg932756($z747748,anf_arg566657,anf_fun557658,anf_fun558659,l294643,ret297644);
++R.GAS;
return $ret751752;
};
var $Hanf_arg932756 = function(anf_arg579755,anf_arg566657,anf_fun557658,anf_fun558659,l294643,ret297644) {
var $z759760 = D;
var $f765766 = function(_) {
return R.isFunction(anf_fun558659)?anf_fun558659.app(l294643,anf_arg566657,ret297644,anf_arg579755):R.ffi.throwNonFunApp(L[88],anf_fun558659,[l294643,anf_arg566657,ret297644,anf_arg579755]);
};
try {
if(--R.GAS > 0) {
$z759760 = $f765766();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f765766,
"from":L[88]});
}
} catch($e757758) {
if(R.isCont($e757758)) {
var $ss761762 = {"from":L[88],
"go":function(anf_arg580767) {
return $Hanf_arg931768(anf_arg580767,anf_fun557658,l294643);
}};
$e757758.stack[R.EXN_STACKHEIGHT++] = $ss761762;
}
if(R.isPyretException($e757758)) {
$e757758.pyretStack.push(L[88]);
}
throw $e757758;
}
var $ret763764 = $Hanf_arg931768($z759760,anf_fun557658,l294643);
++R.GAS;
return $ret763764;
};
var $Hanf_arg931768 = function(anf_arg580767,anf_fun557658,l294643) {
var $z771772 = D;
var $f777778 = function(_) {
return R.isFunction(anf_fun557658)?anf_fun557658.app(l294643,anf_arg580767):R.ffi.throwNonFunApp(L[89],anf_fun557658,[l294643,anf_arg580767]);
};
try {
if(--R.GAS > 0) {
$z771772 = $f777778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f777778,
"from":L[89]});
}
} catch($e769770) {
if(R.isCont($e769770)) {
var $ss773774 = {"from":L[89],
"go":function(ann_DASH_check_DASH_temp556779) {
return $Hann_DASH_check_DASH_temp930780(ann_DASH_check_DASH_temp556779);
}};
$e769770.stack[R.EXN_STACKHEIGHT++] = $ss773774;
}
if(R.isPyretException($e769770)) {
$e769770.pyretStack.push(L[89]);
}
throw $e769770;
}
var $ret775776 = $Hann_DASH_check_DASH_temp930780($z771772);
++R.GAS;
return $ret775776;
};
var $Hann_DASH_check_DASH_temp930780 = function(ann_DASH_check_DASH_temp556779) {
return ann_DASH_check_DASH_temp556779;
};
var $Hann_DASH_check_DASH_temp929677 = function(ann_DASH_check_DASH_temp560676) {
return ann_DASH_check_DASH_temp560676;
};
var $Hann_DASH_check_DASH_temp928781 = function(ann_DASH_check_DASH_temp554782) {
return ann_DASH_check_DASH_temp554782;
};
var $Hann_DASH_check_DASH_temp927783 = function(ann_DASH_check_DASH_temp552784) {
return ann_DASH_check_DASH_temp552784;
};
var $Hanf_arg926785 = function(anf_arg549786,_except289787,anf_DASH_term78497,anf_fun548788,id288789,l286790) {
var $z793794 = D;
var $f799800 = function(_) {
return R.isFunction(anf_DASH_term78497.$var)?anf_DASH_term78497.$var.app(_except289787):R.ffi.throwNonFunApp(L[90],anf_DASH_term78497.$var,[_except289787]);
};
try {
if(--R.GAS > 0) {
$z793794 = $f799800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f799800,
"from":L[90]});
}
} catch($e791792) {
if(R.isCont($e791792)) {
var $ss795796 = {"from":L[90],
"go":function(anf_arg550801) {
return $Hanf_arg925802(anf_arg550801,anf_arg549786,anf_fun548788,id288789,l286790);
}};
$e791792.stack[R.EXN_STACKHEIGHT++] = $ss795796;
}
if(R.isPyretException($e791792)) {
$e791792.pyretStack.push(L[90]);
}
throw $e791792;
}
var $ret797798 = $Hanf_arg925802($z793794,anf_arg549786,anf_fun548788,id288789,l286790);
++R.GAS;
return $ret797798;
};
var $Hanf_arg925802 = function(anf_arg550801,anf_arg549786,anf_fun548788,id288789,l286790) {
var $z805806 = D;
var $f811812 = function(_) {
return R.isFunction(anf_fun548788)?anf_fun548788.app(l286790,anf_arg549786,id288789,anf_arg550801):R.ffi.throwNonFunApp(L[91],anf_fun548788,[l286790,anf_arg549786,id288789,anf_arg550801]);
};
try {
if(--R.GAS > 0) {
$z805806 = $f811812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f811812,
"from":L[91]});
}
} catch($e803804) {
if(R.isCont($e803804)) {
var $ss807808 = {"from":L[91],
"go":function(ann_DASH_check_DASH_temp547813) {
return $Hann_DASH_check_DASH_temp924814(ann_DASH_check_DASH_temp547813);
}};
$e803804.stack[R.EXN_STACKHEIGHT++] = $ss807808;
}
if(R.isPyretException($e803804)) {
$e803804.pyretStack.push(L[91]);
}
throw $e803804;
}
var $ret809810 = $Hann_DASH_check_DASH_temp924814($z805806);
++R.GAS;
return $ret809810;
};
var $Hann_DASH_check_DASH_temp924814 = function(ann_DASH_check_DASH_temp547813) {
return ann_DASH_check_DASH_temp547813;
};
var $Hann_DASH_check_DASH_temp923815 = function(ann_DASH_check_DASH_temp497816) {
return ann_DASH_check_DASH_temp497816;
};
var $Hhelper922817 = function(helper281818,A110,N512,_else275819,anf_DASH_name81136,anf86820,branches274821,fold53822,k_DASH_id77823,k160138,l273824,list25501,mk_DASH_id70825) {
var $z828829 = D;
var $f834835 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(l273824,("if_helper_arg")):R.ffi.throwNonFunApp(L[92],mk_DASH_id70825.$var,[l273824,("if_helper_arg")]);
};
try {
if(--R.GAS > 0) {
$z828829 = $f834835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f834835,
"from":L[92]});
}
} catch($e826827) {
if(R.isCont($e826827)) {
var $ss830831 = {"from":L[92],
"go":function(arg282836) {
return $Harg921837(arg282836,A110,N512,_else275819,anf_DASH_name81136,anf86820,branches274821,fold53822,helper281818,k_DASH_id77823,k160138,l273824,list25501);
}};
$e826827.stack[R.EXN_STACKHEIGHT++] = $ss830831;
}
if(R.isPyretException($e826827)) {
$e826827.pyretStack.push(L[92]);
}
throw $e826827;
}
var $ret832833 = $Harg921837($z828829,A110,N512,_else275819,anf_DASH_name81136,anf86820,branches274821,fold53822,helper281818,k_DASH_id77823,k160138,l273824,list25501);
++R.GAS;
return $ret832833;
};
var $Harg921837 = function(arg282836,A110,N512,_else275819,anf_DASH_name81136,anf86820,branches274821,fold53822,helper281818,k_DASH_id77823,k160138,l273824,list25501) {
var anf_fun513852 = G(N512,"a-let",L[97]);
var anf_arg514851 = G(helper281818,"id-b",L[96]);
var anf_fun515853 = G(N512,"a-lam",L[95]);
var anf_fun516848 = G(list25501,"make",L[93]);
var anf_array_val517849 = G(arg282836,"id-b",L[94]);
var $z840841 = D;
var $f846847 = function(_) {
return R.isFunction(anf_fun516848)?anf_fun516848.app([anf_array_val517849]):R.ffi.throwNonFunApp(L[93],anf_fun516848,[[anf_array_val517849]]);
};
try {
if(--R.GAS > 0) {
$z840841 = $f846847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f846847,
"from":L[93]});
}
} catch($e838839) {
if(R.isCont($e838839)) {
var $ss842843 = {"from":L[93],
"go":function(anf_arg518850) {
return $Hanf_arg920854(anf_arg518850,A110,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_fun513852,anf_fun515853,arg282836,branches274821,fold53822,helper281818,k_DASH_id77823,k160138,l273824);
}};
$e838839.stack[R.EXN_STACKHEIGHT++] = $ss842843;
}
if(R.isPyretException($e838839)) {
$e838839.pyretStack.push(L[93]);
}
throw $e838839;
}
var $ret844845 = $Hanf_arg920854($z840841,A110,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_fun513852,anf_fun515853,arg282836,branches274821,fold53822,helper281818,k_DASH_id77823,k160138,l273824);
++R.GAS;
return $ret844845;
};
var $Hanf_arg920854 = function(anf_arg518850,A110,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_fun513852,anf_fun515853,arg282836,branches274821,fold53822,helper281818,k_DASH_id77823,k160138,l273824) {
var anf_arg519868 = G(A110,"a-blank",L[102]);
var anf_fun520869 = G(k160138,"apply",L[101]);
var anf_fun521865 = G(N512,"a-val",L[100]);
var anf_arg522866 = G(arg282836,"id-e",L[99]);
var $z857858 = D;
var $f863864 = function(_) {
return R.isFunction(anf_fun521865)?anf_fun521865.app(anf_arg522866):R.ffi.throwNonFunApp(L[98],anf_fun521865,[anf_arg522866]);
};
try {
if(--R.GAS > 0) {
$z857858 = $f863864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f863864,
"from":L[98]});
}
} catch($e855856) {
if(R.isCont($e855856)) {
var $ss859860 = {"from":L[98],
"go":function(anf_arg523867) {
return $Hanf_arg919870(anf_arg523867,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_arg518850,anf_arg519868,anf_fun513852,anf_fun515853,anf_fun520869,branches274821,fold53822,helper281818,k_DASH_id77823,l273824);
}};
$e855856.stack[R.EXN_STACKHEIGHT++] = $ss859860;
}
if(R.isPyretException($e855856)) {
$e855856.pyretStack.push(L[98]);
}
throw $e855856;
}
var $ret861862 = $Hanf_arg919870($z857858,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_arg518850,anf_arg519868,anf_fun513852,anf_fun515853,anf_fun520869,branches274821,fold53822,helper281818,k_DASH_id77823,l273824);
++R.GAS;
return $ret861862;
};
var $Hanf_arg919870 = function(anf_arg523867,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_arg518850,anf_arg519868,anf_fun513852,anf_fun515853,anf_fun520869,branches274821,fold53822,helper281818,k_DASH_id77823,l273824) {
var $z873874 = D;
var $f879880 = function(_) {
return R.isFunction(anf_fun520869)?anf_fun520869.app(l273824,anf_arg523867):R.ffi.throwNonFunApp(L[103],anf_fun520869,[l273824,anf_arg523867]);
};
try {
if(--R.GAS > 0) {
$z873874 = $f879880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f879880,
"from":L[103]});
}
} catch($e871872) {
if(R.isCont($e871872)) {
var $ss875876 = {"from":L[103],
"go":function(anf_arg524881) {
return $Hanf_arg918882(anf_arg524881,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_arg518850,anf_arg519868,anf_fun513852,anf_fun515853,branches274821,fold53822,helper281818,k_DASH_id77823,l273824);
}};
$e871872.stack[R.EXN_STACKHEIGHT++] = $ss875876;
}
if(R.isPyretException($e871872)) {
$e871872.pyretStack.push(L[103]);
}
throw $e871872;
}
var $ret877878 = $Hanf_arg918882($z873874,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_arg518850,anf_arg519868,anf_fun513852,anf_fun515853,branches274821,fold53822,helper281818,k_DASH_id77823,l273824);
++R.GAS;
return $ret877878;
};
var $Hanf_arg918882 = function(anf_arg524881,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_arg518850,anf_arg519868,anf_fun513852,anf_fun515853,branches274821,fold53822,helper281818,k_DASH_id77823,l273824) {
var $z885886 = D;
var $f891892 = function(_) {
return R.isFunction(anf_fun515853)?anf_fun515853.app(l273824,anf_arg518850,anf_arg519868,anf_arg524881):R.ffi.throwNonFunApp(L[104],anf_fun515853,[l273824,anf_arg518850,anf_arg519868,anf_arg524881]);
};
try {
if(--R.GAS > 0) {
$z885886 = $f891892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f891892,
"from":L[104]});
}
} catch($e883884) {
if(R.isCont($e883884)) {
var $ss887888 = {"from":L[104],
"go":function(anf_arg525893) {
return $Hanf_arg917894(anf_arg525893,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_fun513852,branches274821,fold53822,helper281818,k_DASH_id77823,l273824);
}};
$e883884.stack[R.EXN_STACKHEIGHT++] = $ss887888;
}
if(R.isPyretException($e883884)) {
$e883884.pyretStack.push(L[104]);
}
throw $e883884;
}
var $ret889890 = $Hanf_arg917894($z885886,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_fun513852,branches274821,fold53822,helper281818,k_DASH_id77823,l273824);
++R.GAS;
return $ret889890;
};
var $Hanf_arg917894 = function(anf_arg525893,N512,_else275819,anf_DASH_name81136,anf86820,anf_arg514851,anf_fun513852,branches274821,fold53822,helper281818,k_DASH_id77823,l273824) {
var anf_arg535907 = R.makeFunction(function(acc283909,branch284910) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[107],2,arguments);
}
var anf_arg527921 = G(branch284910,"test",L[113]);
var anf_arg534922 = R.makeFunction(function(test285925) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[108],1,arguments);
}
var anf_fun529939 = G(N512,"a-if",L[112]);
var anf_arg530938 = G(branch284910,"body",L[111]);
var anf_arg531936 = G(helper281818,"id",L[110]);
var $z928929 = D;
var $f934935 = function(_) {
return R.isFunction(k_DASH_id77823.$var)?k_DASH_id77823.$var.app(anf_arg531936):R.ffi.throwNonFunApp(L[109],k_DASH_id77823.$var,[anf_arg531936]);
};
try {
if(--R.GAS > 0) {
$z928929 = $f934935();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f934935,
"from":L[109]});
}
} catch($e926927) {
if(R.isCont($e926927)) {
var $ss930931 = {"from":L[109],
"go":function(anf_arg532937) {
return $Hanf_arg910940(anf_arg532937,acc283909,anf86820,anf_arg530938,anf_fun529939,l273824,test285925);
}};
$e926927.stack[R.EXN_STACKHEIGHT++] = $ss930931;
}
if(R.isPyretException($e926927)) {
$e926927.pyretStack.push(L[109]);
}
throw $e926927;
}
var $ret932933 = $Hanf_arg910940($z928929,acc283909,anf86820,anf_arg530938,anf_fun529939,l273824,test285925);
++R.GAS;
return $ret932933;
});
var $z913914 = D;
var $f919920 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(anf_arg527921,("anf_if"),anf_arg534922):R.ffi.throwNonFunApp(L[107],anf_DASH_name81136.$var,[anf_arg527921,("anf_if"),anf_arg534922]);
};
try {
if(--R.GAS > 0) {
$z913914 = $f919920();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f919920,
"from":L[107]});
}
} catch($e911912) {
if(R.isCont($e911912)) {
var $ss915916 = {"from":L[107],
"go":function(ann_DASH_check_DASH_temp526923) {
return $Hann_DASH_check_DASH_temp911924(ann_DASH_check_DASH_temp526923);
}};
$e911912.stack[R.EXN_STACKHEIGHT++] = $ss915916;
}
if(R.isPyretException($e911912)) {
$e911912.pyretStack.push(L[107]);
}
throw $e911912;
}
var $ret917918 = $Hann_DASH_check_DASH_temp911924($z913914);
++R.GAS;
return $ret917918;
});
var anf_arg536905 = G(helper281818,"id",L[106]);
var $z897898 = D;
var $f903904 = function(_) {
return R.isFunction(k_DASH_id77823.$var)?k_DASH_id77823.$var.app(anf_arg536905):R.ffi.throwNonFunApp(L[105],k_DASH_id77823.$var,[anf_arg536905]);
};
try {
if(--R.GAS > 0) {
$z897898 = $f903904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f903904,
"from":L[105]});
}
} catch($e895896) {
if(R.isCont($e895896)) {
var $ss899900 = {"from":L[105],
"go":function(anf_arg537906) {
return $Hanf_arg916908(anf_arg537906,_else275819,anf86820,anf_arg514851,anf_arg525893,anf_arg535907,anf_fun513852,branches274821,fold53822,l273824);
}};
$e895896.stack[R.EXN_STACKHEIGHT++] = $ss899900;
}
if(R.isPyretException($e895896)) {
$e895896.pyretStack.push(L[105]);
}
throw $e895896;
}
var $ret901902 = $Hanf_arg916908($z897898,_else275819,anf86820,anf_arg514851,anf_arg525893,anf_arg535907,anf_fun513852,branches274821,fold53822,l273824);
++R.GAS;
return $ret901902;
};
var $Hanf_arg916908 = function(anf_arg537906,_else275819,anf86820,anf_arg514851,anf_arg525893,anf_arg535907,anf_fun513852,branches274821,fold53822,l273824) {
var $z943944 = D;
var $f949950 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(_else275819,anf_arg537906):R.ffi.throwNonFunApp(L[114],anf86820.$var,[_else275819,anf_arg537906]);
};
try {
if(--R.GAS > 0) {
$z943944 = $f949950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f949950,
"from":L[114]});
}
} catch($e941942) {
if(R.isCont($e941942)) {
var $ss945946 = {"from":L[114],
"go":function(anf_arg538951) {
return $Hanf_arg915952(anf_arg538951,anf_arg514851,anf_arg525893,anf_arg535907,anf_fun513852,branches274821,fold53822,l273824);
}};
$e941942.stack[R.EXN_STACKHEIGHT++] = $ss945946;
}
if(R.isPyretException($e941942)) {
$e941942.pyretStack.push(L[114]);
}
throw $e941942;
}
var $ret947948 = $Hanf_arg915952($z943944,anf_arg514851,anf_arg525893,anf_arg535907,anf_fun513852,branches274821,fold53822,l273824);
++R.GAS;
return $ret947948;
};
var $Hanf_arg915952 = function(anf_arg538951,anf_arg514851,anf_arg525893,anf_arg535907,anf_fun513852,branches274821,fold53822,l273824) {
var anf_fun539963 = G(branches274821,"reverse",L[116]);
var $z955956 = D;
var $f961962 = function(_) {
return R.isFunction(anf_fun539963)?anf_fun539963.app():R.ffi.throwNonFunApp(L[115],anf_fun539963,[]);
};
try {
if(--R.GAS > 0) {
$z955956 = $f961962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f961962,
"from":L[115]});
}
} catch($e953954) {
if(R.isCont($e953954)) {
var $ss957958 = {"from":L[115],
"go":function(anf_arg540964) {
return $Hanf_arg914965(anf_arg540964,anf_arg514851,anf_arg525893,anf_arg535907,anf_arg538951,anf_fun513852,fold53822,l273824);
}};
$e953954.stack[R.EXN_STACKHEIGHT++] = $ss957958;
}
if(R.isPyretException($e953954)) {
$e953954.pyretStack.push(L[115]);
}
throw $e953954;
}
var $ret959960 = $Hanf_arg914965($z955956,anf_arg514851,anf_arg525893,anf_arg535907,anf_arg538951,anf_fun513852,fold53822,l273824);
++R.GAS;
return $ret959960;
};
var $Hanf_arg914965 = function(anf_arg540964,anf_arg514851,anf_arg525893,anf_arg535907,anf_arg538951,anf_fun513852,fold53822,l273824) {
var $z968969 = D;
var $f974975 = function(_) {
return R.isFunction(fold53822)?fold53822.app(anf_arg535907,anf_arg538951,anf_arg540964):R.ffi.throwNonFunApp(L[107],fold53822,[anf_arg535907,anf_arg538951,anf_arg540964]);
};
try {
if(--R.GAS > 0) {
$z968969 = $f974975();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f974975,
"from":L[107]});
}
} catch($e966967) {
if(R.isCont($e966967)) {
var $ss970971 = {"from":L[107],
"go":function(anf_arg541976) {
return $Hanf_arg913977(anf_arg541976,anf_arg514851,anf_arg525893,anf_fun513852,l273824);
}};
$e966967.stack[R.EXN_STACKHEIGHT++] = $ss970971;
}
if(R.isPyretException($e966967)) {
$e966967.pyretStack.push(L[107]);
}
throw $e966967;
}
var $ret972973 = $Hanf_arg913977($z968969,anf_arg514851,anf_arg525893,anf_fun513852,l273824);
++R.GAS;
return $ret972973;
};
var $Hanf_arg913977 = function(anf_arg541976,anf_arg514851,anf_arg525893,anf_fun513852,l273824) {
var $z980981 = D;
var $f986987 = function(_) {
return R.isFunction(anf_fun513852)?anf_fun513852.app(l273824,anf_arg514851,anf_arg525893,anf_arg541976):R.ffi.throwNonFunApp(L[117],anf_fun513852,[l273824,anf_arg514851,anf_arg525893,anf_arg541976]);
};
try {
if(--R.GAS > 0) {
$z980981 = $f986987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f986987,
"from":L[117]});
}
} catch($e978979) {
if(R.isCont($e978979)) {
var $ss982983 = {"from":L[117],
"go":function(ann_DASH_check_DASH_temp512988) {
return $Hann_DASH_check_DASH_temp912989(ann_DASH_check_DASH_temp512988);
}};
$e978979.stack[R.EXN_STACKHEIGHT++] = $ss982983;
}
if(R.isPyretException($e978979)) {
$e978979.pyretStack.push(L[117]);
}
throw $e978979;
}
var $ret984985 = $Hann_DASH_check_DASH_temp912989($z980981);
++R.GAS;
return $ret984985;
};
var $Hann_DASH_check_DASH_temp912989 = function(ann_DASH_check_DASH_temp512988) {
return ann_DASH_check_DASH_temp512988;
};
var $Hann_DASH_check_DASH_temp911924 = function(ann_DASH_check_DASH_temp526923) {
return ann_DASH_check_DASH_temp526923;
};
var $Hanf_arg910940 = function(anf_arg532937,acc283909,anf86820,anf_arg530938,anf_fun529939,l273824,test285925) {
var $z992993 = D;
var $f998999 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(anf_arg530938,anf_arg532937):R.ffi.throwNonFunApp(L[118],anf86820.$var,[anf_arg530938,anf_arg532937]);
};
try {
if(--R.GAS > 0) {
$z992993 = $f998999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f998999,
"from":L[118]});
}
} catch($e990991) {
if(R.isCont($e990991)) {
var $ss994995 = {"from":L[118],
"go":function(anf_arg5331000) {
return $Hanf_arg9091001(anf_arg5331000,acc283909,anf_fun529939,l273824,test285925);
}};
$e990991.stack[R.EXN_STACKHEIGHT++] = $ss994995;
}
if(R.isPyretException($e990991)) {
$e990991.pyretStack.push(L[118]);
}
throw $e990991;
}
var $ret996997 = $Hanf_arg9091001($z992993,acc283909,anf_fun529939,l273824,test285925);
++R.GAS;
return $ret996997;
};
var $Hanf_arg9091001 = function(anf_arg5331000,acc283909,anf_fun529939,l273824,test285925) {
var $z10041005 = D;
var $f10101011 = function(_) {
return R.isFunction(anf_fun529939)?anf_fun529939.app(l273824,test285925,anf_arg5331000,acc283909):R.ffi.throwNonFunApp(L[108],anf_fun529939,[l273824,test285925,anf_arg5331000,acc283909]);
};
try {
if(--R.GAS > 0) {
$z10041005 = $f10101011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10101011,
"from":L[108]});
}
} catch($e10021003) {
if(R.isCont($e10021003)) {
var $ss10061007 = {"from":L[108],
"go":function(ann_DASH_check_DASH_temp5281012) {
return $Hann_DASH_check_DASH_temp9081013(ann_DASH_check_DASH_temp5281012);
}};
$e10021003.stack[R.EXN_STACKHEIGHT++] = $ss10061007;
}
if(R.isPyretException($e10021003)) {
$e10021003.pyretStack.push(L[108]);
}
throw $e10021003;
}
var $ret10081009 = $Hann_DASH_check_DASH_temp9081013($z10041005);
++R.GAS;
return $ret10081009;
};
var $Hann_DASH_check_DASH_temp9081013 = function(ann_DASH_check_DASH_temp5281012) {
return ann_DASH_check_DASH_temp5281012;
};
var $Hanf_arg9071014 = function(anf_arg5081015,anf_arg5071016,branches274821,fold53822) {
var anf_fun5091027 = G(branches274821,"reverse",L[120]);
var $z10191020 = D;
var $f10251026 = function(_) {
return R.isFunction(anf_fun5091027)?anf_fun5091027.app():R.ffi.throwNonFunApp(L[119],anf_fun5091027,[]);
};
try {
if(--R.GAS > 0) {
$z10191020 = $f10251026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10251026,
"from":L[119]});
}
} catch($e10171018) {
if(R.isCont($e10171018)) {
var $ss10211022 = {"from":L[119],
"go":function(anf_arg5101028) {
return $Hanf_arg9061029(anf_arg5101028,anf_arg5071016,anf_arg5081015,fold53822);
}};
$e10171018.stack[R.EXN_STACKHEIGHT++] = $ss10211022;
}
if(R.isPyretException($e10171018)) {
$e10171018.pyretStack.push(L[119]);
}
throw $e10171018;
}
var $ret10231024 = $Hanf_arg9061029($z10191020,anf_arg5071016,anf_arg5081015,fold53822);
++R.GAS;
return $ret10231024;
};
var $Hanf_arg9061029 = function(anf_arg5101028,anf_arg5071016,anf_arg5081015,fold53822) {
var $z10321033 = D;
var $f10381039 = function(_) {
return R.isFunction(fold53822)?fold53822.app(anf_arg5071016,anf_arg5081015,anf_arg5101028):R.ffi.throwNonFunApp(L[121],fold53822,[anf_arg5071016,anf_arg5081015,anf_arg5101028]);
};
try {
if(--R.GAS > 0) {
$z10321033 = $f10381039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10381039,
"from":L[121]});
}
} catch($e10301031) {
if(R.isCont($e10301031)) {
var $ss10341035 = {"from":L[121],
"go":function(ann_DASH_check_DASH_temp4991040) {
return $Hann_DASH_check_DASH_temp9051041(ann_DASH_check_DASH_temp4991040);
}};
$e10301031.stack[R.EXN_STACKHEIGHT++] = $ss10341035;
}
if(R.isPyretException($e10301031)) {
$e10301031.pyretStack.push(L[121]);
}
throw $e10301031;
}
var $ret10361037 = $Hann_DASH_check_DASH_temp9051041($z10321033);
++R.GAS;
return $ret10361037;
};
var $Hann_DASH_check_DASH_temp9051041 = function(ann_DASH_check_DASH_temp4991040) {
return ann_DASH_check_DASH_temp4991040;
};
var $Hann_DASH_check_DASH_temp9041042 = function(ann_DASH_check_DASH_temp5001043) {
return ann_DASH_check_DASH_temp5001043;
};
var $Hanf_arg9031044 = function(anf_arg5051045,acc2771046,anf_fun5031047,l273824,test2791048) {
var $z10511052 = D;
var $f10571058 = function(_) {
return R.isFunction(anf_fun5031047)?anf_fun5031047.app(l273824,test2791048,anf_arg5051045,acc2771046):R.ffi.throwNonFunApp(L[122],anf_fun5031047,[l273824,test2791048,anf_arg5051045,acc2771046]);
};
try {
if(--R.GAS > 0) {
$z10511052 = $f10571058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10571058,
"from":L[122]});
}
} catch($e10491050) {
if(R.isCont($e10491050)) {
var $ss10531054 = {"from":L[122],
"go":function(ann_DASH_check_DASH_temp5021059) {
return $Hann_DASH_check_DASH_temp9021060(ann_DASH_check_DASH_temp5021059);
}};
$e10491050.stack[R.EXN_STACKHEIGHT++] = $ss10531054;
}
if(R.isPyretException($e10491050)) {
$e10491050.pyretStack.push(L[122]);
}
throw $e10491050;
}
var $ret10551056 = $Hann_DASH_check_DASH_temp9021060($z10511052);
++R.GAS;
return $ret10551056;
};
var $Hann_DASH_check_DASH_temp9021060 = function(ann_DASH_check_DASH_temp5021059) {
return ann_DASH_check_DASH_temp5021059;
};
var $Hexprs9011061 = function(exprs2671062,N512,anf_DASH_name_DASH_rec82135,anf_DASH_variants2301063,data_DASH_name_DASH_t2221064,data_DASH_name2211065,k160138,l2201066,map238140,shared2261067,variants2251068) {
var anf_arg4951079 = R.makeFunction(function(ts2681082) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[124],1,arguments);
}
var anf_arg4891093 = R.makeFunction(function(f2701096,t2711097) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[126],2,arguments);
}
var anf_fun4851108 = G(N512,"a-field",L[130]);
var anf_arg4861109 = G(f2701096,"l",L[129]);
var anf_bracket4871113 = G(f2701096,"name",L[128]);
var anf_arg4881110 = G(anf_bracket4871113,"s",L[127]);
var $z11001101 = D;
var $f11061107 = function(_) {
return R.isFunction(anf_fun4851108)?anf_fun4851108.app(anf_arg4861109,anf_arg4881110,t2711097):R.ffi.throwNonFunApp(L[126],anf_fun4851108,[anf_arg4861109,anf_arg4881110,t2711097]);
};
try {
if(--R.GAS > 0) {
$z11001101 = $f11061107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11061107,
"from":L[126]});
}
} catch($e10981099) {
if(R.isCont($e10981099)) {
var $ss11021103 = {"from":L[126],
"go":function(ann_DASH_check_DASH_temp4841111) {
return $Hann_DASH_check_DASH_temp8951112(ann_DASH_check_DASH_temp4841111);
}};
$e10981099.stack[R.EXN_STACKHEIGHT++] = $ss11021103;
}
if(R.isPyretException($e10981099)) {
$e10981099.pyretStack.push(L[126]);
}
throw $e10981099;
}
var $ret11041105 = $Hann_DASH_check_DASH_temp8951112($z11001101);
++R.GAS;
return $ret11041105;
});
var $z10851086 = D;
var $f10911092 = function(_) {
return R.isFunction(map238140)?map238140.app(anf_arg4891093,shared2261067,ts2681082):R.ffi.throwNonFunApp(L[125],map238140,[anf_arg4891093,shared2261067,ts2681082]);
};
try {
if(--R.GAS > 0) {
$z10851086 = $f10911092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10911092,
"from":L[125]});
}
} catch($e10831084) {
if(R.isCont($e10831084)) {
var $ss10871088 = {"from":L[125],
"go":function(new_DASH_shared2691094) {
return $Hnew_DASH_shared8991095(new_DASH_shared2691094,N512,anf_DASH_variants2301063,data_DASH_name_DASH_t2221064,data_DASH_name2211065,k160138,l2201066,variants2251068);
}};
$e10831084.stack[R.EXN_STACKHEIGHT++] = $ss10871088;
}
if(R.isPyretException($e10831084)) {
$e10831084.pyretStack.push(L[125]);
}
throw $e10831084;
}
var $ret10891090 = $Hnew_DASH_shared8991095($z10851086,N512,anf_DASH_variants2301063,data_DASH_name_DASH_t2221064,data_DASH_name2211065,k160138,l2201066,variants2251068);
++R.GAS;
return $ret10891090;
});
var $z10711072 = D;
var $f10771078 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(exprs2671062,("anf_shared"),anf_arg4951079):R.ffi.throwNonFunApp(L[123],anf_DASH_name_DASH_rec82135.$var,[exprs2671062,("anf_shared"),anf_arg4951079]);
};
try {
if(--R.GAS > 0) {
$z10711072 = $f10771078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10771078,
"from":L[123]});
}
} catch($e10691070) {
if(R.isCont($e10691070)) {
var $ss10731074 = {"from":L[123],
"go":function(ann_DASH_check_DASH_temp3961080) {
return $Hann_DASH_check_DASH_temp9001081(ann_DASH_check_DASH_temp3961080);
}};
$e10691070.stack[R.EXN_STACKHEIGHT++] = $ss10731074;
}
if(R.isPyretException($e10691070)) {
$e10691070.pyretStack.push(L[123]);
}
throw $e10691070;
}
var $ret10751076 = $Hann_DASH_check_DASH_temp9001081($z10711072);
++R.GAS;
return $ret10751076;
};
var $Hann_DASH_check_DASH_temp9001081 = function(ann_DASH_check_DASH_temp3961080) {
return ann_DASH_check_DASH_temp3961080;
};
var $Hnew_DASH_shared8991095 = function(new_DASH_shared2691094,N512,anf_DASH_variants2301063,data_DASH_name_DASH_t2221064,data_DASH_name2211065,k160138,l2201066,variants2251068) {
var anf_arg4941124 = R.makeFunction(function(new_DASH_variants2721127) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[131],1,arguments);
}
var anf_fun4911140 = G(k160138,"apply",L[134]);
var anf_fun4921138 = G(N512,"a-data-expr",L[133]);
var $z11301131 = D;
var $f11361137 = function(_) {
return R.isFunction(anf_fun4921138)?anf_fun4921138.app(l2201066,data_DASH_name2211065,data_DASH_name_DASH_t2221064,new_DASH_variants2721127,new_DASH_shared2691094):R.ffi.throwNonFunApp(L[132],anf_fun4921138,[l2201066,data_DASH_name2211065,data_DASH_name_DASH_t2221064,new_DASH_variants2721127,new_DASH_shared2691094]);
};
try {
if(--R.GAS > 0) {
$z11301131 = $f11361137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11361137,
"from":L[132]});
}
} catch($e11281129) {
if(R.isCont($e11281129)) {
var $ss11321133 = {"from":L[132],
"go":function(anf_arg4931139) {
return $Hanf_arg8971141(anf_arg4931139,anf_fun4911140,l2201066);
}};
$e11281129.stack[R.EXN_STACKHEIGHT++] = $ss11321133;
}
if(R.isPyretException($e11281129)) {
$e11281129.pyretStack.push(L[132]);
}
throw $e11281129;
}
var $ret11341135 = $Hanf_arg8971141($z11301131,anf_fun4911140,l2201066);
++R.GAS;
return $ret11341135;
});
var $z11161117 = D;
var $f11221123 = function(_) {
return R.isFunction(anf_DASH_variants2301063.$var)?anf_DASH_variants2301063.$var.app(variants2251068,anf_arg4941124):R.ffi.throwNonFunApp(L[124],anf_DASH_variants2301063.$var,[variants2251068,anf_arg4941124]);
};
try {
if(--R.GAS > 0) {
$z11161117 = $f11221123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11221123,
"from":L[124]});
}
} catch($e11141115) {
if(R.isCont($e11141115)) {
var $ss11181119 = {"from":L[124],
"go":function(ann_DASH_check_DASH_temp4831125) {
return $Hann_DASH_check_DASH_temp8981126(ann_DASH_check_DASH_temp4831125);
}};
$e11141115.stack[R.EXN_STACKHEIGHT++] = $ss11181119;
}
if(R.isPyretException($e11141115)) {
$e11141115.pyretStack.push(L[124]);
}
throw $e11141115;
}
var $ret11201121 = $Hann_DASH_check_DASH_temp8981126($z11161117);
++R.GAS;
return $ret11201121;
};
var $Hann_DASH_check_DASH_temp8981126 = function(ann_DASH_check_DASH_temp4831125) {
return ann_DASH_check_DASH_temp4831125;
};
var $Hanf_arg8971141 = function(anf_arg4931139,anf_fun4911140,l2201066) {
var $z11441145 = D;
var $f11501151 = function(_) {
return R.isFunction(anf_fun4911140)?anf_fun4911140.app(l2201066,anf_arg4931139):R.ffi.throwNonFunApp(L[131],anf_fun4911140,[l2201066,anf_arg4931139]);
};
try {
if(--R.GAS > 0) {
$z11441145 = $f11501151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11501151,
"from":L[131]});
}
} catch($e11421143) {
if(R.isCont($e11421143)) {
var $ss11461147 = {"from":L[131],
"go":function(ann_DASH_check_DASH_temp4901152) {
return $Hann_DASH_check_DASH_temp8961153(ann_DASH_check_DASH_temp4901152);
}};
$e11421143.stack[R.EXN_STACKHEIGHT++] = $ss11461147;
}
if(R.isPyretException($e11421143)) {
$e11421143.pyretStack.push(L[131]);
}
throw $e11421143;
}
var $ret11481149 = $Hann_DASH_check_DASH_temp8961153($z11441145);
++R.GAS;
return $ret11481149;
};
var $Hann_DASH_check_DASH_temp8961153 = function(ann_DASH_check_DASH_temp4901152) {
return ann_DASH_check_DASH_temp4901152;
};
var $Hann_DASH_check_DASH_temp8951112 = function(ann_DASH_check_DASH_temp4841111) {
return ann_DASH_check_DASH_temp4841111;
};
var $Hann_DASH_check_DASH_temp8941154 = function(ann_DASH_check_DASH_temp4611155) {
return ann_DASH_check_DASH_temp4611155;
};
var $Hann_DASH_check_DASH_temp8931156 = function(ann_DASH_check_DASH_temp4671157) {
return ann_DASH_check_DASH_temp4671157;
};
var $Hann_DASH_check_DASH_temp8921158 = function(ann_DASH_check_DASH_temp4681159) {
return ann_DASH_check_DASH_temp4681159;
};
var $Hanf_arg8911160 = function(anf_arg4711161,ks2621162,rest_DASH_vs2661163,_plus4) {
var $z11661167 = D;
var $f11721173 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg4711161,rest_DASH_vs2661163):R.ffi.throwNonFunApp(L[135],_plus4,[anf_arg4711161,rest_DASH_vs2661163]);
};
try {
if(--R.GAS > 0) {
$z11661167 = $f11721173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11721173,
"from":L[135]});
}
} catch($e11641165) {
if(R.isCont($e11641165)) {
var $ss11681169 = {"from":L[135],
"go":function(anf_arg4721174) {
return $Hanf_arg8901175(anf_arg4721174,ks2621162);
}};
$e11641165.stack[R.EXN_STACKHEIGHT++] = $ss11681169;
}
if(R.isPyretException($e11641165)) {
$e11641165.pyretStack.push(L[135]);
}
throw $e11641165;
}
var $ret11701171 = $Hanf_arg8901175($z11661167,ks2621162);
++R.GAS;
return $ret11701171;
};
var $Hanf_arg8901175 = function(anf_arg4721174,ks2621162) {
var $z11781179 = D;
var $f11841185 = function(_) {
return R.isFunction(ks2621162)?ks2621162.app(anf_arg4721174):R.ffi.throwNonFunApp(L[136],ks2621162,[anf_arg4721174]);
};
try {
if(--R.GAS > 0) {
$z11781179 = $f11841185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11841185,
"from":L[136]});
}
} catch($e11761177) {
if(R.isCont($e11761177)) {
var $ss11801181 = {"from":L[136],
"go":function(ann_DASH_check_DASH_temp4691186) {
return $Hann_DASH_check_DASH_temp8891187(ann_DASH_check_DASH_temp4691186);
}};
$e11761177.stack[R.EXN_STACKHEIGHT++] = $ss11801181;
}
if(R.isPyretException($e11761177)) {
$e11761177.pyretStack.push(L[136]);
}
throw $e11761177;
}
var $ret11821183 = $Hann_DASH_check_DASH_temp8891187($z11781179);
++R.GAS;
return $ret11821183;
};
var $Hann_DASH_check_DASH_temp8891187 = function(ann_DASH_check_DASH_temp4691186) {
return ann_DASH_check_DASH_temp4691186;
};
var $Hanf_arg8881188 = function(anf_arg4651189,ks2621162) {
var $z11921193 = D;
var $f11981199 = function(_) {
return R.isFunction(ks2621162)?ks2621162.app(anf_arg4651189):R.ffi.throwNonFunApp(L[137],ks2621162,[anf_arg4651189]);
};
try {
if(--R.GAS > 0) {
$z11921193 = $f11981199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11981199,
"from":L[137]});
}
} catch($e11901191) {
if(R.isCont($e11901191)) {
var $ss11941195 = {"from":L[137],
"go":function(ann_DASH_check_DASH_temp4631200) {
return $Hann_DASH_check_DASH_temp8871201(ann_DASH_check_DASH_temp4631200);
}};
$e11901191.stack[R.EXN_STACKHEIGHT++] = $ss11941195;
}
if(R.isPyretException($e11901191)) {
$e11901191.pyretStack.push(L[137]);
}
throw $e11901191;
}
var $ret11961197 = $Hann_DASH_check_DASH_temp8871201($z11921193);
++R.GAS;
return $ret11961197;
};
var $Hann_DASH_check_DASH_temp8871201 = function(ann_DASH_check_DASH_temp4631200) {
return ann_DASH_check_DASH_temp4631200;
};
var $Hann_DASH_check_DASH_temp8861202 = function(ann_DASH_check_DASH_temp4231203) {
return ann_DASH_check_DASH_temp4231203;
};
var $Hwith_DASH_exprs8851204 = function(with_DASH_exprs2561205,N512,anf_DASH_name_DASH_rec82135,kv2421206,l22531207,map238140,vname2541208,with_DASH_members2551209) {
var anf_arg4551220 = R.makeFunction(function(ts2571223) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[139],1,arguments);
}
var anf_arg4521234 = R.makeFunction(function(f2591237,t2601238) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[141],2,arguments);
}
var anf_fun4481249 = G(N512,"a-field",L[145]);
var anf_arg4491250 = G(f2591237,"l",L[144]);
var anf_bracket4501254 = G(f2591237,"name",L[143]);
var anf_arg4511251 = G(anf_bracket4501254,"s",L[142]);
var $z12411242 = D;
var $f12471248 = function(_) {
return R.isFunction(anf_fun4481249)?anf_fun4481249.app(anf_arg4491250,anf_arg4511251,t2601238):R.ffi.throwNonFunApp(L[141],anf_fun4481249,[anf_arg4491250,anf_arg4511251,t2601238]);
};
try {
if(--R.GAS > 0) {
$z12411242 = $f12471248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12471248,
"from":L[141]});
}
} catch($e12391240) {
if(R.isCont($e12391240)) {
var $ss12431244 = {"from":L[141],
"go":function(ann_DASH_check_DASH_temp4471252) {
return $Hann_DASH_check_DASH_temp8801253(ann_DASH_check_DASH_temp4471252);
}};
$e12391240.stack[R.EXN_STACKHEIGHT++] = $ss12431244;
}
if(R.isPyretException($e12391240)) {
$e12391240.pyretStack.push(L[141]);
}
throw $e12391240;
}
var $ret12451246 = $Hann_DASH_check_DASH_temp8801253($z12411242);
++R.GAS;
return $ret12451246;
});
var $z12261227 = D;
var $f12321233 = function(_) {
return R.isFunction(map238140)?map238140.app(anf_arg4521234,with_DASH_members2551209,ts2571223):R.ffi.throwNonFunApp(L[140],map238140,[anf_arg4521234,with_DASH_members2551209,ts2571223]);
};
try {
if(--R.GAS > 0) {
$z12261227 = $f12321233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12321233,
"from":L[140]});
}
} catch($e12241225) {
if(R.isCont($e12241225)) {
var $ss12281229 = {"from":L[140],
"go":function(new_DASH_fields2581235) {
return $Hnew_DASH_fields8831236(new_DASH_fields2581235,N512,kv2421206,l22531207,vname2541208);
}};
$e12241225.stack[R.EXN_STACKHEIGHT++] = $ss12281229;
}
if(R.isPyretException($e12241225)) {
$e12241225.pyretStack.push(L[140]);
}
throw $e12241225;
}
var $ret12301231 = $Hnew_DASH_fields8831236($z12261227,N512,kv2421206,l22531207,vname2541208);
++R.GAS;
return $ret12301231;
});
var $z12121213 = D;
var $f12181219 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(with_DASH_exprs2561205,("anf_singleton_variant_member"),anf_arg4551220):R.ffi.throwNonFunApp(L[138],anf_DASH_name_DASH_rec82135.$var,[with_DASH_exprs2561205,("anf_singleton_variant_member"),anf_arg4551220]);
};
try {
if(--R.GAS > 0) {
$z12121213 = $f12181219();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12181219,
"from":L[138]});
}
} catch($e12101211) {
if(R.isCont($e12101211)) {
var $ss12141215 = {"from":L[138],
"go":function(ann_DASH_check_DASH_temp4421221) {
return $Hann_DASH_check_DASH_temp8841222(ann_DASH_check_DASH_temp4421221);
}};
$e12101211.stack[R.EXN_STACKHEIGHT++] = $ss12141215;
}
if(R.isPyretException($e12101211)) {
$e12101211.pyretStack.push(L[138]);
}
throw $e12101211;
}
var $ret12161217 = $Hann_DASH_check_DASH_temp8841222($z12121213);
++R.GAS;
return $ret12161217;
};
var $Hann_DASH_check_DASH_temp8841222 = function(ann_DASH_check_DASH_temp4421221) {
return ann_DASH_check_DASH_temp4421221;
};
var $Hnew_DASH_fields8831236 = function(new_DASH_fields2581235,N512,kv2421206,l22531207,vname2541208) {
var anf_fun4531265 = G(N512,"a-singleton-variant",L[147]);
var $z12571258 = D;
var $f12631264 = function(_) {
return R.isFunction(anf_fun4531265)?anf_fun4531265.app(l22531207,vname2541208,new_DASH_fields2581235):R.ffi.throwNonFunApp(L[146],anf_fun4531265,[l22531207,vname2541208,new_DASH_fields2581235]);
};
try {
if(--R.GAS > 0) {
$z12571258 = $f12631264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12631264,
"from":L[146]});
}
} catch($e12551256) {
if(R.isCont($e12551256)) {
var $ss12591260 = {"from":L[146],
"go":function(anf_arg4541266) {
return $Hanf_arg8821267(anf_arg4541266,kv2421206);
}};
$e12551256.stack[R.EXN_STACKHEIGHT++] = $ss12591260;
}
if(R.isPyretException($e12551256)) {
$e12551256.pyretStack.push(L[146]);
}
throw $e12551256;
}
var $ret12611262 = $Hanf_arg8821267($z12571258,kv2421206);
++R.GAS;
return $ret12611262;
};
var $Hanf_arg8821267 = function(anf_arg4541266,kv2421206) {
var $z12701271 = D;
var $f12761277 = function(_) {
return R.isFunction(kv2421206)?kv2421206.app(anf_arg4541266):R.ffi.throwNonFunApp(L[139],kv2421206,[anf_arg4541266]);
};
try {
if(--R.GAS > 0) {
$z12701271 = $f12761277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12761277,
"from":L[139]});
}
} catch($e12681269) {
if(R.isCont($e12681269)) {
var $ss12721273 = {"from":L[139],
"go":function(ann_DASH_check_DASH_temp4461278) {
return $Hann_DASH_check_DASH_temp8811279(ann_DASH_check_DASH_temp4461278);
}};
$e12681269.stack[R.EXN_STACKHEIGHT++] = $ss12721273;
}
if(R.isPyretException($e12681269)) {
$e12681269.pyretStack.push(L[139]);
}
throw $e12681269;
}
var $ret12741275 = $Hann_DASH_check_DASH_temp8811279($z12701271);
++R.GAS;
return $ret12741275;
};
var $Hann_DASH_check_DASH_temp8811279 = function(ann_DASH_check_DASH_temp4461278) {
return ann_DASH_check_DASH_temp4461278;
};
var $Hann_DASH_check_DASH_temp8801253 = function(ann_DASH_check_DASH_temp4471252) {
return ann_DASH_check_DASH_temp4471252;
};
var $Hwith_DASH_exprs8791280 = function(with_DASH_exprs2481281,N512,anf_DASH_member2281282,anf_DASH_name_DASH_rec82135,constr_DASH_loc2441283,kv2421206,l22431284,map238140,members2461285,vname2451286,with_DASH_members2471287) {
var anf_arg4401298 = R.makeFunction(function(ts2491301) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[149],1,arguments);
}
var anf_arg4351312 = R.makeFunction(function(f2511315,t2521316) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[151],2,arguments);
}
var anf_fun4311327 = G(N512,"a-field",L[155]);
var anf_arg4321328 = G(f2511315,"l",L[154]);
var anf_bracket4331332 = G(f2511315,"name",L[153]);
var anf_arg4341329 = G(anf_bracket4331332,"s",L[152]);
var $z13191320 = D;
var $f13251326 = function(_) {
return R.isFunction(anf_fun4311327)?anf_fun4311327.app(anf_arg4321328,anf_arg4341329,t2521316):R.ffi.throwNonFunApp(L[151],anf_fun4311327,[anf_arg4321328,anf_arg4341329,t2521316]);
};
try {
if(--R.GAS > 0) {
$z13191320 = $f13251326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13251326,
"from":L[151]});
}
} catch($e13171318) {
if(R.isCont($e13171318)) {
var $ss13211322 = {"from":L[151],
"go":function(ann_DASH_check_DASH_temp4301330) {
return $Hann_DASH_check_DASH_temp8731331(ann_DASH_check_DASH_temp4301330);
}};
$e13171318.stack[R.EXN_STACKHEIGHT++] = $ss13211322;
}
if(R.isPyretException($e13171318)) {
$e13171318.pyretStack.push(L[151]);
}
throw $e13171318;
}
var $ret13231324 = $Hann_DASH_check_DASH_temp8731331($z13191320);
++R.GAS;
return $ret13231324;
});
var $z13041305 = D;
var $f13101311 = function(_) {
return R.isFunction(map238140)?map238140.app(anf_arg4351312,with_DASH_members2471287,ts2491301):R.ffi.throwNonFunApp(L[150],map238140,[anf_arg4351312,with_DASH_members2471287,ts2491301]);
};
try {
if(--R.GAS > 0) {
$z13041305 = $f13101311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13101311,
"from":L[150]});
}
} catch($e13021303) {
if(R.isCont($e13021303)) {
var $ss13061307 = {"from":L[150],
"go":function(new_DASH_fields2501313) {
return $Hnew_DASH_fields8771314(new_DASH_fields2501313,N512,anf_DASH_member2281282,constr_DASH_loc2441283,kv2421206,l22431284,members2461285,vname2451286);
}};
$e13021303.stack[R.EXN_STACKHEIGHT++] = $ss13061307;
}
if(R.isPyretException($e13021303)) {
$e13021303.pyretStack.push(L[150]);
}
throw $e13021303;
}
var $ret13081309 = $Hnew_DASH_fields8771314($z13041305,N512,anf_DASH_member2281282,constr_DASH_loc2441283,kv2421206,l22431284,members2461285,vname2451286);
++R.GAS;
return $ret13081309;
});
var $z12901291 = D;
var $f12961297 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(with_DASH_exprs2481281,("anf_variant_member"),anf_arg4401298):R.ffi.throwNonFunApp(L[148],anf_DASH_name_DASH_rec82135.$var,[with_DASH_exprs2481281,("anf_variant_member"),anf_arg4401298]);
};
try {
if(--R.GAS > 0) {
$z12901291 = $f12961297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12961297,
"from":L[148]});
}
} catch($e12881289) {
if(R.isCont($e12881289)) {
var $ss12921293 = {"from":L[148],
"go":function(ann_DASH_check_DASH_temp4251299) {
return $Hann_DASH_check_DASH_temp8781300(ann_DASH_check_DASH_temp4251299);
}};
$e12881289.stack[R.EXN_STACKHEIGHT++] = $ss12921293;
}
if(R.isPyretException($e12881289)) {
$e12881289.pyretStack.push(L[148]);
}
throw $e12881289;
}
var $ret12941295 = $Hann_DASH_check_DASH_temp8781300($z12901291);
++R.GAS;
return $ret12941295;
};
var $Hann_DASH_check_DASH_temp8781300 = function(ann_DASH_check_DASH_temp4251299) {
return ann_DASH_check_DASH_temp4251299;
};
var $Hnew_DASH_fields8771314 = function(new_DASH_fields2501313,N512,anf_DASH_member2281282,constr_DASH_loc2441283,kv2421206,l22431284,members2461285,vname2451286) {
var anf_fun4361345 = G(N512,"a-variant",L[158]);
var anf_fun4371343 = G(members2461285,"map",L[157]);
var $z13351336 = D;
var $f13411342 = function(_) {
return R.isFunction(anf_fun4371343)?anf_fun4371343.app(anf_DASH_member2281282.$var):R.ffi.throwNonFunApp(L[156],anf_fun4371343,[anf_DASH_member2281282.$var]);
};
try {
if(--R.GAS > 0) {
$z13351336 = $f13411342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13411342,
"from":L[156]});
}
} catch($e13331334) {
if(R.isCont($e13331334)) {
var $ss13371338 = {"from":L[156],
"go":function(anf_arg4381344) {
return $Hanf_arg8761346(anf_arg4381344,anf_fun4361345,constr_DASH_loc2441283,kv2421206,l22431284,new_DASH_fields2501313,vname2451286);
}};
$e13331334.stack[R.EXN_STACKHEIGHT++] = $ss13371338;
}
if(R.isPyretException($e13331334)) {
$e13331334.pyretStack.push(L[156]);
}
throw $e13331334;
}
var $ret13391340 = $Hanf_arg8761346($z13351336,anf_fun4361345,constr_DASH_loc2441283,kv2421206,l22431284,new_DASH_fields2501313,vname2451286);
++R.GAS;
return $ret13391340;
};
var $Hanf_arg8761346 = function(anf_arg4381344,anf_fun4361345,constr_DASH_loc2441283,kv2421206,l22431284,new_DASH_fields2501313,vname2451286) {
var $z13491350 = D;
var $f13551356 = function(_) {
return R.isFunction(anf_fun4361345)?anf_fun4361345.app(l22431284,constr_DASH_loc2441283,vname2451286,anf_arg4381344,new_DASH_fields2501313):R.ffi.throwNonFunApp(L[159],anf_fun4361345,[l22431284,constr_DASH_loc2441283,vname2451286,anf_arg4381344,new_DASH_fields2501313]);
};
try {
if(--R.GAS > 0) {
$z13491350 = $f13551356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13551356,
"from":L[159]});
}
} catch($e13471348) {
if(R.isCont($e13471348)) {
var $ss13511352 = {"from":L[159],
"go":function(anf_arg4391357) {
return $Hanf_arg8751358(anf_arg4391357,kv2421206);
}};
$e13471348.stack[R.EXN_STACKHEIGHT++] = $ss13511352;
}
if(R.isPyretException($e13471348)) {
$e13471348.pyretStack.push(L[159]);
}
throw $e13471348;
}
var $ret13531354 = $Hanf_arg8751358($z13491350,kv2421206);
++R.GAS;
return $ret13531354;
};
var $Hanf_arg8751358 = function(anf_arg4391357,kv2421206) {
var $z13611362 = D;
var $f13671368 = function(_) {
return R.isFunction(kv2421206)?kv2421206.app(anf_arg4391357):R.ffi.throwNonFunApp(L[149],kv2421206,[anf_arg4391357]);
};
try {
if(--R.GAS > 0) {
$z13611362 = $f13671368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13671368,
"from":L[149]});
}
} catch($e13591360) {
if(R.isCont($e13591360)) {
var $ss13631364 = {"from":L[149],
"go":function(ann_DASH_check_DASH_temp4291369) {
return $Hann_DASH_check_DASH_temp8741370(ann_DASH_check_DASH_temp4291369);
}};
$e13591360.stack[R.EXN_STACKHEIGHT++] = $ss13631364;
}
if(R.isPyretException($e13591360)) {
$e13591360.pyretStack.push(L[149]);
}
throw $e13591360;
}
var $ret13651366 = $Hann_DASH_check_DASH_temp8741370($z13611362);
++R.GAS;
return $ret13651366;
};
var $Hann_DASH_check_DASH_temp8741370 = function(ann_DASH_check_DASH_temp4291369) {
return ann_DASH_check_DASH_temp4291369;
};
var $Hann_DASH_check_DASH_temp8731331 = function(ann_DASH_check_DASH_temp4301330) {
return ann_DASH_check_DASH_temp4301330;
};
var $Hann_DASH_check_DASH_temp8721371 = function(ann_DASH_check_DASH_temp3971372) {
return ann_DASH_check_DASH_temp3971372;
};
var $Ha_DASH_type8711373 = function(a_DASH_type2351374,N512,b2341375,l22321376) {
var cases_DASH_val301411 = b2341375;
var anf_fun4101387 = G(cases_DASH_val301411,"_match",L[161]);
var anf_obj4131393 = R.makeFunction(function(l32371394,shadows2381395,name2391396,ann2401397) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[162],4,arguments);
}
var anf_fun4121408 = G(N512,"a-bind",L[163]);
var $z14001401 = D;
var $f14061407 = function(_) {
return R.isFunction(anf_fun4121408)?anf_fun4121408.app(l32371394,name2391396,ann2401397):R.ffi.throwNonFunApp(L[162],anf_fun4121408,[l32371394,name2391396,ann2401397]);
};
try {
if(--R.GAS > 0) {
$z14001401 = $f14061407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14061407,
"from":L[162]});
}
} catch($e13981399) {
if(R.isCont($e13981399)) {
var $ss14021403 = {"from":L[162],
"go":function(ann_DASH_check_DASH_temp4111409) {
return $Hann_DASH_check_DASH_temp8681410(ann_DASH_check_DASH_temp4111409);
}};
$e13981399.stack[R.EXN_STACKHEIGHT++] = $ss14021403;
}
if(R.isPyretException($e13981399)) {
$e13981399.pyretStack.push(L[162]);
}
throw $e13981399;
}
var $ret14041405 = $Hann_DASH_check_DASH_temp8681410($z14001401);
++R.GAS;
return $ret14041405;
});
var anf_arg4141388 = R.makeObject({"s-bind":anf_obj4131393});
var anf_arg4161389 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[161],0,arguments);
}
var ann_DASH_check_DASH_temp4151392 = R.throwNoBranchesMatched(L[161],("cases"));
return ann_DASH_check_DASH_temp4151392;
});
var $z13791380 = D;
var $f13851386 = function(_) {
return R.isFunction(anf_fun4101387)?anf_fun4101387.app(anf_arg4141388,anf_arg4161389):R.ffi.throwNonFunApp(L[160],anf_fun4101387,[anf_arg4141388,anf_arg4161389]);
};
try {
if(--R.GAS > 0) {
$z13791380 = $f13851386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13851386,
"from":L[160]});
}
} catch($e13771378) {
if(R.isCont($e13771378)) {
var $ss13811382 = {"from":L[160],
"go":function(new_DASH_bind2361390) {
return $Hnew_DASH_bind8701391(new_DASH_bind2361390,N512,a_DASH_type2351374,l22321376);
}};
$e13771378.stack[R.EXN_STACKHEIGHT++] = $ss13811382;
}
if(R.isPyretException($e13771378)) {
$e13771378.pyretStack.push(L[160]);
}
throw $e13771378;
}
var $ret13831384 = $Hnew_DASH_bind8701391($z13791380,N512,a_DASH_type2351374,l22321376);
++R.GAS;
return $ret13831384;
};
var $Hnew_DASH_bind8701391 = function(new_DASH_bind2361390,N512,a_DASH_type2351374,l22321376) {
var anf_fun4171422 = G(N512,"a-variant-member",L[165]);
var $z14141415 = D;
var $f14201421 = function(_) {
return R.isFunction(anf_fun4171422)?anf_fun4171422.app(l22321376,a_DASH_type2351374,new_DASH_bind2361390):R.ffi.throwNonFunApp(L[164],anf_fun4171422,[l22321376,a_DASH_type2351374,new_DASH_bind2361390]);
};
try {
if(--R.GAS > 0) {
$z14141415 = $f14201421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14201421,
"from":L[164]});
}
} catch($e14121413) {
if(R.isCont($e14121413)) {
var $ss14161417 = {"from":L[164],
"go":function(ann_DASH_check_DASH_temp3991423) {
return $Hann_DASH_check_DASH_temp8691424(ann_DASH_check_DASH_temp3991423);
}};
$e14121413.stack[R.EXN_STACKHEIGHT++] = $ss14161417;
}
if(R.isPyretException($e14121413)) {
$e14121413.pyretStack.push(L[164]);
}
throw $e14121413;
}
var $ret14181419 = $Hann_DASH_check_DASH_temp8691424($z14141415);
++R.GAS;
return $ret14181419;
};
var $Hann_DASH_check_DASH_temp8691424 = function(ann_DASH_check_DASH_temp3991423) {
return ann_DASH_check_DASH_temp3991423;
};
var $Hann_DASH_check_DASH_temp8681410 = function(ann_DASH_check_DASH_temp4111409) {
return ann_DASH_check_DASH_temp4111409;
};
var $Hlet_DASH_binds8671425 = function(let_DASH_binds2161426,A110,anf86820,binds2141427,body2151428,k160138,l2131429,list25501,map371430,_plus4) {
var anf_arg3871441 = R.makeFunction(function(b2191444) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[167],1,arguments);
}
var anf_fun3821455 = G(A110,"s-assign",L[172]);
var anf_arg3831456 = G(b2191444,"l",L[171]);
var anf_bracket3841461 = G(b2191444,"b",L[170]);
var anf_arg3851457 = G(anf_bracket3841461,"id",L[169]);
var anf_arg3861458 = G(b2191444,"value",L[168]);
var $z14471448 = D;
var $f14531454 = function(_) {
return R.isFunction(anf_fun3821455)?anf_fun3821455.app(anf_arg3831456,anf_arg3851457,anf_arg3861458):R.ffi.throwNonFunApp(L[167],anf_fun3821455,[anf_arg3831456,anf_arg3851457,anf_arg3861458]);
};
try {
if(--R.GAS > 0) {
$z14471448 = $f14531454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14531454,
"from":L[167]});
}
} catch($e14451446) {
if(R.isCont($e14451446)) {
var $ss14491450 = {"from":L[167],
"go":function(ann_DASH_check_DASH_temp3811459) {
return $Hann_DASH_check_DASH_temp8601460(ann_DASH_check_DASH_temp3811459);
}};
$e14451446.stack[R.EXN_STACKHEIGHT++] = $ss14491450;
}
if(R.isPyretException($e14451446)) {
$e14451446.pyretStack.push(L[167]);
}
throw $e14451446;
}
var $ret14511452 = $Hann_DASH_check_DASH_temp8601460($z14471448);
++R.GAS;
return $ret14511452;
});
var $z14331434 = D;
var $f14391440 = function(_) {
return R.isFunction(map371430)?map371430.app(anf_arg3871441,binds2141427):R.ffi.throwNonFunApp(L[166],map371430,[anf_arg3871441,binds2141427]);
};
try {
if(--R.GAS > 0) {
$z14331434 = $f14391440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14391440,
"from":L[166]});
}
} catch($e14311432) {
if(R.isCont($e14311432)) {
var $ss14351436 = {"from":L[166],
"go":function(assigns2181442) {
return $Hassigns8661443(assigns2181442,A110,anf86820,body2151428,k160138,l2131429,let_DASH_binds2161426,list25501,_plus4);
}};
$e14311432.stack[R.EXN_STACKHEIGHT++] = $ss14351436;
}
if(R.isPyretException($e14311432)) {
$e14311432.pyretStack.push(L[166]);
}
throw $e14311432;
}
var $ret14371438 = $Hassigns8661443($z14331434,A110,anf86820,body2151428,k160138,l2131429,let_DASH_binds2161426,list25501,_plus4);
++R.GAS;
return $ret14371438;
};
var $Hassigns8661443 = function(assigns2181442,A110,anf86820,body2151428,k160138,l2131429,let_DASH_binds2161426,list25501,_plus4) {
var anf_fun3881474 = G(A110,"s-let-expr",L[175]);
var anf_fun3891475 = G(A110,"s-block",L[174]);
var anf_fun3901472 = G(list25501,"make",L[173]);
var $z14641465 = D;
var $f14701471 = function(_) {
return R.isFunction(anf_fun3901472)?anf_fun3901472.app([body2151428]):R.ffi.throwNonFunApp(L[173],anf_fun3901472,[[body2151428]]);
};
try {
if(--R.GAS > 0) {
$z14641465 = $f14701471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14701471,
"from":L[173]});
}
} catch($e14621463) {
if(R.isCont($e14621463)) {
var $ss14661467 = {"from":L[173],
"go":function(anf_arg3911473) {
return $Hanf_arg8651476(anf_arg3911473,anf86820,anf_fun3881474,anf_fun3891475,assigns2181442,k160138,l2131429,let_DASH_binds2161426,_plus4);
}};
$e14621463.stack[R.EXN_STACKHEIGHT++] = $ss14661467;
}
if(R.isPyretException($e14621463)) {
$e14621463.pyretStack.push(L[173]);
}
throw $e14621463;
}
var $ret14681469 = $Hanf_arg8651476($z14641465,anf86820,anf_fun3881474,anf_fun3891475,assigns2181442,k160138,l2131429,let_DASH_binds2161426,_plus4);
++R.GAS;
return $ret14681469;
};
var $Hanf_arg8651476 = function(anf_arg3911473,anf86820,anf_fun3881474,anf_fun3891475,assigns2181442,k160138,l2131429,let_DASH_binds2161426,_plus4) {
var $z14791480 = D;
var $f14851486 = function(_) {
return R.isFunction(_plus4)?_plus4.app(assigns2181442,anf_arg3911473):R.ffi.throwNonFunApp(L[176],_plus4,[assigns2181442,anf_arg3911473]);
};
try {
if(--R.GAS > 0) {
$z14791480 = $f14851486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14851486,
"from":L[176]});
}
} catch($e14771478) {
if(R.isCont($e14771478)) {
var $ss14811482 = {"from":L[176],
"go":function(anf_arg3921487) {
return $Hanf_arg8641488(anf_arg3921487,anf86820,anf_fun3881474,anf_fun3891475,k160138,l2131429,let_DASH_binds2161426);
}};
$e14771478.stack[R.EXN_STACKHEIGHT++] = $ss14811482;
}
if(R.isPyretException($e14771478)) {
$e14771478.pyretStack.push(L[176]);
}
throw $e14771478;
}
var $ret14831484 = $Hanf_arg8641488($z14791480,anf86820,anf_fun3881474,anf_fun3891475,k160138,l2131429,let_DASH_binds2161426);
++R.GAS;
return $ret14831484;
};
var $Hanf_arg8641488 = function(anf_arg3921487,anf86820,anf_fun3881474,anf_fun3891475,k160138,l2131429,let_DASH_binds2161426) {
var $z14911492 = D;
var $f14971498 = function(_) {
return R.isFunction(anf_fun3891475)?anf_fun3891475.app(l2131429,anf_arg3921487):R.ffi.throwNonFunApp(L[177],anf_fun3891475,[l2131429,anf_arg3921487]);
};
try {
if(--R.GAS > 0) {
$z14911492 = $f14971498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14971498,
"from":L[177]});
}
} catch($e14891490) {
if(R.isCont($e14891490)) {
var $ss14931494 = {"from":L[177],
"go":function(anf_arg3931499) {
return $Hanf_arg8631500(anf_arg3931499,anf86820,anf_fun3881474,k160138,l2131429,let_DASH_binds2161426);
}};
$e14891490.stack[R.EXN_STACKHEIGHT++] = $ss14931494;
}
if(R.isPyretException($e14891490)) {
$e14891490.pyretStack.push(L[177]);
}
throw $e14891490;
}
var $ret14951496 = $Hanf_arg8631500($z14911492,anf86820,anf_fun3881474,k160138,l2131429,let_DASH_binds2161426);
++R.GAS;
return $ret14951496;
};
var $Hanf_arg8631500 = function(anf_arg3931499,anf86820,anf_fun3881474,k160138,l2131429,let_DASH_binds2161426) {
var $z15031504 = D;
var $f15091510 = function(_) {
return R.isFunction(anf_fun3881474)?anf_fun3881474.app(l2131429,let_DASH_binds2161426,anf_arg3931499):R.ffi.throwNonFunApp(L[178],anf_fun3881474,[l2131429,let_DASH_binds2161426,anf_arg3931499]);
};
try {
if(--R.GAS > 0) {
$z15031504 = $f15091510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15091510,
"from":L[178]});
}
} catch($e15011502) {
if(R.isCont($e15011502)) {
var $ss15051506 = {"from":L[178],
"go":function(anf_arg3941511) {
return $Hanf_arg8621512(anf_arg3941511,anf86820,k160138);
}};
$e15011502.stack[R.EXN_STACKHEIGHT++] = $ss15051506;
}
if(R.isPyretException($e15011502)) {
$e15011502.pyretStack.push(L[178]);
}
throw $e15011502;
}
var $ret15071508 = $Hanf_arg8621512($z15031504,anf86820,k160138);
++R.GAS;
return $ret15071508;
};
var $Hanf_arg8621512 = function(anf_arg3941511,anf86820,k160138) {
var $z15151516 = D;
var $f15211522 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(anf_arg3941511,k160138):R.ffi.throwNonFunApp(L[179],anf86820.$var,[anf_arg3941511,k160138]);
};
try {
if(--R.GAS > 0) {
$z15151516 = $f15211522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15211522,
"from":L[179]});
}
} catch($e15131514) {
if(R.isCont($e15131514)) {
var $ss15171518 = {"from":L[179],
"go":function(ann_DASH_check_DASH_temp3731523) {
return $Hann_DASH_check_DASH_temp8611524(ann_DASH_check_DASH_temp3731523);
}};
$e15131514.stack[R.EXN_STACKHEIGHT++] = $ss15171518;
}
if(R.isPyretException($e15131514)) {
$e15131514.pyretStack.push(L[179]);
}
throw $e15131514;
}
var $ret15191520 = $Hann_DASH_check_DASH_temp8611524($z15151516);
++R.GAS;
return $ret15191520;
};
var $Hann_DASH_check_DASH_temp8611524 = function(ann_DASH_check_DASH_temp3731523) {
return ann_DASH_check_DASH_temp3731523;
};
var $Hann_DASH_check_DASH_temp8601460 = function(ann_DASH_check_DASH_temp3811459) {
return ann_DASH_check_DASH_temp3811459;
};
var $Hanf_arg8591525 = function(anf_arg3791526,anf_arg3761527,anf_arg3771528,anf_fun3751529) {
var $z15321533 = D;
var $f15381539 = function(_) {
return R.isFunction(anf_fun3751529)?anf_fun3751529.app(anf_arg3761527,anf_arg3771528,anf_arg3791526):R.ffi.throwNonFunApp(L[180],anf_fun3751529,[anf_arg3761527,anf_arg3771528,anf_arg3791526]);
};
try {
if(--R.GAS > 0) {
$z15321533 = $f15381539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15381539,
"from":L[180]});
}
} catch($e15301531) {
if(R.isCont($e15301531)) {
var $ss15341535 = {"from":L[180],
"go":function(ann_DASH_check_DASH_temp3741540) {
return $Hann_DASH_check_DASH_temp8581541(ann_DASH_check_DASH_temp3741540);
}};
$e15301531.stack[R.EXN_STACKHEIGHT++] = $ss15341535;
}
if(R.isPyretException($e15301531)) {
$e15301531.pyretStack.push(L[180]);
}
throw $e15301531;
}
var $ret15361537 = $Hann_DASH_check_DASH_temp8581541($z15321533);
++R.GAS;
return $ret15361537;
};
var $Hann_DASH_check_DASH_temp8581541 = function(ann_DASH_check_DASH_temp3741540) {
return ann_DASH_check_DASH_temp3741540;
};
var $Hann_DASH_check_DASH_temp8571542 = function(ann_DASH_check_DASH_temp3331543) {
return ann_DASH_check_DASH_temp3331543;
};
var $Hann_DASH_check_DASH_temp8561544 = function(ann_DASH_check_DASH_temp3371545) {
return ann_DASH_check_DASH_temp3371545;
};
var $Hanf_arg8551546 = function(anf_arg3631547,anf86820,val2111548) {
var $z15511552 = D;
var $f15571558 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(val2111548,anf_arg3631547):R.ffi.throwNonFunApp(L[181],anf86820.$var,[val2111548,anf_arg3631547]);
};
try {
if(--R.GAS > 0) {
$z15511552 = $f15571558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15571558,
"from":L[181]});
}
} catch($e15491550) {
if(R.isCont($e15491550)) {
var $ss15531554 = {"from":L[181],
"go":function(ann_DASH_check_DASH_temp3521559) {
return $Hann_DASH_check_DASH_temp8541560(ann_DASH_check_DASH_temp3521559);
}};
$e15491550.stack[R.EXN_STACKHEIGHT++] = $ss15531554;
}
if(R.isPyretException($e15491550)) {
$e15491550.pyretStack.push(L[181]);
}
throw $e15491550;
}
var $ret15551556 = $Hann_DASH_check_DASH_temp8541560($z15511552);
++R.GAS;
return $ret15551556;
};
var $Hann_DASH_check_DASH_temp8541560 = function(ann_DASH_check_DASH_temp3521559) {
return ann_DASH_check_DASH_temp3521559;
};
var $Hanf_arg8531561 = function(anf_arg3581562,A110,anf86820,anf_fun3541563,body2021564,k160138,l2001565,l22091566,lettable2121567,r2041568) {
var anf_fun3591579 = G(A110,"s-let-expr",L[183]);
var $z15711572 = D;
var $f15771578 = function(_) {
return R.isFunction(anf_fun3591579)?anf_fun3591579.app(l2001565,r2041568,body2021564):R.ffi.throwNonFunApp(L[182],anf_fun3591579,[l2001565,r2041568,body2021564]);
};
try {
if(--R.GAS > 0) {
$z15711572 = $f15771578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15771578,
"from":L[182]});
}
} catch($e15691570) {
if(R.isCont($e15691570)) {
var $ss15731574 = {"from":L[182],
"go":function(anf_arg3601580) {
return $Hanf_arg8521581(anf_arg3601580,anf86820,anf_arg3581562,anf_fun3541563,k160138,l22091566,lettable2121567);
}};
$e15691570.stack[R.EXN_STACKHEIGHT++] = $ss15731574;
}
if(R.isPyretException($e15691570)) {
$e15691570.pyretStack.push(L[182]);
}
throw $e15691570;
}
var $ret15751576 = $Hanf_arg8521581($z15711572,anf86820,anf_arg3581562,anf_fun3541563,k160138,l22091566,lettable2121567);
++R.GAS;
return $ret15751576;
};
var $Hanf_arg8521581 = function(anf_arg3601580,anf86820,anf_arg3581562,anf_fun3541563,k160138,l22091566,lettable2121567) {
var $z15841585 = D;
var $f15901591 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(anf_arg3601580,k160138):R.ffi.throwNonFunApp(L[184],anf86820.$var,[anf_arg3601580,k160138]);
};
try {
if(--R.GAS > 0) {
$z15841585 = $f15901591();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15901591,
"from":L[184]});
}
} catch($e15821583) {
if(R.isCont($e15821583)) {
var $ss15861587 = {"from":L[184],
"go":function(anf_arg3611592) {
return $Hanf_arg8511593(anf_arg3611592,anf_arg3581562,anf_fun3541563,l22091566,lettable2121567);
}};
$e15821583.stack[R.EXN_STACKHEIGHT++] = $ss15861587;
}
if(R.isPyretException($e15821583)) {
$e15821583.pyretStack.push(L[184]);
}
throw $e15821583;
}
var $ret15881589 = $Hanf_arg8511593($z15841585,anf_arg3581562,anf_fun3541563,l22091566,lettable2121567);
++R.GAS;
return $ret15881589;
};
var $Hanf_arg8511593 = function(anf_arg3611592,anf_arg3581562,anf_fun3541563,l22091566,lettable2121567) {
var $z15961597 = D;
var $f16021603 = function(_) {
return R.isFunction(anf_fun3541563)?anf_fun3541563.app(l22091566,anf_arg3581562,lettable2121567,anf_arg3611592):R.ffi.throwNonFunApp(L[185],anf_fun3541563,[l22091566,anf_arg3581562,lettable2121567,anf_arg3611592]);
};
try {
if(--R.GAS > 0) {
$z15961597 = $f16021603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16021603,
"from":L[185]});
}
} catch($e15941595) {
if(R.isCont($e15941595)) {
var $ss15981599 = {"from":L[185],
"go":function(ann_DASH_check_DASH_temp3531604) {
return $Hann_DASH_check_DASH_temp8501605(ann_DASH_check_DASH_temp3531604);
}};
$e15941595.stack[R.EXN_STACKHEIGHT++] = $ss15981599;
}
if(R.isPyretException($e15941595)) {
$e15941595.pyretStack.push(L[185]);
}
throw $e15941595;
}
var $ret16001601 = $Hann_DASH_check_DASH_temp8501605($z15961597);
++R.GAS;
return $ret16001601;
};
var $Hann_DASH_check_DASH_temp8501605 = function(ann_DASH_check_DASH_temp3531604) {
return ann_DASH_check_DASH_temp3531604;
};
var $Hanf_arg8491606 = function(anf_arg3501607,anf86820,val2071608) {
var $z16111612 = D;
var $f16171618 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(val2071608,anf_arg3501607):R.ffi.throwNonFunApp(L[186],anf86820.$var,[val2071608,anf_arg3501607]);
};
try {
if(--R.GAS > 0) {
$z16111612 = $f16171618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16171618,
"from":L[186]});
}
} catch($e16091610) {
if(R.isCont($e16091610)) {
var $ss16131614 = {"from":L[186],
"go":function(ann_DASH_check_DASH_temp3391619) {
return $Hann_DASH_check_DASH_temp8481620(ann_DASH_check_DASH_temp3391619);
}};
$e16091610.stack[R.EXN_STACKHEIGHT++] = $ss16131614;
}
if(R.isPyretException($e16091610)) {
$e16091610.pyretStack.push(L[186]);
}
throw $e16091610;
}
var $ret16151616 = $Hann_DASH_check_DASH_temp8481620($z16111612);
++R.GAS;
return $ret16151616;
};
var $Hann_DASH_check_DASH_temp8481620 = function(ann_DASH_check_DASH_temp3391619) {
return ann_DASH_check_DASH_temp3391619;
};
var $Hanf_arg8471621 = function(anf_arg3451622,A110,anf86820,anf_fun3411623,body2021564,k160138,l2001565,l22051624,lettable2081625,r2041568) {
var anf_fun3461636 = G(A110,"s-let-expr",L[188]);
var $z16281629 = D;
var $f16341635 = function(_) {
return R.isFunction(anf_fun3461636)?anf_fun3461636.app(l2001565,r2041568,body2021564):R.ffi.throwNonFunApp(L[187],anf_fun3461636,[l2001565,r2041568,body2021564]);
};
try {
if(--R.GAS > 0) {
$z16281629 = $f16341635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16341635,
"from":L[187]});
}
} catch($e16261627) {
if(R.isCont($e16261627)) {
var $ss16301631 = {"from":L[187],
"go":function(anf_arg3471637) {
return $Hanf_arg8461638(anf_arg3471637,anf86820,anf_arg3451622,anf_fun3411623,k160138,l22051624,lettable2081625);
}};
$e16261627.stack[R.EXN_STACKHEIGHT++] = $ss16301631;
}
if(R.isPyretException($e16261627)) {
$e16261627.pyretStack.push(L[187]);
}
throw $e16261627;
}
var $ret16321633 = $Hanf_arg8461638($z16281629,anf86820,anf_arg3451622,anf_fun3411623,k160138,l22051624,lettable2081625);
++R.GAS;
return $ret16321633;
};
var $Hanf_arg8461638 = function(anf_arg3471637,anf86820,anf_arg3451622,anf_fun3411623,k160138,l22051624,lettable2081625) {
var $z16411642 = D;
var $f16471648 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(anf_arg3471637,k160138):R.ffi.throwNonFunApp(L[189],anf86820.$var,[anf_arg3471637,k160138]);
};
try {
if(--R.GAS > 0) {
$z16411642 = $f16471648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16471648,
"from":L[189]});
}
} catch($e16391640) {
if(R.isCont($e16391640)) {
var $ss16431644 = {"from":L[189],
"go":function(anf_arg3481649) {
return $Hanf_arg8451650(anf_arg3481649,anf_arg3451622,anf_fun3411623,l22051624,lettable2081625);
}};
$e16391640.stack[R.EXN_STACKHEIGHT++] = $ss16431644;
}
if(R.isPyretException($e16391640)) {
$e16391640.pyretStack.push(L[189]);
}
throw $e16391640;
}
var $ret16451646 = $Hanf_arg8451650($z16411642,anf_arg3451622,anf_fun3411623,l22051624,lettable2081625);
++R.GAS;
return $ret16451646;
};
var $Hanf_arg8451650 = function(anf_arg3481649,anf_arg3451622,anf_fun3411623,l22051624,lettable2081625) {
var $z16531654 = D;
var $f16591660 = function(_) {
return R.isFunction(anf_fun3411623)?anf_fun3411623.app(l22051624,anf_arg3451622,lettable2081625,anf_arg3481649):R.ffi.throwNonFunApp(L[190],anf_fun3411623,[l22051624,anf_arg3451622,lettable2081625,anf_arg3481649]);
};
try {
if(--R.GAS > 0) {
$z16531654 = $f16591660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16591660,
"from":L[190]});
}
} catch($e16511652) {
if(R.isCont($e16511652)) {
var $ss16551656 = {"from":L[190],
"go":function(ann_DASH_check_DASH_temp3401661) {
return $Hann_DASH_check_DASH_temp8441662(ann_DASH_check_DASH_temp3401661);
}};
$e16511652.stack[R.EXN_STACKHEIGHT++] = $ss16551656;
}
if(R.isPyretException($e16511652)) {
$e16511652.pyretStack.push(L[190]);
}
throw $e16511652;
}
var $ret16571658 = $Hann_DASH_check_DASH_temp8441662($z16531654);
++R.GAS;
return $ret16571658;
};
var $Hann_DASH_check_DASH_temp8441662 = function(ann_DASH_check_DASH_temp3401661) {
return ann_DASH_check_DASH_temp3401661;
};
var $Hann_DASH_check_DASH_temp8431663 = function(ann_DASH_check_DASH_temp3351664) {
return ann_DASH_check_DASH_temp3351664;
};
var $Hann_DASH_check_DASH_temp8421665 = function(ann_DASH_check_DASH_temp3091666) {
return ann_DASH_check_DASH_temp3091666;
};
var $Hnew_DASH_bind8411667 = function(new_DASH_bind1931668,A110,N512,anf86820,body1901669,k160138,l1881670,r1921671) {
var anf_fun3241684 = G(N512,"a-type-let",L[193]);
var anf_fun3251682 = G(A110,"s-type-let-expr",L[192]);
var $z16741675 = D;
var $f16801681 = function(_) {
return R.isFunction(anf_fun3251682)?anf_fun3251682.app(l1881670,r1921671,body1901669):R.ffi.throwNonFunApp(L[191],anf_fun3251682,[l1881670,r1921671,body1901669]);
};
try {
if(--R.GAS > 0) {
$z16741675 = $f16801681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16801681,
"from":L[191]});
}
} catch($e16721673) {
if(R.isCont($e16721673)) {
var $ss16761677 = {"from":L[191],
"go":function(anf_arg3261683) {
return $Hanf_arg8401685(anf_arg3261683,anf86820,anf_fun3241684,k160138,l1881670,new_DASH_bind1931668);
}};
$e16721673.stack[R.EXN_STACKHEIGHT++] = $ss16761677;
}
if(R.isPyretException($e16721673)) {
$e16721673.pyretStack.push(L[191]);
}
throw $e16721673;
}
var $ret16781679 = $Hanf_arg8401685($z16741675,anf86820,anf_fun3241684,k160138,l1881670,new_DASH_bind1931668);
++R.GAS;
return $ret16781679;
};
var $Hanf_arg8401685 = function(anf_arg3261683,anf86820,anf_fun3241684,k160138,l1881670,new_DASH_bind1931668) {
var $z16881689 = D;
var $f16941695 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(anf_arg3261683,k160138):R.ffi.throwNonFunApp(L[194],anf86820.$var,[anf_arg3261683,k160138]);
};
try {
if(--R.GAS > 0) {
$z16881689 = $f16941695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16941695,
"from":L[194]});
}
} catch($e16861687) {
if(R.isCont($e16861687)) {
var $ss16901691 = {"from":L[194],
"go":function(anf_arg3271696) {
return $Hanf_arg8391697(anf_arg3271696,anf_fun3241684,l1881670,new_DASH_bind1931668);
}};
$e16861687.stack[R.EXN_STACKHEIGHT++] = $ss16901691;
}
if(R.isPyretException($e16861687)) {
$e16861687.pyretStack.push(L[194]);
}
throw $e16861687;
}
var $ret16921693 = $Hanf_arg8391697($z16881689,anf_fun3241684,l1881670,new_DASH_bind1931668);
++R.GAS;
return $ret16921693;
};
var $Hanf_arg8391697 = function(anf_arg3271696,anf_fun3241684,l1881670,new_DASH_bind1931668) {
var $z17001701 = D;
var $f17061707 = function(_) {
return R.isFunction(anf_fun3241684)?anf_fun3241684.app(l1881670,new_DASH_bind1931668,anf_arg3271696):R.ffi.throwNonFunApp(L[195],anf_fun3241684,[l1881670,new_DASH_bind1931668,anf_arg3271696]);
};
try {
if(--R.GAS > 0) {
$z17001701 = $f17061707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17061707,
"from":L[195]});
}
} catch($e16981699) {
if(R.isCont($e16981699)) {
var $ss17021703 = {"from":L[195],
"go":function(ann_DASH_check_DASH_temp3131708) {
return $Hann_DASH_check_DASH_temp8381709(ann_DASH_check_DASH_temp3131708);
}};
$e16981699.stack[R.EXN_STACKHEIGHT++] = $ss17021703;
}
if(R.isPyretException($e16981699)) {
$e16981699.pyretStack.push(L[195]);
}
throw $e16981699;
}
var $ret17041705 = $Hann_DASH_check_DASH_temp8381709($z17001701);
++R.GAS;
return $ret17041705;
};
var $Hann_DASH_check_DASH_temp8381709 = function(ann_DASH_check_DASH_temp3131708) {
return ann_DASH_check_DASH_temp3131708;
};
var $Hann_DASH_check_DASH_temp8371710 = function(ann_DASH_check_DASH_temp3181711) {
return ann_DASH_check_DASH_temp3181711;
};
var $Hann_DASH_check_DASH_temp8361712 = function(ann_DASH_check_DASH_temp3151713) {
return ann_DASH_check_DASH_temp3151713;
};
var $Hann_DASH_check_DASH_temp8351714 = function(ann_DASH_check_DASH_temp3111715) {
return ann_DASH_check_DASH_temp3111715;
};
var $Hanf_arg8341716 = function(anf_arg3061717,anf_fun3031718,anf_fun3041719,l1861720) {
var $z17231724 = D;
var $f17291730 = function(_) {
return R.isFunction(anf_fun3041719)?anf_fun3041719.app(anf_arg3061717):R.ffi.throwNonFunApp(L[196],anf_fun3041719,[anf_arg3061717]);
};
try {
if(--R.GAS > 0) {
$z17231724 = $f17291730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17291730,
"from":L[196]});
}
} catch($e17211722) {
if(R.isCont($e17211722)) {
var $ss17251726 = {"from":L[196],
"go":function(anf_arg3071731) {
return $Hanf_arg8331732(anf_arg3071731,anf_fun3031718,l1861720);
}};
$e17211722.stack[R.EXN_STACKHEIGHT++] = $ss17251726;
}
if(R.isPyretException($e17211722)) {
$e17211722.pyretStack.push(L[196]);
}
throw $e17211722;
}
var $ret17271728 = $Hanf_arg8331732($z17231724,anf_fun3031718,l1861720);
++R.GAS;
return $ret17271728;
};
var $Hanf_arg8331732 = function(anf_arg3071731,anf_fun3031718,l1861720) {
var $z17351736 = D;
var $f17411742 = function(_) {
return R.isFunction(anf_fun3031718)?anf_fun3031718.app(l1861720,anf_arg3071731):R.ffi.throwNonFunApp(L[197],anf_fun3031718,[l1861720,anf_arg3071731]);
};
try {
if(--R.GAS > 0) {
$z17351736 = $f17411742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17411742,
"from":L[197]});
}
} catch($e17331734) {
if(R.isCont($e17331734)) {
var $ss17371738 = {"from":L[197],
"go":function(ann_DASH_check_DASH_temp3021743) {
return $Hann_DASH_check_DASH_temp8321744(ann_DASH_check_DASH_temp3021743);
}};
$e17331734.stack[R.EXN_STACKHEIGHT++] = $ss17371738;
}
if(R.isPyretException($e17331734)) {
$e17331734.pyretStack.push(L[197]);
}
throw $e17331734;
}
var $ret17391740 = $Hann_DASH_check_DASH_temp8321744($z17351736);
++R.GAS;
return $ret17391740;
};
var $Hann_DASH_check_DASH_temp8321744 = function(ann_DASH_check_DASH_temp3021743) {
return ann_DASH_check_DASH_temp3021743;
};
var $Hanf_arg8311745 = function(anf_arg2991746,anf_fun2961747,anf_fun2971748,l1831749) {
var $z17521753 = D;
var $f17581759 = function(_) {
return R.isFunction(anf_fun2971748)?anf_fun2971748.app(anf_arg2991746):R.ffi.throwNonFunApp(L[198],anf_fun2971748,[anf_arg2991746]);
};
try {
if(--R.GAS > 0) {
$z17521753 = $f17581759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17581759,
"from":L[198]});
}
} catch($e17501751) {
if(R.isCont($e17501751)) {
var $ss17541755 = {"from":L[198],
"go":function(anf_arg3001760) {
return $Hanf_arg8301761(anf_arg3001760,anf_fun2961747,l1831749);
}};
$e17501751.stack[R.EXN_STACKHEIGHT++] = $ss17541755;
}
if(R.isPyretException($e17501751)) {
$e17501751.pyretStack.push(L[198]);
}
throw $e17501751;
}
var $ret17561757 = $Hanf_arg8301761($z17521753,anf_fun2961747,l1831749);
++R.GAS;
return $ret17561757;
};
var $Hanf_arg8301761 = function(anf_arg3001760,anf_fun2961747,l1831749) {
var $z17641765 = D;
var $f17701771 = function(_) {
return R.isFunction(anf_fun2961747)?anf_fun2961747.app(l1831749,anf_arg3001760):R.ffi.throwNonFunApp(L[199],anf_fun2961747,[l1831749,anf_arg3001760]);
};
try {
if(--R.GAS > 0) {
$z17641765 = $f17701771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17701771,
"from":L[199]});
}
} catch($e17621763) {
if(R.isCont($e17621763)) {
var $ss17661767 = {"from":L[199],
"go":function(ann_DASH_check_DASH_temp2951772) {
return $Hann_DASH_check_DASH_temp8291773(ann_DASH_check_DASH_temp2951772);
}};
$e17621763.stack[R.EXN_STACKHEIGHT++] = $ss17661767;
}
if(R.isPyretException($e17621763)) {
$e17621763.pyretStack.push(L[199]);
}
throw $e17621763;
}
var $ret17681769 = $Hann_DASH_check_DASH_temp8291773($z17641765);
++R.GAS;
return $ret17681769;
};
var $Hann_DASH_check_DASH_temp8291773 = function(ann_DASH_check_DASH_temp2951772) {
return ann_DASH_check_DASH_temp2951772;
};
var $Hanf_arg8281774 = function(anf_arg2921775,anf_fun2891776,anf_fun2901777,l1811778) {
var $z17811782 = D;
var $f17871788 = function(_) {
return R.isFunction(anf_fun2901777)?anf_fun2901777.app(anf_arg2921775):R.ffi.throwNonFunApp(L[200],anf_fun2901777,[anf_arg2921775]);
};
try {
if(--R.GAS > 0) {
$z17811782 = $f17871788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17871788,
"from":L[200]});
}
} catch($e17791780) {
if(R.isCont($e17791780)) {
var $ss17831784 = {"from":L[200],
"go":function(anf_arg2931789) {
return $Hanf_arg8271790(anf_arg2931789,anf_fun2891776,l1811778);
}};
$e17791780.stack[R.EXN_STACKHEIGHT++] = $ss17831784;
}
if(R.isPyretException($e17791780)) {
$e17791780.pyretStack.push(L[200]);
}
throw $e17791780;
}
var $ret17851786 = $Hanf_arg8271790($z17811782,anf_fun2891776,l1811778);
++R.GAS;
return $ret17851786;
};
var $Hanf_arg8271790 = function(anf_arg2931789,anf_fun2891776,l1811778) {
var $z17931794 = D;
var $f17991800 = function(_) {
return R.isFunction(anf_fun2891776)?anf_fun2891776.app(l1811778,anf_arg2931789):R.ffi.throwNonFunApp(L[201],anf_fun2891776,[l1811778,anf_arg2931789]);
};
try {
if(--R.GAS > 0) {
$z17931794 = $f17991800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17991800,
"from":L[201]});
}
} catch($e17911792) {
if(R.isCont($e17911792)) {
var $ss17951796 = {"from":L[201],
"go":function(ann_DASH_check_DASH_temp2881801) {
return $Hann_DASH_check_DASH_temp8261802(ann_DASH_check_DASH_temp2881801);
}};
$e17911792.stack[R.EXN_STACKHEIGHT++] = $ss17951796;
}
if(R.isPyretException($e17911792)) {
$e17911792.pyretStack.push(L[201]);
}
throw $e17911792;
}
var $ret17971798 = $Hann_DASH_check_DASH_temp8261802($z17931794);
++R.GAS;
return $ret17971798;
};
var $Hann_DASH_check_DASH_temp8261802 = function(ann_DASH_check_DASH_temp2881801) {
return ann_DASH_check_DASH_temp2881801;
};
var $Hanf_arg8251803 = function(anf_arg2851804,anf_fun2821805,anf_fun2831806,l1791807) {
var $z18101811 = D;
var $f18161817 = function(_) {
return R.isFunction(anf_fun2831806)?anf_fun2831806.app(anf_arg2851804):R.ffi.throwNonFunApp(L[202],anf_fun2831806,[anf_arg2851804]);
};
try {
if(--R.GAS > 0) {
$z18101811 = $f18161817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18161817,
"from":L[202]});
}
} catch($e18081809) {
if(R.isCont($e18081809)) {
var $ss18121813 = {"from":L[202],
"go":function(anf_arg2861818) {
return $Hanf_arg8241819(anf_arg2861818,anf_fun2821805,l1791807);
}};
$e18081809.stack[R.EXN_STACKHEIGHT++] = $ss18121813;
}
if(R.isPyretException($e18081809)) {
$e18081809.pyretStack.push(L[202]);
}
throw $e18081809;
}
var $ret18141815 = $Hanf_arg8241819($z18101811,anf_fun2821805,l1791807);
++R.GAS;
return $ret18141815;
};
var $Hanf_arg8241819 = function(anf_arg2861818,anf_fun2821805,l1791807) {
var $z18221823 = D;
var $f18281829 = function(_) {
return R.isFunction(anf_fun2821805)?anf_fun2821805.app(l1791807,anf_arg2861818):R.ffi.throwNonFunApp(L[203],anf_fun2821805,[l1791807,anf_arg2861818]);
};
try {
if(--R.GAS > 0) {
$z18221823 = $f18281829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18281829,
"from":L[203]});
}
} catch($e18201821) {
if(R.isCont($e18201821)) {
var $ss18241825 = {"from":L[203],
"go":function(ann_DASH_check_DASH_temp2811830) {
return $Hann_DASH_check_DASH_temp8231831(ann_DASH_check_DASH_temp2811830);
}};
$e18201821.stack[R.EXN_STACKHEIGHT++] = $ss18241825;
}
if(R.isPyretException($e18201821)) {
$e18201821.pyretStack.push(L[203]);
}
throw $e18201821;
}
var $ret18261827 = $Hann_DASH_check_DASH_temp8231831($z18221823);
++R.GAS;
return $ret18261827;
};
var $Hann_DASH_check_DASH_temp8231831 = function(ann_DASH_check_DASH_temp2811830) {
return ann_DASH_check_DASH_temp2811830;
};
var $Hanf_arg8221832 = function(anf_arg2781833,anf_fun2751834,anf_fun2761835,l1771836) {
var $z18391840 = D;
var $f18451846 = function(_) {
return R.isFunction(anf_fun2761835)?anf_fun2761835.app(anf_arg2781833):R.ffi.throwNonFunApp(L[204],anf_fun2761835,[anf_arg2781833]);
};
try {
if(--R.GAS > 0) {
$z18391840 = $f18451846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18451846,
"from":L[204]});
}
} catch($e18371838) {
if(R.isCont($e18371838)) {
var $ss18411842 = {"from":L[204],
"go":function(anf_arg2791847) {
return $Hanf_arg8211848(anf_arg2791847,anf_fun2751834,l1771836);
}};
$e18371838.stack[R.EXN_STACKHEIGHT++] = $ss18411842;
}
if(R.isPyretException($e18371838)) {
$e18371838.pyretStack.push(L[204]);
}
throw $e18371838;
}
var $ret18431844 = $Hanf_arg8211848($z18391840,anf_fun2751834,l1771836);
++R.GAS;
return $ret18431844;
};
var $Hanf_arg8211848 = function(anf_arg2791847,anf_fun2751834,l1771836) {
var $z18511852 = D;
var $f18571858 = function(_) {
return R.isFunction(anf_fun2751834)?anf_fun2751834.app(l1771836,anf_arg2791847):R.ffi.throwNonFunApp(L[205],anf_fun2751834,[l1771836,anf_arg2791847]);
};
try {
if(--R.GAS > 0) {
$z18511852 = $f18571858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18571858,
"from":L[205]});
}
} catch($e18491850) {
if(R.isCont($e18491850)) {
var $ss18531854 = {"from":L[205],
"go":function(ann_DASH_check_DASH_temp2741859) {
return $Hann_DASH_check_DASH_temp8201860(ann_DASH_check_DASH_temp2741859);
}};
$e18491850.stack[R.EXN_STACKHEIGHT++] = $ss18531854;
}
if(R.isPyretException($e18491850)) {
$e18491850.pyretStack.push(L[205]);
}
throw $e18491850;
}
var $ret18551856 = $Hann_DASH_check_DASH_temp8201860($z18511852);
++R.GAS;
return $ret18551856;
};
var $Hann_DASH_check_DASH_temp8201860 = function(ann_DASH_check_DASH_temp2741859) {
return ann_DASH_check_DASH_temp2741859;
};
var $Hanf_arg8191861 = function(anf_arg2711862,anf_fun2681863,anf_fun2691864,l1761865) {
var $z18681869 = D;
var $f18741875 = function(_) {
return R.isFunction(anf_fun2691864)?anf_fun2691864.app(anf_arg2711862):R.ffi.throwNonFunApp(L[206],anf_fun2691864,[anf_arg2711862]);
};
try {
if(--R.GAS > 0) {
$z18681869 = $f18741875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18741875,
"from":L[206]});
}
} catch($e18661867) {
if(R.isCont($e18661867)) {
var $ss18701871 = {"from":L[206],
"go":function(anf_arg2721876) {
return $Hanf_arg8181877(anf_arg2721876,anf_fun2681863,l1761865);
}};
$e18661867.stack[R.EXN_STACKHEIGHT++] = $ss18701871;
}
if(R.isPyretException($e18661867)) {
$e18661867.pyretStack.push(L[206]);
}
throw $e18661867;
}
var $ret18721873 = $Hanf_arg8181877($z18681869,anf_fun2681863,l1761865);
++R.GAS;
return $ret18721873;
};
var $Hanf_arg8181877 = function(anf_arg2721876,anf_fun2681863,l1761865) {
var $z18801881 = D;
var $f18861887 = function(_) {
return R.isFunction(anf_fun2681863)?anf_fun2681863.app(l1761865,anf_arg2721876):R.ffi.throwNonFunApp(L[207],anf_fun2681863,[l1761865,anf_arg2721876]);
};
try {
if(--R.GAS > 0) {
$z18801881 = $f18861887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18861887,
"from":L[207]});
}
} catch($e18781879) {
if(R.isCont($e18781879)) {
var $ss18821883 = {"from":L[207],
"go":function(ann_DASH_check_DASH_temp2671888) {
return $Hann_DASH_check_DASH_temp8171889(ann_DASH_check_DASH_temp2671888);
}};
$e18781879.stack[R.EXN_STACKHEIGHT++] = $ss18821883;
}
if(R.isPyretException($e18781879)) {
$e18781879.pyretStack.push(L[207]);
}
throw $e18781879;
}
var $ret18841885 = $Hann_DASH_check_DASH_temp8171889($z18801881);
++R.GAS;
return $ret18841885;
};
var $Hann_DASH_check_DASH_temp8171889 = function(ann_DASH_check_DASH_temp2671888) {
return ann_DASH_check_DASH_temp2671888;
};
var $Hanf_arg8161890 = function(anf_arg2641891,anf_fun2611892,anf_fun2621893,l1741894) {
var $z18971898 = D;
var $f19031904 = function(_) {
return R.isFunction(anf_fun2621893)?anf_fun2621893.app(anf_arg2641891):R.ffi.throwNonFunApp(L[208],anf_fun2621893,[anf_arg2641891]);
};
try {
if(--R.GAS > 0) {
$z18971898 = $f19031904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19031904,
"from":L[208]});
}
} catch($e18951896) {
if(R.isCont($e18951896)) {
var $ss18991900 = {"from":L[208],
"go":function(anf_arg2651905) {
return $Hanf_arg8151906(anf_arg2651905,anf_fun2611892,l1741894);
}};
$e18951896.stack[R.EXN_STACKHEIGHT++] = $ss18991900;
}
if(R.isPyretException($e18951896)) {
$e18951896.pyretStack.push(L[208]);
}
throw $e18951896;
}
var $ret19011902 = $Hanf_arg8151906($z18971898,anf_fun2611892,l1741894);
++R.GAS;
return $ret19011902;
};
var $Hanf_arg8151906 = function(anf_arg2651905,anf_fun2611892,l1741894) {
var $z19091910 = D;
var $f19151916 = function(_) {
return R.isFunction(anf_fun2611892)?anf_fun2611892.app(l1741894,anf_arg2651905):R.ffi.throwNonFunApp(L[209],anf_fun2611892,[l1741894,anf_arg2651905]);
};
try {
if(--R.GAS > 0) {
$z19091910 = $f19151916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19151916,
"from":L[209]});
}
} catch($e19071908) {
if(R.isCont($e19071908)) {
var $ss19111912 = {"from":L[209],
"go":function(ann_DASH_check_DASH_temp2601917) {
return $Hann_DASH_check_DASH_temp8141918(ann_DASH_check_DASH_temp2601917);
}};
$e19071908.stack[R.EXN_STACKHEIGHT++] = $ss19111912;
}
if(R.isPyretException($e19071908)) {
$e19071908.pyretStack.push(L[209]);
}
throw $e19071908;
}
var $ret19131914 = $Hann_DASH_check_DASH_temp8141918($z19091910);
++R.GAS;
return $ret19131914;
};
var $Hann_DASH_check_DASH_temp8141918 = function(ann_DASH_check_DASH_temp2601917) {
return ann_DASH_check_DASH_temp2601917;
};
var $Hanf_arg8131919 = function(anf_arg2561920,anf_fun2531921,anf_fun2541922,anf_fun2551923,l1711924) {
var $z19271928 = D;
var $f19331934 = function(_) {
return R.isFunction(anf_fun2551923)?anf_fun2551923.app(l1711924,anf_arg2561920):R.ffi.throwNonFunApp(L[210],anf_fun2551923,[l1711924,anf_arg2561920]);
};
try {
if(--R.GAS > 0) {
$z19271928 = $f19331934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19331934,
"from":L[210]});
}
} catch($e19251926) {
if(R.isCont($e19251926)) {
var $ss19291930 = {"from":L[210],
"go":function(anf_arg2571935) {
return $Hanf_arg8121936(anf_arg2571935,anf_fun2531921,anf_fun2541922,l1711924);
}};
$e19251926.stack[R.EXN_STACKHEIGHT++] = $ss19291930;
}
if(R.isPyretException($e19251926)) {
$e19251926.pyretStack.push(L[210]);
}
throw $e19251926;
}
var $ret19311932 = $Hanf_arg8121936($z19271928,anf_fun2531921,anf_fun2541922,l1711924);
++R.GAS;
return $ret19311932;
};
var $Hanf_arg8121936 = function(anf_arg2571935,anf_fun2531921,anf_fun2541922,l1711924) {
var $z19391940 = D;
var $f19451946 = function(_) {
return R.isFunction(anf_fun2541922)?anf_fun2541922.app(anf_arg2571935):R.ffi.throwNonFunApp(L[211],anf_fun2541922,[anf_arg2571935]);
};
try {
if(--R.GAS > 0) {
$z19391940 = $f19451946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19451946,
"from":L[211]});
}
} catch($e19371938) {
if(R.isCont($e19371938)) {
var $ss19411942 = {"from":L[211],
"go":function(anf_arg2581947) {
return $Hanf_arg8111948(anf_arg2581947,anf_fun2531921,l1711924);
}};
$e19371938.stack[R.EXN_STACKHEIGHT++] = $ss19411942;
}
if(R.isPyretException($e19371938)) {
$e19371938.pyretStack.push(L[211]);
}
throw $e19371938;
}
var $ret19431944 = $Hanf_arg8111948($z19391940,anf_fun2531921,l1711924);
++R.GAS;
return $ret19431944;
};
var $Hanf_arg8111948 = function(anf_arg2581947,anf_fun2531921,l1711924) {
var $z19511952 = D;
var $f19571958 = function(_) {
return R.isFunction(anf_fun2531921)?anf_fun2531921.app(l1711924,anf_arg2581947):R.ffi.throwNonFunApp(L[212],anf_fun2531921,[l1711924,anf_arg2581947]);
};
try {
if(--R.GAS > 0) {
$z19511952 = $f19571958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19571958,
"from":L[212]});
}
} catch($e19491950) {
if(R.isCont($e19491950)) {
var $ss19531954 = {"from":L[212],
"go":function(ann_DASH_check_DASH_temp2521959) {
return $Hann_DASH_check_DASH_temp8101960(ann_DASH_check_DASH_temp2521959);
}};
$e19491950.stack[R.EXN_STACKHEIGHT++] = $ss19531954;
}
if(R.isPyretException($e19491950)) {
$e19491950.pyretStack.push(L[212]);
}
throw $e19491950;
}
var $ret19551956 = $Hann_DASH_check_DASH_temp8101960($z19511952);
++R.GAS;
return $ret19551956;
};
var $Hann_DASH_check_DASH_temp8101960 = function(ann_DASH_check_DASH_temp2521959) {
return ann_DASH_check_DASH_temp2521959;
};
var $Hanf_arg8091961 = function(anf_arg2491962,anf_fun2461963,anf_fun2471964,l1691965) {
var $z19681969 = D;
var $f19741975 = function(_) {
return R.isFunction(anf_fun2471964)?anf_fun2471964.app(anf_arg2491962):R.ffi.throwNonFunApp(L[213],anf_fun2471964,[anf_arg2491962]);
};
try {
if(--R.GAS > 0) {
$z19681969 = $f19741975();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19741975,
"from":L[213]});
}
} catch($e19661967) {
if(R.isCont($e19661967)) {
var $ss19701971 = {"from":L[213],
"go":function(anf_arg2501976) {
return $Hanf_arg8081977(anf_arg2501976,anf_fun2461963,l1691965);
}};
$e19661967.stack[R.EXN_STACKHEIGHT++] = $ss19701971;
}
if(R.isPyretException($e19661967)) {
$e19661967.pyretStack.push(L[213]);
}
throw $e19661967;
}
var $ret19721973 = $Hanf_arg8081977($z19681969,anf_fun2461963,l1691965);
++R.GAS;
return $ret19721973;
};
var $Hanf_arg8081977 = function(anf_arg2501976,anf_fun2461963,l1691965) {
var $z19801981 = D;
var $f19861987 = function(_) {
return R.isFunction(anf_fun2461963)?anf_fun2461963.app(l1691965,anf_arg2501976):R.ffi.throwNonFunApp(L[214],anf_fun2461963,[l1691965,anf_arg2501976]);
};
try {
if(--R.GAS > 0) {
$z19801981 = $f19861987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19861987,
"from":L[214]});
}
} catch($e19781979) {
if(R.isCont($e19781979)) {
var $ss19821983 = {"from":L[214],
"go":function(ann_DASH_check_DASH_temp2451988) {
return $Hann_DASH_check_DASH_temp8071989(ann_DASH_check_DASH_temp2451988);
}};
$e19781979.stack[R.EXN_STACKHEIGHT++] = $ss19821983;
}
if(R.isPyretException($e19781979)) {
$e19781979.pyretStack.push(L[214]);
}
throw $e19781979;
}
var $ret19841985 = $Hann_DASH_check_DASH_temp8071989($z19801981);
++R.GAS;
return $ret19841985;
};
var $Hann_DASH_check_DASH_temp8071989 = function(ann_DASH_check_DASH_temp2451988) {
return ann_DASH_check_DASH_temp2451988;
};
var $Hann_DASH_check_DASH_temp8061990 = function(ann_DASH_check_DASH_temp2341991) {
return ann_DASH_check_DASH_temp2341991;
};
var $Hann_DASH_check_DASH_temp8051992 = function(ann_DASH_check_DASH_temp2351993) {
return ann_DASH_check_DASH_temp2351993;
};
var $Hann_DASH_check_DASH_temp8041994 = function(ann_DASH_check_DASH_temp2361995) {
return ann_DASH_check_DASH_temp2361995;
};
var $Hanf_arg8031996 = function(anf_arg2401997,anf_fun2381998,l1611999) {
var $z20022003 = D;
var $f20082009 = function(_) {
return R.isFunction(anf_fun2381998)?anf_fun2381998.app(l1611999,anf_arg2401997):R.ffi.throwNonFunApp(L[215],anf_fun2381998,[l1611999,anf_arg2401997]);
};
try {
if(--R.GAS > 0) {
$z20022003 = $f20082009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20082009,
"from":L[215]});
}
} catch($e20002001) {
if(R.isCont($e20002001)) {
var $ss20042005 = {"from":L[215],
"go":function(ann_DASH_check_DASH_temp2372010) {
return $Hann_DASH_check_DASH_temp8022011(ann_DASH_check_DASH_temp2372010);
}};
$e20002001.stack[R.EXN_STACKHEIGHT++] = $ss20042005;
}
if(R.isPyretException($e20002001)) {
$e20002001.pyretStack.push(L[215]);
}
throw $e20002001;
}
var $ret20062007 = $Hann_DASH_check_DASH_temp8022011($z20022003);
++R.GAS;
return $ret20062007;
};
var $Hann_DASH_check_DASH_temp8022011 = function(ann_DASH_check_DASH_temp2372010) {
return ann_DASH_check_DASH_temp2372010;
};
var $Hann_DASH_check_DASH_temp8012012 = function(ann_DASH_check_DASH_temp1992013) {
return ann_DASH_check_DASH_temp1992013;
};
var $Hann_DASH_check_DASH_temp8002014 = function(ann_DASH_check_DASH_temp2002015) {
return ann_DASH_check_DASH_temp2002015;
};
var $Hanf_arg7992016 = function(anf_arg2062017,N512,anf_DASH_block_DASH_help1542018,anf86820,f1562019,k_DASH_cont752020,k1532021,r1572022) {
var if_DASH_232080 = R.equiv(anf_arg2062017,(0));
var if_helper2072034 = R.makeFunction(function(if_helper_arg2082086) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[224],1,arguments);
}
var ann_DASH_check_DASH_temp2042087 = if_helper_arg2082086;
return ann_DASH_check_DASH_temp2042087;
});
var anf_if2112085 = R.isBoolean(if_DASH_232080);
if(R.isPyretTrue(anf_if2112085)) {
if(R.isPyretTrue(if_DASH_232080)) {
var $z20252026 = D;
var $f20312032 = function(_) {
return R.isFunction(anf86820.$var === D?U(L[216],"anf"):anf86820.$var)?anf86820.$var === D?U(L[216],"anf"):anf86820.$var.app(f1562019,k1532021):R.ffi.throwNonFunApp(L[217],anf86820.$var === D?U(L[216],"anf"):anf86820.$var,[f1562019,k1532021]);
};
try {
if(--R.GAS > 0) {
$z20252026 = $f20312032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20312032,
"from":L[217]});
}
} catch($e20232024) {
if(R.isCont($e20232024)) {
var $ss20272028 = {"from":L[217],
"go":function(cont_tail_arg2242033) {
return $Hcont_tail_arg7932035(cont_tail_arg2242033,if_helper2072034);
}};
$e20232024.stack[R.EXN_STACKHEIGHT++] = $ss20272028;
}
if(R.isPyretException($e20232024)) {
$e20232024.pyretStack.push(L[217]);
}
throw $e20232024;
}
var $ret20292030 = $Hcont_tail_arg7932035($z20252026,if_helper2072034);
++R.GAS;
return $ret20292030;
} else {
var cases_DASH_val222079 = f1562019;
var anf_fun2122046 = G(cases_DASH_val222079,"_match",L[218]);
var anf_arg2132047 = R.makeObject({});
var anf_arg2212048 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[218],0,arguments);
}
var anf_arg2192061 = R.makeFunction(function(lettable1582064) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[220],1,arguments);
}
var anf_fun2162077 = G(N512,"a-seq",L[223]);
var anf_arg2172076 = G(f1562019,"l",L[222]);
var $z20672068 = D;
var $f20732074 = function(_) {
return R.isFunction(anf_DASH_block_DASH_help1542018.$var)?anf_DASH_block_DASH_help1542018.$var.app(r1572022):R.ffi.throwNonFunApp(L[221],anf_DASH_block_DASH_help1542018.$var,[r1572022]);
};
try {
if(--R.GAS > 0) {
$z20672068 = $f20732074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20732074,
"from":L[221]});
}
} catch($e20652066) {
if(R.isCont($e20652066)) {
var $ss20692070 = {"from":L[221],
"go":function(anf_arg2182075) {
return $Hanf_arg7952078(anf_arg2182075,anf_arg2172076,anf_fun2162077,lettable1582064);
}};
$e20652066.stack[R.EXN_STACKHEIGHT++] = $ss20692070;
}
if(R.isPyretException($e20652066)) {
$e20652066.pyretStack.push(L[221]);
}
throw $e20652066;
}
var $ret20712072 = $Hanf_arg7952078($z20672068,anf_arg2172076,anf_fun2162077,lettable1582064);
++R.GAS;
return $ret20712072;
});
var $z20532054 = D;
var $f20592060 = function(_) {
return R.isFunction(k_DASH_cont752020.$var)?k_DASH_cont752020.$var.app(anf_arg2192061):R.ffi.throwNonFunApp(L[219],k_DASH_cont752020.$var,[anf_arg2192061]);
};
try {
if(--R.GAS > 0) {
$z20532054 = $f20592060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20592060,
"from":L[219]});
}
} catch($e20512052) {
if(R.isCont($e20512052)) {
var $ss20552056 = {"from":L[219],
"go":function(anf_arg2202062) {
return $Hanf_arg7972063(anf_arg2202062,anf86820,f1562019);
}};
$e20512052.stack[R.EXN_STACKHEIGHT++] = $ss20552056;
}
if(R.isPyretException($e20512052)) {
$e20512052.pyretStack.push(L[219]);
}
throw $e20512052;
}
var $ret20572058 = $Hanf_arg7972063($z20532054,anf86820,f1562019);
++R.GAS;
return $ret20572058;
});
var $z20382039 = D;
var $f20442045 = function(_) {
return R.isFunction(anf_fun2122046)?anf_fun2122046.app(anf_arg2132047,anf_arg2212048):R.ffi.throwNonFunApp(L[218],anf_fun2122046,[anf_arg2132047,anf_arg2212048]);
};
try {
if(--R.GAS > 0) {
$z20382039 = $f20442045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20442045,
"from":L[218]});
}
} catch($e20362037) {
if(R.isCont($e20362037)) {
var $ss20402041 = {"from":L[218],
"go":function(cont_tail_arg2222049) {
return $Hcont_tail_arg7982050(cont_tail_arg2222049,if_helper2072034);
}};
$e20362037.stack[R.EXN_STACKHEIGHT++] = $ss20402041;
}
if(R.isPyretException($e20362037)) {
$e20362037.pyretStack.push(L[218]);
}
throw $e20362037;
}
var $ret20422043 = $Hcont_tail_arg7982050($z20382039,if_helper2072034);
++R.GAS;
return $ret20422043;
}
} else {
var cont_tail_arg2092083 = R.throwNonBooleanCondition(L[224],("if"),if_DASH_232080);
if(--R.GAS > 0) {
$z20812082 = R.isFunction(if_helper2072034)?if_helper2072034.app(cont_tail_arg2092083):R.ffi.throwNonFunApp(L[224],if_helper2072034,[cont_tail_arg2092083]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper2072034)?if_helper2072034.app(cont_tail_arg2092083):R.ffi.throwNonFunApp(L[224],if_helper2072034,[cont_tail_arg2092083]);
},
"from":L[224]});
}
++R.GAS;
return $z20812082;
}
};
var $Hcont_tail_arg7932035 = function(cont_tail_arg2242033,if_helper2072034) {
if(--R.GAS > 0) {
$z20882089 = R.isFunction(if_helper2072034)?if_helper2072034.app(cont_tail_arg2242033):R.ffi.throwNonFunApp(L[217],if_helper2072034,[cont_tail_arg2242033]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper2072034)?if_helper2072034.app(cont_tail_arg2242033):R.ffi.throwNonFunApp(L[217],if_helper2072034,[cont_tail_arg2242033]);
},
"from":L[217]});
}
++R.GAS;
return $z20882089;
};
var $Hcont_tail_arg7982050 = function(cont_tail_arg2222049,if_helper2072034) {
if(--R.GAS > 0) {
$z20902091 = R.isFunction(if_helper2072034)?if_helper2072034.app(cont_tail_arg2222049):R.ffi.throwNonFunApp(L[218],if_helper2072034,[cont_tail_arg2222049]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper2072034)?if_helper2072034.app(cont_tail_arg2222049):R.ffi.throwNonFunApp(L[218],if_helper2072034,[cont_tail_arg2222049]);
},
"from":L[218]});
}
++R.GAS;
return $z20902091;
};
var $Hanf_arg7972063 = function(anf_arg2202062,anf86820,f1562019) {
var $z20942095 = D;
var $f21002101 = function(_) {
return R.isFunction(anf86820.$var === D?U(L[225],"anf"):anf86820.$var)?anf86820.$var === D?U(L[225],"anf"):anf86820.$var.app(f1562019,anf_arg2202062):R.ffi.throwNonFunApp(L[218],anf86820.$var === D?U(L[225],"anf"):anf86820.$var,[f1562019,anf_arg2202062]);
};
try {
if(--R.GAS > 0) {
$z20942095 = $f21002101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21002101,
"from":L[218]});
}
} catch($e20922093) {
if(R.isCont($e20922093)) {
var $ss20962097 = {"from":L[218],
"go":function(ann_DASH_check_DASH_temp2142102) {
return $Hann_DASH_check_DASH_temp7962103(ann_DASH_check_DASH_temp2142102);
}};
$e20922093.stack[R.EXN_STACKHEIGHT++] = $ss20962097;
}
if(R.isPyretException($e20922093)) {
$e20922093.pyretStack.push(L[218]);
}
throw $e20922093;
}
var $ret20982099 = $Hann_DASH_check_DASH_temp7962103($z20942095);
++R.GAS;
return $ret20982099;
};
var $Hann_DASH_check_DASH_temp7962103 = function(ann_DASH_check_DASH_temp2142102) {
return ann_DASH_check_DASH_temp2142102;
};
var $Hanf_arg7952078 = function(anf_arg2182075,anf_arg2172076,anf_fun2162077,lettable1582064) {
var $z21062107 = D;
var $f21122113 = function(_) {
return R.isFunction(anf_fun2162077)?anf_fun2162077.app(anf_arg2172076,lettable1582064,anf_arg2182075):R.ffi.throwNonFunApp(L[220],anf_fun2162077,[anf_arg2172076,lettable1582064,anf_arg2182075]);
};
try {
if(--R.GAS > 0) {
$z21062107 = $f21122113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21122113,
"from":L[220]});
}
} catch($e21042105) {
if(R.isCont($e21042105)) {
var $ss21082109 = {"from":L[220],
"go":function(ann_DASH_check_DASH_temp2152114) {
return $Hann_DASH_check_DASH_temp7942115(ann_DASH_check_DASH_temp2152114);
}};
$e21042105.stack[R.EXN_STACKHEIGHT++] = $ss21082109;
}
if(R.isPyretException($e21042105)) {
$e21042105.pyretStack.push(L[220]);
}
throw $e21042105;
}
var $ret21102111 = $Hann_DASH_check_DASH_temp7942115($z21062107);
++R.GAS;
return $ret21102111;
};
var $Hann_DASH_check_DASH_temp7942115 = function(ann_DASH_check_DASH_temp2152114) {
return ann_DASH_check_DASH_temp2152114;
};
var $Hann_DASH_check_DASH_temp7922116 = function(ann_DASH_check_DASH_temp2022117) {
return ann_DASH_check_DASH_temp2022117;
};
var $Hann_DASH_check_DASH_temp7912118 = function(ann_DASH_check_DASH_temp1672119) {
return ann_DASH_check_DASH_temp1672119;
};
var $Hitype7902120 = function(itype1472121,N512,l1432122,name1452123,types1462124) {
var anf_fun1932135 = G(N512,"a-import-types",L[227]);
var $z21272128 = D;
var $f21332134 = function(_) {
return R.isFunction(anf_fun1932135)?anf_fun1932135.app(l1432122,itype1472121,name1452123,types1462124):R.ffi.throwNonFunApp(L[226],anf_fun1932135,[l1432122,itype1472121,name1452123,types1462124]);
};
try {
if(--R.GAS > 0) {
$z21272128 = $f21332134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21332134,
"from":L[226]});
}
} catch($e21252126) {
if(R.isCont($e21252126)) {
var $ss21292130 = {"from":L[226],
"go":function(ann_DASH_check_DASH_temp1822136) {
return $Hann_DASH_check_DASH_temp7892137(ann_DASH_check_DASH_temp1822136);
}};
$e21252126.stack[R.EXN_STACKHEIGHT++] = $ss21292130;
}
if(R.isPyretException($e21252126)) {
$e21252126.pyretStack.push(L[226]);
}
throw $e21252126;
}
var $ret21312132 = $Hann_DASH_check_DASH_temp7892137($z21272128);
++R.GAS;
return $ret21312132;
};
var $Hann_DASH_check_DASH_temp7892137 = function(ann_DASH_check_DASH_temp1822136) {
return ann_DASH_check_DASH_temp1822136;
};
var $Hann_DASH_check_DASH_temp7882138 = function(ann_DASH_check_DASH_temp1872139) {
return ann_DASH_check_DASH_temp1872139;
};
var $Hann_DASH_check_DASH_temp7872140 = function(ann_DASH_check_DASH_temp1842141) {
return ann_DASH_check_DASH_temp1842141;
};
var $Hitype7862142 = function(itype1382143,N512,l1352144,name1372145) {
var anf_fun1802156 = G(N512,"a-import",L[229]);
var $z21482149 = D;
var $f21542155 = function(_) {
return R.isFunction(anf_fun1802156)?anf_fun1802156.app(l1352144,itype1382143,name1372145):R.ffi.throwNonFunApp(L[228],anf_fun1802156,[l1352144,itype1382143,name1372145]);
};
try {
if(--R.GAS > 0) {
$z21482149 = $f21542155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21542155,
"from":L[228]});
}
} catch($e21462147) {
if(R.isCont($e21462147)) {
var $ss21502151 = {"from":L[228],
"go":function(ann_DASH_check_DASH_temp1692157) {
return $Hann_DASH_check_DASH_temp7852158(ann_DASH_check_DASH_temp1692157);
}};
$e21462147.stack[R.EXN_STACKHEIGHT++] = $ss21502151;
}
if(R.isPyretException($e21462147)) {
$e21462147.pyretStack.push(L[228]);
}
throw $e21462147;
}
var $ret21522153 = $Hann_DASH_check_DASH_temp7852158($z21482149);
++R.GAS;
return $ret21522153;
};
var $Hann_DASH_check_DASH_temp7852158 = function(ann_DASH_check_DASH_temp1692157) {
return ann_DASH_check_DASH_temp1692157;
};
var $Hann_DASH_check_DASH_temp7842159 = function(ann_DASH_check_DASH_temp1742160) {
return ann_DASH_check_DASH_temp1742160;
};
var $Hann_DASH_check_DASH_temp7832161 = function(ann_DASH_check_DASH_temp1712162) {
return ann_DASH_check_DASH_temp1712162;
};
var $Hann_DASH_check_DASH_temp7822163 = function(ann_DASH_check_DASH_temp1552164) {
return ann_DASH_check_DASH_temp1552164;
};
var $Hanf_arg7812165 = function(anf_arg1602166,anf_DASH_term78497,anf_fun1582167,block1332168,l1292169) {
var $z21722173 = D;
var $f21782179 = function(_) {
return R.isFunction(anf_DASH_term78497.$var)?anf_DASH_term78497.$var.app(block1332168):R.ffi.throwNonFunApp(L[230],anf_DASH_term78497.$var,[block1332168]);
};
try {
if(--R.GAS > 0) {
$z21722173 = $f21782179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21782179,
"from":L[230]});
}
} catch($e21702171) {
if(R.isCont($e21702171)) {
var $ss21742175 = {"from":L[230],
"go":function(anf_arg1612180) {
return $Hanf_arg7802181(anf_arg1612180,anf_arg1602166,anf_fun1582167,l1292169);
}};
$e21702171.stack[R.EXN_STACKHEIGHT++] = $ss21742175;
}
if(R.isPyretException($e21702171)) {
$e21702171.pyretStack.push(L[230]);
}
throw $e21702171;
}
var $ret21762177 = $Hanf_arg7802181($z21722173,anf_arg1602166,anf_fun1582167,l1292169);
++R.GAS;
return $ret21762177;
};
var $Hanf_arg7802181 = function(anf_arg1612180,anf_arg1602166,anf_fun1582167,l1292169) {
var $z21842185 = D;
var $f21902191 = function(_) {
return R.isFunction(anf_fun1582167)?anf_fun1582167.app(l1292169,anf_arg1602166,anf_arg1612180):R.ffi.throwNonFunApp(L[231],anf_fun1582167,[l1292169,anf_arg1602166,anf_arg1612180]);
};
try {
if(--R.GAS > 0) {
$z21842185 = $f21902191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21902191,
"from":L[231]});
}
} catch($e21822183) {
if(R.isCont($e21822183)) {
var $ss21862187 = {"from":L[231],
"go":function(ann_DASH_check_DASH_temp1572192) {
return $Hann_DASH_check_DASH_temp7792193(ann_DASH_check_DASH_temp1572192);
}};
$e21822183.stack[R.EXN_STACKHEIGHT++] = $ss21862187;
}
if(R.isPyretException($e21822183)) {
$e21822183.pyretStack.push(L[231]);
}
throw $e21822183;
}
var $ret21882189 = $Hann_DASH_check_DASH_temp7792193($z21842185);
++R.GAS;
return $ret21882189;
};
var $Hann_DASH_check_DASH_temp7792193 = function(ann_DASH_check_DASH_temp1572192) {
return ann_DASH_check_DASH_temp1572192;
};
var $Hann_DASH_check_DASH_temp7782194 = function(ann_DASH_check_DASH_temp1362195,N620) {
return ann_DASH_check_DASH_temp1362195;
};
var $Hann_DASH_check_DASH_temp7772196 = function(ann_DASH_check_DASH_temp1422197) {
return ann_DASH_check_DASH_temp1422197;
};
var $Hann_DASH_check_DASH_temp7762198 = function(ann_DASH_check_DASH_temp1432199) {
return ann_DASH_check_DASH_temp1432199;
};
var $Hanf_arg7752200 = function(anf_arg1462201,k1232202,vs1272203,_plus4) {
var $z22062207 = D;
var $f22122213 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg1462201,vs1272203):R.ffi.throwNonFunApp(L[232],_plus4,[anf_arg1462201,vs1272203]);
};
try {
if(--R.GAS > 0) {
$z22062207 = $f22122213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22122213,
"from":L[232]});
}
} catch($e22042205) {
if(R.isCont($e22042205)) {
var $ss22082209 = {"from":L[232],
"go":function(anf_arg1472214) {
return $Hanf_arg7742215(anf_arg1472214,k1232202);
}};
$e22042205.stack[R.EXN_STACKHEIGHT++] = $ss22082209;
}
if(R.isPyretException($e22042205)) {
$e22042205.pyretStack.push(L[232]);
}
throw $e22042205;
}
var $ret22102211 = $Hanf_arg7742215($z22062207,k1232202);
++R.GAS;
return $ret22102211;
};
var $Hanf_arg7742215 = function(anf_arg1472214,k1232202) {
var $z22182219 = D;
var $f22242225 = function(_) {
return R.isFunction(k1232202)?k1232202.app(anf_arg1472214):R.ffi.throwNonFunApp(L[233],k1232202,[anf_arg1472214]);
};
try {
if(--R.GAS > 0) {
$z22182219 = $f22242225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22242225,
"from":L[233]});
}
} catch($e22162217) {
if(R.isCont($e22162217)) {
var $ss22202221 = {"from":L[233],
"go":function(ann_DASH_check_DASH_temp1442226) {
return $Hann_DASH_check_DASH_temp7732227(ann_DASH_check_DASH_temp1442226);
}};
$e22162217.stack[R.EXN_STACKHEIGHT++] = $ss22202221;
}
if(R.isPyretException($e22162217)) {
$e22162217.pyretStack.push(L[233]);
}
throw $e22162217;
}
var $ret22222223 = $Hann_DASH_check_DASH_temp7732227($z22182219);
++R.GAS;
return $ret22222223;
};
var $Hann_DASH_check_DASH_temp7732227 = function(ann_DASH_check_DASH_temp1442226) {
return ann_DASH_check_DASH_temp1442226;
};
var $Hanf_arg7722228 = function(anf_arg1402229,k1232202) {
var $z22322233 = D;
var $f22382239 = function(_) {
return R.isFunction(k1232202)?k1232202.app(anf_arg1402229):R.ffi.throwNonFunApp(L[234],k1232202,[anf_arg1402229]);
};
try {
if(--R.GAS > 0) {
$z22322233 = $f22382239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22382239,
"from":L[234]});
}
} catch($e22302231) {
if(R.isCont($e22302231)) {
var $ss22342235 = {"from":L[234],
"go":function(ann_DASH_check_DASH_temp1382240) {
return $Hann_DASH_check_DASH_temp7712241(ann_DASH_check_DASH_temp1382240);
}};
$e22302231.stack[R.EXN_STACKHEIGHT++] = $ss22342235;
}
if(R.isPyretException($e22302231)) {
$e22302231.pyretStack.push(L[234]);
}
throw $e22302231;
}
var $ret22362237 = $Hann_DASH_check_DASH_temp7712241($z22322233);
++R.GAS;
return $ret22362237;
};
var $Hann_DASH_check_DASH_temp7712241 = function(ann_DASH_check_DASH_temp1382240) {
return ann_DASH_check_DASH_temp1382240;
};
var $Hanf_arg7702242 = function(anf_arg1342243,N620,anf86820,expr1152244) {
var $z22472248 = D;
var $f22532254 = function(_) {
return R.isFunction(anf86820.$var === D?U(L[235],"anf"):anf86820.$var)?anf86820.$var === D?U(L[235],"anf"):anf86820.$var.app(expr1152244,anf_arg1342243):R.ffi.throwNonFunApp(L[236],anf86820.$var === D?U(L[235],"anf"):anf86820.$var,[expr1152244,anf_arg1342243]);
};
try {
if(--R.GAS > 0) {
$z22472248 = $f22532254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22532254,
"from":L[236]});
}
} catch($e22452246) {
if(R.isCont($e22452246)) {
var $ss22492250 = {"from":L[236],
"go":function(ann_DASH_check_DASH_temp1192255) {
return $Hann_DASH_check_DASH_temp7692256(ann_DASH_check_DASH_temp1192255,N620);
}};
$e22452246.stack[R.EXN_STACKHEIGHT++] = $ss22492250;
}
if(R.isPyretException($e22452246)) {
$e22452246.pyretStack.push(L[236]);
}
throw $e22452246;
}
var $ret22512252 = $Hann_DASH_check_DASH_temp7692256($z22472248,N620);
++R.GAS;
return $ret22512252;
};
var $Hann_DASH_check_DASH_temp7692256 = function(ann_DASH_check_DASH_temp1192255,N620) {
return ann_DASH_check_DASH_temp1192255;
};
var $Hann_DASH_check_DASH_temp7682257 = function(ann_DASH_check_DASH_temp1202258) {
return ann_DASH_check_DASH_temp1202258;
};
var $Ht7672259 = function(t1202260,N512,expr1152244,k1172261,lettable1182262) {
var anf_fun1272277 = G(N512,"a-let",L[241]);
var anf_arg1282275 = G(expr1152244,"l",L[240]);
var anf_arg1292276 = G(t1202260,"id-b",L[239]);
var anf_arg1302273 = G(t1202260,"id-e",L[238]);
var $z22652266 = D;
var $f22712272 = function(_) {
return R.isFunction(k1172261)?k1172261.app(anf_arg1302273):R.ffi.throwNonFunApp(L[237],k1172261,[anf_arg1302273]);
};
try {
if(--R.GAS > 0) {
$z22652266 = $f22712272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22712272,
"from":L[237]});
}
} catch($e22632264) {
if(R.isCont($e22632264)) {
var $ss22672268 = {"from":L[237],
"go":function(anf_arg1312274) {
return $Hanf_arg7662278(anf_arg1312274,anf_arg1282275,anf_arg1292276,anf_fun1272277,lettable1182262);
}};
$e22632264.stack[R.EXN_STACKHEIGHT++] = $ss22672268;
}
if(R.isPyretException($e22632264)) {
$e22632264.pyretStack.push(L[237]);
}
throw $e22632264;
}
var $ret22692270 = $Hanf_arg7662278($z22652266,anf_arg1282275,anf_arg1292276,anf_fun1272277,lettable1182262);
++R.GAS;
return $ret22692270;
};
var $Hanf_arg7662278 = function(anf_arg1312274,anf_arg1282275,anf_arg1292276,anf_fun1272277,lettable1182262) {
var $z22812282 = D;
var $f22872288 = function(_) {
return R.isFunction(anf_fun1272277)?anf_fun1272277.app(anf_arg1282275,anf_arg1292276,lettable1182262,anf_arg1312274):R.ffi.throwNonFunApp(L[242],anf_fun1272277,[anf_arg1282275,anf_arg1292276,lettable1182262,anf_arg1312274]);
};
try {
if(--R.GAS > 0) {
$z22812282 = $f22872288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22872288,
"from":L[242]});
}
} catch($e22792280) {
if(R.isCont($e22792280)) {
var $ss22832284 = {"from":L[242],
"go":function(ann_DASH_check_DASH_temp1252289) {
return $Hann_DASH_check_DASH_temp7652290(ann_DASH_check_DASH_temp1252289);
}};
$e22792280.stack[R.EXN_STACKHEIGHT++] = $ss22832284;
}
if(R.isPyretException($e22792280)) {
$e22792280.pyretStack.push(L[242]);
}
throw $e22792280;
}
var $ret22852286 = $Hann_DASH_check_DASH_temp7652290($z22812282);
++R.GAS;
return $ret22852286;
};
var $Hann_DASH_check_DASH_temp7652290 = function(ann_DASH_check_DASH_temp1252289) {
return ann_DASH_check_DASH_temp1252289;
};
var $Hann_DASH_check_DASH_temp7642291 = function(ann_DASH_check_DASH_temp1222292) {
return ann_DASH_check_DASH_temp1222292;
};
var $Hann_DASH_check_DASH_temp7632293 = function(ann_DASH_check_DASH_temp1102294) {
return ann_DASH_check_DASH_temp1102294;
};
var $Hann_DASH_check_DASH_temp7622295 = function(ann_DASH_check_DASH_temp1122296) {
return ann_DASH_check_DASH_temp1122296;
};
var $Hann_DASH_check_DASH_temp7612297 = function(ann_DASH_check_DASH_temp1062298) {
return ann_DASH_check_DASH_temp1062298;
};
var $Hanf_arg7602299 = function(anf_arg1042300,N620,anf86820,e1022301) {
var $z23042305 = D;
var $f23102311 = function(_) {
return R.isFunction(anf86820.$var === D?U(L[243],"anf"):anf86820.$var)?anf86820.$var === D?U(L[243],"anf"):anf86820.$var.app(e1022301,anf_arg1042300):R.ffi.throwNonFunApp(L[244],anf86820.$var === D?U(L[243],"anf"):anf86820.$var,[e1022301,anf_arg1042300]);
};
try {
if(--R.GAS > 0) {
$z23042305 = $f23102311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23102311,
"from":L[244]});
}
} catch($e23022303) {
if(R.isCont($e23022303)) {
var $ss23062307 = {"from":L[244],
"go":function(ann_DASH_check_DASH_temp872312) {
return $Hann_DASH_check_DASH_temp7592313(ann_DASH_check_DASH_temp872312,N620);
}};
$e23022303.stack[R.EXN_STACKHEIGHT++] = $ss23062307;
}
if(R.isPyretException($e23022303)) {
$e23022303.pyretStack.push(L[244]);
}
throw $e23022303;
}
var $ret23082309 = $Hann_DASH_check_DASH_temp7592313($z23042305,N620);
++R.GAS;
return $ret23082309;
};
var $Hann_DASH_check_DASH_temp7592313 = function(ann_DASH_check_DASH_temp872312,N620) {
return ann_DASH_check_DASH_temp872312;
};
var $Hann_DASH_check_DASH_temp7582314 = function(ann_DASH_check_DASH_temp882315) {
return ann_DASH_check_DASH_temp882315;
};
var $Hann_DASH_check_DASH_temp7572316 = function(ann_DASH_check_DASH_temp1002317) {
return ann_DASH_check_DASH_temp1002317;
};
var $Hname7562318 = function(name1072319,N512,l1042320,x1032321) {
var anf_fun912336 = G(N512,"a-let",L[250]);
var anf_arg922335 = G(name1072319,"id-b",L[249]);
var anf_fun932337 = G(N512,"a-lettable",L[248]);
var anf_fun942332 = G(N512,"a-val",L[247]);
var anf_arg952333 = G(name1072319,"id-e",L[246]);
var $z23242325 = D;
var $f23302331 = function(_) {
return R.isFunction(anf_fun942332)?anf_fun942332.app(anf_arg952333):R.ffi.throwNonFunApp(L[245],anf_fun942332,[anf_arg952333]);
};
try {
if(--R.GAS > 0) {
$z23242325 = $f23302331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23302331,
"from":L[245]});
}
} catch($e23222323) {
if(R.isCont($e23222323)) {
var $ss23262327 = {"from":L[245],
"go":function(anf_arg962334) {
return $Hanf_arg7552338(anf_arg962334,anf_arg922335,anf_fun912336,anf_fun932337,l1042320,x1032321);
}};
$e23222323.stack[R.EXN_STACKHEIGHT++] = $ss23262327;
}
if(R.isPyretException($e23222323)) {
$e23222323.pyretStack.push(L[245]);
}
throw $e23222323;
}
var $ret23282329 = $Hanf_arg7552338($z23242325,anf_arg922335,anf_fun912336,anf_fun932337,l1042320,x1032321);
++R.GAS;
return $ret23282329;
};
var $Hanf_arg7552338 = function(anf_arg962334,anf_arg922335,anf_fun912336,anf_fun932337,l1042320,x1032321) {
var $z23412342 = D;
var $f23472348 = function(_) {
return R.isFunction(anf_fun932337)?anf_fun932337.app(anf_arg962334):R.ffi.throwNonFunApp(L[251],anf_fun932337,[anf_arg962334]);
};
try {
if(--R.GAS > 0) {
$z23412342 = $f23472348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23472348,
"from":L[251]});
}
} catch($e23392340) {
if(R.isCont($e23392340)) {
var $ss23432344 = {"from":L[251],
"go":function(anf_arg972349) {
return $Hanf_arg7542350(anf_arg972349,anf_arg922335,anf_fun912336,l1042320,x1032321);
}};
$e23392340.stack[R.EXN_STACKHEIGHT++] = $ss23432344;
}
if(R.isPyretException($e23392340)) {
$e23392340.pyretStack.push(L[251]);
}
throw $e23392340;
}
var $ret23452346 = $Hanf_arg7542350($z23412342,anf_arg922335,anf_fun912336,l1042320,x1032321);
++R.GAS;
return $ret23452346;
};
var $Hanf_arg7542350 = function(anf_arg972349,anf_arg922335,anf_fun912336,l1042320,x1032321) {
var $z23532354 = D;
var $f23592360 = function(_) {
return R.isFunction(anf_fun912336)?anf_fun912336.app(l1042320,anf_arg922335,x1032321,anf_arg972349):R.ffi.throwNonFunApp(L[252],anf_fun912336,[l1042320,anf_arg922335,x1032321,anf_arg972349]);
};
try {
if(--R.GAS > 0) {
$z23532354 = $f23592360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23592360,
"from":L[252]});
}
} catch($e23512352) {
if(R.isCont($e23512352)) {
var $ss23552356 = {"from":L[252],
"go":function(ann_DASH_check_DASH_temp902361) {
return $Hann_DASH_check_DASH_temp7532362(ann_DASH_check_DASH_temp902361);
}};
$e23512352.stack[R.EXN_STACKHEIGHT++] = $ss23552356;
}
if(R.isPyretException($e23512352)) {
$e23512352.pyretStack.push(L[252]);
}
throw $e23512352;
}
var $ret23572358 = $Hann_DASH_check_DASH_temp7532362($z23532354);
++R.GAS;
return $ret23572358;
};
var $Hann_DASH_check_DASH_temp7532362 = function(ann_DASH_check_DASH_temp902361) {
return ann_DASH_check_DASH_temp902361;
};
var $Hann_DASH_check_DASH_temp7522363 = function(ann_DASH_check_DASH_temp462364) {
return ann_DASH_check_DASH_temp462364;
};
var $He_DASH_name7512365 = function(e_DASH_name1002366,N512,expr972367,l962368,list25501,mk_DASH_id70825,self952369) {
var $z23722373 = D;
var $f23782379 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(l962368,("cont_tail_app")):R.ffi.throwNonFunApp(L[253],mk_DASH_id70825.$var,[l962368,("cont_tail_app")]);
};
try {
if(--R.GAS > 0) {
$z23722373 = $f23782379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23782379,
"from":L[253]});
}
} catch($e23702371) {
if(R.isCont($e23702371)) {
var $ss23742375 = {"from":L[253],
"go":function(name1012380) {
return $Hname7502381(name1012380,N512,e_DASH_name1002366,expr972367,l962368,list25501,self952369);
}};
$e23702371.stack[R.EXN_STACKHEIGHT++] = $ss23742375;
}
if(R.isPyretException($e23702371)) {
$e23702371.pyretStack.push(L[253]);
}
throw $e23702371;
}
var $ret23762377 = $Hname7502381($z23722373,N512,e_DASH_name1002366,expr972367,l962368,list25501,self952369);
++R.GAS;
return $ret23762377;
};
var $Hname7502381 = function(name1012380,N512,e_DASH_name1002366,expr972367,l962368,list25501,self952369) {
var anf_fun662396 = G(N512,"a-let",L[260]);
var anf_arg672395 = G(e_DASH_name1002366,"id-b",L[259]);
var anf_fun682397 = G(N512,"a-lettable",L[258]);
var anf_fun692398 = G(N512,"a-app",L[257]);
var anf_fun702392 = G(N512,"a-id",L[256]);
var anf_arg712393 = G(self952369,"name",L[255]);
var $z23842385 = D;
var $f23902391 = function(_) {
return R.isFunction(anf_fun702392)?anf_fun702392.app(l962368,anf_arg712393):R.ffi.throwNonFunApp(L[254],anf_fun702392,[l962368,anf_arg712393]);
};
try {
if(--R.GAS > 0) {
$z23842385 = $f23902391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23902391,
"from":L[254]});
}
} catch($e23822383) {
if(R.isCont($e23822383)) {
var $ss23862387 = {"from":L[254],
"go":function(anf_arg722394) {
return $Hanf_arg7492399(anf_arg722394,anf_arg672395,anf_fun662396,anf_fun682397,anf_fun692398,e_DASH_name1002366,expr972367,l962368,list25501);
}};
$e23822383.stack[R.EXN_STACKHEIGHT++] = $ss23862387;
}
if(R.isPyretException($e23822383)) {
$e23822383.pyretStack.push(L[254]);
}
throw $e23822383;
}
var $ret23882389 = $Hanf_arg7492399($z23842385,anf_arg672395,anf_fun662396,anf_fun682397,anf_fun692398,e_DASH_name1002366,expr972367,l962368,list25501);
++R.GAS;
return $ret23882389;
};
var $Hanf_arg7492399 = function(anf_arg722394,anf_arg672395,anf_fun662396,anf_fun682397,anf_fun692398,e_DASH_name1002366,expr972367,l962368,list25501) {
var anf_fun732410 = G(list25501,"make",L[261]);
var anf_array_val742411 = G(e_DASH_name1002366,"id-e",L[262]);
var $z24022403 = D;
var $f24082409 = function(_) {
return R.isFunction(anf_fun732410)?anf_fun732410.app([anf_array_val742411]):R.ffi.throwNonFunApp(L[261],anf_fun732410,[[anf_array_val742411]]);
};
try {
if(--R.GAS > 0) {
$z24022403 = $f24082409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24082409,
"from":L[261]});
}
} catch($e24002401) {
if(R.isCont($e24002401)) {
var $ss24042405 = {"from":L[261],
"go":function(anf_arg752412) {
return $Hanf_arg7482413(anf_arg752412,anf_arg672395,anf_arg722394,anf_fun662396,anf_fun682397,anf_fun692398,expr972367,l962368);
}};
$e24002401.stack[R.EXN_STACKHEIGHT++] = $ss24042405;
}
if(R.isPyretException($e24002401)) {
$e24002401.pyretStack.push(L[261]);
}
throw $e24002401;
}
var $ret24062407 = $Hanf_arg7482413($z24022403,anf_arg672395,anf_arg722394,anf_fun662396,anf_fun682397,anf_fun692398,expr972367,l962368);
++R.GAS;
return $ret24062407;
};
var $Hanf_arg7482413 = function(anf_arg752412,anf_arg672395,anf_arg722394,anf_fun662396,anf_fun682397,anf_fun692398,expr972367,l962368) {
var $z24162417 = D;
var $f24222423 = function(_) {
return R.isFunction(anf_fun692398)?anf_fun692398.app(l962368,anf_arg722394,anf_arg752412):R.ffi.throwNonFunApp(L[263],anf_fun692398,[l962368,anf_arg722394,anf_arg752412]);
};
try {
if(--R.GAS > 0) {
$z24162417 = $f24222423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24222423,
"from":L[263]});
}
} catch($e24142415) {
if(R.isCont($e24142415)) {
var $ss24182419 = {"from":L[263],
"go":function(anf_arg762424) {
return $Hanf_arg7472425(anf_arg762424,anf_arg672395,anf_fun662396,anf_fun682397,expr972367,l962368);
}};
$e24142415.stack[R.EXN_STACKHEIGHT++] = $ss24182419;
}
if(R.isPyretException($e24142415)) {
$e24142415.pyretStack.push(L[263]);
}
throw $e24142415;
}
var $ret24202421 = $Hanf_arg7472425($z24162417,anf_arg672395,anf_fun662396,anf_fun682397,expr972367,l962368);
++R.GAS;
return $ret24202421;
};
var $Hanf_arg7472425 = function(anf_arg762424,anf_arg672395,anf_fun662396,anf_fun682397,expr972367,l962368) {
var $z24282429 = D;
var $f24342435 = function(_) {
return R.isFunction(anf_fun682397)?anf_fun682397.app(anf_arg762424):R.ffi.throwNonFunApp(L[264],anf_fun682397,[anf_arg762424]);
};
try {
if(--R.GAS > 0) {
$z24282429 = $f24342435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24342435,
"from":L[264]});
}
} catch($e24262427) {
if(R.isCont($e24262427)) {
var $ss24302431 = {"from":L[264],
"go":function(anf_arg772436) {
return $Hanf_arg7462437(anf_arg772436,anf_arg672395,anf_fun662396,expr972367,l962368);
}};
$e24262427.stack[R.EXN_STACKHEIGHT++] = $ss24302431;
}
if(R.isPyretException($e24262427)) {
$e24262427.pyretStack.push(L[264]);
}
throw $e24262427;
}
var $ret24322433 = $Hanf_arg7462437($z24282429,anf_arg672395,anf_fun662396,expr972367,l962368);
++R.GAS;
return $ret24322433;
};
var $Hanf_arg7462437 = function(anf_arg772436,anf_arg672395,anf_fun662396,expr972367,l962368) {
var $z24402441 = D;
var $f24462447 = function(_) {
return R.isFunction(anf_fun662396)?anf_fun662396.app(l962368,anf_arg672395,expr972367,anf_arg772436):R.ffi.throwNonFunApp(L[265],anf_fun662396,[l962368,anf_arg672395,expr972367,anf_arg772436]);
};
try {
if(--R.GAS > 0) {
$z24402441 = $f24462447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24462447,
"from":L[265]});
}
} catch($e24382439) {
if(R.isCont($e24382439)) {
var $ss24422443 = {"from":L[265],
"go":function(ann_DASH_check_DASH_temp652448) {
return $Hann_DASH_check_DASH_temp7452449(ann_DASH_check_DASH_temp652448);
}};
$e24382439.stack[R.EXN_STACKHEIGHT++] = $ss24422443;
}
if(R.isPyretException($e24382439)) {
$e24382439.pyretStack.push(L[265]);
}
throw $e24382439;
}
var $ret24442445 = $Hann_DASH_check_DASH_temp7452449($z24402441);
++R.GAS;
return $ret24442445;
};
var $Hann_DASH_check_DASH_temp7452449 = function(ann_DASH_check_DASH_temp652448) {
return ann_DASH_check_DASH_temp652448;
};
var $Hname7442450 = function(name992451,N512,l962368,list25501,self952369,v982452) {
var anf_fun492467 = G(N512,"a-let",L[271]);
var anf_arg502466 = G(name992451,"id-b",L[270]);
var anf_fun512468 = G(N512,"a-app",L[269]);
var anf_fun522463 = G(N512,"a-id",L[268]);
var anf_arg532464 = G(self952369,"name",L[267]);
var $z24552456 = D;
var $f24612462 = function(_) {
return R.isFunction(anf_fun522463)?anf_fun522463.app(l962368,anf_arg532464):R.ffi.throwNonFunApp(L[266],anf_fun522463,[l962368,anf_arg532464]);
};
try {
if(--R.GAS > 0) {
$z24552456 = $f24612462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24612462,
"from":L[266]});
}
} catch($e24532454) {
if(R.isCont($e24532454)) {
var $ss24572458 = {"from":L[266],
"go":function(anf_arg542465) {
return $Hanf_arg7432469(anf_arg542465,N512,anf_arg502466,anf_fun492467,anf_fun512468,l962368,list25501,name992451,v982452);
}};
$e24532454.stack[R.EXN_STACKHEIGHT++] = $ss24572458;
}
if(R.isPyretException($e24532454)) {
$e24532454.pyretStack.push(L[266]);
}
throw $e24532454;
}
var $ret24592460 = $Hanf_arg7432469($z24552456,N512,anf_arg502466,anf_fun492467,anf_fun512468,l962368,list25501,name992451,v982452);
++R.GAS;
return $ret24592460;
};
var $Hanf_arg7432469 = function(anf_arg542465,N512,anf_arg502466,anf_fun492467,anf_fun512468,l962368,list25501,name992451,v982452) {
var anf_fun552480 = G(list25501,"make",L[272]);
var $z24722473 = D;
var $f24782479 = function(_) {
return R.isFunction(anf_fun552480)?anf_fun552480.app([v982452]):R.ffi.throwNonFunApp(L[272],anf_fun552480,[[v982452]]);
};
try {
if(--R.GAS > 0) {
$z24722473 = $f24782479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24782479,
"from":L[272]});
}
} catch($e24702471) {
if(R.isCont($e24702471)) {
var $ss24742475 = {"from":L[272],
"go":function(anf_arg562481) {
return $Hanf_arg7422482(anf_arg562481,N512,anf_arg502466,anf_arg542465,anf_fun492467,anf_fun512468,l962368,name992451);
}};
$e24702471.stack[R.EXN_STACKHEIGHT++] = $ss24742475;
}
if(R.isPyretException($e24702471)) {
$e24702471.pyretStack.push(L[272]);
}
throw $e24702471;
}
var $ret24762477 = $Hanf_arg7422482($z24722473,N512,anf_arg502466,anf_arg542465,anf_fun492467,anf_fun512468,l962368,name992451);
++R.GAS;
return $ret24762477;
};
var $Hanf_arg7422482 = function(anf_arg562481,N512,anf_arg502466,anf_arg542465,anf_fun492467,anf_fun512468,l962368,name992451) {
var $z24852486 = D;
var $f24912492 = function(_) {
return R.isFunction(anf_fun512468)?anf_fun512468.app(l962368,anf_arg542465,anf_arg562481):R.ffi.throwNonFunApp(L[273],anf_fun512468,[l962368,anf_arg542465,anf_arg562481]);
};
try {
if(--R.GAS > 0) {
$z24852486 = $f24912492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24912492,
"from":L[273]});
}
} catch($e24832484) {
if(R.isCont($e24832484)) {
var $ss24872488 = {"from":L[273],
"go":function(anf_arg572493) {
return $Hanf_arg7412494(anf_arg572493,N512,anf_arg502466,anf_fun492467,l962368,name992451);
}};
$e24832484.stack[R.EXN_STACKHEIGHT++] = $ss24872488;
}
if(R.isPyretException($e24832484)) {
$e24832484.pyretStack.push(L[273]);
}
throw $e24832484;
}
var $ret24892490 = $Hanf_arg7412494($z24852486,N512,anf_arg502466,anf_fun492467,l962368,name992451);
++R.GAS;
return $ret24892490;
};
var $Hanf_arg7412494 = function(anf_arg572493,N512,anf_arg502466,anf_fun492467,l962368,name992451) {
var anf_fun582508 = G(N512,"a-lettable",L[277]);
var anf_fun592505 = G(N512,"a-val",L[276]);
var anf_arg602506 = G(name992451,"id-e",L[275]);
var $z24972498 = D;
var $f25032504 = function(_) {
return R.isFunction(anf_fun592505)?anf_fun592505.app(anf_arg602506):R.ffi.throwNonFunApp(L[274],anf_fun592505,[anf_arg602506]);
};
try {
if(--R.GAS > 0) {
$z24972498 = $f25032504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25032504,
"from":L[274]});
}
} catch($e24952496) {
if(R.isCont($e24952496)) {
var $ss24992500 = {"from":L[274],
"go":function(anf_arg612507) {
return $Hanf_arg7402509(anf_arg612507,anf_arg502466,anf_arg572493,anf_fun492467,anf_fun582508,l962368);
}};
$e24952496.stack[R.EXN_STACKHEIGHT++] = $ss24992500;
}
if(R.isPyretException($e24952496)) {
$e24952496.pyretStack.push(L[274]);
}
throw $e24952496;
}
var $ret25012502 = $Hanf_arg7402509($z24972498,anf_arg502466,anf_arg572493,anf_fun492467,anf_fun582508,l962368);
++R.GAS;
return $ret25012502;
};
var $Hanf_arg7402509 = function(anf_arg612507,anf_arg502466,anf_arg572493,anf_fun492467,anf_fun582508,l962368) {
var $z25122513 = D;
var $f25182519 = function(_) {
return R.isFunction(anf_fun582508)?anf_fun582508.app(anf_arg612507):R.ffi.throwNonFunApp(L[278],anf_fun582508,[anf_arg612507]);
};
try {
if(--R.GAS > 0) {
$z25122513 = $f25182519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25182519,
"from":L[278]});
}
} catch($e25102511) {
if(R.isCont($e25102511)) {
var $ss25142515 = {"from":L[278],
"go":function(anf_arg622520) {
return $Hanf_arg7392521(anf_arg622520,anf_arg502466,anf_arg572493,anf_fun492467,l962368);
}};
$e25102511.stack[R.EXN_STACKHEIGHT++] = $ss25142515;
}
if(R.isPyretException($e25102511)) {
$e25102511.pyretStack.push(L[278]);
}
throw $e25102511;
}
var $ret25162517 = $Hanf_arg7392521($z25122513,anf_arg502466,anf_arg572493,anf_fun492467,l962368);
++R.GAS;
return $ret25162517;
};
var $Hanf_arg7392521 = function(anf_arg622520,anf_arg502466,anf_arg572493,anf_fun492467,l962368) {
var $z25242525 = D;
var $f25302531 = function(_) {
return R.isFunction(anf_fun492467)?anf_fun492467.app(l962368,anf_arg502466,anf_arg572493,anf_arg622520):R.ffi.throwNonFunApp(L[279],anf_fun492467,[l962368,anf_arg502466,anf_arg572493,anf_arg622520]);
};
try {
if(--R.GAS > 0) {
$z25242525 = $f25302531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25302531,
"from":L[279]});
}
} catch($e25222523) {
if(R.isCont($e25222523)) {
var $ss25262527 = {"from":L[279],
"go":function(ann_DASH_check_DASH_temp482532) {
return $Hann_DASH_check_DASH_temp7382533(ann_DASH_check_DASH_temp482532);
}};
$e25222523.stack[R.EXN_STACKHEIGHT++] = $ss25262527;
}
if(R.isPyretException($e25222523)) {
$e25222523.pyretStack.push(L[279]);
}
throw $e25222523;
}
var $ret25282529 = $Hann_DASH_check_DASH_temp7382533($z25242525);
++R.GAS;
return $ret25282529;
};
var $Hann_DASH_check_DASH_temp7382533 = function(ann_DASH_check_DASH_temp482532) {
return ann_DASH_check_DASH_temp482532;
};
var $Hanf_arg7372534 = function(anf_arg422535,_plus4) {
var $z25382539 = D;
var $f25442545 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg422535,(")")):R.ffi.throwNonFunApp(L[280],_plus4,[anf_arg422535,(")")]);
};
try {
if(--R.GAS > 0) {
$z25382539 = $f25442545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25442545,
"from":L[280]});
}
} catch($e25362537) {
if(R.isCont($e25362537)) {
var $ss25402541 = {"from":L[280],
"go":function(anf_arg432546) {
return $Hanf_arg7362547(anf_arg432546,_plus4);
}};
$e25362537.stack[R.EXN_STACKHEIGHT++] = $ss25402541;
}
if(R.isPyretException($e25362537)) {
$e25362537.pyretStack.push(L[280]);
}
throw $e25362537;
}
var $ret25422543 = $Hanf_arg7362547($z25382539,_plus4);
++R.GAS;
return $ret25422543;
};
var $Hanf_arg7362547 = function(anf_arg432546,_plus4) {
var $z25502551 = D;
var $f25562557 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("("),anf_arg432546):R.ffi.throwNonFunApp(L[280],_plus4,[("("),anf_arg432546]);
};
try {
if(--R.GAS > 0) {
$z25502551 = $f25562557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25562557,
"from":L[280]});
}
} catch($e25482549) {
if(R.isCont($e25482549)) {
var $ss25522553 = {"from":L[280],
"go":function(anf_arg442558) {
return $Hanf_arg7352559(anf_arg442558,_plus4);
}};
$e25482549.stack[R.EXN_STACKHEIGHT++] = $ss25522553;
}
if(R.isPyretException($e25482549)) {
$e25482549.pyretStack.push(L[280]);
}
throw $e25482549;
}
var $ret25542555 = $Hanf_arg7352559($z25502551,_plus4);
++R.GAS;
return $ret25542555;
};
var $Hanf_arg7352559 = function(anf_arg442558,_plus4) {
var $z25622563 = D;
var $f25682569 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("k-id"),anf_arg442558):R.ffi.throwNonFunApp(L[280],_plus4,[("k-id"),anf_arg442558]);
};
try {
if(--R.GAS > 0) {
$z25622563 = $f25682569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25682569,
"from":L[280]});
}
} catch($e25602561) {
if(R.isCont($e25602561)) {
var $ss25642565 = {"from":L[280],
"go":function(ann_DASH_check_DASH_temp402570) {
return $Hann_DASH_check_DASH_temp7342571(ann_DASH_check_DASH_temp402570);
}};
$e25602561.stack[R.EXN_STACKHEIGHT++] = $ss25642565;
}
if(R.isPyretException($e25602561)) {
$e25602561.pyretStack.push(L[280]);
}
throw $e25602561;
}
var $ret25662567 = $Hann_DASH_check_DASH_temp7342571($z25622563);
++R.GAS;
return $ret25662567;
};
var $Hann_DASH_check_DASH_temp7342571 = function(ann_DASH_check_DASH_temp402570) {
return ann_DASH_check_DASH_temp402570;
};
var $Hcont_tail_arg7322572 = function(cont_tail_arg372573,if_helper292574) {
if(--R.GAS > 0) {
$z25752576 = R.isFunction(if_helper292574)?if_helper292574.app(cont_tail_arg372573):R.ffi.throwNonFunApp(L[280],if_helper292574,[cont_tail_arg372573]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper292574)?if_helper292574.app(cont_tail_arg372573):R.ffi.throwNonFunApp(L[280],if_helper292574,[cont_tail_arg372573]);
},
"from":L[280]});
}
++R.GAS;
return $z25752576;
};
var $Hcont_tail_arg7332577 = function(cont_tail_arg342578,if_helper292574) {
if(--R.GAS > 0) {
$z25792580 = R.isFunction(if_helper292574)?if_helper292574.app(cont_tail_arg342578):R.ffi.throwNonFunApp(L[280],if_helper292574,[cont_tail_arg342578]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper292574)?if_helper292574.app(cont_tail_arg342578):R.ffi.throwNonFunApp(L[280],if_helper292574,[cont_tail_arg342578]);
},
"from":L[280]});
}
++R.GAS;
return $z25792580;
};
var $Hann_DASH_check_DASH_temp7312581 = function(ann_DASH_check_DASH_temp252582) {
return ann_DASH_check_DASH_temp252582;
};
var $Hanf_arg7302583 = function(anf_arg212584,_plus4) {
var $z25872588 = D;
var $f25932594 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg212584,(")")):R.ffi.throwNonFunApp(L[281],_plus4,[anf_arg212584,(")")]);
};
try {
if(--R.GAS > 0) {
$z25872588 = $f25932594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25932594,
"from":L[281]});
}
} catch($e25852586) {
if(R.isCont($e25852586)) {
var $ss25892590 = {"from":L[281],
"go":function(anf_arg222595) {
return $Hanf_arg7292596(anf_arg222595,_plus4);
}};
$e25852586.stack[R.EXN_STACKHEIGHT++] = $ss25892590;
}
if(R.isPyretException($e25852586)) {
$e25852586.pyretStack.push(L[281]);
}
throw $e25852586;
}
var $ret25912592 = $Hanf_arg7292596($z25872588,_plus4);
++R.GAS;
return $ret25912592;
};
var $Hanf_arg7292596 = function(anf_arg222595,_plus4) {
var $z25992600 = D;
var $f26052606 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("("),anf_arg222595):R.ffi.throwNonFunApp(L[281],_plus4,[("("),anf_arg222595]);
};
try {
if(--R.GAS > 0) {
$z25992600 = $f26052606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26052606,
"from":L[281]});
}
} catch($e25972598) {
if(R.isCont($e25972598)) {
var $ss26012602 = {"from":L[281],
"go":function(anf_arg232607) {
return $Hanf_arg7282608(anf_arg232607,_plus4);
}};
$e25972598.stack[R.EXN_STACKHEIGHT++] = $ss26012602;
}
if(R.isPyretException($e25972598)) {
$e25972598.pyretStack.push(L[281]);
}
throw $e25972598;
}
var $ret26032604 = $Hanf_arg7282608($z25992600,_plus4);
++R.GAS;
return $ret26032604;
};
var $Hanf_arg7282608 = function(anf_arg232607,_plus4) {
var $z26112612 = D;
var $f26172618 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("k-cont"),anf_arg232607):R.ffi.throwNonFunApp(L[281],_plus4,[("k-cont"),anf_arg232607]);
};
try {
if(--R.GAS > 0) {
$z26112612 = $f26172618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26172618,
"from":L[281]});
}
} catch($e26092610) {
if(R.isCont($e26092610)) {
var $ss26132614 = {"from":L[281],
"go":function(ann_DASH_check_DASH_temp192619) {
return $Hann_DASH_check_DASH_temp7272620(ann_DASH_check_DASH_temp192619);
}};
$e26092610.stack[R.EXN_STACKHEIGHT++] = $ss26132614;
}
if(R.isPyretException($e26092610)) {
$e26092610.pyretStack.push(L[281]);
}
throw $e26092610;
}
var $ret26152616 = $Hann_DASH_check_DASH_temp7272620($z26112612);
++R.GAS;
return $ret26152616;
};
var $Hann_DASH_check_DASH_temp7272620 = function(ann_DASH_check_DASH_temp192619) {
return ann_DASH_check_DASH_temp192619;
};
var $Hcont_tail_arg7252621 = function(cont_tail_arg162622,if_helper82623) {
if(--R.GAS > 0) {
$z26242625 = R.isFunction(if_helper82623)?if_helper82623.app(cont_tail_arg162622):R.ffi.throwNonFunApp(L[281],if_helper82623,[cont_tail_arg162622]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper82623)?if_helper82623.app(cont_tail_arg162622):R.ffi.throwNonFunApp(L[281],if_helper82623,[cont_tail_arg162622]);
},
"from":L[281]});
}
++R.GAS;
return $z26242625;
};
var $Hcont_tail_arg7262626 = function(cont_tail_arg132627,if_helper82623) {
if(--R.GAS > 0) {
$z26282629 = R.isFunction(if_helper82623)?if_helper82623.app(cont_tail_arg132627):R.ffi.throwNonFunApp(L[281],if_helper82623,[cont_tail_arg132627]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper82623)?if_helper82623.app(cont_tail_arg132627):R.ffi.throwNonFunApp(L[281],if_helper82623,[cont_tail_arg132627]);
},
"from":L[281]});
}
++R.GAS;
return $z26282629;
};
var $Ht7242630 = function(t892631,N512,bind792632,loc872633) {
var $z26362637 = D;
var $f26422643 = function(_) {
return R.isFunction(bind792632.$var === D?U(L[282],"bind"):bind792632.$var)?bind792632.$var === D?U(L[282],"bind"):bind792632.$var.app(loc872633,t892631):R.ffi.throwNonFunApp(L[283],bind792632.$var === D?U(L[282],"bind"):bind792632.$var,[loc872633,t892631]);
};
try {
if(--R.GAS > 0) {
$z26362637 = $f26422643();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26422643,
"from":L[283]});
}
} catch($e26342635) {
if(R.isCont($e26342635)) {
var $ss26382639 = {"from":L[283],
"go":function(anf_obj32644) {
return $Hanf_obj7232645(anf_obj32644,N512,loc872633,t892631);
}};
$e26342635.stack[R.EXN_STACKHEIGHT++] = $ss26382639;
}
if(R.isPyretException($e26342635)) {
$e26342635.pyretStack.push(L[283]);
}
throw $e26342635;
}
var $ret26402641 = $Hanf_obj7232645($z26362637,N512,loc872633,t892631);
++R.GAS;
return $ret26402641;
};
var $Hanf_obj7232645 = function(anf_obj32644,N512,loc872633,t892631) {
var anf_fun42656 = G(N512,"a-id",L[285]);
var $z26482649 = D;
var $f26542655 = function(_) {
return R.isFunction(anf_fun42656)?anf_fun42656.app(loc872633,t892631):R.ffi.throwNonFunApp(L[284],anf_fun42656,[loc872633,t892631]);
};
try {
if(--R.GAS > 0) {
$z26482649 = $f26542655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26542655,
"from":L[284]});
}
} catch($e26462647) {
if(R.isCont($e26462647)) {
var $ss26502651 = {"from":L[284],
"go":function(anf_obj52657) {
return $Hanf_obj7222658(anf_obj52657,anf_obj32644,t892631);
}};
$e26462647.stack[R.EXN_STACKHEIGHT++] = $ss26502651;
}
if(R.isPyretException($e26462647)) {
$e26462647.pyretStack.push(L[284]);
}
throw $e26462647;
}
var $ret26522653 = $Hanf_obj7222658($z26482649,anf_obj32644,t892631);
++R.GAS;
return $ret26522653;
};
var $Hanf_obj7222658 = function(anf_obj52657,anf_obj32644,t892631) {
var ann_DASH_check_DASH_temp12659 = R.makeObject({"id":t892631,
"id-b":anf_obj32644,
"id-e":anf_obj52657});
return ann_DASH_check_DASH_temp12659;
};
return R.loadModulesNew(NAMESPACE,[$A11027,$SL31128,$N51229,$arrays71330,$lists91431,$option111532,$error131633,$sets151734],function($A11027,$SL31128,$N51229,$arrays71330,$lists91431,$option111532,$error131633,$sets151734) {
var A110 = R.getField($A11027,"values");
var SL311 = R.getField($SL31128,"values");
var N512 = R.getField($N51229,"values");
var arrays713 = R.getField($arrays71330,"values");
var lists914 = R.getField($lists91431,"values");
var option1115 = R.getField($option111532,"values");
var error1316 = R.getField($error131633,"values");
var sets1517 = R.getField($sets151734,"values");
var A218 = R.getField($A11027,"types");
var SL419 = R.getField($SL31128,"types");
var N620 = R.getField($N51229,"types");
var arrays821 = R.getField($arrays71330,"types");
var lists1022 = R.getField($lists91431,"types");
var option1223 = R.getField($option111532,"types");
var error1424 = R.getField($error131633,"types");
var sets1625 = R.getField($sets151734,"types");
return R.safeCall(function() {
var List172660 = R.getDotAnn(L[286],"lists",lists1022,"List");
var Option182661 = R.getDotAnn(L[286],"option",option1223,"Option");
var Array192662 = R.getDotAnn(L[286],"arrays",arrays821,"Array");
var Set202663 = R.getDotAnn(L[286],"sets",sets1625,"Set");
var array214254 = G(arrays713,"array",L[286]);
var build_DASH_array224253 = G(arrays713,"build-array",L[286]);
var array_DASH_from_DASH_list234252 = G(arrays713,"array-from-list",L[286]);
var is_DASH_array244251 = G(arrays713,"is-array",L[286]);
var list25501 = G(lists914,"list",L[286]);
var is_DASH_empty264250 = G(lists914,"is-empty",L[286]);
var is_DASH_link274249 = G(lists914,"is-link",L[286]);
var empty284248 = G(lists914,"empty",L[286]);
var link294247 = G(lists914,"link",L[286]);
var range304246 = G(lists914,"range",L[286]);
var repeat314245 = G(lists914,"repeat",L[286]);
var filter324244 = G(lists914,"filter",L[286]);
var partition334243 = G(lists914,"partition",L[286]);
var split_DASH_at344242 = G(lists914,"split-at",L[286]);
var any354241 = G(lists914,"any",L[286]);
var find364240 = G(lists914,"find",L[286]);
var map371430 = G(lists914,"map",L[286]);
var map238140 = G(lists914,"map2",L[286]);
var map3394239 = G(lists914,"map3",L[286]);
var map4404238 = G(lists914,"map4",L[286]);
var map_n414237 = G(lists914,"map_n",L[286]);
var map2_n424236 = G(lists914,"map2_n",L[286]);
var map3_n434235 = G(lists914,"map3_n",L[286]);
var map4_n444234 = G(lists914,"map4_n",L[286]);
var each454233 = G(lists914,"each",L[286]);
var each2464232 = G(lists914,"each2",L[286]);
var each3474231 = G(lists914,"each3",L[286]);
var each4484230 = G(lists914,"each4",L[286]);
var each_n494229 = G(lists914,"each_n",L[286]);
var each2_n504228 = G(lists914,"each2_n",L[286]);
var each3_n514227 = G(lists914,"each3_n",L[286]);
var each4_n524226 = G(lists914,"each4_n",L[286]);
var fold53822 = G(lists914,"fold",L[286]);
var fold2544225 = G(lists914,"fold2",L[286]);
var fold3554224 = G(lists914,"fold3",L[286]);
var fold4564223 = G(lists914,"fold4",L[286]);
var index574222 = G(lists914,"index",L[286]);
var Option584221 = G(option1115,"Option",L[286]);
var is_DASH_none594220 = G(option1115,"is-none",L[286]);
var is_DASH_some604219 = G(option1115,"is-some",L[286]);
var none614218 = G(option1115,"none",L[286]);
var some624217 = G(option1115,"some",L[286]);
var set634216 = G(sets1517,"set",L[286]);
var tree_DASH_set644215 = G(sets1517,"tree-set",L[286]);
var list_DASH_set654214 = G(sets1517,"list-set",L[286]);
var ANFContT1672664 = R.namedBrander("ANFCont");
var ANFCont6637 = R.makeBranderAnn(ANFContT1672664,"ANFCont");
var Loc6838 = R.getDotAnn(L[287],"SL",SL419,"Srcloc");
var names692702 = G(A110,"global-names",L[532]);
var mk_DASH_id70825 = {"$var":D,
"$name":"mk-id"};
var ANFCont2712666 = {"$var":D,
"$name":"ANFCont2"};
var ANFCont722668 = {"$var":D,
"$name":"ANFCont"};
var is_DASH_ANFCont732670 = {"$var":D,
"$name":"is-ANFCont"};
var is_DASH_k_DASH_cont742672 = {"$var":D,
"$name":"is-k-cont"};
var k_DASH_cont752020 = {"$var":D,
"$name":"k-cont"};
var is_DASH_k_DASH_id762675 = {"$var":D,
"$name":"is-k-id"};
var k_DASH_id77823 = {"$var":D,
"$name":"k-id"};
var anf_DASH_term78497 = {"$var":D,
"$name":"anf-term"};
var bind792632 = {"$var":D,
"$name":"bind"};
var anf_DASH_bind802680 = {"$var":D,
"$name":"anf-bind"};
var anf_DASH_name81136 = {"$var":D,
"$name":"anf-name"};
var anf_DASH_name_DASH_rec82135 = {"$var":D,
"$name":"anf-name-rec"};
var anf_DASH_program832684 = {"$var":D,
"$name":"anf-program"};
var anf_DASH_import842686 = {"$var":D,
"$name":"anf-import"};
var anf_DASH_block852688 = {"$var":D,
"$name":"anf-block"};
var anf86820 = {"$var":D,
"$name":"anf"};
var anf_assign62665 = R.makeFunction(function(loc872633,base884202) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[529],2,arguments);
}
var anf_fun24213 = G(names692702,"make-atom",L[531]);
var $z42054206 = D;
var $f42114212 = function(_) {
return R.isFunction(anf_fun24213)?anf_fun24213.app(base884202):R.ffi.throwNonFunApp(L[530],anf_fun24213,[base884202]);
};
try {
if(--R.GAS > 0) {
$z42054206 = $f42114212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42114212,
"from":L[530]});
}
} catch($e42034204) {
if(R.isCont($e42034204)) {
var $ss42074208 = {"from":L[530],
"go":function(t892631) {
return $Ht7242630(t892631,N512,bind792632,loc872633);
}};
$e42034204.stack[R.EXN_STACKHEIGHT++] = $ss42074208;
}
if(R.isPyretException($e42034204)) {
$e42034204.pyretStack.push(L[530]);
}
throw $e42034204;
}
var $ret42094210 = $Ht7242630($z42054206,N512,bind792632,loc872633);
++R.GAS;
return $ret42094210;
});
mk_DASH_id70825.$var = anf_assign62665;
var anf_variant_member184052 = R.makeMethod(function(self24182) {
return function(cases_DASH_funs34183,else_DASH_clause44194) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[281],2,arguments);
}
var if_DASH_64195 = R.hasField(cases_DASH_funs34183,("k-cont"));
var if_helper82623 = R.makeFunction(function(if_helper_arg94200) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[281],1,arguments);
}
var ann_DASH_check_DASH_temp74201 = if_helper_arg94200;
return ann_DASH_check_DASH_temp74201;
});
var anf_if124199 = R.isBoolean(if_DASH_64195);
if(R.isPyretTrue(anf_if124199)) {
if(R.isPyretTrue(if_DASH_64195)) {
var call_DASH_k_DASH_cont14180 = G(cases_DASH_funs34183,"k-cont",L[281]);
var anf_arg154181 = G(self24182,"k",L[528]);
var $z41724173 = D;
var $f41784179 = function(_) {
return R.isFunction(call_DASH_k_DASH_cont14180)?call_DASH_k_DASH_cont14180.app(anf_arg154181):R.ffi.throwNonFunApp(L[281],call_DASH_k_DASH_cont14180,[anf_arg154181]);
};
try {
if(--R.GAS > 0) {
$z41724173 = $f41784179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41784179,
"from":L[281]});
}
} catch($e41704171) {
if(R.isCont($e41704171)) {
var $ss41744175 = {"from":L[281],
"go":function(cont_tail_arg162622) {
return $Hcont_tail_arg7252621(cont_tail_arg162622,if_helper82623);
}};
$e41704171.stack[R.EXN_STACKHEIGHT++] = $ss41744175;
}
if(R.isPyretException($e41704171)) {
$e41704171.pyretStack.push(L[281]);
}
throw $e41704171;
}
var $ret41764177 = $Hcont_tail_arg7252621($z41724173,if_helper82623);
++R.GAS;
return $ret41764177;
} else {
var $z41864187 = D;
var $f41924193 = function(_) {
return R.isFunction(else_DASH_clause44194)?else_DASH_clause44194.app():R.ffi.throwNonFunApp(L[281],else_DASH_clause44194,[]);
};
try {
if(--R.GAS > 0) {
$z41864187 = $f41924193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41924193,
"from":L[281]});
}
} catch($e41844185) {
if(R.isCont($e41844185)) {
var $ss41884189 = {"from":L[281],
"go":function(cont_tail_arg132627) {
return $Hcont_tail_arg7262626(cont_tail_arg132627,if_helper82623);
}};
$e41844185.stack[R.EXN_STACKHEIGHT++] = $ss41884189;
}
if(R.isPyretException($e41844185)) {
$e41844185.pyretStack.push(L[281]);
}
throw $e41844185;
}
var $ret41904191 = $Hcont_tail_arg7262626($z41864187,if_helper82623);
++R.GAS;
return $ret41904191;
}
} else {
var cont_tail_arg104198 = R.throwNonBooleanCondition(L[281],("if"),if_DASH_64195);
if(--R.GAS > 0) {
$z41964197 = R.isFunction(if_helper82623)?if_helper82623.app(cont_tail_arg104198):R.ffi.throwNonFunApp(L[281],if_helper82623,[cont_tail_arg104198]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper82623)?if_helper82623.app(cont_tail_arg104198):R.ffi.throwNonFunApp(L[281],if_helper82623,[cont_tail_arg104198]);
},
"from":L[281]});
}
++R.GAS;
return $z41964197;
}
};
},{"length":3});
var anf_variant_member244053 = R.makeMethod(function(self54169) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[281],0,arguments);
}
var anf_arg204168 = G(self54169,"k",L[281]);
var $z41604161 = D;
var $f41664167 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg204168):R.ffi.throwNonFunApp(L[281],torepr8,[anf_arg204168]);
};
try {
if(--R.GAS > 0) {
$z41604161 = $f41664167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41664167,
"from":L[281]});
}
} catch($e41584159) {
if(R.isCont($e41584159)) {
var $ss41624163 = {"from":L[281],
"go":function(anf_arg212584) {
return $Hanf_arg7302583(anf_arg212584,_plus4);
}};
$e41584159.stack[R.EXN_STACKHEIGHT++] = $ss41624163;
}
if(R.isPyretException($e41584159)) {
$e41584159.pyretStack.push(L[281]);
}
throw $e41584159;
}
var $ret41644165 = $Hanf_arg7302583($z41604161,_plus4);
++R.GAS;
return $ret41644165;
};
},{"length":1});
var anf_variant_member274054 = R.makeMethod(function(self914156) {
return function(l924157,expr934155) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[524],2,arguments);
}
return R.checkAnnArgs([Loc6838,R.getDotAnn(L[526],"N",N620,"ALettable")],[l924157,expr934155],[L[527],L[526]],function() {
var anf_fun264154 = G(self914156,"k",L[525]);
var $z41464147 = D;
var $f41524153 = function(_) {
return R.isFunction(anf_fun264154)?anf_fun264154.app(expr934155):R.ffi.throwNonFunApp(L[524],anf_fun264154,[expr934155]);
};
try {
if(--R.GAS > 0) {
$z41464147 = $f41524153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41524153,
"from":L[524]});
}
} catch($e41444145) {
if(R.isCont($e41444145)) {
var $ss41484149 = {"from":L[524],
"go":function(ann_DASH_check_DASH_temp252582) {
return $Hann_DASH_check_DASH_temp7312581(ann_DASH_check_DASH_temp252582);
}};
$e41444145.stack[R.EXN_STACKHEIGHT++] = $ss41484149;
}
if(R.isPyretException($e41444145)) {
$e41444145.pyretStack.push(L[524]);
}
throw $e41444145;
}
var $ret41504151 = $Hann_DASH_check_DASH_temp7312581($z41464147);
++R.GAS;
return $ret41504151;
});
};
},{"length":3});
var anf_variant_member394061 = R.makeMethod(function(self84124) {
return function(cases_DASH_funs94125,else_DASH_clause104136) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[280],2,arguments);
}
var if_DASH_124137 = R.hasField(cases_DASH_funs94125,("k-id"));
var if_helper292574 = R.makeFunction(function(if_helper_arg304142) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[280],1,arguments);
}
var ann_DASH_check_DASH_temp284143 = if_helper_arg304142;
return ann_DASH_check_DASH_temp284143;
});
var anf_if334141 = R.isBoolean(if_DASH_124137);
if(R.isPyretTrue(anf_if334141)) {
if(R.isPyretTrue(if_DASH_124137)) {
var call_DASH_k_DASH_id74122 = G(cases_DASH_funs94125,"k-id",L[280]);
var anf_arg364123 = G(self84124,"name",L[523]);
var $z41144115 = D;
var $f41204121 = function(_) {
return R.isFunction(call_DASH_k_DASH_id74122)?call_DASH_k_DASH_id74122.app(anf_arg364123):R.ffi.throwNonFunApp(L[280],call_DASH_k_DASH_id74122,[anf_arg364123]);
};
try {
if(--R.GAS > 0) {
$z41144115 = $f41204121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41204121,
"from":L[280]});
}
} catch($e41124113) {
if(R.isCont($e41124113)) {
var $ss41164117 = {"from":L[280],
"go":function(cont_tail_arg372573) {
return $Hcont_tail_arg7322572(cont_tail_arg372573,if_helper292574);
}};
$e41124113.stack[R.EXN_STACKHEIGHT++] = $ss41164117;
}
if(R.isPyretException($e41124113)) {
$e41124113.pyretStack.push(L[280]);
}
throw $e41124113;
}
var $ret41184119 = $Hcont_tail_arg7322572($z41144115,if_helper292574);
++R.GAS;
return $ret41184119;
} else {
var $z41284129 = D;
var $f41344135 = function(_) {
return R.isFunction(else_DASH_clause104136)?else_DASH_clause104136.app():R.ffi.throwNonFunApp(L[280],else_DASH_clause104136,[]);
};
try {
if(--R.GAS > 0) {
$z41284129 = $f41344135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41344135,
"from":L[280]});
}
} catch($e41264127) {
if(R.isCont($e41264127)) {
var $ss41304131 = {"from":L[280],
"go":function(cont_tail_arg342578) {
return $Hcont_tail_arg7332577(cont_tail_arg342578,if_helper292574);
}};
$e41264127.stack[R.EXN_STACKHEIGHT++] = $ss41304131;
}
if(R.isPyretException($e41264127)) {
$e41264127.pyretStack.push(L[280]);
}
throw $e41264127;
}
var $ret41324133 = $Hcont_tail_arg7332577($z41284129,if_helper292574);
++R.GAS;
return $ret41324133;
}
} else {
var cont_tail_arg314140 = R.throwNonBooleanCondition(L[280],("if"),if_DASH_124137);
if(--R.GAS > 0) {
$z41384139 = R.isFunction(if_helper292574)?if_helper292574.app(cont_tail_arg314140):R.ffi.throwNonFunApp(L[280],if_helper292574,[cont_tail_arg314140]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored2084) {
return R.isFunction(if_helper292574)?if_helper292574.app(cont_tail_arg314140):R.ffi.throwNonFunApp(L[280],if_helper292574,[cont_tail_arg314140]);
},
"from":L[280]});
}
++R.GAS;
return $z41384139;
}
};
},{"length":3});
var anf_variant_member454062 = R.makeMethod(function(self114111) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[280],0,arguments);
}
var anf_arg414110 = G(self114111,"name",L[280]);
var $z41024103 = D;
var $f41084109 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg414110):R.ffi.throwNonFunApp(L[280],torepr8,[anf_arg414110]);
};
try {
if(--R.GAS > 0) {
$z41024103 = $f41084109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41084109,
"from":L[280]});
}
} catch($e41004101) {
if(R.isCont($e41004101)) {
var $ss41044105 = {"from":L[280],
"go":function(anf_arg422535) {
return $Hanf_arg7372534(anf_arg422535,_plus4);
}};
$e41004101.stack[R.EXN_STACKHEIGHT++] = $ss41044105;
}
if(R.isPyretException($e41004101)) {
$e41004101.pyretStack.push(L[280]);
}
throw $e41004101;
}
var $ret41064107 = $Hanf_arg7372534($z41024103,_plus4);
++R.GAS;
return $ret41064107;
};
},{"length":1});
var anf_variant_member794063 = R.makeMethod(function(self952369) {
return function(l962368,expr972367) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[518],2,arguments);
}
return R.checkAnnArgs([Loc6838,R.getDotAnn(L[521],"N",N620,"ALettable")],[l962368,expr972367],[L[522],L[521]],function() {
var cases_DASH_val134099 = expr972367;
var anf_fun474075 = G(cases_DASH_val134099,"_match",L[265]);
var anf_obj634088 = R.makeFunction(function(v982452) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[279],1,arguments);
}
var $z40914092 = D;
var $f40974098 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(l962368,("cont_tail_app")):R.ffi.throwNonFunApp(L[520],mk_DASH_id70825.$var,[l962368,("cont_tail_app")]);
};
try {
if(--R.GAS > 0) {
$z40914092 = $f40974098();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40974098,
"from":L[520]});
}
} catch($e40894090) {
if(R.isCont($e40894090)) {
var $ss40934094 = {"from":L[520],
"go":function(name992451) {
return $Hname7442450(name992451,N512,l962368,list25501,self952369,v982452);
}};
$e40894090.stack[R.EXN_STACKHEIGHT++] = $ss40934094;
}
if(R.isPyretException($e40894090)) {
$e40894090.pyretStack.push(L[520]);
}
throw $e40894090;
}
var $ret40954096 = $Hname7442450($z40914092,N512,l962368,list25501,self952369,v982452);
++R.GAS;
return $ret40954096;
});
var anf_arg644076 = R.makeObject({"a-val":anf_obj634088});
var anf_arg784077 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[265],0,arguments);
}
var $z40804081 = D;
var $f40864087 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(l962368,("cont_tail_arg")):R.ffi.throwNonFunApp(L[519],mk_DASH_id70825.$var,[l962368,("cont_tail_arg")]);
};
try {
if(--R.GAS > 0) {
$z40804081 = $f40864087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40864087,
"from":L[519]});
}
} catch($e40784079) {
if(R.isCont($e40784079)) {
var $ss40824083 = {"from":L[519],
"go":function(e_DASH_name1002366) {
return $He_DASH_name7512365(e_DASH_name1002366,N512,expr972367,l962368,list25501,mk_DASH_id70825,self952369);
}};
$e40784079.stack[R.EXN_STACKHEIGHT++] = $ss40824083;
}
if(R.isPyretException($e40784079)) {
$e40784079.pyretStack.push(L[519]);
}
throw $e40784079;
}
var $ret40844085 = $He_DASH_name7512365($z40804081,N512,expr972367,l962368,list25501,mk_DASH_id70825,self952369);
++R.GAS;
return $ret40844085;
});
var $z40674068 = D;
var $f40734074 = function(_) {
return R.isFunction(anf_fun474075)?anf_fun474075.app(anf_arg644076,anf_arg784077):R.ffi.throwNonFunApp(L[518],anf_fun474075,[anf_arg644076,anf_arg784077]);
};
try {
if(--R.GAS > 0) {
$z40674068 = $f40734074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40734074,
"from":L[518]});
}
} catch($e40654066) {
if(R.isCont($e40654066)) {
var $ss40694070 = {"from":L[518],
"go":function(ann_DASH_check_DASH_temp462364) {
return $Hann_DASH_check_DASH_temp7522363(ann_DASH_check_DASH_temp462364);
}};
$e40654066.stack[R.EXN_STACKHEIGHT++] = $ss40694070;
}
if(R.isPyretException($e40654066)) {
$e40654066.pyretStack.push(L[518]);
}
throw $e40654066;
}
var $ret40714072 = $Hann_DASH_check_DASH_temp7522363($z40674068);
++R.GAS;
return $ret40714072;
});
};
},{"length":3});
var anf_assign802667 = (function() {
var $k_DASH_cont_DASH_base40474048 = {"_match":anf_variant_member184052,
"_torepr":anf_variant_member244053,
"apply":anf_variant_member274054};
var $k_DASH_cont_DASH_brands40504051 = {"$brand-k-cont4049":true};
$k_DASH_cont_DASH_brands40504051[ANFContT1672664._brand] = true
var $k_DASH_id_DASH_base40564057 = {"_match":anf_variant_member394061,
"_torepr":anf_variant_member454062,
"apply":anf_variant_member794063};
var $k_DASH_id_DASH_brands40594060 = {"$brand-k-id4058":true};
$k_DASH_id_DASH_brands40594060[ANFContT1672664._brand] = true
return R.makeObject({"ANFCont":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ANFContT1672664._brand));
}),
"is-k-cont":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[281],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-k-cont4049"));
}),
"k-cont":R.makeFunction(function(k904055) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[514],1,arguments);
}
return R.checkAnnArgs([R.Function],[k904055],[L[515]],function() {
var dict = R.create($k_DASH_cont_DASH_base40474048);
dict["k"] = k904055
return R.makeBrandedObject(dict,$k_DASH_cont_DASH_brands40504051);
});
}),
"is-k-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[280],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-k-id4058"));
}),
"k-id":R.makeFunction(function(name944064) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[516],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[517],"A",A218,"Name")],[name944064],[L[517]],function() {
var dict = R.create($k_DASH_id_DASH_base40564057);
dict["name"] = name944064
return R.makeBrandedObject(dict,$k_DASH_id_DASH_brands40594060);
});
})});
})();
ANFCont2712666.$var = anf_assign802667;
var anf_assign812669 = G(ANFCont2712666.$var,"ANFCont",L[0]);
ANFCont722668.$var = anf_assign812669;
var anf_assign822671 = G(ANFCont2712666.$var,"ANFCont",L[0]);
is_DASH_ANFCont732670.$var = anf_assign822671;
var anf_assign832673 = G(ANFCont2712666.$var,"is-k-cont",L[281]);
is_DASH_k_DASH_cont742672.$var = anf_assign832673;
var anf_assign842674 = G(ANFCont2712666.$var,"k-cont",L[281]);
k_DASH_cont752020.$var = anf_assign842674;
var anf_assign852676 = G(ANFCont2712666.$var,"is-k-id",L[280]);
is_DASH_k_DASH_id762675.$var = anf_assign852676;
var anf_assign862677 = G(ANFCont2712666.$var,"k-id",L[280]);
k_DASH_id77823.$var = anf_assign862677;
var anf_assign1052678 = R.makeFunction(function(e1022301) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[244],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[513],"A",A218,"Expr")],[e1022301],[L[513]],function() {
var anf_arg1034008 = R.makeFunction(function(x1032321) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[509],1,arguments);
}
var cases_DASH_val144046 = x1032321;
var anf_fun894019 = G(cases_DASH_val144046,"_match",L[510]);
var anf_obj984033 = R.makeFunction(function(l1042320,f1054034,args1064035) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[252],3,arguments);
}
var $z40384039 = D;
var $f40444045 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(l1042320,("anf_tail_app")):R.ffi.throwNonFunApp(L[512],mk_DASH_id70825.$var,[l1042320,("anf_tail_app")]);
};
try {
if(--R.GAS > 0) {
$z40384039 = $f40444045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40444045,
"from":L[512]});
}
} catch($e40364037) {
if(R.isCont($e40364037)) {
var $ss40404041 = {"from":L[512],
"go":function(name1072319) {
return $Hname7562318(name1072319,N512,l1042320,x1032321);
}};
$e40364037.stack[R.EXN_STACKHEIGHT++] = $ss40404041;
}
if(R.isPyretException($e40364037)) {
$e40364037.pyretStack.push(L[512]);
}
throw $e40364037;
}
var $ret40424043 = $Hname7562318($z40384039,N512,l1042320,x1032321);
++R.GAS;
return $ret40424043;
});
var anf_arg994020 = R.makeObject({"a-app":anf_obj984033});
var anf_arg1024021 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[510],0,arguments);
}
var anf_fun1014032 = G(N512,"a-lettable",L[511]);
var $z40244025 = D;
var $f40304031 = function(_) {
return R.isFunction(anf_fun1014032)?anf_fun1014032.app(x1032321):R.ffi.throwNonFunApp(L[510],anf_fun1014032,[x1032321]);
};
try {
if(--R.GAS > 0) {
$z40244025 = $f40304031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40304031,
"from":L[510]});
}
} catch($e40224023) {
if(R.isCont($e40224023)) {
var $ss40264027 = {"from":L[510],
"go":function(ann_DASH_check_DASH_temp1002317) {
return $Hann_DASH_check_DASH_temp7572316(ann_DASH_check_DASH_temp1002317);
}};
$e40224023.stack[R.EXN_STACKHEIGHT++] = $ss40264027;
}
if(R.isPyretException($e40224023)) {
$e40224023.pyretStack.push(L[510]);
}
throw $e40224023;
}
var $ret40284029 = $Hann_DASH_check_DASH_temp7572316($z40244025);
++R.GAS;
return $ret40284029;
});
var $z40114012 = D;
var $f40174018 = function(_) {
return R.isFunction(anf_fun894019)?anf_fun894019.app(anf_arg994020,anf_arg1024021):R.ffi.throwNonFunApp(L[509],anf_fun894019,[anf_arg994020,anf_arg1024021]);
};
try {
if(--R.GAS > 0) {
$z40114012 = $f40174018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40174018,
"from":L[509]});
}
} catch($e40094010) {
if(R.isCont($e40094010)) {
var $ss40134014 = {"from":L[509],
"go":function(ann_DASH_check_DASH_temp882315) {
return $Hann_DASH_check_DASH_temp7582314(ann_DASH_check_DASH_temp882315);
}};
$e40094010.stack[R.EXN_STACKHEIGHT++] = $ss40134014;
}
if(R.isPyretException($e40094010)) {
$e40094010.pyretStack.push(L[509]);
}
throw $e40094010;
}
var $ret40154016 = $Hann_DASH_check_DASH_temp7582314($z40114012);
++R.GAS;
return $ret40154016;
});
var $z40004001 = D;
var $f40064007 = function(_) {
return R.isFunction(k_DASH_cont752020.$var)?k_DASH_cont752020.$var.app(anf_arg1034008):R.ffi.throwNonFunApp(L[508],k_DASH_cont752020.$var,[anf_arg1034008]);
};
try {
if(--R.GAS > 0) {
$z40004001 = $f40064007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40064007,
"from":L[508]});
}
} catch($e39983999) {
if(R.isCont($e39983999)) {
var $ss40024003 = {"from":L[508],
"go":function(anf_arg1042300) {
return $Hanf_arg7602299(anf_arg1042300,N620,anf86820,e1022301);
}};
$e39983999.stack[R.EXN_STACKHEIGHT++] = $ss40024003;
}
if(R.isPyretException($e39983999)) {
$e39983999.pyretStack.push(L[508]);
}
throw $e39983999;
}
var $ret40044005 = $Hanf_arg7602299($z40004001,N620,anf86820,e1022301);
++R.GAS;
return $ret40044005;
});
});
anf_DASH_term78497.$var = anf_assign1052678;
var anf_assign1092679 = R.makeFunction(function(l1083984,id1093985) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[505],2,arguments);
}
var anf_fun1073996 = G(N512,"a-bind",L[507]);
var anf_arg1083997 = G(A110,"a-blank",L[506]);
var $z39883989 = D;
var $f39943995 = function(_) {
return R.isFunction(anf_fun1073996)?anf_fun1073996.app(l1083984,id1093985,anf_arg1083997):R.ffi.throwNonFunApp(L[505],anf_fun1073996,[l1083984,id1093985,anf_arg1083997]);
};
try {
if(--R.GAS > 0) {
$z39883989 = $f39943995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39943995,
"from":L[505]});
}
} catch($e39863987) {
if(R.isCont($e39863987)) {
var $ss39903991 = {"from":L[505],
"go":function(ann_DASH_check_DASH_temp1062298) {
return $Hann_DASH_check_DASH_temp7612297(ann_DASH_check_DASH_temp1062298);
}};
$e39863987.stack[R.EXN_STACKHEIGHT++] = $ss39903991;
}
if(R.isPyretException($e39863987)) {
$e39863987.pyretStack.push(L[505]);
}
throw $e39863987;
}
var $ret39923993 = $Hann_DASH_check_DASH_temp7612297($z39883989);
++R.GAS;
return $ret39923993;
});
bind792632.$var = anf_assign1092679;
var anf_assign1182681 = R.makeFunction(function(b1103952) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[501],1,arguments);
}
var cases_DASH_val153983 = b1103952;
var anf_fun1113963 = G(cases_DASH_val153983,"_match",L[502]);
var anf_obj1143967 = R.makeFunction(function(l1113968,shadows1123969,id1133970,ann1143971) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[503],4,arguments);
}
var anf_fun1133982 = G(N512,"a-bind",L[504]);
var $z39743975 = D;
var $f39803981 = function(_) {
return R.isFunction(anf_fun1133982)?anf_fun1133982.app(l1113968,id1133970,ann1143971):R.ffi.throwNonFunApp(L[503],anf_fun1133982,[l1113968,id1133970,ann1143971]);
};
try {
if(--R.GAS > 0) {
$z39743975 = $f39803981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39803981,
"from":L[503]});
}
} catch($e39723973) {
if(R.isCont($e39723973)) {
var $ss39763977 = {"from":L[503],
"go":function(ann_DASH_check_DASH_temp1122296) {
return $Hann_DASH_check_DASH_temp7622295(ann_DASH_check_DASH_temp1122296);
}};
$e39723973.stack[R.EXN_STACKHEIGHT++] = $ss39763977;
}
if(R.isPyretException($e39723973)) {
$e39723973.pyretStack.push(L[503]);
}
throw $e39723973;
}
var $ret39783979 = $Hann_DASH_check_DASH_temp7622295($z39743975);
++R.GAS;
return $ret39783979;
});
var anf_arg1153964 = R.makeObject({"s-bind":anf_obj1143967});
var anf_arg1173965 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[502],0,arguments);
}
var ann_DASH_check_DASH_temp1163966 = R.throwNoBranchesMatched(L[502],("cases"));
return ann_DASH_check_DASH_temp1163966;
});
var $z39553956 = D;
var $f39613962 = function(_) {
return R.isFunction(anf_fun1113963)?anf_fun1113963.app(anf_arg1153964,anf_arg1173965):R.ffi.throwNonFunApp(L[501],anf_fun1113963,[anf_arg1153964,anf_arg1173965]);
};
try {
if(--R.GAS > 0) {
$z39553956 = $f39613962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39613962,
"from":L[501]});
}
} catch($e39533954) {
if(R.isCont($e39533954)) {
var $ss39573958 = {"from":L[501],
"go":function(ann_DASH_check_DASH_temp1102294) {
return $Hann_DASH_check_DASH_temp7632293(ann_DASH_check_DASH_temp1102294);
}};
$e39533954.stack[R.EXN_STACKHEIGHT++] = $ss39573958;
}
if(R.isPyretException($e39533954)) {
$e39533954.pyretStack.push(L[501]);
}
throw $e39533954;
}
var $ret39593960 = $Hann_DASH_check_DASH_temp7632293($z39553956);
++R.GAS;
return $ret39593960;
});
anf_DASH_bind802680.$var = anf_assign1182681;
var anf_assign1352682 = R.makeFunction(function(expr1152244,name_DASH_hint1163903,k1172261) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[236],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[498],"A",A218,"Expr"),$type$String9,R.Function],[expr1152244,name_DASH_hint1163903,k1172261],[L[498],L[499],L[500]],function() {
var anf_arg1333914 = R.makeFunction(function(lettable1182262) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[494],1,arguments);
}
var cases_DASH_val163951 = lettable1182262;
var anf_fun1213925 = G(cases_DASH_val163951,"_match",L[242]);
var anf_obj1233939 = R.makeFunction(function(v1193940) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[497],1,arguments);
}
var $z39433944 = D;
var $f39493950 = function(_) {
return R.isFunction(k1172261)?k1172261.app(v1193940):R.ffi.throwNonFunApp(L[497],k1172261,[v1193940]);
};
try {
if(--R.GAS > 0) {
$z39433944 = $f39493950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39493950,
"from":L[497]});
}
} catch($e39413942) {
if(R.isCont($e39413942)) {
var $ss39453946 = {"from":L[497],
"go":function(ann_DASH_check_DASH_temp1222292) {
return $Hann_DASH_check_DASH_temp7642291(ann_DASH_check_DASH_temp1222292);
}};
$e39413942.stack[R.EXN_STACKHEIGHT++] = $ss39453946;
}
if(R.isPyretException($e39413942)) {
$e39413942.pyretStack.push(L[497]);
}
throw $e39413942;
}
var $ret39473948 = $Hann_DASH_check_DASH_temp7642291($z39433944);
++R.GAS;
return $ret39473948;
});
var anf_arg1243926 = R.makeObject({"a-val":anf_obj1233939});
var anf_arg1323927 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[242],0,arguments);
}
var anf_arg1263938 = G(expr1152244,"l",L[496]);
var $z39303931 = D;
var $f39363937 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(anf_arg1263938,name_DASH_hint1163903):R.ffi.throwNonFunApp(L[495],mk_DASH_id70825.$var,[anf_arg1263938,name_DASH_hint1163903]);
};
try {
if(--R.GAS > 0) {
$z39303931 = $f39363937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39363937,
"from":L[495]});
}
} catch($e39283929) {
if(R.isCont($e39283929)) {
var $ss39323933 = {"from":L[495],
"go":function(t1202260) {
return $Ht7672259(t1202260,N512,expr1152244,k1172261,lettable1182262);
}};
$e39283929.stack[R.EXN_STACKHEIGHT++] = $ss39323933;
}
if(R.isPyretException($e39283929)) {
$e39283929.pyretStack.push(L[495]);
}
throw $e39283929;
}
var $ret39343935 = $Ht7672259($z39303931,N512,expr1152244,k1172261,lettable1182262);
++R.GAS;
return $ret39343935;
});
var $z39173918 = D;
var $f39233924 = function(_) {
return R.isFunction(anf_fun1213925)?anf_fun1213925.app(anf_arg1243926,anf_arg1323927):R.ffi.throwNonFunApp(L[494],anf_fun1213925,[anf_arg1243926,anf_arg1323927]);
};
try {
if(--R.GAS > 0) {
$z39173918 = $f39233924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39233924,
"from":L[494]});
}
} catch($e39153916) {
if(R.isCont($e39153916)) {
var $ss39193920 = {"from":L[494],
"go":function(ann_DASH_check_DASH_temp1202258) {
return $Hann_DASH_check_DASH_temp7682257(ann_DASH_check_DASH_temp1202258);
}};
$e39153916.stack[R.EXN_STACKHEIGHT++] = $ss39193920;
}
if(R.isPyretException($e39153916)) {
$e39153916.pyretStack.push(L[494]);
}
throw $e39153916;
}
var $ret39213922 = $Hann_DASH_check_DASH_temp7682257($z39173918);
++R.GAS;
return $ret39213922;
});
var $z39063907 = D;
var $f39123913 = function(_) {
return R.isFunction(k_DASH_cont752020.$var)?k_DASH_cont752020.$var.app(anf_arg1333914):R.ffi.throwNonFunApp(L[493],k_DASH_cont752020.$var,[anf_arg1333914]);
};
try {
if(--R.GAS > 0) {
$z39063907 = $f39123913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39123913,
"from":L[493]});
}
} catch($e39043905) {
if(R.isCont($e39043905)) {
var $ss39083909 = {"from":L[493],
"go":function(anf_arg1342243) {
return $Hanf_arg7702242(anf_arg1342243,N620,anf86820,expr1152244);
}};
$e39043905.stack[R.EXN_STACKHEIGHT++] = $ss39083909;
}
if(R.isPyretException($e39043905)) {
$e39043905.pyretStack.push(L[493]);
}
throw $e39043905;
}
var $ret39103911 = $Hanf_arg7702242($z39063907,N620,anf86820,expr1152244);
++R.GAS;
return $ret39103911;
});
});
anf_DASH_name81136.$var = anf_assign1352682;
var anf_assign1542683 = R.makeFunction(function(exprs1213837,name_DASH_hint1223838,k1232202) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[483],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[489],"lists",lists1022,"List"),$type$String9,R.Function],[exprs1213837,name_DASH_hint1223838,k1232202],[L[490],L[491],L[492]],function() {
var cases_DASH_val173902 = exprs1213837;
var anf_fun1373849 = G(cases_DASH_val173902,"_match",L[484]);
var anf_obj1413853 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[234],0,arguments);
}
var anf_fun1393901 = G(list25501,"make",L[488]);
var $z38933894 = D;
var $f38993900 = function(_) {
return R.isFunction(anf_fun1393901)?anf_fun1393901.app([]):R.ffi.throwNonFunApp(L[488],anf_fun1393901,[[]]);
};
try {
if(--R.GAS > 0) {
$z38933894 = $f38993900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38993900,
"from":L[488]});
}
} catch($e38913892) {
if(R.isCont($e38913892)) {
var $ss38953896 = {"from":L[488],
"go":function(anf_arg1402229) {
return $Hanf_arg7722228(anf_arg1402229,k1232202);
}};
$e38913892.stack[R.EXN_STACKHEIGHT++] = $ss38953896;
}
if(R.isPyretException($e38913892)) {
$e38913892.pyretStack.push(L[488]);
}
throw $e38913892;
}
var $ret38973898 = $Hanf_arg7722228($z38933894,k1232202);
++R.GAS;
return $ret38973898;
});
var anf_obj1503854 = R.makeFunction(function(f1243855,r1253856) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[485],2,arguments);
}
var anf_arg1493867 = R.makeFunction(function(v1263868) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[486],1,arguments);
}
var anf_arg1483879 = R.makeFunction(function(vs1272203) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[233],1,arguments);
}
var anf_fun1453890 = G(list25501,"make",L[487]);
var $z38823883 = D;
var $f38883889 = function(_) {
return R.isFunction(anf_fun1453890)?anf_fun1453890.app([v1263868]):R.ffi.throwNonFunApp(L[487],anf_fun1453890,[[v1263868]]);
};
try {
if(--R.GAS > 0) {
$z38823883 = $f38883889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38883889,
"from":L[487]});
}
} catch($e38803881) {
if(R.isCont($e38803881)) {
var $ss38843885 = {"from":L[487],
"go":function(anf_arg1462201) {
return $Hanf_arg7752200(anf_arg1462201,k1232202,vs1272203,_plus4);
}};
$e38803881.stack[R.EXN_STACKHEIGHT++] = $ss38843885;
}
if(R.isPyretException($e38803881)) {
$e38803881.pyretStack.push(L[487]);
}
throw $e38803881;
}
var $ret38863887 = $Hanf_arg7752200($z38823883,k1232202,vs1272203,_plus4);
++R.GAS;
return $ret38863887;
});
var $z38713872 = D;
var $f38773878 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(r1253856,name_DASH_hint1223838,anf_arg1483879):R.ffi.throwNonFunApp(L[486],anf_DASH_name_DASH_rec82135.$var,[r1253856,name_DASH_hint1223838,anf_arg1483879]);
};
try {
if(--R.GAS > 0) {
$z38713872 = $f38773878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38773878,
"from":L[486]});
}
} catch($e38693870) {
if(R.isCont($e38693870)) {
var $ss38733874 = {"from":L[486],
"go":function(ann_DASH_check_DASH_temp1432199) {
return $Hann_DASH_check_DASH_temp7762198(ann_DASH_check_DASH_temp1432199);
}};
$e38693870.stack[R.EXN_STACKHEIGHT++] = $ss38733874;
}
if(R.isPyretException($e38693870)) {
$e38693870.pyretStack.push(L[486]);
}
throw $e38693870;
}
var $ret38753876 = $Hann_DASH_check_DASH_temp7762198($z38713872);
++R.GAS;
return $ret38753876;
});
var $z38593860 = D;
var $f38653866 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(f1243855,name_DASH_hint1223838,anf_arg1493867):R.ffi.throwNonFunApp(L[485],anf_DASH_name81136.$var,[f1243855,name_DASH_hint1223838,anf_arg1493867]);
};
try {
if(--R.GAS > 0) {
$z38593860 = $f38653866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38653866,
"from":L[485]});
}
} catch($e38573858) {
if(R.isCont($e38573858)) {
var $ss38613862 = {"from":L[485],
"go":function(ann_DASH_check_DASH_temp1422197) {
return $Hann_DASH_check_DASH_temp7772196(ann_DASH_check_DASH_temp1422197);
}};
$e38573858.stack[R.EXN_STACKHEIGHT++] = $ss38613862;
}
if(R.isPyretException($e38573858)) {
$e38573858.pyretStack.push(L[485]);
}
throw $e38573858;
}
var $ret38633864 = $Hann_DASH_check_DASH_temp7772196($z38593860);
++R.GAS;
return $ret38633864;
});
var anf_arg1513850 = R.makeObject({"empty":anf_obj1413853,
"link":anf_obj1503854});
var anf_arg1533851 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[484],0,arguments);
}
var ann_DASH_check_DASH_temp1523852 = R.throwNoBranchesMatched(L[484],("cases"));
return ann_DASH_check_DASH_temp1523852;
});
var $z38413842 = D;
var $f38473848 = function(_) {
return R.isFunction(anf_fun1373849)?anf_fun1373849.app(anf_arg1513850,anf_arg1533851):R.ffi.throwNonFunApp(L[483],anf_fun1373849,[anf_arg1513850,anf_arg1533851]);
};
try {
if(--R.GAS > 0) {
$z38413842 = $f38473848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38473848,
"from":L[483]});
}
} catch($e38393840) {
if(R.isCont($e38393840)) {
var $ss38433844 = {"from":L[483],
"go":function(ann_DASH_check_DASH_temp1362195) {
return $Hann_DASH_check_DASH_temp7782194(ann_DASH_check_DASH_temp1362195,N620);
}};
$e38393840.stack[R.EXN_STACKHEIGHT++] = $ss38433844;
}
if(R.isPyretException($e38393840)) {
$e38393840.pyretStack.push(L[483]);
}
throw $e38393840;
}
var $ret38453846 = $Hann_DASH_check_DASH_temp7782194($z38413842,N620);
++R.GAS;
return $ret38453846;
});
});
anf_DASH_name_DASH_rec82135.$var = anf_assign1542683;
var anf_assign1662685 = R.makeFunction(function(e1283806) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[476],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[482],"A",A218,"Program")],[e1283806],[L[482]],function() {
var cases_DASH_val183836 = e1283806;
var anf_fun1563817 = G(cases_DASH_val183836,"_match",L[477]);
var anf_obj1623821 = R.makeFunction(function(l1292169,$underscore1303822,$underscore1313823,imports1323824,block1332168) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[231],5,arguments);
}
var anf_fun1582167 = G(N512,"a-program",L[481]);
var anf_fun1593835 = G(imports1323824,"map",L[480]);
var $z38273828 = D;
var $f38333834 = function(_) {
return R.isFunction(anf_fun1593835)?anf_fun1593835.app(anf_DASH_import842686.$var === D?U(L[478],"anf-import"):anf_DASH_import842686.$var):R.ffi.throwNonFunApp(L[479],anf_fun1593835,[anf_DASH_import842686.$var === D?U(L[478],"anf-import"):anf_DASH_import842686.$var]);
};
try {
if(--R.GAS > 0) {
$z38273828 = $f38333834();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38333834,
"from":L[479]});
}
} catch($e38253826) {
if(R.isCont($e38253826)) {
var $ss38293830 = {"from":L[479],
"go":function(anf_arg1602166) {
return $Hanf_arg7812165(anf_arg1602166,anf_DASH_term78497,anf_fun1582167,block1332168,l1292169);
}};
$e38253826.stack[R.EXN_STACKHEIGHT++] = $ss38293830;
}
if(R.isPyretException($e38253826)) {
$e38253826.pyretStack.push(L[479]);
}
throw $e38253826;
}
var $ret38313832 = $Hanf_arg7812165($z38273828,anf_DASH_term78497,anf_fun1582167,block1332168,l1292169);
++R.GAS;
return $ret38313832;
});
var anf_arg1633818 = R.makeObject({"s-program":anf_obj1623821});
var anf_arg1653819 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[477],0,arguments);
}
var ann_DASH_check_DASH_temp1643820 = R.throwNoBranchesMatched(L[477],("cases"));
return ann_DASH_check_DASH_temp1643820;
});
var $z38093810 = D;
var $f38153816 = function(_) {
return R.isFunction(anf_fun1563817)?anf_fun1563817.app(anf_arg1633818,anf_arg1653819):R.ffi.throwNonFunApp(L[476],anf_fun1563817,[anf_arg1633818,anf_arg1653819]);
};
try {
if(--R.GAS > 0) {
$z38093810 = $f38153816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38153816,
"from":L[476]});
}
} catch($e38073808) {
if(R.isCont($e38073808)) {
var $ss38113812 = {"from":L[476],
"go":function(ann_DASH_check_DASH_temp1552164) {
return $Hann_DASH_check_DASH_temp7822163(ann_DASH_check_DASH_temp1552164);
}};
$e38073808.stack[R.EXN_STACKHEIGHT++] = $ss38113812;
}
if(R.isPyretException($e38073808)) {
$e38073808.pyretStack.push(L[476]);
}
throw $e38073808;
}
var $ret38133814 = $Hann_DASH_check_DASH_temp7822163($z38093810);
++R.GAS;
return $ret38133814;
});
});
anf_DASH_program832684.$var = anf_assign1662685;
var anf_assign1982687 = R.makeFunction(function(i1343700) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[461],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[475],"A",A218,"Import")],[i1343700],[L[475]],function() {
var cases_DASH_val213805 = i1343700;
var anf_fun1683711 = G(cases_DASH_val213805,"_match",L[462]);
var anf_obj1813715 = R.makeFunction(function(l1352144,f1363761,name1372145) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[228],3,arguments);
}
var cases_DASH_val193804 = f1363761;
var anf_fun1703772 = G(cases_DASH_val193804,"_match",L[470]);
var anf_obj1733776 = R.makeFunction(function($underscore1393791,fname1403792) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[473],2,arguments);
}
var anf_fun1723803 = G(N512,"a-import-file",L[474]);
var $z37953796 = D;
var $f38013802 = function(_) {
return R.isFunction(anf_fun1723803)?anf_fun1723803.app(l1352144,fname1403792):R.ffi.throwNonFunApp(L[473],anf_fun1723803,[l1352144,fname1403792]);
};
try {
if(--R.GAS > 0) {
$z37953796 = $f38013802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38013802,
"from":L[473]});
}
} catch($e37933794) {
if(R.isCont($e37933794)) {
var $ss37973798 = {"from":L[473],
"go":function(ann_DASH_check_DASH_temp1712162) {
return $Hann_DASH_check_DASH_temp7832161(ann_DASH_check_DASH_temp1712162);
}};
$e37933794.stack[R.EXN_STACKHEIGHT++] = $ss37973798;
}
if(R.isPyretException($e37933794)) {
$e37933794.pyretStack.push(L[473]);
}
throw $e37933794;
}
var $ret37993800 = $Hann_DASH_check_DASH_temp7832161($z37953796);
++R.GAS;
return $ret37993800;
});
var anf_obj1763777 = R.makeFunction(function($underscore1413778,mod1423779) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[471],2,arguments);
}
var anf_fun1753790 = G(N512,"a-import-builtin",L[472]);
var $z37823783 = D;
var $f37883789 = function(_) {
return R.isFunction(anf_fun1753790)?anf_fun1753790.app(l1352144,mod1423779):R.ffi.throwNonFunApp(L[471],anf_fun1753790,[l1352144,mod1423779]);
};
try {
if(--R.GAS > 0) {
$z37823783 = $f37883789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37883789,
"from":L[471]});
}
} catch($e37803781) {
if(R.isCont($e37803781)) {
var $ss37843785 = {"from":L[471],
"go":function(ann_DASH_check_DASH_temp1742160) {
return $Hann_DASH_check_DASH_temp7842159(ann_DASH_check_DASH_temp1742160);
}};
$e37803781.stack[R.EXN_STACKHEIGHT++] = $ss37843785;
}
if(R.isPyretException($e37803781)) {
$e37803781.pyretStack.push(L[471]);
}
throw $e37803781;
}
var $ret37863787 = $Hann_DASH_check_DASH_temp7842159($z37823783);
++R.GAS;
return $ret37863787;
});
var anf_arg1773773 = R.makeObject({"s-file-import":anf_obj1733776,
"s-const-import":anf_obj1763777});
var anf_arg1793774 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[470],0,arguments);
}
var ann_DASH_check_DASH_temp1783775 = R.throwNoBranchesMatched(L[470],("cases"));
return ann_DASH_check_DASH_temp1783775;
});
var $z37643765 = D;
var $f37703771 = function(_) {
return R.isFunction(anf_fun1703772)?anf_fun1703772.app(anf_arg1773773,anf_arg1793774):R.ffi.throwNonFunApp(L[469],anf_fun1703772,[anf_arg1773773,anf_arg1793774]);
};
try {
if(--R.GAS > 0) {
$z37643765 = $f37703771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37703771,
"from":L[469]});
}
} catch($e37623763) {
if(R.isCont($e37623763)) {
var $ss37663767 = {"from":L[469],
"go":function(itype1382143) {
return $Hitype7862142(itype1382143,N512,l1352144,name1372145);
}};
$e37623763.stack[R.EXN_STACKHEIGHT++] = $ss37663767;
}
if(R.isPyretException($e37623763)) {
$e37623763.pyretStack.push(L[469]);
}
throw $e37623763;
}
var $ret37683769 = $Hitype7862142($z37643765,N512,l1352144,name1372145);
++R.GAS;
return $ret37683769;
});
var anf_obj1943716 = R.makeFunction(function(l1432122,f1443717,name1452123,types1462124) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[226],4,arguments);
}
var cases_DASH_val203760 = f1443717;
var anf_fun1833728 = G(cases_DASH_val203760,"_match",L[464]);
var anf_obj1863732 = R.makeFunction(function($underscore1483747,fname1493748) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[467],2,arguments);
}
var anf_fun1853759 = G(N512,"a-import-file",L[468]);
var $z37513752 = D;
var $f37573758 = function(_) {
return R.isFunction(anf_fun1853759)?anf_fun1853759.app(l1432122,fname1493748):R.ffi.throwNonFunApp(L[467],anf_fun1853759,[l1432122,fname1493748]);
};
try {
if(--R.GAS > 0) {
$z37513752 = $f37573758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37573758,
"from":L[467]});
}
} catch($e37493750) {
if(R.isCont($e37493750)) {
var $ss37533754 = {"from":L[467],
"go":function(ann_DASH_check_DASH_temp1842141) {
return $Hann_DASH_check_DASH_temp7872140(ann_DASH_check_DASH_temp1842141);
}};
$e37493750.stack[R.EXN_STACKHEIGHT++] = $ss37533754;
}
if(R.isPyretException($e37493750)) {
$e37493750.pyretStack.push(L[467]);
}
throw $e37493750;
}
var $ret37553756 = $Hann_DASH_check_DASH_temp7872140($z37513752);
++R.GAS;
return $ret37553756;
});
var anf_obj1893733 = R.makeFunction(function($underscore1503734,mod1513735) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[465],2,arguments);
}
var anf_fun1883746 = G(N512,"a-import-builtin",L[466]);
var $z37383739 = D;
var $f37443745 = function(_) {
return R.isFunction(anf_fun1883746)?anf_fun1883746.app(l1432122,mod1513735):R.ffi.throwNonFunApp(L[465],anf_fun1883746,[l1432122,mod1513735]);
};
try {
if(--R.GAS > 0) {
$z37383739 = $f37443745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37443745,
"from":L[465]});
}
} catch($e37363737) {
if(R.isCont($e37363737)) {
var $ss37403741 = {"from":L[465],
"go":function(ann_DASH_check_DASH_temp1872139) {
return $Hann_DASH_check_DASH_temp7882138(ann_DASH_check_DASH_temp1872139);
}};
$e37363737.stack[R.EXN_STACKHEIGHT++] = $ss37403741;
}
if(R.isPyretException($e37363737)) {
$e37363737.pyretStack.push(L[465]);
}
throw $e37363737;
}
var $ret37423743 = $Hann_DASH_check_DASH_temp7882138($z37383739);
++R.GAS;
return $ret37423743;
});
var anf_arg1903729 = R.makeObject({"s-file-import":anf_obj1863732,
"s-const-import":anf_obj1893733});
var anf_arg1923730 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[464],0,arguments);
}
var ann_DASH_check_DASH_temp1913731 = R.throwNoBranchesMatched(L[464],("cases"));
return ann_DASH_check_DASH_temp1913731;
});
var $z37203721 = D;
var $f37263727 = function(_) {
return R.isFunction(anf_fun1833728)?anf_fun1833728.app(anf_arg1903729,anf_arg1923730):R.ffi.throwNonFunApp(L[463],anf_fun1833728,[anf_arg1903729,anf_arg1923730]);
};
try {
if(--R.GAS > 0) {
$z37203721 = $f37263727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37263727,
"from":L[463]});
}
} catch($e37183719) {
if(R.isCont($e37183719)) {
var $ss37223723 = {"from":L[463],
"go":function(itype1472121) {
return $Hitype7902120(itype1472121,N512,l1432122,name1452123,types1462124);
}};
$e37183719.stack[R.EXN_STACKHEIGHT++] = $ss37223723;
}
if(R.isPyretException($e37183719)) {
$e37183719.pyretStack.push(L[463]);
}
throw $e37183719;
}
var $ret37243725 = $Hitype7902120($z37203721,N512,l1432122,name1452123,types1462124);
++R.GAS;
return $ret37243725;
});
var anf_arg1953712 = R.makeObject({"s-import":anf_obj1813715,
"s-import-types":anf_obj1943716});
var anf_arg1973713 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[462],0,arguments);
}
var ann_DASH_check_DASH_temp1963714 = R.throwNoBranchesMatched(L[462],("cases"));
return ann_DASH_check_DASH_temp1963714;
});
var $z37033704 = D;
var $f37093710 = function(_) {
return R.isFunction(anf_fun1683711)?anf_fun1683711.app(anf_arg1953712,anf_arg1973713):R.ffi.throwNonFunApp(L[461],anf_fun1683711,[anf_arg1953712,anf_arg1973713]);
};
try {
if(--R.GAS > 0) {
$z37033704 = $f37093710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37093710,
"from":L[461]});
}
} catch($e37013702) {
if(R.isCont($e37013702)) {
var $ss37053706 = {"from":L[461],
"go":function(ann_DASH_check_DASH_temp1672119) {
return $Hann_DASH_check_DASH_temp7912118(ann_DASH_check_DASH_temp1672119);
}};
$e37013702.stack[R.EXN_STACKHEIGHT++] = $ss37053706;
}
if(R.isPyretException($e37013702)) {
$e37013702.pyretStack.push(L[461]);
}
throw $e37013702;
}
var $ret37073708 = $Hann_DASH_check_DASH_temp7912118($z37033704);
++R.GAS;
return $ret37073708;
});
});
anf_DASH_import842686.$var = anf_assign1982687;
var anf_assign2312689 = R.makeFunction(function(es_DASH_init1523649,k1532021) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[451],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[458],"lists",lists1022,"List"),ANFCont6637],[es_DASH_init1523649,k1532021],[L[459],L[460]],function() {
var anf_DASH_block_DASH_help1542018 = {"$var":D,
"$name":"anf-block-help"};
var anf_assign2303650 = R.makeFunction(function(es1553661) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[452],1,arguments);
}
var cases_DASH_val243699 = es1553661;
var anf_fun2013672 = G(cases_DASH_val243699,"_match",L[453]);
var anf_obj2033676 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[457],0,arguments);
}
var $z36913692 = D;
var $f36973698 = function(_) {
return R.isFunction(raise7)?raise7.app(("Empty block")):R.ffi.throwNonFunApp(L[457],raise7,[("Empty block")]);
};
try {
if(--R.GAS > 0) {
$z36913692 = $f36973698();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36973698,
"from":L[457]});
}
} catch($e36893690) {
if(R.isCont($e36893690)) {
var $ss36933694 = {"from":L[457],
"go":function(ann_DASH_check_DASH_temp2022117) {
return $Hann_DASH_check_DASH_temp7922116(ann_DASH_check_DASH_temp2022117);
}};
$e36893690.stack[R.EXN_STACKHEIGHT++] = $ss36933694;
}
if(R.isPyretException($e36893690)) {
$e36893690.pyretStack.push(L[457]);
}
throw $e36893690;
}
var $ret36953696 = $Hann_DASH_check_DASH_temp7922116($z36913692);
++R.GAS;
return $ret36953696;
});
var anf_obj2263677 = R.makeFunction(function(f1562019,r1572022) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[454],2,arguments);
}
var anf_fun2053688 = G(r1572022,"length",L[456]);
var $z36803681 = D;
var $f36863687 = function(_) {
return R.isFunction(anf_fun2053688)?anf_fun2053688.app():R.ffi.throwNonFunApp(L[455],anf_fun2053688,[]);
};
try {
if(--R.GAS > 0) {
$z36803681 = $f36863687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36863687,
"from":L[455]});
}
} catch($e36783679) {
if(R.isCont($e36783679)) {
var $ss36823683 = {"from":L[455],
"go":function(anf_arg2062017) {
return $Hanf_arg7992016(anf_arg2062017,N512,anf_DASH_block_DASH_help1542018,anf86820,f1562019,k_DASH_cont752020,k1532021,r1572022);
}};
$e36783679.stack[R.EXN_STACKHEIGHT++] = $ss36823683;
}
if(R.isPyretException($e36783679)) {
$e36783679.pyretStack.push(L[455]);
}
throw $e36783679;
}
var $ret36843685 = $Hanf_arg7992016($z36803681,N512,anf_DASH_block_DASH_help1542018,anf86820,f1562019,k_DASH_cont752020,k1532021,r1572022);
++R.GAS;
return $ret36843685;
});
var anf_arg2273673 = R.makeObject({"empty":anf_obj2033676,
"link":anf_obj2263677});
var anf_arg2293674 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[453],0,arguments);
}
var ann_DASH_check_DASH_temp2283675 = R.throwNoBranchesMatched(L[453],("cases"));
return ann_DASH_check_DASH_temp2283675;
});
var $z36643665 = D;
var $f36703671 = function(_) {
return R.isFunction(anf_fun2013672)?anf_fun2013672.app(anf_arg2273673,anf_arg2293674):R.ffi.throwNonFunApp(L[452],anf_fun2013672,[anf_arg2273673,anf_arg2293674]);
};
try {
if(--R.GAS > 0) {
$z36643665 = $f36703671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36703671,
"from":L[452]});
}
} catch($e36623663) {
if(R.isCont($e36623663)) {
var $ss36663667 = {"from":L[452],
"go":function(ann_DASH_check_DASH_temp2002015) {
return $Hann_DASH_check_DASH_temp8002014(ann_DASH_check_DASH_temp2002015);
}};
$e36623663.stack[R.EXN_STACKHEIGHT++] = $ss36663667;
}
if(R.isPyretException($e36623663)) {
$e36623663.pyretStack.push(L[452]);
}
throw $e36623663;
}
var $ret36683669 = $Hann_DASH_check_DASH_temp8002014($z36643665);
++R.GAS;
return $ret36683669;
});
anf_DASH_block_DASH_help1542018.$var = anf_assign2303650;
var $z36533654 = D;
var $f36593660 = function(_) {
return R.isFunction(anf_DASH_block_DASH_help1542018.$var)?anf_DASH_block_DASH_help1542018.$var.app(es_DASH_init1523649):R.ffi.throwNonFunApp(L[451],anf_DASH_block_DASH_help1542018.$var,[es_DASH_init1523649]);
};
try {
if(--R.GAS > 0) {
$z36533654 = $f36593660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36593660,
"from":L[451]});
}
} catch($e36513652) {
if(R.isCont($e36513652)) {
var $ss36553656 = {"from":L[451],
"go":function(ann_DASH_check_DASH_temp1992013) {
return $Hann_DASH_check_DASH_temp8012012(ann_DASH_check_DASH_temp1992013);
}};
$e36513652.stack[R.EXN_STACKHEIGHT++] = $ss36553656;
}
if(R.isPyretException($e36513652)) {
$e36513652.pyretStack.push(L[451]);
}
throw $e36513652;
}
var $ret36573658 = $Hann_DASH_check_DASH_temp8012012($z36533654);
++R.GAS;
return $ret36573658;
});
});
anf_DASH_block852688.$var = anf_assign2312689;
var anf_assign7162690 = R.makeFunction(function(e1592703,k160138) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[288],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[449],"A",A218,"Expr"),ANFCont6637],[e1592703,k160138],[L[449],L[450]],function() {
var cases_DASH_val413648 = e1592703;
var anf_fun2332714 = G(cases_DASH_val413648,"_match",L[2]);
var anf_obj2442727 = R.makeFunction(function(l1611999,answer1623597,provides1633598,types1643599,checks1653600) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[443],5,arguments);
}
var anf_arg2433611 = R.makeFunction(function(ans1663612) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[444],1,arguments);
}
var anf_arg2423623 = R.makeFunction(function(provs1673624) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[445],1,arguments);
}
var anf_arg2413635 = R.makeFunction(function(chks1683636) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[215],1,arguments);
}
var anf_fun2381998 = G(k160138,"apply",L[448]);
var anf_fun2393647 = G(N512,"a-module",L[447]);
var $z36393640 = D;
var $f36453646 = function(_) {
return R.isFunction(anf_fun2393647)?anf_fun2393647.app(l1611999,ans1663612,provs1673624,types1643599,chks1683636):R.ffi.throwNonFunApp(L[446],anf_fun2393647,[l1611999,ans1663612,provs1673624,types1643599,chks1683636]);
};
try {
if(--R.GAS > 0) {
$z36393640 = $f36453646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36453646,
"from":L[446]});
}
} catch($e36373638) {
if(R.isCont($e36373638)) {
var $ss36413642 = {"from":L[446],
"go":function(anf_arg2401997) {
return $Hanf_arg8031996(anf_arg2401997,anf_fun2381998,l1611999);
}};
$e36373638.stack[R.EXN_STACKHEIGHT++] = $ss36413642;
}
if(R.isPyretException($e36373638)) {
$e36373638.pyretStack.push(L[446]);
}
throw $e36373638;
}
var $ret36433644 = $Hanf_arg8031996($z36393640,anf_fun2381998,l1611999);
++R.GAS;
return $ret36433644;
});
var $z36273628 = D;
var $f36333634 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(checks1653600,("checks"),anf_arg2413635):R.ffi.throwNonFunApp(L[445],anf_DASH_name81136.$var,[checks1653600,("checks"),anf_arg2413635]);
};
try {
if(--R.GAS > 0) {
$z36273628 = $f36333634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36333634,
"from":L[445]});
}
} catch($e36253626) {
if(R.isCont($e36253626)) {
var $ss36293630 = {"from":L[445],
"go":function(ann_DASH_check_DASH_temp2361995) {
return $Hann_DASH_check_DASH_temp8041994(ann_DASH_check_DASH_temp2361995);
}};
$e36253626.stack[R.EXN_STACKHEIGHT++] = $ss36293630;
}
if(R.isPyretException($e36253626)) {
$e36253626.pyretStack.push(L[445]);
}
throw $e36253626;
}
var $ret36313632 = $Hann_DASH_check_DASH_temp8041994($z36273628);
++R.GAS;
return $ret36313632;
});
var $z36153616 = D;
var $f36213622 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(provides1633598,("provides"),anf_arg2423623):R.ffi.throwNonFunApp(L[444],anf_DASH_name81136.$var,[provides1633598,("provides"),anf_arg2423623]);
};
try {
if(--R.GAS > 0) {
$z36153616 = $f36213622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36213622,
"from":L[444]});
}
} catch($e36133614) {
if(R.isCont($e36133614)) {
var $ss36173618 = {"from":L[444],
"go":function(ann_DASH_check_DASH_temp2351993) {
return $Hann_DASH_check_DASH_temp8051992(ann_DASH_check_DASH_temp2351993);
}};
$e36133614.stack[R.EXN_STACKHEIGHT++] = $ss36173618;
}
if(R.isPyretException($e36133614)) {
$e36133614.pyretStack.push(L[444]);
}
throw $e36133614;
}
var $ret36193620 = $Hann_DASH_check_DASH_temp8051992($z36153616);
++R.GAS;
return $ret36193620;
});
var $z36033604 = D;
var $f36093610 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(answer1623597,("answer"),anf_arg2433611):R.ffi.throwNonFunApp(L[443],anf_DASH_name81136.$var,[answer1623597,("answer"),anf_arg2433611]);
};
try {
if(--R.GAS > 0) {
$z36033604 = $f36093610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36093610,
"from":L[443]});
}
} catch($e36013602) {
if(R.isCont($e36013602)) {
var $ss36053606 = {"from":L[443],
"go":function(ann_DASH_check_DASH_temp2341991) {
return $Hann_DASH_check_DASH_temp8061990(ann_DASH_check_DASH_temp2341991);
}};
$e36013602.stack[R.EXN_STACKHEIGHT++] = $ss36053606;
}
if(R.isPyretException($e36013602)) {
$e36013602.pyretStack.push(L[443]);
}
throw $e36013602;
}
var $ret36073608 = $Hann_DASH_check_DASH_temp8061990($z36033604);
++R.GAS;
return $ret36073608;
});
var anf_obj2512728 = R.makeFunction(function(l1691965,n1703585) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[214],2,arguments);
}
var anf_fun2461963 = G(k160138,"apply",L[442]);
var anf_fun2471964 = G(N512,"a-val",L[441]);
var anf_fun2483596 = G(N512,"a-num",L[440]);
var $z35883589 = D;
var $f35943595 = function(_) {
return R.isFunction(anf_fun2483596)?anf_fun2483596.app(l1691965,n1703585):R.ffi.throwNonFunApp(L[439],anf_fun2483596,[l1691965,n1703585]);
};
try {
if(--R.GAS > 0) {
$z35883589 = $f35943595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35943595,
"from":L[439]});
}
} catch($e35863587) {
if(R.isCont($e35863587)) {
var $ss35903591 = {"from":L[439],
"go":function(anf_arg2491962) {
return $Hanf_arg8091961(anf_arg2491962,anf_fun2461963,anf_fun2471964,l1691965);
}};
$e35863587.stack[R.EXN_STACKHEIGHT++] = $ss35903591;
}
if(R.isPyretException($e35863587)) {
$e35863587.pyretStack.push(L[439]);
}
throw $e35863587;
}
var $ret35923593 = $Hanf_arg8091961($z35883589,anf_fun2461963,anf_fun2471964,l1691965);
++R.GAS;
return $ret35923593;
});
var anf_obj2592729 = R.makeFunction(function(l1711924,num1723573,den1733574) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[212],3,arguments);
}
var anf_fun2531921 = G(k160138,"apply",L[438]);
var anf_fun2541922 = G(N512,"a-val",L[437]);
var anf_fun2551923 = G(N512,"a-num",L[436]);
var $z35773578 = D;
var $f35833584 = function(_) {
return R.isFunction(_divide3)?_divide3.app(num1723573,den1733574):R.ffi.throwNonFunApp(L[435],_divide3,[num1723573,den1733574]);
};
try {
if(--R.GAS > 0) {
$z35773578 = $f35833584();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35833584,
"from":L[435]});
}
} catch($e35753576) {
if(R.isCont($e35753576)) {
var $ss35793580 = {"from":L[435],
"go":function(anf_arg2561920) {
return $Hanf_arg8131919(anf_arg2561920,anf_fun2531921,anf_fun2541922,anf_fun2551923,l1711924);
}};
$e35753576.stack[R.EXN_STACKHEIGHT++] = $ss35793580;
}
if(R.isPyretException($e35753576)) {
$e35753576.pyretStack.push(L[435]);
}
throw $e35753576;
}
var $ret35813582 = $Hanf_arg8131919($z35773578,anf_fun2531921,anf_fun2541922,anf_fun2551923,l1711924);
++R.GAS;
return $ret35813582;
});
var anf_obj2662730 = R.makeFunction(function(l1741894,s1753561) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[209],2,arguments);
}
var anf_fun2611892 = G(k160138,"apply",L[434]);
var anf_fun2621893 = G(N512,"a-val",L[433]);
var anf_fun2633572 = G(N512,"a-str",L[432]);
var $z35643565 = D;
var $f35703571 = function(_) {
return R.isFunction(anf_fun2633572)?anf_fun2633572.app(l1741894,s1753561):R.ffi.throwNonFunApp(L[431],anf_fun2633572,[l1741894,s1753561]);
};
try {
if(--R.GAS > 0) {
$z35643565 = $f35703571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35703571,
"from":L[431]});
}
} catch($e35623563) {
if(R.isCont($e35623563)) {
var $ss35663567 = {"from":L[431],
"go":function(anf_arg2641891) {
return $Hanf_arg8161890(anf_arg2641891,anf_fun2611892,anf_fun2621893,l1741894);
}};
$e35623563.stack[R.EXN_STACKHEIGHT++] = $ss35663567;
}
if(R.isPyretException($e35623563)) {
$e35623563.pyretStack.push(L[431]);
}
throw $e35623563;
}
var $ret35683569 = $Hanf_arg8161890($z35643565,anf_fun2611892,anf_fun2621893,l1741894);
++R.GAS;
return $ret35683569;
});
var anf_obj2732731 = R.makeFunction(function(l1761865) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[207],1,arguments);
}
var anf_fun2681863 = G(k160138,"apply",L[430]);
var anf_fun2691864 = G(N512,"a-val",L[429]);
var anf_fun2703560 = G(N512,"a-undefined",L[428]);
var $z35523553 = D;
var $f35583559 = function(_) {
return R.isFunction(anf_fun2703560)?anf_fun2703560.app(l1761865):R.ffi.throwNonFunApp(L[427],anf_fun2703560,[l1761865]);
};
try {
if(--R.GAS > 0) {
$z35523553 = $f35583559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35583559,
"from":L[427]});
}
} catch($e35503551) {
if(R.isCont($e35503551)) {
var $ss35543555 = {"from":L[427],
"go":function(anf_arg2711862) {
return $Hanf_arg8191861(anf_arg2711862,anf_fun2681863,anf_fun2691864,l1761865);
}};
$e35503551.stack[R.EXN_STACKHEIGHT++] = $ss35543555;
}
if(R.isPyretException($e35503551)) {
$e35503551.pyretStack.push(L[427]);
}
throw $e35503551;
}
var $ret35563557 = $Hanf_arg8191861($z35523553,anf_fun2681863,anf_fun2691864,l1761865);
++R.GAS;
return $ret35563557;
});
var anf_obj2802732 = R.makeFunction(function(l1771836,b1783538) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[205],2,arguments);
}
var anf_fun2751834 = G(k160138,"apply",L[426]);
var anf_fun2761835 = G(N512,"a-val",L[425]);
var anf_fun2773549 = G(N512,"a-bool",L[424]);
var $z35413542 = D;
var $f35473548 = function(_) {
return R.isFunction(anf_fun2773549)?anf_fun2773549.app(l1771836,b1783538):R.ffi.throwNonFunApp(L[423],anf_fun2773549,[l1771836,b1783538]);
};
try {
if(--R.GAS > 0) {
$z35413542 = $f35473548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35473548,
"from":L[423]});
}
} catch($e35393540) {
if(R.isCont($e35393540)) {
var $ss35433544 = {"from":L[423],
"go":function(anf_arg2781833) {
return $Hanf_arg8221832(anf_arg2781833,anf_fun2751834,anf_fun2761835,l1771836);
}};
$e35393540.stack[R.EXN_STACKHEIGHT++] = $ss35433544;
}
if(R.isPyretException($e35393540)) {
$e35393540.pyretStack.push(L[423]);
}
throw $e35393540;
}
var $ret35453546 = $Hanf_arg8221832($z35413542,anf_fun2751834,anf_fun2761835,l1771836);
++R.GAS;
return $ret35453546;
});
var anf_obj2872733 = R.makeFunction(function(l1791807,id1803526) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[203],2,arguments);
}
var anf_fun2821805 = G(k160138,"apply",L[422]);
var anf_fun2831806 = G(N512,"a-val",L[421]);
var anf_fun2843537 = G(N512,"a-id",L[420]);
var $z35293530 = D;
var $f35353536 = function(_) {
return R.isFunction(anf_fun2843537)?anf_fun2843537.app(l1791807,id1803526):R.ffi.throwNonFunApp(L[419],anf_fun2843537,[l1791807,id1803526]);
};
try {
if(--R.GAS > 0) {
$z35293530 = $f35353536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35353536,
"from":L[419]});
}
} catch($e35273528) {
if(R.isCont($e35273528)) {
var $ss35313532 = {"from":L[419],
"go":function(anf_arg2851804) {
return $Hanf_arg8251803(anf_arg2851804,anf_fun2821805,anf_fun2831806,l1791807);
}};
$e35273528.stack[R.EXN_STACKHEIGHT++] = $ss35313532;
}
if(R.isPyretException($e35273528)) {
$e35273528.pyretStack.push(L[419]);
}
throw $e35273528;
}
var $ret35333534 = $Hanf_arg8251803($z35293530,anf_fun2821805,anf_fun2831806,l1791807);
++R.GAS;
return $ret35333534;
});
var anf_obj2942734 = R.makeFunction(function(l1811778,id1823514) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[201],2,arguments);
}
var anf_fun2891776 = G(k160138,"apply",L[418]);
var anf_fun2901777 = G(N512,"a-val",L[417]);
var anf_fun2913525 = G(N512,"a-id-var",L[416]);
var $z35173518 = D;
var $f35233524 = function(_) {
return R.isFunction(anf_fun2913525)?anf_fun2913525.app(l1811778,id1823514):R.ffi.throwNonFunApp(L[415],anf_fun2913525,[l1811778,id1823514]);
};
try {
if(--R.GAS > 0) {
$z35173518 = $f35233524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35233524,
"from":L[415]});
}
} catch($e35153516) {
if(R.isCont($e35153516)) {
var $ss35193520 = {"from":L[415],
"go":function(anf_arg2921775) {
return $Hanf_arg8281774(anf_arg2921775,anf_fun2891776,anf_fun2901777,l1811778);
}};
$e35153516.stack[R.EXN_STACKHEIGHT++] = $ss35193520;
}
if(R.isPyretException($e35153516)) {
$e35153516.pyretStack.push(L[415]);
}
throw $e35153516;
}
var $ret35213522 = $Hanf_arg8281774($z35173518,anf_fun2891776,anf_fun2901777,l1811778);
++R.GAS;
return $ret35213522;
});
var anf_obj3012735 = R.makeFunction(function(l1831749,id1843501,safe1853502) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[199],3,arguments);
}
var anf_fun2961747 = G(k160138,"apply",L[414]);
var anf_fun2971748 = G(N512,"a-val",L[413]);
var anf_fun2983513 = G(N512,"a-id-letrec",L[412]);
var $z35053506 = D;
var $f35113512 = function(_) {
return R.isFunction(anf_fun2983513)?anf_fun2983513.app(l1831749,id1843501,safe1853502):R.ffi.throwNonFunApp(L[411],anf_fun2983513,[l1831749,id1843501,safe1853502]);
};
try {
if(--R.GAS > 0) {
$z35053506 = $f35113512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35113512,
"from":L[411]});
}
} catch($e35033504) {
if(R.isCont($e35033504)) {
var $ss35073508 = {"from":L[411],
"go":function(anf_arg2991746) {
return $Hanf_arg8311745(anf_arg2991746,anf_fun2961747,anf_fun2971748,l1831749);
}};
$e35033504.stack[R.EXN_STACKHEIGHT++] = $ss35073508;
}
if(R.isPyretException($e35033504)) {
$e35033504.pyretStack.push(L[411]);
}
throw $e35033504;
}
var $ret35093510 = $Hanf_arg8311745($z35053506,anf_fun2961747,anf_fun2971748,l1831749);
++R.GAS;
return $ret35093510;
});
var anf_obj3082736 = R.makeFunction(function(l1861720,loc1873489) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[197],2,arguments);
}
var anf_fun3031718 = G(k160138,"apply",L[410]);
var anf_fun3041719 = G(N512,"a-val",L[409]);
var anf_fun3053500 = G(N512,"a-srcloc",L[408]);
var $z34923493 = D;
var $f34983499 = function(_) {
return R.isFunction(anf_fun3053500)?anf_fun3053500.app(l1861720,loc1873489):R.ffi.throwNonFunApp(L[407],anf_fun3053500,[l1861720,loc1873489]);
};
try {
if(--R.GAS > 0) {
$z34923493 = $f34983499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34983499,
"from":L[407]});
}
} catch($e34903491) {
if(R.isCont($e34903491)) {
var $ss34943495 = {"from":L[407],
"go":function(anf_arg3061717) {
return $Hanf_arg8341716(anf_arg3061717,anf_fun3031718,anf_fun3041719,l1861720);
}};
$e34903491.stack[R.EXN_STACKHEIGHT++] = $ss34943495;
}
if(R.isPyretException($e34903491)) {
$e34903491.pyretStack.push(L[407]);
}
throw $e34903491;
}
var $ret34963497 = $Hanf_arg8341716($z34923493,anf_fun3031718,anf_fun3041719,l1861720);
++R.GAS;
return $ret34963497;
});
var anf_obj3322737 = R.makeFunction(function(l1881670,binds1893415,body1901669) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[398],3,arguments);
}
var cases_DASH_val263488 = binds1893415;
var anf_fun3103426 = G(cases_DASH_val263488,"_match",L[399]);
var anf_obj3123430 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[406],0,arguments);
}
var $z34803481 = D;
var $f34863487 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(body1901669,k160138):R.ffi.throwNonFunApp(L[406],anf86820.$var,[body1901669,k160138]);
};
try {
if(--R.GAS > 0) {
$z34803481 = $f34863487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34863487,
"from":L[406]});
}
} catch($e34783479) {
if(R.isCont($e34783479)) {
var $ss34823483 = {"from":L[406],
"go":function(ann_DASH_check_DASH_temp3111715) {
return $Hann_DASH_check_DASH_temp8351714(ann_DASH_check_DASH_temp3111715);
}};
$e34783479.stack[R.EXN_STACKHEIGHT++] = $ss34823483;
}
if(R.isPyretException($e34783479)) {
$e34783479.pyretStack.push(L[406]);
}
throw $e34783479;
}
var $ret34843485 = $Hann_DASH_check_DASH_temp8351714($z34803481);
++R.GAS;
return $ret34843485;
});
var anf_obj3283431 = R.makeFunction(function(f1913432,r1921671) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[195],2,arguments);
}
var cases_DASH_val253477 = f1913432;
var anf_fun3143443 = G(cases_DASH_val253477,"_match",L[401]);
var anf_obj3173447 = R.makeFunction(function(l21943463,name1953464,ann1963465) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[404],3,arguments);
}
var anf_fun3163476 = G(N512,"a-type-bind",L[405]);
var $z34683469 = D;
var $f34743475 = function(_) {
return R.isFunction(anf_fun3163476)?anf_fun3163476.app(l21943463,name1953464,ann1963465):R.ffi.throwNonFunApp(L[404],anf_fun3163476,[l21943463,name1953464,ann1963465]);
};
try {
if(--R.GAS > 0) {
$z34683469 = $f34743475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34743475,
"from":L[404]});
}
} catch($e34663467) {
if(R.isCont($e34663467)) {
var $ss34703471 = {"from":L[404],
"go":function(ann_DASH_check_DASH_temp3151713) {
return $Hann_DASH_check_DASH_temp8361712(ann_DASH_check_DASH_temp3151713);
}};
$e34663467.stack[R.EXN_STACKHEIGHT++] = $ss34703471;
}
if(R.isPyretException($e34663467)) {
$e34663467.pyretStack.push(L[404]);
}
throw $e34663467;
}
var $ret34723473 = $Hann_DASH_check_DASH_temp8361712($z34683469);
++R.GAS;
return $ret34723473;
});
var anf_obj3203448 = R.makeFunction(function(l21973449,name1983450,namet1993451) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[402],3,arguments);
}
var anf_fun3193462 = G(N512,"a-newtype-bind",L[403]);
var $z34543455 = D;
var $f34603461 = function(_) {
return R.isFunction(anf_fun3193462)?anf_fun3193462.app(l21973449,name1983450,namet1993451):R.ffi.throwNonFunApp(L[402],anf_fun3193462,[l21973449,name1983450,namet1993451]);
};
try {
if(--R.GAS > 0) {
$z34543455 = $f34603461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34603461,
"from":L[402]});
}
} catch($e34523453) {
if(R.isCont($e34523453)) {
var $ss34563457 = {"from":L[402],
"go":function(ann_DASH_check_DASH_temp3181711) {
return $Hann_DASH_check_DASH_temp8371710(ann_DASH_check_DASH_temp3181711);
}};
$e34523453.stack[R.EXN_STACKHEIGHT++] = $ss34563457;
}
if(R.isPyretException($e34523453)) {
$e34523453.pyretStack.push(L[402]);
}
throw $e34523453;
}
var $ret34583459 = $Hann_DASH_check_DASH_temp8371710($z34543455);
++R.GAS;
return $ret34583459;
});
var anf_arg3213444 = R.makeObject({"s-type-bind":anf_obj3173447,
"s-newtype-bind":anf_obj3203448});
var anf_arg3233445 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[401],0,arguments);
}
var ann_DASH_check_DASH_temp3223446 = R.throwNoBranchesMatched(L[401],("cases"));
return ann_DASH_check_DASH_temp3223446;
});
var $z34353436 = D;
var $f34413442 = function(_) {
return R.isFunction(anf_fun3143443)?anf_fun3143443.app(anf_arg3213444,anf_arg3233445):R.ffi.throwNonFunApp(L[400],anf_fun3143443,[anf_arg3213444,anf_arg3233445]);
};
try {
if(--R.GAS > 0) {
$z34353436 = $f34413442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34413442,
"from":L[400]});
}
} catch($e34333434) {
if(R.isCont($e34333434)) {
var $ss34373438 = {"from":L[400],
"go":function(new_DASH_bind1931668) {
return $Hnew_DASH_bind8411667(new_DASH_bind1931668,A110,N512,anf86820,body1901669,k160138,l1881670,r1921671);
}};
$e34333434.stack[R.EXN_STACKHEIGHT++] = $ss34373438;
}
if(R.isPyretException($e34333434)) {
$e34333434.pyretStack.push(L[400]);
}
throw $e34333434;
}
var $ret34393440 = $Hnew_DASH_bind8411667($z34353436,A110,N512,anf86820,body1901669,k160138,l1881670,r1921671);
++R.GAS;
return $ret34393440;
});
var anf_arg3293427 = R.makeObject({"empty":anf_obj3123430,
"link":anf_obj3283431});
var anf_arg3313428 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[399],0,arguments);
}
var ann_DASH_check_DASH_temp3303429 = R.throwNoBranchesMatched(L[399],("cases"));
return ann_DASH_check_DASH_temp3303429;
});
var $z34183419 = D;
var $f34243425 = function(_) {
return R.isFunction(anf_fun3103426)?anf_fun3103426.app(anf_arg3293427,anf_arg3313428):R.ffi.throwNonFunApp(L[398],anf_fun3103426,[anf_arg3293427,anf_arg3313428]);
};
try {
if(--R.GAS > 0) {
$z34183419 = $f34243425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34243425,
"from":L[398]});
}
} catch($e34163417) {
if(R.isCont($e34163417)) {
var $ss34203421 = {"from":L[398],
"go":function(ann_DASH_check_DASH_temp3091666) {
return $Hann_DASH_check_DASH_temp8421665(ann_DASH_check_DASH_temp3091666);
}};
$e34163417.stack[R.EXN_STACKHEIGHT++] = $ss34203421;
}
if(R.isPyretException($e34163417)) {
$e34163417.pyretStack.push(L[398]);
}
throw $e34163417;
}
var $ret34223423 = $Hann_DASH_check_DASH_temp8421665($z34183419);
++R.GAS;
return $ret34223423;
});
var anf_obj3722738 = R.makeFunction(function(l2001565,binds2013319,body2021564) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[381],3,arguments);
}
var cases_DASH_val283414 = binds2013319;
var anf_fun3343330 = G(cases_DASH_val283414,"_match",L[382]);
var anf_obj3363334 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[397],0,arguments);
}
var $z34063407 = D;
var $f34123413 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(body2021564,k160138):R.ffi.throwNonFunApp(L[397],anf86820.$var,[body2021564,k160138]);
};
try {
if(--R.GAS > 0) {
$z34063407 = $f34123413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34123413,
"from":L[397]});
}
} catch($e34043405) {
if(R.isCont($e34043405)) {
var $ss34083409 = {"from":L[397],
"go":function(ann_DASH_check_DASH_temp3351664) {
return $Hann_DASH_check_DASH_temp8431663(ann_DASH_check_DASH_temp3351664);
}};
$e34043405.stack[R.EXN_STACKHEIGHT++] = $ss34083409;
}
if(R.isPyretException($e34043405)) {
$e34043405.pyretStack.push(L[397]);
}
throw $e34043405;
}
var $ret34103411 = $Hann_DASH_check_DASH_temp8431663($z34063407);
++R.GAS;
return $ret34103411;
});
var anf_obj3683335 = R.makeFunction(function(f2033336,r2041568) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[383],2,arguments);
}
var cases_DASH_val273403 = f2033336;
var anf_fun3383347 = G(cases_DASH_val273403,"_match",L[384]);
var anf_obj3513351 = R.makeFunction(function(l22051624,b2063378,val2071608) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[186],3,arguments);
}
var anf_arg3493389 = R.makeFunction(function(lettable2081625) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[190],1,arguments);
}
var anf_fun3411623 = G(N512,"a-var",L[396]);
var anf_fun3423400 = G(N512,"a-bind",L[395]);
var anf_arg3433401 = G(b2063378,"id",L[394]);
var anf_arg3443402 = G(b2063378,"ann",L[393]);
var $z33923393 = D;
var $f33983399 = function(_) {
return R.isFunction(anf_fun3423400)?anf_fun3423400.app(l22051624,anf_arg3433401,anf_arg3443402):R.ffi.throwNonFunApp(L[392],anf_fun3423400,[l22051624,anf_arg3433401,anf_arg3443402]);
};
try {
if(--R.GAS > 0) {
$z33923393 = $f33983399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33983399,
"from":L[392]});
}
} catch($e33903391) {
if(R.isCont($e33903391)) {
var $ss33943395 = {"from":L[392],
"go":function(anf_arg3451622) {
return $Hanf_arg8471621(anf_arg3451622,A110,anf86820,anf_fun3411623,body2021564,k160138,l2001565,l22051624,lettable2081625,r2041568);
}};
$e33903391.stack[R.EXN_STACKHEIGHT++] = $ss33943395;
}
if(R.isPyretException($e33903391)) {
$e33903391.pyretStack.push(L[392]);
}
throw $e33903391;
}
var $ret33963397 = $Hanf_arg8471621($z33923393,A110,anf86820,anf_fun3411623,body2021564,k160138,l2001565,l22051624,lettable2081625,r2041568);
++R.GAS;
return $ret33963397;
});
var $z33813382 = D;
var $f33873388 = function(_) {
return R.isFunction(k_DASH_cont752020.$var)?k_DASH_cont752020.$var.app(anf_arg3493389):R.ffi.throwNonFunApp(L[391],k_DASH_cont752020.$var,[anf_arg3493389]);
};
try {
if(--R.GAS > 0) {
$z33813382 = $f33873388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33873388,
"from":L[391]});
}
} catch($e33793380) {
if(R.isCont($e33793380)) {
var $ss33833384 = {"from":L[391],
"go":function(anf_arg3501607) {
return $Hanf_arg8491606(anf_arg3501607,anf86820,val2071608);
}};
$e33793380.stack[R.EXN_STACKHEIGHT++] = $ss33833384;
}
if(R.isPyretException($e33793380)) {
$e33793380.pyretStack.push(L[391]);
}
throw $e33793380;
}
var $ret33853386 = $Hanf_arg8491606($z33813382,anf86820,val2071608);
++R.GAS;
return $ret33853386;
});
var anf_obj3643352 = R.makeFunction(function(l22091566,b2103353,val2111548) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[181],3,arguments);
}
var anf_arg3623364 = R.makeFunction(function(lettable2121567) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[185],1,arguments);
}
var anf_fun3541563 = G(N512,"a-let",L[390]);
var anf_fun3553375 = G(N512,"a-bind",L[389]);
var anf_arg3563376 = G(b2103353,"id",L[388]);
var anf_arg3573377 = G(b2103353,"ann",L[387]);
var $z33673368 = D;
var $f33733374 = function(_) {
return R.isFunction(anf_fun3553375)?anf_fun3553375.app(l22091566,anf_arg3563376,anf_arg3573377):R.ffi.throwNonFunApp(L[386],anf_fun3553375,[l22091566,anf_arg3563376,anf_arg3573377]);
};
try {
if(--R.GAS > 0) {
$z33673368 = $f33733374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33733374,
"from":L[386]});
}
} catch($e33653366) {
if(R.isCont($e33653366)) {
var $ss33693370 = {"from":L[386],
"go":function(anf_arg3581562) {
return $Hanf_arg8531561(anf_arg3581562,A110,anf86820,anf_fun3541563,body2021564,k160138,l2001565,l22091566,lettable2121567,r2041568);
}};
$e33653366.stack[R.EXN_STACKHEIGHT++] = $ss33693370;
}
if(R.isPyretException($e33653366)) {
$e33653366.pyretStack.push(L[386]);
}
throw $e33653366;
}
var $ret33713372 = $Hanf_arg8531561($z33673368,A110,anf86820,anf_fun3541563,body2021564,k160138,l2001565,l22091566,lettable2121567,r2041568);
++R.GAS;
return $ret33713372;
});
var $z33563357 = D;
var $f33623363 = function(_) {
return R.isFunction(k_DASH_cont752020.$var)?k_DASH_cont752020.$var.app(anf_arg3623364):R.ffi.throwNonFunApp(L[385],k_DASH_cont752020.$var,[anf_arg3623364]);
};
try {
if(--R.GAS > 0) {
$z33563357 = $f33623363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33623363,
"from":L[385]});
}
} catch($e33543355) {
if(R.isCont($e33543355)) {
var $ss33583359 = {"from":L[385],
"go":function(anf_arg3631547) {
return $Hanf_arg8551546(anf_arg3631547,anf86820,val2111548);
}};
$e33543355.stack[R.EXN_STACKHEIGHT++] = $ss33583359;
}
if(R.isPyretException($e33543355)) {
$e33543355.pyretStack.push(L[385]);
}
throw $e33543355;
}
var $ret33603361 = $Hanf_arg8551546($z33563357,anf86820,val2111548);
++R.GAS;
return $ret33603361;
});
var anf_arg3653348 = R.makeObject({"s-var-bind":anf_obj3513351,
"s-let-bind":anf_obj3643352});
var anf_arg3673349 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[384],0,arguments);
}
var ann_DASH_check_DASH_temp3663350 = R.throwNoBranchesMatched(L[384],("cases"));
return ann_DASH_check_DASH_temp3663350;
});
var $z33393340 = D;
var $f33453346 = function(_) {
return R.isFunction(anf_fun3383347)?anf_fun3383347.app(anf_arg3653348,anf_arg3673349):R.ffi.throwNonFunApp(L[383],anf_fun3383347,[anf_arg3653348,anf_arg3673349]);
};
try {
if(--R.GAS > 0) {
$z33393340 = $f33453346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33453346,
"from":L[383]});
}
} catch($e33373338) {
if(R.isCont($e33373338)) {
var $ss33413342 = {"from":L[383],
"go":function(ann_DASH_check_DASH_temp3371545) {
return $Hann_DASH_check_DASH_temp8561544(ann_DASH_check_DASH_temp3371545);
}};
$e33373338.stack[R.EXN_STACKHEIGHT++] = $ss33413342;
}
if(R.isPyretException($e33373338)) {
$e33373338.pyretStack.push(L[383]);
}
throw $e33373338;
}
var $ret33433344 = $Hann_DASH_check_DASH_temp8561544($z33393340);
++R.GAS;
return $ret33433344;
});
var anf_arg3693331 = R.makeObject({"empty":anf_obj3363334,
"link":anf_obj3683335});
var anf_arg3713332 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[382],0,arguments);
}
var ann_DASH_check_DASH_temp3703333 = R.throwNoBranchesMatched(L[382],("cases"));
return ann_DASH_check_DASH_temp3703333;
});
var $z33223323 = D;
var $f33283329 = function(_) {
return R.isFunction(anf_fun3343330)?anf_fun3343330.app(anf_arg3693331,anf_arg3713332):R.ffi.throwNonFunApp(L[381],anf_fun3343330,[anf_arg3693331,anf_arg3713332]);
};
try {
if(--R.GAS > 0) {
$z33223323 = $f33283329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33283329,
"from":L[381]});
}
} catch($e33203321) {
if(R.isCont($e33203321)) {
var $ss33243325 = {"from":L[381],
"go":function(ann_DASH_check_DASH_temp3331543) {
return $Hann_DASH_check_DASH_temp8571542(ann_DASH_check_DASH_temp3331543);
}};
$e33203321.stack[R.EXN_STACKHEIGHT++] = $ss33243325;
}
if(R.isPyretException($e33203321)) {
$e33203321.pyretStack.push(L[381]);
}
throw $e33203321;
}
var $ret33263327 = $Hann_DASH_check_DASH_temp8571542($z33223323);
++R.GAS;
return $ret33263327;
});
var anf_obj3952739 = R.makeFunction(function(l2131429,binds2141427,body2151428) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[179],3,arguments);
}
var anf_arg3803306 = R.makeFunction(function(b2173307) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[180],1,arguments);
}
var anf_fun3751529 = G(A110,"s-var-bind",L[380]);
var anf_arg3761527 = G(b2173307,"l",L[379]);
var anf_arg3771528 = G(b2173307,"b",L[378]);
var anf_fun3783318 = G(A110,"s-undefined",L[377]);
var $z33103311 = D;
var $f33163317 = function(_) {
return R.isFunction(anf_fun3783318)?anf_fun3783318.app(l2131429):R.ffi.throwNonFunApp(L[376],anf_fun3783318,[l2131429]);
};
try {
if(--R.GAS > 0) {
$z33103311 = $f33163317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33163317,
"from":L[376]});
}
} catch($e33083309) {
if(R.isCont($e33083309)) {
var $ss33123313 = {"from":L[376],
"go":function(anf_arg3791526) {
return $Hanf_arg8591525(anf_arg3791526,anf_arg3761527,anf_arg3771528,anf_fun3751529);
}};
$e33083309.stack[R.EXN_STACKHEIGHT++] = $ss33123313;
}
if(R.isPyretException($e33083309)) {
$e33083309.pyretStack.push(L[376]);
}
throw $e33083309;
}
var $ret33143315 = $Hanf_arg8591525($z33103311,anf_arg3761527,anf_arg3771528,anf_fun3751529);
++R.GAS;
return $ret33143315;
});
var $z32983299 = D;
var $f33043305 = function(_) {
return R.isFunction(map371430)?map371430.app(anf_arg3803306,binds2141427):R.ffi.throwNonFunApp(L[375],map371430,[anf_arg3803306,binds2141427]);
};
try {
if(--R.GAS > 0) {
$z32983299 = $f33043305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33043305,
"from":L[375]});
}
} catch($e32963297) {
if(R.isCont($e32963297)) {
var $ss33003301 = {"from":L[375],
"go":function(let_DASH_binds2161426) {
return $Hlet_DASH_binds8671425(let_DASH_binds2161426,A110,anf86820,binds2141427,body2151428,k160138,l2131429,list25501,map371430,_plus4);
}};
$e32963297.stack[R.EXN_STACKHEIGHT++] = $ss33003301;
}
if(R.isPyretException($e32963297)) {
$e32963297.pyretStack.push(L[375]);
}
throw $e32963297;
}
var $ret33023303 = $Hlet_DASH_binds8671425($z32983299,A110,anf86820,binds2141427,body2151428,k160138,l2131429,list25501,map371430,_plus4);
++R.GAS;
return $ret33023303;
});
var anf_obj4962740 = R.makeFunction(function(l2201066,data_DASH_name2211065,data_DASH_name_DASH_t2221064,params2233125,mixins2243126,variants2251068,shared2261067,_check2273127) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[123],8,arguments);
}
var anf_DASH_member2281282 = {"$var":D,
"$name":"anf-member"};
var anf_DASH_variant2293129 = {"$var":D,
"$name":"anf-variant"};
var anf_DASH_variants2301063 = {"$var":D,
"$name":"anf-variants"};
var anf_assign4223128 = R.makeFunction(function(member2313257) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[364],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[374],"A",A218,"VariantMember")],[member2313257],[L[374]],function() {
var cases_DASH_val313295 = member2313257;
var anf_fun3983268 = G(cases_DASH_val313295,"_match",L[365]);
var anf_obj4183272 = R.makeFunction(function(l22321376,typ2333273,b2341375) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[164],3,arguments);
}
var cases_DASH_val293294 = typ2333273;
var anf_fun4003284 = G(cases_DASH_val293294,"_match",L[367]);
var anf_obj4023288 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[372],0,arguments);
}
var ann_DASH_check_DASH_temp4013293 = G(N512,"a-normal",L[373]);
return ann_DASH_check_DASH_temp4013293;
});
var anf_obj4043289 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[370],0,arguments);
}
var ann_DASH_check_DASH_temp4033292 = G(N512,"a-cyclic",L[371]);
return ann_DASH_check_DASH_temp4033292;
});
var anf_obj4063290 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[368],0,arguments);
}
var ann_DASH_check_DASH_temp4053291 = G(N512,"a-mutable",L[369]);
return ann_DASH_check_DASH_temp4053291;
});
var anf_arg4073285 = R.makeObject({"s-normal":anf_obj4023288,
"s-cyclic":anf_obj4043289,
"s-mutable":anf_obj4063290});
var anf_arg4093286 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[367],0,arguments);
}
var ann_DASH_check_DASH_temp4083287 = R.throwNoBranchesMatched(L[367],("cases"));
return ann_DASH_check_DASH_temp4083287;
});
var $z32763277 = D;
var $f32823283 = function(_) {
return R.isFunction(anf_fun4003284)?anf_fun4003284.app(anf_arg4073285,anf_arg4093286):R.ffi.throwNonFunApp(L[366],anf_fun4003284,[anf_arg4073285,anf_arg4093286]);
};
try {
if(--R.GAS > 0) {
$z32763277 = $f32823283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32823283,
"from":L[366]});
}
} catch($e32743275) {
if(R.isCont($e32743275)) {
var $ss32783279 = {"from":L[366],
"go":function(a_DASH_type2351374) {
return $Ha_DASH_type8711373(a_DASH_type2351374,N512,b2341375,l22321376);
}};
$e32743275.stack[R.EXN_STACKHEIGHT++] = $ss32783279;
}
if(R.isPyretException($e32743275)) {
$e32743275.pyretStack.push(L[366]);
}
throw $e32743275;
}
var $ret32803281 = $Ha_DASH_type8711373($z32763277,N512,b2341375,l22321376);
++R.GAS;
return $ret32803281;
});
var anf_arg4193269 = R.makeObject({"s-variant-member":anf_obj4183272});
var anf_arg4213270 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[365],0,arguments);
}
var ann_DASH_check_DASH_temp4203271 = R.throwNoBranchesMatched(L[365],("cases"));
return ann_DASH_check_DASH_temp4203271;
});
var $z32603261 = D;
var $f32663267 = function(_) {
return R.isFunction(anf_fun3983268)?anf_fun3983268.app(anf_arg4193269,anf_arg4213270):R.ffi.throwNonFunApp(L[364],anf_fun3983268,[anf_arg4193269,anf_arg4213270]);
};
try {
if(--R.GAS > 0) {
$z32603261 = $f32663267();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32663267,
"from":L[364]});
}
} catch($e32583259) {
if(R.isCont($e32583259)) {
var $ss32623263 = {"from":L[364],
"go":function(ann_DASH_check_DASH_temp3971372) {
return $Hann_DASH_check_DASH_temp8721371(ann_DASH_check_DASH_temp3971372);
}};
$e32583259.stack[R.EXN_STACKHEIGHT++] = $ss32623263;
}
if(R.isPyretException($e32583259)) {
$e32583259.pyretStack.push(L[364]);
}
throw $e32583259;
}
var $ret32643265 = $Hann_DASH_check_DASH_temp8721371($z32603261);
++R.GAS;
return $ret32643265;
});
});
anf_DASH_member2281282.$var = anf_assign4223128;
var anf_assign4603130 = R.makeFunction(function(v2413211,kv2421206) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[354],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[362],"A",A218,"Variant"),R.Function],[v2413211,kv2421206],[L[362],L[363]],function() {
var cases_DASH_val343256 = v2413211;
var anf_fun4243222 = G(cases_DASH_val343256,"_match",L[355]);
var anf_obj4413226 = R.makeFunction(function(l22431284,constr_DASH_loc2441283,vname2451286,members2461285,with_DASH_members2471287) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[148],5,arguments);
}
var anf_fun4263252 = G(with_DASH_members2471287,"map",L[361]);
var anf_arg4283253 = R.makeFunction(function(recv_DASH_323254) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[360],1,arguments);
}
var ann_DASH_check_DASH_temp4273255 = G(recv_DASH_323254,"value",L[360]);
return ann_DASH_check_DASH_temp4273255;
});
var $z32443245 = D;
var $f32503251 = function(_) {
return R.isFunction(anf_fun4263252)?anf_fun4263252.app(anf_arg4283253):R.ffi.throwNonFunApp(L[359],anf_fun4263252,[anf_arg4283253]);
};
try {
if(--R.GAS > 0) {
$z32443245 = $f32503251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32503251,
"from":L[359]});
}
} catch($e32423243) {
if(R.isCont($e32423243)) {
var $ss32463247 = {"from":L[359],
"go":function(with_DASH_exprs2481281) {
return $Hwith_DASH_exprs8791280(with_DASH_exprs2481281,N512,anf_DASH_member2281282,anf_DASH_name_DASH_rec82135,constr_DASH_loc2441283,kv2421206,l22431284,map238140,members2461285,vname2451286,with_DASH_members2471287);
}};
$e32423243.stack[R.EXN_STACKHEIGHT++] = $ss32463247;
}
if(R.isPyretException($e32423243)) {
$e32423243.pyretStack.push(L[359]);
}
throw $e32423243;
}
var $ret32483249 = $Hwith_DASH_exprs8791280($z32443245,N512,anf_DASH_member2281282,anf_DASH_name_DASH_rec82135,constr_DASH_loc2441283,kv2421206,l22431284,map238140,members2461285,vname2451286,with_DASH_members2471287);
++R.GAS;
return $ret32483249;
});
var anf_obj4563227 = R.makeFunction(function(l22531207,vname2541208,with_DASH_members2551209) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[138],3,arguments);
}
var anf_fun4433238 = G(with_DASH_members2551209,"map",L[358]);
var anf_arg4453239 = R.makeFunction(function(recv_DASH_333240) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[357],1,arguments);
}
var ann_DASH_check_DASH_temp4443241 = G(recv_DASH_333240,"value",L[357]);
return ann_DASH_check_DASH_temp4443241;
});
var $z32303231 = D;
var $f32363237 = function(_) {
return R.isFunction(anf_fun4433238)?anf_fun4433238.app(anf_arg4453239):R.ffi.throwNonFunApp(L[356],anf_fun4433238,[anf_arg4453239]);
};
try {
if(--R.GAS > 0) {
$z32303231 = $f32363237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32363237,
"from":L[356]});
}
} catch($e32283229) {
if(R.isCont($e32283229)) {
var $ss32323233 = {"from":L[356],
"go":function(with_DASH_exprs2561205) {
return $Hwith_DASH_exprs8851204(with_DASH_exprs2561205,N512,anf_DASH_name_DASH_rec82135,kv2421206,l22531207,map238140,vname2541208,with_DASH_members2551209);
}};
$e32283229.stack[R.EXN_STACKHEIGHT++] = $ss32323233;
}
if(R.isPyretException($e32283229)) {
$e32283229.pyretStack.push(L[356]);
}
throw $e32283229;
}
var $ret32343235 = $Hwith_DASH_exprs8851204($z32303231,N512,anf_DASH_name_DASH_rec82135,kv2421206,l22531207,map238140,vname2541208,with_DASH_members2551209);
++R.GAS;
return $ret32343235;
});
var anf_arg4573223 = R.makeObject({"s-variant":anf_obj4413226,
"s-singleton-variant":anf_obj4563227});
var anf_arg4593224 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[355],0,arguments);
}
var ann_DASH_check_DASH_temp4583225 = R.throwNoBranchesMatched(L[355],("cases"));
return ann_DASH_check_DASH_temp4583225;
});
var $z32143215 = D;
var $f32203221 = function(_) {
return R.isFunction(anf_fun4243222)?anf_fun4243222.app(anf_arg4573223,anf_arg4593224):R.ffi.throwNonFunApp(L[354],anf_fun4243222,[anf_arg4573223,anf_arg4593224]);
};
try {
if(--R.GAS > 0) {
$z32143215 = $f32203221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32203221,
"from":L[354]});
}
} catch($e32123213) {
if(R.isCont($e32123213)) {
var $ss32163217 = {"from":L[354],
"go":function(ann_DASH_check_DASH_temp4231203) {
return $Hann_DASH_check_DASH_temp8861202(ann_DASH_check_DASH_temp4231203);
}};
$e32123213.stack[R.EXN_STACKHEIGHT++] = $ss32163217;
}
if(R.isPyretException($e32123213)) {
$e32123213.pyretStack.push(L[354]);
}
throw $e32123213;
}
var $ret32183219 = $Hann_DASH_check_DASH_temp8861202($z32143215);
++R.GAS;
return $ret32183219;
});
});
anf_DASH_variant2293129.$var = anf_assign4603130;
var anf_assign4793131 = R.makeFunction(function(vs2613146,ks2621162) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[345],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[351],"lists",lists1022,"List"),R.Function],[vs2613146,ks2621162],[L[352],L[353]],function() {
var cases_DASH_val353210 = vs2613146;
var anf_fun4623157 = G(cases_DASH_val353210,"_match",L[346]);
var anf_obj4663161 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[137],0,arguments);
}
var anf_fun4643209 = G(list25501,"make",L[350]);
var $z32013202 = D;
var $f32073208 = function(_) {
return R.isFunction(anf_fun4643209)?anf_fun4643209.app([]):R.ffi.throwNonFunApp(L[350],anf_fun4643209,[[]]);
};
try {
if(--R.GAS > 0) {
$z32013202 = $f32073208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32073208,
"from":L[350]});
}
} catch($e31993200) {
if(R.isCont($e31993200)) {
var $ss32033204 = {"from":L[350],
"go":function(anf_arg4651189) {
return $Hanf_arg8881188(anf_arg4651189,ks2621162);
}};
$e31993200.stack[R.EXN_STACKHEIGHT++] = $ss32033204;
}
if(R.isPyretException($e31993200)) {
$e31993200.pyretStack.push(L[350]);
}
throw $e31993200;
}
var $ret32053206 = $Hanf_arg8881188($z32013202,ks2621162);
++R.GAS;
return $ret32053206;
});
var anf_obj4753162 = R.makeFunction(function(f2633163,r2643164) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[347],2,arguments);
}
var anf_arg4743175 = R.makeFunction(function(v2653176) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[348],1,arguments);
}
var anf_arg4733187 = R.makeFunction(function(rest_DASH_vs2661163) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[136],1,arguments);
}
var anf_fun4703198 = G(list25501,"make",L[349]);
var $z31903191 = D;
var $f31963197 = function(_) {
return R.isFunction(anf_fun4703198)?anf_fun4703198.app([v2653176]):R.ffi.throwNonFunApp(L[349],anf_fun4703198,[[v2653176]]);
};
try {
if(--R.GAS > 0) {
$z31903191 = $f31963197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31963197,
"from":L[349]});
}
} catch($e31883189) {
if(R.isCont($e31883189)) {
var $ss31923193 = {"from":L[349],
"go":function(anf_arg4711161) {
return $Hanf_arg8911160(anf_arg4711161,ks2621162,rest_DASH_vs2661163,_plus4);
}};
$e31883189.stack[R.EXN_STACKHEIGHT++] = $ss31923193;
}
if(R.isPyretException($e31883189)) {
$e31883189.pyretStack.push(L[349]);
}
throw $e31883189;
}
var $ret31943195 = $Hanf_arg8911160($z31903191,ks2621162,rest_DASH_vs2661163,_plus4);
++R.GAS;
return $ret31943195;
});
var $z31793180 = D;
var $f31853186 = function(_) {
return R.isFunction(anf_DASH_variants2301063.$var)?anf_DASH_variants2301063.$var.app(r2643164,anf_arg4733187):R.ffi.throwNonFunApp(L[348],anf_DASH_variants2301063.$var,[r2643164,anf_arg4733187]);
};
try {
if(--R.GAS > 0) {
$z31793180 = $f31853186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31853186,
"from":L[348]});
}
} catch($e31773178) {
if(R.isCont($e31773178)) {
var $ss31813182 = {"from":L[348],
"go":function(ann_DASH_check_DASH_temp4681159) {
return $Hann_DASH_check_DASH_temp8921158(ann_DASH_check_DASH_temp4681159);
}};
$e31773178.stack[R.EXN_STACKHEIGHT++] = $ss31813182;
}
if(R.isPyretException($e31773178)) {
$e31773178.pyretStack.push(L[348]);
}
throw $e31773178;
}
var $ret31833184 = $Hann_DASH_check_DASH_temp8921158($z31793180);
++R.GAS;
return $ret31833184;
});
var $z31673168 = D;
var $f31733174 = function(_) {
return R.isFunction(anf_DASH_variant2293129.$var)?anf_DASH_variant2293129.$var.app(f2633163,anf_arg4743175):R.ffi.throwNonFunApp(L[347],anf_DASH_variant2293129.$var,[f2633163,anf_arg4743175]);
};
try {
if(--R.GAS > 0) {
$z31673168 = $f31733174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31733174,
"from":L[347]});
}
} catch($e31653166) {
if(R.isCont($e31653166)) {
var $ss31693170 = {"from":L[347],
"go":function(ann_DASH_check_DASH_temp4671157) {
return $Hann_DASH_check_DASH_temp8931156(ann_DASH_check_DASH_temp4671157);
}};
$e31653166.stack[R.EXN_STACKHEIGHT++] = $ss31693170;
}
if(R.isPyretException($e31653166)) {
$e31653166.pyretStack.push(L[347]);
}
throw $e31653166;
}
var $ret31713172 = $Hann_DASH_check_DASH_temp8931156($z31673168);
++R.GAS;
return $ret31713172;
});
var anf_arg4763158 = R.makeObject({"empty":anf_obj4663161,
"link":anf_obj4753162});
var anf_arg4783159 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[346],0,arguments);
}
var ann_DASH_check_DASH_temp4773160 = R.throwNoBranchesMatched(L[346],("cases"));
return ann_DASH_check_DASH_temp4773160;
});
var $z31493150 = D;
var $f31553156 = function(_) {
return R.isFunction(anf_fun4623157)?anf_fun4623157.app(anf_arg4763158,anf_arg4783159):R.ffi.throwNonFunApp(L[345],anf_fun4623157,[anf_arg4763158,anf_arg4783159]);
};
try {
if(--R.GAS > 0) {
$z31493150 = $f31553156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31553156,
"from":L[345]});
}
} catch($e31473148) {
if(R.isCont($e31473148)) {
var $ss31513152 = {"from":L[345],
"go":function(ann_DASH_check_DASH_temp4611155) {
return $Hann_DASH_check_DASH_temp8941154(ann_DASH_check_DASH_temp4611155);
}};
$e31473148.stack[R.EXN_STACKHEIGHT++] = $ss31513152;
}
if(R.isPyretException($e31473148)) {
$e31473148.pyretStack.push(L[345]);
}
throw $e31473148;
}
var $ret31533154 = $Hann_DASH_check_DASH_temp8941154($z31493150);
++R.GAS;
return $ret31533154;
});
});
anf_DASH_variants2301063.$var = anf_assign4793131;
var anf_fun4803142 = G(shared2261067,"map",L[344]);
var anf_arg4823143 = R.makeFunction(function(recv_DASH_363144) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[343],1,arguments);
}
var ann_DASH_check_DASH_temp4813145 = G(recv_DASH_363144,"value",L[343]);
return ann_DASH_check_DASH_temp4813145;
});
var $z31343135 = D;
var $f31403141 = function(_) {
return R.isFunction(anf_fun4803142)?anf_fun4803142.app(anf_arg4823143):R.ffi.throwNonFunApp(L[342],anf_fun4803142,[anf_arg4823143]);
};
try {
if(--R.GAS > 0) {
$z31343135 = $f31403141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31403141,
"from":L[342]});
}
} catch($e31323133) {
if(R.isCont($e31323133)) {
var $ss31363137 = {"from":L[342],
"go":function(exprs2671062) {
return $Hexprs9011061(exprs2671062,N512,anf_DASH_name_DASH_rec82135,anf_DASH_variants2301063,data_DASH_name_DASH_t2221064,data_DASH_name2211065,k160138,l2201066,map238140,shared2261067,variants2251068);
}};
$e31323133.stack[R.EXN_STACKHEIGHT++] = $ss31363137;
}
if(R.isPyretException($e31323133)) {
$e31323133.pyretStack.push(L[342]);
}
throw $e31323133;
}
var $ret31383139 = $Hexprs9011061($z31343135,N512,anf_DASH_name_DASH_rec82135,anf_DASH_variants2301063,data_DASH_name_DASH_t2221064,data_DASH_name2211065,k160138,l2201066,map238140,shared2261067,variants2251068);
++R.GAS;
return $ret31383139;
});
var anf_obj5462741 = R.makeFunction(function(l273824,branches274821,_else275819) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[333],3,arguments);
}
var cases_DASH_val373124 = k160138;
var anf_fun4983072 = G(cases_DASH_val373124,"_match",L[334]);
var anf_obj5113076 = R.makeFunction(function($underscore2763089) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[121],1,arguments);
}
var anf_arg5071016 = R.makeFunction(function(acc2771046,branch2783100) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[337],2,arguments);
}
var anf_arg5013111 = G(branch2783100,"test",L[341]);
var anf_arg5063112 = R.makeFunction(function(test2791048) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[122],1,arguments);
}
var anf_fun5031047 = G(N512,"a-if",L[340]);
var anf_arg5043123 = G(branch2783100,"body",L[339]);
var $z31153116 = D;
var $f31213122 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(anf_arg5043123,k160138):R.ffi.throwNonFunApp(L[338],anf86820.$var,[anf_arg5043123,k160138]);
};
try {
if(--R.GAS > 0) {
$z31153116 = $f31213122();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31213122,
"from":L[338]});
}
} catch($e31133114) {
if(R.isCont($e31133114)) {
var $ss31173118 = {"from":L[338],
"go":function(anf_arg5051045) {
return $Hanf_arg9031044(anf_arg5051045,acc2771046,anf_fun5031047,l273824,test2791048);
}};
$e31133114.stack[R.EXN_STACKHEIGHT++] = $ss31173118;
}
if(R.isPyretException($e31133114)) {
$e31133114.pyretStack.push(L[338]);
}
throw $e31133114;
}
var $ret31193120 = $Hanf_arg9031044($z31153116,acc2771046,anf_fun5031047,l273824,test2791048);
++R.GAS;
return $ret31193120;
});
var $z31033104 = D;
var $f31093110 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(anf_arg5013111,("anf_if"),anf_arg5063112):R.ffi.throwNonFunApp(L[337],anf_DASH_name81136.$var,[anf_arg5013111,("anf_if"),anf_arg5063112]);
};
try {
if(--R.GAS > 0) {
$z31033104 = $f31093110();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31093110,
"from":L[337]});
}
} catch($e31013102) {
if(R.isCont($e31013102)) {
var $ss31053106 = {"from":L[337],
"go":function(ann_DASH_check_DASH_temp5001043) {
return $Hann_DASH_check_DASH_temp9041042(ann_DASH_check_DASH_temp5001043);
}};
$e31013102.stack[R.EXN_STACKHEIGHT++] = $ss31053106;
}
if(R.isPyretException($e31013102)) {
$e31013102.pyretStack.push(L[337]);
}
throw $e31013102;
}
var $ret31073108 = $Hann_DASH_check_DASH_temp9041042($z31033104);
++R.GAS;
return $ret31073108;
});
var $z30923093 = D;
var $f30983099 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(_else275819,k160138):R.ffi.throwNonFunApp(L[336],anf86820.$var,[_else275819,k160138]);
};
try {
if(--R.GAS > 0) {
$z30923093 = $f30983099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30983099,
"from":L[336]});
}
} catch($e30903091) {
if(R.isCont($e30903091)) {
var $ss30943095 = {"from":L[336],
"go":function(anf_arg5081015) {
return $Hanf_arg9071014(anf_arg5081015,anf_arg5071016,branches274821,fold53822);
}};
$e30903091.stack[R.EXN_STACKHEIGHT++] = $ss30943095;
}
if(R.isPyretException($e30903091)) {
$e30903091.pyretStack.push(L[336]);
}
throw $e30903091;
}
var $ret30963097 = $Hanf_arg9071014($z30923093,anf_arg5071016,branches274821,fold53822);
++R.GAS;
return $ret30963097;
});
var anf_obj5423077 = R.makeFunction(function($underscore2803078) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
var $z30813082 = D;
var $f30873088 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(l273824,("if_helper")):R.ffi.throwNonFunApp(L[335],mk_DASH_id70825.$var,[l273824,("if_helper")]);
};
try {
if(--R.GAS > 0) {
$z30813082 = $f30873088();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30873088,
"from":L[335]});
}
} catch($e30793080) {
if(R.isCont($e30793080)) {
var $ss30833084 = {"from":L[335],
"go":function(helper281818) {
return $Hhelper922817(helper281818,A110,N512,_else275819,anf_DASH_name81136,anf86820,branches274821,fold53822,k_DASH_id77823,k160138,l273824,list25501,mk_DASH_id70825);
}};
$e30793080.stack[R.EXN_STACKHEIGHT++] = $ss30833084;
}
if(R.isPyretException($e30793080)) {
$e30793080.pyretStack.push(L[335]);
}
throw $e30793080;
}
var $ret30853086 = $Hhelper922817($z30813082,A110,N512,_else275819,anf_DASH_name81136,anf86820,branches274821,fold53822,k_DASH_id77823,k160138,l273824,list25501,mk_DASH_id70825);
++R.GAS;
return $ret30853086;
});
var anf_arg5433073 = R.makeObject({"k-id":anf_obj5113076,
"k-cont":anf_obj5423077});
var anf_arg5453074 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[334],0,arguments);
}
var ann_DASH_check_DASH_temp5443075 = R.throwNoBranchesMatched(L[334],("cases"));
return ann_DASH_check_DASH_temp5443075;
});
var $z30643065 = D;
var $f30703071 = function(_) {
return R.isFunction(anf_fun4983072)?anf_fun4983072.app(anf_arg5433073,anf_arg5453074):R.ffi.throwNonFunApp(L[333],anf_fun4983072,[anf_arg5433073,anf_arg5453074]);
};
try {
if(--R.GAS > 0) {
$z30643065 = $f30703071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30703071,
"from":L[333]});
}
} catch($e30623063) {
if(R.isCont($e30623063)) {
var $ss30663067 = {"from":L[333],
"go":function(ann_DASH_check_DASH_temp497816) {
return $Hann_DASH_check_DASH_temp923815(ann_DASH_check_DASH_temp497816);
}};
$e30623063.stack[R.EXN_STACKHEIGHT++] = $ss30663067;
}
if(R.isPyretException($e30623063)) {
$e30623063.pyretStack.push(L[333]);
}
throw $e30623063;
}
var $ret30683069 = $Hann_DASH_check_DASH_temp923815($z30643065);
++R.GAS;
return $ret30683069;
});
var anf_obj5512742 = R.makeFunction(function(l286790,body2873051,id288789,_except289787) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[91],4,arguments);
}
var anf_fun548788 = G(N512,"a-try",L[332]);
var $z30543055 = D;
var $f30603061 = function(_) {
return R.isFunction(anf_DASH_term78497.$var)?anf_DASH_term78497.$var.app(body2873051):R.ffi.throwNonFunApp(L[331],anf_DASH_term78497.$var,[body2873051]);
};
try {
if(--R.GAS > 0) {
$z30543055 = $f30603061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30603061,
"from":L[331]});
}
} catch($e30523053) {
if(R.isCont($e30523053)) {
var $ss30563057 = {"from":L[331],
"go":function(anf_arg549786) {
return $Hanf_arg926785(anf_arg549786,_except289787,anf_DASH_term78497,anf_fun548788,id288789,l286790);
}};
$e30523053.stack[R.EXN_STACKHEIGHT++] = $ss30563057;
}
if(R.isPyretException($e30523053)) {
$e30523053.pyretStack.push(L[331]);
}
throw $e30523053;
}
var $ret30583059 = $Hanf_arg926785($z30543055,_except289787,anf_DASH_term78497,anf_fun548788,id288789,l286790);
++R.GAS;
return $ret30583059;
});
var anf_obj5532743 = R.makeFunction(function(l2903039,stmts2913040) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[330],2,arguments);
}
var $z30433044 = D;
var $f30493050 = function(_) {
return R.isFunction(anf_DASH_block852688.$var)?anf_DASH_block852688.$var.app(stmts2913040,k160138):R.ffi.throwNonFunApp(L[330],anf_DASH_block852688.$var,[stmts2913040,k160138]);
};
try {
if(--R.GAS > 0) {
$z30433044 = $f30493050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30493050,
"from":L[330]});
}
} catch($e30413042) {
if(R.isCont($e30413042)) {
var $ss30453046 = {"from":L[330],
"go":function(ann_DASH_check_DASH_temp552784) {
return $Hann_DASH_check_DASH_temp927783(ann_DASH_check_DASH_temp552784);
}};
$e30413042.stack[R.EXN_STACKHEIGHT++] = $ss30453046;
}
if(R.isPyretException($e30413042)) {
$e30413042.pyretStack.push(L[330]);
}
throw $e30413042;
}
var $ret30473048 = $Hann_DASH_check_DASH_temp927783($z30433044);
++R.GAS;
return $ret30473048;
});
var anf_obj5552744 = R.makeFunction(function(l2923027,body2933028) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[329],2,arguments);
}
var $z30313032 = D;
var $f30373038 = function(_) {
return R.isFunction(anf86820.$var)?anf86820.$var.app(body2933028,k160138):R.ffi.throwNonFunApp(L[329],anf86820.$var,[body2933028,k160138]);
};
try {
if(--R.GAS > 0) {
$z30313032 = $f30373038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30373038,
"from":L[329]});
}
} catch($e30293030) {
if(R.isCont($e30293030)) {
var $ss30333034 = {"from":L[329],
"go":function(ann_DASH_check_DASH_temp554782) {
return $Hann_DASH_check_DASH_temp928781(ann_DASH_check_DASH_temp554782);
}};
$e30293030.stack[R.EXN_STACKHEIGHT++] = $ss30333034;
}
if(R.isPyretException($e30293030)) {
$e30293030.pyretStack.push(L[329]);
}
throw $e30293030;
}
var $ret30353036 = $Hann_DASH_check_DASH_temp928781($z30313032);
++R.GAS;
return $ret30353036;
});
var anf_obj5812745 = R.makeFunction(function(l294643,params2953014,args296641,ret297644,doc2983015,body299642,$underscore3003016) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[89],7,arguments);
}
var $z30193020 = D;
var $f30253026 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(l294643,("ann-check-temp")):R.ffi.throwNonFunApp(L[328],mk_DASH_id70825.$var,[l294643,("ann-check-temp")]);
};
try {
if(--R.GAS > 0) {
$z30193020 = $f30253026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30253026,
"from":L[328]});
}
} catch($e30173018) {
if(R.isCont($e30173018)) {
var $ss30213022 = {"from":L[328],
"go":function(name301640) {
return $Hname939639(name301640,A110,N512,anf_DASH_term78497,args296641,body299642,k160138,l294643,list25501,ret297644);
}};
$e30173018.stack[R.EXN_STACKHEIGHT++] = $ss30213022;
}
if(R.isPyretException($e30173018)) {
$e30173018.pyretStack.push(L[328]);
}
throw $e30173018;
}
var $ret30233024 = $Hname939639($z30193020,A110,N512,anf_DASH_term78497,args296641,body299642,k160138,l294643,list25501,ret297644);
++R.GAS;
return $ret30233024;
});
var anf_obj6072746 = R.makeFunction(function(l303500,args304498,ret305502,doc3063002,body307499,$underscore3083003) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[66],6,arguments);
}
var $z30063007 = D;
var $f30123013 = function(_) {
return R.isFunction(mk_DASH_id70825.$var)?mk_DASH_id70825.$var.app(l303500,("ann-check-temp")):R.ffi.throwNonFunApp(L[327],mk_DASH_id70825.$var,[l303500,("ann-check-temp")]);
};
try {
if(--R.GAS > 0) {
$z30063007 = $f30123013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30123013,
"from":L[327]});
}
} catch($e30043005) {
if(R.isCont($e30043005)) {
var $ss30083009 = {"from":L[327],
"go":function(name309496) {
return $Hname950495(name309496,A110,N512,anf_DASH_term78497,args304498,body307499,k160138,l303500,list25501,ret305502);
}};
$e30043005.stack[R.EXN_STACKHEIGHT++] = $ss30083009;
}
if(R.isPyretException($e30043005)) {
$e30043005.pyretStack.push(L[327]);
}
throw $e30043005;
}
var $ret30103011 = $Hname950495($z30063007,A110,N512,anf_DASH_term78497,args304498,body307499,k160138,l303500,list25501,ret305502);
++R.GAS;
return $ret30103011;
});
var anf_obj6162747 = R.makeFunction(function(l311470,values3122978) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[322],2,arguments);
}
var anf_arg6152989 = R.makeFunction(function(vs3132990) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[43],1,arguments);
}
var anf_fun610468 = G(k160138,"apply",L[326]);
var anf_fun611469 = G(N512,"a-val",L[325]);
var anf_fun6123001 = G(N512,"a-array",L[324]);
var $z29932994 = D;
var $f29993000 = function(_) {
return R.isFunction(anf_fun6123001)?anf_fun6123001.app(l311470,vs3132990):R.ffi.throwNonFunApp(L[323],anf_fun6123001,[l311470,vs3132990]);
};
try {
if(--R.GAS > 0) {
$z29932994 = $f29993000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29993000,
"from":L[323]});
}
} catch($e29912992) {
if(R.isCont($e29912992)) {
var $ss29952996 = {"from":L[323],
"go":function(anf_arg613467) {
return $Hanf_arg953466(anf_arg613467,anf_fun610468,anf_fun611469,l311470);
}};
$e29912992.stack[R.EXN_STACKHEIGHT++] = $ss29952996;
}
if(R.isPyretException($e29912992)) {
$e29912992.pyretStack.push(L[323]);
}
throw $e29912992;
}
var $ret29972998 = $Hanf_arg953466($z29932994,anf_fun610468,anf_fun611469,l311470);
++R.GAS;
return $ret29972998;
});
var $z29812982 = D;
var $f29872988 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(values3122978,("anf_array_val"),anf_arg6152989):R.ffi.throwNonFunApp(L[322],anf_DASH_name_DASH_rec82135.$var,[values3122978,("anf_array_val"),anf_arg6152989]);
};
try {
if(--R.GAS > 0) {
$z29812982 = $f29872988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29872988,
"from":L[322]});
}
} catch($e29792980) {
if(R.isCont($e29792980)) {
var $ss29832984 = {"from":L[322],
"go":function(ann_DASH_check_DASH_temp608465) {
return $Hann_DASH_check_DASH_temp954464(ann_DASH_check_DASH_temp608465);
}};
$e29792980.stack[R.EXN_STACKHEIGHT++] = $ss29832984;
}
if(R.isPyretException($e29792980)) {
$e29792980.pyretStack.push(L[322]);
}
throw $e29792980;
}
var $ret29852986 = $Hann_DASH_check_DASH_temp954464($z29812982);
++R.GAS;
return $ret29852986;
});
var anf_obj6252748 = R.makeFunction(function(l314451,f3152941,args3162942) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[317],3,arguments);
}
var anf_arg6242953 = R.makeFunction(function(v3172954) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[318],1,arguments);
}
var anf_arg6232965 = R.makeFunction(function(vs3182966) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[41],1,arguments);
}
var anf_fun620450 = G(k160138,"apply",L[321]);
var anf_fun6212977 = G(N512,"a-app",L[320]);
var $z29692970 = D;
var $f29752976 = function(_) {
return R.isFunction(anf_fun6212977)?anf_fun6212977.app(l314451,v3172954,vs3182966):R.ffi.throwNonFunApp(L[319],anf_fun6212977,[l314451,v3172954,vs3182966]);
};
try {
if(--R.GAS > 0) {
$z29692970 = $f29752976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29752976,
"from":L[319]});
}
} catch($e29672968) {
if(R.isCont($e29672968)) {
var $ss29712972 = {"from":L[319],
"go":function(anf_arg622449) {
return $Hanf_arg956448(anf_arg622449,anf_fun620450,l314451);
}};
$e29672968.stack[R.EXN_STACKHEIGHT++] = $ss29712972;
}
if(R.isPyretException($e29672968)) {
$e29672968.pyretStack.push(L[319]);
}
throw $e29672968;
}
var $ret29732974 = $Hanf_arg956448($z29692970,anf_fun620450,l314451);
++R.GAS;
return $ret29732974;
});
var $z29572958 = D;
var $f29632964 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(args3162942,("anf_arg"),anf_arg6232965):R.ffi.throwNonFunApp(L[318],anf_DASH_name_DASH_rec82135.$var,[args3162942,("anf_arg"),anf_arg6232965]);
};
try {
if(--R.GAS > 0) {
$z29572958 = $f29632964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29632964,
"from":L[318]});
}
} catch($e29552956) {
if(R.isCont($e29552956)) {
var $ss29592960 = {"from":L[318],
"go":function(ann_DASH_check_DASH_temp618447) {
return $Hann_DASH_check_DASH_temp957446(ann_DASH_check_DASH_temp618447);
}};
$e29552956.stack[R.EXN_STACKHEIGHT++] = $ss29592960;
}
if(R.isPyretException($e29552956)) {
$e29552956.pyretStack.push(L[318]);
}
throw $e29552956;
}
var $ret29612962 = $Hann_DASH_check_DASH_temp957446($z29572958);
++R.GAS;
return $ret29612962;
});
var $z29452946 = D;
var $f29512952 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(f3152941,("anf_fun"),anf_arg6242953):R.ffi.throwNonFunApp(L[317],anf_DASH_name81136.$var,[f3152941,("anf_fun"),anf_arg6242953]);
};
try {
if(--R.GAS > 0) {
$z29452946 = $f29512952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29512952,
"from":L[317]});
}
} catch($e29432944) {
if(R.isCont($e29432944)) {
var $ss29472948 = {"from":L[317],
"go":function(ann_DASH_check_DASH_temp617445) {
return $Hann_DASH_check_DASH_temp958444(ann_DASH_check_DASH_temp617445);
}};
$e29432944.stack[R.EXN_STACKHEIGHT++] = $ss29472948;
}
if(R.isPyretException($e29432944)) {
$e29432944.pyretStack.push(L[317]);
}
throw $e29432944;
}
var $ret29492950 = $Hann_DASH_check_DASH_temp958444($z29452946);
++R.GAS;
return $ret29492950;
});
var anf_obj6322749 = R.makeFunction(function(l319431,f3202916,args3212917) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[313],3,arguments);
}
var anf_arg6312928 = R.makeFunction(function(vs3222929) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[40],1,arguments);
}
var anf_fun628430 = G(k160138,"apply",L[316]);
var anf_fun6292940 = G(N512,"a-prim-app",L[315]);
var $z29322933 = D;
var $f29382939 = function(_) {
return R.isFunction(anf_fun6292940)?anf_fun6292940.app(l319431,f3202916,vs3222929):R.ffi.throwNonFunApp(L[314],anf_fun6292940,[l319431,f3202916,vs3222929]);
};
try {
if(--R.GAS > 0) {
$z29322933 = $f29382939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29382939,
"from":L[314]});
}
} catch($e29302931) {
if(R.isCont($e29302931)) {
var $ss29342935 = {"from":L[314],
"go":function(anf_arg630429) {
return $Hanf_arg960428(anf_arg630429,anf_fun628430,l319431);
}};
$e29302931.stack[R.EXN_STACKHEIGHT++] = $ss29342935;
}
if(R.isPyretException($e29302931)) {
$e29302931.pyretStack.push(L[314]);
}
throw $e29302931;
}
var $ret29362937 = $Hanf_arg960428($z29322933,anf_fun628430,l319431);
++R.GAS;
return $ret29362937;
});
var $z29202921 = D;
var $f29262927 = function(_) {
return R.isFunction(anf_DASH_name_DASH_rec82135.$var)?anf_DASH_name_DASH_rec82135.$var.app(args3212917,("anf_arg"),anf_arg6312928):R.ffi.throwNonFunApp(L[313],anf_DASH_name_DASH_rec82135.$var,[args3212917,("anf_arg"),anf_arg6312928]);
};
try {
if(--R.GAS > 0) {
$z29202921 = $f29262927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29262927,
"from":L[313]});
}
} catch($e29182919) {
if(R.isCont($e29182919)) {
var $ss29222923 = {"from":L[313],
"go":function(ann_DASH_check_DASH_temp626427) {
return $Hann_DASH_check_DASH_temp961426(ann_DASH_check_DASH_temp626427);
}};
$e29182919.stack[R.EXN_STACKHEIGHT++] = $ss29222923;
}
if(R.isPyretException($e29182919)) {
$e29182919.pyretStack.push(L[313]);
}
throw $e29182919;
}
var $ret29242925 = $Hann_DASH_check_DASH_temp961426($z29202921);
++R.GAS;
return $ret29242925;
});
var anf_obj6392750 = R.makeFunction(function(l323413,obj3242891,field3252892) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[309],3,arguments);
}
var anf_arg6382903 = R.makeFunction(function(t_DASH_obj3262904) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[39],1,arguments);
}
var anf_fun635412 = G(k160138,"apply",L[312]);
var anf_fun6362915 = G(N512,"a-dot",L[311]);
var $z29072908 = D;
var $f29132914 = function(_) {
return R.isFunction(anf_fun6362915)?anf_fun6362915.app(l323413,t_DASH_obj3262904,field3252892):R.ffi.throwNonFunApp(L[310],anf_fun6362915,[l323413,t_DASH_obj3262904,field3252892]);
};
try {
if(--R.GAS > 0) {
$z29072908 = $f29132914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29132914,
"from":L[310]});
}
} catch($e29052906) {
if(R.isCont($e29052906)) {
var $ss29092910 = {"from":L[310],
"go":function(anf_arg637411) {
return $Hanf_arg963410(anf_arg637411,anf_fun635412,l323413);
}};
$e29052906.stack[R.EXN_STACKHEIGHT++] = $ss29092910;
}
if(R.isPyretException($e29052906)) {
$e29052906.pyretStack.push(L[310]);
}
throw $e29052906;
}
var $ret29112912 = $Hanf_arg963410($z29072908,anf_fun635412,l323413);
++R.GAS;
return $ret29112912;
});
var $z28952896 = D;
var $f29012902 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(obj3242891,("anf_bracket"),anf_arg6382903):R.ffi.throwNonFunApp(L[309],anf_DASH_name81136.$var,[obj3242891,("anf_bracket"),anf_arg6382903]);
};
try {
if(--R.GAS > 0) {
$z28952896 = $f29012902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29012902,
"from":L[309]});
}
} catch($e28932894) {
if(R.isCont($e28932894)) {
var $ss28972898 = {"from":L[309],
"go":function(ann_DASH_check_DASH_temp633409) {
return $Hann_DASH_check_DASH_temp964408(ann_DASH_check_DASH_temp633409);
}};
$e28932894.stack[R.EXN_STACKHEIGHT++] = $ss28972898;
}
if(R.isPyretException($e28932894)) {
$e28932894.pyretStack.push(L[309]);
}
throw $e28932894;
}
var $ret28992900 = $Hann_DASH_check_DASH_temp964408($z28952896);
++R.GAS;
return $ret28992900;
});
var anf_obj6542751 = R.makeFunction(function(l327340,obj328341,field3292862) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[32],3,arguments);
}
var cases_DASH_val382890 = field3292862;
var anf_fun6412873 = G(cases_DASH_val382890,"_match",L[38]);
var anf_obj6432886 = R.makeFunction(function($underscore3312887,s3322888) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[308],2,arguments);
}
var ann_DASH_check_DASH_temp6422889 = s3322888;
return ann_DASH_check_DASH_temp6422889;
});
var anf_arg6442874 = R.makeObject({"s-str":anf_obj6432886});
var anf_arg6482875 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[38],0,arguments);
}
var $z28782879 = D;
var $f28842885 = function(_) {
return R.isFunction(torepr8)?torepr8.app(field3292862):R.ffi.throwNonFunApp(L[307],torepr8,[field3292862]);
};
try {
if(--R.GAS > 0) {
$z28782879 = $f28842885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28842885,
"from":L[307]});
}
} catch($e28762877) {
if(R.isCont($e28762877)) {
var $ss28802881 = {"from":L[307],
"go":function(anf_arg646383) {
return $Hanf_arg967382(anf_arg646383,_plus4,raise7);
}};
$e28762877.stack[R.EXN_STACKHEIGHT++] = $ss28802881;
}
if(R.isPyretException($e28762877)) {
$e28762877.pyretStack.push(L[307]);
}
throw $e28762877;
}
var $ret28822883 = $Hanf_arg967382($z28782879,_plus4,raise7);
++R.GAS;
return $ret28822883;
});
var $z28652866 = D;
var $f28712872 = function(_) {
return R.isFunction(anf_fun6412873)?anf_fun6412873.app(anf_arg6442874,anf_arg6482875):R.ffi.throwNonFunApp(L[306],anf_fun6412873,[anf_arg6442874,anf_arg6482875]);
};
try {
if(--R.GAS > 0) {
$z28652866 = $f28712872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28712872,
"from":L[306]});
}
} catch($e28632864) {
if(R.isCont($e28632864)) {
var $ss28672868 = {"from":L[306],
"go":function(fname330339) {
return $Hfname971338(fname330339,N512,anf_DASH_name81136,k160138,l327340,obj328341);
}};
$e28632864.stack[R.EXN_STACKHEIGHT++] = $ss28672868;
}
if(R.isPyretException($e28632864)) {
$e28632864.pyretStack.push(L[306]);
}
throw $e28632864;
}
var $ret28692870 = $Hfname971338($z28652866,N512,anf_DASH_name81136,k160138,l327340,obj328341);
++R.GAS;
return $ret28692870;
});
var anf_obj6612752 = R.makeFunction(function(l334325,obj3352837,field3362838) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[302],3,arguments);
}
var anf_arg6602849 = R.makeFunction(function(t3372850) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[31],1,arguments);
}
var anf_fun657324 = G(k160138,"apply",L[305]);
var anf_fun6582861 = G(N512,"a-get-bang",L[304]);
var $z28532854 = D;
var $f28592860 = function(_) {
return R.isFunction(anf_fun6582861)?anf_fun6582861.app(l334325,t3372850,field3362838):R.ffi.throwNonFunApp(L[303],anf_fun6582861,[l334325,t3372850,field3362838]);
};
try {
if(--R.GAS > 0) {
$z28532854 = $f28592860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28592860,
"from":L[303]});
}
} catch($e28512852) {
if(R.isCont($e28512852)) {
var $ss28552856 = {"from":L[303],
"go":function(anf_arg659323) {
return $Hanf_arg973322(anf_arg659323,anf_fun657324,l334325);
}};
$e28512852.stack[R.EXN_STACKHEIGHT++] = $ss28552856;
}
if(R.isPyretException($e28512852)) {
$e28512852.pyretStack.push(L[303]);
}
throw $e28512852;
}
var $ret28572858 = $Hanf_arg973322($z28532854,anf_fun657324,l334325);
++R.GAS;
return $ret28572858;
});
var $z28412842 = D;
var $f28472848 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(obj3352837,("anf_get_bang"),anf_arg6602849):R.ffi.throwNonFunApp(L[302],anf_DASH_name81136.$var,[obj3352837,("anf_get_bang"),anf_arg6602849]);
};
try {
if(--R.GAS > 0) {
$z28412842 = $f28472848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28472848,
"from":L[302]});
}
} catch($e28392840) {
if(R.isCont($e28392840)) {
var $ss28432844 = {"from":L[302],
"go":function(ann_DASH_check_DASH_temp655321) {
return $Hann_DASH_check_DASH_temp974320(ann_DASH_check_DASH_temp655321);
}};
$e28392840.stack[R.EXN_STACKHEIGHT++] = $ss28432844;
}
if(R.isPyretException($e28392840)) {
$e28392840.pyretStack.push(L[302]);
}
throw $e28392840;
}
var $ret28452846 = $Hann_DASH_check_DASH_temp974320($z28412842);
++R.GAS;
return $ret28452846;
});
var anf_obj6682753 = R.makeFunction(function(l338307,id3392812,value3402813) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[298],3,arguments);
}
var anf_arg6672824 = R.makeFunction(function(v3412825) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
var anf_fun664306 = G(k160138,"apply",L[301]);
var anf_fun6652836 = G(N512,"a-assign",L[300]);
var $z28282829 = D;
var $f28342835 = function(_) {
return R.isFunction(anf_fun6652836)?anf_fun6652836.app(l338307,id3392812,v3412825):R.ffi.throwNonFunApp(L[299],anf_fun6652836,[l338307,id3392812,v3412825]);
};
try {
if(--R.GAS > 0) {
$z28282829 = $f28342835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28342835,
"from":L[299]});
}
} catch($e28262827) {
if(R.isCont($e28262827)) {
var $ss28302831 = {"from":L[299],
"go":function(anf_arg666305) {
return $Hanf_arg976304(anf_arg666305,anf_fun664306,l338307);
}};
$e28262827.stack[R.EXN_STACKHEIGHT++] = $ss28302831;
}
if(R.isPyretException($e28262827)) {
$e28262827.pyretStack.push(L[299]);
}
throw $e28262827;
}
var $ret28322833 = $Hanf_arg976304($z28282829,anf_fun664306,l338307);
++R.GAS;
return $ret28322833;
});
var $z28162817 = D;
var $f28222823 = function(_) {
return R.isFunction(anf_DASH_name81136.$var)?anf_DASH_name81136.$var.app(value3402813,("anf_assign"),anf_arg6672824):R.ffi.throwNonFunApp(L[298],anf_DASH_name81136.$var,[value3402813,("anf_assign"),anf_arg6672824]);
};
try {
if(--R.GAS > 0) {
$z28162817 = $f28222823();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28222823,
"from":L[298]});
}
} catch($e28142815) {
if(R.isCont($e28142815)) {
var $ss28182819 = {"from":L[298],
"go":function(ann_DASH_check_DASH_temp662303) {
return $Hann_DASH_check_DASH_temp977302(ann_DASH_check_DASH_temp662303);
}};
$e28142815.stack[R.EXN_STACKHEIGHT++] = $ss28182819;
}
if(R.isPyretException($e28142815)) {
$e28142815.pyretStack.push(L[298]);
}
throw $e28142815;
}
var $ret28202821 = $Hann_DASH_check_DASH_temp977302($z28162817);
++R.GAS;
return $ret28202821;
});
var anf_obj6842754 = R.makeFunction(function(l342230,fields343229) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[19],2,arguments);
}
var anf_fun6702808 = G(fields343229,"map",L[297]);
var anf_arg6722809 = R.makeFunction(function(recv_DASH_392810) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[296],1,arguments);
}
var ann_DASH_check_DASH_temp6712811 = G(recv_DASH_392810,"value",L[296]);
return ann_DASH_check_DASH_temp6712811;
});
var $z28002801 = D;
var $f28062807 = function(_) {
return R.isFunction(anf_fun6702808)?anf_fun6702808.app(anf_arg6722809):R.ffi.throwNonFunApp(L[295],anf_fun6702808,[anf_arg6722809]);
};
try {
if(--R.GAS > 0) {
$z28002801 = $f28062807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28062807,
"from":L[295]});
}
} catch($e27982799) {
if(R.isCont($e27982799)) {
var $ss28022803 = {"from":L[295],
"go":function(exprs344228) {
return $Hexprs983227(exprs344228,N512,anf_DASH_name_DASH_rec82135,fields343229,k160138,l342230,map238140);
}};
$e27982799.stack[R.EXN_STACKHEIGHT++] = $ss28022803;
}
if(R.isPyretException($e27982799)) {
$e27982799.pyretStack.push(L[295]);
}
throw $e27982799;
}
var $ret28042805 = $Hexprs983227($z28002801,N512,anf_DASH_name_DASH_rec82135,fields343229,k160138,l342230,map238140);
++R.GAS;
return $ret28042805;
});
var anf_obj7022755 = R.makeFunction(function(l349139,obj350141,fields351137) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[7],3,arguments);
}
var anf_fun6862794 = G(fields351137,"map",L[294]);
var anf_arg6882795 = R.makeFunction(function(recv_DASH_402796) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[293],1,arguments);
}
var ann_DASH_check_DASH_temp6872797 = G(recv_DASH_402796,"value",L[293]);
return ann_DASH_check_DASH_temp6872797;
});
var $z27862787 = D;
var $f27922793 = function(_) {
return R.isFunction(anf_fun6862794)?anf_fun6862794.app(anf_arg6882795):R.ffi.throwNonFunApp(L[292],anf_fun6862794,[anf_arg6882795]);
};
try {
if(--R.GAS > 0) {
$z27862787 = $f27922793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27922793,
"from":L[292]});
}
} catch($e27842785) {
if(R.isCont($e27842785)) {
var $ss27882789 = {"from":L[292],
"go":function(exprs352134) {
return $Hexprs990133(exprs352134,N512,anf_DASH_name_DASH_rec82135,anf_DASH_name81136,fields351137,k160138,l349139,map238140,obj350141);
}};
$e27842785.stack[R.EXN_STACKHEIGHT++] = $ss27882789;
}
if(R.isPyretException($e27842785)) {
$e27842785.pyretStack.push(L[292]);
}
throw $e27842785;
}
var $ret27902791 = $Hexprs990133($z27862787,N512,anf_DASH_name_DASH_rec82135,anf_DASH_name81136,fields351137,k160138,l349139,map238140,obj350141);
++R.GAS;
return $ret27902791;
});
var anf_obj7062756 = R.makeFunction(function($underscore3582771,$underscore3592772,$underscore3602773) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[6],3,arguments);
}
var $z27762777 = D;
var $f27822783 = function(_) {
return R.isFunction(torepr8)?torepr8.app(e1592703):R.ffi.throwNonFunApp(L[291],torepr8,[e1592703]);
};
try {
if(--R.GAS > 0) {
$z27762777 = $f27822783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27822783,
"from":L[291]});
}
} catch($e27742775) {
if(R.isCont($e27742775)) {
var $ss27782779 = {"from":L[291],
"go":function(anf_arg704108) {
return $Hanf_arg993107(anf_arg704108,_plus4,raise7);
}};
$e27742775.stack[R.EXN_STACKHEIGHT++] = $ss27782779;
}
if(R.isPyretException($e27742775)) {
$e27742775.pyretStack.push(L[291]);
}
throw $e27742775;
}
var $ret27802781 = $Hanf_arg993107($z27762777,_plus4,raise7);
++R.GAS;
return $ret27802781;
});
var anf_obj7102757 = R.makeFunction(function($underscore3612758,$underscore3622759,$underscore3632760) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[4],3,arguments);
}
var $z27632764 = D;
var $f27692770 = function(_) {
return R.isFunction(torepr8)?torepr8.app(e1592703):R.ffi.throwNonFunApp(L[290],torepr8,[e1592703]);
};
try {
if(--R.GAS > 0) {
$z27632764 = $f27692770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27692770,
"from":L[290]});
}
} catch($e27612762) {
if(R.isCont($e27612762)) {
var $ss27652766 = {"from":L[290],
"go":function(anf_arg70882) {
return $Hanf_arg99681(anf_arg70882,_plus4,raise7);
}};
$e27612762.stack[R.EXN_STACKHEIGHT++] = $ss27652766;
}
if(R.isPyretException($e27612762)) {
$e27612762.pyretStack.push(L[290]);
}
throw $e27612762;
}
var $ret27672768 = $Hanf_arg99681($z27632764,_plus4,raise7);
++R.GAS;
return $ret27672768;
});
var anf_arg7112715 = R.makeObject({"s-module":anf_obj2442727,
"s-num":anf_obj2512728,
"s-frac":anf_obj2592729,
"s-str":anf_obj2662730,
"s-undefined":anf_obj2732731,
"s-bool":anf_obj2802732,
"s-id":anf_obj2872733,
"s-id-var":anf_obj2942734,
"s-id-letrec":anf_obj3012735,
"s-srcloc":anf_obj3082736,
"s-type-let-expr":anf_obj3322737,
"s-let-expr":anf_obj3722738,
"s-letrec":anf_obj3952739,
"s-data-expr":anf_obj4962740,
"s-if-else":anf_obj5462741,
"s-try":anf_obj5512742,
"s-block":anf_obj5532743,
"s-user-block":anf_obj5552744,
"s-lam":anf_obj5812745,
"s-method":anf_obj6072746,
"s-array":anf_obj6162747,
"s-app":anf_obj6252748,
"s-prim-app":anf_obj6322749,
"s-dot":anf_obj6392750,
"s-bracket":anf_obj6542751,
"s-get-bang":anf_obj6612752,
"s-assign":anf_obj6682753,
"s-obj":anf_obj6842754,
"s-extend":anf_obj7022755,
"s-let":anf_obj7062756,
"s-var":anf_obj7102757});
var anf_arg7152716 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2],0,arguments);
}
var $z27192720 = D;
var $f27252726 = function(_) {
return R.isFunction(torepr8)?torepr8.app(e1592703):R.ffi.throwNonFunApp(L[289],torepr8,[e1592703]);
};
try {
if(--R.GAS > 0) {
$z27192720 = $f27252726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27252726,
"from":L[289]});
}
} catch($e27172718) {
if(R.isCont($e27172718)) {
var $ss27212722 = {"from":L[289],
"go":function(anf_arg71356) {
return $Hanf_arg99955(anf_arg71356,_plus4,raise7);
}};
$e27172718.stack[R.EXN_STACKHEIGHT++] = $ss27212722;
}
if(R.isPyretException($e27172718)) {
$e27172718.pyretStack.push(L[289]);
}
throw $e27172718;
}
var $ret27232724 = $Hanf_arg99955($z27192720,_plus4,raise7);
++R.GAS;
return $ret27232724;
});
var $z27062707 = D;
var $f27122713 = function(_) {
return R.isFunction(anf_fun2332714)?anf_fun2332714.app(anf_arg7112715,anf_arg7152716):R.ffi.throwNonFunApp(L[288],anf_fun2332714,[anf_arg7112715,anf_arg7152716]);
};
try {
if(--R.GAS > 0) {
$z27062707 = $f27122713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27122713,
"from":L[288]});
}
} catch($e27042705) {
if(R.isCont($e27042705)) {
var $ss27082709 = {"from":L[288],
"go":function(ann_DASH_check_DASH_temp23254) {
return $Hann_DASH_check_DASH_temp100053(ann_DASH_check_DASH_temp23254,N620);
}};
$e27042705.stack[R.EXN_STACKHEIGHT++] = $ss27082709;
}
if(R.isPyretException($e27042705)) {
$e27042705.pyretStack.push(L[288]);
}
throw $e27042705;
}
var $ret27102711 = $Hann_DASH_check_DASH_temp100053($z27062707,N620);
++R.GAS;
return $ret27102711;
});
});
anf86820.$var = anf_assign7162690;
var provides71739 = R.makeObject({"names":names692702,
"mk-id":mk_DASH_id70825.$var,
"ANFCont":ANFCont722668.$var,
"is-ANFCont":is_DASH_ANFCont732670.$var,
"k-cont":k_DASH_cont752020.$var,
"is-k-cont":is_DASH_k_DASH_cont742672.$var,
"k-id":k_DASH_id77823.$var,
"is-k-id":is_DASH_k_DASH_id762675.$var,
"anf-term":anf_DASH_term78497.$var,
"bind":bind792632.$var,
"anf-bind":anf_DASH_bind802680.$var,
"anf-name":anf_DASH_name81136.$var,
"anf-name-rec":anf_DASH_name_DASH_rec82135.$var,
"anf-program":anf_DASH_program832684.$var,
"anf-import":anf_DASH_import842686.$var,
"anf-block":anf_DASH_block852688.$var,
"anf":anf86820.$var});
var anf_fun7182701 = G(builtins5,"current-checker",L[0]);
var $z26932694 = D;
var $f26992700 = function(_) {
return R.isFunction(anf_fun7182701)?anf_fun7182701.app():R.ffi.throwNonFunApp(L[0],anf_fun7182701,[]);
};
try {
if(--R.GAS > 0) {
$z26932694 = $f26992700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26992700,
"from":L[0]});
}
} catch($e26912692) {
if(R.isCont($e26912692)) {
var $ss26952696 = {"from":L[0],
"go":function(anf_bracket71936) {
return $Hanf_bracket100235(anf_bracket71936,ANFCont6637,Loc6838,provides71739,nothing6);
}};
$e26912692.stack[R.EXN_STACKHEIGHT++] = $ss26952696;
}
if(R.isPyretException($e26912692)) {
$e26912692.pyretStack.push(L[0]);
}
throw $e26912692;
}
var $ret26972698 = $Hanf_bracket100235($z26932694,ANFCont6637,Loc6838,provides71739,nothing6);
++R.GAS;
return $ret26972698;
},function(moduleVal) {
R.modules["$src/arr/compiler/anf.arr26"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/ast-split.arr',["compiler/ast-anf.arr",
"trove/ast",
"trove/pprint",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($N11633,$A31734,$PP51835,$arrays71936,$lists92037,$option112138,$error132239,$sets152340) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/ast-split.arr32"]) {
return R.modules["$src/arr/compiler/ast-split.arr32"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/ast-split.arr";
var D = R.undefined;
var L = [[M,9,0,111,227,3,7730],
[M,194,0,6523,227,3,7730],
[M,207,28,6915,207,41,6928],
[M,207,28,6915,207,35,6922],
[M,207,20,6907,207,27,6914],
[M,207,7,6894,207,19,6906],
[M,206,6,6862,206,30,6886],
[M,206,6,6862,206,20,6876],
[M,205,6,6844,205,17,6855],
[M,204,6,6828,204,15,6837],
[M,200,2,6669,203,5,6821],
[M,201,4,6693,201,27,6716],
[M,195,2,6532,199,5,6666],
[M,196,4,6557,198,7,6660],
[M,197,6,6580,197,78,6652],
[M,197,55,6629,197,77,6651],
[M,197,55,6629,197,71,6645],
[M,14,0,269,31,3,911],
[M,207,20,6907,207,42,6929],
[M,207,2,6889,207,43,6930],
[M,208,2,6933,208,78,7009],
[M,208,2,6933,208,17,6948],
[M,208,21,6952,208,78,7009],
[M,208,58,6989,208,77,7008],
[M,210,2,7013,210,12,7023],
[M,211,18,7042,211,43,7067],
[M,211,33,7057,211,42,7066],
[M,211,18,7042,211,26,7050],
[M,211,7,7031,211,14,7038],
[M,211,53,7077,211,66,7090],
[M,211,53,7077,211,60,7084],
[M,211,45,7069,211,52,7076],
[M,211,45,7069,211,67,7091],
[M,211,90,7114,211,102,7126],
[M,211,90,7114,211,96,7120],
[M,211,82,7106,211,89,7113],
[M,211,69,7093,211,81,7105],
[M,211,82,7106,211,103,7127],
[M,211,69,7093,211,104,7128],
[M,211,2,7026,211,105,7129],
[M,212,2,7132,212,28,7158],
[M,213,2,7161,213,40,7199],
[M,213,2,7161,213,28,7187],
[M,213,2,7161,213,26,7185],
[M,213,2,7161,213,18,7177],
[M,213,32,7191,213,40,7199],
[M,214,2,7202,214,21,7221],
[M,214,2,7202,214,15,7215],
[M,215,2,7224,215,42,7264],
[M,215,23,7245,215,42,7264],
[M,215,2,7224,215,19,7241],
[M,217,2,7268,217,12,7278],
[M,218,2,7281,218,12,7291],
[M,219,18,7310,219,43,7335],
[M,219,33,7325,219,42,7334],
[M,219,18,7310,219,26,7318],
[M,219,7,7299,219,14,7306],
[M,219,56,7348,219,68,7360],
[M,219,56,7348,219,62,7354],
[M,219,45,7337,219,52,7344],
[M,219,77,7369,219,90,7382],
[M,219,77,7369,219,84,7376],
[M,219,70,7362,219,91,7383],
[M,219,45,7337,219,92,7384],
[M,220,25,7411,220,37,7423],
[M,220,25,7411,220,31,7417],
[M,220,17,7403,220,24,7410],
[M,220,4,7390,220,16,7402],
[M,220,17,7403,220,38,7424],
[M,220,4,7390,220,39,7425],
[M,219,2,7294,220,40,7426],
[M,221,2,7429,221,28,7455],
[M,222,2,7458,222,42,7498],
[M,222,2,7458,222,28,7484],
[M,222,2,7458,222,26,7482],
[M,222,2,7458,222,18,7474],
[M,222,2,7458,222,37,7493],
[M,222,2,7458,222,35,7491],
[M,223,2,7501,224,39,7581],
[M,223,2,7501,223,28,7527],
[M,223,2,7501,223,26,7525],
[M,223,2,7501,223,18,7517],
[M,224,25,7567,224,37,7579],
[M,224,25,7567,224,31,7573],
[M,224,17,7559,224,24,7566],
[M,224,4,7546,224,16,7558],
[M,223,2,7501,223,39,7538],
[M,223,2,7501,223,34,7533],
[M,224,17,7559,224,38,7580],
[M,224,4,7546,224,39,7581],
[M,225,2,7584,226,125,7726],
[M,226,28,7629,226,40,7641],
[M,226,28,7629,226,34,7635],
[M,226,4,7605,226,17,7618],
[M,225,2,7584,225,15,7597],
[M,226,49,7650,226,62,7663],
[M,226,49,7650,226,56,7657],
[M,226,42,7643,226,63,7664],
[M,226,65,7666,226,91,7692],
[M,226,65,7666,226,89,7690],
[M,226,65,7666,226,81,7682],
[M,226,111,7712,226,123,7724],
[M,226,111,7712,226,117,7718],
[M,226,104,7705,226,124,7725],
[M,226,65,7666,226,102,7703],
[M,226,65,7666,226,97,7698],
[M,226,4,7605,226,125,7726],
[M,202,23,6740,202,52,6769],
[M,202,23,6740,202,38,6755],
[M,202,23,6740,202,34,6751],
[M,202,54,6771,202,80,6797],
[M,202,71,6788,202,79,6796],
[M,202,54,6771,202,70,6787],
[M,202,82,6799,202,97,6814],
[M,202,82,6799,202,94,6811],
[M,170,2,5687,187,5,6461],
[M,182,10,6187,182,51,6228],
[M,182,35,6212,182,50,6227],
[M,182,10,6187,182,20,6197],
[M,181,10,6157,181,28,6175],
[M,183,54,6284,183,69,6299],
[M,183,63,6293,183,68,6298],
[M,183,54,6284,183,62,6292],
[M,183,34,6264,183,53,6283],
[M,183,10,6240,183,28,6258],
[M,183,124,6354,183,138,6368],
[M,183,133,6363,183,137,6367],
[M,183,124,6354,183,132,6362],
[M,183,102,6332,183,123,6353],
[M,183,71,6301,183,101,6331],
[M,183,71,6301,183,90,6320],
[M,183,102,6332,183,139,6369],
[M,183,71,6301,183,140,6370],
[M,183,34,6264,183,141,6371],
[M,183,10,6240,183,142,6372],
[M,178,4,6047,184,9,6382],
[M,175,10,5850,175,48,5888],
[M,175,32,5872,175,47,5887],
[M,175,10,5850,175,17,5857],
[M,174,10,5820,174,28,5838],
[M,176,54,5944,176,69,5959],
[M,176,63,5953,176,68,5958],
[M,176,54,5944,176,62,5952],
[M,176,34,5924,176,53,5943],
[M,176,10,5900,176,28,5918],
[M,176,124,6014,176,138,6028],
[M,176,133,6023,176,137,6027],
[M,176,124,6014,176,132,6022],
[M,176,102,5992,176,123,6013],
[M,176,71,5961,176,101,5991],
[M,176,71,5961,176,90,5980],
[M,176,102,5992,176,139,6029],
[M,176,71,5961,176,140,6030],
[M,176,34,5924,176,141,6031],
[M,176,10,5900,176,142,6032],
[M,171,4,5713,177,9,6042],
[M,165,20,5566,165,43,5589],
[M,113,2,3440,166,5,5595],
[M,163,49,5484,163,78,5513],
[M,163,62,5497,163,77,5512],
[M,163,49,5484,163,61,5496],
[M,163,29,5464,163,47,5482],
[M,158,6,5195,164,9,5545],
[M,163,80,5515,163,99,5534],
[M,160,69,5317,160,84,5332],
[M,160,69,5317,160,81,5329],
[M,160,98,5346,160,120,5368],
[M,160,107,5355,160,119,5367],
[M,160,98,5346,160,106,5354],
[M,160,69,5317,160,90,5338],
[M,160,91,5339,160,121,5369],
[M,160,69,5317,160,122,5370],
[M,159,8,5225,160,123,5371],
[M,147,6,4785,151,9,5030],
[M,147,17,4796,151,9,5030],
[M,149,8,4921,150,67,5020],
[M,150,34,4987,150,66,5019],
[M,150,34,4987,150,60,5013],
[M,150,34,4987,150,53,5006],
[M,150,10,4963,150,28,4981],
[M,148,8,4829,148,91,4912],
[M,148,45,4866,148,77,4898],
[M,148,45,4866,148,71,4892],
[M,148,45,4866,148,64,4885],
[M,154,10,5097,154,48,5135],
[M,154,32,5119,154,47,5134],
[M,154,10,5097,154,22,5109],
[M,153,10,5067,153,28,5085],
[M,145,4,4708,156,9,5165],
[M,148,45,4866,148,84,4905],
[M,139,6,4441,139,37,4472],
[M,141,10,4509,141,50,4549],
[M,141,32,4531,141,49,4548],
[M,141,10,4509,141,29,4528],
[M,142,10,4560,142,59,4609],
[M,142,44,4594,142,58,4608],
[M,142,26,4576,142,42,4592],
[M,142,10,4560,142,16,4566],
[M,143,10,4621,143,28,4639],
[M,143,10,4621,143,22,4633],
[M,143,10,4621,143,56,4667],
[M,143,35,4646,143,55,4666],
[M,143,10,4621,143,34,4645],
[M,143,10,4621,143,82,4693],
[M,143,63,4674,143,81,4692],
[M,143,10,4621,143,62,4673],
[M,137,4,4362,144,9,4703],
[M,134,23,4259,134,48,4284],
[M,134,38,4274,134,47,4283],
[M,134,23,4259,134,31,4267],
[M,134,12,4248,134,19,4255],
[M,135,36,4325,135,48,4337],
[M,135,36,4325,135,42,4331],
[M,135,28,4317,135,35,4324],
[M,135,14,4303,135,21,4310],
[M,135,28,4317,135,49,4338],
[M,135,14,4303,135,56,4345],
[M,134,12,4248,135,57,4346],
[M,129,6,4073,136,9,4357],
[M,121,10,3797,121,39,3826],
[M,123,12,3869,123,48,3905],
[M,123,31,3888,123,47,3904],
[M,123,12,3869,123,28,3885],
[M,124,12,3918,124,52,3958],
[M,124,38,3944,124,51,3957],
[M,124,23,3929,124,36,3942],
[M,124,12,3918,124,19,3925],
[M,125,12,3972,125,54,4014],
[M,125,36,3996,125,53,4013],
[M,125,12,3972,125,35,3995],
[M,125,12,3972,125,29,3989],
[M,117,6,3563,127,9,4036],
[M,118,54,3641,118,128,3715],
[M,118,118,3705,118,127,3714],
[M,118,8,3595,118,137,3724],
[M,101,8,3028,101,41,3061],
[M,103,12,3102,103,49,3139],
[M,103,33,3123,103,48,3138],
[M,103,12,3102,103,30,3120],
[M,105,14,3177,105,58,3221],
[M,105,42,3205,105,57,3220],
[M,105,28,3191,105,40,3203],
[M,105,14,3177,105,21,3184],
[M,107,14,3254,107,58,3298],
[M,107,42,3282,107,57,3297],
[M,107,28,3268,107,40,3280],
[M,107,14,3254,107,21,3261],
[M,104,15,3155,104,21,3161],
[M,109,38,3354,109,70,3386],
[M,109,65,3381,109,69,3385],
[M,109,38,3354,109,64,3380],
[M,109,38,3354,109,57,3373],
[M,109,31,3347,109,36,3352],
[M,109,12,3328,109,30,3346],
[M,109,38,3354,109,94,3410],
[M,109,77,3393,109,93,3409],
[M,109,38,3354,109,76,3392],
[M,109,12,3328,109,95,3411],
[M,89,4,2449,111,7,3431],
[M,92,40,2583,92,72,2615],
[M,92,67,2610,92,71,2614],
[M,92,40,2583,92,66,2609],
[M,92,40,2583,92,59,2602],
[M,92,33,2576,92,38,2581],
[M,92,14,2557,92,32,2575],
[M,92,8,2551,92,73,2616],
[M,93,35,2652,93,48,2665],
[M,93,35,2652,93,46,2663],
[M,93,35,2652,93,39,2656],
[M,93,19,2636,93,34,2651],
[M,93,19,2636,93,49,2666],
[M,93,62,2679,93,75,2692],
[M,93,62,2679,93,73,2690],
[M,93,56,2673,93,60,2677],
[M,93,51,2668,93,76,2693],
[M,93,8,2625,93,94,2711],
[M,93,78,2695,93,93,2710],
[M,95,12,2752,95,31,2771],
[M,95,12,2752,95,53,2793],
[M,95,34,2774,95,52,2792],
[M,96,54,2848,96,78,2872],
[M,96,65,2859,96,77,2871],
[M,96,65,2859,96,71,2865],
[M,96,54,2848,96,64,2858],
[M,96,54,2848,96,60,2854],
[M,96,46,2840,96,52,2846],
[M,96,12,2806,96,25,2819],
[M,96,12,2806,96,79,2873],
[M,97,29,2904,97,51,2926],
[M,97,38,2913,97,50,2925],
[M,97,29,2904,97,37,2912],
[M,97,12,2887,97,21,2896],
[M,97,22,2897,97,52,2927],
[M,97,12,2887,97,53,2928],
[M,97,60,2935,97,75,2950],
[M,97,60,2935,97,72,2947],
[M,97,12,2887,97,59,2934],
[M,97,12,2887,97,76,2951],
[M,90,6,2477,98,11,2963],
[M,84,15,2302,84,34,2321],
[M,84,15,2302,84,32,2319],
[M,84,15,2302,84,24,2311],
[M,82,0,2213,85,3,2346],
[M,84,44,2331,84,54,2341],
[M,84,36,2323,84,42,2329],
[M,68,2,1950,72,5,2071],
[M,63,2,1830,67,5,1947],
[M,54,54,1706,54,74,1726],
[M,54,54,1706,54,72,1724],
[M,54,54,1706,54,63,1715],
[M,54,47,1699,54,75,1727],
[M,54,14,1666,54,76,1728],
[M,53,4,1636,55,7,1736],
[M,52,2,1544,55,7,1736],
[M,47,36,1484,47,63,1511],
[M,47,36,1484,47,57,1505],
[M,47,6,1454,47,35,1483],
[M,46,4,1418,47,64,1512],
[M,38,47,1154,38,74,1181],
[M,38,61,1168,38,73,1180],
[M,38,47,1154,38,60,1167],
[M,38,47,1154,38,56,1163],
[M,38,36,1143,38,45,1152],
[M,38,21,1128,38,34,1141],
[M,38,10,1117,38,19,1126],
[M,37,33,1052,38,75,1182],
[M,37,6,1025,38,76,1183],
[M,39,43,1227,39,63,1247],
[M,39,43,1227,39,61,1245],
[M,39,43,1227,39,52,1236],
[M,39,24,1208,39,30,1214],
[M,39,15,1199,39,23,1207],
[M,39,31,1215,39,64,1248],
[M,39,24,1208,39,64,1248],
[M,39,24,1208,39,91,1275],
[M,39,78,1262,39,90,1274],
[M,39,78,1262,39,84,1268],
[M,39,6,1190,39,91,1275],
[M,40,37,1313,40,57,1333],
[M,40,37,1313,40,55,1331],
[M,40,37,1313,40,46,1322],
[M,40,6,1282,40,17,1293],
[M,40,59,1335,40,70,1346],
[M,40,59,1335,40,65,1341],
[M,36,4,1003,41,7,1355],
[M,35,2,929,41,7,1355],
[M,25,50,754,25,67,771],
[M,25,50,754,25,64,768],
[M,25,50,754,25,60,764],
[M,25,18,722,25,31,735],
[M,25,4,708,25,72,776],
[M,22,4,604,24,7,702],
[M,21,2,531,25,72,776],
[M,20,18,491,20,34,507],
[M,20,4,477,20,55,528],
[M,18,2,380,20,55,528],
[M,15,2,291,17,26,377],
[M,30,2,862,30,47,907],
[M,3,0,13,227,3,7730],
[M,190,0,6467,192,3,6521],
[M,191,20,6507,191,29,6516],
[M,191,2,6489,191,10,6497],
[M,169,0,5601,188,3,6465],
[M,186,42,6439,186,57,6454],
[M,186,42,6439,186,54,6451],
[M,179,6,6087,179,39,6120],
[M,172,6,5750,172,39,5783],
[M,169,28,5629,169,39,5640],
[M,87,0,2348,167,3,5599],
[M,165,30,5576,165,42,5588],
[M,157,4,5170,164,9,5545],
[M,162,23,5413,162,41,5431],
[M,162,10,5400,162,44,5434],
[M,160,43,5291,160,67,5315],
[M,160,43,5291,160,55,5303],
[M,146,6,4745,146,39,4778],
[M,138,6,4399,138,41,4434],
[M,128,4,4041,136,9,4357],
[M,132,10,4178,132,41,4209],
[M,132,14,4182,132,29,4197],
[M,130,8,4103,130,54,4149],
[M,116,4,3535,127,9,4036],
[M,120,21,3764,120,39,3782],
[M,120,10,3753,120,43,3786],
[M,118,67,3654,118,116,3703],
[M,118,67,3654,118,91,3678],
[M,118,67,3654,118,81,3668],
[M,118,54,3641,118,62,3649],
[M,114,4,3465,115,39,3530],
[M,88,2,2405,112,5,3437],
[M,100,18,2998,100,36,3016],
[M,100,8,2988,100,39,3019],
[M,91,8,2509,91,41,2542],
[M,87,27,2375,87,34,2382],
[M,83,6,2266,83,20,2280],
[M,83,2,2262,83,26,2286],
[M,82,22,2235,82,29,2242],
[M,75,0,2077,79,3,2210],
[M,76,24,2147,76,43,2166],
[M,76,2,2125,78,5,2206],
[M,77,4,2184,77,17,2197],
[M,75,21,2098,75,33,2110],
[M,62,0,1807,73,3,2075],
[M,63,4,1832,67,5,1947],
[M,65,14,1903,65,21,1910],
[M,64,17,1869,64,35,1887],
[M,66,18,1930,67,4,1946],
[M,68,4,1952,72,5,2071],
[M,70,14,2023,70,25,2034],
[M,69,17,1989,69,35,2007],
[M,71,18,2054,72,4,2070],
[M,71,6,2042,72,4,2070],
[M,70,6,2015,70,25,2034],
[M,69,6,1978,69,35,2007],
[M,66,6,1918,67,4,1946],
[M,65,6,1895,65,21,1910],
[M,64,6,1858,64,35,1887],
[M,58,0,1742,60,3,1805],
[M,59,2,1790,59,13,1801],
[M,58,32,1774,58,43,1785],
[M,51,0,1524,56,3,1740],
[M,52,4,1546,52,83,1625],
[M,52,50,1592,52,57,1599],
[M,52,28,1570,52,40,1582],
[M,52,71,1613,52,82,1624],
[M,54,14,1666,54,44,1696],
[M,54,31,1683,54,43,1695],
[M,54,14,1666,54,30,1682],
[M,54,14,1666,54,26,1678],
[M,54,6,1658,54,13,1665],
[M,52,59,1601,52,82,1624],
[M,52,42,1584,52,57,1599],
[M,52,17,1559,52,40,1582],
[M,44,0,1361,49,3,1522],
[M,45,2,1397,48,5,1518],
[M,47,6,1454,47,24,1472],
[M,47,6,1454,47,18,1466],
[M,44,25,1386,44,31,1392],
[M,34,0,914,42,3,1359],
[M,35,4,931,35,65,992],
[M,35,19,946,35,25,952],
[M,35,57,984,35,64,991],
[M,35,35,962,35,47,974],
[M,37,65,1084,37,87,1106],
[M,37,77,1096,37,86,1105],
[M,37,65,1084,37,74,1093],
[M,37,33,1052,37,53,1072],
[M,37,17,1036,37,24,1043],
[M,35,49,976,35,64,991],
[M,35,27,954,35,47,974],
[M,35,11,938,35,25,952],
[M,18,4,382,18,29,407],
[M,21,4,533,21,64,593],
[M,21,26,555,21,39,568],
[M,21,50,579,21,63,592],
[M,25,32,736,25,48,752],
[M,25,32,736,25,45,749],
[M,25,32,736,25,41,745],
[M,23,28,665,23,56,693],
[M,23,28,665,23,50,687],
[M,23,28,665,23,38,675],
[M,23,6,643,23,27,664],
[M,23,6,643,23,15,652],
[M,22,30,630,22,34,634],
[M,21,41,570,21,63,592],
[M,21,18,547,21,39,568],
[M,20,35,508,20,50,523],
[M,20,37,510,20,49,522],
[M,19,4,418,19,57,471],
[M,19,34,448,19,46,460],
[M,18,21,399,18,28,406],
[M,17,4,355,17,26,377],
[M,16,4,316,16,37,349],
[M,30,34,894,30,42,902],
[M,30,17,877,30,33,893],
[M,28,4,826,28,17,839],
[M,27,2,788,29,5,858],
[M,27,23,809,27,33,819],
[M,9,8,119,9,22,133]];
var _plus10 = NAMESPACE.get("_plus");
var builtins11 = NAMESPACE.get("builtins");
var nothing12 = NAMESPACE.get("nothing");
var raise13 = NAMESPACE.get("raise");
var torepr14 = NAMESPACE.get("torepr");
var $type$String15 = NAMESPACE.get("$type$String");
var $Hanf_bracket97841 = function(anf_bracket55342,A317,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,N116,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,list2572,names7473,param10874,result_DASH_after_DASH_checks122375,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11) {
var anf_fun55493 = G(anf_bracket55342,"run-checks",L[0]);
var anf_fun55590 = G(list2572,"make",L[0]);
var anf_obj68895 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1],0,arguments);
}
var strip_DASH_helper22497 = {"$var":D,
"$name":"strip-helper"};
var split_DASH_strip22599 = {"$var":D,
"$name":"split-strip"};
var anf_assign56698 = R.makeFunction(function(h226133) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[12],1,arguments);
}
var cases_DASH_val59167 = h226133;
var anf_fun558144 = G(cases_DASH_val59167,"_match",L[13]);
var anf_obj562150 = R.makeFunction(function(name227151,args228152,body229153) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[14],3,arguments);
}
var anf_fun560164 = G(N116,"strip-loc-expr",L[16]);
var $z156157 = D;
var $f162163 = function(_) {
return R.isFunction(anf_fun560164)?anf_fun560164.app(body229153):R.ffi.throwNonFunApp(L[15],anf_fun560164,[body229153]);
};
try {
if(--R.GAS > 0) {
$z156157 = $f162163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f162163,
"from":L[15]});
}
} catch($e154155) {
if(R.isCont($e154155)) {
var $ss158159 = {"from":L[15],
"go":function(anf_arg561165) {
return $Hanf_arg905166(anf_arg561165,args228152,helper8960,name227151);
}};
$e154155.stack[R.EXN_STACKHEIGHT++] = $ss158159;
}
if(R.isPyretException($e154155)) {
$e154155.pyretStack.push(L[15]);
}
throw $e154155;
}
var $ret160161 = $Hanf_arg905166($z156157,args228152,helper8960,name227151);
++R.GAS;
return $ret160161;
});
var anf_arg563145 = R.makeObject({"helper":anf_obj562150});
var anf_arg565146 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[13],0,arguments);
}
var ann_DASH_check_DASH_temp564149 = R.throwNoBranchesMatched(L[13],("cases"));
return ann_DASH_check_DASH_temp564149;
});
var $z136137 = D;
var $f142143 = function(_) {
return R.isFunction(anf_fun558144)?anf_fun558144.app(anf_arg563145,anf_arg565146):R.ffi.throwNonFunApp(L[12],anf_fun558144,[anf_arg563145,anf_arg565146]);
};
try {
if(--R.GAS > 0) {
$z136137 = $f142143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f142143,
"from":L[12]});
}
} catch($e134135) {
if(R.isCont($e134135)) {
var $ss138139 = {"from":L[12],
"go":function(ann_DASH_check_DASH_temp557147) {
return $Hann_DASH_check_DASH_temp906148(ann_DASH_check_DASH_temp557147);
}};
$e134135.stack[R.EXN_STACKHEIGHT++] = $ss138139;
}
if(R.isPyretException($e134135)) {
$e134135.pyretStack.push(L[12]);
}
throw $e134135;
}
var $ret140141 = $Hann_DASH_check_DASH_temp906148($z136137);
++R.GAS;
return $ret140141;
});
strip_DASH_helper22497.$var = anf_assign56698;
var anf_assign576100 = R.makeFunction(function(e230120) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[10],1,arguments);
}
var $z123124 = D;
var $f129130 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(e230120):R.ffi.throwNonFunApp(L[11],ast_DASH_split_DASH_expr10652.$var,[e230120]);
};
try {
if(--R.GAS > 0) {
$z123124 = $f129130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f129130,
"from":L[11]});
}
} catch($e121122) {
if(R.isCont($e121122)) {
var $ss125126 = {"from":L[11],
"go":function(res231131) {
return $Hres911132(res231131,N116,e230120,split_DASH_result_DASH_int_DASH_e10176,strip_DASH_helper22497);
}};
$e121122.stack[R.EXN_STACKHEIGHT++] = $ss125126;
}
if(R.isPyretException($e121122)) {
$e121122.pyretStack.push(L[11]);
}
throw $e121122;
}
var $ret127128 = $Hres911132($z123124,N116,e230120,split_DASH_result_DASH_int_DASH_e10176,strip_DASH_helper22497);
++R.GAS;
return $ret127128;
});
split_DASH_strip22599.$var = anf_assign576100;
var b232119 = G(A317,"a-blank",L[9]);
var d233112 = G(N116,"dummy-loc",L[8]);
var anf_bracket577118 = G(A317,"global-names",L[7]);
var n234116 = G(anf_bracket577118,"make-atom",L[6]);
var anf_fun578114 = G(N116,"a-lettable",L[5]);
var anf_fun579115 = G(N116,"a-val",L[4]);
var anf_fun580111 = G(N116,"a-num",L[3]);
var $z103104 = D;
var $f109110 = function(_) {
return R.isFunction(anf_fun580111)?anf_fun580111.app(d233112,(5)):R.ffi.throwNonFunApp(L[2],anf_fun580111,[d233112,(5)]);
};
try {
if(--R.GAS > 0) {
$z103104 = $f109110();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f109110,
"from":L[2]});
}
} catch($e101102) {
if(R.isCont($e101102)) {
var $ss105106 = {"from":L[2],
"go":function(anf_arg581113) {
return $Hanf_arg972117(anf_arg581113,A317,N116,anf_fun578114,anf_fun579115,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
}};
$e101102.stack[R.EXN_STACKHEIGHT++] = $ss105106;
}
if(R.isPyretException($e101102)) {
$e101102.pyretStack.push(L[2]);
}
throw $e101102;
}
var $ret107108 = $Hanf_arg972117($z103104,A317,N116,anf_fun578114,anf_fun579115,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret107108;
});
var anf_obj68996 = R.makeSrcloc(L[1]);
var anf_array_val69091 = R.makeObject({"name":("check-block-1"),
"run":anf_obj68895,
"location":anf_obj68996});
var $z8283 = D;
var $f8889 = function(_) {
return R.isFunction(anf_fun55590)?anf_fun55590.app([anf_array_val69091]):R.ffi.throwNonFunApp(L[0],anf_fun55590,[[anf_array_val69091]]);
};
try {
if(--R.GAS > 0) {
$z8283 = $f8889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8889,
"from":L[0]});
}
} catch($e8081) {
if(R.isCont($e8081)) {
var $ss8485 = {"from":L[0],
"go":function(anf_arg69192) {
return $Hanf_arg97794(anf_arg69192,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,anf_fun55493,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,names7473,param10874,result_DASH_after_DASH_checks122375,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11);
}};
$e8081.stack[R.EXN_STACKHEIGHT++] = $ss8485;
}
if(R.isPyretException($e8081)) {
$e8081.pyretStack.push(L[0]);
}
throw $e8081;
}
var $ret8687 = $Hanf_arg97794($z8283,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,anf_fun55493,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,names7473,param10874,result_DASH_after_DASH_checks122375,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11);
++R.GAS;
return $ret8687;
};
var $Hanf_arg97794 = function(anf_arg69192,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,anf_fun55493,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,names7473,param10874,result_DASH_after_DASH_checks122375,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11) {
var $z170171 = D;
var $f176177 = function(_) {
return R.isFunction(anf_fun55493)?anf_fun55493.app(("src/arr/compiler/ast-split.arr"),anf_arg69192):R.ffi.throwNonFunApp(L[0],anf_fun55493,[("src/arr/compiler/ast-split.arr"),anf_arg69192]);
};
try {
if(--R.GAS > 0) {
$z170171 = $f176177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f176177,
"from":L[0]});
}
} catch($e168169) {
if(R.isCont($e168169)) {
var $ss172173 = {"from":L[0],
"go":function(anf_begin_app_dropped973178) {
return $Hanf_begin_app_dropped976179(anf_begin_app_dropped973178,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,names7473,param10874,result_DASH_after_DASH_checks122375,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11);
}};
$e168169.stack[R.EXN_STACKHEIGHT++] = $ss172173;
}
if(R.isPyretException($e168169)) {
$e168169.pyretStack.push(L[0]);
}
throw $e168169;
}
var $ret174175 = $Hanf_begin_app_dropped976179($z170171,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,names7473,param10874,result_DASH_after_DASH_checks122375,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11);
++R.GAS;
return $ret174175;
};
var $Hanf_begin_app_dropped976179 = function(anf_begin_app_dropped973178,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,names7473,param10874,result_DASH_after_DASH_checks122375,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11) {
var provides692192 = R.makeObject({"names":names7473,
"INDENT":INDENT7547,
"ConcatList":ConcatList7744.$var,
"is-ConcatList":is_DASH_ConcatList7861.$var,
"concat-empty":concat_DASH_empty8056.$var,
"is-concat-empty":is_DASH_concat_DASH_empty7966.$var,
"concat-singleton":concat_DASH_singleton8257.$var,
"is-concat-singleton":is_DASH_concat_DASH_singleton8167.$var,
"concat-append":concat_DASH_append8455.$var,
"is-concat-append":is_DASH_concat_DASH_append8365.$var,
"Helper":Helper8646.$var,
"is-Helper":is_DASH_Helper8762.$var,
"helper":helper8960.$var,
"is-helper":is_DASH_helper8868.$var,
"freevars-helper":freevars_DASH_helper9058.$var,
"SplitResult":SplitResult9249.$var,
"is-SplitResult":is_DASH_SplitResult9363.$var,
"split-result":split_DASH_result9578.$var,
"is-split-result":is_DASH_split_DASH_result9471.$var,
"freevars-split-result":freevars_DASH_split_DASH_result9659.$var,
"SplitResultInt":SplitResultInt9851.$var,
"is-SplitResultInt":is_DASH_SplitResultInt9964.$var,
"split-result-int-e":split_DASH_result_DASH_int_DASH_e10176.$var,
"is-split-result-int-e":is_DASH_split_DASH_result_DASH_int_DASH_e10069.$var,
"split-result-int-l":split_DASH_result_DASH_int_DASH_l10377.$var,
"is-split-result-int-l":is_DASH_split_DASH_result_DASH_int_DASH_l10270.$var,
"unions":unions10479.$var,
"ast-split":ast_DASH_split10554.$var,
"ast-split-expr":ast_DASH_split_DASH_expr10652.$var,
"ast-split-lettable":ast_DASH_split_DASH_lettable10753.$var,
"param":param10874.$var,
"result-after-checks1":result_DASH_after_DASH_checks122375});
var anf_fun693190 = G(builtins11,"current-checker",L[17]);
var $z182183 = D;
var $f188189 = function(_) {
return R.isFunction(anf_fun693190)?anf_fun693190.app():R.ffi.throwNonFunApp(L[17],anf_fun693190,[]);
};
try {
if(--R.GAS > 0) {
$z182183 = $f188189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f188189,
"from":L[17]});
}
} catch($e180181) {
if(R.isCont($e180181)) {
var $ss184185 = {"from":L[17],
"go":function(anf_bracket694191) {
return $Hanf_bracket975193(anf_bracket694191,ConcatList6643,Helper6845,SplitResult7048,SplitResultInt7250,provides692192,result_DASH_after_DASH_checks122375);
}};
$e180181.stack[R.EXN_STACKHEIGHT++] = $ss184185;
}
if(R.isPyretException($e180181)) {
$e180181.pyretStack.push(L[17]);
}
throw $e180181;
}
var $ret186187 = $Hanf_bracket975193($z182183,ConcatList6643,Helper6845,SplitResult7048,SplitResultInt7250,provides692192,result_DASH_after_DASH_checks122375);
++R.GAS;
return $ret186187;
};
var $Hanf_bracket975193 = function(anf_bracket694191,ConcatList6643,Helper6845,SplitResult7048,SplitResultInt7250,provides692192,result_DASH_after_DASH_checks122375) {
var anf_fun695204 = G(anf_bracket694191,"results",L[17]);
var $z196197 = D;
var $f202203 = function(_) {
return R.isFunction(anf_fun695204)?anf_fun695204.app():R.ffi.throwNonFunApp(L[17],anf_fun695204,[]);
};
try {
if(--R.GAS > 0) {
$z196197 = $f202203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f202203,
"from":L[17]});
}
} catch($e194195) {
if(R.isCont($e194195)) {
var $ss198199 = {"from":L[17],
"go":function(checks696205) {
return $Hchecks974206(checks696205,ConcatList6643,Helper6845,SplitResult7048,SplitResultInt7250,provides692192,result_DASH_after_DASH_checks122375);
}};
$e194195.stack[R.EXN_STACKHEIGHT++] = $ss198199;
}
if(R.isPyretException($e194195)) {
$e194195.pyretStack.push(L[17]);
}
throw $e194195;
}
var $ret200201 = $Hchecks974206($z196197,ConcatList6643,Helper6845,SplitResult7048,SplitResultInt7250,provides692192,result_DASH_after_DASH_checks122375);
++R.GAS;
return $ret200201;
};
var $Hchecks974206 = function(checks696205,ConcatList6643,Helper6845,SplitResult7048,SplitResultInt7250,provides692192,result_DASH_after_DASH_checks122375) {
return R.makeObject({"answer":result_DASH_after_DASH_checks122375,
"provide-plus-types":R.makeObject({"values":provides692192,
"types":{"ConcatList":ConcatList6643,
"Helper":Helper6845,
"SplitResult":SplitResult7048,
"SplitResultInt":SplitResultInt7250}}),
"checks":checks696205});
};
var $Hanf_arg972117 = function(anf_arg581113,A317,N116,anf_fun578114,anf_fun579115,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11) {
var $z209210 = D;
var $f215216 = function(_) {
return R.isFunction(anf_fun579115)?anf_fun579115.app(anf_arg581113):R.ffi.throwNonFunApp(L[18],anf_fun579115,[anf_arg581113]);
};
try {
if(--R.GAS > 0) {
$z209210 = $f215216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f215216,
"from":L[18]});
}
} catch($e207208) {
if(R.isCont($e207208)) {
var $ss211212 = {"from":L[18],
"go":function(anf_arg582217) {
return $Hanf_arg971218(anf_arg582217,A317,N116,anf_fun578114,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
}};
$e207208.stack[R.EXN_STACKHEIGHT++] = $ss211212;
}
if(R.isPyretException($e207208)) {
$e207208.pyretStack.push(L[18]);
}
throw $e207208;
}
var $ret213214 = $Hanf_arg971218($z209210,A317,N116,anf_fun578114,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret213214;
};
var $Hanf_arg971218 = function(anf_arg582217,A317,N116,anf_fun578114,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11) {
var $z221222 = D;
var $f227228 = function(_) {
return R.isFunction(anf_fun578114)?anf_fun578114.app(anf_arg582217):R.ffi.throwNonFunApp(L[19],anf_fun578114,[anf_arg582217]);
};
try {
if(--R.GAS > 0) {
$z221222 = $f227228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f227228,
"from":L[19]});
}
} catch($e219220) {
if(R.isCont($e219220)) {
var $ss223224 = {"from":L[19],
"go":function(e1235229) {
return $He1970230(e1235229,A317,N116,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
}};
$e219220.stack[R.EXN_STACKHEIGHT++] = $ss223224;
}
if(R.isPyretException($e219220)) {
$e219220.pyretStack.push(L[19]);
}
throw $e219220;
}
var $ret225226 = $He1970230($z221222,A317,N116,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret225226;
};
var $He1970230 = function(e1235229,A317,N116,concat_DASH_empty8056,d233112,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11) {
var anf_fun583241 = G(builtins11,"current-checker",L[20]);
var $z233234 = D;
var $f239240 = function(_) {
return R.isFunction(anf_fun583241)?anf_fun583241.app():R.ffi.throwNonFunApp(L[20],anf_fun583241,[]);
};
try {
if(--R.GAS > 0) {
$z233234 = $f239240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f239240,
"from":L[20]});
}
} catch($e231232) {
if(R.isCont($e231232)) {
var $ss235236 = {"from":L[20],
"go":function(anf_bracket584242) {
return $Hanf_bracket969243(anf_bracket584242,A317,N116,concat_DASH_empty8056,d233112,e1235229,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
}};
$e231232.stack[R.EXN_STACKHEIGHT++] = $ss235236;
}
if(R.isPyretException($e231232)) {
$e231232.pyretStack.push(L[20]);
}
throw $e231232;
}
var $ret237238 = $Hanf_bracket969243($z233234,A317,N116,concat_DASH_empty8056,d233112,e1235229,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret237238;
};
var $Hanf_bracket969243 = function(anf_bracket584242,A317,N116,concat_DASH_empty8056,d233112,e1235229,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11) {
var anf_fun585255 = G(anf_bracket584242,"check-is",L[20]);
var $z246247 = D;
var $f252253 = function(_) {
return R.isFunction(split_DASH_strip22599.$var)?split_DASH_strip22599.$var.app(e1235229):R.ffi.throwNonFunApp(L[21],split_DASH_strip22599.$var,[e1235229]);
};
try {
if(--R.GAS > 0) {
$z246247 = $f252253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f252253,
"from":L[21]});
}
} catch($e244245) {
if(R.isCont($e244245)) {
var $ss248249 = {"from":L[21],
"go":function(anf_arg586254) {
return $Hanf_arg968256(anf_arg586254,A317,N116,anf_fun585255,concat_DASH_empty8056,d233112,e1235229,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
}};
$e244245.stack[R.EXN_STACKHEIGHT++] = $ss248249;
}
if(R.isPyretException($e244245)) {
$e244245.pyretStack.push(L[21]);
}
throw $e244245;
}
var $ret250251 = $Hanf_arg968256($z246247,A317,N116,anf_fun585255,concat_DASH_empty8056,d233112,e1235229,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret250251;
};
var $Hanf_arg968256 = function(anf_arg586254,A317,N116,anf_fun585255,concat_DASH_empty8056,d233112,e1235229,list2572,n234116,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_strip22599,builtins11) {
var anf_arg587267 = G(sets1523,"empty-tree-set",L[23]);
var $z259260 = D;
var $f265266 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(concat_DASH_empty8056.$var,e1235229,anf_arg587267):R.ffi.throwNonFunApp(L[22],split_DASH_result_DASH_int_DASH_e10176.$var,[concat_DASH_empty8056.$var,e1235229,anf_arg587267]);
};
try {
if(--R.GAS > 0) {
$z259260 = $f265266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f265266,
"from":L[22]});
}
} catch($e257258) {
if(R.isCont($e257258)) {
var $ss261262 = {"from":L[22],
"go":function(anf_arg588268) {
return $Hanf_arg967269(anf_arg588268,A317,N116,anf_arg586254,anf_fun585255,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e257258.stack[R.EXN_STACKHEIGHT++] = $ss261262;
}
if(R.isPyretException($e257258)) {
$e257258.pyretStack.push(L[22]);
}
throw $e257258;
}
var $ret263264 = $Hanf_arg967269($z259260,A317,N116,anf_arg586254,anf_fun585255,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret263264;
};
var $Hanf_arg967269 = function(anf_arg588268,A317,N116,anf_arg586254,anf_fun585255,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_arg589280 = R.makeSrcloc(L[20]);
var $z272273 = D;
var $f278279 = function(_) {
return R.isFunction(anf_fun585255)?anf_fun585255.app(("split-strip(e1) is split-result-int-e(concat-empty, e1, sets.empty-tree-set)"),anf_arg586254,anf_arg588268,anf_arg589280):R.ffi.throwNonFunApp(L[20],anf_fun585255,[("split-strip(e1) is split-result-int-e(concat-empty, e1, sets.empty-tree-set)"),anf_arg586254,anf_arg588268,anf_arg589280]);
};
try {
if(--R.GAS > 0) {
$z272273 = $f278279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f278279,
"from":L[20]});
}
} catch($e270271) {
if(R.isCont($e270271)) {
var $ss274275 = {"from":L[20],
"go":function(anf_begin_app_dropped912281) {
return $Hanf_begin_app_dropped966282(anf_begin_app_dropped912281,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e270271.stack[R.EXN_STACKHEIGHT++] = $ss274275;
}
if(R.isPyretException($e270271)) {
$e270271.pyretStack.push(L[20]);
}
throw $e270271;
}
var $ret276277 = $Hanf_begin_app_dropped966282($z272273,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret276277;
};
var $Hanf_begin_app_dropped966282 = function(anf_begin_app_dropped912281,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var $z285286 = D;
var $f291292 = function(_) {
return R.isFunction(n234116)?n234116.app(("x")):R.ffi.throwNonFunApp(L[24],n234116,[("x")]);
};
try {
if(--R.GAS > 0) {
$z285286 = $f291292();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f291292,
"from":L[24]});
}
} catch($e283284) {
if(R.isCont($e283284)) {
var $ss287288 = {"from":L[24],
"go":function(x236293) {
return $Hx965294(x236293,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e283284.stack[R.EXN_STACKHEIGHT++] = $ss287288;
}
if(R.isPyretException($e283284)) {
$e283284.pyretStack.push(L[24]);
}
throw $e283284;
}
var $ret289290 = $Hx965294($z285286,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret289290;
};
var $Hx965294 = function(x236293,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_fun590308 = G(N116,"a-let",L[28]);
var anf_fun591305 = G(N116,"a-bind",L[27]);
var anf_arg592306 = G(A317,"a-blank",L[26]);
var $z297298 = D;
var $f303304 = function(_) {
return R.isFunction(anf_fun591305)?anf_fun591305.app(d233112,x236293,anf_arg592306):R.ffi.throwNonFunApp(L[25],anf_fun591305,[d233112,x236293,anf_arg592306]);
};
try {
if(--R.GAS > 0) {
$z297298 = $f303304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f303304,
"from":L[25]});
}
} catch($e295296) {
if(R.isCont($e295296)) {
var $ss299300 = {"from":L[25],
"go":function(anf_arg593307) {
return $Hanf_arg964309(anf_arg593307,A317,N116,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11);
}};
$e295296.stack[R.EXN_STACKHEIGHT++] = $ss299300;
}
if(R.isPyretException($e295296)) {
$e295296.pyretStack.push(L[25]);
}
throw $e295296;
}
var $ret301302 = $Hanf_arg964309($z297298,A317,N116,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11);
++R.GAS;
return $ret301302;
};
var $Hanf_arg964309 = function(anf_arg593307,A317,N116,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11) {
var anf_fun594322 = G(N116,"a-val",L[31]);
var anf_fun595320 = G(N116,"a-num",L[30]);
var $z312313 = D;
var $f318319 = function(_) {
return R.isFunction(anf_fun595320)?anf_fun595320.app(d233112,(5)):R.ffi.throwNonFunApp(L[29],anf_fun595320,[d233112,(5)]);
};
try {
if(--R.GAS > 0) {
$z312313 = $f318319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f318319,
"from":L[29]});
}
} catch($e310311) {
if(R.isCont($e310311)) {
var $ss314315 = {"from":L[29],
"go":function(anf_arg596321) {
return $Hanf_arg963323(anf_arg596321,A317,N116,anf_arg593307,anf_fun590308,anf_fun594322,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11);
}};
$e310311.stack[R.EXN_STACKHEIGHT++] = $ss314315;
}
if(R.isPyretException($e310311)) {
$e310311.pyretStack.push(L[29]);
}
throw $e310311;
}
var $ret316317 = $Hanf_arg963323($z312313,A317,N116,anf_arg593307,anf_fun590308,anf_fun594322,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11);
++R.GAS;
return $ret316317;
};
var $Hanf_arg963323 = function(anf_arg596321,A317,N116,anf_arg593307,anf_fun590308,anf_fun594322,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11) {
var $z326327 = D;
var $f332333 = function(_) {
return R.isFunction(anf_fun594322)?anf_fun594322.app(anf_arg596321):R.ffi.throwNonFunApp(L[32],anf_fun594322,[anf_arg596321]);
};
try {
if(--R.GAS > 0) {
$z326327 = $f332333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f332333,
"from":L[32]});
}
} catch($e324325) {
if(R.isCont($e324325)) {
var $ss328329 = {"from":L[32],
"go":function(anf_arg597334) {
return $Hanf_arg962335(anf_arg597334,A317,N116,anf_arg593307,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11);
}};
$e324325.stack[R.EXN_STACKHEIGHT++] = $ss328329;
}
if(R.isPyretException($e324325)) {
$e324325.pyretStack.push(L[32]);
}
throw $e324325;
}
var $ret330331 = $Hanf_arg962335($z326327,A317,N116,anf_arg593307,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11);
++R.GAS;
return $ret330331;
};
var $Hanf_arg962335 = function(anf_arg597334,A317,N116,anf_arg593307,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,x236293,builtins11) {
var anf_fun598348 = G(N116,"a-lettable",L[36]);
var anf_fun599349 = G(N116,"a-val",L[35]);
var anf_fun600346 = G(N116,"a-id",L[34]);
var $z338339 = D;
var $f344345 = function(_) {
return R.isFunction(anf_fun600346)?anf_fun600346.app(d233112,x236293):R.ffi.throwNonFunApp(L[33],anf_fun600346,[d233112,x236293]);
};
try {
if(--R.GAS > 0) {
$z338339 = $f344345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f344345,
"from":L[33]});
}
} catch($e336337) {
if(R.isCont($e336337)) {
var $ss340341 = {"from":L[33],
"go":function(anf_arg601347) {
return $Hanf_arg961350(anf_arg601347,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,anf_fun598348,anf_fun599349,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e336337.stack[R.EXN_STACKHEIGHT++] = $ss340341;
}
if(R.isPyretException($e336337)) {
$e336337.pyretStack.push(L[33]);
}
throw $e336337;
}
var $ret342343 = $Hanf_arg961350($z338339,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,anf_fun598348,anf_fun599349,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret342343;
};
var $Hanf_arg961350 = function(anf_arg601347,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,anf_fun598348,anf_fun599349,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var $z353354 = D;
var $f359360 = function(_) {
return R.isFunction(anf_fun599349)?anf_fun599349.app(anf_arg601347):R.ffi.throwNonFunApp(L[37],anf_fun599349,[anf_arg601347]);
};
try {
if(--R.GAS > 0) {
$z353354 = $f359360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f359360,
"from":L[37]});
}
} catch($e351352) {
if(R.isCont($e351352)) {
var $ss355356 = {"from":L[37],
"go":function(anf_arg602361) {
return $Hanf_arg960362(anf_arg602361,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,anf_fun598348,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e351352.stack[R.EXN_STACKHEIGHT++] = $ss355356;
}
if(R.isPyretException($e351352)) {
$e351352.pyretStack.push(L[37]);
}
throw $e351352;
}
var $ret357358 = $Hanf_arg960362($z353354,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,anf_fun598348,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret357358;
};
var $Hanf_arg960362 = function(anf_arg602361,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,anf_fun598348,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var $z365366 = D;
var $f371372 = function(_) {
return R.isFunction(anf_fun598348)?anf_fun598348.app(anf_arg602361):R.ffi.throwNonFunApp(L[38],anf_fun598348,[anf_arg602361]);
};
try {
if(--R.GAS > 0) {
$z365366 = $f371372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f371372,
"from":L[38]});
}
} catch($e363364) {
if(R.isCont($e363364)) {
var $ss367368 = {"from":L[38],
"go":function(anf_arg603373) {
return $Hanf_arg959374(anf_arg603373,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e363364.stack[R.EXN_STACKHEIGHT++] = $ss367368;
}
if(R.isPyretException($e363364)) {
$e363364.pyretStack.push(L[38]);
}
throw $e363364;
}
var $ret369370 = $Hanf_arg959374($z365366,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret369370;
};
var $Hanf_arg959374 = function(anf_arg603373,A317,N116,anf_arg593307,anf_arg597334,anf_fun590308,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var $z377378 = D;
var $f383384 = function(_) {
return R.isFunction(anf_fun590308)?anf_fun590308.app(d233112,anf_arg593307,anf_arg597334,anf_arg603373):R.ffi.throwNonFunApp(L[39],anf_fun590308,[d233112,anf_arg593307,anf_arg597334,anf_arg603373]);
};
try {
if(--R.GAS > 0) {
$z377378 = $f383384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f383384,
"from":L[39]});
}
} catch($e375376) {
if(R.isCont($e375376)) {
var $ss379380 = {"from":L[39],
"go":function(e2237385) {
return $He2958386(e2237385,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e375376.stack[R.EXN_STACKHEIGHT++] = $ss379380;
}
if(R.isPyretException($e375376)) {
$e375376.pyretStack.push(L[39]);
}
throw $e375376;
}
var $ret381382 = $He2958386($z377378,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret381382;
};
var $He2958386 = function(e2237385,A317,N116,d233112,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var $z389390 = D;
var $f395396 = function(_) {
return R.isFunction(split_DASH_strip22599.$var)?split_DASH_strip22599.$var.app(e2237385):R.ffi.throwNonFunApp(L[40],split_DASH_strip22599.$var,[e2237385]);
};
try {
if(--R.GAS > 0) {
$z389390 = $f395396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f395396,
"from":L[40]});
}
} catch($e387388) {
if(R.isCont($e387388)) {
var $ss391392 = {"from":L[40],
"go":function(e2_DASH_split238397) {
return $He2_DASH_split957398(e2_DASH_split238397,A317,N116,d233112,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e387388.stack[R.EXN_STACKHEIGHT++] = $ss391392;
}
if(R.isPyretException($e387388)) {
$e387388.pyretStack.push(L[40]);
}
throw $e387388;
}
var $ret393394 = $He2_DASH_split957398($z389390,A317,N116,d233112,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret393394;
};
var $He2_DASH_split957398 = function(e2_DASH_split238397,A317,N116,d233112,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_fun604409 = G(builtins11,"current-checker",L[41]);
var $z401402 = D;
var $f407408 = function(_) {
return R.isFunction(anf_fun604409)?anf_fun604409.app():R.ffi.throwNonFunApp(L[41],anf_fun604409,[]);
};
try {
if(--R.GAS > 0) {
$z401402 = $f407408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f407408,
"from":L[41]});
}
} catch($e399400) {
if(R.isCont($e399400)) {
var $ss403404 = {"from":L[41],
"go":function(anf_bracket605410) {
return $Hanf_bracket956411(anf_bracket605410,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e399400.stack[R.EXN_STACKHEIGHT++] = $ss403404;
}
if(R.isPyretException($e399400)) {
$e399400.pyretStack.push(L[41]);
}
throw $e399400;
}
var $ret405406 = $Hanf_bracket956411($z401402,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret405406;
};
var $Hanf_bracket956411 = function(anf_bracket605410,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_fun606424 = G(anf_bracket605410,"check-is",L[41]);
var anf_bracket607426 = G(e2_DASH_split238397,"helpers",L[44]);
var anf_fun608422 = G(anf_bracket607426,"to-list",L[43]);
var $z414415 = D;
var $f420421 = function(_) {
return R.isFunction(anf_fun608422)?anf_fun608422.app():R.ffi.throwNonFunApp(L[42],anf_fun608422,[]);
};
try {
if(--R.GAS > 0) {
$z414415 = $f420421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f420421,
"from":L[42]});
}
} catch($e412413) {
if(R.isCont($e412413)) {
var $ss416417 = {"from":L[42],
"go":function(anf_arg609423) {
return $Hanf_arg955425(anf_arg609423,A317,N116,anf_fun606424,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e412413.stack[R.EXN_STACKHEIGHT++] = $ss416417;
}
if(R.isPyretException($e412413)) {
$e412413.pyretStack.push(L[42]);
}
throw $e412413;
}
var $ret418419 = $Hanf_arg955425($z414415,A317,N116,anf_fun606424,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret418419;
};
var $Hanf_arg955425 = function(anf_arg609423,A317,N116,anf_fun606424,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_fun610437 = G(list2572,"make",L[45]);
var $z429430 = D;
var $f435436 = function(_) {
return R.isFunction(anf_fun610437)?anf_fun610437.app([]):R.ffi.throwNonFunApp(L[45],anf_fun610437,[[]]);
};
try {
if(--R.GAS > 0) {
$z429430 = $f435436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f435436,
"from":L[45]});
}
} catch($e427428) {
if(R.isCont($e427428)) {
var $ss431432 = {"from":L[45],
"go":function(anf_arg611438) {
return $Hanf_arg954439(anf_arg611438,A317,N116,anf_arg609423,anf_fun606424,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e427428.stack[R.EXN_STACKHEIGHT++] = $ss431432;
}
if(R.isPyretException($e427428)) {
$e427428.pyretStack.push(L[45]);
}
throw $e427428;
}
var $ret433434 = $Hanf_arg954439($z429430,A317,N116,anf_arg609423,anf_fun606424,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret433434;
};
var $Hanf_arg954439 = function(anf_arg611438,A317,N116,anf_arg609423,anf_fun606424,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_arg612450 = R.makeSrcloc(L[41]);
var $z442443 = D;
var $f448449 = function(_) {
return R.isFunction(anf_fun606424)?anf_fun606424.app(("e2-split.helpers.to-list() is [list: ]"),anf_arg609423,anf_arg611438,anf_arg612450):R.ffi.throwNonFunApp(L[41],anf_fun606424,[("e2-split.helpers.to-list() is [list: ]"),anf_arg609423,anf_arg611438,anf_arg612450]);
};
try {
if(--R.GAS > 0) {
$z442443 = $f448449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f448449,
"from":L[41]});
}
} catch($e440441) {
if(R.isCont($e440441)) {
var $ss444445 = {"from":L[41],
"go":function(anf_begin_app_dropped913451) {
return $Hanf_begin_app_dropped953452(anf_begin_app_dropped913451,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e440441.stack[R.EXN_STACKHEIGHT++] = $ss444445;
}
if(R.isPyretException($e440441)) {
$e440441.pyretStack.push(L[41]);
}
throw $e440441;
}
var $ret446447 = $Hanf_begin_app_dropped953452($z442443,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret446447;
};
var $Hanf_begin_app_dropped953452 = function(anf_begin_app_dropped913451,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_fun613463 = G(builtins11,"current-checker",L[46]);
var $z455456 = D;
var $f461462 = function(_) {
return R.isFunction(anf_fun613463)?anf_fun613463.app():R.ffi.throwNonFunApp(L[46],anf_fun613463,[]);
};
try {
if(--R.GAS > 0) {
$z455456 = $f461462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f461462,
"from":L[46]});
}
} catch($e453454) {
if(R.isCont($e453454)) {
var $ss457458 = {"from":L[46],
"go":function(anf_bracket614464) {
return $Hanf_bracket952465(anf_bracket614464,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e453454.stack[R.EXN_STACKHEIGHT++] = $ss457458;
}
if(R.isPyretException($e453454)) {
$e453454.pyretStack.push(L[46]);
}
throw $e453454;
}
var $ret459460 = $Hanf_bracket952465($z455456,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret459460;
};
var $Hanf_bracket952465 = function(anf_bracket614464,A317,N116,d233112,e2_DASH_split238397,e2237385,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_fun615476 = G(anf_bracket614464,"check-is",L[46]);
var anf_arg616477 = G(e2_DASH_split238397,"body",L[47]);
var anf_arg617478 = R.makeSrcloc(L[46]);
var $z468469 = D;
var $f474475 = function(_) {
return R.isFunction(anf_fun615476)?anf_fun615476.app(("e2-split.body is e2"),anf_arg616477,e2237385,anf_arg617478):R.ffi.throwNonFunApp(L[46],anf_fun615476,[("e2-split.body is e2"),anf_arg616477,e2237385,anf_arg617478]);
};
try {
if(--R.GAS > 0) {
$z468469 = $f474475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f474475,
"from":L[46]});
}
} catch($e466467) {
if(R.isCont($e466467)) {
var $ss470471 = {"from":L[46],
"go":function(anf_begin_app_dropped914479) {
return $Hanf_begin_app_dropped951480(anf_begin_app_dropped914479,A317,N116,d233112,e2_DASH_split238397,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e466467.stack[R.EXN_STACKHEIGHT++] = $ss470471;
}
if(R.isPyretException($e466467)) {
$e466467.pyretStack.push(L[46]);
}
throw $e466467;
}
var $ret472473 = $Hanf_begin_app_dropped951480($z468469,A317,N116,d233112,e2_DASH_split238397,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret472473;
};
var $Hanf_begin_app_dropped951480 = function(anf_begin_app_dropped914479,A317,N116,d233112,e2_DASH_split238397,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_fun618491 = G(builtins11,"current-checker",L[48]);
var $z483484 = D;
var $f489490 = function(_) {
return R.isFunction(anf_fun618491)?anf_fun618491.app():R.ffi.throwNonFunApp(L[48],anf_fun618491,[]);
};
try {
if(--R.GAS > 0) {
$z483484 = $f489490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f489490,
"from":L[48]});
}
} catch($e481482) {
if(R.isCont($e481482)) {
var $ss485486 = {"from":L[48],
"go":function(anf_bracket619492) {
return $Hanf_bracket950493(anf_bracket619492,A317,N116,d233112,e2_DASH_split238397,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
}};
$e481482.stack[R.EXN_STACKHEIGHT++] = $ss485486;
}
if(R.isPyretException($e481482)) {
$e481482.pyretStack.push(L[48]);
}
throw $e481482;
}
var $ret487488 = $Hanf_bracket950493($z483484,A317,N116,d233112,e2_DASH_split238397,list2572,n234116,sets1523,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret487488;
};
var $Hanf_bracket950493 = function(anf_bracket619492,A317,N116,d233112,e2_DASH_split238397,list2572,n234116,sets1523,split_DASH_strip22599,builtins11) {
var anf_fun620504 = G(anf_bracket619492,"check-is",L[48]);
var anf_arg621505 = G(e2_DASH_split238397,"freevars",L[50]);
var anf_arg622506 = G(sets1523,"empty-tree-set",L[49]);
var anf_arg623507 = R.makeSrcloc(L[48]);
var $z496497 = D;
var $f502503 = function(_) {
return R.isFunction(anf_fun620504)?anf_fun620504.app(("e2-split.freevars is sets.empty-tree-set"),anf_arg621505,anf_arg622506,anf_arg623507):R.ffi.throwNonFunApp(L[48],anf_fun620504,[("e2-split.freevars is sets.empty-tree-set"),anf_arg621505,anf_arg622506,anf_arg623507]);
};
try {
if(--R.GAS > 0) {
$z496497 = $f502503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f502503,
"from":L[48]});
}
} catch($e494495) {
if(R.isCont($e494495)) {
var $ss498499 = {"from":L[48],
"go":function(anf_begin_app_dropped915508) {
return $Hanf_begin_app_dropped949509(anf_begin_app_dropped915508,A317,N116,d233112,list2572,n234116,split_DASH_strip22599,builtins11);
}};
$e494495.stack[R.EXN_STACKHEIGHT++] = $ss498499;
}
if(R.isPyretException($e494495)) {
$e494495.pyretStack.push(L[48]);
}
throw $e494495;
}
var $ret500501 = $Hanf_begin_app_dropped949509($z496497,A317,N116,d233112,list2572,n234116,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret500501;
};
var $Hanf_begin_app_dropped949509 = function(anf_begin_app_dropped915508,A317,N116,d233112,list2572,n234116,split_DASH_strip22599,builtins11) {
var $z512513 = D;
var $f518519 = function(_) {
return R.isFunction(n234116)?n234116.app(("v")):R.ffi.throwNonFunApp(L[51],n234116,[("v")]);
};
try {
if(--R.GAS > 0) {
$z512513 = $f518519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f518519,
"from":L[51]});
}
} catch($e510511) {
if(R.isCont($e510511)) {
var $ss514515 = {"from":L[51],
"go":function(v239520) {
return $Hv948521(v239520,A317,N116,d233112,list2572,n234116,split_DASH_strip22599,builtins11);
}};
$e510511.stack[R.EXN_STACKHEIGHT++] = $ss514515;
}
if(R.isPyretException($e510511)) {
$e510511.pyretStack.push(L[51]);
}
throw $e510511;
}
var $ret516517 = $Hv948521($z512513,A317,N116,d233112,list2572,n234116,split_DASH_strip22599,builtins11);
++R.GAS;
return $ret516517;
};
var $Hv948521 = function(v239520,A317,N116,d233112,list2572,n234116,split_DASH_strip22599,builtins11) {
var $z524525 = D;
var $f530531 = function(_) {
return R.isFunction(n234116)?n234116.app(("f")):R.ffi.throwNonFunApp(L[52],n234116,[("f")]);
};
try {
if(--R.GAS > 0) {
$z524525 = $f530531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f530531,
"from":L[52]});
}
} catch($e522523) {
if(R.isCont($e522523)) {
var $ss526527 = {"from":L[52],
"go":function(f240532) {
return $Hf947533(f240532,A317,N116,d233112,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e522523.stack[R.EXN_STACKHEIGHT++] = $ss526527;
}
if(R.isPyretException($e522523)) {
$e522523.pyretStack.push(L[52]);
}
throw $e522523;
}
var $ret528529 = $Hf947533($z524525,A317,N116,d233112,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret528529;
};
var $Hf947533 = function(f240532,A317,N116,d233112,list2572,split_DASH_strip22599,v239520,builtins11) {
var anf_fun624547 = G(N116,"a-let",L[56]);
var anf_fun625544 = G(N116,"a-bind",L[55]);
var anf_arg626545 = G(A317,"a-blank",L[54]);
var $z536537 = D;
var $f542543 = function(_) {
return R.isFunction(anf_fun625544)?anf_fun625544.app(d233112,v239520,anf_arg626545):R.ffi.throwNonFunApp(L[53],anf_fun625544,[d233112,v239520,anf_arg626545]);
};
try {
if(--R.GAS > 0) {
$z536537 = $f542543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f542543,
"from":L[53]});
}
} catch($e534535) {
if(R.isCont($e534535)) {
var $ss538539 = {"from":L[53],
"go":function(anf_arg627546) {
return $Hanf_arg946548(anf_arg627546,N116,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e534535.stack[R.EXN_STACKHEIGHT++] = $ss538539;
}
if(R.isPyretException($e534535)) {
$e534535.pyretStack.push(L[53]);
}
throw $e534535;
}
var $ret540541 = $Hanf_arg946548($z536537,N116,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret540541;
};
var $Hanf_arg946548 = function(anf_arg627546,N116,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var anf_fun628561 = G(N116,"a-app",L[59]);
var anf_fun629559 = G(N116,"a-id",L[58]);
var $z551552 = D;
var $f557558 = function(_) {
return R.isFunction(anf_fun629559)?anf_fun629559.app(d233112,f240532):R.ffi.throwNonFunApp(L[57],anf_fun629559,[d233112,f240532]);
};
try {
if(--R.GAS > 0) {
$z551552 = $f557558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f557558,
"from":L[57]});
}
} catch($e549550) {
if(R.isCont($e549550)) {
var $ss553554 = {"from":L[57],
"go":function(anf_arg630560) {
return $Hanf_arg945562(anf_arg630560,N116,anf_arg627546,anf_fun624547,anf_fun628561,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e549550.stack[R.EXN_STACKHEIGHT++] = $ss553554;
}
if(R.isPyretException($e549550)) {
$e549550.pyretStack.push(L[57]);
}
throw $e549550;
}
var $ret555556 = $Hanf_arg945562($z551552,N116,anf_arg627546,anf_fun624547,anf_fun628561,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret555556;
};
var $Hanf_arg945562 = function(anf_arg630560,N116,anf_arg627546,anf_fun624547,anf_fun628561,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var anf_fun631575 = G(list2572,"make",L[62]);
var anf_fun632573 = G(N116,"a-num",L[61]);
var $z565566 = D;
var $f571572 = function(_) {
return R.isFunction(anf_fun632573)?anf_fun632573.app(d233112,(5)):R.ffi.throwNonFunApp(L[60],anf_fun632573,[d233112,(5)]);
};
try {
if(--R.GAS > 0) {
$z565566 = $f571572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f571572,
"from":L[60]});
}
} catch($e563564) {
if(R.isCont($e563564)) {
var $ss567568 = {"from":L[60],
"go":function(anf_array_val633574) {
return $Hanf_array_val944576(anf_array_val633574,N116,anf_arg627546,anf_arg630560,anf_fun624547,anf_fun628561,anf_fun631575,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e563564.stack[R.EXN_STACKHEIGHT++] = $ss567568;
}
if(R.isPyretException($e563564)) {
$e563564.pyretStack.push(L[60]);
}
throw $e563564;
}
var $ret569570 = $Hanf_array_val944576($z565566,N116,anf_arg627546,anf_arg630560,anf_fun624547,anf_fun628561,anf_fun631575,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret569570;
};
var $Hanf_array_val944576 = function(anf_array_val633574,N116,anf_arg627546,anf_arg630560,anf_fun624547,anf_fun628561,anf_fun631575,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var $z579580 = D;
var $f585586 = function(_) {
return R.isFunction(anf_fun631575)?anf_fun631575.app([anf_array_val633574]):R.ffi.throwNonFunApp(L[62],anf_fun631575,[[anf_array_val633574]]);
};
try {
if(--R.GAS > 0) {
$z579580 = $f585586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f585586,
"from":L[62]});
}
} catch($e577578) {
if(R.isCont($e577578)) {
var $ss581582 = {"from":L[62],
"go":function(anf_arg634587) {
return $Hanf_arg943588(anf_arg634587,N116,anf_arg627546,anf_arg630560,anf_fun624547,anf_fun628561,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e577578.stack[R.EXN_STACKHEIGHT++] = $ss581582;
}
if(R.isPyretException($e577578)) {
$e577578.pyretStack.push(L[62]);
}
throw $e577578;
}
var $ret583584 = $Hanf_arg943588($z579580,N116,anf_arg627546,anf_arg630560,anf_fun624547,anf_fun628561,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret583584;
};
var $Hanf_arg943588 = function(anf_arg634587,N116,anf_arg627546,anf_arg630560,anf_fun624547,anf_fun628561,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var $z591592 = D;
var $f597598 = function(_) {
return R.isFunction(anf_fun628561)?anf_fun628561.app(d233112,anf_arg630560,anf_arg634587):R.ffi.throwNonFunApp(L[63],anf_fun628561,[d233112,anf_arg630560,anf_arg634587]);
};
try {
if(--R.GAS > 0) {
$z591592 = $f597598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f597598,
"from":L[63]});
}
} catch($e589590) {
if(R.isCont($e589590)) {
var $ss593594 = {"from":L[63],
"go":function(anf_arg635599) {
return $Hanf_arg942600(anf_arg635599,N116,anf_arg627546,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e589590.stack[R.EXN_STACKHEIGHT++] = $ss593594;
}
if(R.isPyretException($e589590)) {
$e589590.pyretStack.push(L[63]);
}
throw $e589590;
}
var $ret595596 = $Hanf_arg942600($z591592,N116,anf_arg627546,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret595596;
};
var $Hanf_arg942600 = function(anf_arg635599,N116,anf_arg627546,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var anf_fun636613 = G(N116,"a-lettable",L[67]);
var anf_fun637614 = G(N116,"a-val",L[66]);
var anf_fun638611 = G(N116,"a-id",L[65]);
var $z603604 = D;
var $f609610 = function(_) {
return R.isFunction(anf_fun638611)?anf_fun638611.app(d233112,v239520):R.ffi.throwNonFunApp(L[64],anf_fun638611,[d233112,v239520]);
};
try {
if(--R.GAS > 0) {
$z603604 = $f609610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f609610,
"from":L[64]});
}
} catch($e601602) {
if(R.isCont($e601602)) {
var $ss605606 = {"from":L[64],
"go":function(anf_arg639612) {
return $Hanf_arg941615(anf_arg639612,N116,anf_arg627546,anf_arg635599,anf_fun624547,anf_fun636613,anf_fun637614,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e601602.stack[R.EXN_STACKHEIGHT++] = $ss605606;
}
if(R.isPyretException($e601602)) {
$e601602.pyretStack.push(L[64]);
}
throw $e601602;
}
var $ret607608 = $Hanf_arg941615($z603604,N116,anf_arg627546,anf_arg635599,anf_fun624547,anf_fun636613,anf_fun637614,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret607608;
};
var $Hanf_arg941615 = function(anf_arg639612,N116,anf_arg627546,anf_arg635599,anf_fun624547,anf_fun636613,anf_fun637614,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var $z618619 = D;
var $f624625 = function(_) {
return R.isFunction(anf_fun637614)?anf_fun637614.app(anf_arg639612):R.ffi.throwNonFunApp(L[68],anf_fun637614,[anf_arg639612]);
};
try {
if(--R.GAS > 0) {
$z618619 = $f624625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f624625,
"from":L[68]});
}
} catch($e616617) {
if(R.isCont($e616617)) {
var $ss620621 = {"from":L[68],
"go":function(anf_arg640626) {
return $Hanf_arg940627(anf_arg640626,N116,anf_arg627546,anf_arg635599,anf_fun624547,anf_fun636613,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e616617.stack[R.EXN_STACKHEIGHT++] = $ss620621;
}
if(R.isPyretException($e616617)) {
$e616617.pyretStack.push(L[68]);
}
throw $e616617;
}
var $ret622623 = $Hanf_arg940627($z618619,N116,anf_arg627546,anf_arg635599,anf_fun624547,anf_fun636613,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret622623;
};
var $Hanf_arg940627 = function(anf_arg640626,N116,anf_arg627546,anf_arg635599,anf_fun624547,anf_fun636613,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var $z630631 = D;
var $f636637 = function(_) {
return R.isFunction(anf_fun636613)?anf_fun636613.app(anf_arg640626):R.ffi.throwNonFunApp(L[69],anf_fun636613,[anf_arg640626]);
};
try {
if(--R.GAS > 0) {
$z630631 = $f636637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f636637,
"from":L[69]});
}
} catch($e628629) {
if(R.isCont($e628629)) {
var $ss632633 = {"from":L[69],
"go":function(anf_arg641638) {
return $Hanf_arg939639(anf_arg641638,N116,anf_arg627546,anf_arg635599,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e628629.stack[R.EXN_STACKHEIGHT++] = $ss632633;
}
if(R.isPyretException($e628629)) {
$e628629.pyretStack.push(L[69]);
}
throw $e628629;
}
var $ret634635 = $Hanf_arg939639($z630631,N116,anf_arg627546,anf_arg635599,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret634635;
};
var $Hanf_arg939639 = function(anf_arg641638,N116,anf_arg627546,anf_arg635599,anf_fun624547,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var $z642643 = D;
var $f648649 = function(_) {
return R.isFunction(anf_fun624547)?anf_fun624547.app(d233112,anf_arg627546,anf_arg635599,anf_arg641638):R.ffi.throwNonFunApp(L[70],anf_fun624547,[d233112,anf_arg627546,anf_arg635599,anf_arg641638]);
};
try {
if(--R.GAS > 0) {
$z642643 = $f648649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f648649,
"from":L[70]});
}
} catch($e640641) {
if(R.isCont($e640641)) {
var $ss644645 = {"from":L[70],
"go":function(e3241650) {
return $He3938651(e3241650,N116,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
}};
$e640641.stack[R.EXN_STACKHEIGHT++] = $ss644645;
}
if(R.isPyretException($e640641)) {
$e640641.pyretStack.push(L[70]);
}
throw $e640641;
}
var $ret646647 = $He3938651($z642643,N116,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11);
++R.GAS;
return $ret646647;
};
var $He3938651 = function(e3241650,N116,d233112,f240532,list2572,split_DASH_strip22599,v239520,builtins11) {
var $z654655 = D;
var $f660661 = function(_) {
return R.isFunction(split_DASH_strip22599.$var)?split_DASH_strip22599.$var.app(e3241650):R.ffi.throwNonFunApp(L[71],split_DASH_strip22599.$var,[e3241650]);
};
try {
if(--R.GAS > 0) {
$z654655 = $f660661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f660661,
"from":L[71]});
}
} catch($e652653) {
if(R.isCont($e652653)) {
var $ss656657 = {"from":L[71],
"go":function(e3_DASH_split242662) {
return $He3_DASH_split937663(e3_DASH_split242662,N116,d233112,f240532,list2572,v239520,builtins11);
}};
$e652653.stack[R.EXN_STACKHEIGHT++] = $ss656657;
}
if(R.isPyretException($e652653)) {
$e652653.pyretStack.push(L[71]);
}
throw $e652653;
}
var $ret658659 = $He3_DASH_split937663($z654655,N116,d233112,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret658659;
};
var $He3_DASH_split937663 = function(e3_DASH_split242662,N116,d233112,f240532,list2572,v239520,builtins11) {
var anf_fun642674 = G(builtins11,"current-checker",L[72]);
var $z666667 = D;
var $f672673 = function(_) {
return R.isFunction(anf_fun642674)?anf_fun642674.app():R.ffi.throwNonFunApp(L[72],anf_fun642674,[]);
};
try {
if(--R.GAS > 0) {
$z666667 = $f672673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f672673,
"from":L[72]});
}
} catch($e664665) {
if(R.isCont($e664665)) {
var $ss668669 = {"from":L[72],
"go":function(anf_bracket643675) {
return $Hanf_bracket936676(anf_bracket643675,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e664665.stack[R.EXN_STACKHEIGHT++] = $ss668669;
}
if(R.isPyretException($e664665)) {
$e664665.pyretStack.push(L[72]);
}
throw $e664665;
}
var $ret670671 = $Hanf_bracket936676($z666667,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret670671;
};
var $Hanf_bracket936676 = function(anf_bracket643675,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var anf_fun644689 = G(anf_bracket643675,"check-is",L[72]);
var anf_bracket645691 = G(e3_DASH_split242662,"helpers",L[75]);
var anf_fun646687 = G(anf_bracket645691,"to-list",L[74]);
var $z679680 = D;
var $f685686 = function(_) {
return R.isFunction(anf_fun646687)?anf_fun646687.app():R.ffi.throwNonFunApp(L[73],anf_fun646687,[]);
};
try {
if(--R.GAS > 0) {
$z679680 = $f685686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f685686,
"from":L[73]});
}
} catch($e677678) {
if(R.isCont($e677678)) {
var $ss681682 = {"from":L[73],
"go":function(anf_bracket647688) {
return $Hanf_bracket935690(anf_bracket647688,N116,anf_fun644689,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e677678.stack[R.EXN_STACKHEIGHT++] = $ss681682;
}
if(R.isPyretException($e677678)) {
$e677678.pyretStack.push(L[73]);
}
throw $e677678;
}
var $ret683684 = $Hanf_bracket935690($z679680,N116,anf_fun644689,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret683684;
};
var $Hanf_bracket935690 = function(anf_bracket647688,N116,anf_fun644689,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var anf_fun648702 = G(anf_bracket647688,"length",L[77]);
var $z694695 = D;
var $f700701 = function(_) {
return R.isFunction(anf_fun648702)?anf_fun648702.app():R.ffi.throwNonFunApp(L[76],anf_fun648702,[]);
};
try {
if(--R.GAS > 0) {
$z694695 = $f700701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f700701,
"from":L[76]});
}
} catch($e692693) {
if(R.isCont($e692693)) {
var $ss696697 = {"from":L[76],
"go":function(anf_arg649703) {
return $Hanf_arg934704(anf_arg649703,N116,anf_fun644689,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e692693.stack[R.EXN_STACKHEIGHT++] = $ss696697;
}
if(R.isPyretException($e692693)) {
$e692693.pyretStack.push(L[76]);
}
throw $e692693;
}
var $ret698699 = $Hanf_arg934704($z694695,N116,anf_fun644689,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret698699;
};
var $Hanf_arg934704 = function(anf_arg649703,N116,anf_fun644689,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var anf_arg650715 = R.makeSrcloc(L[72]);
var $z707708 = D;
var $f713714 = function(_) {
return R.isFunction(anf_fun644689)?anf_fun644689.app(("e3-split.helpers.to-list().length() is 1"),anf_arg649703,(1),anf_arg650715):R.ffi.throwNonFunApp(L[72],anf_fun644689,[("e3-split.helpers.to-list().length() is 1"),anf_arg649703,(1),anf_arg650715]);
};
try {
if(--R.GAS > 0) {
$z707708 = $f713714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f713714,
"from":L[72]});
}
} catch($e705706) {
if(R.isCont($e705706)) {
var $ss709710 = {"from":L[72],
"go":function(anf_begin_app_dropped916716) {
return $Hanf_begin_app_dropped933717(anf_begin_app_dropped916716,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e705706.stack[R.EXN_STACKHEIGHT++] = $ss709710;
}
if(R.isPyretException($e705706)) {
$e705706.pyretStack.push(L[72]);
}
throw $e705706;
}
var $ret711712 = $Hanf_begin_app_dropped933717($z707708,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret711712;
};
var $Hanf_begin_app_dropped933717 = function(anf_begin_app_dropped916716,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var anf_fun651728 = G(builtins11,"current-checker",L[78]);
var $z720721 = D;
var $f726727 = function(_) {
return R.isFunction(anf_fun651728)?anf_fun651728.app():R.ffi.throwNonFunApp(L[78],anf_fun651728,[]);
};
try {
if(--R.GAS > 0) {
$z720721 = $f726727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f726727,
"from":L[78]});
}
} catch($e718719) {
if(R.isCont($e718719)) {
var $ss722723 = {"from":L[78],
"go":function(anf_bracket652729) {
return $Hanf_bracket932730(anf_bracket652729,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e718719.stack[R.EXN_STACKHEIGHT++] = $ss722723;
}
if(R.isPyretException($e718719)) {
$e718719.pyretStack.push(L[78]);
}
throw $e718719;
}
var $ret724725 = $Hanf_bracket932730($z720721,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret724725;
};
var $Hanf_bracket932730 = function(anf_bracket652729,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var anf_fun653743 = G(anf_bracket652729,"check-is",L[78]);
var anf_bracket654745 = G(e3_DASH_split242662,"helpers",L[81]);
var anf_fun655741 = G(anf_bracket654745,"to-list",L[80]);
var $z733734 = D;
var $f739740 = function(_) {
return R.isFunction(anf_fun655741)?anf_fun655741.app():R.ffi.throwNonFunApp(L[79],anf_fun655741,[]);
};
try {
if(--R.GAS > 0) {
$z733734 = $f739740();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f739740,
"from":L[79]});
}
} catch($e731732) {
if(R.isCont($e731732)) {
var $ss735736 = {"from":L[79],
"go":function(anf_bracket656742) {
return $Hanf_bracket931744(anf_bracket656742,N116,anf_fun653743,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e731732.stack[R.EXN_STACKHEIGHT++] = $ss735736;
}
if(R.isPyretException($e731732)) {
$e731732.pyretStack.push(L[79]);
}
throw $e731732;
}
var $ret737738 = $Hanf_bracket931744($z733734,N116,anf_fun653743,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret737738;
};
var $Hanf_bracket931744 = function(anf_bracket656742,N116,anf_fun653743,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var anf_bracket657762 = G(anf_bracket656742,"first",L[87]);
var anf_arg658758 = G(anf_bracket657762,"body",L[86]);
var anf_fun659759 = G(N116,"a-lettable",L[85]);
var anf_fun660760 = G(N116,"a-val",L[84]);
var anf_fun661756 = G(N116,"a-id",L[83]);
var $z748749 = D;
var $f754755 = function(_) {
return R.isFunction(anf_fun661756)?anf_fun661756.app(d233112,v239520):R.ffi.throwNonFunApp(L[82],anf_fun661756,[d233112,v239520]);
};
try {
if(--R.GAS > 0) {
$z748749 = $f754755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f754755,
"from":L[82]});
}
} catch($e746747) {
if(R.isCont($e746747)) {
var $ss750751 = {"from":L[82],
"go":function(anf_arg662757) {
return $Hanf_arg930761(anf_arg662757,N116,anf_arg658758,anf_fun653743,anf_fun659759,anf_fun660760,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e746747.stack[R.EXN_STACKHEIGHT++] = $ss750751;
}
if(R.isPyretException($e746747)) {
$e746747.pyretStack.push(L[82]);
}
throw $e746747;
}
var $ret752753 = $Hanf_arg930761($z748749,N116,anf_arg658758,anf_fun653743,anf_fun659759,anf_fun660760,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret752753;
};
var $Hanf_arg930761 = function(anf_arg662757,N116,anf_arg658758,anf_fun653743,anf_fun659759,anf_fun660760,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var $z765766 = D;
var $f771772 = function(_) {
return R.isFunction(anf_fun660760)?anf_fun660760.app(anf_arg662757):R.ffi.throwNonFunApp(L[88],anf_fun660760,[anf_arg662757]);
};
try {
if(--R.GAS > 0) {
$z765766 = $f771772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f771772,
"from":L[88]});
}
} catch($e763764) {
if(R.isCont($e763764)) {
var $ss767768 = {"from":L[88],
"go":function(anf_arg663773) {
return $Hanf_arg929774(anf_arg663773,N116,anf_arg658758,anf_fun653743,anf_fun659759,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e763764.stack[R.EXN_STACKHEIGHT++] = $ss767768;
}
if(R.isPyretException($e763764)) {
$e763764.pyretStack.push(L[88]);
}
throw $e763764;
}
var $ret769770 = $Hanf_arg929774($z765766,N116,anf_arg658758,anf_fun653743,anf_fun659759,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret769770;
};
var $Hanf_arg929774 = function(anf_arg663773,N116,anf_arg658758,anf_fun653743,anf_fun659759,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var $z777778 = D;
var $f783784 = function(_) {
return R.isFunction(anf_fun659759)?anf_fun659759.app(anf_arg663773):R.ffi.throwNonFunApp(L[89],anf_fun659759,[anf_arg663773]);
};
try {
if(--R.GAS > 0) {
$z777778 = $f783784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f783784,
"from":L[89]});
}
} catch($e775776) {
if(R.isCont($e775776)) {
var $ss779780 = {"from":L[89],
"go":function(anf_arg664785) {
return $Hanf_arg928786(anf_arg664785,N116,anf_arg658758,anf_fun653743,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e775776.stack[R.EXN_STACKHEIGHT++] = $ss779780;
}
if(R.isPyretException($e775776)) {
$e775776.pyretStack.push(L[89]);
}
throw $e775776;
}
var $ret781782 = $Hanf_arg928786($z777778,N116,anf_arg658758,anf_fun653743,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret781782;
};
var $Hanf_arg928786 = function(anf_arg664785,N116,anf_arg658758,anf_fun653743,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var anf_arg665797 = R.makeSrcloc(L[78]);
var $z789790 = D;
var $f795796 = function(_) {
return R.isFunction(anf_fun653743)?anf_fun653743.app(("e3-split.helpers.to-list().first.body is N.a-lettable(N.a-val(N.a-id(d, v)))"),anf_arg658758,anf_arg664785,anf_arg665797):R.ffi.throwNonFunApp(L[78],anf_fun653743,[("e3-split.helpers.to-list().first.body is N.a-lettable(N.a-val(N.a-id(d, v)))"),anf_arg658758,anf_arg664785,anf_arg665797]);
};
try {
if(--R.GAS > 0) {
$z789790 = $f795796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f795796,
"from":L[78]});
}
} catch($e787788) {
if(R.isCont($e787788)) {
var $ss791792 = {"from":L[78],
"go":function(anf_begin_app_dropped917798) {
return $Hanf_begin_app_dropped927799(anf_begin_app_dropped917798,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
}};
$e787788.stack[R.EXN_STACKHEIGHT++] = $ss791792;
}
if(R.isPyretException($e787788)) {
$e787788.pyretStack.push(L[78]);
}
throw $e787788;
}
var $ret793794 = $Hanf_begin_app_dropped927799($z789790,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11);
++R.GAS;
return $ret793794;
};
var $Hanf_begin_app_dropped927799 = function(anf_begin_app_dropped917798,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520,builtins11) {
var anf_fun666810 = G(builtins11,"current-checker",L[90]);
var $z802803 = D;
var $f808809 = function(_) {
return R.isFunction(anf_fun666810)?anf_fun666810.app():R.ffi.throwNonFunApp(L[90],anf_fun666810,[]);
};
try {
if(--R.GAS > 0) {
$z802803 = $f808809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f808809,
"from":L[90]});
}
} catch($e800801) {
if(R.isCont($e800801)) {
var $ss804805 = {"from":L[90],
"go":function(anf_bracket667811) {
return $Hanf_bracket926812(anf_bracket667811,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520);
}};
$e800801.stack[R.EXN_STACKHEIGHT++] = $ss804805;
}
if(R.isPyretException($e800801)) {
$e800801.pyretStack.push(L[90]);
}
throw $e800801;
}
var $ret806807 = $Hanf_bracket926812($z802803,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520);
++R.GAS;
return $ret806807;
};
var $Hanf_bracket926812 = function(anf_bracket667811,N116,d233112,e3_DASH_split242662,f240532,list2572,v239520) {
var anf_fun668826 = G(anf_bracket667811,"check-is",L[90]);
var anf_arg669825 = G(e3_DASH_split242662,"body",L[94]);
var anf_fun670827 = G(N116,"a-split-app",L[93]);
var anf_fun671823 = G(N116,"a-id",L[92]);
var $z815816 = D;
var $f821822 = function(_) {
return R.isFunction(anf_fun671823)?anf_fun671823.app(d233112,f240532):R.ffi.throwNonFunApp(L[91],anf_fun671823,[d233112,f240532]);
};
try {
if(--R.GAS > 0) {
$z815816 = $f821822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f821822,
"from":L[91]});
}
} catch($e813814) {
if(R.isCont($e813814)) {
var $ss817818 = {"from":L[91],
"go":function(anf_arg672824) {
return $Hanf_arg925828(anf_arg672824,N116,anf_arg669825,anf_fun668826,anf_fun670827,d233112,e3_DASH_split242662,list2572,v239520);
}};
$e813814.stack[R.EXN_STACKHEIGHT++] = $ss817818;
}
if(R.isPyretException($e813814)) {
$e813814.pyretStack.push(L[91]);
}
throw $e813814;
}
var $ret819820 = $Hanf_arg925828($z815816,N116,anf_arg669825,anf_fun668826,anf_fun670827,d233112,e3_DASH_split242662,list2572,v239520);
++R.GAS;
return $ret819820;
};
var $Hanf_arg925828 = function(anf_arg672824,N116,anf_arg669825,anf_fun668826,anf_fun670827,d233112,e3_DASH_split242662,list2572,v239520) {
var anf_fun673841 = G(list2572,"make",L[97]);
var anf_fun674839 = G(N116,"a-num",L[96]);
var $z831832 = D;
var $f837838 = function(_) {
return R.isFunction(anf_fun674839)?anf_fun674839.app(d233112,(5)):R.ffi.throwNonFunApp(L[95],anf_fun674839,[d233112,(5)]);
};
try {
if(--R.GAS > 0) {
$z831832 = $f837838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f837838,
"from":L[95]});
}
} catch($e829830) {
if(R.isCont($e829830)) {
var $ss833834 = {"from":L[95],
"go":function(anf_array_val675840) {
return $Hanf_array_val924842(anf_array_val675840,N116,anf_arg669825,anf_arg672824,anf_fun668826,anf_fun670827,anf_fun673841,d233112,e3_DASH_split242662,list2572,v239520);
}};
$e829830.stack[R.EXN_STACKHEIGHT++] = $ss833834;
}
if(R.isPyretException($e829830)) {
$e829830.pyretStack.push(L[95]);
}
throw $e829830;
}
var $ret835836 = $Hanf_array_val924842($z831832,N116,anf_arg669825,anf_arg672824,anf_fun668826,anf_fun670827,anf_fun673841,d233112,e3_DASH_split242662,list2572,v239520);
++R.GAS;
return $ret835836;
};
var $Hanf_array_val924842 = function(anf_array_val675840,N116,anf_arg669825,anf_arg672824,anf_fun668826,anf_fun670827,anf_fun673841,d233112,e3_DASH_split242662,list2572,v239520) {
var $z845846 = D;
var $f851852 = function(_) {
return R.isFunction(anf_fun673841)?anf_fun673841.app([anf_array_val675840]):R.ffi.throwNonFunApp(L[97],anf_fun673841,[[anf_array_val675840]]);
};
try {
if(--R.GAS > 0) {
$z845846 = $f851852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f851852,
"from":L[97]});
}
} catch($e843844) {
if(R.isCont($e843844)) {
var $ss847848 = {"from":L[97],
"go":function(anf_arg676853) {
return $Hanf_arg923854(anf_arg676853,N116,anf_arg669825,anf_arg672824,anf_fun668826,anf_fun670827,d233112,e3_DASH_split242662,list2572,v239520);
}};
$e843844.stack[R.EXN_STACKHEIGHT++] = $ss847848;
}
if(R.isPyretException($e843844)) {
$e843844.pyretStack.push(L[97]);
}
throw $e843844;
}
var $ret849850 = $Hanf_arg923854($z845846,N116,anf_arg669825,anf_arg672824,anf_fun668826,anf_fun670827,d233112,e3_DASH_split242662,list2572,v239520);
++R.GAS;
return $ret849850;
};
var $Hanf_arg923854 = function(anf_arg676853,N116,anf_arg669825,anf_arg672824,anf_fun668826,anf_fun670827,d233112,e3_DASH_split242662,list2572,v239520) {
var anf_bracket677868 = G(e3_DASH_split242662,"helpers",L[100]);
var anf_fun678865 = G(anf_bracket677868,"to-list",L[99]);
var $z857858 = D;
var $f863864 = function(_) {
return R.isFunction(anf_fun678865)?anf_fun678865.app():R.ffi.throwNonFunApp(L[98],anf_fun678865,[]);
};
try {
if(--R.GAS > 0) {
$z857858 = $f863864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f863864,
"from":L[98]});
}
} catch($e855856) {
if(R.isCont($e855856)) {
var $ss859860 = {"from":L[98],
"go":function(anf_bracket679866) {
return $Hanf_bracket922867(anf_bracket679866,N116,anf_arg669825,anf_arg672824,anf_arg676853,anf_fun668826,anf_fun670827,d233112,list2572,v239520);
}};
$e855856.stack[R.EXN_STACKHEIGHT++] = $ss859860;
}
if(R.isPyretException($e855856)) {
$e855856.pyretStack.push(L[98]);
}
throw $e855856;
}
var $ret861862 = $Hanf_bracket922867($z857858,N116,anf_arg669825,anf_arg672824,anf_arg676853,anf_fun668826,anf_fun670827,d233112,list2572,v239520);
++R.GAS;
return $ret861862;
};
var $Hanf_bracket922867 = function(anf_bracket679866,N116,anf_arg669825,anf_arg672824,anf_arg676853,anf_fun668826,anf_fun670827,d233112,list2572,v239520) {
var anf_bracket680884 = G(anf_bracket679866,"first",L[105]);
var anf_arg681881 = G(anf_bracket680884,"name",L[104]);
var anf_fun682882 = G(list2572,"make",L[103]);
var anf_fun683879 = G(N116,"a-id",L[102]);
var $z871872 = D;
var $f877878 = function(_) {
return R.isFunction(anf_fun683879)?anf_fun683879.app(d233112,v239520):R.ffi.throwNonFunApp(L[101],anf_fun683879,[d233112,v239520]);
};
try {
if(--R.GAS > 0) {
$z871872 = $f877878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f877878,
"from":L[101]});
}
} catch($e869870) {
if(R.isCont($e869870)) {
var $ss873874 = {"from":L[101],
"go":function(anf_array_val684880) {
return $Hanf_array_val921883(anf_array_val684880,anf_arg669825,anf_arg672824,anf_arg676853,anf_arg681881,anf_fun668826,anf_fun670827,anf_fun682882,d233112);
}};
$e869870.stack[R.EXN_STACKHEIGHT++] = $ss873874;
}
if(R.isPyretException($e869870)) {
$e869870.pyretStack.push(L[101]);
}
throw $e869870;
}
var $ret875876 = $Hanf_array_val921883($z871872,anf_arg669825,anf_arg672824,anf_arg676853,anf_arg681881,anf_fun668826,anf_fun670827,anf_fun682882,d233112);
++R.GAS;
return $ret875876;
};
var $Hanf_array_val921883 = function(anf_array_val684880,anf_arg669825,anf_arg672824,anf_arg676853,anf_arg681881,anf_fun668826,anf_fun670827,anf_fun682882,d233112) {
var $z887888 = D;
var $f893894 = function(_) {
return R.isFunction(anf_fun682882)?anf_fun682882.app([anf_array_val684880]):R.ffi.throwNonFunApp(L[103],anf_fun682882,[[anf_array_val684880]]);
};
try {
if(--R.GAS > 0) {
$z887888 = $f893894();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f893894,
"from":L[103]});
}
} catch($e885886) {
if(R.isCont($e885886)) {
var $ss889890 = {"from":L[103],
"go":function(anf_arg685895) {
return $Hanf_arg920896(anf_arg685895,anf_arg669825,anf_arg672824,anf_arg676853,anf_arg681881,anf_fun668826,anf_fun670827,d233112);
}};
$e885886.stack[R.EXN_STACKHEIGHT++] = $ss889890;
}
if(R.isPyretException($e885886)) {
$e885886.pyretStack.push(L[103]);
}
throw $e885886;
}
var $ret891892 = $Hanf_arg920896($z887888,anf_arg669825,anf_arg672824,anf_arg676853,anf_arg681881,anf_fun668826,anf_fun670827,d233112);
++R.GAS;
return $ret891892;
};
var $Hanf_arg920896 = function(anf_arg685895,anf_arg669825,anf_arg672824,anf_arg676853,anf_arg681881,anf_fun668826,anf_fun670827,d233112) {
var $z899900 = D;
var $f905906 = function(_) {
return R.isFunction(anf_fun670827)?anf_fun670827.app(d233112,(false),anf_arg672824,anf_arg676853,anf_arg681881,anf_arg685895):R.ffi.throwNonFunApp(L[106],anf_fun670827,[d233112,(false),anf_arg672824,anf_arg676853,anf_arg681881,anf_arg685895]);
};
try {
if(--R.GAS > 0) {
$z899900 = $f905906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f905906,
"from":L[106]});
}
} catch($e897898) {
if(R.isCont($e897898)) {
var $ss901902 = {"from":L[106],
"go":function(anf_arg686907) {
return $Hanf_arg919908(anf_arg686907,anf_arg669825,anf_fun668826);
}};
$e897898.stack[R.EXN_STACKHEIGHT++] = $ss901902;
}
if(R.isPyretException($e897898)) {
$e897898.pyretStack.push(L[106]);
}
throw $e897898;
}
var $ret903904 = $Hanf_arg919908($z899900,anf_arg669825,anf_fun668826);
++R.GAS;
return $ret903904;
};
var $Hanf_arg919908 = function(anf_arg686907,anf_arg669825,anf_fun668826) {
var anf_arg687919 = R.makeSrcloc(L[90]);
var $z911912 = D;
var $f917918 = function(_) {
return R.isFunction(anf_fun668826)?anf_fun668826.app(("e3-split.body is\n  N.a-split-app(d,\n    false,\n    N.a-id(d, f),\n    [list: N.a-num(d, 5)],\n    e3-split.helpers.to-list().first.name,\n    [list: N.a-id(d, v)])"),anf_arg669825,anf_arg686907,anf_arg687919):R.ffi.throwNonFunApp(L[1],anf_fun668826,[("e3-split.body is\n  N.a-split-app(d,\n    false,\n    N.a-id(d, f),\n    [list: N.a-num(d, 5)],\n    e3-split.helpers.to-list().first.name,\n    [list: N.a-id(d, v)])"),anf_arg669825,anf_arg686907,anf_arg687919]);
};
try {
if(--R.GAS > 0) {
$z911912 = $f917918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f917918,
"from":L[1]});
}
} catch($e909910) {
if(R.isCont($e909910)) {
var $ss913914 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp556920) {
return $Hann_DASH_check_DASH_temp918921(ann_DASH_check_DASH_temp556920);
}};
$e909910.stack[R.EXN_STACKHEIGHT++] = $ss913914;
}
if(R.isPyretException($e909910)) {
$e909910.pyretStack.push(L[1]);
}
throw $e909910;
}
var $ret915916 = $Hann_DASH_check_DASH_temp918921($z911912);
++R.GAS;
return $ret915916;
};
var $Hann_DASH_check_DASH_temp918921 = function(ann_DASH_check_DASH_temp556920) {
return ann_DASH_check_DASH_temp556920;
};
var $Hres911132 = function(res231131,N116,e230120,split_DASH_result_DASH_int_DASH_e10176,strip_DASH_helper22497) {
var anf_bracket568935 = G(res231131,"helpers",L[109]);
var anf_fun569932 = G(anf_bracket568935,"map",L[108]);
var $z924925 = D;
var $f930931 = function(_) {
return R.isFunction(anf_fun569932)?anf_fun569932.app(strip_DASH_helper22497.$var):R.ffi.throwNonFunApp(L[107],anf_fun569932,[strip_DASH_helper22497.$var]);
};
try {
if(--R.GAS > 0) {
$z924925 = $f930931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f930931,
"from":L[107]});
}
} catch($e922923) {
if(R.isCont($e922923)) {
var $ss926927 = {"from":L[107],
"go":function(anf_arg570933) {
return $Hanf_arg910934(anf_arg570933,N116,e230120,res231131,split_DASH_result_DASH_int_DASH_e10176);
}};
$e922923.stack[R.EXN_STACKHEIGHT++] = $ss926927;
}
if(R.isPyretException($e922923)) {
$e922923.pyretStack.push(L[107]);
}
throw $e922923;
}
var $ret928929 = $Hanf_arg910934($z924925,N116,e230120,res231131,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret928929;
};
var $Hanf_arg910934 = function(anf_arg570933,N116,e230120,res231131,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun571946 = G(N116,"strip-loc-expr",L[112]);
var anf_arg572947 = G(res231131,"body",L[111]);
var $z938939 = D;
var $f944945 = function(_) {
return R.isFunction(anf_fun571946)?anf_fun571946.app(anf_arg572947):R.ffi.throwNonFunApp(L[110],anf_fun571946,[anf_arg572947]);
};
try {
if(--R.GAS > 0) {
$z938939 = $f944945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f944945,
"from":L[110]});
}
} catch($e936937) {
if(R.isCont($e936937)) {
var $ss940941 = {"from":L[110],
"go":function(anf_arg573948) {
return $Hanf_arg909949(anf_arg573948,N116,anf_arg570933,e230120,split_DASH_result_DASH_int_DASH_e10176);
}};
$e936937.stack[R.EXN_STACKHEIGHT++] = $ss940941;
}
if(R.isPyretException($e936937)) {
$e936937.pyretStack.push(L[110]);
}
throw $e936937;
}
var $ret942943 = $Hanf_arg909949($z938939,N116,anf_arg570933,e230120,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret942943;
};
var $Hanf_arg909949 = function(anf_arg573948,N116,anf_arg570933,e230120,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun574960 = G(N116,"freevars-e",L[114]);
var $z952953 = D;
var $f958959 = function(_) {
return R.isFunction(anf_fun574960)?anf_fun574960.app(e230120):R.ffi.throwNonFunApp(L[113],anf_fun574960,[e230120]);
};
try {
if(--R.GAS > 0) {
$z952953 = $f958959();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f958959,
"from":L[113]});
}
} catch($e950951) {
if(R.isCont($e950951)) {
var $ss954955 = {"from":L[113],
"go":function(anf_arg575961) {
return $Hanf_arg908962(anf_arg575961,anf_arg570933,anf_arg573948,split_DASH_result_DASH_int_DASH_e10176);
}};
$e950951.stack[R.EXN_STACKHEIGHT++] = $ss954955;
}
if(R.isPyretException($e950951)) {
$e950951.pyretStack.push(L[113]);
}
throw $e950951;
}
var $ret956957 = $Hanf_arg908962($z952953,anf_arg570933,anf_arg573948,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret956957;
};
var $Hanf_arg908962 = function(anf_arg575961,anf_arg570933,anf_arg573948,split_DASH_result_DASH_int_DASH_e10176) {
var $z965966 = D;
var $f971972 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(anf_arg570933,anf_arg573948,anf_arg575961):R.ffi.throwNonFunApp(L[10],split_DASH_result_DASH_int_DASH_e10176.$var,[anf_arg570933,anf_arg573948,anf_arg575961]);
};
try {
if(--R.GAS > 0) {
$z965966 = $f971972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f971972,
"from":L[10]});
}
} catch($e963964) {
if(R.isCont($e963964)) {
var $ss967968 = {"from":L[10],
"go":function(ann_DASH_check_DASH_temp567973) {
return $Hann_DASH_check_DASH_temp907974(ann_DASH_check_DASH_temp567973);
}};
$e963964.stack[R.EXN_STACKHEIGHT++] = $ss967968;
}
if(R.isPyretException($e963964)) {
$e963964.pyretStack.push(L[10]);
}
throw $e963964;
}
var $ret969970 = $Hann_DASH_check_DASH_temp907974($z965966);
++R.GAS;
return $ret969970;
};
var $Hann_DASH_check_DASH_temp907974 = function(ann_DASH_check_DASH_temp567973) {
return ann_DASH_check_DASH_temp567973;
};
var $Hann_DASH_check_DASH_temp906148 = function(ann_DASH_check_DASH_temp557147) {
return ann_DASH_check_DASH_temp557147;
};
var $Hanf_arg905166 = function(anf_arg561165,args228152,helper8960,name227151) {
var $z977978 = D;
var $f983984 = function(_) {
return R.isFunction(helper8960.$var)?helper8960.$var.app(name227151,args228152,anf_arg561165):R.ffi.throwNonFunApp(L[14],helper8960.$var,[name227151,args228152,anf_arg561165]);
};
try {
if(--R.GAS > 0) {
$z977978 = $f983984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f983984,
"from":L[14]});
}
} catch($e975976) {
if(R.isCont($e975976)) {
var $ss979980 = {"from":L[14],
"go":function(ann_DASH_check_DASH_temp559985) {
return $Hann_DASH_check_DASH_temp904986(ann_DASH_check_DASH_temp559985);
}};
$e975976.stack[R.EXN_STACKHEIGHT++] = $ss979980;
}
if(R.isPyretException($e975976)) {
$e975976.pyretStack.push(L[14]);
}
throw $e975976;
}
var $ret981982 = $Hann_DASH_check_DASH_temp904986($z977978);
++R.GAS;
return $ret981982;
};
var $Hann_DASH_check_DASH_temp904986 = function(ann_DASH_check_DASH_temp559985) {
return ann_DASH_check_DASH_temp559985;
};
var $Hann_DASH_check_DASH_temp903987 = function(ann_DASH_check_DASH_temp548988) {
return ann_DASH_check_DASH_temp548988;
};
var $Hann_DASH_check_DASH_temp902989 = function(ann_DASH_check_DASH_temp494990,SplitResultInt7250,is_DASH_split_DASH_result_DASH_int_DASH_l10270) {
return ann_DASH_check_DASH_temp494990;
};
var $Hanf_arg901991 = function(anf_arg545992,concat_DASH_empty8056,e210993,split_DASH_result_DASH_int_DASH_l10377) {
var $z996997 = D;
var $f10021003 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_l10377.$var)?split_DASH_result_DASH_int_DASH_l10377.$var.app(concat_DASH_empty8056.$var,e210993,anf_arg545992):R.ffi.throwNonFunApp(L[115],split_DASH_result_DASH_int_DASH_l10377.$var,[concat_DASH_empty8056.$var,e210993,anf_arg545992]);
};
try {
if(--R.GAS > 0) {
$z996997 = $f10021003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10021003,
"from":L[115]});
}
} catch($e994995) {
if(R.isCont($e994995)) {
var $ss998999 = {"from":L[115],
"go":function(ann_DASH_check_DASH_temp5431004) {
return $Hann_DASH_check_DASH_temp9001005(ann_DASH_check_DASH_temp5431004);
}};
$e994995.stack[R.EXN_STACKHEIGHT++] = $ss998999;
}
if(R.isPyretException($e994995)) {
$e994995.pyretStack.push(L[115]);
}
throw $e994995;
}
var $ret10001001 = $Hann_DASH_check_DASH_temp9001005($z996997);
++R.GAS;
return $ret10001001;
};
var $Hann_DASH_check_DASH_temp9001005 = function(ann_DASH_check_DASH_temp5431004) {
return ann_DASH_check_DASH_temp5431004;
};
var $Hbody_DASH_split8991006 = function(body_DASH_split2201007,N116,args2171008,l2161009,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377) {
var anf_arg5201024 = G(body_DASH_split2201007,"helpers",L[119]);
var anf_fun5211021 = G(N116,"a-method",L[118]);
var anf_arg5221022 = G(body_DASH_split2201007,"body",L[117]);
var $z10131014 = D;
var $f10191020 = function(_) {
return R.isFunction(anf_fun5211021)?anf_fun5211021.app(l2161009,args2171008,ret2181010,anf_arg5221022):R.ffi.throwNonFunApp(L[116],anf_fun5211021,[l2161009,args2171008,ret2181010,anf_arg5221022]);
};
try {
if(--R.GAS > 0) {
$z10131014 = $f10191020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10191020,
"from":L[116]});
}
} catch($e10111012) {
if(R.isCont($e10111012)) {
var $ss10151016 = {"from":L[116],
"go":function(anf_arg5231023) {
return $Hanf_arg8981025(anf_arg5231023,N116,anf_arg5201024,args2171008,body_DASH_split2201007,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377);
}};
$e10111012.stack[R.EXN_STACKHEIGHT++] = $ss10151016;
}
if(R.isPyretException($e10111012)) {
$e10111012.pyretStack.push(L[116]);
}
throw $e10111012;
}
var $ret10171018 = $Hanf_arg8981025($z10131014,N116,anf_arg5201024,args2171008,body_DASH_split2201007,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret10171018;
};
var $Hanf_arg8981025 = function(anf_arg5231023,N116,anf_arg5201024,args2171008,body_DASH_split2201007,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377) {
var anf_fun5241039 = G(N116,"freevars-ann-acc",L[124]);
var anf_fun5251040 = G(N116,"freevars-list-acc",L[123]);
var anf_fun5261036 = G(args2171008,"map",L[122]);
var anf_arg5281037 = R.makeFunction(function(recv_DASH_561042) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[121],1,arguments);
}
var ann_DASH_check_DASH_temp5271043 = G(recv_DASH_561042,"ann",L[121]);
return ann_DASH_check_DASH_temp5271043;
});
var $z10281029 = D;
var $f10341035 = function(_) {
return R.isFunction(anf_fun5261036)?anf_fun5261036.app(anf_arg5281037):R.ffi.throwNonFunApp(L[120],anf_fun5261036,[anf_arg5281037]);
};
try {
if(--R.GAS > 0) {
$z10281029 = $f10341035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10341035,
"from":L[120]});
}
} catch($e10261027) {
if(R.isCont($e10261027)) {
var $ss10301031 = {"from":L[120],
"go":function(anf_arg5291038) {
return $Hanf_arg8971041(anf_arg5291038,anf_arg5201024,anf_arg5231023,anf_fun5241039,anf_fun5251040,args2171008,body_DASH_split2201007,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377);
}};
$e10261027.stack[R.EXN_STACKHEIGHT++] = $ss10301031;
}
if(R.isPyretException($e10261027)) {
$e10261027.pyretStack.push(L[120]);
}
throw $e10261027;
}
var $ret10321033 = $Hanf_arg8971041($z10281029,anf_arg5201024,anf_arg5231023,anf_fun5241039,anf_fun5251040,args2171008,body_DASH_split2201007,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret10321033;
};
var $Hanf_arg8971041 = function(anf_arg5291038,anf_arg5201024,anf_arg5231023,anf_fun5241039,anf_fun5251040,args2171008,body_DASH_split2201007,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377) {
var anf_bracket5301062 = G(body_DASH_split2201007,"freevars",L[130]);
var anf_fun5311057 = G(anf_bracket5301062,"difference",L[129]);
var anf_fun5321058 = G(sets1523,"list-to-tree-set",L[128]);
var anf_fun5331054 = G(args2171008,"map",L[127]);
var anf_arg5351055 = R.makeFunction(function(recv_DASH_571060) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[126],1,arguments);
}
var ann_DASH_check_DASH_temp5341061 = G(recv_DASH_571060,"id",L[126]);
return ann_DASH_check_DASH_temp5341061;
});
var $z10461047 = D;
var $f10521053 = function(_) {
return R.isFunction(anf_fun5331054)?anf_fun5331054.app(anf_arg5351055):R.ffi.throwNonFunApp(L[125],anf_fun5331054,[anf_arg5351055]);
};
try {
if(--R.GAS > 0) {
$z10461047 = $f10521053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10521053,
"from":L[125]});
}
} catch($e10441045) {
if(R.isCont($e10441045)) {
var $ss10481049 = {"from":L[125],
"go":function(anf_arg5361056) {
return $Hanf_arg8961059(anf_arg5361056,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,anf_fun5311057,anf_fun5321058,ret2181010,split_DASH_result_DASH_int_DASH_l10377);
}};
$e10441045.stack[R.EXN_STACKHEIGHT++] = $ss10481049;
}
if(R.isPyretException($e10441045)) {
$e10441045.pyretStack.push(L[125]);
}
throw $e10441045;
}
var $ret10501051 = $Hanf_arg8961059($z10461047,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,anf_fun5311057,anf_fun5321058,ret2181010,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret10501051;
};
var $Hanf_arg8961059 = function(anf_arg5361056,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,anf_fun5311057,anf_fun5321058,ret2181010,split_DASH_result_DASH_int_DASH_l10377) {
var $z10651066 = D;
var $f10711072 = function(_) {
return R.isFunction(anf_fun5321058)?anf_fun5321058.app(anf_arg5361056):R.ffi.throwNonFunApp(L[131],anf_fun5321058,[anf_arg5361056]);
};
try {
if(--R.GAS > 0) {
$z10651066 = $f10711072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10711072,
"from":L[131]});
}
} catch($e10631064) {
if(R.isCont($e10631064)) {
var $ss10671068 = {"from":L[131],
"go":function(anf_arg5371073) {
return $Hanf_arg8951074(anf_arg5371073,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,anf_fun5311057,ret2181010,split_DASH_result_DASH_int_DASH_l10377);
}};
$e10631064.stack[R.EXN_STACKHEIGHT++] = $ss10671068;
}
if(R.isPyretException($e10631064)) {
$e10631064.pyretStack.push(L[131]);
}
throw $e10631064;
}
var $ret10691070 = $Hanf_arg8951074($z10651066,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,anf_fun5311057,ret2181010,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret10691070;
};
var $Hanf_arg8951074 = function(anf_arg5371073,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,anf_fun5311057,ret2181010,split_DASH_result_DASH_int_DASH_l10377) {
var $z10771078 = D;
var $f10831084 = function(_) {
return R.isFunction(anf_fun5311057)?anf_fun5311057.app(anf_arg5371073):R.ffi.throwNonFunApp(L[132],anf_fun5311057,[anf_arg5371073]);
};
try {
if(--R.GAS > 0) {
$z10771078 = $f10831084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10831084,
"from":L[132]});
}
} catch($e10751076) {
if(R.isCont($e10751076)) {
var $ss10791080 = {"from":L[132],
"go":function(anf_arg5381085) {
return $Hanf_arg8941086(anf_arg5381085,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,ret2181010,split_DASH_result_DASH_int_DASH_l10377);
}};
$e10751076.stack[R.EXN_STACKHEIGHT++] = $ss10791080;
}
if(R.isPyretException($e10751076)) {
$e10751076.pyretStack.push(L[132]);
}
throw $e10751076;
}
var $ret10811082 = $Hanf_arg8941086($z10771078,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,ret2181010,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret10811082;
};
var $Hanf_arg8941086 = function(anf_arg5381085,anf_arg5201024,anf_arg5231023,anf_arg5291038,anf_fun5241039,anf_fun5251040,ret2181010,split_DASH_result_DASH_int_DASH_l10377) {
var $z10891090 = D;
var $f10951096 = function(_) {
return R.isFunction(anf_fun5251040)?anf_fun5251040.app(anf_arg5291038,anf_arg5381085):R.ffi.throwNonFunApp(L[133],anf_fun5251040,[anf_arg5291038,anf_arg5381085]);
};
try {
if(--R.GAS > 0) {
$z10891090 = $f10951096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10951096,
"from":L[133]});
}
} catch($e10871088) {
if(R.isCont($e10871088)) {
var $ss10911092 = {"from":L[133],
"go":function(anf_arg5391097) {
return $Hanf_arg8931098(anf_arg5391097,anf_arg5201024,anf_arg5231023,anf_fun5241039,ret2181010,split_DASH_result_DASH_int_DASH_l10377);
}};
$e10871088.stack[R.EXN_STACKHEIGHT++] = $ss10911092;
}
if(R.isPyretException($e10871088)) {
$e10871088.pyretStack.push(L[133]);
}
throw $e10871088;
}
var $ret10931094 = $Hanf_arg8931098($z10891090,anf_arg5201024,anf_arg5231023,anf_fun5241039,ret2181010,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret10931094;
};
var $Hanf_arg8931098 = function(anf_arg5391097,anf_arg5201024,anf_arg5231023,anf_fun5241039,ret2181010,split_DASH_result_DASH_int_DASH_l10377) {
var $z11011102 = D;
var $f11071108 = function(_) {
return R.isFunction(anf_fun5241039)?anf_fun5241039.app(ret2181010,anf_arg5391097):R.ffi.throwNonFunApp(L[134],anf_fun5241039,[ret2181010,anf_arg5391097]);
};
try {
if(--R.GAS > 0) {
$z11011102 = $f11071108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11071108,
"from":L[134]});
}
} catch($e10991100) {
if(R.isCont($e10991100)) {
var $ss11031104 = {"from":L[134],
"go":function(anf_arg5401109) {
return $Hanf_arg8921110(anf_arg5401109,anf_arg5201024,anf_arg5231023,split_DASH_result_DASH_int_DASH_l10377);
}};
$e10991100.stack[R.EXN_STACKHEIGHT++] = $ss11031104;
}
if(R.isPyretException($e10991100)) {
$e10991100.pyretStack.push(L[134]);
}
throw $e10991100;
}
var $ret11051106 = $Hanf_arg8921110($z11011102,anf_arg5201024,anf_arg5231023,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret11051106;
};
var $Hanf_arg8921110 = function(anf_arg5401109,anf_arg5201024,anf_arg5231023,split_DASH_result_DASH_int_DASH_l10377) {
var $z11131114 = D;
var $f11191120 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_l10377.$var)?split_DASH_result_DASH_int_DASH_l10377.$var.app(anf_arg5201024,anf_arg5231023,anf_arg5401109):R.ffi.throwNonFunApp(L[135],split_DASH_result_DASH_int_DASH_l10377.$var,[anf_arg5201024,anf_arg5231023,anf_arg5401109]);
};
try {
if(--R.GAS > 0) {
$z11131114 = $f11191120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11191120,
"from":L[135]});
}
} catch($e11111112) {
if(R.isCont($e11111112)) {
var $ss11151116 = {"from":L[135],
"go":function(ann_DASH_check_DASH_temp5191121) {
return $Hann_DASH_check_DASH_temp8911122(ann_DASH_check_DASH_temp5191121);
}};
$e11111112.stack[R.EXN_STACKHEIGHT++] = $ss11151116;
}
if(R.isPyretException($e11111112)) {
$e11111112.pyretStack.push(L[135]);
}
throw $e11111112;
}
var $ret11171118 = $Hann_DASH_check_DASH_temp8911122($z11131114);
++R.GAS;
return $ret11171118;
};
var $Hann_DASH_check_DASH_temp8911122 = function(ann_DASH_check_DASH_temp5191121) {
return ann_DASH_check_DASH_temp5191121;
};
var $Hbody_DASH_split8901123 = function(body_DASH_split2151124,N116,args2121125,l2111126,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377) {
var anf_arg4971141 = G(body_DASH_split2151124,"helpers",L[139]);
var anf_fun4981138 = G(N116,"a-lam",L[138]);
var anf_arg4991139 = G(body_DASH_split2151124,"body",L[137]);
var $z11301131 = D;
var $f11361137 = function(_) {
return R.isFunction(anf_fun4981138)?anf_fun4981138.app(l2111126,args2121125,ret2131127,anf_arg4991139):R.ffi.throwNonFunApp(L[136],anf_fun4981138,[l2111126,args2121125,ret2131127,anf_arg4991139]);
};
try {
if(--R.GAS > 0) {
$z11301131 = $f11361137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11361137,
"from":L[136]});
}
} catch($e11281129) {
if(R.isCont($e11281129)) {
var $ss11321133 = {"from":L[136],
"go":function(anf_arg5001140) {
return $Hanf_arg8891142(anf_arg5001140,N116,anf_arg4971141,args2121125,body_DASH_split2151124,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377);
}};
$e11281129.stack[R.EXN_STACKHEIGHT++] = $ss11321133;
}
if(R.isPyretException($e11281129)) {
$e11281129.pyretStack.push(L[136]);
}
throw $e11281129;
}
var $ret11341135 = $Hanf_arg8891142($z11301131,N116,anf_arg4971141,args2121125,body_DASH_split2151124,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret11341135;
};
var $Hanf_arg8891142 = function(anf_arg5001140,N116,anf_arg4971141,args2121125,body_DASH_split2151124,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377) {
var anf_fun5011156 = G(N116,"freevars-ann-acc",L[144]);
var anf_fun5021157 = G(N116,"freevars-list-acc",L[143]);
var anf_fun5031153 = G(args2121125,"map",L[142]);
var anf_arg5051154 = R.makeFunction(function(recv_DASH_541159) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[141],1,arguments);
}
var ann_DASH_check_DASH_temp5041160 = G(recv_DASH_541159,"ann",L[141]);
return ann_DASH_check_DASH_temp5041160;
});
var $z11451146 = D;
var $f11511152 = function(_) {
return R.isFunction(anf_fun5031153)?anf_fun5031153.app(anf_arg5051154):R.ffi.throwNonFunApp(L[140],anf_fun5031153,[anf_arg5051154]);
};
try {
if(--R.GAS > 0) {
$z11451146 = $f11511152();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11511152,
"from":L[140]});
}
} catch($e11431144) {
if(R.isCont($e11431144)) {
var $ss11471148 = {"from":L[140],
"go":function(anf_arg5061155) {
return $Hanf_arg8881158(anf_arg5061155,anf_arg4971141,anf_arg5001140,anf_fun5011156,anf_fun5021157,args2121125,body_DASH_split2151124,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377);
}};
$e11431144.stack[R.EXN_STACKHEIGHT++] = $ss11471148;
}
if(R.isPyretException($e11431144)) {
$e11431144.pyretStack.push(L[140]);
}
throw $e11431144;
}
var $ret11491150 = $Hanf_arg8881158($z11451146,anf_arg4971141,anf_arg5001140,anf_fun5011156,anf_fun5021157,args2121125,body_DASH_split2151124,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret11491150;
};
var $Hanf_arg8881158 = function(anf_arg5061155,anf_arg4971141,anf_arg5001140,anf_fun5011156,anf_fun5021157,args2121125,body_DASH_split2151124,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377) {
var anf_bracket5071179 = G(body_DASH_split2151124,"freevars",L[150]);
var anf_fun5081174 = G(anf_bracket5071179,"difference",L[149]);
var anf_fun5091175 = G(sets1523,"list-to-tree-set",L[148]);
var anf_fun5101171 = G(args2121125,"map",L[147]);
var anf_arg5121172 = R.makeFunction(function(recv_DASH_551177) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[146],1,arguments);
}
var ann_DASH_check_DASH_temp5111178 = G(recv_DASH_551177,"id",L[146]);
return ann_DASH_check_DASH_temp5111178;
});
var $z11631164 = D;
var $f11691170 = function(_) {
return R.isFunction(anf_fun5101171)?anf_fun5101171.app(anf_arg5121172):R.ffi.throwNonFunApp(L[145],anf_fun5101171,[anf_arg5121172]);
};
try {
if(--R.GAS > 0) {
$z11631164 = $f11691170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11691170,
"from":L[145]});
}
} catch($e11611162) {
if(R.isCont($e11611162)) {
var $ss11651166 = {"from":L[145],
"go":function(anf_arg5131173) {
return $Hanf_arg8871176(anf_arg5131173,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,anf_fun5081174,anf_fun5091175,ret2131127,split_DASH_result_DASH_int_DASH_l10377);
}};
$e11611162.stack[R.EXN_STACKHEIGHT++] = $ss11651166;
}
if(R.isPyretException($e11611162)) {
$e11611162.pyretStack.push(L[145]);
}
throw $e11611162;
}
var $ret11671168 = $Hanf_arg8871176($z11631164,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,anf_fun5081174,anf_fun5091175,ret2131127,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret11671168;
};
var $Hanf_arg8871176 = function(anf_arg5131173,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,anf_fun5081174,anf_fun5091175,ret2131127,split_DASH_result_DASH_int_DASH_l10377) {
var $z11821183 = D;
var $f11881189 = function(_) {
return R.isFunction(anf_fun5091175)?anf_fun5091175.app(anf_arg5131173):R.ffi.throwNonFunApp(L[151],anf_fun5091175,[anf_arg5131173]);
};
try {
if(--R.GAS > 0) {
$z11821183 = $f11881189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11881189,
"from":L[151]});
}
} catch($e11801181) {
if(R.isCont($e11801181)) {
var $ss11841185 = {"from":L[151],
"go":function(anf_arg5141190) {
return $Hanf_arg8861191(anf_arg5141190,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,anf_fun5081174,ret2131127,split_DASH_result_DASH_int_DASH_l10377);
}};
$e11801181.stack[R.EXN_STACKHEIGHT++] = $ss11841185;
}
if(R.isPyretException($e11801181)) {
$e11801181.pyretStack.push(L[151]);
}
throw $e11801181;
}
var $ret11861187 = $Hanf_arg8861191($z11821183,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,anf_fun5081174,ret2131127,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret11861187;
};
var $Hanf_arg8861191 = function(anf_arg5141190,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,anf_fun5081174,ret2131127,split_DASH_result_DASH_int_DASH_l10377) {
var $z11941195 = D;
var $f12001201 = function(_) {
return R.isFunction(anf_fun5081174)?anf_fun5081174.app(anf_arg5141190):R.ffi.throwNonFunApp(L[152],anf_fun5081174,[anf_arg5141190]);
};
try {
if(--R.GAS > 0) {
$z11941195 = $f12001201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12001201,
"from":L[152]});
}
} catch($e11921193) {
if(R.isCont($e11921193)) {
var $ss11961197 = {"from":L[152],
"go":function(anf_arg5151202) {
return $Hanf_arg8851203(anf_arg5151202,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,ret2131127,split_DASH_result_DASH_int_DASH_l10377);
}};
$e11921193.stack[R.EXN_STACKHEIGHT++] = $ss11961197;
}
if(R.isPyretException($e11921193)) {
$e11921193.pyretStack.push(L[152]);
}
throw $e11921193;
}
var $ret11981199 = $Hanf_arg8851203($z11941195,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,ret2131127,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret11981199;
};
var $Hanf_arg8851203 = function(anf_arg5151202,anf_arg4971141,anf_arg5001140,anf_arg5061155,anf_fun5011156,anf_fun5021157,ret2131127,split_DASH_result_DASH_int_DASH_l10377) {
var $z12061207 = D;
var $f12121213 = function(_) {
return R.isFunction(anf_fun5021157)?anf_fun5021157.app(anf_arg5061155,anf_arg5151202):R.ffi.throwNonFunApp(L[153],anf_fun5021157,[anf_arg5061155,anf_arg5151202]);
};
try {
if(--R.GAS > 0) {
$z12061207 = $f12121213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12121213,
"from":L[153]});
}
} catch($e12041205) {
if(R.isCont($e12041205)) {
var $ss12081209 = {"from":L[153],
"go":function(anf_arg5161214) {
return $Hanf_arg8841215(anf_arg5161214,anf_arg4971141,anf_arg5001140,anf_fun5011156,ret2131127,split_DASH_result_DASH_int_DASH_l10377);
}};
$e12041205.stack[R.EXN_STACKHEIGHT++] = $ss12081209;
}
if(R.isPyretException($e12041205)) {
$e12041205.pyretStack.push(L[153]);
}
throw $e12041205;
}
var $ret12101211 = $Hanf_arg8841215($z12061207,anf_arg4971141,anf_arg5001140,anf_fun5011156,ret2131127,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret12101211;
};
var $Hanf_arg8841215 = function(anf_arg5161214,anf_arg4971141,anf_arg5001140,anf_fun5011156,ret2131127,split_DASH_result_DASH_int_DASH_l10377) {
var $z12181219 = D;
var $f12241225 = function(_) {
return R.isFunction(anf_fun5011156)?anf_fun5011156.app(ret2131127,anf_arg5161214):R.ffi.throwNonFunApp(L[154],anf_fun5011156,[ret2131127,anf_arg5161214]);
};
try {
if(--R.GAS > 0) {
$z12181219 = $f12241225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12241225,
"from":L[154]});
}
} catch($e12161217) {
if(R.isCont($e12161217)) {
var $ss12201221 = {"from":L[154],
"go":function(anf_arg5171226) {
return $Hanf_arg8831227(anf_arg5171226,anf_arg4971141,anf_arg5001140,split_DASH_result_DASH_int_DASH_l10377);
}};
$e12161217.stack[R.EXN_STACKHEIGHT++] = $ss12201221;
}
if(R.isPyretException($e12161217)) {
$e12161217.pyretStack.push(L[154]);
}
throw $e12161217;
}
var $ret12221223 = $Hanf_arg8831227($z12181219,anf_arg4971141,anf_arg5001140,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret12221223;
};
var $Hanf_arg8831227 = function(anf_arg5171226,anf_arg4971141,anf_arg5001140,split_DASH_result_DASH_int_DASH_l10377) {
var $z12301231 = D;
var $f12361237 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_l10377.$var)?split_DASH_result_DASH_int_DASH_l10377.$var.app(anf_arg4971141,anf_arg5001140,anf_arg5171226):R.ffi.throwNonFunApp(L[155],split_DASH_result_DASH_int_DASH_l10377.$var,[anf_arg4971141,anf_arg5001140,anf_arg5171226]);
};
try {
if(--R.GAS > 0) {
$z12301231 = $f12361237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12361237,
"from":L[155]});
}
} catch($e12281229) {
if(R.isCont($e12281229)) {
var $ss12321233 = {"from":L[155],
"go":function(ann_DASH_check_DASH_temp4961238) {
return $Hann_DASH_check_DASH_temp8821239(ann_DASH_check_DASH_temp4961238);
}};
$e12281229.stack[R.EXN_STACKHEIGHT++] = $ss12321233;
}
if(R.isPyretException($e12281229)) {
$e12281229.pyretStack.push(L[155]);
}
throw $e12281229;
}
var $ret12341235 = $Hann_DASH_check_DASH_temp8821239($z12301231);
++R.GAS;
return $ret12341235;
};
var $Hann_DASH_check_DASH_temp8821239 = function(ann_DASH_check_DASH_temp4961238) {
return ann_DASH_check_DASH_temp4961238;
};
var $Hann_DASH_check_DASH_temp8811240 = function(ann_DASH_check_DASH_temp3031241,SplitResultInt7250) {
return ann_DASH_check_DASH_temp3031241;
};
var $Hanf_arg8801242 = function(anf_arg4901243,_plus10,raise13) {
var $z12461247 = D;
var $f12521253 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("NYI: "),anf_arg4901243):R.ffi.throwNonFunApp(L[156],_plus10,[("NYI: "),anf_arg4901243]);
};
try {
if(--R.GAS > 0) {
$z12461247 = $f12521253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12521253,
"from":L[156]});
}
} catch($e12441245) {
if(R.isCont($e12441245)) {
var $ss12481249 = {"from":L[156],
"go":function(anf_arg4911254) {
return $Hanf_arg8791255(anf_arg4911254,raise13);
}};
$e12441245.stack[R.EXN_STACKHEIGHT++] = $ss12481249;
}
if(R.isPyretException($e12441245)) {
$e12441245.pyretStack.push(L[156]);
}
throw $e12441245;
}
var $ret12501251 = $Hanf_arg8791255($z12461247,raise13);
++R.GAS;
return $ret12501251;
};
var $Hanf_arg8791255 = function(anf_arg4911254,raise13) {
var $z12581259 = D;
var $f12641265 = function(_) {
return R.isFunction(raise13)?raise13.app(anf_arg4911254):R.ffi.throwNonFunApp(L[157],raise13,[anf_arg4911254]);
};
try {
if(--R.GAS > 0) {
$z12581259 = $f12641265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12641265,
"from":L[157]});
}
} catch($e12561257) {
if(R.isCont($e12561257)) {
var $ss12601261 = {"from":L[157],
"go":function(ann_DASH_check_DASH_temp4891266) {
return $Hann_DASH_check_DASH_temp8781267(ann_DASH_check_DASH_temp4891266);
}};
$e12561257.stack[R.EXN_STACKHEIGHT++] = $ss12601261;
}
if(R.isPyretException($e12561257)) {
$e12561257.pyretStack.push(L[157]);
}
throw $e12561257;
}
var $ret12621263 = $Hann_DASH_check_DASH_temp8781267($z12581259);
++R.GAS;
return $ret12621263;
};
var $Hann_DASH_check_DASH_temp8781267 = function(ann_DASH_check_DASH_temp4891266) {
return ann_DASH_check_DASH_temp4891266;
};
var $Hann_DASH_check_DASH_temp8771268 = function(ann_DASH_check_DASH_temp4651269) {
return ann_DASH_check_DASH_temp4651269;
};
var $Hlet_DASH_result8761270 = function(let_DASH_result2091271,N116,split_DASH_result_DASH_int_DASH_e10176) {
var anf_arg4811285 = G(let_DASH_result2091271,"helpers",L[161]);
var anf_fun4821282 = G(N116,"a-lettable",L[160]);
var anf_arg4831283 = G(let_DASH_result2091271,"body",L[159]);
var $z12741275 = D;
var $f12801281 = function(_) {
return R.isFunction(anf_fun4821282)?anf_fun4821282.app(anf_arg4831283):R.ffi.throwNonFunApp(L[158],anf_fun4821282,[anf_arg4831283]);
};
try {
if(--R.GAS > 0) {
$z12741275 = $f12801281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12801281,
"from":L[158]});
}
} catch($e12721273) {
if(R.isCont($e12721273)) {
var $ss12761277 = {"from":L[158],
"go":function(anf_arg4841284) {
return $Hanf_arg8751286(anf_arg4841284,anf_arg4811285,let_DASH_result2091271,split_DASH_result_DASH_int_DASH_e10176);
}};
$e12721273.stack[R.EXN_STACKHEIGHT++] = $ss12761277;
}
if(R.isPyretException($e12721273)) {
$e12721273.pyretStack.push(L[158]);
}
throw $e12721273;
}
var $ret12781279 = $Hanf_arg8751286($z12741275,anf_arg4811285,let_DASH_result2091271,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret12781279;
};
var $Hanf_arg8751286 = function(anf_arg4841284,anf_arg4811285,let_DASH_result2091271,split_DASH_result_DASH_int_DASH_e10176) {
var anf_arg4851297 = G(let_DASH_result2091271,"freevars",L[163]);
var $z12891290 = D;
var $f12951296 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(anf_arg4811285,anf_arg4841284,anf_arg4851297):R.ffi.throwNonFunApp(L[162],split_DASH_result_DASH_int_DASH_e10176.$var,[anf_arg4811285,anf_arg4841284,anf_arg4851297]);
};
try {
if(--R.GAS > 0) {
$z12891290 = $f12951296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12951296,
"from":L[162]});
}
} catch($e12871288) {
if(R.isCont($e12871288)) {
var $ss12911292 = {"from":L[162],
"go":function(ann_DASH_check_DASH_temp4801298) {
return $Hann_DASH_check_DASH_temp8741299(ann_DASH_check_DASH_temp4801298);
}};
$e12871288.stack[R.EXN_STACKHEIGHT++] = $ss12911292;
}
if(R.isPyretException($e12871288)) {
$e12871288.pyretStack.push(L[162]);
}
throw $e12871288;
}
var $ret12931294 = $Hann_DASH_check_DASH_temp8741299($z12891290);
++R.GAS;
return $ret12931294;
};
var $Hann_DASH_check_DASH_temp8741299 = function(ann_DASH_check_DASH_temp4801298) {
return ann_DASH_check_DASH_temp4801298;
};
var $Hanf_arg8731300 = function(anf_arg4691301,N116,args2081302,concat_DASH_empty8056,f2071303,split_DASH_result_DASH_int_DASH_e10176,unions10479) {
var anf_fun4701314 = G(N116,"freevars-v",L[165]);
var $z13061307 = D;
var $f13121313 = function(_) {
return R.isFunction(anf_fun4701314)?anf_fun4701314.app(f2071303):R.ffi.throwNonFunApp(L[164],anf_fun4701314,[f2071303]);
};
try {
if(--R.GAS > 0) {
$z13061307 = $f13121313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13121313,
"from":L[164]});
}
} catch($e13041305) {
if(R.isCont($e13041305)) {
var $ss13081309 = {"from":L[164],
"go":function(anf_bracket4711315) {
return $Hanf_bracket8721316(anf_bracket4711315,N116,anf_arg4691301,args2081302,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176,unions10479);
}};
$e13041305.stack[R.EXN_STACKHEIGHT++] = $ss13081309;
}
if(R.isPyretException($e13041305)) {
$e13041305.pyretStack.push(L[164]);
}
throw $e13041305;
}
var $ret13101311 = $Hanf_bracket8721316($z13061307,N116,anf_arg4691301,args2081302,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176,unions10479);
++R.GAS;
return $ret13101311;
};
var $Hanf_bracket8721316 = function(anf_bracket4711315,N116,anf_arg4691301,args2081302,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176,unions10479) {
var anf_fun4721330 = G(anf_bracket4711315,"union",L[169]);
var anf_fun4731327 = G(args2081302,"map",L[168]);
var anf_arg4741328 = G(N116,"freevars-v",L[167]);
var $z13191320 = D;
var $f13251326 = function(_) {
return R.isFunction(anf_fun4731327)?anf_fun4731327.app(anf_arg4741328):R.ffi.throwNonFunApp(L[166],anf_fun4731327,[anf_arg4741328]);
};
try {
if(--R.GAS > 0) {
$z13191320 = $f13251326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13251326,
"from":L[166]});
}
} catch($e13171318) {
if(R.isCont($e13171318)) {
var $ss13211322 = {"from":L[166],
"go":function(anf_arg4751329) {
return $Hanf_arg8711331(anf_arg4751329,anf_arg4691301,anf_fun4721330,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176,unions10479);
}};
$e13171318.stack[R.EXN_STACKHEIGHT++] = $ss13211322;
}
if(R.isPyretException($e13171318)) {
$e13171318.pyretStack.push(L[166]);
}
throw $e13171318;
}
var $ret13231324 = $Hanf_arg8711331($z13191320,anf_arg4691301,anf_fun4721330,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176,unions10479);
++R.GAS;
return $ret13231324;
};
var $Hanf_arg8711331 = function(anf_arg4751329,anf_arg4691301,anf_fun4721330,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176,unions10479) {
var $z13341335 = D;
var $f13401341 = function(_) {
return R.isFunction(unions10479.$var)?unions10479.$var.app(anf_arg4751329):R.ffi.throwNonFunApp(L[170],unions10479.$var,[anf_arg4751329]);
};
try {
if(--R.GAS > 0) {
$z13341335 = $f13401341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13401341,
"from":L[170]});
}
} catch($e13321333) {
if(R.isCont($e13321333)) {
var $ss13361337 = {"from":L[170],
"go":function(anf_arg4761342) {
return $Hanf_arg8701343(anf_arg4761342,anf_arg4691301,anf_fun4721330,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176);
}};
$e13321333.stack[R.EXN_STACKHEIGHT++] = $ss13361337;
}
if(R.isPyretException($e13321333)) {
$e13321333.pyretStack.push(L[170]);
}
throw $e13321333;
}
var $ret13381339 = $Hanf_arg8701343($z13341335,anf_arg4691301,anf_fun4721330,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret13381339;
};
var $Hanf_arg8701343 = function(anf_arg4761342,anf_arg4691301,anf_fun4721330,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176) {
var $z13461347 = D;
var $f13521353 = function(_) {
return R.isFunction(anf_fun4721330)?anf_fun4721330.app(anf_arg4761342):R.ffi.throwNonFunApp(L[171],anf_fun4721330,[anf_arg4761342]);
};
try {
if(--R.GAS > 0) {
$z13461347 = $f13521353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13521353,
"from":L[171]});
}
} catch($e13441345) {
if(R.isCont($e13441345)) {
var $ss13481349 = {"from":L[171],
"go":function(anf_arg4771354) {
return $Hanf_arg8691355(anf_arg4771354,anf_arg4691301,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176);
}};
$e13441345.stack[R.EXN_STACKHEIGHT++] = $ss13481349;
}
if(R.isPyretException($e13441345)) {
$e13441345.pyretStack.push(L[171]);
}
throw $e13441345;
}
var $ret13501351 = $Hanf_arg8691355($z13461347,anf_arg4691301,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret13501351;
};
var $Hanf_arg8691355 = function(anf_arg4771354,anf_arg4691301,concat_DASH_empty8056,split_DASH_result_DASH_int_DASH_e10176) {
var $z13581359 = D;
var $f13641365 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(concat_DASH_empty8056.$var,anf_arg4691301,anf_arg4771354):R.ffi.throwNonFunApp(L[172],split_DASH_result_DASH_int_DASH_e10176.$var,[concat_DASH_empty8056.$var,anf_arg4691301,anf_arg4771354]);
};
try {
if(--R.GAS > 0) {
$z13581359 = $f13641365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13641365,
"from":L[172]});
}
} catch($e13561357) {
if(R.isCont($e13561357)) {
var $ss13601361 = {"from":L[172],
"go":function(ann_DASH_check_DASH_temp4671366) {
return $Hann_DASH_check_DASH_temp8681367(ann_DASH_check_DASH_temp4671366);
}};
$e13561357.stack[R.EXN_STACKHEIGHT++] = $ss13601361;
}
if(R.isPyretException($e13561357)) {
$e13561357.pyretStack.push(L[172]);
}
throw $e13561357;
}
var $ret13621363 = $Hann_DASH_check_DASH_temp8681367($z13581359);
++R.GAS;
return $ret13621363;
};
var $Hann_DASH_check_DASH_temp8681367 = function(ann_DASH_check_DASH_temp4671366) {
return ann_DASH_check_DASH_temp4671366;
};
var $Hbody_DASH_split8671368 = function(body_DASH_split1971369,N116,bind1951370,l1941371,split_DASH_result_DASH_int_DASH_e10176) {
var cases_DASH_val511425 = bind1951370;
var anf_fun4441382 = G(cases_DASH_val511425,"_match",L[174]);
var anf_obj4501388 = R.makeFunction(function(l21991408,name2001409,nameb2011410) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[180],3,arguments);
}
var anf_bracket4461424 = G(body_DASH_split1971369,"freevars",L[183]);
var anf_fun4471421 = G(anf_bracket4461424,"remove",L[182]);
var $z14131414 = D;
var $f14191420 = function(_) {
return R.isFunction(anf_fun4471421)?anf_fun4471421.app(name2001409):R.ffi.throwNonFunApp(L[181],anf_fun4471421,[name2001409]);
};
try {
if(--R.GAS > 0) {
$z14131414 = $f14191420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14191420,
"from":L[181]});
}
} catch($e14111412) {
if(R.isCont($e14111412)) {
var $ss14151416 = {"from":L[181],
"go":function(anf_bracket4481422) {
return $Hanf_bracket8611423(anf_bracket4481422,nameb2011410);
}};
$e14111412.stack[R.EXN_STACKHEIGHT++] = $ss14151416;
}
if(R.isPyretException($e14111412)) {
$e14111412.pyretStack.push(L[181]);
}
throw $e14111412;
}
var $ret14171418 = $Hanf_bracket8611423($z14131414,nameb2011410);
++R.GAS;
return $ret14171418;
});
var anf_obj4561389 = R.makeFunction(function(l22021390,name2031391,ann2041392) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[175],3,arguments);
}
var anf_fun4521405 = G(N116,"freevars-ann-acc",L[179]);
var anf_bracket4531407 = G(body_DASH_split1971369,"freevars",L[178]);
var anf_fun4541403 = G(anf_bracket4531407,"remove",L[177]);
var $z13951396 = D;
var $f14011402 = function(_) {
return R.isFunction(anf_fun4541403)?anf_fun4541403.app(name2031391):R.ffi.throwNonFunApp(L[176],anf_fun4541403,[name2031391]);
};
try {
if(--R.GAS > 0) {
$z13951396 = $f14011402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14011402,
"from":L[176]});
}
} catch($e13931394) {
if(R.isCont($e13931394)) {
var $ss13971398 = {"from":L[176],
"go":function(anf_arg4551404) {
return $Hanf_arg8631406(anf_arg4551404,anf_fun4521405,ann2041392);
}};
$e13931394.stack[R.EXN_STACKHEIGHT++] = $ss13971398;
}
if(R.isPyretException($e13931394)) {
$e13931394.pyretStack.push(L[176]);
}
throw $e13931394;
}
var $ret13991400 = $Hanf_arg8631406($z13951396,anf_fun4521405,ann2041392);
++R.GAS;
return $ret13991400;
});
var anf_arg4571383 = R.makeObject({"a-newtype-bind":anf_obj4501388,
"a-type-bind":anf_obj4561389});
var anf_arg4591384 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[174],0,arguments);
}
var ann_DASH_check_DASH_temp4581387 = R.throwNoBranchesMatched(L[174],("cases"));
return ann_DASH_check_DASH_temp4581387;
});
var $z13741375 = D;
var $f13801381 = function(_) {
return R.isFunction(anf_fun4441382)?anf_fun4441382.app(anf_arg4571383,anf_arg4591384):R.ffi.throwNonFunApp(L[173],anf_fun4441382,[anf_arg4571383,anf_arg4591384]);
};
try {
if(--R.GAS > 0) {
$z13741375 = $f13801381();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13801381,
"from":L[173]});
}
} catch($e13721373) {
if(R.isCont($e13721373)) {
var $ss13761377 = {"from":L[173],
"go":function(freevars1981385) {
return $Hfreevars8661386(freevars1981385,N116,bind1951370,body_DASH_split1971369,l1941371,split_DASH_result_DASH_int_DASH_e10176);
}};
$e13721373.stack[R.EXN_STACKHEIGHT++] = $ss13761377;
}
if(R.isPyretException($e13721373)) {
$e13721373.pyretStack.push(L[173]);
}
throw $e13721373;
}
var $ret13781379 = $Hfreevars8661386($z13741375,N116,bind1951370,body_DASH_split1971369,l1941371,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret13781379;
};
var $Hfreevars8661386 = function(freevars1981385,N116,bind1951370,body_DASH_split1971369,l1941371,split_DASH_result_DASH_int_DASH_e10176) {
var anf_arg4601439 = G(body_DASH_split1971369,"helpers",L[187]);
var anf_fun4611436 = G(N116,"a-type-let",L[186]);
var anf_arg4621437 = G(body_DASH_split1971369,"body",L[185]);
var $z14281429 = D;
var $f14341435 = function(_) {
return R.isFunction(anf_fun4611436)?anf_fun4611436.app(l1941371,bind1951370,anf_arg4621437):R.ffi.throwNonFunApp(L[184],anf_fun4611436,[l1941371,bind1951370,anf_arg4621437]);
};
try {
if(--R.GAS > 0) {
$z14281429 = $f14341435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14341435,
"from":L[184]});
}
} catch($e14261427) {
if(R.isCont($e14261427)) {
var $ss14301431 = {"from":L[184],
"go":function(anf_arg4631438) {
return $Hanf_arg8651440(anf_arg4631438,anf_arg4601439,freevars1981385,split_DASH_result_DASH_int_DASH_e10176);
}};
$e14261427.stack[R.EXN_STACKHEIGHT++] = $ss14301431;
}
if(R.isPyretException($e14261427)) {
$e14261427.pyretStack.push(L[184]);
}
throw $e14261427;
}
var $ret14321433 = $Hanf_arg8651440($z14281429,anf_arg4601439,freevars1981385,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret14321433;
};
var $Hanf_arg8651440 = function(anf_arg4631438,anf_arg4601439,freevars1981385,split_DASH_result_DASH_int_DASH_e10176) {
var $z14431444 = D;
var $f14491450 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(anf_arg4601439,anf_arg4631438,freevars1981385):R.ffi.throwNonFunApp(L[188],split_DASH_result_DASH_int_DASH_e10176.$var,[anf_arg4601439,anf_arg4631438,freevars1981385]);
};
try {
if(--R.GAS > 0) {
$z14431444 = $f14491450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14491450,
"from":L[188]});
}
} catch($e14411442) {
if(R.isCont($e14411442)) {
var $ss14451446 = {"from":L[188],
"go":function(ann_DASH_check_DASH_temp4431451) {
return $Hann_DASH_check_DASH_temp8641452(ann_DASH_check_DASH_temp4431451);
}};
$e14411442.stack[R.EXN_STACKHEIGHT++] = $ss14451446;
}
if(R.isPyretException($e14411442)) {
$e14411442.pyretStack.push(L[188]);
}
throw $e14411442;
}
var $ret14471448 = $Hann_DASH_check_DASH_temp8641452($z14431444);
++R.GAS;
return $ret14471448;
};
var $Hann_DASH_check_DASH_temp8641452 = function(ann_DASH_check_DASH_temp4431451) {
return ann_DASH_check_DASH_temp4431451;
};
var $Hanf_arg8631406 = function(anf_arg4551404,anf_fun4521405,ann2041392) {
var $z14551456 = D;
var $f14611462 = function(_) {
return R.isFunction(anf_fun4521405)?anf_fun4521405.app(ann2041392,anf_arg4551404):R.ffi.throwNonFunApp(L[175],anf_fun4521405,[ann2041392,anf_arg4551404]);
};
try {
if(--R.GAS > 0) {
$z14551456 = $f14611462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14611462,
"from":L[175]});
}
} catch($e14531454) {
if(R.isCont($e14531454)) {
var $ss14571458 = {"from":L[175],
"go":function(ann_DASH_check_DASH_temp4511463) {
return $Hann_DASH_check_DASH_temp8621464(ann_DASH_check_DASH_temp4511463);
}};
$e14531454.stack[R.EXN_STACKHEIGHT++] = $ss14571458;
}
if(R.isPyretException($e14531454)) {
$e14531454.pyretStack.push(L[175]);
}
throw $e14531454;
}
var $ret14591460 = $Hann_DASH_check_DASH_temp8621464($z14551456);
++R.GAS;
return $ret14591460;
};
var $Hann_DASH_check_DASH_temp8621464 = function(ann_DASH_check_DASH_temp4511463) {
return ann_DASH_check_DASH_temp4511463;
};
var $Hanf_bracket8611423 = function(anf_bracket4481422,nameb2011410) {
var anf_fun4491475 = G(anf_bracket4481422,"remove",L[189]);
var $z14671468 = D;
var $f14731474 = function(_) {
return R.isFunction(anf_fun4491475)?anf_fun4491475.app(nameb2011410):R.ffi.throwNonFunApp(L[180],anf_fun4491475,[nameb2011410]);
};
try {
if(--R.GAS > 0) {
$z14671468 = $f14731474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14731474,
"from":L[180]});
}
} catch($e14651466) {
if(R.isCont($e14651466)) {
var $ss14691470 = {"from":L[180],
"go":function(ann_DASH_check_DASH_temp4451476) {
return $Hann_DASH_check_DASH_temp8601477(ann_DASH_check_DASH_temp4451476);
}};
$e14651466.stack[R.EXN_STACKHEIGHT++] = $ss14691470;
}
if(R.isPyretException($e14651466)) {
$e14651466.pyretStack.push(L[180]);
}
throw $e14651466;
}
var $ret14711472 = $Hann_DASH_check_DASH_temp8601477($z14671468);
++R.GAS;
return $ret14711472;
};
var $Hann_DASH_check_DASH_temp8601477 = function(ann_DASH_check_DASH_temp4451476) {
return ann_DASH_check_DASH_temp4451476;
};
var $Hconsq_DASH_split8591478 = function(consq_DASH_split1921479,N116,alt1911480,ast_DASH_split_DASH_expr10652,cond1891481,l1881482,split_DASH_result_DASH_int_DASH_e10176,_plus10) {
var $z14851486 = D;
var $f14911492 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(alt1911480):R.ffi.throwNonFunApp(L[190],ast_DASH_split_DASH_expr10652.$var,[alt1911480]);
};
try {
if(--R.GAS > 0) {
$z14851486 = $f14911492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14911492,
"from":L[190]});
}
} catch($e14831484) {
if(R.isCont($e14831484)) {
var $ss14871488 = {"from":L[190],
"go":function(alt_DASH_split1931493) {
return $Halt_DASH_split8581494(alt_DASH_split1931493,N116,cond1891481,consq_DASH_split1921479,l1881482,split_DASH_result_DASH_int_DASH_e10176,_plus10);
}};
$e14831484.stack[R.EXN_STACKHEIGHT++] = $ss14871488;
}
if(R.isPyretException($e14831484)) {
$e14831484.pyretStack.push(L[190]);
}
throw $e14831484;
}
var $ret14891490 = $Halt_DASH_split8581494($z14851486,N116,cond1891481,consq_DASH_split1921479,l1881482,split_DASH_result_DASH_int_DASH_e10176,_plus10);
++R.GAS;
return $ret14891490;
};
var $Halt_DASH_split8581494 = function(alt_DASH_split1931493,N116,cond1891481,consq_DASH_split1921479,l1881482,split_DASH_result_DASH_int_DASH_e10176,_plus10) {
var anf_arg4271505 = G(consq_DASH_split1921479,"helpers",L[193]);
var anf_arg4281506 = G(alt_DASH_split1931493,"helpers",L[192]);
var $z14971498 = D;
var $f15031504 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg4271505,anf_arg4281506):R.ffi.throwNonFunApp(L[191],_plus10,[anf_arg4271505,anf_arg4281506]);
};
try {
if(--R.GAS > 0) {
$z14971498 = $f15031504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15031504,
"from":L[191]});
}
} catch($e14951496) {
if(R.isCont($e14951496)) {
var $ss14991500 = {"from":L[191],
"go":function(anf_arg4291507) {
return $Hanf_arg8571508(anf_arg4291507,N116,alt_DASH_split1931493,cond1891481,consq_DASH_split1921479,l1881482,split_DASH_result_DASH_int_DASH_e10176);
}};
$e14951496.stack[R.EXN_STACKHEIGHT++] = $ss14991500;
}
if(R.isPyretException($e14951496)) {
$e14951496.pyretStack.push(L[191]);
}
throw $e14951496;
}
var $ret15011502 = $Hanf_arg8571508($z14971498,N116,alt_DASH_split1931493,cond1891481,consq_DASH_split1921479,l1881482,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret15011502;
};
var $Hanf_arg8571508 = function(anf_arg4291507,N116,alt_DASH_split1931493,cond1891481,consq_DASH_split1921479,l1881482,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun4301519 = G(N116,"a-if",L[197]);
var anf_arg4311520 = G(consq_DASH_split1921479,"body",L[196]);
var anf_arg4321521 = G(alt_DASH_split1931493,"body",L[195]);
var $z15111512 = D;
var $f15171518 = function(_) {
return R.isFunction(anf_fun4301519)?anf_fun4301519.app(l1881482,cond1891481,anf_arg4311520,anf_arg4321521):R.ffi.throwNonFunApp(L[194],anf_fun4301519,[l1881482,cond1891481,anf_arg4311520,anf_arg4321521]);
};
try {
if(--R.GAS > 0) {
$z15111512 = $f15171518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15171518,
"from":L[194]});
}
} catch($e15091510) {
if(R.isCont($e15091510)) {
var $ss15131514 = {"from":L[194],
"go":function(anf_arg4331522) {
return $Hanf_arg8561523(anf_arg4331522,N116,alt_DASH_split1931493,anf_arg4291507,cond1891481,consq_DASH_split1921479,split_DASH_result_DASH_int_DASH_e10176);
}};
$e15091510.stack[R.EXN_STACKHEIGHT++] = $ss15131514;
}
if(R.isPyretException($e15091510)) {
$e15091510.pyretStack.push(L[194]);
}
throw $e15091510;
}
var $ret15151516 = $Hanf_arg8561523($z15111512,N116,alt_DASH_split1931493,anf_arg4291507,cond1891481,consq_DASH_split1921479,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret15151516;
};
var $Hanf_arg8561523 = function(anf_arg4331522,N116,alt_DASH_split1931493,anf_arg4291507,cond1891481,consq_DASH_split1921479,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun4341534 = G(N116,"freevars-v",L[199]);
var $z15261527 = D;
var $f15321533 = function(_) {
return R.isFunction(anf_fun4341534)?anf_fun4341534.app(cond1891481):R.ffi.throwNonFunApp(L[198],anf_fun4341534,[cond1891481]);
};
try {
if(--R.GAS > 0) {
$z15261527 = $f15321533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15321533,
"from":L[198]});
}
} catch($e15241525) {
if(R.isCont($e15241525)) {
var $ss15281529 = {"from":L[198],
"go":function(anf_bracket4351535) {
return $Hanf_bracket8551536(anf_bracket4351535,alt_DASH_split1931493,anf_arg4291507,anf_arg4331522,consq_DASH_split1921479,split_DASH_result_DASH_int_DASH_e10176);
}};
$e15241525.stack[R.EXN_STACKHEIGHT++] = $ss15281529;
}
if(R.isPyretException($e15241525)) {
$e15241525.pyretStack.push(L[198]);
}
throw $e15241525;
}
var $ret15301531 = $Hanf_bracket8551536($z15261527,alt_DASH_split1931493,anf_arg4291507,anf_arg4331522,consq_DASH_split1921479,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret15301531;
};
var $Hanf_bracket8551536 = function(anf_bracket4351535,alt_DASH_split1931493,anf_arg4291507,anf_arg4331522,consq_DASH_split1921479,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun4361547 = G(anf_bracket4351535,"union",L[202]);
var anf_arg4371548 = G(consq_DASH_split1921479,"freevars",L[201]);
var $z15391540 = D;
var $f15451546 = function(_) {
return R.isFunction(anf_fun4361547)?anf_fun4361547.app(anf_arg4371548):R.ffi.throwNonFunApp(L[200],anf_fun4361547,[anf_arg4371548]);
};
try {
if(--R.GAS > 0) {
$z15391540 = $f15451546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15451546,
"from":L[200]});
}
} catch($e15371538) {
if(R.isCont($e15371538)) {
var $ss15411542 = {"from":L[200],
"go":function(anf_bracket4381549) {
return $Hanf_bracket8541550(anf_bracket4381549,alt_DASH_split1931493,anf_arg4291507,anf_arg4331522,split_DASH_result_DASH_int_DASH_e10176);
}};
$e15371538.stack[R.EXN_STACKHEIGHT++] = $ss15411542;
}
if(R.isPyretException($e15371538)) {
$e15371538.pyretStack.push(L[200]);
}
throw $e15371538;
}
var $ret15431544 = $Hanf_bracket8541550($z15391540,alt_DASH_split1931493,anf_arg4291507,anf_arg4331522,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret15431544;
};
var $Hanf_bracket8541550 = function(anf_bracket4381549,alt_DASH_split1931493,anf_arg4291507,anf_arg4331522,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun4391561 = G(anf_bracket4381549,"union",L[205]);
var anf_arg4401562 = G(alt_DASH_split1931493,"freevars",L[204]);
var $z15531554 = D;
var $f15591560 = function(_) {
return R.isFunction(anf_fun4391561)?anf_fun4391561.app(anf_arg4401562):R.ffi.throwNonFunApp(L[203],anf_fun4391561,[anf_arg4401562]);
};
try {
if(--R.GAS > 0) {
$z15531554 = $f15591560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15591560,
"from":L[203]});
}
} catch($e15511552) {
if(R.isCont($e15511552)) {
var $ss15551556 = {"from":L[203],
"go":function(anf_arg4411563) {
return $Hanf_arg8531564(anf_arg4411563,anf_arg4291507,anf_arg4331522,split_DASH_result_DASH_int_DASH_e10176);
}};
$e15511552.stack[R.EXN_STACKHEIGHT++] = $ss15551556;
}
if(R.isPyretException($e15511552)) {
$e15511552.pyretStack.push(L[203]);
}
throw $e15511552;
}
var $ret15571558 = $Hanf_arg8531564($z15531554,anf_arg4291507,anf_arg4331522,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret15571558;
};
var $Hanf_arg8531564 = function(anf_arg4411563,anf_arg4291507,anf_arg4331522,split_DASH_result_DASH_int_DASH_e10176) {
var $z15671568 = D;
var $f15731574 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(anf_arg4291507,anf_arg4331522,anf_arg4411563):R.ffi.throwNonFunApp(L[206],split_DASH_result_DASH_int_DASH_e10176.$var,[anf_arg4291507,anf_arg4331522,anf_arg4411563]);
};
try {
if(--R.GAS > 0) {
$z15671568 = $f15731574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15731574,
"from":L[206]});
}
} catch($e15651566) {
if(R.isCont($e15651566)) {
var $ss15691570 = {"from":L[206],
"go":function(ann_DASH_check_DASH_temp4261575) {
return $Hann_DASH_check_DASH_temp8521576(ann_DASH_check_DASH_temp4261575);
}};
$e15651566.stack[R.EXN_STACKHEIGHT++] = $ss15691570;
}
if(R.isPyretException($e15651566)) {
$e15651566.pyretStack.push(L[206]);
}
throw $e15651566;
}
var $ret15711572 = $Hann_DASH_check_DASH_temp8521576($z15671568);
++R.GAS;
return $ret15711572;
};
var $Hann_DASH_check_DASH_temp8521576 = function(ann_DASH_check_DASH_temp4261575) {
return ann_DASH_check_DASH_temp4261575;
};
var $Hann_DASH_check_DASH_temp8511577 = function(ann_DASH_check_DASH_temp4061578) {
return ann_DASH_check_DASH_temp4061578;
};
var $Hn8501579 = function(n1871580,A317,N116,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584) {
var anf_fun4131598 = G(N116,"a-let",L[210]);
var anf_fun4141595 = G(N116,"a-bind",L[209]);
var anf_arg4151596 = G(A317,"a-blank",L[208]);
var $z15871588 = D;
var $f15931594 = function(_) {
return R.isFunction(anf_fun4141595)?anf_fun4141595.app(l1821584,n1871580,anf_arg4151596):R.ffi.throwNonFunApp(L[207],anf_fun4141595,[l1821584,n1871580,anf_arg4151596]);
};
try {
if(--R.GAS > 0) {
$z15871588 = $f15931594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15931594,
"from":L[207]});
}
} catch($e15851586) {
if(R.isCont($e15851586)) {
var $ss15891590 = {"from":L[207],
"go":function(anf_arg4161597) {
return $Hanf_arg8491599(anf_arg4161597,N116,anf_fun4131598,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584,n1871580);
}};
$e15851586.stack[R.EXN_STACKHEIGHT++] = $ss15891590;
}
if(R.isPyretException($e15851586)) {
$e15851586.pyretStack.push(L[207]);
}
throw $e15851586;
}
var $ret15911592 = $Hanf_arg8491599($z15871588,N116,anf_fun4131598,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584,n1871580);
++R.GAS;
return $ret15911592;
};
var $Hanf_arg8491599 = function(anf_arg4161597,N116,anf_fun4131598,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584,n1871580) {
var anf_fun4171612 = G(N116,"a-var",L[214]);
var anf_fun4181613 = G(N116,"a-val",L[213]);
var anf_fun4191610 = G(N116,"a-id",L[212]);
var $z16021603 = D;
var $f16081609 = function(_) {
return R.isFunction(anf_fun4191610)?anf_fun4191610.app(l1821584,n1871580):R.ffi.throwNonFunApp(L[211],anf_fun4191610,[l1821584,n1871580]);
};
try {
if(--R.GAS > 0) {
$z16021603 = $f16081609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16081609,
"from":L[211]});
}
} catch($e16001601) {
if(R.isCont($e16001601)) {
var $ss16041605 = {"from":L[211],
"go":function(anf_arg4201611) {
return $Hanf_arg8481614(anf_arg4201611,anf_arg4161597,anf_fun4131598,anf_fun4171612,anf_fun4181613,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584);
}};
$e16001601.stack[R.EXN_STACKHEIGHT++] = $ss16041605;
}
if(R.isPyretException($e16001601)) {
$e16001601.pyretStack.push(L[211]);
}
throw $e16001601;
}
var $ret16061607 = $Hanf_arg8481614($z16021603,anf_arg4161597,anf_fun4131598,anf_fun4171612,anf_fun4181613,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584);
++R.GAS;
return $ret16061607;
};
var $Hanf_arg8481614 = function(anf_arg4201611,anf_arg4161597,anf_fun4131598,anf_fun4171612,anf_fun4181613,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584) {
var $z16171618 = D;
var $f16231624 = function(_) {
return R.isFunction(anf_fun4181613)?anf_fun4181613.app(anf_arg4201611):R.ffi.throwNonFunApp(L[215],anf_fun4181613,[anf_arg4201611]);
};
try {
if(--R.GAS > 0) {
$z16171618 = $f16231624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16231624,
"from":L[215]});
}
} catch($e16151616) {
if(R.isCont($e16151616)) {
var $ss16191620 = {"from":L[215],
"go":function(anf_arg4211625) {
return $Hanf_arg8471626(anf_arg4211625,anf_arg4161597,anf_fun4131598,anf_fun4171612,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584);
}};
$e16151616.stack[R.EXN_STACKHEIGHT++] = $ss16191620;
}
if(R.isPyretException($e16151616)) {
$e16151616.pyretStack.push(L[215]);
}
throw $e16151616;
}
var $ret16211622 = $Hanf_arg8471626($z16171618,anf_arg4161597,anf_fun4131598,anf_fun4171612,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584);
++R.GAS;
return $ret16211622;
};
var $Hanf_arg8471626 = function(anf_arg4211625,anf_arg4161597,anf_fun4131598,anf_fun4171612,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584) {
var $z16291630 = D;
var $f16351636 = function(_) {
return R.isFunction(anf_fun4171612)?anf_fun4171612.app(l1821584,b1831581,anf_arg4211625,body1851582):R.ffi.throwNonFunApp(L[216],anf_fun4171612,[l1821584,b1831581,anf_arg4211625,body1851582]);
};
try {
if(--R.GAS > 0) {
$z16291630 = $f16351636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16351636,
"from":L[216]});
}
} catch($e16271628) {
if(R.isCont($e16271628)) {
var $ss16311632 = {"from":L[216],
"go":function(anf_arg4221637) {
return $Hanf_arg8461638(anf_arg4221637,anf_arg4161597,anf_fun4131598,ast_DASH_split_DASH_expr10652,e1841583,l1821584);
}};
$e16271628.stack[R.EXN_STACKHEIGHT++] = $ss16311632;
}
if(R.isPyretException($e16271628)) {
$e16271628.pyretStack.push(L[216]);
}
throw $e16271628;
}
var $ret16331634 = $Hanf_arg8461638($z16291630,anf_arg4161597,anf_fun4131598,ast_DASH_split_DASH_expr10652,e1841583,l1821584);
++R.GAS;
return $ret16331634;
};
var $Hanf_arg8461638 = function(anf_arg4221637,anf_arg4161597,anf_fun4131598,ast_DASH_split_DASH_expr10652,e1841583,l1821584) {
var $z16411642 = D;
var $f16471648 = function(_) {
return R.isFunction(anf_fun4131598)?anf_fun4131598.app(l1821584,anf_arg4161597,e1841583,anf_arg4221637):R.ffi.throwNonFunApp(L[217],anf_fun4131598,[l1821584,anf_arg4161597,e1841583,anf_arg4221637]);
};
try {
if(--R.GAS > 0) {
$z16411642 = $f16471648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16471648,
"from":L[217]});
}
} catch($e16391640) {
if(R.isCont($e16391640)) {
var $ss16431644 = {"from":L[217],
"go":function(anf_arg4231649) {
return $Hanf_arg8451650(anf_arg4231649,ast_DASH_split_DASH_expr10652);
}};
$e16391640.stack[R.EXN_STACKHEIGHT++] = $ss16431644;
}
if(R.isPyretException($e16391640)) {
$e16391640.pyretStack.push(L[217]);
}
throw $e16391640;
}
var $ret16451646 = $Hanf_arg8451650($z16411642,ast_DASH_split_DASH_expr10652);
++R.GAS;
return $ret16451646;
};
var $Hanf_arg8451650 = function(anf_arg4231649,ast_DASH_split_DASH_expr10652) {
var $z16531654 = D;
var $f16591660 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(anf_arg4231649):R.ffi.throwNonFunApp(L[218],ast_DASH_split_DASH_expr10652.$var,[anf_arg4231649]);
};
try {
if(--R.GAS > 0) {
$z16531654 = $f16591660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16591660,
"from":L[218]});
}
} catch($e16511652) {
if(R.isCont($e16511652)) {
var $ss16551656 = {"from":L[218],
"go":function(ann_DASH_check_DASH_temp4111661) {
return $Hann_DASH_check_DASH_temp8441662(ann_DASH_check_DASH_temp4111661);
}};
$e16511652.stack[R.EXN_STACKHEIGHT++] = $ss16551656;
}
if(R.isPyretException($e16511652)) {
$e16511652.pyretStack.push(L[218]);
}
throw $e16511652;
}
var $ret16571658 = $Hann_DASH_check_DASH_temp8441662($z16531654);
++R.GAS;
return $ret16571658;
};
var $Hann_DASH_check_DASH_temp8441662 = function(ann_DASH_check_DASH_temp4111661) {
return ann_DASH_check_DASH_temp4111661;
};
var $Hann_DASH_check_DASH_temp8431663 = function(ann_DASH_check_DASH_temp4081664) {
return ann_DASH_check_DASH_temp4081664;
};
var $Hann_DASH_check_DASH_temp8421665 = function(ann_DASH_check_DASH_temp3811666) {
return ann_DASH_check_DASH_temp3811666;
};
var $He1_DASH_split8411667 = function(e1_DASH_split1801668,N116,ast_DASH_split_DASH_expr10652,e21761669,l1741670,split_DASH_result_DASH_int_DASH_e10176,_plus10) {
var $z16731674 = D;
var $f16791680 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(e21761669):R.ffi.throwNonFunApp(L[219],ast_DASH_split_DASH_expr10652.$var,[e21761669]);
};
try {
if(--R.GAS > 0) {
$z16731674 = $f16791680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16791680,
"from":L[219]});
}
} catch($e16711672) {
if(R.isCont($e16711672)) {
var $ss16751676 = {"from":L[219],
"go":function(e2_DASH_split1811681) {
return $He2_DASH_split8401682(e2_DASH_split1811681,N116,e1_DASH_split1801668,l1741670,split_DASH_result_DASH_int_DASH_e10176,_plus10);
}};
$e16711672.stack[R.EXN_STACKHEIGHT++] = $ss16751676;
}
if(R.isPyretException($e16711672)) {
$e16711672.pyretStack.push(L[219]);
}
throw $e16711672;
}
var $ret16771678 = $He2_DASH_split8401682($z16731674,N116,e1_DASH_split1801668,l1741670,split_DASH_result_DASH_int_DASH_e10176,_plus10);
++R.GAS;
return $ret16771678;
};
var $He2_DASH_split8401682 = function(e2_DASH_split1811681,N116,e1_DASH_split1801668,l1741670,split_DASH_result_DASH_int_DASH_e10176,_plus10) {
var anf_arg3931693 = G(e2_DASH_split1811681,"helpers",L[222]);
var anf_arg3941694 = G(e1_DASH_split1801668,"helpers",L[221]);
var $z16851686 = D;
var $f16911692 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg3931693,anf_arg3941694):R.ffi.throwNonFunApp(L[220],_plus10,[anf_arg3931693,anf_arg3941694]);
};
try {
if(--R.GAS > 0) {
$z16851686 = $f16911692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16911692,
"from":L[220]});
}
} catch($e16831684) {
if(R.isCont($e16831684)) {
var $ss16871688 = {"from":L[220],
"go":function(anf_arg3951695) {
return $Hanf_arg8391696(anf_arg3951695,N116,e1_DASH_split1801668,e2_DASH_split1811681,l1741670,split_DASH_result_DASH_int_DASH_e10176);
}};
$e16831684.stack[R.EXN_STACKHEIGHT++] = $ss16871688;
}
if(R.isPyretException($e16831684)) {
$e16831684.pyretStack.push(L[220]);
}
throw $e16831684;
}
var $ret16891690 = $Hanf_arg8391696($z16851686,N116,e1_DASH_split1801668,e2_DASH_split1811681,l1741670,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret16891690;
};
var $Hanf_arg8391696 = function(anf_arg3951695,N116,e1_DASH_split1801668,e2_DASH_split1811681,l1741670,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun3961707 = G(N116,"a-seq",L[226]);
var anf_arg3971708 = G(e1_DASH_split1801668,"body",L[225]);
var anf_arg3981709 = G(e2_DASH_split1811681,"body",L[224]);
var $z16991700 = D;
var $f17051706 = function(_) {
return R.isFunction(anf_fun3961707)?anf_fun3961707.app(l1741670,anf_arg3971708,anf_arg3981709):R.ffi.throwNonFunApp(L[223],anf_fun3961707,[l1741670,anf_arg3971708,anf_arg3981709]);
};
try {
if(--R.GAS > 0) {
$z16991700 = $f17051706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17051706,
"from":L[223]});
}
} catch($e16971698) {
if(R.isCont($e16971698)) {
var $ss17011702 = {"from":L[223],
"go":function(anf_arg3991710) {
return $Hanf_arg8381711(anf_arg3991710,anf_arg3951695,e1_DASH_split1801668,e2_DASH_split1811681,split_DASH_result_DASH_int_DASH_e10176);
}};
$e16971698.stack[R.EXN_STACKHEIGHT++] = $ss17011702;
}
if(R.isPyretException($e16971698)) {
$e16971698.pyretStack.push(L[223]);
}
throw $e16971698;
}
var $ret17031704 = $Hanf_arg8381711($z16991700,anf_arg3951695,e1_DASH_split1801668,e2_DASH_split1811681,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret17031704;
};
var $Hanf_arg8381711 = function(anf_arg3991710,anf_arg3951695,e1_DASH_split1801668,e2_DASH_split1811681,split_DASH_result_DASH_int_DASH_e10176) {
var anf_bracket4001726 = G(e2_DASH_split1811681,"freevars",L[230]);
var anf_fun4011722 = G(anf_bracket4001726,"union",L[229]);
var anf_arg4021723 = G(e1_DASH_split1801668,"freevars",L[228]);
var $z17141715 = D;
var $f17201721 = function(_) {
return R.isFunction(anf_fun4011722)?anf_fun4011722.app(anf_arg4021723):R.ffi.throwNonFunApp(L[227],anf_fun4011722,[anf_arg4021723]);
};
try {
if(--R.GAS > 0) {
$z17141715 = $f17201721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17201721,
"from":L[227]});
}
} catch($e17121713) {
if(R.isCont($e17121713)) {
var $ss17161717 = {"from":L[227],
"go":function(anf_arg4031724) {
return $Hanf_arg8371725(anf_arg4031724,anf_arg3951695,anf_arg3991710,split_DASH_result_DASH_int_DASH_e10176);
}};
$e17121713.stack[R.EXN_STACKHEIGHT++] = $ss17161717;
}
if(R.isPyretException($e17121713)) {
$e17121713.pyretStack.push(L[227]);
}
throw $e17121713;
}
var $ret17181719 = $Hanf_arg8371725($z17141715,anf_arg3951695,anf_arg3991710,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret17181719;
};
var $Hanf_arg8371725 = function(anf_arg4031724,anf_arg3951695,anf_arg3991710,split_DASH_result_DASH_int_DASH_e10176) {
var $z17291730 = D;
var $f17351736 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(anf_arg3951695,anf_arg3991710,anf_arg4031724):R.ffi.throwNonFunApp(L[231],split_DASH_result_DASH_int_DASH_e10176.$var,[anf_arg3951695,anf_arg3991710,anf_arg4031724]);
};
try {
if(--R.GAS > 0) {
$z17291730 = $f17351736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17351736,
"from":L[231]});
}
} catch($e17271728) {
if(R.isCont($e17271728)) {
var $ss17311732 = {"from":L[231],
"go":function(ann_DASH_check_DASH_temp3921737) {
return $Hann_DASH_check_DASH_temp8361738(ann_DASH_check_DASH_temp3921737);
}};
$e17271728.stack[R.EXN_STACKHEIGHT++] = $ss17311732;
}
if(R.isPyretException($e17271728)) {
$e17271728.pyretStack.push(L[231]);
}
throw $e17271728;
}
var $ret17331734 = $Hann_DASH_check_DASH_temp8361738($z17291730);
++R.GAS;
return $ret17331734;
};
var $Hann_DASH_check_DASH_temp8361738 = function(ann_DASH_check_DASH_temp3921737) {
return ann_DASH_check_DASH_temp3921737;
};
var $Hanf_arg8351739 = function(anf_arg3871740,A317,anf_fun3841741,e11751742,e21761669,handle_DASH_bind1561743,l1741670,l21771744) {
var anf_arg3881755 = G(A317,"a-blank",L[233]);
var $z17471748 = D;
var $f17531754 = function(_) {
return R.isFunction(anf_fun3841741)?anf_fun3841741.app(l21771744,anf_arg3871740,anf_arg3881755):R.ffi.throwNonFunApp(L[232],anf_fun3841741,[l21771744,anf_arg3871740,anf_arg3881755]);
};
try {
if(--R.GAS > 0) {
$z17471748 = $f17531754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17531754,
"from":L[232]});
}
} catch($e17451746) {
if(R.isCont($e17451746)) {
var $ss17491750 = {"from":L[232],
"go":function(anf_arg3891756) {
return $Hanf_arg8341757(anf_arg3891756,e11751742,e21761669,handle_DASH_bind1561743,l1741670);
}};
$e17451746.stack[R.EXN_STACKHEIGHT++] = $ss17491750;
}
if(R.isPyretException($e17451746)) {
$e17451746.pyretStack.push(L[232]);
}
throw $e17451746;
}
var $ret17511752 = $Hanf_arg8341757($z17471748,e11751742,e21761669,handle_DASH_bind1561743,l1741670);
++R.GAS;
return $ret17511752;
};
var $Hanf_arg8341757 = function(anf_arg3891756,e11751742,e21761669,handle_DASH_bind1561743,l1741670) {
var $z17601761 = D;
var $f17661767 = function(_) {
return R.isFunction(handle_DASH_bind1561743.$var)?handle_DASH_bind1561743.$var.app(l1741670,(false),anf_arg3891756,e11751742,e21761669):R.ffi.throwNonFunApp(L[234],handle_DASH_bind1561743.$var,[l1741670,(false),anf_arg3891756,e11751742,e21761669]);
};
try {
if(--R.GAS > 0) {
$z17601761 = $f17661767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17661767,
"from":L[234]});
}
} catch($e17581759) {
if(R.isCont($e17581759)) {
var $ss17621763 = {"from":L[234],
"go":function(ann_DASH_check_DASH_temp3831768) {
return $Hann_DASH_check_DASH_temp8331769(ann_DASH_check_DASH_temp3831768);
}};
$e17581759.stack[R.EXN_STACKHEIGHT++] = $ss17621763;
}
if(R.isPyretException($e17581759)) {
$e17581759.pyretStack.push(L[234]);
}
throw $e17581759;
}
var $ret17641765 = $Hann_DASH_check_DASH_temp8331769($z17601761);
++R.GAS;
return $ret17641765;
};
var $Hann_DASH_check_DASH_temp8331769 = function(ann_DASH_check_DASH_temp3831768) {
return ann_DASH_check_DASH_temp3831768;
};
var $Hann_DASH_check_DASH_temp8321770 = function(ann_DASH_check_DASH_temp3791771) {
return ann_DASH_check_DASH_temp3791771;
};
var $Hann_DASH_check_DASH_temp8311772 = function(ann_DASH_check_DASH_temp3041773) {
return ann_DASH_check_DASH_temp3041773;
};
var $He_DASH_split8301774 = function(e_DASH_split1681775,N116,ast_DASH_split_DASH_expr10652,b1591776,body1611777,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,_plus10) {
var $z17821783 = D;
var $f17881789 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(body1611777):R.ffi.throwNonFunApp(L[235],ast_DASH_split_DASH_expr10652.$var,[body1611777]);
};
try {
if(--R.GAS > 0) {
$z17821783 = $f17881789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17881789,
"from":L[235]});
}
} catch($e17801781) {
if(R.isCont($e17801781)) {
var $ss17841785 = {"from":L[235],
"go":function(rest_DASH_split1691790) {
return $Hrest_DASH_split8291791(rest_DASH_split1691790,N116,b1591776,e_DASH_split1681775,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,_plus10);
}};
$e17801781.stack[R.EXN_STACKHEIGHT++] = $ss17841785;
}
if(R.isPyretException($e17801781)) {
$e17801781.pyretStack.push(L[235]);
}
throw $e17801781;
}
var $ret17861787 = $Hrest_DASH_split8291791($z17821783,N116,b1591776,e_DASH_split1681775,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,_plus10);
++R.GAS;
return $ret17861787;
};
var $Hrest_DASH_split8291791 = function(rest_DASH_split1691790,N116,b1591776,e_DASH_split1681775,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,_plus10) {
var anf_arg3481802 = G(rest_DASH_split1691790,"helpers",L[238]);
var anf_arg3491803 = G(e_DASH_split1681775,"helpers",L[237]);
var $z17941795 = D;
var $f18001801 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg3481802,anf_arg3491803):R.ffi.throwNonFunApp(L[236],_plus10,[anf_arg3481802,anf_arg3491803]);
};
try {
if(--R.GAS > 0) {
$z17941795 = $f18001801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18001801,
"from":L[236]});
}
} catch($e17921793) {
if(R.isCont($e17921793)) {
var $ss17961797 = {"from":L[236],
"go":function(anf_arg3501804) {
return $Hanf_arg8281805(anf_arg3501804,N116,b1591776,e_DASH_split1681775,is_DASH_var1581778,l1571779,rest_DASH_split1691790,split_DASH_result_DASH_int_DASH_e10176);
}};
$e17921793.stack[R.EXN_STACKHEIGHT++] = $ss17961797;
}
if(R.isPyretException($e17921793)) {
$e17921793.pyretStack.push(L[236]);
}
throw $e17921793;
}
var $ret17981799 = $Hanf_arg8281805($z17941795,N116,b1591776,e_DASH_split1681775,is_DASH_var1581778,l1571779,rest_DASH_split1691790,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret17981799;
};
var $Hanf_arg8281805 = function(anf_arg3501804,N116,b1591776,e_DASH_split1681775,is_DASH_var1581778,l1571779,rest_DASH_split1691790,split_DASH_result_DASH_int_DASH_e10176) {
var if_DASH_471837 = is_DASH_var1581778;
var if_helper3511820 = R.makeFunction(function(if_helper_arg3521843) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[247],1,arguments);
}
var anf_fun3531858 = G(N116,"freevars-ann-acc",L[253]);
var anf_arg3541857 = G(b1591776,"ann",L[252]);
var anf_bracket3551860 = G(rest_DASH_split1691790,"freevars",L[251]);
var anf_fun3561854 = G(anf_bracket3551860,"remove",L[250]);
var anf_arg3571855 = G(b1591776,"id",L[249]);
var $z18461847 = D;
var $f18521853 = function(_) {
return R.isFunction(anf_fun3561854)?anf_fun3561854.app(anf_arg3571855):R.ffi.throwNonFunApp(L[248],anf_fun3561854,[anf_arg3571855]);
};
try {
if(--R.GAS > 0) {
$z18461847 = $f18521853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18521853,
"from":L[248]});
}
} catch($e18441845) {
if(R.isCont($e18441845)) {
var $ss18481849 = {"from":L[248],
"go":function(anf_bracket3581856) {
return $Hanf_bracket8251859(anf_bracket3581856,anf_arg3501804,anf_arg3541857,anf_fun3531858,e_DASH_split1681775,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176);
}};
$e18441845.stack[R.EXN_STACKHEIGHT++] = $ss18481849;
}
if(R.isPyretException($e18441845)) {
$e18441845.pyretStack.push(L[248]);
}
throw $e18441845;
}
var $ret18501851 = $Hanf_bracket8251859($z18461847,anf_arg3501804,anf_arg3541857,anf_fun3531858,e_DASH_split1681775,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret18501851;
});
var anf_if3651842 = R.isBoolean(if_DASH_471837);
if(R.isPyretTrue(anf_if3651842)) {
if(R.isPyretTrue(if_DASH_471837)) {
var anf_fun3711816 = G(N116,"a-var",L[242]);
var anf_arg3721817 = G(e_DASH_split1681775,"body",L[241]);
var anf_arg3731818 = G(rest_DASH_split1691790,"body",L[240]);
var $z18081809 = D;
var $f18141815 = function(_) {
return R.isFunction(anf_fun3711816)?anf_fun3711816.app(l1571779,b1591776,anf_arg3721817,anf_arg3731818):R.ffi.throwNonFunApp(L[239],anf_fun3711816,[l1571779,b1591776,anf_arg3721817,anf_arg3731818]);
};
try {
if(--R.GAS > 0) {
$z18081809 = $f18141815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18141815,
"from":L[239]});
}
} catch($e18061807) {
if(R.isCont($e18061807)) {
var $ss18101811 = {"from":L[239],
"go":function(cont_tail_arg3741819) {
return $Hcont_tail_arg8261821(cont_tail_arg3741819,if_helper3511820);
}};
$e18061807.stack[R.EXN_STACKHEIGHT++] = $ss18101811;
}
if(R.isPyretException($e18061807)) {
$e18061807.pyretStack.push(L[239]);
}
throw $e18061807;
}
var $ret18121813 = $Hcont_tail_arg8261821($z18081809,if_helper3511820);
++R.GAS;
return $ret18121813;
} else {
var anf_fun3661832 = G(N116,"a-let",L[246]);
var anf_arg3671833 = G(e_DASH_split1681775,"body",L[245]);
var anf_arg3681834 = G(rest_DASH_split1691790,"body",L[244]);
var $z18241825 = D;
var $f18301831 = function(_) {
return R.isFunction(anf_fun3661832)?anf_fun3661832.app(l1571779,b1591776,anf_arg3671833,anf_arg3681834):R.ffi.throwNonFunApp(L[243],anf_fun3661832,[l1571779,b1591776,anf_arg3671833,anf_arg3681834]);
};
try {
if(--R.GAS > 0) {
$z18241825 = $f18301831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18301831,
"from":L[243]});
}
} catch($e18221823) {
if(R.isCont($e18221823)) {
var $ss18261827 = {"from":L[243],
"go":function(cont_tail_arg3691835) {
return $Hcont_tail_arg8271836(cont_tail_arg3691835,if_helper3511820);
}};
$e18221823.stack[R.EXN_STACKHEIGHT++] = $ss18261827;
}
if(R.isPyretException($e18221823)) {
$e18221823.pyretStack.push(L[243]);
}
throw $e18221823;
}
var $ret18281829 = $Hcont_tail_arg8271836($z18241825,if_helper3511820);
++R.GAS;
return $ret18281829;
}
} else {
var cont_tail_arg3631840 = R.throwNonBooleanCondition(L[247],("if"),if_DASH_471837);
if(--R.GAS > 0) {
$z18381839 = R.isFunction(if_helper3511820)?if_helper3511820.app(cont_tail_arg3631840):R.ffi.throwNonFunApp(L[247],if_helper3511820,[cont_tail_arg3631840]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper3511820)?if_helper3511820.app(cont_tail_arg3631840):R.ffi.throwNonFunApp(L[247],if_helper3511820,[cont_tail_arg3631840]);
},
"from":L[247]});
}
++R.GAS;
return $z18381839;
}
};
var $Hcont_tail_arg8261821 = function(cont_tail_arg3741819,if_helper3511820) {
if(--R.GAS > 0) {
$z18611862 = R.isFunction(if_helper3511820)?if_helper3511820.app(cont_tail_arg3741819):R.ffi.throwNonFunApp(L[239],if_helper3511820,[cont_tail_arg3741819]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper3511820)?if_helper3511820.app(cont_tail_arg3741819):R.ffi.throwNonFunApp(L[239],if_helper3511820,[cont_tail_arg3741819]);
},
"from":L[239]});
}
++R.GAS;
return $z18611862;
};
var $Hcont_tail_arg8271836 = function(cont_tail_arg3691835,if_helper3511820) {
if(--R.GAS > 0) {
$z18631864 = R.isFunction(if_helper3511820)?if_helper3511820.app(cont_tail_arg3691835):R.ffi.throwNonFunApp(L[243],if_helper3511820,[cont_tail_arg3691835]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper3511820)?if_helper3511820.app(cont_tail_arg3691835):R.ffi.throwNonFunApp(L[243],if_helper3511820,[cont_tail_arg3691835]);
},
"from":L[243]});
}
++R.GAS;
return $z18631864;
};
var $Hanf_bracket8251859 = function(anf_bracket3581856,anf_arg3501804,anf_arg3541857,anf_fun3531858,e_DASH_split1681775,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun3591875 = G(anf_bracket3581856,"union",L[256]);
var anf_arg3601876 = G(e_DASH_split1681775,"freevars",L[255]);
var $z18671868 = D;
var $f18731874 = function(_) {
return R.isFunction(anf_fun3591875)?anf_fun3591875.app(anf_arg3601876):R.ffi.throwNonFunApp(L[254],anf_fun3591875,[anf_arg3601876]);
};
try {
if(--R.GAS > 0) {
$z18671868 = $f18731874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18731874,
"from":L[254]});
}
} catch($e18651866) {
if(R.isCont($e18651866)) {
var $ss18691870 = {"from":L[254],
"go":function(anf_arg3611877) {
return $Hanf_arg8241878(anf_arg3611877,anf_arg3501804,anf_arg3541857,anf_fun3531858,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176);
}};
$e18651866.stack[R.EXN_STACKHEIGHT++] = $ss18691870;
}
if(R.isPyretException($e18651866)) {
$e18651866.pyretStack.push(L[254]);
}
throw $e18651866;
}
var $ret18711872 = $Hanf_arg8241878($z18671868,anf_arg3501804,anf_arg3541857,anf_fun3531858,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret18711872;
};
var $Hanf_arg8241878 = function(anf_arg3611877,anf_arg3501804,anf_arg3541857,anf_fun3531858,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176) {
var $z18811882 = D;
var $f18871888 = function(_) {
return R.isFunction(anf_fun3531858)?anf_fun3531858.app(anf_arg3541857,anf_arg3611877):R.ffi.throwNonFunApp(L[257],anf_fun3531858,[anf_arg3541857,anf_arg3611877]);
};
try {
if(--R.GAS > 0) {
$z18811882 = $f18871888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18871888,
"from":L[257]});
}
} catch($e18791880) {
if(R.isCont($e18791880)) {
var $ss18831884 = {"from":L[257],
"go":function(anf_arg3621889) {
return $Hanf_arg8231890(anf_arg3621889,anf_arg3501804,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176);
}};
$e18791880.stack[R.EXN_STACKHEIGHT++] = $ss18831884;
}
if(R.isPyretException($e18791880)) {
$e18791880.pyretStack.push(L[257]);
}
throw $e18791880;
}
var $ret18851886 = $Hanf_arg8231890($z18811882,anf_arg3501804,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret18851886;
};
var $Hanf_arg8231890 = function(anf_arg3621889,anf_arg3501804,if_helper_arg3521843,split_DASH_result_DASH_int_DASH_e10176) {
var $z18931894 = D;
var $f18991900 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(anf_arg3501804,if_helper_arg3521843,anf_arg3621889):R.ffi.throwNonFunApp(L[258],split_DASH_result_DASH_int_DASH_e10176.$var,[anf_arg3501804,if_helper_arg3521843,anf_arg3621889]);
};
try {
if(--R.GAS > 0) {
$z18931894 = $f18991900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18991900,
"from":L[258]});
}
} catch($e18911892) {
if(R.isCont($e18911892)) {
var $ss18951896 = {"from":L[258],
"go":function(ann_DASH_check_DASH_temp3471901) {
return $Hann_DASH_check_DASH_temp8221902(ann_DASH_check_DASH_temp3471901);
}};
$e18911892.stack[R.EXN_STACKHEIGHT++] = $ss18951896;
}
if(R.isPyretException($e18911892)) {
$e18911892.pyretStack.push(L[258]);
}
throw $e18911892;
}
var $ret18971898 = $Hann_DASH_check_DASH_temp8221902($z18931894);
++R.GAS;
return $ret18971898;
};
var $Hann_DASH_check_DASH_temp8221902 = function(ann_DASH_check_DASH_temp3471901) {
return ann_DASH_check_DASH_temp3471901;
};
var $Hrest_DASH_split8211903 = function(rest_DASH_split1651904,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var anf_fun3071922 = G(N116,"freevars-ann-acc",L[264]);
var anf_arg3081921 = G(b1591776,"ann",L[263]);
var anf_bracket3091924 = G(rest_DASH_split1651904,"freevars",L[262]);
var anf_fun3101918 = G(anf_bracket3091924,"remove",L[261]);
var anf_arg3111919 = G(b1591776,"id",L[260]);
var $z19101911 = D;
var $f19161917 = function(_) {
return R.isFunction(anf_fun3101918)?anf_fun3101918.app(anf_arg3111919):R.ffi.throwNonFunApp(L[259],anf_fun3101918,[anf_arg3111919]);
};
try {
if(--R.GAS > 0) {
$z19101911 = $f19161917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19161917,
"from":L[259]});
}
} catch($e19081909) {
if(R.isCont($e19081909)) {
var $ss19121913 = {"from":L[259],
"go":function(anf_arg3121920) {
return $Hanf_arg8201923(anf_arg3121920,N116,anf_arg3081921,anf_fun3071922,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e19081909.stack[R.EXN_STACKHEIGHT++] = $ss19121913;
}
if(R.isPyretException($e19081909)) {
$e19081909.pyretStack.push(L[259]);
}
throw $e19081909;
}
var $ret19141915 = $Hanf_arg8201923($z19101911,N116,anf_arg3081921,anf_fun3071922,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret19141915;
};
var $Hanf_arg8201923 = function(anf_arg3121920,N116,anf_arg3081921,anf_fun3071922,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var $z19271928 = D;
var $f19331934 = function(_) {
return R.isFunction(anf_fun3071922)?anf_fun3071922.app(anf_arg3081921,anf_arg3121920):R.ffi.throwNonFunApp(L[265],anf_fun3071922,[anf_arg3081921,anf_arg3121920]);
};
try {
if(--R.GAS > 0) {
$z19271928 = $f19331934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19331934,
"from":L[265]});
}
} catch($e19251926) {
if(R.isCont($e19251926)) {
var $ss19291930 = {"from":L[265],
"go":function(fvs1661935) {
return $Hfvs8191936(fvs1661935,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e19251926.stack[R.EXN_STACKHEIGHT++] = $ss19291930;
}
if(R.isPyretException($e19251926)) {
$e19251926.pyretStack.push(L[265]);
}
throw $e19251926;
}
var $ret19311932 = $Hfvs8191936($z19271928,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret19311932;
};
var $Hfvs8191936 = function(fvs1661935,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var anf_fun3131949 = G(names7473,"make-atom",L[269]);
var anf_bracket3141951 = G(b1591776,"id",L[268]);
var anf_fun3151947 = G(anf_bracket3141951,"toname",L[267]);
var $z19391940 = D;
var $f19451946 = function(_) {
return R.isFunction(anf_fun3151947)?anf_fun3151947.app():R.ffi.throwNonFunApp(L[266],anf_fun3151947,[]);
};
try {
if(--R.GAS > 0) {
$z19391940 = $f19451946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19451946,
"from":L[266]});
}
} catch($e19371938) {
if(R.isCont($e19371938)) {
var $ss19411942 = {"from":L[266],
"go":function(anf_arg3161948) {
return $Hanf_arg8181950(anf_arg3161948,N116,anf_fun3131949,args1641905,b1591776,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e19371938.stack[R.EXN_STACKHEIGHT++] = $ss19411942;
}
if(R.isPyretException($e19371938)) {
$e19371938.pyretStack.push(L[266]);
}
throw $e19371938;
}
var $ret19431944 = $Hanf_arg8181950($z19391940,N116,anf_fun3131949,args1641905,b1591776,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret19431944;
};
var $Hanf_arg8181950 = function(anf_arg3161948,N116,anf_fun3131949,args1641905,b1591776,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var $z19541955 = D;
var $f19601961 = function(_) {
return R.isFunction(anf_fun3131949)?anf_fun3131949.app(anf_arg3161948):R.ffi.throwNonFunApp(L[270],anf_fun3131949,[anf_arg3161948]);
};
try {
if(--R.GAS > 0) {
$z19541955 = $f19601961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19601961,
"from":L[270]});
}
} catch($e19521953) {
if(R.isCont($e19521953)) {
var $ss19561957 = {"from":L[270],
"go":function(anf_arg3171962) {
return $Hanf_arg8171963(anf_arg3171962,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e19521953.stack[R.EXN_STACKHEIGHT++] = $ss19561957;
}
if(R.isPyretException($e19521953)) {
$e19521953.pyretStack.push(L[270]);
}
throw $e19521953;
}
var $ret19581959 = $Hanf_arg8171963($z19541955,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret19581959;
};
var $Hanf_arg8171963 = function(anf_arg3171962,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var anf_arg3181976 = G(b1591776,"id",L[273]);
var anf_fun3191974 = G(fvs1661935,"to-list",L[272]);
var $z19661967 = D;
var $f19721973 = function(_) {
return R.isFunction(anf_fun3191974)?anf_fun3191974.app():R.ffi.throwNonFunApp(L[271],anf_fun3191974,[]);
};
try {
if(--R.GAS > 0) {
$z19661967 = $f19721973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19721973,
"from":L[271]});
}
} catch($e19641965) {
if(R.isCont($e19641965)) {
var $ss19681969 = {"from":L[271],
"go":function(anf_arg3201975) {
return $Hanf_arg8161977(anf_arg3201975,N116,anf_arg3171962,anf_arg3181976,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e19641965.stack[R.EXN_STACKHEIGHT++] = $ss19681969;
}
if(R.isPyretException($e19641965)) {
$e19641965.pyretStack.push(L[271]);
}
throw $e19641965;
}
var $ret19701971 = $Hanf_arg8161977($z19661967,N116,anf_arg3171962,anf_arg3181976,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret19701971;
};
var $Hanf_arg8161977 = function(anf_arg3201975,N116,anf_arg3171962,anf_arg3181976,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,link291907,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var $z19801981 = D;
var $f19861987 = function(_) {
return R.isFunction(link291907)?link291907.app(anf_arg3181976,anf_arg3201975):R.ffi.throwNonFunApp(L[274],link291907,[anf_arg3181976,anf_arg3201975]);
};
try {
if(--R.GAS > 0) {
$z19801981 = $f19861987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19861987,
"from":L[274]});
}
} catch($e19781979) {
if(R.isCont($e19781979)) {
var $ss19821983 = {"from":L[274],
"go":function(anf_arg3211988) {
return $Hanf_arg8151989(anf_arg3211988,N116,anf_arg3171962,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e19781979.stack[R.EXN_STACKHEIGHT++] = $ss19821983;
}
if(R.isPyretException($e19781979)) {
$e19781979.pyretStack.push(L[274]);
}
throw $e19781979;
}
var $ret19841985 = $Hanf_arg8151989($z19801981,N116,anf_arg3171962,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret19841985;
};
var $Hanf_arg8151989 = function(anf_arg3211988,N116,anf_arg3171962,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,helper8960,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var anf_arg3222000 = G(rest_DASH_split1651904,"body",L[276]);
var $z19921993 = D;
var $f19981999 = function(_) {
return R.isFunction(helper8960.$var)?helper8960.$var.app(anf_arg3171962,anf_arg3211988,anf_arg3222000):R.ffi.throwNonFunApp(L[275],helper8960.$var,[anf_arg3171962,anf_arg3211988,anf_arg3222000]);
};
try {
if(--R.GAS > 0) {
$z19921993 = $f19981999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19981999,
"from":L[275]});
}
} catch($e19901991) {
if(R.isCont($e19901991)) {
var $ss19941995 = {"from":L[275],
"go":function(h1672001) {
return $Hh8142002(h1672001,N116,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e19901991.stack[R.EXN_STACKHEIGHT++] = $ss19941995;
}
if(R.isPyretException($e19901991)) {
$e19901991.pyretStack.push(L[275]);
}
throw $e19901991;
}
var $ret19961997 = $Hh8142002($z19921993,N116,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret19961997;
};
var $Hh8142002 = function(h1672001,N116,args1641905,concat_DASH_singleton8257,f1631906,fvs1661935,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var $z20052006 = D;
var $f20112012 = function(_) {
return R.isFunction(concat_DASH_singleton8257.$var)?concat_DASH_singleton8257.$var.app(h1672001):R.ffi.throwNonFunApp(L[277],concat_DASH_singleton8257.$var,[h1672001]);
};
try {
if(--R.GAS > 0) {
$z20052006 = $f20112012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20112012,
"from":L[277]});
}
} catch($e20032004) {
if(R.isCont($e20032004)) {
var $ss20072008 = {"from":L[277],
"go":function(anf_arg3232013) {
return $Hanf_arg8132014(anf_arg3232013,N116,args1641905,f1631906,fvs1661935,h1672001,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e20032004.stack[R.EXN_STACKHEIGHT++] = $ss20072008;
}
if(R.isPyretException($e20032004)) {
$e20032004.pyretStack.push(L[277]);
}
throw $e20032004;
}
var $ret20092010 = $Hanf_arg8132014($z20052006,N116,args1641905,f1631906,fvs1661935,h1672001,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret20092010;
};
var $Hanf_arg8132014 = function(anf_arg3232013,N116,args1641905,f1631906,fvs1661935,h1672001,is_DASH_var1581778,l1571779,rest_DASH_split1651904,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10) {
var anf_arg3242025 = G(rest_DASH_split1651904,"helpers",L[279]);
var $z20172018 = D;
var $f20232024 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg3232013,anf_arg3242025):R.ffi.throwNonFunApp(L[278],_plus10,[anf_arg3232013,anf_arg3242025]);
};
try {
if(--R.GAS > 0) {
$z20172018 = $f20232024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20232024,
"from":L[278]});
}
} catch($e20152016) {
if(R.isCont($e20152016)) {
var $ss20192020 = {"from":L[278],
"go":function(anf_arg3252026) {
return $Hanf_arg8122027(anf_arg3252026,N116,args1641905,f1631906,fvs1661935,h1672001,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,unions10479);
}};
$e20152016.stack[R.EXN_STACKHEIGHT++] = $ss20192020;
}
if(R.isPyretException($e20152016)) {
$e20152016.pyretStack.push(L[278]);
}
throw $e20152016;
}
var $ret20212022 = $Hanf_arg8122027($z20172018,N116,args1641905,f1631906,fvs1661935,h1672001,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,unions10479);
++R.GAS;
return $ret20212022;
};
var $Hanf_arg8122027 = function(anf_arg3252026,N116,args1641905,f1631906,fvs1661935,h1672001,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,unions10479) {
var anf_fun3262042 = G(N116,"a-split-app",L[286]);
var anf_arg3272041 = G(h1672001,"name",L[285]);
var anf_bracket3282058 = G(h1672001,"args",L[284]);
var anf_fun3292038 = G(anf_bracket3282058,"map",L[283]);
var anf_arg3322039 = R.makeFunction(function(arg_DASH_462044) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[281],1,arguments);
}
var anf_fun3312055 = G(N116,"a-id",L[282]);
var $z20472048 = D;
var $f20532054 = function(_) {
return R.isFunction(anf_fun3312055)?anf_fun3312055.app(l1571779,arg_DASH_462044):R.ffi.throwNonFunApp(L[281],anf_fun3312055,[l1571779,arg_DASH_462044]);
};
try {
if(--R.GAS > 0) {
$z20472048 = $f20532054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20532054,
"from":L[281]});
}
} catch($e20452046) {
if(R.isCont($e20452046)) {
var $ss20492050 = {"from":L[281],
"go":function(ann_DASH_check_DASH_temp3302056) {
return $Hann_DASH_check_DASH_temp8032057(ann_DASH_check_DASH_temp3302056);
}};
$e20452046.stack[R.EXN_STACKHEIGHT++] = $ss20492050;
}
if(R.isPyretException($e20452046)) {
$e20452046.pyretStack.push(L[281]);
}
throw $e20452046;
}
var $ret20512052 = $Hann_DASH_check_DASH_temp8032057($z20472048);
++R.GAS;
return $ret20512052;
});
var $z20302031 = D;
var $f20362037 = function(_) {
return R.isFunction(anf_fun3292038)?anf_fun3292038.app(anf_arg3322039):R.ffi.throwNonFunApp(L[280],anf_fun3292038,[anf_arg3322039]);
};
try {
if(--R.GAS > 0) {
$z20302031 = $f20362037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20362037,
"from":L[280]});
}
} catch($e20282029) {
if(R.isCont($e20282029)) {
var $ss20322033 = {"from":L[280],
"go":function(anf_arg3332040) {
return $Hanf_arg8112043(anf_arg3332040,N116,anf_arg3252026,anf_arg3272041,anf_fun3262042,args1641905,f1631906,fvs1661935,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,unions10479);
}};
$e20282029.stack[R.EXN_STACKHEIGHT++] = $ss20322033;
}
if(R.isPyretException($e20282029)) {
$e20282029.pyretStack.push(L[280]);
}
throw $e20282029;
}
var $ret20342035 = $Hanf_arg8112043($z20302031,N116,anf_arg3252026,anf_arg3272041,anf_fun3262042,args1641905,f1631906,fvs1661935,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,unions10479);
++R.GAS;
return $ret20342035;
};
var $Hanf_arg8112043 = function(anf_arg3332040,N116,anf_arg3252026,anf_arg3272041,anf_fun3262042,args1641905,f1631906,fvs1661935,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,unions10479) {
var $z20612062 = D;
var $f20672068 = function(_) {
return R.isFunction(anf_fun3262042)?anf_fun3262042.app(l1571779,is_DASH_var1581778,f1631906,args1641905,anf_arg3272041,anf_arg3332040):R.ffi.throwNonFunApp(L[287],anf_fun3262042,[l1571779,is_DASH_var1581778,f1631906,args1641905,anf_arg3272041,anf_arg3332040]);
};
try {
if(--R.GAS > 0) {
$z20612062 = $f20672068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20672068,
"from":L[287]});
}
} catch($e20592060) {
if(R.isCont($e20592060)) {
var $ss20632064 = {"from":L[287],
"go":function(anf_arg3342069) {
return $Hanf_arg8102070(anf_arg3342069,N116,anf_arg3252026,args1641905,f1631906,fvs1661935,split_DASH_result_DASH_int_DASH_e10176,unions10479);
}};
$e20592060.stack[R.EXN_STACKHEIGHT++] = $ss20632064;
}
if(R.isPyretException($e20592060)) {
$e20592060.pyretStack.push(L[287]);
}
throw $e20592060;
}
var $ret20652066 = $Hanf_arg8102070($z20612062,N116,anf_arg3252026,args1641905,f1631906,fvs1661935,split_DASH_result_DASH_int_DASH_e10176,unions10479);
++R.GAS;
return $ret20652066;
};
var $Hanf_arg8102070 = function(anf_arg3342069,N116,anf_arg3252026,args1641905,f1631906,fvs1661935,split_DASH_result_DASH_int_DASH_e10176,unions10479) {
var anf_fun3352084 = G(fvs1661935,"union",L[291]);
var anf_fun3362081 = G(args1641905,"map",L[290]);
var anf_arg3372082 = G(N116,"freevars-v",L[289]);
var $z20732074 = D;
var $f20792080 = function(_) {
return R.isFunction(anf_fun3362081)?anf_fun3362081.app(anf_arg3372082):R.ffi.throwNonFunApp(L[288],anf_fun3362081,[anf_arg3372082]);
};
try {
if(--R.GAS > 0) {
$z20732074 = $f20792080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20792080,
"from":L[288]});
}
} catch($e20712072) {
if(R.isCont($e20712072)) {
var $ss20752076 = {"from":L[288],
"go":function(anf_arg3382083) {
return $Hanf_arg8092085(anf_arg3382083,N116,anf_arg3252026,anf_arg3342069,anf_fun3352084,f1631906,split_DASH_result_DASH_int_DASH_e10176,unions10479);
}};
$e20712072.stack[R.EXN_STACKHEIGHT++] = $ss20752076;
}
if(R.isPyretException($e20712072)) {
$e20712072.pyretStack.push(L[288]);
}
throw $e20712072;
}
var $ret20772078 = $Hanf_arg8092085($z20732074,N116,anf_arg3252026,anf_arg3342069,anf_fun3352084,f1631906,split_DASH_result_DASH_int_DASH_e10176,unions10479);
++R.GAS;
return $ret20772078;
};
var $Hanf_arg8092085 = function(anf_arg3382083,N116,anf_arg3252026,anf_arg3342069,anf_fun3352084,f1631906,split_DASH_result_DASH_int_DASH_e10176,unions10479) {
var $z20882089 = D;
var $f20942095 = function(_) {
return R.isFunction(unions10479.$var)?unions10479.$var.app(anf_arg3382083):R.ffi.throwNonFunApp(L[292],unions10479.$var,[anf_arg3382083]);
};
try {
if(--R.GAS > 0) {
$z20882089 = $f20942095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20942095,
"from":L[292]});
}
} catch($e20862087) {
if(R.isCont($e20862087)) {
var $ss20902091 = {"from":L[292],
"go":function(anf_arg3392096) {
return $Hanf_arg8082097(anf_arg3392096,N116,anf_arg3252026,anf_arg3342069,anf_fun3352084,f1631906,split_DASH_result_DASH_int_DASH_e10176);
}};
$e20862087.stack[R.EXN_STACKHEIGHT++] = $ss20902091;
}
if(R.isPyretException($e20862087)) {
$e20862087.pyretStack.push(L[292]);
}
throw $e20862087;
}
var $ret20922093 = $Hanf_arg8082097($z20882089,N116,anf_arg3252026,anf_arg3342069,anf_fun3352084,f1631906,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret20922093;
};
var $Hanf_arg8082097 = function(anf_arg3392096,N116,anf_arg3252026,anf_arg3342069,anf_fun3352084,f1631906,split_DASH_result_DASH_int_DASH_e10176) {
var $z21002101 = D;
var $f21062107 = function(_) {
return R.isFunction(anf_fun3352084)?anf_fun3352084.app(anf_arg3392096):R.ffi.throwNonFunApp(L[293],anf_fun3352084,[anf_arg3392096]);
};
try {
if(--R.GAS > 0) {
$z21002101 = $f21062107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21062107,
"from":L[293]});
}
} catch($e20982099) {
if(R.isCont($e20982099)) {
var $ss21022103 = {"from":L[293],
"go":function(anf_bracket3402108) {
return $Hanf_bracket8072109(anf_bracket3402108,N116,anf_arg3252026,anf_arg3342069,f1631906,split_DASH_result_DASH_int_DASH_e10176);
}};
$e20982099.stack[R.EXN_STACKHEIGHT++] = $ss21022103;
}
if(R.isPyretException($e20982099)) {
$e20982099.pyretStack.push(L[293]);
}
throw $e20982099;
}
var $ret21042105 = $Hanf_bracket8072109($z21002101,N116,anf_arg3252026,anf_arg3342069,f1631906,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret21042105;
};
var $Hanf_bracket8072109 = function(anf_bracket3402108,N116,anf_arg3252026,anf_arg3342069,f1631906,split_DASH_result_DASH_int_DASH_e10176) {
var anf_fun3412122 = G(anf_bracket3402108,"union",L[296]);
var anf_fun3422120 = G(N116,"freevars-v",L[295]);
var $z21122113 = D;
var $f21182119 = function(_) {
return R.isFunction(anf_fun3422120)?anf_fun3422120.app(f1631906):R.ffi.throwNonFunApp(L[294],anf_fun3422120,[f1631906]);
};
try {
if(--R.GAS > 0) {
$z21122113 = $f21182119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21182119,
"from":L[294]});
}
} catch($e21102111) {
if(R.isCont($e21102111)) {
var $ss21142115 = {"from":L[294],
"go":function(anf_arg3432121) {
return $Hanf_arg8062123(anf_arg3432121,anf_arg3252026,anf_arg3342069,anf_fun3412122,split_DASH_result_DASH_int_DASH_e10176);
}};
$e21102111.stack[R.EXN_STACKHEIGHT++] = $ss21142115;
}
if(R.isPyretException($e21102111)) {
$e21102111.pyretStack.push(L[294]);
}
throw $e21102111;
}
var $ret21162117 = $Hanf_arg8062123($z21122113,anf_arg3252026,anf_arg3342069,anf_fun3412122,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret21162117;
};
var $Hanf_arg8062123 = function(anf_arg3432121,anf_arg3252026,anf_arg3342069,anf_fun3412122,split_DASH_result_DASH_int_DASH_e10176) {
var $z21262127 = D;
var $f21322133 = function(_) {
return R.isFunction(anf_fun3412122)?anf_fun3412122.app(anf_arg3432121):R.ffi.throwNonFunApp(L[297],anf_fun3412122,[anf_arg3432121]);
};
try {
if(--R.GAS > 0) {
$z21262127 = $f21322133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21322133,
"from":L[297]});
}
} catch($e21242125) {
if(R.isCont($e21242125)) {
var $ss21282129 = {"from":L[297],
"go":function(anf_arg3442134) {
return $Hanf_arg8052135(anf_arg3442134,anf_arg3252026,anf_arg3342069,split_DASH_result_DASH_int_DASH_e10176);
}};
$e21242125.stack[R.EXN_STACKHEIGHT++] = $ss21282129;
}
if(R.isPyretException($e21242125)) {
$e21242125.pyretStack.push(L[297]);
}
throw $e21242125;
}
var $ret21302131 = $Hanf_arg8052135($z21262127,anf_arg3252026,anf_arg3342069,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret21302131;
};
var $Hanf_arg8052135 = function(anf_arg3442134,anf_arg3252026,anf_arg3342069,split_DASH_result_DASH_int_DASH_e10176) {
var $z21382139 = D;
var $f21442145 = function(_) {
return R.isFunction(split_DASH_result_DASH_int_DASH_e10176.$var)?split_DASH_result_DASH_int_DASH_e10176.$var.app(anf_arg3252026,anf_arg3342069,anf_arg3442134):R.ffi.throwNonFunApp(L[298],split_DASH_result_DASH_int_DASH_e10176.$var,[anf_arg3252026,anf_arg3342069,anf_arg3442134]);
};
try {
if(--R.GAS > 0) {
$z21382139 = $f21442145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21442145,
"from":L[298]});
}
} catch($e21362137) {
if(R.isCont($e21362137)) {
var $ss21402141 = {"from":L[298],
"go":function(ann_DASH_check_DASH_temp3062146) {
return $Hann_DASH_check_DASH_temp8042147(ann_DASH_check_DASH_temp3062146);
}};
$e21362137.stack[R.EXN_STACKHEIGHT++] = $ss21402141;
}
if(R.isPyretException($e21362137)) {
$e21362137.pyretStack.push(L[298]);
}
throw $e21362137;
}
var $ret21422143 = $Hann_DASH_check_DASH_temp8042147($z21382139);
++R.GAS;
return $ret21422143;
};
var $Hann_DASH_check_DASH_temp8042147 = function(ann_DASH_check_DASH_temp3062146) {
return ann_DASH_check_DASH_temp3062146;
};
var $Hann_DASH_check_DASH_temp8032057 = function(ann_DASH_check_DASH_temp3302056) {
return ann_DASH_check_DASH_temp3302056;
};
var $Hr8022148 = function(r1542149,SplitResult7048,split_DASH_result9578) {
var anf_bracket2972163 = G(r1542149,"helpers",L[301]);
var anf_fun2982160 = G(anf_bracket2972163,"to-list",L[300]);
var $z21522153 = D;
var $f21582159 = function(_) {
return R.isFunction(anf_fun2982160)?anf_fun2982160.app():R.ffi.throwNonFunApp(L[299],anf_fun2982160,[]);
};
try {
if(--R.GAS > 0) {
$z21522153 = $f21582159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21582159,
"from":L[299]});
}
} catch($e21502151) {
if(R.isCont($e21502151)) {
var $ss21542155 = {"from":L[299],
"go":function(anf_arg2992161) {
return $Hanf_arg8012162(anf_arg2992161,SplitResult7048,r1542149,split_DASH_result9578);
}};
$e21502151.stack[R.EXN_STACKHEIGHT++] = $ss21542155;
}
if(R.isPyretException($e21502151)) {
$e21502151.pyretStack.push(L[299]);
}
throw $e21502151;
}
var $ret21562157 = $Hanf_arg8012162($z21522153,SplitResult7048,r1542149,split_DASH_result9578);
++R.GAS;
return $ret21562157;
};
var $Hanf_arg8012162 = function(anf_arg2992161,SplitResult7048,r1542149,split_DASH_result9578) {
var anf_arg3002174 = G(r1542149,"body",L[304]);
var anf_arg3012175 = G(r1542149,"freevars",L[303]);
var $z21662167 = D;
var $f21722173 = function(_) {
return R.isFunction(split_DASH_result9578.$var)?split_DASH_result9578.$var.app(anf_arg2992161,anf_arg3002174,anf_arg3012175):R.ffi.throwNonFunApp(L[302],split_DASH_result9578.$var,[anf_arg2992161,anf_arg3002174,anf_arg3012175]);
};
try {
if(--R.GAS > 0) {
$z21662167 = $f21722173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21722173,
"from":L[302]});
}
} catch($e21642165) {
if(R.isCont($e21642165)) {
var $ss21682169 = {"from":L[302],
"go":function(ann_DASH_check_DASH_temp2962176) {
return $Hann_DASH_check_DASH_temp8002177(ann_DASH_check_DASH_temp2962176,SplitResult7048);
}};
$e21642165.stack[R.EXN_STACKHEIGHT++] = $ss21682169;
}
if(R.isPyretException($e21642165)) {
$e21642165.pyretStack.push(L[302]);
}
throw $e21642165;
}
var $ret21702171 = $Hann_DASH_check_DASH_temp8002177($z21662167,SplitResult7048);
++R.GAS;
return $ret21702171;
};
var $Hann_DASH_check_DASH_temp8002177 = function(ann_DASH_check_DASH_temp2962176,SplitResult7048) {
return ann_DASH_check_DASH_temp2962176;
};
var $Hann_DASH_check_DASH_temp7992178 = function(ann_DASH_check_DASH_temp2902179,Set202180) {
return ann_DASH_check_DASH_temp2902179;
};
var $Hann_DASH_check_DASH_temp7982181 = function(ann_DASH_check_DASH_temp2912182) {
return ann_DASH_check_DASH_temp2912182;
};
var $Hanf_arg7972183 = function(anf_arg2712184,self442185,_plus10,torepr14) {
var anf_arg2722196 = G(self442185,"body",L[305]);
var $z21882189 = D;
var $f21942195 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2722196):R.ffi.throwNonFunApp(L[305],torepr14,[anf_arg2722196]);
};
try {
if(--R.GAS > 0) {
$z21882189 = $f21942195();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21942195,
"from":L[305]});
}
} catch($e21862187) {
if(R.isCont($e21862187)) {
var $ss21902191 = {"from":L[305],
"go":function(anf_arg2732197) {
return $Hanf_arg7962198(anf_arg2732197,anf_arg2712184,self442185,_plus10,torepr14);
}};
$e21862187.stack[R.EXN_STACKHEIGHT++] = $ss21902191;
}
if(R.isPyretException($e21862187)) {
$e21862187.pyretStack.push(L[305]);
}
throw $e21862187;
}
var $ret21922193 = $Hanf_arg7962198($z21882189,anf_arg2712184,self442185,_plus10,torepr14);
++R.GAS;
return $ret21922193;
};
var $Hanf_arg7962198 = function(anf_arg2732197,anf_arg2712184,self442185,_plus10,torepr14) {
var $z22012202 = D;
var $f22072208 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg2732197):R.ffi.throwNonFunApp(L[305],_plus10,[(", "),anf_arg2732197]);
};
try {
if(--R.GAS > 0) {
$z22012202 = $f22072208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22072208,
"from":L[305]});
}
} catch($e21992200) {
if(R.isCont($e21992200)) {
var $ss22032204 = {"from":L[305],
"go":function(anf_arg2742209) {
return $Hanf_arg7952210(anf_arg2742209,anf_arg2712184,self442185,_plus10,torepr14);
}};
$e21992200.stack[R.EXN_STACKHEIGHT++] = $ss22032204;
}
if(R.isPyretException($e21992200)) {
$e21992200.pyretStack.push(L[305]);
}
throw $e21992200;
}
var $ret22052206 = $Hanf_arg7952210($z22012202,anf_arg2712184,self442185,_plus10,torepr14);
++R.GAS;
return $ret22052206;
};
var $Hanf_arg7952210 = function(anf_arg2742209,anf_arg2712184,self442185,_plus10,torepr14) {
var $z22132214 = D;
var $f22192220 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg2712184,anf_arg2742209):R.ffi.throwNonFunApp(L[305],_plus10,[anf_arg2712184,anf_arg2742209]);
};
try {
if(--R.GAS > 0) {
$z22132214 = $f22192220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22192220,
"from":L[305]});
}
} catch($e22112212) {
if(R.isCont($e22112212)) {
var $ss22152216 = {"from":L[305],
"go":function(anf_arg2752221) {
return $Hanf_arg7942222(anf_arg2752221,self442185,_plus10,torepr14);
}};
$e22112212.stack[R.EXN_STACKHEIGHT++] = $ss22152216;
}
if(R.isPyretException($e22112212)) {
$e22112212.pyretStack.push(L[305]);
}
throw $e22112212;
}
var $ret22172218 = $Hanf_arg7942222($z22132214,self442185,_plus10,torepr14);
++R.GAS;
return $ret22172218;
};
var $Hanf_arg7942222 = function(anf_arg2752221,self442185,_plus10,torepr14) {
var anf_arg2762233 = G(self442185,"freevars",L[305]);
var $z22252226 = D;
var $f22312232 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2762233):R.ffi.throwNonFunApp(L[305],torepr14,[anf_arg2762233]);
};
try {
if(--R.GAS > 0) {
$z22252226 = $f22312232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22312232,
"from":L[305]});
}
} catch($e22232224) {
if(R.isCont($e22232224)) {
var $ss22272228 = {"from":L[305],
"go":function(anf_arg2772234) {
return $Hanf_arg7932235(anf_arg2772234,anf_arg2752221,_plus10);
}};
$e22232224.stack[R.EXN_STACKHEIGHT++] = $ss22272228;
}
if(R.isPyretException($e22232224)) {
$e22232224.pyretStack.push(L[305]);
}
throw $e22232224;
}
var $ret22292230 = $Hanf_arg7932235($z22252226,anf_arg2752221,_plus10);
++R.GAS;
return $ret22292230;
};
var $Hanf_arg7932235 = function(anf_arg2772234,anf_arg2752221,_plus10) {
var $z22382239 = D;
var $f22442245 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg2772234):R.ffi.throwNonFunApp(L[305],_plus10,[(", "),anf_arg2772234]);
};
try {
if(--R.GAS > 0) {
$z22382239 = $f22442245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22442245,
"from":L[305]});
}
} catch($e22362237) {
if(R.isCont($e22362237)) {
var $ss22402241 = {"from":L[305],
"go":function(anf_arg2782246) {
return $Hanf_arg7922247(anf_arg2782246,anf_arg2752221,_plus10);
}};
$e22362237.stack[R.EXN_STACKHEIGHT++] = $ss22402241;
}
if(R.isPyretException($e22362237)) {
$e22362237.pyretStack.push(L[305]);
}
throw $e22362237;
}
var $ret22422243 = $Hanf_arg7922247($z22382239,anf_arg2752221,_plus10);
++R.GAS;
return $ret22422243;
};
var $Hanf_arg7922247 = function(anf_arg2782246,anf_arg2752221,_plus10) {
var $z22502251 = D;
var $f22562257 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg2752221,anf_arg2782246):R.ffi.throwNonFunApp(L[305],_plus10,[anf_arg2752221,anf_arg2782246]);
};
try {
if(--R.GAS > 0) {
$z22502251 = $f22562257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22562257,
"from":L[305]});
}
} catch($e22482249) {
if(R.isCont($e22482249)) {
var $ss22522253 = {"from":L[305],
"go":function(anf_arg2792258) {
return $Hanf_arg7912259(anf_arg2792258,_plus10);
}};
$e22482249.stack[R.EXN_STACKHEIGHT++] = $ss22522253;
}
if(R.isPyretException($e22482249)) {
$e22482249.pyretStack.push(L[305]);
}
throw $e22482249;
}
var $ret22542255 = $Hanf_arg7912259($z22502251,_plus10);
++R.GAS;
return $ret22542255;
};
var $Hanf_arg7912259 = function(anf_arg2792258,_plus10) {
var $z22622263 = D;
var $f22682269 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg2792258,(")")):R.ffi.throwNonFunApp(L[305],_plus10,[anf_arg2792258,(")")]);
};
try {
if(--R.GAS > 0) {
$z22622263 = $f22682269();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22682269,
"from":L[305]});
}
} catch($e22602261) {
if(R.isCont($e22602261)) {
var $ss22642265 = {"from":L[305],
"go":function(anf_arg2802270) {
return $Hanf_arg7902271(anf_arg2802270,_plus10);
}};
$e22602261.stack[R.EXN_STACKHEIGHT++] = $ss22642265;
}
if(R.isPyretException($e22602261)) {
$e22602261.pyretStack.push(L[305]);
}
throw $e22602261;
}
var $ret22662267 = $Hanf_arg7902271($z22622263,_plus10);
++R.GAS;
return $ret22662267;
};
var $Hanf_arg7902271 = function(anf_arg2802270,_plus10) {
var $z22742275 = D;
var $f22802281 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("("),anf_arg2802270):R.ffi.throwNonFunApp(L[305],_plus10,[("("),anf_arg2802270]);
};
try {
if(--R.GAS > 0) {
$z22742275 = $f22802281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22802281,
"from":L[305]});
}
} catch($e22722273) {
if(R.isCont($e22722273)) {
var $ss22762277 = {"from":L[305],
"go":function(anf_arg2812282) {
return $Hanf_arg7892283(anf_arg2812282,_plus10);
}};
$e22722273.stack[R.EXN_STACKHEIGHT++] = $ss22762277;
}
if(R.isPyretException($e22722273)) {
$e22722273.pyretStack.push(L[305]);
}
throw $e22722273;
}
var $ret22782279 = $Hanf_arg7892283($z22742275,_plus10);
++R.GAS;
return $ret22782279;
};
var $Hanf_arg7892283 = function(anf_arg2812282,_plus10) {
var $z22862287 = D;
var $f22922293 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("split-result-int-l"),anf_arg2812282):R.ffi.throwNonFunApp(L[305],_plus10,[("split-result-int-l"),anf_arg2812282]);
};
try {
if(--R.GAS > 0) {
$z22862287 = $f22922293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22922293,
"from":L[305]});
}
} catch($e22842285) {
if(R.isCont($e22842285)) {
var $ss22882289 = {"from":L[305],
"go":function(ann_DASH_check_DASH_temp2692294) {
return $Hann_DASH_check_DASH_temp7882295(ann_DASH_check_DASH_temp2692294);
}};
$e22842285.stack[R.EXN_STACKHEIGHT++] = $ss22882289;
}
if(R.isPyretException($e22842285)) {
$e22842285.pyretStack.push(L[305]);
}
throw $e22842285;
}
var $ret22902291 = $Hann_DASH_check_DASH_temp7882295($z22862287);
++R.GAS;
return $ret22902291;
};
var $Hann_DASH_check_DASH_temp7882295 = function(ann_DASH_check_DASH_temp2692294) {
return ann_DASH_check_DASH_temp2692294;
};
var $Hcont_tail_arg7862296 = function(cont_tail_arg2662297,if_helper2562298) {
if(--R.GAS > 0) {
$z22992300 = R.isFunction(if_helper2562298)?if_helper2562298.app(cont_tail_arg2662297):R.ffi.throwNonFunApp(L[305],if_helper2562298,[cont_tail_arg2662297]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper2562298)?if_helper2562298.app(cont_tail_arg2662297):R.ffi.throwNonFunApp(L[305],if_helper2562298,[cont_tail_arg2662297]);
},
"from":L[305]});
}
++R.GAS;
return $z22992300;
};
var $Hcont_tail_arg7872301 = function(cont_tail_arg2612302,if_helper2562298) {
if(--R.GAS > 0) {
$z23032304 = R.isFunction(if_helper2562298)?if_helper2562298.app(cont_tail_arg2612302):R.ffi.throwNonFunApp(L[305],if_helper2562298,[cont_tail_arg2612302]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper2562298)?if_helper2562298.app(cont_tail_arg2612302):R.ffi.throwNonFunApp(L[305],if_helper2562298,[cont_tail_arg2612302]);
},
"from":L[305]});
}
++R.GAS;
return $z23032304;
};
var $Hanf_arg7852305 = function(anf_arg2432306,self382307,_plus10,torepr14) {
var anf_arg2442318 = G(self382307,"body",L[306]);
var $z23102311 = D;
var $f23162317 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2442318):R.ffi.throwNonFunApp(L[306],torepr14,[anf_arg2442318]);
};
try {
if(--R.GAS > 0) {
$z23102311 = $f23162317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23162317,
"from":L[306]});
}
} catch($e23082309) {
if(R.isCont($e23082309)) {
var $ss23122313 = {"from":L[306],
"go":function(anf_arg2452319) {
return $Hanf_arg7842320(anf_arg2452319,anf_arg2432306,self382307,_plus10,torepr14);
}};
$e23082309.stack[R.EXN_STACKHEIGHT++] = $ss23122313;
}
if(R.isPyretException($e23082309)) {
$e23082309.pyretStack.push(L[306]);
}
throw $e23082309;
}
var $ret23142315 = $Hanf_arg7842320($z23102311,anf_arg2432306,self382307,_plus10,torepr14);
++R.GAS;
return $ret23142315;
};
var $Hanf_arg7842320 = function(anf_arg2452319,anf_arg2432306,self382307,_plus10,torepr14) {
var $z23232324 = D;
var $f23292330 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg2452319):R.ffi.throwNonFunApp(L[306],_plus10,[(", "),anf_arg2452319]);
};
try {
if(--R.GAS > 0) {
$z23232324 = $f23292330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23292330,
"from":L[306]});
}
} catch($e23212322) {
if(R.isCont($e23212322)) {
var $ss23252326 = {"from":L[306],
"go":function(anf_arg2462331) {
return $Hanf_arg7832332(anf_arg2462331,anf_arg2432306,self382307,_plus10,torepr14);
}};
$e23212322.stack[R.EXN_STACKHEIGHT++] = $ss23252326;
}
if(R.isPyretException($e23212322)) {
$e23212322.pyretStack.push(L[306]);
}
throw $e23212322;
}
var $ret23272328 = $Hanf_arg7832332($z23232324,anf_arg2432306,self382307,_plus10,torepr14);
++R.GAS;
return $ret23272328;
};
var $Hanf_arg7832332 = function(anf_arg2462331,anf_arg2432306,self382307,_plus10,torepr14) {
var $z23352336 = D;
var $f23412342 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg2432306,anf_arg2462331):R.ffi.throwNonFunApp(L[306],_plus10,[anf_arg2432306,anf_arg2462331]);
};
try {
if(--R.GAS > 0) {
$z23352336 = $f23412342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23412342,
"from":L[306]});
}
} catch($e23332334) {
if(R.isCont($e23332334)) {
var $ss23372338 = {"from":L[306],
"go":function(anf_arg2472343) {
return $Hanf_arg7822344(anf_arg2472343,self382307,_plus10,torepr14);
}};
$e23332334.stack[R.EXN_STACKHEIGHT++] = $ss23372338;
}
if(R.isPyretException($e23332334)) {
$e23332334.pyretStack.push(L[306]);
}
throw $e23332334;
}
var $ret23392340 = $Hanf_arg7822344($z23352336,self382307,_plus10,torepr14);
++R.GAS;
return $ret23392340;
};
var $Hanf_arg7822344 = function(anf_arg2472343,self382307,_plus10,torepr14) {
var anf_arg2482355 = G(self382307,"freevars",L[306]);
var $z23472348 = D;
var $f23532354 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2482355):R.ffi.throwNonFunApp(L[306],torepr14,[anf_arg2482355]);
};
try {
if(--R.GAS > 0) {
$z23472348 = $f23532354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23532354,
"from":L[306]});
}
} catch($e23452346) {
if(R.isCont($e23452346)) {
var $ss23492350 = {"from":L[306],
"go":function(anf_arg2492356) {
return $Hanf_arg7812357(anf_arg2492356,anf_arg2472343,_plus10);
}};
$e23452346.stack[R.EXN_STACKHEIGHT++] = $ss23492350;
}
if(R.isPyretException($e23452346)) {
$e23452346.pyretStack.push(L[306]);
}
throw $e23452346;
}
var $ret23512352 = $Hanf_arg7812357($z23472348,anf_arg2472343,_plus10);
++R.GAS;
return $ret23512352;
};
var $Hanf_arg7812357 = function(anf_arg2492356,anf_arg2472343,_plus10) {
var $z23602361 = D;
var $f23662367 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg2492356):R.ffi.throwNonFunApp(L[306],_plus10,[(", "),anf_arg2492356]);
};
try {
if(--R.GAS > 0) {
$z23602361 = $f23662367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23662367,
"from":L[306]});
}
} catch($e23582359) {
if(R.isCont($e23582359)) {
var $ss23622363 = {"from":L[306],
"go":function(anf_arg2502368) {
return $Hanf_arg7802369(anf_arg2502368,anf_arg2472343,_plus10);
}};
$e23582359.stack[R.EXN_STACKHEIGHT++] = $ss23622363;
}
if(R.isPyretException($e23582359)) {
$e23582359.pyretStack.push(L[306]);
}
throw $e23582359;
}
var $ret23642365 = $Hanf_arg7802369($z23602361,anf_arg2472343,_plus10);
++R.GAS;
return $ret23642365;
};
var $Hanf_arg7802369 = function(anf_arg2502368,anf_arg2472343,_plus10) {
var $z23722373 = D;
var $f23782379 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg2472343,anf_arg2502368):R.ffi.throwNonFunApp(L[306],_plus10,[anf_arg2472343,anf_arg2502368]);
};
try {
if(--R.GAS > 0) {
$z23722373 = $f23782379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23782379,
"from":L[306]});
}
} catch($e23702371) {
if(R.isCont($e23702371)) {
var $ss23742375 = {"from":L[306],
"go":function(anf_arg2512380) {
return $Hanf_arg7792381(anf_arg2512380,_plus10);
}};
$e23702371.stack[R.EXN_STACKHEIGHT++] = $ss23742375;
}
if(R.isPyretException($e23702371)) {
$e23702371.pyretStack.push(L[306]);
}
throw $e23702371;
}
var $ret23762377 = $Hanf_arg7792381($z23722373,_plus10);
++R.GAS;
return $ret23762377;
};
var $Hanf_arg7792381 = function(anf_arg2512380,_plus10) {
var $z23842385 = D;
var $f23902391 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg2512380,(")")):R.ffi.throwNonFunApp(L[306],_plus10,[anf_arg2512380,(")")]);
};
try {
if(--R.GAS > 0) {
$z23842385 = $f23902391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23902391,
"from":L[306]});
}
} catch($e23822383) {
if(R.isCont($e23822383)) {
var $ss23862387 = {"from":L[306],
"go":function(anf_arg2522392) {
return $Hanf_arg7782393(anf_arg2522392,_plus10);
}};
$e23822383.stack[R.EXN_STACKHEIGHT++] = $ss23862387;
}
if(R.isPyretException($e23822383)) {
$e23822383.pyretStack.push(L[306]);
}
throw $e23822383;
}
var $ret23882389 = $Hanf_arg7782393($z23842385,_plus10);
++R.GAS;
return $ret23882389;
};
var $Hanf_arg7782393 = function(anf_arg2522392,_plus10) {
var $z23962397 = D;
var $f24022403 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("("),anf_arg2522392):R.ffi.throwNonFunApp(L[306],_plus10,[("("),anf_arg2522392]);
};
try {
if(--R.GAS > 0) {
$z23962397 = $f24022403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24022403,
"from":L[306]});
}
} catch($e23942395) {
if(R.isCont($e23942395)) {
var $ss23982399 = {"from":L[306],
"go":function(anf_arg2532404) {
return $Hanf_arg7772405(anf_arg2532404,_plus10);
}};
$e23942395.stack[R.EXN_STACKHEIGHT++] = $ss23982399;
}
if(R.isPyretException($e23942395)) {
$e23942395.pyretStack.push(L[306]);
}
throw $e23942395;
}
var $ret24002401 = $Hanf_arg7772405($z23962397,_plus10);
++R.GAS;
return $ret24002401;
};
var $Hanf_arg7772405 = function(anf_arg2532404,_plus10) {
var $z24082409 = D;
var $f24142415 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("split-result-int-e"),anf_arg2532404):R.ffi.throwNonFunApp(L[306],_plus10,[("split-result-int-e"),anf_arg2532404]);
};
try {
if(--R.GAS > 0) {
$z24082409 = $f24142415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24142415,
"from":L[306]});
}
} catch($e24062407) {
if(R.isCont($e24062407)) {
var $ss24102411 = {"from":L[306],
"go":function(ann_DASH_check_DASH_temp2412416) {
return $Hann_DASH_check_DASH_temp7762417(ann_DASH_check_DASH_temp2412416);
}};
$e24062407.stack[R.EXN_STACKHEIGHT++] = $ss24102411;
}
if(R.isPyretException($e24062407)) {
$e24062407.pyretStack.push(L[306]);
}
throw $e24062407;
}
var $ret24122413 = $Hann_DASH_check_DASH_temp7762417($z24082409);
++R.GAS;
return $ret24122413;
};
var $Hann_DASH_check_DASH_temp7762417 = function(ann_DASH_check_DASH_temp2412416) {
return ann_DASH_check_DASH_temp2412416;
};
var $Hcont_tail_arg7742418 = function(cont_tail_arg2382419,if_helper2282420) {
if(--R.GAS > 0) {
$z24212422 = R.isFunction(if_helper2282420)?if_helper2282420.app(cont_tail_arg2382419):R.ffi.throwNonFunApp(L[306],if_helper2282420,[cont_tail_arg2382419]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper2282420)?if_helper2282420.app(cont_tail_arg2382419):R.ffi.throwNonFunApp(L[306],if_helper2282420,[cont_tail_arg2382419]);
},
"from":L[306]});
}
++R.GAS;
return $z24212422;
};
var $Hcont_tail_arg7752423 = function(cont_tail_arg2332424,if_helper2282420) {
if(--R.GAS > 0) {
$z24252426 = R.isFunction(if_helper2282420)?if_helper2282420.app(cont_tail_arg2332424):R.ffi.throwNonFunApp(L[306],if_helper2282420,[cont_tail_arg2332424]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper2282420)?if_helper2282420.app(cont_tail_arg2332424):R.ffi.throwNonFunApp(L[306],if_helper2282420,[cont_tail_arg2332424]);
},
"from":L[306]});
}
++R.GAS;
return $z24252426;
};
var $Hanf_arg7732427 = function(anf_arg2122428,anf_fun2062429,list2572,self1412430,_plus10) {
var anf_fun2132443 = G(list2572,"make",L[310]);
var anf_bracket2142445 = G(self1412430,"body",L[309]);
var anf_fun2152441 = G(anf_bracket2142445,"tosource",L[308]);
var $z24332434 = D;
var $f24392440 = function(_) {
return R.isFunction(anf_fun2152441)?anf_fun2152441.app():R.ffi.throwNonFunApp(L[307],anf_fun2152441,[]);
};
try {
if(--R.GAS > 0) {
$z24332434 = $f24392440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24392440,
"from":L[307]});
}
} catch($e24312432) {
if(R.isCont($e24312432)) {
var $ss24352436 = {"from":L[307],
"go":function(anf_array_val2162442) {
return $Hanf_array_val7722444(anf_array_val2162442,anf_arg2122428,anf_fun2062429,anf_fun2132443,_plus10);
}};
$e24312432.stack[R.EXN_STACKHEIGHT++] = $ss24352436;
}
if(R.isPyretException($e24312432)) {
$e24312432.pyretStack.push(L[307]);
}
throw $e24312432;
}
var $ret24372438 = $Hanf_array_val7722444($z24332434,anf_arg2122428,anf_fun2062429,anf_fun2132443,_plus10);
++R.GAS;
return $ret24372438;
};
var $Hanf_array_val7722444 = function(anf_array_val2162442,anf_arg2122428,anf_fun2062429,anf_fun2132443,_plus10) {
var $z24482449 = D;
var $f24542455 = function(_) {
return R.isFunction(anf_fun2132443)?anf_fun2132443.app([anf_array_val2162442]):R.ffi.throwNonFunApp(L[310],anf_fun2132443,[[anf_array_val2162442]]);
};
try {
if(--R.GAS > 0) {
$z24482449 = $f24542455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24542455,
"from":L[310]});
}
} catch($e24462447) {
if(R.isCont($e24462447)) {
var $ss24502451 = {"from":L[310],
"go":function(anf_arg2172456) {
return $Hanf_arg7712457(anf_arg2172456,anf_arg2122428,anf_fun2062429,_plus10);
}};
$e24462447.stack[R.EXN_STACKHEIGHT++] = $ss24502451;
}
if(R.isPyretException($e24462447)) {
$e24462447.pyretStack.push(L[310]);
}
throw $e24462447;
}
var $ret24522453 = $Hanf_arg7712457($z24482449,anf_arg2122428,anf_fun2062429,_plus10);
++R.GAS;
return $ret24522453;
};
var $Hanf_arg7712457 = function(anf_arg2172456,anf_arg2122428,anf_fun2062429,_plus10) {
var $z24602461 = D;
var $f24662467 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg2122428,anf_arg2172456):R.ffi.throwNonFunApp(L[311],_plus10,[anf_arg2122428,anf_arg2172456]);
};
try {
if(--R.GAS > 0) {
$z24602461 = $f24662467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24662467,
"from":L[311]});
}
} catch($e24582459) {
if(R.isCont($e24582459)) {
var $ss24622463 = {"from":L[311],
"go":function(anf_arg2182468) {
return $Hanf_arg7702469(anf_arg2182468,anf_fun2062429);
}};
$e24582459.stack[R.EXN_STACKHEIGHT++] = $ss24622463;
}
if(R.isPyretException($e24582459)) {
$e24582459.pyretStack.push(L[311]);
}
throw $e24582459;
}
var $ret24642465 = $Hanf_arg7702469($z24602461,anf_fun2062429);
++R.GAS;
return $ret24642465;
};
var $Hanf_arg7702469 = function(anf_arg2182468,anf_fun2062429) {
var $z24722473 = D;
var $f24782479 = function(_) {
return R.isFunction(anf_fun2062429)?anf_fun2062429.app(anf_arg2182468):R.ffi.throwNonFunApp(L[312],anf_fun2062429,[anf_arg2182468]);
};
try {
if(--R.GAS > 0) {
$z24722473 = $f24782479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24782479,
"from":L[312]});
}
} catch($e24702471) {
if(R.isCont($e24702471)) {
var $ss24742475 = {"from":L[312],
"go":function(ann_DASH_check_DASH_temp2052480) {
return $Hann_DASH_check_DASH_temp7692481(ann_DASH_check_DASH_temp2052480);
}};
$e24702471.stack[R.EXN_STACKHEIGHT++] = $ss24742475;
}
if(R.isPyretException($e24702471)) {
$e24702471.pyretStack.push(L[312]);
}
throw $e24702471;
}
var $ret24762477 = $Hann_DASH_check_DASH_temp7692481($z24722473);
++R.GAS;
return $ret24762477;
};
var $Hann_DASH_check_DASH_temp7692481 = function(ann_DASH_check_DASH_temp2052480) {
return ann_DASH_check_DASH_temp2052480;
};
var $Hann_DASH_check_DASH_temp7682482 = function(ann_DASH_check_DASH_temp2092483) {
return ann_DASH_check_DASH_temp2092483;
};
var $Hanf_arg7672484 = function(anf_arg1932485,self312486,_plus10,torepr14) {
var anf_arg1942497 = G(self312486,"body",L[313]);
var $z24892490 = D;
var $f24952496 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1942497):R.ffi.throwNonFunApp(L[313],torepr14,[anf_arg1942497]);
};
try {
if(--R.GAS > 0) {
$z24892490 = $f24952496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24952496,
"from":L[313]});
}
} catch($e24872488) {
if(R.isCont($e24872488)) {
var $ss24912492 = {"from":L[313],
"go":function(anf_arg1952498) {
return $Hanf_arg7662499(anf_arg1952498,anf_arg1932485,self312486,_plus10,torepr14);
}};
$e24872488.stack[R.EXN_STACKHEIGHT++] = $ss24912492;
}
if(R.isPyretException($e24872488)) {
$e24872488.pyretStack.push(L[313]);
}
throw $e24872488;
}
var $ret24932494 = $Hanf_arg7662499($z24892490,anf_arg1932485,self312486,_plus10,torepr14);
++R.GAS;
return $ret24932494;
};
var $Hanf_arg7662499 = function(anf_arg1952498,anf_arg1932485,self312486,_plus10,torepr14) {
var $z25022503 = D;
var $f25082509 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg1952498):R.ffi.throwNonFunApp(L[313],_plus10,[(", "),anf_arg1952498]);
};
try {
if(--R.GAS > 0) {
$z25022503 = $f25082509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25082509,
"from":L[313]});
}
} catch($e25002501) {
if(R.isCont($e25002501)) {
var $ss25042505 = {"from":L[313],
"go":function(anf_arg1962510) {
return $Hanf_arg7652511(anf_arg1962510,anf_arg1932485,self312486,_plus10,torepr14);
}};
$e25002501.stack[R.EXN_STACKHEIGHT++] = $ss25042505;
}
if(R.isPyretException($e25002501)) {
$e25002501.pyretStack.push(L[313]);
}
throw $e25002501;
}
var $ret25062507 = $Hanf_arg7652511($z25022503,anf_arg1932485,self312486,_plus10,torepr14);
++R.GAS;
return $ret25062507;
};
var $Hanf_arg7652511 = function(anf_arg1962510,anf_arg1932485,self312486,_plus10,torepr14) {
var $z25142515 = D;
var $f25202521 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg1932485,anf_arg1962510):R.ffi.throwNonFunApp(L[313],_plus10,[anf_arg1932485,anf_arg1962510]);
};
try {
if(--R.GAS > 0) {
$z25142515 = $f25202521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25202521,
"from":L[313]});
}
} catch($e25122513) {
if(R.isCont($e25122513)) {
var $ss25162517 = {"from":L[313],
"go":function(anf_arg1972522) {
return $Hanf_arg7642523(anf_arg1972522,self312486,_plus10,torepr14);
}};
$e25122513.stack[R.EXN_STACKHEIGHT++] = $ss25162517;
}
if(R.isPyretException($e25122513)) {
$e25122513.pyretStack.push(L[313]);
}
throw $e25122513;
}
var $ret25182519 = $Hanf_arg7642523($z25142515,self312486,_plus10,torepr14);
++R.GAS;
return $ret25182519;
};
var $Hanf_arg7642523 = function(anf_arg1972522,self312486,_plus10,torepr14) {
var anf_arg1982534 = G(self312486,"freevars",L[313]);
var $z25262527 = D;
var $f25322533 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1982534):R.ffi.throwNonFunApp(L[313],torepr14,[anf_arg1982534]);
};
try {
if(--R.GAS > 0) {
$z25262527 = $f25322533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25322533,
"from":L[313]});
}
} catch($e25242525) {
if(R.isCont($e25242525)) {
var $ss25282529 = {"from":L[313],
"go":function(anf_arg1992535) {
return $Hanf_arg7632536(anf_arg1992535,anf_arg1972522,_plus10);
}};
$e25242525.stack[R.EXN_STACKHEIGHT++] = $ss25282529;
}
if(R.isPyretException($e25242525)) {
$e25242525.pyretStack.push(L[313]);
}
throw $e25242525;
}
var $ret25302531 = $Hanf_arg7632536($z25262527,anf_arg1972522,_plus10);
++R.GAS;
return $ret25302531;
};
var $Hanf_arg7632536 = function(anf_arg1992535,anf_arg1972522,_plus10) {
var $z25392540 = D;
var $f25452546 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg1992535):R.ffi.throwNonFunApp(L[313],_plus10,[(", "),anf_arg1992535]);
};
try {
if(--R.GAS > 0) {
$z25392540 = $f25452546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25452546,
"from":L[313]});
}
} catch($e25372538) {
if(R.isCont($e25372538)) {
var $ss25412542 = {"from":L[313],
"go":function(anf_arg2002547) {
return $Hanf_arg7622548(anf_arg2002547,anf_arg1972522,_plus10);
}};
$e25372538.stack[R.EXN_STACKHEIGHT++] = $ss25412542;
}
if(R.isPyretException($e25372538)) {
$e25372538.pyretStack.push(L[313]);
}
throw $e25372538;
}
var $ret25432544 = $Hanf_arg7622548($z25392540,anf_arg1972522,_plus10);
++R.GAS;
return $ret25432544;
};
var $Hanf_arg7622548 = function(anf_arg2002547,anf_arg1972522,_plus10) {
var $z25512552 = D;
var $f25572558 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg1972522,anf_arg2002547):R.ffi.throwNonFunApp(L[313],_plus10,[anf_arg1972522,anf_arg2002547]);
};
try {
if(--R.GAS > 0) {
$z25512552 = $f25572558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25572558,
"from":L[313]});
}
} catch($e25492550) {
if(R.isCont($e25492550)) {
var $ss25532554 = {"from":L[313],
"go":function(anf_arg2012559) {
return $Hanf_arg7612560(anf_arg2012559,_plus10);
}};
$e25492550.stack[R.EXN_STACKHEIGHT++] = $ss25532554;
}
if(R.isPyretException($e25492550)) {
$e25492550.pyretStack.push(L[313]);
}
throw $e25492550;
}
var $ret25552556 = $Hanf_arg7612560($z25512552,_plus10);
++R.GAS;
return $ret25552556;
};
var $Hanf_arg7612560 = function(anf_arg2012559,_plus10) {
var $z25632564 = D;
var $f25692570 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg2012559,(")")):R.ffi.throwNonFunApp(L[313],_plus10,[anf_arg2012559,(")")]);
};
try {
if(--R.GAS > 0) {
$z25632564 = $f25692570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25692570,
"from":L[313]});
}
} catch($e25612562) {
if(R.isCont($e25612562)) {
var $ss25652566 = {"from":L[313],
"go":function(anf_arg2022571) {
return $Hanf_arg7602572(anf_arg2022571,_plus10);
}};
$e25612562.stack[R.EXN_STACKHEIGHT++] = $ss25652566;
}
if(R.isPyretException($e25612562)) {
$e25612562.pyretStack.push(L[313]);
}
throw $e25612562;
}
var $ret25672568 = $Hanf_arg7602572($z25632564,_plus10);
++R.GAS;
return $ret25672568;
};
var $Hanf_arg7602572 = function(anf_arg2022571,_plus10) {
var $z25752576 = D;
var $f25812582 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("("),anf_arg2022571):R.ffi.throwNonFunApp(L[313],_plus10,[("("),anf_arg2022571]);
};
try {
if(--R.GAS > 0) {
$z25752576 = $f25812582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25812582,
"from":L[313]});
}
} catch($e25732574) {
if(R.isCont($e25732574)) {
var $ss25772578 = {"from":L[313],
"go":function(anf_arg2032583) {
return $Hanf_arg7592584(anf_arg2032583,_plus10);
}};
$e25732574.stack[R.EXN_STACKHEIGHT++] = $ss25772578;
}
if(R.isPyretException($e25732574)) {
$e25732574.pyretStack.push(L[313]);
}
throw $e25732574;
}
var $ret25792580 = $Hanf_arg7592584($z25752576,_plus10);
++R.GAS;
return $ret25792580;
};
var $Hanf_arg7592584 = function(anf_arg2032583,_plus10) {
var $z25872588 = D;
var $f25932594 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("split-result"),anf_arg2032583):R.ffi.throwNonFunApp(L[313],_plus10,[("split-result"),anf_arg2032583]);
};
try {
if(--R.GAS > 0) {
$z25872588 = $f25932594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25932594,
"from":L[313]});
}
} catch($e25852586) {
if(R.isCont($e25852586)) {
var $ss25892590 = {"from":L[313],
"go":function(ann_DASH_check_DASH_temp1912595) {
return $Hann_DASH_check_DASH_temp7582596(ann_DASH_check_DASH_temp1912595);
}};
$e25852586.stack[R.EXN_STACKHEIGHT++] = $ss25892590;
}
if(R.isPyretException($e25852586)) {
$e25852586.pyretStack.push(L[313]);
}
throw $e25852586;
}
var $ret25912592 = $Hann_DASH_check_DASH_temp7582596($z25872588);
++R.GAS;
return $ret25912592;
};
var $Hann_DASH_check_DASH_temp7582596 = function(ann_DASH_check_DASH_temp1912595) {
return ann_DASH_check_DASH_temp1912595;
};
var $Hcont_tail_arg7562597 = function(cont_tail_arg1882598,if_helper1782599) {
if(--R.GAS > 0) {
$z26002601 = R.isFunction(if_helper1782599)?if_helper1782599.app(cont_tail_arg1882598):R.ffi.throwNonFunApp(L[313],if_helper1782599,[cont_tail_arg1882598]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper1782599)?if_helper1782599.app(cont_tail_arg1882598):R.ffi.throwNonFunApp(L[313],if_helper1782599,[cont_tail_arg1882598]);
},
"from":L[313]});
}
++R.GAS;
return $z26002601;
};
var $Hcont_tail_arg7572602 = function(cont_tail_arg1832603,if_helper1782599) {
if(--R.GAS > 0) {
$z26042605 = R.isFunction(if_helper1782599)?if_helper1782599.app(cont_tail_arg1832603):R.ffi.throwNonFunApp(L[313],if_helper1782599,[cont_tail_arg1832603]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper1782599)?if_helper1782599.app(cont_tail_arg1832603):R.ffi.throwNonFunApp(L[313],if_helper1782599,[cont_tail_arg1832603]);
},
"from":L[313]});
}
++R.GAS;
return $z26042605;
};
var $Hann_DASH_check_DASH_temp7552606 = function(ann_DASH_check_DASH_temp1642607) {
return ann_DASH_check_DASH_temp1642607;
};
var $Hanf_bracket7542608 = function(anf_bracket1682609,args1362610,sets1523) {
var anf_fun1692623 = G(anf_bracket1682609,"difference",L[316]);
var anf_fun1702621 = G(sets1523,"list-to-tree-set",L[315]);
var $z26132614 = D;
var $f26192620 = function(_) {
return R.isFunction(anf_fun1702621)?anf_fun1702621.app(args1362610):R.ffi.throwNonFunApp(L[314],anf_fun1702621,[args1362610]);
};
try {
if(--R.GAS > 0) {
$z26132614 = $f26192620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26192620,
"from":L[314]});
}
} catch($e26112612) {
if(R.isCont($e26112612)) {
var $ss26152616 = {"from":L[314],
"go":function(anf_arg1712622) {
return $Hanf_arg7532624(anf_arg1712622,anf_fun1692623);
}};
$e26112612.stack[R.EXN_STACKHEIGHT++] = $ss26152616;
}
if(R.isPyretException($e26112612)) {
$e26112612.pyretStack.push(L[314]);
}
throw $e26112612;
}
var $ret26172618 = $Hanf_arg7532624($z26132614,anf_fun1692623);
++R.GAS;
return $ret26172618;
};
var $Hanf_arg7532624 = function(anf_arg1712622,anf_fun1692623) {
var $z26272628 = D;
var $f26332634 = function(_) {
return R.isFunction(anf_fun1692623)?anf_fun1692623.app(anf_arg1712622):R.ffi.throwNonFunApp(L[317],anf_fun1692623,[anf_arg1712622]);
};
try {
if(--R.GAS > 0) {
$z26272628 = $f26332634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26332634,
"from":L[317]});
}
} catch($e26252626) {
if(R.isCont($e26252626)) {
var $ss26292630 = {"from":L[317],
"go":function(ann_DASH_check_DASH_temp1662635) {
return $Hann_DASH_check_DASH_temp7522636(ann_DASH_check_DASH_temp1662635);
}};
$e26252626.stack[R.EXN_STACKHEIGHT++] = $ss26292630;
}
if(R.isPyretException($e26252626)) {
$e26252626.pyretStack.push(L[317]);
}
throw $e26252626;
}
var $ret26312632 = $Hann_DASH_check_DASH_temp7522636($z26272628);
++R.GAS;
return $ret26312632;
};
var $Hann_DASH_check_DASH_temp7522636 = function(ann_DASH_check_DASH_temp1662635) {
return ann_DASH_check_DASH_temp1662635;
};
var $Hanf_arg7512637 = function(anf_arg1302638,INDENT7547,PP518,anf_fun1262639,anf_fun1272640,self1312641,_plus10) {
var anf_arg1312655 = G(PP518,"lparen",L[324]);
var anf_arg1322656 = G(PP518,"commabreak",L[323]);
var anf_arg1332657 = G(PP518,"rparen",L[322]);
var anf_bracket1342673 = G(self1312641,"args",L[321]);
var anf_fun1352652 = G(anf_bracket1342673,"map",L[320]);
var anf_arg1382653 = R.makeFunction(function(recv_DASH_252659) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[319],1,arguments);
}
var anf_fun1372670 = G(recv_DASH_252659,"tosource",L[319]);
var $z26622663 = D;
var $f26682669 = function(_) {
return R.isFunction(anf_fun1372670)?anf_fun1372670.app():R.ffi.throwNonFunApp(L[319],anf_fun1372670,[]);
};
try {
if(--R.GAS > 0) {
$z26622663 = $f26682669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26682669,
"from":L[319]});
}
} catch($e26602661) {
if(R.isCont($e26602661)) {
var $ss26642665 = {"from":L[319],
"go":function(ann_DASH_check_DASH_temp1362671) {
return $Hann_DASH_check_DASH_temp7372672(ann_DASH_check_DASH_temp1362671);
}};
$e26602661.stack[R.EXN_STACKHEIGHT++] = $ss26642665;
}
if(R.isPyretException($e26602661)) {
$e26602661.pyretStack.push(L[319]);
}
throw $e26602661;
}
var $ret26662667 = $Hann_DASH_check_DASH_temp7372672($z26622663);
++R.GAS;
return $ret26662667;
});
var $z26442645 = D;
var $f26502651 = function(_) {
return R.isFunction(anf_fun1352652)?anf_fun1352652.app(anf_arg1382653):R.ffi.throwNonFunApp(L[318],anf_fun1352652,[anf_arg1382653]);
};
try {
if(--R.GAS > 0) {
$z26442645 = $f26502651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26502651,
"from":L[318]});
}
} catch($e26422643) {
if(R.isCont($e26422643)) {
var $ss26462647 = {"from":L[318],
"go":function(anf_arg1392654) {
return $Hanf_arg7502658(anf_arg1392654,INDENT7547,PP518,anf_arg1302638,anf_arg1312655,anf_arg1322656,anf_arg1332657,anf_fun1262639,anf_fun1272640,self1312641,_plus10);
}};
$e26422643.stack[R.EXN_STACKHEIGHT++] = $ss26462647;
}
if(R.isPyretException($e26422643)) {
$e26422643.pyretStack.push(L[318]);
}
throw $e26422643;
}
var $ret26482649 = $Hanf_arg7502658($z26442645,INDENT7547,PP518,anf_arg1302638,anf_arg1312655,anf_arg1322656,anf_arg1332657,anf_fun1262639,anf_fun1272640,self1312641,_plus10);
++R.GAS;
return $ret26482649;
};
var $Hanf_arg7502658 = function(anf_arg1392654,INDENT7547,PP518,anf_arg1302638,anf_arg1312655,anf_arg1322656,anf_arg1332657,anf_fun1262639,anf_fun1272640,self1312641,_plus10) {
var $z26762677 = D;
var $f26822683 = function(_) {
return R.isFunction(anf_fun1272640)?anf_fun1272640.app(INDENT7547,(0),anf_arg1302638,anf_arg1312655,anf_arg1322656,anf_arg1332657,anf_arg1392654):R.ffi.throwNonFunApp(L[325],anf_fun1272640,[INDENT7547,(0),anf_arg1302638,anf_arg1312655,anf_arg1322656,anf_arg1332657,anf_arg1392654]);
};
try {
if(--R.GAS > 0) {
$z26762677 = $f26822683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26822683,
"from":L[325]});
}
} catch($e26742675) {
if(R.isCont($e26742675)) {
var $ss26782679 = {"from":L[325],
"go":function(anf_arg1402684) {
return $Hanf_arg7492685(anf_arg1402684,INDENT7547,PP518,anf_fun1262639,self1312641,_plus10);
}};
$e26742675.stack[R.EXN_STACKHEIGHT++] = $ss26782679;
}
if(R.isPyretException($e26742675)) {
$e26742675.pyretStack.push(L[325]);
}
throw $e26742675;
}
var $ret26802681 = $Hanf_arg7492685($z26762677,INDENT7547,PP518,anf_fun1262639,self1312641,_plus10);
++R.GAS;
return $ret26802681;
};
var $Hanf_arg7492685 = function(anf_arg1402684,INDENT7547,PP518,anf_fun1262639,self1312641,_plus10) {
var $z26882689 = D;
var $f26942695 = function(_) {
return R.isFunction(anf_fun1262639)?anf_fun1262639.app(INDENT7547,anf_arg1402684):R.ffi.throwNonFunApp(L[326],anf_fun1262639,[INDENT7547,anf_arg1402684]);
};
try {
if(--R.GAS > 0) {
$z26882689 = $f26942695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26942695,
"from":L[326]});
}
} catch($e26862687) {
if(R.isCont($e26862687)) {
var $ss26902691 = {"from":L[326],
"go":function(arg_DASH_list1322696) {
return $Harg_DASH_list7482697(arg_DASH_list1322696,INDENT7547,PP518,self1312641,_plus10);
}};
$e26862687.stack[R.EXN_STACKHEIGHT++] = $ss26902691;
}
if(R.isPyretException($e26862687)) {
$e26862687.pyretStack.push(L[326]);
}
throw $e26862687;
}
var $ret26922693 = $Harg_DASH_list7482697($z26882689,INDENT7547,PP518,self1312641,_plus10);
++R.GAS;
return $ret26922693;
};
var $Harg_DASH_list7482697 = function(arg_DASH_list1322696,INDENT7547,PP518,self1312641,_plus10) {
var anf_fun1412710 = G(PP518,"group",L[331]);
var anf_fun1422711 = G(PP518,"str",L[330]);
var anf_bracket1432713 = G(self1312641,"name",L[329]);
var anf_fun1442708 = G(anf_bracket1432713,"tostring",L[328]);
var $z27002701 = D;
var $f27062707 = function(_) {
return R.isFunction(anf_fun1442708)?anf_fun1442708.app():R.ffi.throwNonFunApp(L[327],anf_fun1442708,[]);
};
try {
if(--R.GAS > 0) {
$z27002701 = $f27062707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27062707,
"from":L[327]});
}
} catch($e26982699) {
if(R.isCont($e26982699)) {
var $ss27022703 = {"from":L[327],
"go":function(anf_arg1452709) {
return $Hanf_arg7472712(anf_arg1452709,INDENT7547,PP518,anf_fun1412710,anf_fun1422711,arg_DASH_list1322696,self1312641,_plus10);
}};
$e26982699.stack[R.EXN_STACKHEIGHT++] = $ss27022703;
}
if(R.isPyretException($e26982699)) {
$e26982699.pyretStack.push(L[327]);
}
throw $e26982699;
}
var $ret27042705 = $Hanf_arg7472712($z27002701,INDENT7547,PP518,anf_fun1412710,anf_fun1422711,arg_DASH_list1322696,self1312641,_plus10);
++R.GAS;
return $ret27042705;
};
var $Hanf_arg7472712 = function(anf_arg1452709,INDENT7547,PP518,anf_fun1412710,anf_fun1422711,arg_DASH_list1322696,self1312641,_plus10) {
var $z27162717 = D;
var $f27222723 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("helper "),anf_arg1452709):R.ffi.throwNonFunApp(L[332],_plus10,[("helper "),anf_arg1452709]);
};
try {
if(--R.GAS > 0) {
$z27162717 = $f27222723();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27222723,
"from":L[332]});
}
} catch($e27142715) {
if(R.isCont($e27142715)) {
var $ss27182719 = {"from":L[332],
"go":function(anf_arg1462724) {
return $Hanf_arg7462725(anf_arg1462724,INDENT7547,PP518,anf_fun1412710,anf_fun1422711,arg_DASH_list1322696,self1312641,_plus10);
}};
$e27142715.stack[R.EXN_STACKHEIGHT++] = $ss27182719;
}
if(R.isPyretException($e27142715)) {
$e27142715.pyretStack.push(L[332]);
}
throw $e27142715;
}
var $ret27202721 = $Hanf_arg7462725($z27162717,INDENT7547,PP518,anf_fun1412710,anf_fun1422711,arg_DASH_list1322696,self1312641,_plus10);
++R.GAS;
return $ret27202721;
};
var $Hanf_arg7462725 = function(anf_arg1462724,INDENT7547,PP518,anf_fun1412710,anf_fun1422711,arg_DASH_list1322696,self1312641,_plus10) {
var $z27282729 = D;
var $f27342735 = function(_) {
return R.isFunction(anf_fun1422711)?anf_fun1422711.app(anf_arg1462724):R.ffi.throwNonFunApp(L[333],anf_fun1422711,[anf_arg1462724]);
};
try {
if(--R.GAS > 0) {
$z27282729 = $f27342735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27342735,
"from":L[333]});
}
} catch($e27262727) {
if(R.isCont($e27262727)) {
var $ss27302731 = {"from":L[333],
"go":function(anf_arg1472736) {
return $Hanf_arg7452737(anf_arg1472736,INDENT7547,PP518,anf_fun1412710,arg_DASH_list1322696,self1312641,_plus10);
}};
$e27262727.stack[R.EXN_STACKHEIGHT++] = $ss27302731;
}
if(R.isPyretException($e27262727)) {
$e27262727.pyretStack.push(L[333]);
}
throw $e27262727;
}
var $ret27322733 = $Hanf_arg7452737($z27282729,INDENT7547,PP518,anf_fun1412710,arg_DASH_list1322696,self1312641,_plus10);
++R.GAS;
return $ret27322733;
};
var $Hanf_arg7452737 = function(anf_arg1472736,INDENT7547,PP518,anf_fun1412710,arg_DASH_list1322696,self1312641,_plus10) {
var $z27402741 = D;
var $f27462747 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg1472736,arg_DASH_list1322696):R.ffi.throwNonFunApp(L[334],_plus10,[anf_arg1472736,arg_DASH_list1322696]);
};
try {
if(--R.GAS > 0) {
$z27402741 = $f27462747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27462747,
"from":L[334]});
}
} catch($e27382739) {
if(R.isCont($e27382739)) {
var $ss27422743 = {"from":L[334],
"go":function(anf_arg1482748) {
return $Hanf_arg7442749(anf_arg1482748,INDENT7547,PP518,anf_fun1412710,self1312641,_plus10);
}};
$e27382739.stack[R.EXN_STACKHEIGHT++] = $ss27422743;
}
if(R.isPyretException($e27382739)) {
$e27382739.pyretStack.push(L[334]);
}
throw $e27382739;
}
var $ret27442745 = $Hanf_arg7442749($z27402741,INDENT7547,PP518,anf_fun1412710,self1312641,_plus10);
++R.GAS;
return $ret27442745;
};
var $Hanf_arg7442749 = function(anf_arg1482748,INDENT7547,PP518,anf_fun1412710,self1312641,_plus10) {
var anf_fun1492760 = G(PP518,"str",L[336]);
var $z27522753 = D;
var $f27582759 = function(_) {
return R.isFunction(anf_fun1492760)?anf_fun1492760.app((" {")):R.ffi.throwNonFunApp(L[335],anf_fun1492760,[(" {")]);
};
try {
if(--R.GAS > 0) {
$z27522753 = $f27582759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27582759,
"from":L[335]});
}
} catch($e27502751) {
if(R.isCont($e27502751)) {
var $ss27542755 = {"from":L[335],
"go":function(anf_arg1502761) {
return $Hanf_arg7432762(anf_arg1502761,INDENT7547,PP518,anf_arg1482748,anf_fun1412710,self1312641,_plus10);
}};
$e27502751.stack[R.EXN_STACKHEIGHT++] = $ss27542755;
}
if(R.isPyretException($e27502751)) {
$e27502751.pyretStack.push(L[335]);
}
throw $e27502751;
}
var $ret27562757 = $Hanf_arg7432762($z27522753,INDENT7547,PP518,anf_arg1482748,anf_fun1412710,self1312641,_plus10);
++R.GAS;
return $ret27562757;
};
var $Hanf_arg7432762 = function(anf_arg1502761,INDENT7547,PP518,anf_arg1482748,anf_fun1412710,self1312641,_plus10) {
var $z27652766 = D;
var $f27712772 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg1482748,anf_arg1502761):R.ffi.throwNonFunApp(L[334],_plus10,[anf_arg1482748,anf_arg1502761]);
};
try {
if(--R.GAS > 0) {
$z27652766 = $f27712772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27712772,
"from":L[334]});
}
} catch($e27632764) {
if(R.isCont($e27632764)) {
var $ss27672768 = {"from":L[334],
"go":function(anf_arg1512773) {
return $Hanf_arg7422774(anf_arg1512773,INDENT7547,PP518,anf_fun1412710,self1312641);
}};
$e27632764.stack[R.EXN_STACKHEIGHT++] = $ss27672768;
}
if(R.isPyretException($e27632764)) {
$e27632764.pyretStack.push(L[334]);
}
throw $e27632764;
}
var $ret27692770 = $Hanf_arg7422774($z27652766,INDENT7547,PP518,anf_fun1412710,self1312641);
++R.GAS;
return $ret27692770;
};
var $Hanf_arg7422774 = function(anf_arg1512773,INDENT7547,PP518,anf_fun1412710,self1312641) {
var $z27772778 = D;
var $f27832784 = function(_) {
return R.isFunction(anf_fun1412710)?anf_fun1412710.app(anf_arg1512773):R.ffi.throwNonFunApp(L[337],anf_fun1412710,[anf_arg1512773]);
};
try {
if(--R.GAS > 0) {
$z27772778 = $f27832784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27832784,
"from":L[337]});
}
} catch($e27752776) {
if(R.isCont($e27752776)) {
var $ss27792780 = {"from":L[337],
"go":function(header1332785) {
return $Hheader7412786(header1332785,INDENT7547,PP518,self1312641);
}};
$e27752776.stack[R.EXN_STACKHEIGHT++] = $ss27792780;
}
if(R.isPyretException($e27752776)) {
$e27752776.pyretStack.push(L[337]);
}
throw $e27752776;
}
var $ret27812782 = $Hheader7412786($z27772778,INDENT7547,PP518,self1312641);
++R.GAS;
return $ret27812782;
};
var $Hheader7412786 = function(header1332785,INDENT7547,PP518,self1312641) {
var anf_fun1522799 = G(PP518,"surround",L[341]);
var anf_bracket1532801 = G(self1312641,"body",L[340]);
var anf_fun1542797 = G(anf_bracket1532801,"tosource",L[339]);
var $z27892790 = D;
var $f27952796 = function(_) {
return R.isFunction(anf_fun1542797)?anf_fun1542797.app():R.ffi.throwNonFunApp(L[338],anf_fun1542797,[]);
};
try {
if(--R.GAS > 0) {
$z27892790 = $f27952796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27952796,
"from":L[338]});
}
} catch($e27872788) {
if(R.isCont($e27872788)) {
var $ss27912792 = {"from":L[338],
"go":function(anf_arg1552798) {
return $Hanf_arg7402800(anf_arg1552798,INDENT7547,PP518,anf_fun1522799,header1332785);
}};
$e27872788.stack[R.EXN_STACKHEIGHT++] = $ss27912792;
}
if(R.isPyretException($e27872788)) {
$e27872788.pyretStack.push(L[338]);
}
throw $e27872788;
}
var $ret27932794 = $Hanf_arg7402800($z27892790,INDENT7547,PP518,anf_fun1522799,header1332785);
++R.GAS;
return $ret27932794;
};
var $Hanf_arg7402800 = function(anf_arg1552798,INDENT7547,PP518,anf_fun1522799,header1332785) {
var anf_fun1562812 = G(PP518,"str",L[343]);
var $z28042805 = D;
var $f28102811 = function(_) {
return R.isFunction(anf_fun1562812)?anf_fun1562812.app(("}")):R.ffi.throwNonFunApp(L[342],anf_fun1562812,[("}")]);
};
try {
if(--R.GAS > 0) {
$z28042805 = $f28102811();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28102811,
"from":L[342]});
}
} catch($e28022803) {
if(R.isCont($e28022803)) {
var $ss28062807 = {"from":L[342],
"go":function(anf_arg1572813) {
return $Hanf_arg7392814(anf_arg1572813,INDENT7547,anf_arg1552798,anf_fun1522799,header1332785);
}};
$e28022803.stack[R.EXN_STACKHEIGHT++] = $ss28062807;
}
if(R.isPyretException($e28022803)) {
$e28022803.pyretStack.push(L[342]);
}
throw $e28022803;
}
var $ret28082809 = $Hanf_arg7392814($z28042805,INDENT7547,anf_arg1552798,anf_fun1522799,header1332785);
++R.GAS;
return $ret28082809;
};
var $Hanf_arg7392814 = function(anf_arg1572813,INDENT7547,anf_arg1552798,anf_fun1522799,header1332785) {
var $z28172818 = D;
var $f28232824 = function(_) {
return R.isFunction(anf_fun1522799)?anf_fun1522799.app(INDENT7547,(1),header1332785,anf_arg1552798,anf_arg1572813):R.ffi.throwNonFunApp(L[344],anf_fun1522799,[INDENT7547,(1),header1332785,anf_arg1552798,anf_arg1572813]);
};
try {
if(--R.GAS > 0) {
$z28172818 = $f28232824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28232824,
"from":L[344]});
}
} catch($e28152816) {
if(R.isCont($e28152816)) {
var $ss28192820 = {"from":L[344],
"go":function(ann_DASH_check_DASH_temp1252825) {
return $Hann_DASH_check_DASH_temp7382826(ann_DASH_check_DASH_temp1252825);
}};
$e28152816.stack[R.EXN_STACKHEIGHT++] = $ss28192820;
}
if(R.isPyretException($e28152816)) {
$e28152816.pyretStack.push(L[344]);
}
throw $e28152816;
}
var $ret28212822 = $Hann_DASH_check_DASH_temp7382826($z28172818);
++R.GAS;
return $ret28212822;
};
var $Hann_DASH_check_DASH_temp7382826 = function(ann_DASH_check_DASH_temp1252825) {
return ann_DASH_check_DASH_temp1252825;
};
var $Hann_DASH_check_DASH_temp7372672 = function(ann_DASH_check_DASH_temp1362671) {
return ann_DASH_check_DASH_temp1362671;
};
var $Hanf_arg7362827 = function(anf_arg1132828,self232829,_plus10,torepr14) {
var anf_arg1142840 = G(self232829,"args",L[345]);
var $z28322833 = D;
var $f28382839 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1142840):R.ffi.throwNonFunApp(L[345],torepr14,[anf_arg1142840]);
};
try {
if(--R.GAS > 0) {
$z28322833 = $f28382839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28382839,
"from":L[345]});
}
} catch($e28302831) {
if(R.isCont($e28302831)) {
var $ss28342835 = {"from":L[345],
"go":function(anf_arg1152841) {
return $Hanf_arg7352842(anf_arg1152841,anf_arg1132828,self232829,_plus10,torepr14);
}};
$e28302831.stack[R.EXN_STACKHEIGHT++] = $ss28342835;
}
if(R.isPyretException($e28302831)) {
$e28302831.pyretStack.push(L[345]);
}
throw $e28302831;
}
var $ret28362837 = $Hanf_arg7352842($z28322833,anf_arg1132828,self232829,_plus10,torepr14);
++R.GAS;
return $ret28362837;
};
var $Hanf_arg7352842 = function(anf_arg1152841,anf_arg1132828,self232829,_plus10,torepr14) {
var $z28452846 = D;
var $f28512852 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg1152841):R.ffi.throwNonFunApp(L[345],_plus10,[(", "),anf_arg1152841]);
};
try {
if(--R.GAS > 0) {
$z28452846 = $f28512852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28512852,
"from":L[345]});
}
} catch($e28432844) {
if(R.isCont($e28432844)) {
var $ss28472848 = {"from":L[345],
"go":function(anf_arg1162853) {
return $Hanf_arg7342854(anf_arg1162853,anf_arg1132828,self232829,_plus10,torepr14);
}};
$e28432844.stack[R.EXN_STACKHEIGHT++] = $ss28472848;
}
if(R.isPyretException($e28432844)) {
$e28432844.pyretStack.push(L[345]);
}
throw $e28432844;
}
var $ret28492850 = $Hanf_arg7342854($z28452846,anf_arg1132828,self232829,_plus10,torepr14);
++R.GAS;
return $ret28492850;
};
var $Hanf_arg7342854 = function(anf_arg1162853,anf_arg1132828,self232829,_plus10,torepr14) {
var $z28572858 = D;
var $f28632864 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg1132828,anf_arg1162853):R.ffi.throwNonFunApp(L[345],_plus10,[anf_arg1132828,anf_arg1162853]);
};
try {
if(--R.GAS > 0) {
$z28572858 = $f28632864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28632864,
"from":L[345]});
}
} catch($e28552856) {
if(R.isCont($e28552856)) {
var $ss28592860 = {"from":L[345],
"go":function(anf_arg1172865) {
return $Hanf_arg7332866(anf_arg1172865,self232829,_plus10,torepr14);
}};
$e28552856.stack[R.EXN_STACKHEIGHT++] = $ss28592860;
}
if(R.isPyretException($e28552856)) {
$e28552856.pyretStack.push(L[345]);
}
throw $e28552856;
}
var $ret28612862 = $Hanf_arg7332866($z28572858,self232829,_plus10,torepr14);
++R.GAS;
return $ret28612862;
};
var $Hanf_arg7332866 = function(anf_arg1172865,self232829,_plus10,torepr14) {
var anf_arg1182877 = G(self232829,"body",L[345]);
var $z28692870 = D;
var $f28752876 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1182877):R.ffi.throwNonFunApp(L[345],torepr14,[anf_arg1182877]);
};
try {
if(--R.GAS > 0) {
$z28692870 = $f28752876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28752876,
"from":L[345]});
}
} catch($e28672868) {
if(R.isCont($e28672868)) {
var $ss28712872 = {"from":L[345],
"go":function(anf_arg1192878) {
return $Hanf_arg7322879(anf_arg1192878,anf_arg1172865,_plus10);
}};
$e28672868.stack[R.EXN_STACKHEIGHT++] = $ss28712872;
}
if(R.isPyretException($e28672868)) {
$e28672868.pyretStack.push(L[345]);
}
throw $e28672868;
}
var $ret28732874 = $Hanf_arg7322879($z28692870,anf_arg1172865,_plus10);
++R.GAS;
return $ret28732874;
};
var $Hanf_arg7322879 = function(anf_arg1192878,anf_arg1172865,_plus10) {
var $z28822883 = D;
var $f28882889 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg1192878):R.ffi.throwNonFunApp(L[345],_plus10,[(", "),anf_arg1192878]);
};
try {
if(--R.GAS > 0) {
$z28822883 = $f28882889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28882889,
"from":L[345]});
}
} catch($e28802881) {
if(R.isCont($e28802881)) {
var $ss28842885 = {"from":L[345],
"go":function(anf_arg1202890) {
return $Hanf_arg7312891(anf_arg1202890,anf_arg1172865,_plus10);
}};
$e28802881.stack[R.EXN_STACKHEIGHT++] = $ss28842885;
}
if(R.isPyretException($e28802881)) {
$e28802881.pyretStack.push(L[345]);
}
throw $e28802881;
}
var $ret28862887 = $Hanf_arg7312891($z28822883,anf_arg1172865,_plus10);
++R.GAS;
return $ret28862887;
};
var $Hanf_arg7312891 = function(anf_arg1202890,anf_arg1172865,_plus10) {
var $z28942895 = D;
var $f29002901 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg1172865,anf_arg1202890):R.ffi.throwNonFunApp(L[345],_plus10,[anf_arg1172865,anf_arg1202890]);
};
try {
if(--R.GAS > 0) {
$z28942895 = $f29002901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29002901,
"from":L[345]});
}
} catch($e28922893) {
if(R.isCont($e28922893)) {
var $ss28962897 = {"from":L[345],
"go":function(anf_arg1212902) {
return $Hanf_arg7302903(anf_arg1212902,_plus10);
}};
$e28922893.stack[R.EXN_STACKHEIGHT++] = $ss28962897;
}
if(R.isPyretException($e28922893)) {
$e28922893.pyretStack.push(L[345]);
}
throw $e28922893;
}
var $ret28982899 = $Hanf_arg7302903($z28942895,_plus10);
++R.GAS;
return $ret28982899;
};
var $Hanf_arg7302903 = function(anf_arg1212902,_plus10) {
var $z29062907 = D;
var $f29122913 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg1212902,(")")):R.ffi.throwNonFunApp(L[345],_plus10,[anf_arg1212902,(")")]);
};
try {
if(--R.GAS > 0) {
$z29062907 = $f29122913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29122913,
"from":L[345]});
}
} catch($e29042905) {
if(R.isCont($e29042905)) {
var $ss29082909 = {"from":L[345],
"go":function(anf_arg1222914) {
return $Hanf_arg7292915(anf_arg1222914,_plus10);
}};
$e29042905.stack[R.EXN_STACKHEIGHT++] = $ss29082909;
}
if(R.isPyretException($e29042905)) {
$e29042905.pyretStack.push(L[345]);
}
throw $e29042905;
}
var $ret29102911 = $Hanf_arg7292915($z29062907,_plus10);
++R.GAS;
return $ret29102911;
};
var $Hanf_arg7292915 = function(anf_arg1222914,_plus10) {
var $z29182919 = D;
var $f29242925 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("("),anf_arg1222914):R.ffi.throwNonFunApp(L[345],_plus10,[("("),anf_arg1222914]);
};
try {
if(--R.GAS > 0) {
$z29182919 = $f29242925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29242925,
"from":L[345]});
}
} catch($e29162917) {
if(R.isCont($e29162917)) {
var $ss29202921 = {"from":L[345],
"go":function(anf_arg1232926) {
return $Hanf_arg7282927(anf_arg1232926,_plus10);
}};
$e29162917.stack[R.EXN_STACKHEIGHT++] = $ss29202921;
}
if(R.isPyretException($e29162917)) {
$e29162917.pyretStack.push(L[345]);
}
throw $e29162917;
}
var $ret29222923 = $Hanf_arg7282927($z29182919,_plus10);
++R.GAS;
return $ret29222923;
};
var $Hanf_arg7282927 = function(anf_arg1232926,_plus10) {
var $z29302931 = D;
var $f29362937 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("helper"),anf_arg1232926):R.ffi.throwNonFunApp(L[345],_plus10,[("helper"),anf_arg1232926]);
};
try {
if(--R.GAS > 0) {
$z29302931 = $f29362937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29362937,
"from":L[345]});
}
} catch($e29282929) {
if(R.isCont($e29282929)) {
var $ss29322933 = {"from":L[345],
"go":function(ann_DASH_check_DASH_temp1112938) {
return $Hann_DASH_check_DASH_temp7272939(ann_DASH_check_DASH_temp1112938);
}};
$e29282929.stack[R.EXN_STACKHEIGHT++] = $ss29322933;
}
if(R.isPyretException($e29282929)) {
$e29282929.pyretStack.push(L[345]);
}
throw $e29282929;
}
var $ret29342935 = $Hann_DASH_check_DASH_temp7272939($z29302931);
++R.GAS;
return $ret29342935;
};
var $Hann_DASH_check_DASH_temp7272939 = function(ann_DASH_check_DASH_temp1112938) {
return ann_DASH_check_DASH_temp1112938;
};
var $Hcont_tail_arg7252940 = function(cont_tail_arg1082941,if_helper982942) {
if(--R.GAS > 0) {
$z29432944 = R.isFunction(if_helper982942)?if_helper982942.app(cont_tail_arg1082941):R.ffi.throwNonFunApp(L[345],if_helper982942,[cont_tail_arg1082941]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper982942)?if_helper982942.app(cont_tail_arg1082941):R.ffi.throwNonFunApp(L[345],if_helper982942,[cont_tail_arg1082941]);
},
"from":L[345]});
}
++R.GAS;
return $z29432944;
};
var $Hcont_tail_arg7262945 = function(cont_tail_arg1032946,if_helper982942) {
if(--R.GAS > 0) {
$z29472948 = R.isFunction(if_helper982942)?if_helper982942.app(cont_tail_arg1032946):R.ffi.throwNonFunApp(L[345],if_helper982942,[cont_tail_arg1032946]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper982942)?if_helper982942.app(cont_tail_arg1032946):R.ffi.throwNonFunApp(L[345],if_helper982942,[cont_tail_arg1032946]);
},
"from":L[345]});
}
++R.GAS;
return $z29472948;
};
var $Hanf_arg7242949 = function(anf_arg832950,concat_DASH_append8455,f1242951,self1232952) {
var anf_bracket842966 = G(self1232952,"right",L[348]);
var anf_fun852963 = G(anf_bracket842966,"map",L[347]);
var $z29552956 = D;
var $f29612962 = function(_) {
return R.isFunction(anf_fun852963)?anf_fun852963.app(f1242951):R.ffi.throwNonFunApp(L[346],anf_fun852963,[f1242951]);
};
try {
if(--R.GAS > 0) {
$z29552956 = $f29612962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29612962,
"from":L[346]});
}
} catch($e29532954) {
if(R.isCont($e29532954)) {
var $ss29572958 = {"from":L[346],
"go":function(anf_arg862964) {
return $Hanf_arg7232965(anf_arg862964,anf_arg832950,concat_DASH_append8455);
}};
$e29532954.stack[R.EXN_STACKHEIGHT++] = $ss29572958;
}
if(R.isPyretException($e29532954)) {
$e29532954.pyretStack.push(L[346]);
}
throw $e29532954;
}
var $ret29592960 = $Hanf_arg7232965($z29552956,anf_arg832950,concat_DASH_append8455);
++R.GAS;
return $ret29592960;
};
var $Hanf_arg7232965 = function(anf_arg862964,anf_arg832950,concat_DASH_append8455) {
var $z29692970 = D;
var $f29752976 = function(_) {
return R.isFunction(concat_DASH_append8455.$var === D?U(L[349],"concat-append"):concat_DASH_append8455.$var)?concat_DASH_append8455.$var === D?U(L[349],"concat-append"):concat_DASH_append8455.$var.app(anf_arg832950,anf_arg862964):R.ffi.throwNonFunApp(L[350],concat_DASH_append8455.$var === D?U(L[349],"concat-append"):concat_DASH_append8455.$var,[anf_arg832950,anf_arg862964]);
};
try {
if(--R.GAS > 0) {
$z29692970 = $f29752976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29752976,
"from":L[350]});
}
} catch($e29672968) {
if(R.isCont($e29672968)) {
var $ss29712972 = {"from":L[350],
"go":function(ann_DASH_check_DASH_temp802977) {
return $Hann_DASH_check_DASH_temp7222978(ann_DASH_check_DASH_temp802977);
}};
$e29672968.stack[R.EXN_STACKHEIGHT++] = $ss29712972;
}
if(R.isPyretException($e29672968)) {
$e29672968.pyretStack.push(L[350]);
}
throw $e29672968;
}
var $ret29732974 = $Hann_DASH_check_DASH_temp7222978($z29692970);
++R.GAS;
return $ret29732974;
};
var $Hann_DASH_check_DASH_temp7222978 = function(ann_DASH_check_DASH_temp802977) {
return ann_DASH_check_DASH_temp802977;
};
var $Hanf_arg7212979 = function(anf_arg782980,anf_fun752981) {
var $z29842985 = D;
var $f29902991 = function(_) {
return R.isFunction(anf_fun752981)?anf_fun752981.app(anf_arg782980):R.ffi.throwNonFunApp(L[351],anf_fun752981,[anf_arg782980]);
};
try {
if(--R.GAS > 0) {
$z29842985 = $f29902991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29902991,
"from":L[351]});
}
} catch($e29822983) {
if(R.isCont($e29822983)) {
var $ss29862987 = {"from":L[351],
"go":function(ann_DASH_check_DASH_temp732992) {
return $Hann_DASH_check_DASH_temp7202993(ann_DASH_check_DASH_temp732992);
}};
$e29822983.stack[R.EXN_STACKHEIGHT++] = $ss29862987;
}
if(R.isPyretException($e29822983)) {
$e29822983.pyretStack.push(L[351]);
}
throw $e29822983;
}
var $ret29882989 = $Hann_DASH_check_DASH_temp7202993($z29842985);
++R.GAS;
return $ret29882989;
};
var $Hann_DASH_check_DASH_temp7202993 = function(ann_DASH_check_DASH_temp732992) {
return ann_DASH_check_DASH_temp732992;
};
var $Hanf_arg7192994 = function(anf_arg652995,self172996,_plus10,torepr14) {
var anf_arg663007 = G(self172996,"right",L[352]);
var $z29993000 = D;
var $f30053006 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg663007):R.ffi.throwNonFunApp(L[352],torepr14,[anf_arg663007]);
};
try {
if(--R.GAS > 0) {
$z29993000 = $f30053006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30053006,
"from":L[352]});
}
} catch($e29972998) {
if(R.isCont($e29972998)) {
var $ss30013002 = {"from":L[352],
"go":function(anf_arg673008) {
return $Hanf_arg7183009(anf_arg673008,anf_arg652995,_plus10);
}};
$e29972998.stack[R.EXN_STACKHEIGHT++] = $ss30013002;
}
if(R.isPyretException($e29972998)) {
$e29972998.pyretStack.push(L[352]);
}
throw $e29972998;
}
var $ret30033004 = $Hanf_arg7183009($z29993000,anf_arg652995,_plus10);
++R.GAS;
return $ret30033004;
};
var $Hanf_arg7183009 = function(anf_arg673008,anf_arg652995,_plus10) {
var $z30123013 = D;
var $f30183019 = function(_) {
return R.isFunction(_plus10)?_plus10.app((", "),anf_arg673008):R.ffi.throwNonFunApp(L[352],_plus10,[(", "),anf_arg673008]);
};
try {
if(--R.GAS > 0) {
$z30123013 = $f30183019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30183019,
"from":L[352]});
}
} catch($e30103011) {
if(R.isCont($e30103011)) {
var $ss30143015 = {"from":L[352],
"go":function(anf_arg683020) {
return $Hanf_arg7173021(anf_arg683020,anf_arg652995,_plus10);
}};
$e30103011.stack[R.EXN_STACKHEIGHT++] = $ss30143015;
}
if(R.isPyretException($e30103011)) {
$e30103011.pyretStack.push(L[352]);
}
throw $e30103011;
}
var $ret30163017 = $Hanf_arg7173021($z30123013,anf_arg652995,_plus10);
++R.GAS;
return $ret30163017;
};
var $Hanf_arg7173021 = function(anf_arg683020,anf_arg652995,_plus10) {
var $z30243025 = D;
var $f30303031 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg652995,anf_arg683020):R.ffi.throwNonFunApp(L[352],_plus10,[anf_arg652995,anf_arg683020]);
};
try {
if(--R.GAS > 0) {
$z30243025 = $f30303031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30303031,
"from":L[352]});
}
} catch($e30223023) {
if(R.isCont($e30223023)) {
var $ss30263027 = {"from":L[352],
"go":function(anf_arg693032) {
return $Hanf_arg7163033(anf_arg693032,_plus10);
}};
$e30223023.stack[R.EXN_STACKHEIGHT++] = $ss30263027;
}
if(R.isPyretException($e30223023)) {
$e30223023.pyretStack.push(L[352]);
}
throw $e30223023;
}
var $ret30283029 = $Hanf_arg7163033($z30243025,_plus10);
++R.GAS;
return $ret30283029;
};
var $Hanf_arg7163033 = function(anf_arg693032,_plus10) {
var $z30363037 = D;
var $f30423043 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg693032,(")")):R.ffi.throwNonFunApp(L[352],_plus10,[anf_arg693032,(")")]);
};
try {
if(--R.GAS > 0) {
$z30363037 = $f30423043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30423043,
"from":L[352]});
}
} catch($e30343035) {
if(R.isCont($e30343035)) {
var $ss30383039 = {"from":L[352],
"go":function(anf_arg703044) {
return $Hanf_arg7153045(anf_arg703044,_plus10);
}};
$e30343035.stack[R.EXN_STACKHEIGHT++] = $ss30383039;
}
if(R.isPyretException($e30343035)) {
$e30343035.pyretStack.push(L[352]);
}
throw $e30343035;
}
var $ret30403041 = $Hanf_arg7153045($z30363037,_plus10);
++R.GAS;
return $ret30403041;
};
var $Hanf_arg7153045 = function(anf_arg703044,_plus10) {
var $z30483049 = D;
var $f30543055 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("("),anf_arg703044):R.ffi.throwNonFunApp(L[352],_plus10,[("("),anf_arg703044]);
};
try {
if(--R.GAS > 0) {
$z30483049 = $f30543055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30543055,
"from":L[352]});
}
} catch($e30463047) {
if(R.isCont($e30463047)) {
var $ss30503051 = {"from":L[352],
"go":function(anf_arg713056) {
return $Hanf_arg7143057(anf_arg713056,_plus10);
}};
$e30463047.stack[R.EXN_STACKHEIGHT++] = $ss30503051;
}
if(R.isPyretException($e30463047)) {
$e30463047.pyretStack.push(L[352]);
}
throw $e30463047;
}
var $ret30523053 = $Hanf_arg7143057($z30483049,_plus10);
++R.GAS;
return $ret30523053;
};
var $Hanf_arg7143057 = function(anf_arg713056,_plus10) {
var $z30603061 = D;
var $f30663067 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("concat-append"),anf_arg713056):R.ffi.throwNonFunApp(L[352],_plus10,[("concat-append"),anf_arg713056]);
};
try {
if(--R.GAS > 0) {
$z30603061 = $f30663067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30663067,
"from":L[352]});
}
} catch($e30583059) {
if(R.isCont($e30583059)) {
var $ss30623063 = {"from":L[352],
"go":function(ann_DASH_check_DASH_temp633068) {
return $Hann_DASH_check_DASH_temp7133069(ann_DASH_check_DASH_temp633068);
}};
$e30583059.stack[R.EXN_STACKHEIGHT++] = $ss30623063;
}
if(R.isPyretException($e30583059)) {
$e30583059.pyretStack.push(L[352]);
}
throw $e30583059;
}
var $ret30643065 = $Hann_DASH_check_DASH_temp7133069($z30603061);
++R.GAS;
return $ret30643065;
};
var $Hann_DASH_check_DASH_temp7133069 = function(ann_DASH_check_DASH_temp633068) {
return ann_DASH_check_DASH_temp633068;
};
var $Hcont_tail_arg7113070 = function(cont_tail_arg603071,if_helper513072) {
if(--R.GAS > 0) {
$z30733074 = R.isFunction(if_helper513072)?if_helper513072.app(cont_tail_arg603071):R.ffi.throwNonFunApp(L[352],if_helper513072,[cont_tail_arg603071]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper513072)?if_helper513072.app(cont_tail_arg603071):R.ffi.throwNonFunApp(L[352],if_helper513072,[cont_tail_arg603071]);
},
"from":L[352]});
}
++R.GAS;
return $z30733074;
};
var $Hcont_tail_arg7123075 = function(cont_tail_arg563076,if_helper513072) {
if(--R.GAS > 0) {
$z30773078 = R.isFunction(if_helper513072)?if_helper513072.app(cont_tail_arg563076):R.ffi.throwNonFunApp(L[352],if_helper513072,[cont_tail_arg563076]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper513072)?if_helper513072.app(cont_tail_arg563076):R.ffi.throwNonFunApp(L[352],if_helper513072,[cont_tail_arg563076]);
},
"from":L[352]});
}
++R.GAS;
return $z30773078;
};
var $Hanf_arg7103079 = function(anf_arg483080,concat_DASH_singleton8257) {
var $z30833084 = D;
var $f30893090 = function(_) {
return R.isFunction(concat_DASH_singleton8257.$var === D?U(L[353],"concat-singleton"):concat_DASH_singleton8257.$var)?concat_DASH_singleton8257.$var === D?U(L[353],"concat-singleton"):concat_DASH_singleton8257.$var.app(anf_arg483080):R.ffi.throwNonFunApp(L[354],concat_DASH_singleton8257.$var === D?U(L[353],"concat-singleton"):concat_DASH_singleton8257.$var,[anf_arg483080]);
};
try {
if(--R.GAS > 0) {
$z30833084 = $f30893090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30893090,
"from":L[354]});
}
} catch($e30813082) {
if(R.isCont($e30813082)) {
var $ss30853086 = {"from":L[354],
"go":function(ann_DASH_check_DASH_temp463091) {
return $Hann_DASH_check_DASH_temp7093092(ann_DASH_check_DASH_temp463091);
}};
$e30813082.stack[R.EXN_STACKHEIGHT++] = $ss30853086;
}
if(R.isPyretException($e30813082)) {
$e30813082.pyretStack.push(L[354]);
}
throw $e30813082;
}
var $ret30873088 = $Hann_DASH_check_DASH_temp7093092($z30833084);
++R.GAS;
return $ret30873088;
};
var $Hann_DASH_check_DASH_temp7093092 = function(ann_DASH_check_DASH_temp463091) {
return ann_DASH_check_DASH_temp463091;
};
var $Hann_DASH_check_DASH_temp7083093 = function(ann_DASH_check_DASH_temp433094) {
return ann_DASH_check_DASH_temp433094;
};
var $Hanf_arg7073095 = function(anf_arg393096,_plus10) {
var $z30993100 = D;
var $f31053106 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg393096,(")")):R.ffi.throwNonFunApp(L[355],_plus10,[anf_arg393096,(")")]);
};
try {
if(--R.GAS > 0) {
$z30993100 = $f31053106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31053106,
"from":L[355]});
}
} catch($e30973098) {
if(R.isCont($e30973098)) {
var $ss31013102 = {"from":L[355],
"go":function(anf_arg403107) {
return $Hanf_arg7063108(anf_arg403107,_plus10);
}};
$e30973098.stack[R.EXN_STACKHEIGHT++] = $ss31013102;
}
if(R.isPyretException($e30973098)) {
$e30973098.pyretStack.push(L[355]);
}
throw $e30973098;
}
var $ret31033104 = $Hanf_arg7063108($z30993100,_plus10);
++R.GAS;
return $ret31033104;
};
var $Hanf_arg7063108 = function(anf_arg403107,_plus10) {
var $z31113112 = D;
var $f31173118 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("("),anf_arg403107):R.ffi.throwNonFunApp(L[355],_plus10,[("("),anf_arg403107]);
};
try {
if(--R.GAS > 0) {
$z31113112 = $f31173118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31173118,
"from":L[355]});
}
} catch($e31093110) {
if(R.isCont($e31093110)) {
var $ss31133114 = {"from":L[355],
"go":function(anf_arg413119) {
return $Hanf_arg7053120(anf_arg413119,_plus10);
}};
$e31093110.stack[R.EXN_STACKHEIGHT++] = $ss31133114;
}
if(R.isPyretException($e31093110)) {
$e31093110.pyretStack.push(L[355]);
}
throw $e31093110;
}
var $ret31153116 = $Hanf_arg7053120($z31113112,_plus10);
++R.GAS;
return $ret31153116;
};
var $Hanf_arg7053120 = function(anf_arg413119,_plus10) {
var $z31233124 = D;
var $f31293130 = function(_) {
return R.isFunction(_plus10)?_plus10.app(("concat-singleton"),anf_arg413119):R.ffi.throwNonFunApp(L[355],_plus10,[("concat-singleton"),anf_arg413119]);
};
try {
if(--R.GAS > 0) {
$z31233124 = $f31293130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31293130,
"from":L[355]});
}
} catch($e31213122) {
if(R.isCont($e31213122)) {
var $ss31253126 = {"from":L[355],
"go":function(ann_DASH_check_DASH_temp373131) {
return $Hann_DASH_check_DASH_temp7043132(ann_DASH_check_DASH_temp373131);
}};
$e31213122.stack[R.EXN_STACKHEIGHT++] = $ss31253126;
}
if(R.isPyretException($e31213122)) {
$e31213122.pyretStack.push(L[355]);
}
throw $e31213122;
}
var $ret31273128 = $Hann_DASH_check_DASH_temp7043132($z31233124);
++R.GAS;
return $ret31273128;
};
var $Hann_DASH_check_DASH_temp7043132 = function(ann_DASH_check_DASH_temp373131) {
return ann_DASH_check_DASH_temp373131;
};
var $Hcont_tail_arg7023133 = function(cont_tail_arg343134,if_helper263135) {
if(--R.GAS > 0) {
$z31363137 = R.isFunction(if_helper263135)?if_helper263135.app(cont_tail_arg343134):R.ffi.throwNonFunApp(L[355],if_helper263135,[cont_tail_arg343134]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper263135)?if_helper263135.app(cont_tail_arg343134):R.ffi.throwNonFunApp(L[355],if_helper263135,[cont_tail_arg343134]);
},
"from":L[355]});
}
++R.GAS;
return $z31363137;
};
var $Hcont_tail_arg7033138 = function(cont_tail_arg313139,if_helper263135) {
if(--R.GAS > 0) {
$z31403141 = R.isFunction(if_helper263135)?if_helper263135.app(cont_tail_arg313139):R.ffi.throwNonFunApp(L[355],if_helper263135,[cont_tail_arg313139]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper263135)?if_helper263135.app(cont_tail_arg313139):R.ffi.throwNonFunApp(L[355],if_helper263135,[cont_tail_arg313139]);
},
"from":L[355]});
}
++R.GAS;
return $z31403141;
};
var $Hcont_tail_arg7003142 = function(cont_tail_arg163143,if_helper93144) {
if(--R.GAS > 0) {
$z31453146 = R.isFunction(if_helper93144)?if_helper93144.app(cont_tail_arg163143):R.ffi.throwNonFunApp(L[356],if_helper93144,[cont_tail_arg163143]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper93144)?if_helper93144.app(cont_tail_arg163143):R.ffi.throwNonFunApp(L[356],if_helper93144,[cont_tail_arg163143]);
},
"from":L[356]});
}
++R.GAS;
return $z31453146;
};
var $Hcont_tail_arg7013147 = function(cont_tail_arg143148,if_helper93144) {
if(--R.GAS > 0) {
$z31493150 = R.isFunction(if_helper93144)?if_helper93144.app(cont_tail_arg143148):R.ffi.throwNonFunApp(L[356],if_helper93144,[cont_tail_arg143148]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper93144)?if_helper93144.app(cont_tail_arg143148):R.ffi.throwNonFunApp(L[356],if_helper93144,[cont_tail_arg143148]);
},
"from":L[356]});
}
++R.GAS;
return $z31493150;
};
var $Hanf_arg6993151 = function(anf_arg63152,anf_fun43153) {
var $z31563157 = D;
var $f31623163 = function(_) {
return R.isFunction(anf_fun43153)?anf_fun43153.app(anf_arg63152):R.ffi.throwNonFunApp(L[357],anf_fun43153,[anf_arg63152]);
};
try {
if(--R.GAS > 0) {
$z31563157 = $f31623163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31623163,
"from":L[357]});
}
} catch($e31543155) {
if(R.isCont($e31543155)) {
var $ss31583159 = {"from":L[357],
"go":function(ann_DASH_check_DASH_temp33164) {
return $Hann_DASH_check_DASH_temp6983165(ann_DASH_check_DASH_temp33164);
}};
$e31543155.stack[R.EXN_STACKHEIGHT++] = $ss31583159;
}
if(R.isPyretException($e31543155)) {
$e31543155.pyretStack.push(L[357]);
}
throw $e31543155;
}
var $ret31603161 = $Hann_DASH_check_DASH_temp6983165($z31563157);
++R.GAS;
return $ret31603161;
};
var $Hann_DASH_check_DASH_temp6983165 = function(ann_DASH_check_DASH_temp33164) {
return ann_DASH_check_DASH_temp33164;
};
var $Hann_DASH_check_DASH_temp6973166 = function(ann_DASH_check_DASH_temp13167) {
return ann_DASH_check_DASH_temp13167;
};
return R.loadModulesNew(NAMESPACE,[$N11633,$A31734,$PP51835,$arrays71936,$lists92037,$option112138,$error132239,$sets152340],function($N11633,$A31734,$PP51835,$arrays71936,$lists92037,$option112138,$error132239,$sets152340) {
var N116 = R.getField($N11633,"values");
var A317 = R.getField($A31734,"values");
var PP518 = R.getField($PP51835,"values");
var arrays719 = R.getField($arrays71936,"values");
var lists920 = R.getField($lists92037,"values");
var option1121 = R.getField($option112138,"values");
var error1322 = R.getField($error132239,"values");
var sets1523 = R.getField($sets152340,"values");
var N224 = R.getField($N11633,"types");
var A425 = R.getField($A31734,"types");
var PP626 = R.getField($PP51835,"types");
var arrays827 = R.getField($arrays71936,"types");
var lists1028 = R.getField($lists92037,"types");
var option1229 = R.getField($option112138,"types");
var error1430 = R.getField($error132239,"types");
var sets1631 = R.getField($sets152340,"types");
return R.safeCall(function() {
var List173168 = R.getDotAnn(L[358],"lists",lists1028,"List");
var Option183169 = R.getDotAnn(L[358],"option",option1229,"Option");
var Array193170 = R.getDotAnn(L[358],"arrays",arrays827,"Array");
var Set202180 = R.getDotAnn(L[358],"sets",sets1631,"Set");
var array214111 = G(arrays719,"array",L[358]);
var build_DASH_array224110 = G(arrays719,"build-array",L[358]);
var array_DASH_from_DASH_list234109 = G(arrays719,"array-from-list",L[358]);
var is_DASH_array244108 = G(arrays719,"is-array",L[358]);
var list2572 = G(lists920,"list",L[358]);
var is_DASH_empty264107 = G(lists920,"is-empty",L[358]);
var is_DASH_link274106 = G(lists920,"is-link",L[358]);
var empty284105 = G(lists920,"empty",L[358]);
var link291907 = G(lists920,"link",L[358]);
var range304104 = G(lists920,"range",L[358]);
var repeat314103 = G(lists920,"repeat",L[358]);
var filter324102 = G(lists920,"filter",L[358]);
var partition334101 = G(lists920,"partition",L[358]);
var split_DASH_at344100 = G(lists920,"split-at",L[358]);
var any354099 = G(lists920,"any",L[358]);
var find364098 = G(lists920,"find",L[358]);
var map374097 = G(lists920,"map",L[358]);
var map2384096 = G(lists920,"map2",L[358]);
var map3394095 = G(lists920,"map3",L[358]);
var map4404094 = G(lists920,"map4",L[358]);
var map_n414093 = G(lists920,"map_n",L[358]);
var map2_n424092 = G(lists920,"map2_n",L[358]);
var map3_n434091 = G(lists920,"map3_n",L[358]);
var map4_n444090 = G(lists920,"map4_n",L[358]);
var each454089 = G(lists920,"each",L[358]);
var each2464088 = G(lists920,"each2",L[358]);
var each3474087 = G(lists920,"each3",L[358]);
var each4484086 = G(lists920,"each4",L[358]);
var each_n494085 = G(lists920,"each_n",L[358]);
var each2_n504084 = G(lists920,"each2_n",L[358]);
var each3_n514083 = G(lists920,"each3_n",L[358]);
var each4_n524082 = G(lists920,"each4_n",L[358]);
var fold533527 = G(lists920,"fold",L[358]);
var fold2544081 = G(lists920,"fold2",L[358]);
var fold3554080 = G(lists920,"fold3",L[358]);
var fold4564079 = G(lists920,"fold4",L[358]);
var index574078 = G(lists920,"index",L[358]);
var Option584077 = G(option1121,"Option",L[358]);
var is_DASH_none594076 = G(option1121,"is-none",L[358]);
var is_DASH_some604075 = G(option1121,"is-some",L[358]);
var none614074 = G(option1121,"none",L[358]);
var some624073 = G(option1121,"some",L[358]);
var set634072 = G(sets1523,"set",L[358]);
var tree_DASH_set644071 = G(sets1523,"tree-set",L[358]);
var list_DASH_set654070 = G(sets1523,"list-set",L[358]);
var ConcatListT2673171 = R.namedBrander("ConcatList");
var ConcatList6643 = R.makeBranderAnn(ConcatListT2673171,"ConcatList");
var HelperT3693172 = R.namedBrander("Helper");
var Helper6845 = R.makeBranderAnn(HelperT3693172,"Helper");
var SplitResultT4713173 = R.namedBrander("SplitResult");
var SplitResult7048 = R.makeBranderAnn(SplitResultT4713173,"SplitResult");
var SplitResultIntT5733174 = R.namedBrander("SplitResultInt");
var SplitResultInt7250 = R.makeBranderAnn(SplitResultIntT5733174,"SplitResultInt");
var names7473 = G(A317,"global-names",L[478]);
var INDENT7547 = (2);
var ConcatList6763175 = {"$var":D,
"$name":"ConcatList6"};
var ConcatList7744 = {"$var":D,
"$name":"ConcatList"};
var is_DASH_ConcatList7861 = {"$var":D,
"$name":"is-ConcatList"};
var is_DASH_concat_DASH_empty7966 = {"$var":D,
"$name":"is-concat-empty"};
var concat_DASH_empty8056 = {"$var":D,
"$name":"concat-empty"};
var is_DASH_concat_DASH_singleton8167 = {"$var":D,
"$name":"is-concat-singleton"};
var concat_DASH_singleton8257 = {"$var":D,
"$name":"concat-singleton"};
var is_DASH_concat_DASH_append8365 = {"$var":D,
"$name":"is-concat-append"};
var concat_DASH_append8455 = {"$var":D,
"$name":"concat-append"};
var Helper7853185 = {"$var":D,
"$name":"Helper7"};
var Helper8646 = {"$var":D,
"$name":"Helper"};
var is_DASH_Helper8762 = {"$var":D,
"$name":"is-Helper"};
var is_DASH_helper8868 = {"$var":D,
"$name":"is-helper"};
var helper8960 = {"$var":D,
"$name":"helper"};
var freevars_DASH_helper9058 = {"$var":D,
"$name":"freevars-helper"};
var SplitResult8913192 = {"$var":D,
"$name":"SplitResult8"};
var SplitResult9249 = {"$var":D,
"$name":"SplitResult"};
var is_DASH_SplitResult9363 = {"$var":D,
"$name":"is-SplitResult"};
var is_DASH_split_DASH_result9471 = {"$var":D,
"$name":"is-split-result"};
var split_DASH_result9578 = {"$var":D,
"$name":"split-result"};
var freevars_DASH_split_DASH_result9659 = {"$var":D,
"$name":"freevars-split-result"};
var SplitResultInt9973199 = {"$var":D,
"$name":"SplitResultInt9"};
var SplitResultInt9851 = {"$var":D,
"$name":"SplitResultInt"};
var is_DASH_SplitResultInt9964 = {"$var":D,
"$name":"is-SplitResultInt"};
var is_DASH_split_DASH_result_DASH_int_DASH_e10069 = {"$var":D,
"$name":"is-split-result-int-e"};
var split_DASH_result_DASH_int_DASH_e10176 = {"$var":D,
"$name":"split-result-int-e"};
var is_DASH_split_DASH_result_DASH_int_DASH_l10270 = {"$var":D,
"$name":"is-split-result-int-l"};
var split_DASH_result_DASH_int_DASH_l10377 = {"$var":D,
"$name":"split-result-int-l"};
var unions10479 = {"$var":D,
"$name":"unions"};
var ast_DASH_split10554 = {"$var":D,
"$name":"ast-split"};
var ast_DASH_split_DASH_expr10652 = {"$var":D,
"$name":"ast-split-expr"};
var ast_DASH_split_DASH_lettable10753 = {"$var":D,
"$name":"ast-split-lettable"};
var param10874 = {"$var":D,
"$name":"param"};
var anf_shared23834 = R.makeMethod(function(self1254068) {
return function(other1264069) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[476],1,arguments);
}
return R.checkAnnArgs([ConcatList6643],[other1264069],[L[477]],function() {
var $z40604061 = D;
var $f40664067 = function(_) {
return R.isFunction(concat_DASH_append8455.$var === D?U(L[475],"concat-append"):concat_DASH_append8455.$var)?concat_DASH_append8455.$var === D?U(L[475],"concat-append"):concat_DASH_append8455.$var.app(self1254068,other1264069):R.ffi.throwNonFunApp(L[476],concat_DASH_append8455.$var === D?U(L[475],"concat-append"):concat_DASH_append8455.$var,[self1254068,other1264069]);
};
try {
if(--R.GAS > 0) {
$z40604061 = $f40664067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40664067,
"from":L[476]});
}
} catch($e40584059) {
if(R.isCont($e40584059)) {
var $ss40624063 = {"from":L[476],
"go":function(ann_DASH_check_DASH_temp13167) {
return $Hann_DASH_check_DASH_temp6973166(ann_DASH_check_DASH_temp13167);
}};
$e40584059.stack[R.EXN_STACKHEIGHT++] = $ss40624063;
}
if(R.isPyretException($e40584059)) {
$e40584059.pyretStack.push(L[476]);
}
throw $e40584059;
}
var $ret40644065 = $Hann_DASH_check_DASH_temp6973166($z40604061);
++R.GAS;
return $ret40644065;
});
};
},{"length":2});
var anf_shared73835 = R.makeMethod(function(self1274057) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[357],0,arguments);
}
var anf_fun43153 = G(self1274057,"to-list-acc",L[474]);
var anf_fun54056 = G(list2572,"make",L[473]);
var $z40484049 = D;
var $f40544055 = function(_) {
return R.isFunction(anf_fun54056)?anf_fun54056.app([]):R.ffi.throwNonFunApp(L[473],anf_fun54056,[[]]);
};
try {
if(--R.GAS > 0) {
$z40484049 = $f40544055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40544055,
"from":L[473]});
}
} catch($e40464047) {
if(R.isCont($e40464047)) {
var $ss40504051 = {"from":L[473],
"go":function(anf_arg63152) {
return $Hanf_arg6993151(anf_arg63152,anf_fun43153);
}};
$e40464047.stack[R.EXN_STACKHEIGHT++] = $ss40504051;
}
if(R.isPyretException($e40464047)) {
$e40464047.pyretStack.push(L[473]);
}
throw $e40464047;
}
var $ret40524053 = $Hanf_arg6993151($z40484049,anf_fun43153);
++R.GAS;
return $ret40524053;
};
},{"length":1});
var anf_singleton_variant_member183841 = R.makeMethod(function(self24045) {
return function(cases_DASH_funs34026,else_DASH_clause44037) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[356],2,arguments);
}
var if_DASH_64038 = R.hasField(cases_DASH_funs34026,("concat-empty"));
var if_helper93144 = R.makeFunction(function(if_helper_arg104043) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[356],1,arguments);
}
var ann_DASH_check_DASH_temp84044 = if_helper_arg104043;
return ann_DASH_check_DASH_temp84044;
});
var anf_if134042 = R.isBoolean(if_DASH_64038);
if(R.isPyretTrue(anf_if134042)) {
if(R.isPyretTrue(if_DASH_64038)) {
var call_DASH_concat_DASH_empty14025 = G(cases_DASH_funs34026,"concat-empty",L[356]);
var $z40174018 = D;
var $f40234024 = function(_) {
return R.isFunction(call_DASH_concat_DASH_empty14025)?call_DASH_concat_DASH_empty14025.app():R.ffi.throwNonFunApp(L[356],call_DASH_concat_DASH_empty14025,[]);
};
try {
if(--R.GAS > 0) {
$z40174018 = $f40234024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40234024,
"from":L[356]});
}
} catch($e40154016) {
if(R.isCont($e40154016)) {
var $ss40194020 = {"from":L[356],
"go":function(cont_tail_arg163143) {
return $Hcont_tail_arg7003142(cont_tail_arg163143,if_helper93144);
}};
$e40154016.stack[R.EXN_STACKHEIGHT++] = $ss40194020;
}
if(R.isPyretException($e40154016)) {
$e40154016.pyretStack.push(L[356]);
}
throw $e40154016;
}
var $ret40214022 = $Hcont_tail_arg7003142($z40174018,if_helper93144);
++R.GAS;
return $ret40214022;
} else {
var $z40294030 = D;
var $f40354036 = function(_) {
return R.isFunction(else_DASH_clause44037)?else_DASH_clause44037.app():R.ffi.throwNonFunApp(L[356],else_DASH_clause44037,[]);
};
try {
if(--R.GAS > 0) {
$z40294030 = $f40354036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40354036,
"from":L[356]});
}
} catch($e40274028) {
if(R.isCont($e40274028)) {
var $ss40314032 = {"from":L[356],
"go":function(cont_tail_arg143148) {
return $Hcont_tail_arg7013147(cont_tail_arg143148,if_helper93144);
}};
$e40274028.stack[R.EXN_STACKHEIGHT++] = $ss40314032;
}
if(R.isPyretException($e40274028)) {
$e40274028.pyretStack.push(L[356]);
}
throw $e40274028;
}
var $ret40334034 = $Hcont_tail_arg7013147($z40294030,if_helper93144);
++R.GAS;
return $ret40334034;
}
} else {
var cont_tail_arg114041 = R.throwNonBooleanCondition(L[356],("if"),if_DASH_64038);
if(--R.GAS > 0) {
$z40394040 = R.isFunction(if_helper93144)?if_helper93144.app(cont_tail_arg114041):R.ffi.throwNonFunApp(L[356],if_helper93144,[cont_tail_arg114041]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper93144)?if_helper93144.app(cont_tail_arg114041):R.ffi.throwNonFunApp(L[356],if_helper93144,[cont_tail_arg114041]);
},
"from":L[356]});
}
++R.GAS;
return $z40394040;
}
};
},{"length":3});
var anf_singleton_variant_member203842 = R.makeMethod(function(self54014) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[356],0,arguments);
}
var ann_DASH_check_DASH_temp194013 = ("concat-empty");
return ann_DASH_check_DASH_temp194013;
};
},{"length":1});
var anf_singleton_variant_member223843 = R.makeMethod(function(self1104012) {
return function(rest1114011) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[472],1,arguments);
}
var ann_DASH_check_DASH_temp214010 = rest1114011;
return ann_DASH_check_DASH_temp214010;
};
},{"length":2});
var anf_singleton_variant_member243844 = R.makeMethod(function(self1124008) {
return function(f1134009) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[471],1,arguments);
}
var ann_DASH_check_DASH_temp234007 = self1124008;
return ann_DASH_check_DASH_temp234007;
};
},{"length":2});
var anf_variant_member363850 = R.makeMethod(function(self83987) {
return function(cases_DASH_funs93988,else_DASH_clause103999) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[355],2,arguments);
}
var if_DASH_124000 = R.hasField(cases_DASH_funs93988,("concat-singleton"));
var if_helper263135 = R.makeFunction(function(if_helper_arg274005) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[355],1,arguments);
}
var ann_DASH_check_DASH_temp254006 = if_helper_arg274005;
return ann_DASH_check_DASH_temp254006;
});
var anf_if304004 = R.isBoolean(if_DASH_124000);
if(R.isPyretTrue(anf_if304004)) {
if(R.isPyretTrue(if_DASH_124000)) {
var call_DASH_concat_DASH_singleton73985 = G(cases_DASH_funs93988,"concat-singleton",L[355]);
var anf_arg333986 = G(self83987,"element",L[470]);
var $z39773978 = D;
var $f39833984 = function(_) {
return R.isFunction(call_DASH_concat_DASH_singleton73985)?call_DASH_concat_DASH_singleton73985.app(anf_arg333986):R.ffi.throwNonFunApp(L[355],call_DASH_concat_DASH_singleton73985,[anf_arg333986]);
};
try {
if(--R.GAS > 0) {
$z39773978 = $f39833984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39833984,
"from":L[355]});
}
} catch($e39753976) {
if(R.isCont($e39753976)) {
var $ss39793980 = {"from":L[355],
"go":function(cont_tail_arg343134) {
return $Hcont_tail_arg7023133(cont_tail_arg343134,if_helper263135);
}};
$e39753976.stack[R.EXN_STACKHEIGHT++] = $ss39793980;
}
if(R.isPyretException($e39753976)) {
$e39753976.pyretStack.push(L[355]);
}
throw $e39753976;
}
var $ret39813982 = $Hcont_tail_arg7023133($z39773978,if_helper263135);
++R.GAS;
return $ret39813982;
} else {
var $z39913992 = D;
var $f39973998 = function(_) {
return R.isFunction(else_DASH_clause103999)?else_DASH_clause103999.app():R.ffi.throwNonFunApp(L[355],else_DASH_clause103999,[]);
};
try {
if(--R.GAS > 0) {
$z39913992 = $f39973998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39973998,
"from":L[355]});
}
} catch($e39893990) {
if(R.isCont($e39893990)) {
var $ss39933994 = {"from":L[355],
"go":function(cont_tail_arg313139) {
return $Hcont_tail_arg7033138(cont_tail_arg313139,if_helper263135);
}};
$e39893990.stack[R.EXN_STACKHEIGHT++] = $ss39933994;
}
if(R.isPyretException($e39893990)) {
$e39893990.pyretStack.push(L[355]);
}
throw $e39893990;
}
var $ret39953996 = $Hcont_tail_arg7033138($z39913992,if_helper263135);
++R.GAS;
return $ret39953996;
}
} else {
var cont_tail_arg284003 = R.throwNonBooleanCondition(L[355],("if"),if_DASH_124000);
if(--R.GAS > 0) {
$z40014002 = R.isFunction(if_helper263135)?if_helper263135.app(cont_tail_arg284003):R.ffi.throwNonFunApp(L[355],if_helper263135,[cont_tail_arg284003]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper263135)?if_helper263135.app(cont_tail_arg284003):R.ffi.throwNonFunApp(L[355],if_helper263135,[cont_tail_arg284003]);
},
"from":L[355]});
}
++R.GAS;
return $z40014002;
}
};
},{"length":3});
var anf_variant_member423851 = R.makeMethod(function(self113974) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[355],0,arguments);
}
var anf_arg383973 = G(self113974,"element",L[355]);
var $z39653966 = D;
var $f39713972 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg383973):R.ffi.throwNonFunApp(L[355],torepr14,[anf_arg383973]);
};
try {
if(--R.GAS > 0) {
$z39653966 = $f39713972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39713972,
"from":L[355]});
}
} catch($e39633964) {
if(R.isCont($e39633964)) {
var $ss39673968 = {"from":L[355],
"go":function(anf_arg393096) {
return $Hanf_arg7073095(anf_arg393096,_plus10);
}};
$e39633964.stack[R.EXN_STACKHEIGHT++] = $ss39673968;
}
if(R.isPyretException($e39633964)) {
$e39633964.pyretStack.push(L[355]);
}
throw $e39633964;
}
var $ret39693970 = $Hanf_arg7073095($z39653966,_plus10);
++R.GAS;
return $ret39693970;
};
},{"length":1});
var anf_variant_member453852 = R.makeMethod(function(self1153962) {
return function(rest1163961) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[468],1,arguments);
}
var anf_arg443960 = G(self1153962,"element",L[469]);
var $z39523953 = D;
var $f39583959 = function(_) {
return R.isFunction(link291907)?link291907.app(anf_arg443960,rest1163961):R.ffi.throwNonFunApp(L[468],link291907,[anf_arg443960,rest1163961]);
};
try {
if(--R.GAS > 0) {
$z39523953 = $f39583959();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39583959,
"from":L[468]});
}
} catch($e39503951) {
if(R.isCont($e39503951)) {
var $ss39543955 = {"from":L[468],
"go":function(ann_DASH_check_DASH_temp433094) {
return $Hann_DASH_check_DASH_temp7083093(ann_DASH_check_DASH_temp433094);
}};
$e39503951.stack[R.EXN_STACKHEIGHT++] = $ss39543955;
}
if(R.isPyretException($e39503951)) {
$e39503951.pyretStack.push(L[468]);
}
throw $e39503951;
}
var $ret39563957 = $Hann_DASH_check_DASH_temp7083093($z39523953);
++R.GAS;
return $ret39563957;
};
},{"length":2});
var anf_variant_member493853 = R.makeMethod(function(self1173949) {
return function(f1183947) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[354],1,arguments);
}
var anf_arg473948 = G(self1173949,"element",L[467]);
var $z39393940 = D;
var $f39453946 = function(_) {
return R.isFunction(f1183947)?f1183947.app(anf_arg473948):R.ffi.throwNonFunApp(L[466],f1183947,[anf_arg473948]);
};
try {
if(--R.GAS > 0) {
$z39393940 = $f39453946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39453946,
"from":L[466]});
}
} catch($e39373938) {
if(R.isCont($e39373938)) {
var $ss39413942 = {"from":L[466],
"go":function(anf_arg483080) {
return $Hanf_arg7103079(anf_arg483080,concat_DASH_singleton8257);
}};
$e39373938.stack[R.EXN_STACKHEIGHT++] = $ss39413942;
}
if(R.isPyretException($e39373938)) {
$e39373938.pyretStack.push(L[466]);
}
throw $e39373938;
}
var $ret39433944 = $Hanf_arg7103079($z39393940,concat_DASH_singleton8257);
++R.GAS;
return $ret39433944;
};
},{"length":2});
var anf_variant_member623860 = R.makeMethod(function(self143917) {
return function(cases_DASH_funs153918,else_DASH_clause163929) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[352],2,arguments);
}
var if_DASH_183930 = R.hasField(cases_DASH_funs153918,("concat-append"));
var if_helper513072 = R.makeFunction(function(if_helper_arg523935) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[352],1,arguments);
}
var ann_DASH_check_DASH_temp503936 = if_helper_arg523935;
return ann_DASH_check_DASH_temp503936;
});
var anf_if553934 = R.isBoolean(if_DASH_183930);
if(R.isPyretTrue(anf_if553934)) {
if(R.isPyretTrue(if_DASH_183930)) {
var call_DASH_concat_DASH_append133914 = G(cases_DASH_funs153918,"concat-append",L[352]);
var anf_arg583915 = G(self143917,"left",L[465]);
var anf_arg593916 = G(self143917,"right",L[464]);
var $z39063907 = D;
var $f39123913 = function(_) {
return R.isFunction(call_DASH_concat_DASH_append133914)?call_DASH_concat_DASH_append133914.app(anf_arg583915,anf_arg593916):R.ffi.throwNonFunApp(L[352],call_DASH_concat_DASH_append133914,[anf_arg583915,anf_arg593916]);
};
try {
if(--R.GAS > 0) {
$z39063907 = $f39123913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39123913,
"from":L[352]});
}
} catch($e39043905) {
if(R.isCont($e39043905)) {
var $ss39083909 = {"from":L[352],
"go":function(cont_tail_arg603071) {
return $Hcont_tail_arg7113070(cont_tail_arg603071,if_helper513072);
}};
$e39043905.stack[R.EXN_STACKHEIGHT++] = $ss39083909;
}
if(R.isPyretException($e39043905)) {
$e39043905.pyretStack.push(L[352]);
}
throw $e39043905;
}
var $ret39103911 = $Hcont_tail_arg7113070($z39063907,if_helper513072);
++R.GAS;
return $ret39103911;
} else {
var $z39213922 = D;
var $f39273928 = function(_) {
return R.isFunction(else_DASH_clause163929)?else_DASH_clause163929.app():R.ffi.throwNonFunApp(L[352],else_DASH_clause163929,[]);
};
try {
if(--R.GAS > 0) {
$z39213922 = $f39273928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39273928,
"from":L[352]});
}
} catch($e39193920) {
if(R.isCont($e39193920)) {
var $ss39233924 = {"from":L[352],
"go":function(cont_tail_arg563076) {
return $Hcont_tail_arg7123075(cont_tail_arg563076,if_helper513072);
}};
$e39193920.stack[R.EXN_STACKHEIGHT++] = $ss39233924;
}
if(R.isPyretException($e39193920)) {
$e39193920.pyretStack.push(L[352]);
}
throw $e39193920;
}
var $ret39253926 = $Hcont_tail_arg7123075($z39213922,if_helper513072);
++R.GAS;
return $ret39253926;
}
} else {
var cont_tail_arg533933 = R.throwNonBooleanCondition(L[352],("if"),if_DASH_183930);
if(--R.GAS > 0) {
$z39313932 = R.isFunction(if_helper513072)?if_helper513072.app(cont_tail_arg533933):R.ffi.throwNonFunApp(L[352],if_helper513072,[cont_tail_arg533933]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper513072)?if_helper513072.app(cont_tail_arg533933):R.ffi.throwNonFunApp(L[352],if_helper513072,[cont_tail_arg533933]);
},
"from":L[352]});
}
++R.GAS;
return $z39313932;
}
};
},{"length":3});
var anf_variant_member723861 = R.makeMethod(function(self172996) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[352],0,arguments);
}
var anf_arg643903 = G(self172996,"left",L[352]);
var $z38953896 = D;
var $f39013902 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg643903):R.ffi.throwNonFunApp(L[352],torepr14,[anf_arg643903]);
};
try {
if(--R.GAS > 0) {
$z38953896 = $f39013902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39013902,
"from":L[352]});
}
} catch($e38933894) {
if(R.isCont($e38933894)) {
var $ss38973898 = {"from":L[352],
"go":function(anf_arg652995) {
return $Hanf_arg7192994(anf_arg652995,self172996,_plus10,torepr14);
}};
$e38933894.stack[R.EXN_STACKHEIGHT++] = $ss38973898;
}
if(R.isPyretException($e38933894)) {
$e38933894.pyretStack.push(L[352]);
}
throw $e38933894;
}
var $ret38993900 = $Hanf_arg7192994($z38953896,self172996,_plus10,torepr14);
++R.GAS;
return $ret38993900;
};
},{"length":1});
var anf_variant_member793862 = R.makeMethod(function(self1213891) {
return function(rest1223889) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[351],1,arguments);
}
return R.checkAnnArgs([List173168],[rest1223889],[L[463]],function() {
var anf_bracket743892 = G(self1213891,"left",L[462]);
var anf_fun752981 = G(anf_bracket743892,"to-list-acc",L[461]);
var anf_bracket763890 = G(self1213891,"right",L[460]);
var anf_fun773888 = G(anf_bracket763890,"to-list-acc",L[459]);
var $z38803881 = D;
var $f38863887 = function(_) {
return R.isFunction(anf_fun773888)?anf_fun773888.app(rest1223889):R.ffi.throwNonFunApp(L[458],anf_fun773888,[rest1223889]);
};
try {
if(--R.GAS > 0) {
$z38803881 = $f38863887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38863887,
"from":L[458]});
}
} catch($e38783879) {
if(R.isCont($e38783879)) {
var $ss38823883 = {"from":L[458],
"go":function(anf_arg782980) {
return $Hanf_arg7212979(anf_arg782980,anf_fun752981);
}};
$e38783879.stack[R.EXN_STACKHEIGHT++] = $ss38823883;
}
if(R.isPyretException($e38783879)) {
$e38783879.pyretStack.push(L[458]);
}
throw $e38783879;
}
var $ret38843885 = $Hanf_arg7212979($z38803881,anf_fun752981);
++R.GAS;
return $ret38843885;
});
};
},{"length":2});
var anf_variant_member873863 = R.makeMethod(function(self1232952) {
return function(f1242951) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[350],1,arguments);
}
var anf_bracket813877 = G(self1232952,"left",L[457]);
var anf_fun823876 = G(anf_bracket813877,"map",L[456]);
var $z38683869 = D;
var $f38743875 = function(_) {
return R.isFunction(anf_fun823876)?anf_fun823876.app(f1242951):R.ffi.throwNonFunApp(L[455],anf_fun823876,[f1242951]);
};
try {
if(--R.GAS > 0) {
$z38683869 = $f38743875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38743875,
"from":L[455]});
}
} catch($e38663867) {
if(R.isCont($e38663867)) {
var $ss38703871 = {"from":L[455],
"go":function(anf_arg832950) {
return $Hanf_arg7242949(anf_arg832950,concat_DASH_append8455,f1242951,self1232952);
}};
$e38663867.stack[R.EXN_STACKHEIGHT++] = $ss38703871;
}
if(R.isPyretException($e38663867)) {
$e38663867.pyretStack.push(L[455]);
}
throw $e38663867;
}
var $ret38723873 = $Hanf_arg7242949($z38683869,concat_DASH_append8455,f1242951,self1232952);
++R.GAS;
return $ret38723873;
};
},{"length":2});
var anf_assign883176 = (function() {
var $concat_DASH_empty_DASH_base38363837 = {"_plus":anf_shared23834,
"to-list":anf_shared73835,
"_match":anf_singleton_variant_member183841,
"_torepr":anf_singleton_variant_member203842,
"to-list-acc":anf_singleton_variant_member223843,
"map":anf_singleton_variant_member243844};
var $concat_DASH_empty_DASH_brands38393840 = {"$brand-concat-empty3838":true};
$concat_DASH_empty_DASH_brands38393840[ConcatListT2673171._brand] = true
var $concat_DASH_singleton_DASH_base38453846 = {"_plus":anf_shared23834,
"to-list":anf_shared73835,
"_match":anf_variant_member363850,
"_torepr":anf_variant_member423851,
"to-list-acc":anf_variant_member453852,
"map":anf_variant_member493853};
var $concat_DASH_singleton_DASH_brands38483849 = {"$brand-concat-singleton3847":true};
$concat_DASH_singleton_DASH_brands38483849[ConcatListT2673171._brand] = true
var $concat_DASH_append_DASH_base38553856 = {"_plus":anf_shared23834,
"to-list":anf_shared73835,
"_match":anf_variant_member623860,
"_torepr":anf_variant_member723861,
"to-list-acc":anf_variant_member793862,
"map":anf_variant_member873863};
var $concat_DASH_append_DASH_brands38583859 = {"$brand-concat-append3857":true};
$concat_DASH_append_DASH_brands38583859[ConcatListT2673171._brand] = true
return R.makeObject({"ConcatList":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[17],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ConcatListT2673171._brand));
}),
"is-concat-empty":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[356],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat-empty3838"));
}),
"concat-empty":R.makeBrandedObject($concat_DASH_empty_DASH_base38363837,$concat_DASH_empty_DASH_brands38393840),
"is-concat-singleton":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[355],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat-singleton3847"));
}),
"concat-singleton":R.makeFunction(function(element1143854) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[451],1,arguments);
}
var dict = R.create($concat_DASH_singleton_DASH_base38453846);
dict["element"] = element1143854
return R.makeBrandedObject(dict,$concat_DASH_singleton_DASH_brands38483849);
}),
"is-concat-append":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[352],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat-append3857"));
}),
"concat-append":R.makeFunction(function(left1193864,right1203865) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[452],2,arguments);
}
return R.checkAnnArgs([ConcatList6643,ConcatList6643],[left1193864,right1203865],[L[453],L[454]],function() {
var dict = R.create($concat_DASH_append_DASH_base38553856);
dict["left"] = left1193864
dict["right"] = right1203865
return R.makeBrandedObject(dict,$concat_DASH_append_DASH_brands38583859);
});
})});
})();
ConcatList6763175.$var = anf_assign883176;
var anf_assign893177 = G(ConcatList6763175.$var,"ConcatList",L[17]);
ConcatList7744.$var = anf_assign893177;
var anf_assign903178 = G(ConcatList6763175.$var,"ConcatList",L[17]);
is_DASH_ConcatList7861.$var = anf_assign903178;
var anf_assign913179 = G(ConcatList6763175.$var,"is-concat-empty",L[356]);
is_DASH_concat_DASH_empty7966.$var = anf_assign913179;
var anf_assign923180 = G(ConcatList6763175.$var,"concat-empty",L[356]);
concat_DASH_empty8056.$var = anf_assign923180;
var anf_assign933181 = G(ConcatList6763175.$var,"is-concat-singleton",L[355]);
is_DASH_concat_DASH_singleton8167.$var = anf_assign933181;
var anf_assign943182 = G(ConcatList6763175.$var,"concat-singleton",L[355]);
concat_DASH_singleton8257.$var = anf_assign943182;
var anf_assign953183 = G(ConcatList6763175.$var,"is-concat-append",L[352]);
is_DASH_concat_DASH_append8365.$var = anf_assign953183;
var anf_assign963184 = G(ConcatList6763175.$var,"concat-append",L[352]);
concat_DASH_append8455.$var = anf_assign963184;
var anf_variant_member1103771 = R.makeMethod(function(self203814) {
return function(cases_DASH_funs213815,else_DASH_clause223826) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[345],2,arguments);
}
var if_DASH_243827 = R.hasField(cases_DASH_funs213815,("helper"));
var if_helper982942 = R.makeFunction(function(if_helper_arg993832) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[345],1,arguments);
}
var ann_DASH_check_DASH_temp973833 = if_helper_arg993832;
return ann_DASH_check_DASH_temp973833;
});
var anf_if1023831 = R.isBoolean(if_DASH_243827);
if(R.isPyretTrue(anf_if1023831)) {
if(R.isPyretTrue(if_DASH_243827)) {
var call_DASH_helper193810 = G(cases_DASH_funs213815,"helper",L[345]);
var anf_arg1053811 = G(self203814,"name",L[450]);
var anf_arg1063812 = G(self203814,"args",L[449]);
var anf_arg1073813 = G(self203814,"body",L[448]);
var $z38023803 = D;
var $f38083809 = function(_) {
return R.isFunction(call_DASH_helper193810)?call_DASH_helper193810.app(anf_arg1053811,anf_arg1063812,anf_arg1073813):R.ffi.throwNonFunApp(L[345],call_DASH_helper193810,[anf_arg1053811,anf_arg1063812,anf_arg1073813]);
};
try {
if(--R.GAS > 0) {
$z38023803 = $f38083809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38083809,
"from":L[345]});
}
} catch($e38003801) {
if(R.isCont($e38003801)) {
var $ss38043805 = {"from":L[345],
"go":function(cont_tail_arg1082941) {
return $Hcont_tail_arg7252940(cont_tail_arg1082941,if_helper982942);
}};
$e38003801.stack[R.EXN_STACKHEIGHT++] = $ss38043805;
}
if(R.isPyretException($e38003801)) {
$e38003801.pyretStack.push(L[345]);
}
throw $e38003801;
}
var $ret38063807 = $Hcont_tail_arg7252940($z38023803,if_helper982942);
++R.GAS;
return $ret38063807;
} else {
var $z38183819 = D;
var $f38243825 = function(_) {
return R.isFunction(else_DASH_clause223826)?else_DASH_clause223826.app():R.ffi.throwNonFunApp(L[345],else_DASH_clause223826,[]);
};
try {
if(--R.GAS > 0) {
$z38183819 = $f38243825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38243825,
"from":L[345]});
}
} catch($e38163817) {
if(R.isCont($e38163817)) {
var $ss38203821 = {"from":L[345],
"go":function(cont_tail_arg1032946) {
return $Hcont_tail_arg7262945(cont_tail_arg1032946,if_helper982942);
}};
$e38163817.stack[R.EXN_STACKHEIGHT++] = $ss38203821;
}
if(R.isPyretException($e38163817)) {
$e38163817.pyretStack.push(L[345]);
}
throw $e38163817;
}
var $ret38223823 = $Hcont_tail_arg7262945($z38183819,if_helper982942);
++R.GAS;
return $ret38223823;
}
} else {
var cont_tail_arg1003830 = R.throwNonBooleanCondition(L[345],("if"),if_DASH_243827);
if(--R.GAS > 0) {
$z38283829 = R.isFunction(if_helper982942)?if_helper982942.app(cont_tail_arg1003830):R.ffi.throwNonFunApp(L[345],if_helper982942,[cont_tail_arg1003830]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper982942)?if_helper982942.app(cont_tail_arg1003830):R.ffi.throwNonFunApp(L[345],if_helper982942,[cont_tail_arg1003830]);
},
"from":L[345]});
}
++R.GAS;
return $z38283829;
}
};
},{"length":3});
var anf_variant_member1243772 = R.makeMethod(function(self232829) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[345],0,arguments);
}
var anf_arg1123799 = G(self232829,"name",L[345]);
var $z37913792 = D;
var $f37973798 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1123799):R.ffi.throwNonFunApp(L[345],torepr14,[anf_arg1123799]);
};
try {
if(--R.GAS > 0) {
$z37913792 = $f37973798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37973798,
"from":L[345]});
}
} catch($e37893790) {
if(R.isCont($e37893790)) {
var $ss37933794 = {"from":L[345],
"go":function(anf_arg1132828) {
return $Hanf_arg7362827(anf_arg1132828,self232829,_plus10,torepr14);
}};
$e37893790.stack[R.EXN_STACKHEIGHT++] = $ss37933794;
}
if(R.isPyretException($e37893790)) {
$e37893790.pyretStack.push(L[345]);
}
throw $e37893790;
}
var $ret37953796 = $Hanf_arg7362827($z37913792,self232829,_plus10,torepr14);
++R.GAS;
return $ret37953796;
};
},{"length":1});
var anf_variant_member1583773 = R.makeMethod(function(self1312641) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[344],0,arguments);
}
var anf_fun1262639 = G(PP518,"nest",L[447]);
var anf_fun1272640 = G(PP518,"surround-separate",L[446]);
var anf_arg1283787 = G(PP518,"lparen",L[445]);
var anf_arg1293788 = G(PP518,"rparen",L[444]);
var $z37793780 = D;
var $f37853786 = function(_) {
return R.isFunction(_plus10)?_plus10.app(anf_arg1283787,anf_arg1293788):R.ffi.throwNonFunApp(L[443],_plus10,[anf_arg1283787,anf_arg1293788]);
};
try {
if(--R.GAS > 0) {
$z37793780 = $f37853786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37853786,
"from":L[443]});
}
} catch($e37773778) {
if(R.isCont($e37773778)) {
var $ss37813782 = {"from":L[443],
"go":function(anf_arg1302638) {
return $Hanf_arg7512637(anf_arg1302638,INDENT7547,PP518,anf_fun1262639,anf_fun1272640,self1312641,_plus10);
}};
$e37773778.stack[R.EXN_STACKHEIGHT++] = $ss37813782;
}
if(R.isPyretException($e37773778)) {
$e37773778.pyretStack.push(L[443]);
}
throw $e37773778;
}
var $ret37833784 = $Hanf_arg7512637($z37793780,INDENT7547,PP518,anf_fun1262639,anf_fun1272640,self1312641,_plus10);
++R.GAS;
return $ret37833784;
};
},{"length":1});
var anf_assign1593186 = (function() {
var $helper_DASH_base37663767 = {"_match":anf_variant_member1103771,
"_torepr":anf_variant_member1243772,
"tosource":anf_variant_member1583773};
var $helper_DASH_brands37693770 = {"$brand-helper3768":true};
$helper_DASH_brands37693770[HelperT3693172._brand] = true
return R.makeObject({"Helper":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[438],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,HelperT3693172._brand));
}),
"is-helper":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[345],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-helper3768"));
}),
"helper":R.makeFunction(function(name1283774,args1293775,body1303776) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[439],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[440],"A",A425,"Name"),List173168,R.getDotAnn(L[441],"N",N224,"AExpr")],[name1283774,args1293775,body1303776],[L[440],L[442],L[441]],function() {
var dict = R.create($helper_DASH_base37663767);
dict["name"] = name1283774
dict["args"] = args1293775
dict["body"] = body1303776
return R.makeBrandedObject(dict,$helper_DASH_brands37693770);
});
})});
})();
Helper7853185.$var = anf_assign1593186;
var anf_assign1603187 = G(Helper7853185.$var,"Helper",L[438]);
Helper8646.$var = anf_assign1603187;
var anf_assign1613188 = G(Helper7853185.$var,"Helper",L[438]);
is_DASH_Helper8762.$var = anf_assign1613188;
var anf_assign1623189 = G(Helper7853185.$var,"is-helper",L[345]);
is_DASH_helper8868.$var = anf_assign1623189;
var anf_assign1633190 = G(Helper7853185.$var,"helper",L[345]);
helper8960.$var = anf_assign1633190;
var anf_assign1763191 = R.makeFunction(function(h1343736) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[433],1,arguments);
}
return R.checkAnnArgs([Helper6845],[h1343736],[L[437]],function() {
var cases_DASH_val263765 = h1343736;
var anf_fun1653747 = G(cases_DASH_val263765,"_match",L[434]);
var anf_obj1723751 = R.makeFunction(function(name1353752,args1362610,body1373753) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[317],3,arguments);
}
var anf_fun1673764 = G(N116,"freevars-e",L[436]);
var $z37563757 = D;
var $f37623763 = function(_) {
return R.isFunction(anf_fun1673764)?anf_fun1673764.app(body1373753):R.ffi.throwNonFunApp(L[435],anf_fun1673764,[body1373753]);
};
try {
if(--R.GAS > 0) {
$z37563757 = $f37623763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37623763,
"from":L[435]});
}
} catch($e37543755) {
if(R.isCont($e37543755)) {
var $ss37583759 = {"from":L[435],
"go":function(anf_bracket1682609) {
return $Hanf_bracket7542608(anf_bracket1682609,args1362610,sets1523);
}};
$e37543755.stack[R.EXN_STACKHEIGHT++] = $ss37583759;
}
if(R.isPyretException($e37543755)) {
$e37543755.pyretStack.push(L[435]);
}
throw $e37543755;
}
var $ret37603761 = $Hanf_bracket7542608($z37563757,args1362610,sets1523);
++R.GAS;
return $ret37603761;
});
var anf_arg1733748 = R.makeObject({"helper":anf_obj1723751});
var anf_arg1753749 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[434],0,arguments);
}
var ann_DASH_check_DASH_temp1743750 = R.throwNoBranchesMatched(L[434],("cases"));
return ann_DASH_check_DASH_temp1743750;
});
var $z37393740 = D;
var $f37453746 = function(_) {
return R.isFunction(anf_fun1653747)?anf_fun1653747.app(anf_arg1733748,anf_arg1753749):R.ffi.throwNonFunApp(L[433],anf_fun1653747,[anf_arg1733748,anf_arg1753749]);
};
try {
if(--R.GAS > 0) {
$z37393740 = $f37453746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37453746,
"from":L[433]});
}
} catch($e37373738) {
if(R.isCont($e37373738)) {
var $ss37413742 = {"from":L[433],
"go":function(ann_DASH_check_DASH_temp1642607) {
return $Hann_DASH_check_DASH_temp7552606(ann_DASH_check_DASH_temp1642607);
}};
$e37373738.stack[R.EXN_STACKHEIGHT++] = $ss37413742;
}
if(R.isPyretException($e37373738)) {
$e37373738.pyretStack.push(L[433]);
}
throw $e37373738;
}
var $ret37433744 = $Hann_DASH_check_DASH_temp7552606($z37393740);
++R.GAS;
return $ret37433744;
});
});
freevars_DASH_helper9058.$var = anf_assign1763191;
var anf_variant_member1903660 = R.makeMethod(function(self283716) {
return function(cases_DASH_funs293717,else_DASH_clause303728) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[313],2,arguments);
}
var if_DASH_323729 = R.hasField(cases_DASH_funs293717,("split-result"));
var if_helper1782599 = R.makeFunction(function(if_helper_arg1793734) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[313],1,arguments);
}
var ann_DASH_check_DASH_temp1773735 = if_helper_arg1793734;
return ann_DASH_check_DASH_temp1773735;
});
var anf_if1823733 = R.isBoolean(if_DASH_323729);
if(R.isPyretTrue(anf_if1823733)) {
if(R.isPyretTrue(if_DASH_323729)) {
var call_DASH_split_DASH_result273712 = G(cases_DASH_funs293717,"split-result",L[313]);
var anf_arg1853713 = G(self283716,"helpers",L[432]);
var anf_arg1863714 = G(self283716,"body",L[431]);
var anf_arg1873715 = G(self283716,"freevars",L[430]);
var $z37043705 = D;
var $f37103711 = function(_) {
return R.isFunction(call_DASH_split_DASH_result273712)?call_DASH_split_DASH_result273712.app(anf_arg1853713,anf_arg1863714,anf_arg1873715):R.ffi.throwNonFunApp(L[313],call_DASH_split_DASH_result273712,[anf_arg1853713,anf_arg1863714,anf_arg1873715]);
};
try {
if(--R.GAS > 0) {
$z37043705 = $f37103711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37103711,
"from":L[313]});
}
} catch($e37023703) {
if(R.isCont($e37023703)) {
var $ss37063707 = {"from":L[313],
"go":function(cont_tail_arg1882598) {
return $Hcont_tail_arg7562597(cont_tail_arg1882598,if_helper1782599);
}};
$e37023703.stack[R.EXN_STACKHEIGHT++] = $ss37063707;
}
if(R.isPyretException($e37023703)) {
$e37023703.pyretStack.push(L[313]);
}
throw $e37023703;
}
var $ret37083709 = $Hcont_tail_arg7562597($z37043705,if_helper1782599);
++R.GAS;
return $ret37083709;
} else {
var $z37203721 = D;
var $f37263727 = function(_) {
return R.isFunction(else_DASH_clause303728)?else_DASH_clause303728.app():R.ffi.throwNonFunApp(L[313],else_DASH_clause303728,[]);
};
try {
if(--R.GAS > 0) {
$z37203721 = $f37263727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37263727,
"from":L[313]});
}
} catch($e37183719) {
if(R.isCont($e37183719)) {
var $ss37223723 = {"from":L[313],
"go":function(cont_tail_arg1832603) {
return $Hcont_tail_arg7572602(cont_tail_arg1832603,if_helper1782599);
}};
$e37183719.stack[R.EXN_STACKHEIGHT++] = $ss37223723;
}
if(R.isPyretException($e37183719)) {
$e37183719.pyretStack.push(L[313]);
}
throw $e37183719;
}
var $ret37243725 = $Hcont_tail_arg7572602($z37203721,if_helper1782599);
++R.GAS;
return $ret37243725;
}
} else {
var cont_tail_arg1803732 = R.throwNonBooleanCondition(L[313],("if"),if_DASH_323729);
if(--R.GAS > 0) {
$z37303731 = R.isFunction(if_helper1782599)?if_helper1782599.app(cont_tail_arg1803732):R.ffi.throwNonFunApp(L[313],if_helper1782599,[cont_tail_arg1803732]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper1782599)?if_helper1782599.app(cont_tail_arg1803732):R.ffi.throwNonFunApp(L[313],if_helper1782599,[cont_tail_arg1803732]);
},
"from":L[313]});
}
++R.GAS;
return $z37303731;
}
};
},{"length":3});
var anf_variant_member2043661 = R.makeMethod(function(self312486) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[313],0,arguments);
}
var anf_arg1923701 = G(self312486,"helpers",L[313]);
var $z36933694 = D;
var $f36993700 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg1923701):R.ffi.throwNonFunApp(L[313],torepr14,[anf_arg1923701]);
};
try {
if(--R.GAS > 0) {
$z36933694 = $f36993700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36993700,
"from":L[313]});
}
} catch($e36913692) {
if(R.isCont($e36913692)) {
var $ss36953696 = {"from":L[313],
"go":function(anf_arg1932485) {
return $Hanf_arg7672484(anf_arg1932485,self312486,_plus10,torepr14);
}};
$e36913692.stack[R.EXN_STACKHEIGHT++] = $ss36953696;
}
if(R.isPyretException($e36913692)) {
$e36913692.pyretStack.push(L[313]);
}
throw $e36913692;
}
var $ret36973698 = $Hanf_arg7672484($z36933694,self312486,_plus10,torepr14);
++R.GAS;
return $ret36973698;
};
},{"length":1});
var anf_variant_member2193662 = R.makeMethod(function(self1412430) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[312],0,arguments);
}
var anf_fun2062429 = G(PP518,"vert",L[429]);
var anf_bracket2073690 = G(self1412430,"helpers",L[428]);
var anf_fun2083676 = G(anf_bracket2073690,"map",L[427]);
var anf_arg2113677 = R.makeFunction(function(recv_DASH_333678) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[426],1,arguments);
}
var anf_fun2103689 = G(recv_DASH_333678,"tosource",L[426]);
var $z36813682 = D;
var $f36873688 = function(_) {
return R.isFunction(anf_fun2103689)?anf_fun2103689.app():R.ffi.throwNonFunApp(L[426],anf_fun2103689,[]);
};
try {
if(--R.GAS > 0) {
$z36813682 = $f36873688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36873688,
"from":L[426]});
}
} catch($e36793680) {
if(R.isCont($e36793680)) {
var $ss36833684 = {"from":L[426],
"go":function(ann_DASH_check_DASH_temp2092483) {
return $Hann_DASH_check_DASH_temp7682482(ann_DASH_check_DASH_temp2092483);
}};
$e36793680.stack[R.EXN_STACKHEIGHT++] = $ss36833684;
}
if(R.isPyretException($e36793680)) {
$e36793680.pyretStack.push(L[426]);
}
throw $e36793680;
}
var $ret36853686 = $Hann_DASH_check_DASH_temp7682482($z36813682);
++R.GAS;
return $ret36853686;
});
var $z36683669 = D;
var $f36743675 = function(_) {
return R.isFunction(anf_fun2083676)?anf_fun2083676.app(anf_arg2113677):R.ffi.throwNonFunApp(L[425],anf_fun2083676,[anf_arg2113677]);
};
try {
if(--R.GAS > 0) {
$z36683669 = $f36743675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36743675,
"from":L[425]});
}
} catch($e36663667) {
if(R.isCont($e36663667)) {
var $ss36703671 = {"from":L[425],
"go":function(anf_arg2122428) {
return $Hanf_arg7732427(anf_arg2122428,anf_fun2062429,list2572,self1412430,_plus10);
}};
$e36663667.stack[R.EXN_STACKHEIGHT++] = $ss36703671;
}
if(R.isPyretException($e36663667)) {
$e36663667.pyretStack.push(L[425]);
}
throw $e36663667;
}
var $ret36723673 = $Hanf_arg7732427($z36683669,anf_fun2062429,list2572,self1412430,_plus10);
++R.GAS;
return $ret36723673;
};
},{"length":1});
var anf_assign2203193 = (function() {
var $split_DASH_result_DASH_base36553656 = {"_match":anf_variant_member1903660,
"_torepr":anf_variant_member2043661,
"tosource":anf_variant_member2193662};
var $split_DASH_result_DASH_brands36583659 = {"$brand-split-result3657":true};
$split_DASH_result_DASH_brands36583659[SplitResultT4713173._brand] = true
return R.makeObject({"SplitResult":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[420],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,SplitResultT4713173._brand));
}),
"is-split-result":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[313],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-split-result3657"));
}),
"split-result":R.makeFunction(function(helpers1383663,body1393664,freevars1403665) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[421],3,arguments);
}
return R.checkAnnArgs([List173168,R.getDotAnn(L[422],"N",N224,"AExpr"),Set202180],[helpers1383663,body1393664,freevars1403665],[L[423],L[422],L[424]],function() {
var dict = R.create($split_DASH_result_DASH_base36553656);
dict["helpers"] = helpers1383663
dict["body"] = body1393664
dict["freevars"] = freevars1403665
return R.makeBrandedObject(dict,$split_DASH_result_DASH_brands36583659);
});
})});
})();
SplitResult8913192.$var = anf_assign2203193;
var anf_assign2213194 = G(SplitResult8913192.$var,"SplitResult",L[420]);
SplitResult9249.$var = anf_assign2213194;
var anf_assign2223195 = G(SplitResult8913192.$var,"SplitResult",L[420]);
is_DASH_SplitResult9363.$var = anf_assign2223195;
var anf_assign2233196 = G(SplitResult8913192.$var,"is-split-result",L[313]);
is_DASH_split_DASH_result9471.$var = anf_assign2233196;
var anf_assign2243197 = G(SplitResult8913192.$var,"split-result",L[313]);
split_DASH_result9578.$var = anf_assign2243197;
var anf_assign2263198 = R.makeFunction(function(sr1423653) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[417],1,arguments);
}
return R.checkAnnArgs([SplitResult7048],[sr1423653],[L[419]],function() {
var ann_DASH_check_DASH_temp2253654 = G(sr1423653,"freevars",L[418]);
return ann_DASH_check_DASH_temp2253654;
});
});
freevars_DASH_split_DASH_result9659.$var = anf_assign2263198;
var anf_variant_member2403548 = R.makeMethod(function(self353633) {
return function(cases_DASH_funs363634,else_DASH_clause373645) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[306],2,arguments);
}
var if_DASH_393646 = R.hasField(cases_DASH_funs363634,("split-result-int-e"));
var if_helper2282420 = R.makeFunction(function(if_helper_arg2293651) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[306],1,arguments);
}
var ann_DASH_check_DASH_temp2273652 = if_helper_arg2293651;
return ann_DASH_check_DASH_temp2273652;
});
var anf_if2323650 = R.isBoolean(if_DASH_393646);
if(R.isPyretTrue(anf_if2323650)) {
if(R.isPyretTrue(if_DASH_393646)) {
var call_DASH_split_DASH_result_DASH_int_DASH_e343629 = G(cases_DASH_funs363634,"split-result-int-e",L[306]);
var anf_arg2353630 = G(self353633,"helpers",L[416]);
var anf_arg2363631 = G(self353633,"body",L[415]);
var anf_arg2373632 = G(self353633,"freevars",L[414]);
var $z36213622 = D;
var $f36273628 = function(_) {
return R.isFunction(call_DASH_split_DASH_result_DASH_int_DASH_e343629)?call_DASH_split_DASH_result_DASH_int_DASH_e343629.app(anf_arg2353630,anf_arg2363631,anf_arg2373632):R.ffi.throwNonFunApp(L[306],call_DASH_split_DASH_result_DASH_int_DASH_e343629,[anf_arg2353630,anf_arg2363631,anf_arg2373632]);
};
try {
if(--R.GAS > 0) {
$z36213622 = $f36273628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36273628,
"from":L[306]});
}
} catch($e36193620) {
if(R.isCont($e36193620)) {
var $ss36233624 = {"from":L[306],
"go":function(cont_tail_arg2382419) {
return $Hcont_tail_arg7742418(cont_tail_arg2382419,if_helper2282420);
}};
$e36193620.stack[R.EXN_STACKHEIGHT++] = $ss36233624;
}
if(R.isPyretException($e36193620)) {
$e36193620.pyretStack.push(L[306]);
}
throw $e36193620;
}
var $ret36253626 = $Hcont_tail_arg7742418($z36213622,if_helper2282420);
++R.GAS;
return $ret36253626;
} else {
var $z36373638 = D;
var $f36433644 = function(_) {
return R.isFunction(else_DASH_clause373645)?else_DASH_clause373645.app():R.ffi.throwNonFunApp(L[306],else_DASH_clause373645,[]);
};
try {
if(--R.GAS > 0) {
$z36373638 = $f36433644();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36433644,
"from":L[306]});
}
} catch($e36353636) {
if(R.isCont($e36353636)) {
var $ss36393640 = {"from":L[306],
"go":function(cont_tail_arg2332424) {
return $Hcont_tail_arg7752423(cont_tail_arg2332424,if_helper2282420);
}};
$e36353636.stack[R.EXN_STACKHEIGHT++] = $ss36393640;
}
if(R.isPyretException($e36353636)) {
$e36353636.pyretStack.push(L[306]);
}
throw $e36353636;
}
var $ret36413642 = $Hcont_tail_arg7752423($z36373638,if_helper2282420);
++R.GAS;
return $ret36413642;
}
} else {
var cont_tail_arg2303649 = R.throwNonBooleanCondition(L[306],("if"),if_DASH_393646);
if(--R.GAS > 0) {
$z36473648 = R.isFunction(if_helper2282420)?if_helper2282420.app(cont_tail_arg2303649):R.ffi.throwNonFunApp(L[306],if_helper2282420,[cont_tail_arg2303649]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper2282420)?if_helper2282420.app(cont_tail_arg2303649):R.ffi.throwNonFunApp(L[306],if_helper2282420,[cont_tail_arg2303649]);
},
"from":L[306]});
}
++R.GAS;
return $z36473648;
}
};
},{"length":3});
var anf_variant_member2543549 = R.makeMethod(function(self382307) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[306],0,arguments);
}
var anf_arg2423618 = G(self382307,"helpers",L[306]);
var $z36103611 = D;
var $f36163617 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2423618):R.ffi.throwNonFunApp(L[306],torepr14,[anf_arg2423618]);
};
try {
if(--R.GAS > 0) {
$z36103611 = $f36163617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36163617,
"from":L[306]});
}
} catch($e36083609) {
if(R.isCont($e36083609)) {
var $ss36123613 = {"from":L[306],
"go":function(anf_arg2432306) {
return $Hanf_arg7852305(anf_arg2432306,self382307,_plus10,torepr14);
}};
$e36083609.stack[R.EXN_STACKHEIGHT++] = $ss36123613;
}
if(R.isPyretException($e36083609)) {
$e36083609.pyretStack.push(L[306]);
}
throw $e36083609;
}
var $ret36143615 = $Hanf_arg7852305($z36103611,self382307,_plus10,torepr14);
++R.GAS;
return $ret36143615;
};
},{"length":1});
var anf_variant_member2683558 = R.makeMethod(function(self413588) {
return function(cases_DASH_funs423589,else_DASH_clause433600) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[305],2,arguments);
}
var if_DASH_453601 = R.hasField(cases_DASH_funs423589,("split-result-int-l"));
var if_helper2562298 = R.makeFunction(function(if_helper_arg2573606) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[305],1,arguments);
}
var ann_DASH_check_DASH_temp2553607 = if_helper_arg2573606;
return ann_DASH_check_DASH_temp2553607;
});
var anf_if2603605 = R.isBoolean(if_DASH_453601);
if(R.isPyretTrue(anf_if2603605)) {
if(R.isPyretTrue(if_DASH_453601)) {
var call_DASH_split_DASH_result_DASH_int_DASH_l403584 = G(cases_DASH_funs423589,"split-result-int-l",L[305]);
var anf_arg2633585 = G(self413588,"helpers",L[413]);
var anf_arg2643586 = G(self413588,"body",L[412]);
var anf_arg2653587 = G(self413588,"freevars",L[411]);
var $z35763577 = D;
var $f35823583 = function(_) {
return R.isFunction(call_DASH_split_DASH_result_DASH_int_DASH_l403584)?call_DASH_split_DASH_result_DASH_int_DASH_l403584.app(anf_arg2633585,anf_arg2643586,anf_arg2653587):R.ffi.throwNonFunApp(L[305],call_DASH_split_DASH_result_DASH_int_DASH_l403584,[anf_arg2633585,anf_arg2643586,anf_arg2653587]);
};
try {
if(--R.GAS > 0) {
$z35763577 = $f35823583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35823583,
"from":L[305]});
}
} catch($e35743575) {
if(R.isCont($e35743575)) {
var $ss35783579 = {"from":L[305],
"go":function(cont_tail_arg2662297) {
return $Hcont_tail_arg7862296(cont_tail_arg2662297,if_helper2562298);
}};
$e35743575.stack[R.EXN_STACKHEIGHT++] = $ss35783579;
}
if(R.isPyretException($e35743575)) {
$e35743575.pyretStack.push(L[305]);
}
throw $e35743575;
}
var $ret35803581 = $Hcont_tail_arg7862296($z35763577,if_helper2562298);
++R.GAS;
return $ret35803581;
} else {
var $z35923593 = D;
var $f35983599 = function(_) {
return R.isFunction(else_DASH_clause433600)?else_DASH_clause433600.app():R.ffi.throwNonFunApp(L[305],else_DASH_clause433600,[]);
};
try {
if(--R.GAS > 0) {
$z35923593 = $f35983599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35983599,
"from":L[305]});
}
} catch($e35903591) {
if(R.isCont($e35903591)) {
var $ss35943595 = {"from":L[305],
"go":function(cont_tail_arg2612302) {
return $Hcont_tail_arg7872301(cont_tail_arg2612302,if_helper2562298);
}};
$e35903591.stack[R.EXN_STACKHEIGHT++] = $ss35943595;
}
if(R.isPyretException($e35903591)) {
$e35903591.pyretStack.push(L[305]);
}
throw $e35903591;
}
var $ret35963597 = $Hcont_tail_arg7872301($z35923593,if_helper2562298);
++R.GAS;
return $ret35963597;
}
} else {
var cont_tail_arg2583604 = R.throwNonBooleanCondition(L[305],("if"),if_DASH_453601);
if(--R.GAS > 0) {
$z36023603 = R.isFunction(if_helper2562298)?if_helper2562298.app(cont_tail_arg2583604):R.ffi.throwNonFunApp(L[305],if_helper2562298,[cont_tail_arg2583604]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1841) {
return R.isFunction(if_helper2562298)?if_helper2562298.app(cont_tail_arg2583604):R.ffi.throwNonFunApp(L[305],if_helper2562298,[cont_tail_arg2583604]);
},
"from":L[305]});
}
++R.GAS;
return $z36023603;
}
};
},{"length":3});
var anf_variant_member2823559 = R.makeMethod(function(self442185) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[305],0,arguments);
}
var anf_arg2703573 = G(self442185,"helpers",L[305]);
var $z35653566 = D;
var $f35713572 = function(_) {
return R.isFunction(torepr14)?torepr14.app(anf_arg2703573):R.ffi.throwNonFunApp(L[305],torepr14,[anf_arg2703573]);
};
try {
if(--R.GAS > 0) {
$z35653566 = $f35713572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35713572,
"from":L[305]});
}
} catch($e35633564) {
if(R.isCont($e35633564)) {
var $ss35673568 = {"from":L[305],
"go":function(anf_arg2712184) {
return $Hanf_arg7972183(anf_arg2712184,self442185,_plus10,torepr14);
}};
$e35633564.stack[R.EXN_STACKHEIGHT++] = $ss35673568;
}
if(R.isPyretException($e35633564)) {
$e35633564.pyretStack.push(L[305]);
}
throw $e35633564;
}
var $ret35693570 = $Hanf_arg7972183($z35653566,self442185,_plus10,torepr14);
++R.GAS;
return $ret35693570;
};
},{"length":1});
var anf_assign2833200 = (function() {
var $split_DASH_result_DASH_int_DASH_e_DASH_base35433544 = {"_match":anf_variant_member2403548,
"_torepr":anf_variant_member2543549};
var $split_DASH_result_DASH_int_DASH_e_DASH_brands35463547 = {"$brand-split-result-int-e3545":true};
$split_DASH_result_DASH_int_DASH_e_DASH_brands35463547[SplitResultIntT5733174._brand] = true
var $split_DASH_result_DASH_int_DASH_l_DASH_base35533554 = {"_match":anf_variant_member2683558,
"_torepr":anf_variant_member2823559};
var $split_DASH_result_DASH_int_DASH_l_DASH_brands35563557 = {"$brand-split-result-int-l3555":true};
$split_DASH_result_DASH_int_DASH_l_DASH_brands35563557[SplitResultIntT5733174._brand] = true
return R.makeObject({"SplitResultInt":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[402],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,SplitResultIntT5733174._brand));
}),
"is-split-result-int-e":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[306],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-split-result-int-e3545"));
}),
"split-result-int-e":R.makeFunction(function(helpers1433550,body1443551,freevars1453552) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[403],3,arguments);
}
return R.checkAnnArgs([ConcatList6643,R.getDotAnn(L[404],"N",N224,"AExpr"),Set202180],[helpers1433550,body1443551,freevars1453552],[L[405],L[404],L[406]],function() {
var dict = R.create($split_DASH_result_DASH_int_DASH_e_DASH_base35433544);
dict["helpers"] = helpers1433550
dict["body"] = body1443551
dict["freevars"] = freevars1453552
return R.makeBrandedObject(dict,$split_DASH_result_DASH_int_DASH_e_DASH_brands35463547);
});
}),
"is-split-result-int-l":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[305],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-split-result-int-l3555"));
}),
"split-result-int-l":R.makeFunction(function(helpers1463560,body1473561,freevars1483562) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[407],3,arguments);
}
return R.checkAnnArgs([ConcatList6643,R.getDotAnn(L[408],"N",N224,"ALettable"),Set202180],[helpers1463560,body1473561,freevars1483562],[L[409],L[408],L[410]],function() {
var dict = R.create($split_DASH_result_DASH_int_DASH_l_DASH_base35533554);
dict["helpers"] = helpers1463560
dict["body"] = body1473561
dict["freevars"] = freevars1483562
return R.makeBrandedObject(dict,$split_DASH_result_DASH_int_DASH_l_DASH_brands35563557);
});
})});
})();
SplitResultInt9973199.$var = anf_assign2833200;
var anf_assign2843201 = G(SplitResultInt9973199.$var,"SplitResultInt",L[402]);
SplitResultInt9851.$var = anf_assign2843201;
var anf_assign2853202 = G(SplitResultInt9973199.$var,"SplitResultInt",L[402]);
is_DASH_SplitResultInt9964.$var = anf_assign2853202;
var anf_assign2863203 = G(SplitResultInt9973199.$var,"is-split-result-int-e",L[306]);
is_DASH_split_DASH_result_DASH_int_DASH_e10069.$var = anf_assign2863203;
var anf_assign2873204 = G(SplitResultInt9973199.$var,"split-result-int-e",L[306]);
split_DASH_result_DASH_int_DASH_e10176.$var = anf_assign2873204;
var anf_assign2883205 = G(SplitResultInt9973199.$var,"is-split-result-int-l",L[305]);
is_DASH_split_DASH_result_DASH_int_DASH_l10270.$var = anf_assign2883205;
var anf_assign2893206 = G(SplitResultInt9973199.$var,"split-result-int-l",L[305]);
split_DASH_result_DASH_int_DASH_l10377.$var = anf_assign2893206;
var anf_assign2953207 = R.makeFunction(function(ss1503516) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[397],1,arguments);
}
return R.checkAnnArgs([List173168],[ss1503516],[L[401]],function() {
var anf_arg2933528 = R.makeFunction(function(unioned1513530,s1523531) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[399],2,arguments);
}
var anf_fun2923542 = G(unioned1513530,"union",L[400]);
var $z35343535 = D;
var $f35403541 = function(_) {
return R.isFunction(anf_fun2923542)?anf_fun2923542.app(s1523531):R.ffi.throwNonFunApp(L[399],anf_fun2923542,[s1523531]);
};
try {
if(--R.GAS > 0) {
$z35343535 = $f35403541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35403541,
"from":L[399]});
}
} catch($e35323533) {
if(R.isCont($e35323533)) {
var $ss35363537 = {"from":L[399],
"go":function(ann_DASH_check_DASH_temp2912182) {
return $Hann_DASH_check_DASH_temp7982181(ann_DASH_check_DASH_temp2912182);
}};
$e35323533.stack[R.EXN_STACKHEIGHT++] = $ss35363537;
}
if(R.isPyretException($e35323533)) {
$e35323533.pyretStack.push(L[399]);
}
throw $e35323533;
}
var $ret35383539 = $Hann_DASH_check_DASH_temp7982181($z35343535);
++R.GAS;
return $ret35383539;
});
var anf_arg2943529 = G(sets1523,"empty-tree-set",L[398]);
var $z35193520 = D;
var $f35253526 = function(_) {
return R.isFunction(fold533527)?fold533527.app(anf_arg2933528,anf_arg2943529,ss1503516):R.ffi.throwNonFunApp(L[397],fold533527,[anf_arg2933528,anf_arg2943529,ss1503516]);
};
try {
if(--R.GAS > 0) {
$z35193520 = $f35253526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35253526,
"from":L[397]});
}
} catch($e35173518) {
if(R.isCont($e35173518)) {
var $ss35213522 = {"from":L[397],
"go":function(ann_DASH_check_DASH_temp2902179) {
return $Hann_DASH_check_DASH_temp7992178(ann_DASH_check_DASH_temp2902179,Set202180);
}};
$e35173518.stack[R.EXN_STACKHEIGHT++] = $ss35213522;
}
if(R.isPyretException($e35173518)) {
$e35173518.pyretStack.push(L[397]);
}
throw $e35173518;
}
var $ret35233524 = $Hann_DASH_check_DASH_temp7992178($z35193520,Set202180);
++R.GAS;
return $ret35233524;
});
});
unions10479.$var = anf_assign2953207;
var anf_assign3023208 = R.makeFunction(function(expr1533505) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[302],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[396],"N",N224,"AExpr")],[expr1533505],[L[396]],function() {
var $z35083509 = D;
var $f35143515 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var === D?U(L[394],"ast-split-expr"):ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var === D?U(L[394],"ast-split-expr"):ast_DASH_split_DASH_expr10652.$var.app(expr1533505):R.ffi.throwNonFunApp(L[395],ast_DASH_split_DASH_expr10652.$var === D?U(L[394],"ast-split-expr"):ast_DASH_split_DASH_expr10652.$var,[expr1533505]);
};
try {
if(--R.GAS > 0) {
$z35083509 = $f35143515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35143515,
"from":L[395]});
}
} catch($e35063507) {
if(R.isCont($e35063507)) {
var $ss35103511 = {"from":L[395],
"go":function(r1542149) {
return $Hr8022148(r1542149,SplitResult7048,split_DASH_result9578);
}};
$e35063507.stack[R.EXN_STACKHEIGHT++] = $ss35103511;
}
if(R.isPyretException($e35063507)) {
$e35063507.pyretStack.push(L[395]);
}
throw $e35063507;
}
var $ret35123513 = $Hr8022148($z35083509,SplitResult7048,split_DASH_result9578);
++R.GAS;
return $ret35123513;
});
});
ast_DASH_split10554.$var = anf_assign3023208;
var anf_assign4933209 = R.makeFunction(function(expr1553286) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[368],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[393],"N",N224,"AExpr")],[expr1553286],[L[393]],function() {
var handle_DASH_bind1561743 = {"$var":D,
"$name":"handle-bind"};
var anf_assign3773287 = R.makeFunction(function(l1571779,is_DASH_var1581778,b1591776,e1603468,body1611777) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[389],5,arguments);
}
var cases_DASH_val483504 = e1603468;
var anf_fun3053479 = G(cases_DASH_val483504,"_match",L[258]);
var anf_obj3453492 = R.makeFunction(function(l21623493,f1631906,args1641905) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[298],3,arguments);
}
var $z34963497 = D;
var $f35023503 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(body1611777):R.ffi.throwNonFunApp(L[392],ast_DASH_split_DASH_expr10652.$var,[body1611777]);
};
try {
if(--R.GAS > 0) {
$z34963497 = $f35023503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35023503,
"from":L[392]});
}
} catch($e34943495) {
if(R.isCont($e34943495)) {
var $ss34983499 = {"from":L[392],
"go":function(rest_DASH_split1651904) {
return $Hrest_DASH_split8211903(rest_DASH_split1651904,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
}};
$e34943495.stack[R.EXN_STACKHEIGHT++] = $ss34983499;
}
if(R.isPyretException($e34943495)) {
$e34943495.pyretStack.push(L[392]);
}
throw $e34943495;
}
var $ret35003501 = $Hrest_DASH_split8211903($z34963497,N116,args1641905,b1591776,concat_DASH_singleton8257,f1631906,helper8960,is_DASH_var1581778,l1571779,link291907,names7473,split_DASH_result_DASH_int_DASH_e10176,unions10479,_plus10);
++R.GAS;
return $ret35003501;
});
var anf_arg3463480 = R.makeObject({"a-app":anf_obj3453492});
var anf_arg3763481 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[258],0,arguments);
}
var $z34843485 = D;
var $f34903491 = function(_) {
return R.isFunction(ast_DASH_split_DASH_lettable10753.$var === D?U(L[390],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var)?ast_DASH_split_DASH_lettable10753.$var === D?U(L[390],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var.app(e1603468):R.ffi.throwNonFunApp(L[391],ast_DASH_split_DASH_lettable10753.$var === D?U(L[390],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var,[e1603468]);
};
try {
if(--R.GAS > 0) {
$z34843485 = $f34903491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34903491,
"from":L[391]});
}
} catch($e34823483) {
if(R.isCont($e34823483)) {
var $ss34863487 = {"from":L[391],
"go":function(e_DASH_split1681775) {
return $He_DASH_split8301774(e_DASH_split1681775,N116,ast_DASH_split_DASH_expr10652,b1591776,body1611777,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,_plus10);
}};
$e34823483.stack[R.EXN_STACKHEIGHT++] = $ss34863487;
}
if(R.isPyretException($e34823483)) {
$e34823483.pyretStack.push(L[391]);
}
throw $e34823483;
}
var $ret34883489 = $He_DASH_split8301774($z34843485,N116,ast_DASH_split_DASH_expr10652,b1591776,body1611777,is_DASH_var1581778,l1571779,split_DASH_result_DASH_int_DASH_e10176,_plus10);
++R.GAS;
return $ret34883489;
});
var $z34713472 = D;
var $f34773478 = function(_) {
return R.isFunction(anf_fun3053479)?anf_fun3053479.app(anf_arg3463480,anf_arg3763481):R.ffi.throwNonFunApp(L[389],anf_fun3053479,[anf_arg3463480,anf_arg3763481]);
};
try {
if(--R.GAS > 0) {
$z34713472 = $f34773478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34773478,
"from":L[389]});
}
} catch($e34693470) {
if(R.isCont($e34693470)) {
var $ss34733474 = {"from":L[389],
"go":function(ann_DASH_check_DASH_temp3041773) {
return $Hann_DASH_check_DASH_temp8311772(ann_DASH_check_DASH_temp3041773);
}};
$e34693470.stack[R.EXN_STACKHEIGHT++] = $ss34733474;
}
if(R.isPyretException($e34693470)) {
$e34693470.pyretStack.push(L[389]);
}
throw $e34693470;
}
var $ret34753476 = $Hann_DASH_check_DASH_temp8311772($z34713472);
++R.GAS;
return $ret34753476;
});
handle_DASH_bind1561743.$var = anf_assign3773287;
var cases_DASH_val533467 = expr1553286;
var anf_fun3783298 = G(cases_DASH_val533467,"_match",L[157]);
var anf_obj3803311 = R.makeFunction(function(l1703453,b1713454,e1723455,body1733456) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[388],4,arguments);
}
var $z34593460 = D;
var $f34653466 = function(_) {
return R.isFunction(handle_DASH_bind1561743.$var)?handle_DASH_bind1561743.$var.app(l1703453,(false),b1713454,e1723455,body1733456):R.ffi.throwNonFunApp(L[388],handle_DASH_bind1561743.$var,[l1703453,(false),b1713454,e1723455,body1733456]);
};
try {
if(--R.GAS > 0) {
$z34593460 = $f34653466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34653466,
"from":L[388]});
}
} catch($e34573458) {
if(R.isCont($e34573458)) {
var $ss34613462 = {"from":L[388],
"go":function(ann_DASH_check_DASH_temp3791771) {
return $Hann_DASH_check_DASH_temp8321770(ann_DASH_check_DASH_temp3791771);
}};
$e34573458.stack[R.EXN_STACKHEIGHT++] = $ss34613462;
}
if(R.isPyretException($e34573458)) {
$e34573458.pyretStack.push(L[388]);
}
throw $e34573458;
}
var $ret34633464 = $Hann_DASH_check_DASH_temp8321770($z34593460);
++R.GAS;
return $ret34633464;
});
var anf_obj4053312 = R.makeFunction(function(l1741670,e11751742,e21761669) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[381],3,arguments);
}
var cases_DASH_val493452 = e11751742;
var anf_fun3823424 = G(cases_DASH_val493452,"_match",L[231]);
var anf_obj3903437 = R.makeFunction(function(l21771744,f1783438,args1793439) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[234],3,arguments);
}
var anf_fun3841741 = G(N116,"a-bind",L[387]);
var anf_bracket3853451 = G(A317,"global-names",L[386]);
var anf_fun3863450 = G(anf_bracket3853451,"make-atom",L[385]);
var $z34423443 = D;
var $f34483449 = function(_) {
return R.isFunction(anf_fun3863450)?anf_fun3863450.app(("anf_begin_app_dropped")):R.ffi.throwNonFunApp(L[384],anf_fun3863450,[("anf_begin_app_dropped")]);
};
try {
if(--R.GAS > 0) {
$z34423443 = $f34483449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34483449,
"from":L[384]});
}
} catch($e34403441) {
if(R.isCont($e34403441)) {
var $ss34443445 = {"from":L[384],
"go":function(anf_arg3871740) {
return $Hanf_arg8351739(anf_arg3871740,A317,anf_fun3841741,e11751742,e21761669,handle_DASH_bind1561743,l1741670,l21771744);
}};
$e34403441.stack[R.EXN_STACKHEIGHT++] = $ss34443445;
}
if(R.isPyretException($e34403441)) {
$e34403441.pyretStack.push(L[384]);
}
throw $e34403441;
}
var $ret34463447 = $Hanf_arg8351739($z34423443,A317,anf_fun3841741,e11751742,e21761669,handle_DASH_bind1561743,l1741670,l21771744);
++R.GAS;
return $ret34463447;
});
var anf_arg3913425 = R.makeObject({"a-app":anf_obj3903437});
var anf_arg4043426 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[231],0,arguments);
}
var $z34293430 = D;
var $f34353436 = function(_) {
return R.isFunction(ast_DASH_split_DASH_lettable10753.$var === D?U(L[382],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var)?ast_DASH_split_DASH_lettable10753.$var === D?U(L[382],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var.app(e11751742):R.ffi.throwNonFunApp(L[383],ast_DASH_split_DASH_lettable10753.$var === D?U(L[382],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var,[e11751742]);
};
try {
if(--R.GAS > 0) {
$z34293430 = $f34353436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34353436,
"from":L[383]});
}
} catch($e34273428) {
if(R.isCont($e34273428)) {
var $ss34313432 = {"from":L[383],
"go":function(e1_DASH_split1801668) {
return $He1_DASH_split8411667(e1_DASH_split1801668,N116,ast_DASH_split_DASH_expr10652,e21761669,l1741670,split_DASH_result_DASH_int_DASH_e10176,_plus10);
}};
$e34273428.stack[R.EXN_STACKHEIGHT++] = $ss34313432;
}
if(R.isPyretException($e34273428)) {
$e34273428.pyretStack.push(L[383]);
}
throw $e34273428;
}
var $ret34333434 = $He1_DASH_split8411667($z34293430,N116,ast_DASH_split_DASH_expr10652,e21761669,l1741670,split_DASH_result_DASH_int_DASH_e10176,_plus10);
++R.GAS;
return $ret34333434;
});
var $z34163417 = D;
var $f34223423 = function(_) {
return R.isFunction(anf_fun3823424)?anf_fun3823424.app(anf_arg3913425,anf_arg4043426):R.ffi.throwNonFunApp(L[381],anf_fun3823424,[anf_arg3913425,anf_arg4043426]);
};
try {
if(--R.GAS > 0) {
$z34163417 = $f34223423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34223423,
"from":L[381]});
}
} catch($e34143415) {
if(R.isCont($e34143415)) {
var $ss34183419 = {"from":L[381],
"go":function(ann_DASH_check_DASH_temp3811666) {
return $Hann_DASH_check_DASH_temp8421665(ann_DASH_check_DASH_temp3811666);
}};
$e34143415.stack[R.EXN_STACKHEIGHT++] = $ss34183419;
}
if(R.isPyretException($e34143415)) {
$e34143415.pyretStack.push(L[381]);
}
throw $e34143415;
}
var $ret34203421 = $Hann_DASH_check_DASH_temp8421665($z34163417);
++R.GAS;
return $ret34203421;
});
var anf_obj4253313 = R.makeFunction(function(l1821584,b1831581,e1841583,body1851582) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[377],4,arguments);
}
var cases_DASH_val503413 = e1841583;
var anf_fun4073387 = G(cases_DASH_val503413,"_match",L[218]);
var anf_obj4093401 = R.makeFunction(function(v1863402) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[380],1,arguments);
}
var $z34053406 = D;
var $f34113412 = function(_) {
return R.isFunction(handle_DASH_bind1561743.$var)?handle_DASH_bind1561743.$var.app(l1821584,(true),b1831581,e1841583,body1851582):R.ffi.throwNonFunApp(L[380],handle_DASH_bind1561743.$var,[l1821584,(true),b1831581,e1841583,body1851582]);
};
try {
if(--R.GAS > 0) {
$z34053406 = $f34113412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34113412,
"from":L[380]});
}
} catch($e34033404) {
if(R.isCont($e34033404)) {
var $ss34073408 = {"from":L[380],
"go":function(ann_DASH_check_DASH_temp4081664) {
return $Hann_DASH_check_DASH_temp8431663(ann_DASH_check_DASH_temp4081664);
}};
$e34033404.stack[R.EXN_STACKHEIGHT++] = $ss34073408;
}
if(R.isPyretException($e34033404)) {
$e34033404.pyretStack.push(L[380]);
}
throw $e34033404;
}
var $ret34093410 = $Hann_DASH_check_DASH_temp8431663($z34053406);
++R.GAS;
return $ret34093410;
});
var anf_arg4103388 = R.makeObject({"a-val":anf_obj4093401});
var anf_arg4243389 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[218],0,arguments);
}
var anf_fun4123400 = G(names7473,"make-atom",L[379]);
var $z33923393 = D;
var $f33983399 = function(_) {
return R.isFunction(anf_fun4123400)?anf_fun4123400.app(("var-bind")):R.ffi.throwNonFunApp(L[378],anf_fun4123400,[("var-bind")]);
};
try {
if(--R.GAS > 0) {
$z33923393 = $f33983399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33983399,
"from":L[378]});
}
} catch($e33903391) {
if(R.isCont($e33903391)) {
var $ss33943395 = {"from":L[378],
"go":function(n1871580) {
return $Hn8501579(n1871580,A317,N116,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584);
}};
$e33903391.stack[R.EXN_STACKHEIGHT++] = $ss33943395;
}
if(R.isPyretException($e33903391)) {
$e33903391.pyretStack.push(L[378]);
}
throw $e33903391;
}
var $ret33963397 = $Hn8501579($z33923393,A317,N116,ast_DASH_split_DASH_expr10652,b1831581,body1851582,e1841583,l1821584);
++R.GAS;
return $ret33963397;
});
var $z33793380 = D;
var $f33853386 = function(_) {
return R.isFunction(anf_fun4073387)?anf_fun4073387.app(anf_arg4103388,anf_arg4243389):R.ffi.throwNonFunApp(L[377],anf_fun4073387,[anf_arg4103388,anf_arg4243389]);
};
try {
if(--R.GAS > 0) {
$z33793380 = $f33853386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33853386,
"from":L[377]});
}
} catch($e33773378) {
if(R.isCont($e33773378)) {
var $ss33813382 = {"from":L[377],
"go":function(ann_DASH_check_DASH_temp4061578) {
return $Hann_DASH_check_DASH_temp8511577(ann_DASH_check_DASH_temp4061578);
}};
$e33773378.stack[R.EXN_STACKHEIGHT++] = $ss33813382;
}
if(R.isPyretException($e33773378)) {
$e33773378.pyretStack.push(L[377]);
}
throw $e33773378;
}
var $ret33833384 = $Hann_DASH_check_DASH_temp8511577($z33793380);
++R.GAS;
return $ret33833384;
});
var anf_obj4423314 = R.makeFunction(function(l1881482,cond1891481,consq1903366,alt1911480) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[206],4,arguments);
}
var $z33693370 = D;
var $f33753376 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(consq1903366):R.ffi.throwNonFunApp(L[376],ast_DASH_split_DASH_expr10652.$var,[consq1903366]);
};
try {
if(--R.GAS > 0) {
$z33693370 = $f33753376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33753376,
"from":L[376]});
}
} catch($e33673368) {
if(R.isCont($e33673368)) {
var $ss33713372 = {"from":L[376],
"go":function(consq_DASH_split1921479) {
return $Hconsq_DASH_split8591478(consq_DASH_split1921479,N116,alt1911480,ast_DASH_split_DASH_expr10652,cond1891481,l1881482,split_DASH_result_DASH_int_DASH_e10176,_plus10);
}};
$e33673368.stack[R.EXN_STACKHEIGHT++] = $ss33713372;
}
if(R.isPyretException($e33673368)) {
$e33673368.pyretStack.push(L[376]);
}
throw $e33673368;
}
var $ret33733374 = $Hconsq_DASH_split8591478($z33693370,N116,alt1911480,ast_DASH_split_DASH_expr10652,cond1891481,l1881482,split_DASH_result_DASH_int_DASH_e10176,_plus10);
++R.GAS;
return $ret33733374;
});
var anf_obj4643315 = R.makeFunction(function(l1941371,bind1951370,body1963355) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[188],3,arguments);
}
var $z33583359 = D;
var $f33643365 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(body1963355):R.ffi.throwNonFunApp(L[375],ast_DASH_split_DASH_expr10652.$var,[body1963355]);
};
try {
if(--R.GAS > 0) {
$z33583359 = $f33643365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33643365,
"from":L[375]});
}
} catch($e33563357) {
if(R.isCont($e33563357)) {
var $ss33603361 = {"from":L[375],
"go":function(body_DASH_split1971369) {
return $Hbody_DASH_split8671368(body_DASH_split1971369,N116,bind1951370,l1941371,split_DASH_result_DASH_int_DASH_e10176);
}};
$e33563357.stack[R.EXN_STACKHEIGHT++] = $ss33603361;
}
if(R.isPyretException($e33563357)) {
$e33563357.pyretStack.push(L[375]);
}
throw $e33563357;
}
var $ret33623363 = $Hbody_DASH_split8671368($z33583359,N116,bind1951370,l1941371,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret33623363;
});
var anf_obj4873316 = R.makeFunction(function(e2053317) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[370],1,arguments);
}
var cases_DASH_val523354 = e2053317;
var anf_fun4663328 = G(cases_DASH_val523354,"_match",L[162]);
var anf_obj4783341 = R.makeFunction(function(l2063342,f2071303,args2081302) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[172],3,arguments);
}
var anf_fun4683353 = G(N116,"a-tail-app",L[374]);
var $z33453346 = D;
var $f33513352 = function(_) {
return R.isFunction(anf_fun4683353)?anf_fun4683353.app(l2063342,f2071303,args2081302):R.ffi.throwNonFunApp(L[373],anf_fun4683353,[l2063342,f2071303,args2081302]);
};
try {
if(--R.GAS > 0) {
$z33453346 = $f33513352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33513352,
"from":L[373]});
}
} catch($e33433344) {
if(R.isCont($e33433344)) {
var $ss33473348 = {"from":L[373],
"go":function(anf_arg4691301) {
return $Hanf_arg8731300(anf_arg4691301,N116,args2081302,concat_DASH_empty8056,f2071303,split_DASH_result_DASH_int_DASH_e10176,unions10479);
}};
$e33433344.stack[R.EXN_STACKHEIGHT++] = $ss33473348;
}
if(R.isPyretException($e33433344)) {
$e33433344.pyretStack.push(L[373]);
}
throw $e33433344;
}
var $ret33493350 = $Hanf_arg8731300($z33453346,N116,args2081302,concat_DASH_empty8056,f2071303,split_DASH_result_DASH_int_DASH_e10176,unions10479);
++R.GAS;
return $ret33493350;
});
var anf_arg4793329 = R.makeObject({"a-app":anf_obj4783341});
var anf_arg4863330 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[162],0,arguments);
}
var $z33333334 = D;
var $f33393340 = function(_) {
return R.isFunction(ast_DASH_split_DASH_lettable10753.$var === D?U(L[371],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var)?ast_DASH_split_DASH_lettable10753.$var === D?U(L[371],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var.app(e2053317):R.ffi.throwNonFunApp(L[372],ast_DASH_split_DASH_lettable10753.$var === D?U(L[371],"ast-split-lettable"):ast_DASH_split_DASH_lettable10753.$var,[e2053317]);
};
try {
if(--R.GAS > 0) {
$z33333334 = $f33393340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33393340,
"from":L[372]});
}
} catch($e33313332) {
if(R.isCont($e33313332)) {
var $ss33353336 = {"from":L[372],
"go":function(let_DASH_result2091271) {
return $Hlet_DASH_result8761270(let_DASH_result2091271,N116,split_DASH_result_DASH_int_DASH_e10176);
}};
$e33313332.stack[R.EXN_STACKHEIGHT++] = $ss33353336;
}
if(R.isPyretException($e33313332)) {
$e33313332.pyretStack.push(L[372]);
}
throw $e33313332;
}
var $ret33373338 = $Hlet_DASH_result8761270($z33333334,N116,split_DASH_result_DASH_int_DASH_e10176);
++R.GAS;
return $ret33373338;
});
var $z33203321 = D;
var $f33263327 = function(_) {
return R.isFunction(anf_fun4663328)?anf_fun4663328.app(anf_arg4793329,anf_arg4863330):R.ffi.throwNonFunApp(L[370],anf_fun4663328,[anf_arg4793329,anf_arg4863330]);
};
try {
if(--R.GAS > 0) {
$z33203321 = $f33263327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33263327,
"from":L[370]});
}
} catch($e33183319) {
if(R.isCont($e33183319)) {
var $ss33223323 = {"from":L[370],
"go":function(ann_DASH_check_DASH_temp4651269) {
return $Hann_DASH_check_DASH_temp8771268(ann_DASH_check_DASH_temp4651269);
}};
$e33183319.stack[R.EXN_STACKHEIGHT++] = $ss33223323;
}
if(R.isPyretException($e33183319)) {
$e33183319.pyretStack.push(L[370]);
}
throw $e33183319;
}
var $ret33243325 = $Hann_DASH_check_DASH_temp8771268($z33203321);
++R.GAS;
return $ret33243325;
});
var anf_arg4883299 = R.makeObject({"a-let":anf_obj3803311,
"a-seq":anf_obj4053312,
"a-var":anf_obj4253313,
"a-if":anf_obj4423314,
"a-type-let":anf_obj4643315,
"a-lettable":anf_obj4873316});
var anf_arg4923300 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[157],0,arguments);
}
var $z33033304 = D;
var $f33093310 = function(_) {
return R.isFunction(torepr14)?torepr14.app(expr1553286):R.ffi.throwNonFunApp(L[369],torepr14,[expr1553286]);
};
try {
if(--R.GAS > 0) {
$z33033304 = $f33093310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33093310,
"from":L[369]});
}
} catch($e33013302) {
if(R.isCont($e33013302)) {
var $ss33053306 = {"from":L[369],
"go":function(anf_arg4901243) {
return $Hanf_arg8801242(anf_arg4901243,_plus10,raise13);
}};
$e33013302.stack[R.EXN_STACKHEIGHT++] = $ss33053306;
}
if(R.isPyretException($e33013302)) {
$e33013302.pyretStack.push(L[369]);
}
throw $e33013302;
}
var $ret33073308 = $Hanf_arg8801242($z33033304,_plus10,raise13);
++R.GAS;
return $ret33073308;
});
var $z32903291 = D;
var $f32963297 = function(_) {
return R.isFunction(anf_fun3783298)?anf_fun3783298.app(anf_arg4883299,anf_arg4923300):R.ffi.throwNonFunApp(L[368],anf_fun3783298,[anf_arg4883299,anf_arg4923300]);
};
try {
if(--R.GAS > 0) {
$z32903291 = $f32963297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32963297,
"from":L[368]});
}
} catch($e32883289) {
if(R.isCont($e32883289)) {
var $ss32923293 = {"from":L[368],
"go":function(ann_DASH_check_DASH_temp3031241) {
return $Hann_DASH_check_DASH_temp8811240(ann_DASH_check_DASH_temp3031241,SplitResultInt7250);
}};
$e32883289.stack[R.EXN_STACKHEIGHT++] = $ss32923293;
}
if(R.isPyretException($e32883289)) {
$e32883289.pyretStack.push(L[368]);
}
throw $e32883289;
}
var $ret32943295 = $Hann_DASH_check_DASH_temp8811240($z32903291,SplitResultInt7250);
++R.GAS;
return $ret32943295;
});
});
ast_DASH_split_DASH_expr10652.$var = anf_assign4933209;
var anf_assign5473210 = R.makeFunction(function(e210993) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[362],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[367],"N",N224,"ALettable")],[e210993],[L[367]],function() {
var cases_DASH_val583285 = e210993;
var anf_fun4953247 = G(cases_DASH_val583285,"_match",L[115]);
var anf_obj5183261 = R.makeFunction(function(l2111126,args2121125,ret2131127,body2143274) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[155],4,arguments);
}
var $z32773278 = D;
var $f32833284 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(body2143274):R.ffi.throwNonFunApp(L[366],ast_DASH_split_DASH_expr10652.$var,[body2143274]);
};
try {
if(--R.GAS > 0) {
$z32773278 = $f32833284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32833284,
"from":L[366]});
}
} catch($e32753276) {
if(R.isCont($e32753276)) {
var $ss32793280 = {"from":L[366],
"go":function(body_DASH_split2151124) {
return $Hbody_DASH_split8901123(body_DASH_split2151124,N116,args2121125,l2111126,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377);
}};
$e32753276.stack[R.EXN_STACKHEIGHT++] = $ss32793280;
}
if(R.isPyretException($e32753276)) {
$e32753276.pyretStack.push(L[366]);
}
throw $e32753276;
}
var $ret32813282 = $Hbody_DASH_split8901123($z32773278,N116,args2121125,l2111126,ret2131127,sets1523,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret32813282;
});
var anf_obj5413262 = R.makeFunction(function(l2161009,args2171008,ret2181010,body2193263) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[135],4,arguments);
}
var $z32663267 = D;
var $f32723273 = function(_) {
return R.isFunction(ast_DASH_split_DASH_expr10652.$var)?ast_DASH_split_DASH_expr10652.$var.app(body2193263):R.ffi.throwNonFunApp(L[365],ast_DASH_split_DASH_expr10652.$var,[body2193263]);
};
try {
if(--R.GAS > 0) {
$z32663267 = $f32723273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32723273,
"from":L[365]});
}
} catch($e32643265) {
if(R.isCont($e32643265)) {
var $ss32683269 = {"from":L[365],
"go":function(body_DASH_split2201007) {
return $Hbody_DASH_split8991006(body_DASH_split2201007,N116,args2171008,l2161009,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377);
}};
$e32643265.stack[R.EXN_STACKHEIGHT++] = $ss32683269;
}
if(R.isPyretException($e32643265)) {
$e32643265.pyretStack.push(L[365]);
}
throw $e32643265;
}
var $ret32703271 = $Hbody_DASH_split8991006($z32663267,N116,args2171008,l2161009,ret2181010,sets1523,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret32703271;
});
var anf_arg5423248 = R.makeObject({"a-lam":anf_obj5183261,
"a-method":anf_obj5413262});
var anf_arg5463249 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[115],0,arguments);
}
var anf_fun5443260 = G(N116,"freevars-l",L[364]);
var $z32523253 = D;
var $f32583259 = function(_) {
return R.isFunction(anf_fun5443260)?anf_fun5443260.app(e210993):R.ffi.throwNonFunApp(L[363],anf_fun5443260,[e210993]);
};
try {
if(--R.GAS > 0) {
$z32523253 = $f32583259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32583259,
"from":L[363]});
}
} catch($e32503251) {
if(R.isCont($e32503251)) {
var $ss32543255 = {"from":L[363],
"go":function(anf_arg545992) {
return $Hanf_arg901991(anf_arg545992,concat_DASH_empty8056,e210993,split_DASH_result_DASH_int_DASH_l10377);
}};
$e32503251.stack[R.EXN_STACKHEIGHT++] = $ss32543255;
}
if(R.isPyretException($e32503251)) {
$e32503251.pyretStack.push(L[363]);
}
throw $e32503251;
}
var $ret32563257 = $Hanf_arg901991($z32523253,concat_DASH_empty8056,e210993,split_DASH_result_DASH_int_DASH_l10377);
++R.GAS;
return $ret32563257;
});
var $z32393240 = D;
var $f32453246 = function(_) {
return R.isFunction(anf_fun4953247)?anf_fun4953247.app(anf_arg5423248,anf_arg5463249):R.ffi.throwNonFunApp(L[362],anf_fun4953247,[anf_arg5423248,anf_arg5463249]);
};
try {
if(--R.GAS > 0) {
$z32393240 = $f32453246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32453246,
"from":L[362]});
}
} catch($e32373238) {
if(R.isCont($e32373238)) {
var $ss32413242 = {"from":L[362],
"go":function(ann_DASH_check_DASH_temp494990) {
return $Hann_DASH_check_DASH_temp902989(ann_DASH_check_DASH_temp494990,SplitResultInt7250,is_DASH_split_DASH_result_DASH_int_DASH_l10270);
}};
$e32373238.stack[R.EXN_STACKHEIGHT++] = $ss32413242;
}
if(R.isPyretException($e32373238)) {
$e32373238.pyretStack.push(L[362]);
}
throw $e32373238;
}
var $ret32433244 = $Hann_DASH_check_DASH_temp902989($z32393240,SplitResultInt7250,is_DASH_split_DASH_result_DASH_int_DASH_l10270);
++R.GAS;
return $ret32433244;
});
});
ast_DASH_split_DASH_lettable10753.$var = anf_assign5473210;
var anf_assign5513211 = R.makeFunction(function(l2213223,name2223224) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[359],2,arguments);
}
var anf_fun5493235 = G(N116,"a-bind",L[361]);
var anf_arg5503236 = G(A317,"a-blank",L[360]);
var $z32273228 = D;
var $f32333234 = function(_) {
return R.isFunction(anf_fun5493235)?anf_fun5493235.app(l2213223,name2223224,anf_arg5503236):R.ffi.throwNonFunApp(L[359],anf_fun5493235,[l2213223,name2223224,anf_arg5503236]);
};
try {
if(--R.GAS > 0) {
$z32273228 = $f32333234();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32333234,
"from":L[359]});
}
} catch($e32253226) {
if(R.isCont($e32253226)) {
var $ss32293230 = {"from":L[359],
"go":function(ann_DASH_check_DASH_temp548988) {
return $Hann_DASH_check_DASH_temp903987(ann_DASH_check_DASH_temp548988);
}};
$e32253226.stack[R.EXN_STACKHEIGHT++] = $ss32293230;
}
if(R.isPyretException($e32253226)) {
$e32253226.pyretStack.push(L[359]);
}
throw $e32253226;
}
var $ret32313232 = $Hann_DASH_check_DASH_temp903987($z32273228);
++R.GAS;
return $ret32313232;
});
param10874.$var = anf_assign5513211;
nothing12;
var result_DASH_after_DASH_checks122375 = nothing12;
var anf_fun5523222 = G(builtins11,"current-checker",L[0]);
var $z32143215 = D;
var $f32203221 = function(_) {
return R.isFunction(anf_fun5523222)?anf_fun5523222.app():R.ffi.throwNonFunApp(L[0],anf_fun5523222,[]);
};
try {
if(--R.GAS > 0) {
$z32143215 = $f32203221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32203221,
"from":L[0]});
}
} catch($e32123213) {
if(R.isCont($e32123213)) {
var $ss32163217 = {"from":L[0],
"go":function(anf_bracket55342) {
return $Hanf_bracket97841(anf_bracket55342,A317,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,N116,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,list2572,names7473,param10874,result_DASH_after_DASH_checks122375,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11);
}};
$e32123213.stack[R.EXN_STACKHEIGHT++] = $ss32163217;
}
if(R.isPyretException($e32123213)) {
$e32123213.pyretStack.push(L[0]);
}
throw $e32123213;
}
var $ret32183219 = $Hanf_bracket97841($z32143215,A317,ConcatList6643,ConcatList7744,Helper6845,Helper8646,INDENT7547,N116,SplitResult7048,SplitResult9249,SplitResultInt7250,SplitResultInt9851,ast_DASH_split_DASH_expr10652,ast_DASH_split_DASH_lettable10753,ast_DASH_split10554,concat_DASH_append8455,concat_DASH_empty8056,concat_DASH_singleton8257,freevars_DASH_helper9058,freevars_DASH_split_DASH_result9659,helper8960,is_DASH_ConcatList7861,is_DASH_Helper8762,is_DASH_SplitResult9363,is_DASH_SplitResultInt9964,is_DASH_concat_DASH_append8365,is_DASH_concat_DASH_empty7966,is_DASH_concat_DASH_singleton8167,is_DASH_helper8868,is_DASH_split_DASH_result_DASH_int_DASH_e10069,is_DASH_split_DASH_result_DASH_int_DASH_l10270,is_DASH_split_DASH_result9471,list2572,names7473,param10874,result_DASH_after_DASH_checks122375,sets1523,split_DASH_result_DASH_int_DASH_e10176,split_DASH_result_DASH_int_DASH_l10377,split_DASH_result9578,unions10479,builtins11);
++R.GAS;
return $ret32183219;
},function(moduleVal) {
R.modules["$src/arr/compiler/ast-split.arr32"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/js-ast.arr',["trove/pprint",
"trove/format",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($PP12338,$F32439,$arrays52540,$lists72641,$option92742,$error112843,$sets132944) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/js-ast.arr37"]) {
return R.modules["$src/arr/compiler/js-ast.arr37"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/js-ast.arr";
var D = R.undefined;
var L = [[M,12,0,134,12,23,157],
[M,12,12,146,12,20,154],
[M,8,0,79,470,3,15055],
[M,454,2,14594,463,7,14917],
[M,453,0,14579,470,3,15055],
[M,454,4,14596,454,43,14635],
[M,454,20,14612,454,26,14618],
[M,454,37,14629,454,42,14634],
[M,462,32,14851,462,49,14868],
[M,462,39,14858,462,48,14867],
[M,462,32,14851,462,38,14857],
[M,462,22,14841,462,31,14850],
[M,462,6,14825,462,13,14832],
[M,461,4,14803,463,7,14917],
[M,456,6,14686,456,19,14699],
[M,455,4,14646,460,7,14797],
[M,454,28,14620,454,42,14634],
[M,454,12,14604,454,26,14618],
[M,466,4,14955,466,31,14982],
[M,465,2,14929,469,5,15051],
[M,404,2,12900,412,7,13285],
[M,399,2,12748,403,43,12897],
[M,394,2,12608,398,43,12745],
[M,389,2,12483,393,38,12605],
[M,384,2,12355,388,39,12480],
[M,379,2,12230,383,38,12352],
[M,374,2,12080,378,41,12227],
[M,369,2,11927,373,46,12077],
[M,364,2,11788,368,39,11924],
[M,348,2,11271,363,7,11785],
[M,331,2,10708,347,7,11268],
[M,321,2,10353,330,7,10705],
[M,314,2,10074,320,97,10350],
[M,303,2,9628,313,7,10071],
[M,290,2,9133,302,7,9625],
[M,281,2,8821,289,7,9130],
[M,267,2,8248,280,7,8818],
[M,247,2,7563,266,7,8245],
[M,229,2,6991,246,7,7560],
[M,216,2,6420,228,7,6988],
[M,207,2,6039,215,104,6417],
[M,186,2,5314,206,7,6036],
[M,177,2,5049,185,7,5311],
[M,176,0,5035,451,3,14577],
[M,177,4,5051,177,26,5073],
[M,177,20,5067,177,25,5072],
[M,186,4,5316,186,37,5349],
[M,186,18,5330,186,23,5335],
[M,186,31,5343,186,36,5348],
[M,207,4,6041,207,56,6093],
[M,207,20,6057,207,25,6062],
[M,207,33,6070,207,39,6076],
[M,207,50,6087,207,55,6092],
[M,216,4,6422,216,47,6465],
[M,216,18,6436,216,30,6448],
[M,216,40,6458,216,46,6464],
[M,229,4,6993,229,45,7034],
[M,229,18,7007,229,23,7012],
[M,229,33,7022,229,44,7033],
[M,247,4,7565,247,63,7624],
[M,247,20,7581,247,25,7586],
[M,247,35,7596,247,41,7602],
[M,247,51,7612,247,62,7623],
[M,267,4,8250,267,61,8307],
[M,267,22,8268,267,27,8273],
[M,267,38,8284,267,43,8289],
[M,267,55,8301,267,60,8306],
[M,281,4,8823,281,42,8861],
[M,281,21,8840,281,27,8846],
[M,281,36,8855,281,41,8860],
[M,290,4,9135,290,64,9195],
[M,290,28,9159,290,33,9164],
[M,290,44,9175,290,49,9180],
[M,290,58,9189,290,63,9194],
[M,303,4,9630,303,60,9686],
[M,303,24,9650,303,29,9655],
[M,303,39,9665,303,45,9671],
[M,303,54,9680,303,59,9685],
[M,314,4,10076,314,40,10112],
[M,314,17,10089,314,22,10094],
[M,314,33,10105,314,39,10111],
[M,321,4,10355,321,43,10394],
[M,321,21,10372,321,26,10377],
[M,321,37,10388,321,42,10393],
[M,331,4,10710,331,54,10760],
[M,331,25,10731,331,32,10738],
[M,331,42,10748,331,53,10759],
[M,348,4,11273,348,33,11302],
[M,348,20,11289,348,32,11301],
[M,364,4,11790,364,22,11808],
[M,364,15,11801,364,21,11807],
[M,369,4,11929,369,22,11947],
[M,369,15,11940,369,21,11946],
[M,374,4,12082,374,22,12100],
[M,374,15,12093,374,21,12099],
[M,399,4,12750,399,27,12773],
[M,399,20,12766,399,26,12772],
[M,404,4,12902,404,72,12970],
[M,404,26,12924,404,32,12930],
[M,404,43,12941,404,54,12952],
[M,409,6,13111,409,45,13150],
[M,409,32,13137,409,44,13149],
[M,409,17,13122,409,31,13136],
[M,409,17,13122,409,27,13132],
[M,408,4,13089,412,7,13285],
[M,405,4,12981,407,7,13083],
[M,404,56,12954,404,71,12969],
[M,404,34,12932,404,54,12952],
[M,404,16,12914,404,32,12930],
[M,403,4,12858,403,43,12897],
[M,403,27,12881,403,38,12892],
[M,403,20,12874,403,26,12880],
[M,400,4,12784,402,7,12852],
[M,401,14,12832,401,25,12843],
[M,399,10,12756,399,26,12772],
[M,398,4,12706,398,43,12745],
[M,398,20,12722,398,26,12728],
[M,395,4,12632,397,7,12700],
[M,393,4,12571,393,38,12605],
[M,393,20,12587,393,26,12593],
[M,390,4,12502,392,7,12565],
[M,388,4,12445,388,39,12480],
[M,388,20,12461,388,26,12467],
[M,385,4,12375,387,7,12439],
[M,383,4,12318,383,38,12352],
[M,383,20,12334,383,26,12340],
[M,380,4,12249,382,7,12312],
[M,378,4,12190,378,41,12227],
[M,378,30,12216,378,36,12222],
[M,378,20,12206,378,29,12215],
[M,376,14,12159,376,30,12175],
[M,376,23,12168,376,29,12174],
[M,375,4,12111,377,7,12184],
[M,374,10,12088,374,21,12099],
[M,373,27,12058,373,41,12072],
[M,373,34,12065,373,40,12071],
[M,373,20,12051,373,26,12057],
[M,373,4,12035,373,46,12077],
[M,371,14,12006,371,28,12020],
[M,371,21,12013,371,27,12019],
[M,370,4,11958,372,7,12029],
[M,369,10,11935,369,21,11946],
[M,368,4,11889,368,39,11924],
[M,368,27,11912,368,34,11919],
[M,368,20,11905,368,26,11911],
[M,365,4,11819,367,7,11883],
[M,366,14,11867,366,21,11874],
[M,364,9,11795,364,21,11807],
[M,361,38,11667,361,60,11689],
[M,361,50,11679,361,59,11688],
[M,361,38,11667,361,47,11676],
[M,361,6,11635,361,26,11655],
[M,360,4,11613,363,7,11785],
[M,350,6,11353,350,18,11365],
[M,349,4,11313,359,7,11607],
[M,348,10,11279,348,32,11301],
[M,345,38,11164,345,60,11186],
[M,345,50,11176,345,59,11185],
[M,345,38,11164,345,47,11173],
[M,345,6,11132,345,26,11152],
[M,344,4,11110,347,7,11268],
[M,333,6,10811,333,18,10823],
[M,332,4,10771,343,7,11104],
[M,331,34,10740,331,53,10759],
[M,331,11,10717,331,32,10738],
[M,328,29,10601,328,48,10620],
[M,328,29,10601,328,46,10618],
[M,328,29,10601,328,37,10609],
[M,328,20,10592,328,28,10600],
[M,328,4,10576,330,7,10705],
[M,323,6,10445,323,41,10480],
[M,323,6,10445,323,32,10471],
[M,323,6,10445,323,14,10453],
[M,322,4,10405,327,7,10570],
[M,321,28,10379,321,42,10393],
[M,321,14,10365,321,26,10377],
[M,320,40,10293,320,51,10304],
[M,320,40,10293,320,46,10299],
[M,320,20,10273,320,28,10281],
[M,320,4,10257,320,97,10350],
[M,316,6,10163,316,41,10198],
[M,316,6,10163,316,32,10189],
[M,316,6,10163,316,14,10171],
[M,315,4,10123,319,7,10251],
[M,314,24,10096,314,39,10111],
[M,314,10,10082,314,22,10094],
[M,312,51,9960,312,62,9971],
[M,312,51,9960,312,57,9966],
[M,312,31,9940,312,39,9948],
[M,312,15,9924,312,22,9931],
[M,312,6,9915,312,14,9923],
[M,311,4,9893,313,7,10071],
[M,305,6,9737,305,41,9772],
[M,305,6,9737,305,32,9763],
[M,305,6,9737,305,14,9745],
[M,304,4,9697,310,7,9887],
[M,303,47,9673,303,59,9685],
[M,303,31,9657,303,45,9671],
[M,303,17,9643,303,29,9655],
[M,300,31,9487,300,50,9506],
[M,300,31,9487,300,48,9504],
[M,300,31,9487,300,39,9495],
[M,300,15,9471,300,22,9478],
[M,300,6,9462,300,14,9470],
[M,299,4,9440,302,7,9625],
[M,292,6,9246,292,41,9281],
[M,292,6,9246,292,32,9272],
[M,292,6,9246,292,14,9254],
[M,291,4,9206,298,7,9434],
[M,290,51,9182,290,63,9194],
[M,290,35,9166,290,49,9180],
[M,290,21,9152,290,33,9164],
[M,288,31,9054,288,48,9071],
[M,288,38,9061,288,47,9070],
[M,288,31,9054,288,37,9060],
[M,288,15,9038,288,22,9045],
[M,288,6,9029,288,14,9037],
[M,287,4,9007,289,7,9130],
[M,283,6,8912,283,24,8930],
[M,283,14,8920,283,23,8929],
[M,282,4,8872,286,7,9001],
[M,281,29,8848,281,41,8860],
[M,281,13,8832,281,27,8846],
[M,277,8,8576,277,28,8596],
[M,277,8,8576,277,26,8594],
[M,277,8,8576,277,17,8585],
[M,276,6,8557,276,15,8566],
[M,275,4,8535,280,7,8818],
[M,269,6,8358,269,42,8394],
[M,269,6,8358,269,33,8385],
[M,269,6,8358,269,15,8367],
[M,268,4,8318,274,7,8529],
[M,267,45,8291,267,60,8306],
[M,267,29,8275,267,43,8289],
[M,267,14,8260,267,27,8273],
[M,263,35,8064,263,46,8075],
[M,263,35,8064,263,41,8070],
[M,263,15,8044,263,23,8052],
[M,263,6,8035,263,14,8043],
[M,262,4,8013,266,7,8245],
[M,249,6,7675,249,41,7710],
[M,249,6,7675,249,32,7701],
[M,249,6,7675,249,14,7683],
[M,248,4,7635,261,7,8007],
[M,247,43,7604,247,62,7623],
[M,247,27,7588,247,41,7602],
[M,247,13,7574,247,25,7586],
[M,243,15,7411,243,35,7431],
[M,243,15,7411,243,33,7429],
[M,243,15,7411,243,24,7420],
[M,243,6,7402,243,14,7410],
[M,242,4,7380,246,7,7560],
[M,231,6,7085,231,42,7121],
[M,231,6,7085,231,33,7112],
[M,231,6,7085,231,15,7094],
[M,230,4,7045,241,7,7374],
[M,229,25,7014,229,44,7033],
[M,229,10,6999,229,23,7012],
[M,225,64,6756,225,86,6778],
[M,225,76,6768,225,85,6777],
[M,225,64,6756,225,73,6765],
[M,225,32,6724,225,52,6744],
[M,225,16,6708,225,23,6715],
[M,224,4,6676,228,7,6988],
[M,218,6,6516,218,26,6536],
[M,217,4,6476,223,7,6670],
[M,216,32,6450,216,46,6464],
[M,216,10,6428,216,30,6448],
[M,215,35,6348,215,55,6368],
[M,215,35,6348,215,53,6366],
[M,215,35,6348,215,44,6357],
[M,215,28,6341,215,99,6412],
[M,215,20,6333,215,27,6340],
[M,215,4,6317,215,104,6417],
[M,209,6,6144,209,42,6180],
[M,209,6,6144,209,33,6171],
[M,209,6,6144,209,15,6153],
[M,208,4,6104,214,7,6311],
[M,207,41,6078,207,55,6092],
[M,207,27,6064,207,39,6076],
[M,207,12,6049,207,25,6062],
[M,200,4,5785,206,7,6036],
[M,201,6,5807,205,9,6028],
[M,204,18,5978,204,36,5996],
[M,204,18,5978,204,34,5994],
[M,204,18,5978,204,25,5985],
[M,203,8,5902,203,65,5959],
[M,203,25,5919,203,44,5938],
[M,203,25,5919,203,42,5936],
[M,203,25,5919,203,33,5927],
[M,202,8,5837,202,64,5893],
[M,202,24,5853,202,43,5872],
[M,202,24,5853,202,41,5870],
[M,202,24,5853,202,32,5861],
[M,201,19,5820,201,26,5827],
[M,187,4,5360,199,7,5779],
[M,188,6,5400,198,9,5771],
[M,196,10,5681,196,44,5715],
[M,196,10,5681,196,35,5706],
[M,196,10,5681,196,17,5688],
[M,192,8,5545,194,44,5652],
[M,193,10,5572,193,45,5607],
[M,193,10,5572,193,36,5598],
[M,193,10,5572,193,18,5580],
[M,189,8,5430,191,44,5536],
[M,190,10,5456,190,45,5491],
[M,190,10,5456,190,36,5482],
[M,190,10,5456,190,18,5464],
[M,188,19,5413,188,26,5420],
[M,186,25,5337,186,36,5348],
[M,186,11,5323,186,23,5335],
[M,184,29,5257,184,40,5268],
[M,184,29,5257,184,35,5263],
[M,184,6,5234,184,17,5245],
[M,183,4,5212,185,7,5311],
[M,179,6,5125,179,18,5137],
[M,178,4,5084,182,7,5206],
[M,177,13,5060,177,25,5072],
[M,415,4,13323,415,31,13350],
[M,414,2,13297,418,5,13419],
[M,166,2,4835,166,51,4884],
[M,165,2,4783,165,51,4832],
[M,164,2,4735,164,47,4780],
[M,163,2,4687,163,47,4732],
[M,162,0,4673,174,3,5033],
[M,166,21,4854,166,51,4884],
[M,165,21,4802,165,51,4832],
[M,164,17,4750,164,47,4780],
[M,163,17,4702,163,47,4732],
[M,172,11,5001,172,32,5022],
[M,172,11,5001,172,30,5020],
[M,172,4,4994,172,10,5000],
[M,171,2,4974,173,5,5029],
[M,169,12,4942,169,33,4963],
[M,169,12,4942,169,31,4961],
[M,168,2,4896,170,5,4970],
[M,152,2,4474,152,50,4522],
[M,151,2,4426,151,47,4471],
[M,150,2,4376,150,49,4423],
[M,149,2,4329,149,46,4373],
[M,148,2,4282,148,46,4326],
[M,147,2,4237,147,44,4279],
[M,146,2,4190,146,46,4234],
[M,145,2,4145,145,44,4187],
[M,144,2,4099,144,45,4142],
[M,143,2,4052,143,46,4096],
[M,142,2,4003,142,48,4049],
[M,141,2,3955,141,47,4000],
[M,140,2,3907,140,47,3952],
[M,139,2,3860,139,46,3904],
[M,138,0,3845,160,3,4671],
[M,152,20,4492,152,50,4522],
[M,151,16,4440,151,47,4471],
[M,150,19,4393,150,49,4423],
[M,149,15,4342,149,46,4373],
[M,148,16,4296,148,46,4326],
[M,147,15,4250,147,44,4279],
[M,146,16,4204,146,46,4234],
[M,145,15,4158,145,44,4187],
[M,144,15,4112,144,45,4142],
[M,143,16,4066,143,46,4096],
[M,142,19,4020,142,48,4049],
[M,141,18,3971,141,47,4000],
[M,140,18,3923,140,47,3952],
[M,139,17,3875,139,46,3904],
[M,158,11,4639,158,32,4660],
[M,158,11,4639,158,30,4658],
[M,158,4,4632,158,10,4638],
[M,157,2,4612,159,5,4667],
[M,155,12,4580,155,33,4601],
[M,155,12,4580,155,31,4599],
[M,154,2,4534,156,5,4608],
[M,122,2,3498,129,7,3705],
[M,113,2,3220,121,7,3495],
[M,101,2,2710,112,7,3217],
[M,92,2,2453,100,7,2707],
[M,72,2,1723,91,7,2450],
[M,60,2,1293,71,7,1720],
[M,49,2,904,59,7,1290],
[M,48,0,890,136,3,3843],
[M,49,4,906,49,39,941],
[M,49,18,920,49,24,926],
[M,49,33,935,49,38,940],
[M,60,4,1295,60,41,1332],
[M,60,18,1309,60,23,1314],
[M,60,34,1325,60,40,1331],
[M,72,4,1725,72,55,1776],
[M,72,17,1738,72,22,1743],
[M,72,33,1754,72,39,1760],
[M,72,48,1769,72,54,1775],
[M,92,4,2455,92,27,2478],
[M,92,21,2472,92,26,2477],
[M,101,4,2712,101,62,2770],
[M,101,24,2732,101,29,2737],
[M,101,38,2746,101,44,2752],
[M,101,55,2763,101,61,2769],
[M,113,4,3222,113,25,3243],
[M,113,19,3237,113,24,3242],
[M,122,4,3500,122,25,3521],
[M,122,19,3515,122,24,3520],
[M,128,6,3663,128,26,3683],
[M,128,6,3663,128,24,3681],
[M,128,6,3663,128,15,3672],
[M,127,4,3641,129,7,3705],
[M,124,6,3572,124,42,3608],
[M,124,6,3572,124,33,3599],
[M,124,6,3572,124,15,3581],
[M,123,4,3532,126,7,3635],
[M,122,11,3507,122,24,3520],
[M,120,31,3433,120,47,3449],
[M,120,31,3433,120,37,3439],
[M,120,15,3417,120,22,3424],
[M,120,6,3408,120,14,3416],
[M,119,4,3386,121,7,3495],
[M,115,6,3294,115,23,3311],
[M,114,4,3254,118,7,3380],
[M,113,12,3230,113,24,3242],
[M,110,29,3055,110,44,3070],
[M,110,29,3055,110,35,3061],
[M,110,6,3032,110,17,3043],
[M,109,4,3010,112,7,3217],
[M,103,6,2821,103,24,2839],
[M,102,4,2781,108,7,3004],
[M,101,46,2754,101,61,2769],
[M,101,31,2739,101,44,2752],
[M,101,16,2724,101,29,2737],
[M,99,6,2645,99,23,2662],
[M,99,6,2645,99,12,2651],
[M,98,4,2623,100,7,2707],
[M,94,6,2529,94,24,2547],
[M,93,4,2489,97,7,2617],
[M,92,13,2464,92,26,2477],
[M,83,6,2080,83,35,2109],
[M,83,16,2090,83,33,2107],
[M,83,16,2090,83,24,2098],
[M,82,4,2058,91,7,2450],
[M,74,6,1827,74,20,1841],
[M,73,4,1787,81,7,2052],
[M,72,41,1762,72,54,1775],
[M,72,24,1745,72,39,1760],
[M,72,9,1730,72,22,1743],
[M,69,15,1573,69,27,1585],
[M,69,15,1573,69,21,1579],
[M,69,6,1564,69,14,1572],
[M,68,4,1542,71,7,1720],
[M,62,6,1383,62,20,1397],
[M,61,4,1343,67,7,1536],
[M,60,25,1316,60,40,1331],
[M,60,10,1301,60,23,1314],
[M,57,8,1142,57,22,1156],
[M,57,8,1142,57,14,1148],
[M,56,6,1124,56,14,1132],
[M,55,4,1102,59,7,1290],
[M,51,14,1000,51,41,1027],
[M,51,23,1009,51,32,1018],
[M,50,4,952,54,7,1096],
[M,49,26,928,49,38,940],
[M,49,10,912,49,24,926],
[M,132,4,3743,132,31,3770],
[M,131,2,3717,135,5,3839],
[M,24,2,289,39,7,750],
[M,23,0,274,46,3,888],
[M,24,4,291,24,33,320],
[M,24,21,308,24,32,319],
[M,34,4,589,39,7,750],
[M,35,6,611,38,9,742],
[M,37,57,721,37,67,731],
[M,37,43,707,37,55,719],
[M,37,30,694,37,41,705],
[M,37,18,682,37,29,693],
[M,36,8,643,36,28,663],
[M,36,19,654,36,28,663],
[M,35,18,623,35,28,633],
[M,26,6,371,32,9,575],
[M,26,19,384,26,29,394],
[M,25,4,331,33,7,583],
[M,24,12,299,24,32,319],
[M,42,4,788,42,31,815],
[M,41,2,762,45,5,884],
[M,14,0,159,20,3,271],
[M,18,9,249,18,23,263],
[M,17,12,212,17,38,238],
[M,17,27,227,17,34,234],
[M,421,2,13430,422,37,13569],
[M,421,8,13436,421,23,13451],
[M,421,46,13474,421,55,13483],
[M,421,33,13461,421,76,13504],
[M,421,64,13492,421,73,13501],
[M,421,57,13485,421,74,13502],
[M,421,40,13468,421,75,13503],
[M,421,25,13453,421,77,13505],
[M,421,2,13430,421,78,13506],
[M,421,2,13430,421,89,13517],
[M,421,2,13430,421,87,13515],
[M,421,2,13430,421,100,13528],
[M,421,2,13430,421,96,13524],
[M,422,4,13536,422,37,13569],
[M,424,2,13573,434,5,13992],
[M,424,8,13579,424,38,13609],
[M,425,30,13657,425,47,13674],
[M,424,48,13619,427,5,13795],
[M,425,63,13690,425,77,13704],
[M,425,56,13683,425,78,13705],
[M,425,21,13648,425,79,13706],
[M,425,6,13633,425,80,13707],
[M,426,30,13739,426,47,13756],
[M,426,63,13772,426,77,13786],
[M,426,56,13765,426,78,13787],
[M,426,21,13730,426,79,13788],
[M,426,6,13715,426,80,13789],
[M,424,40,13611,427,6,13796],
[M,424,2,13573,427,7,13797],
[M,424,2,13573,427,18,13808],
[M,424,2,13573,427,16,13806],
[M,424,2,13573,427,29,13819],
[M,424,2,13573,427,25,13815],
[M,429,4,13831,434,5,13992],
[M,436,2,13996,440,0,14157],
[M,436,2,13996,436,19,14013],
[M,436,2,13996,436,17,14011],
[M,436,2,13996,436,29,14023],
[M,436,2,13996,436,26,14020],
[M,436,33,14027,436,47,14041],
[M,441,2,14160,443,42,14316],
[M,442,11,14213,442,25,14227],
[M,442,4,14206,442,37,14239],
[M,442,27,14229,442,36,14238],
[M,441,2,14160,442,46,14248],
[M,441,2,14160,442,57,14259],
[M,441,2,14160,442,55,14257],
[M,441,2,14160,442,68,14270],
[M,441,2,14160,442,64,14266],
[M,443,4,14278,443,42,14316],
[M,445,2,14320,447,59,14495],
[M,445,30,14348,445,47,14365],
[M,445,23,14341,445,48,14366],
[M,445,15,14333,445,49,14367],
[M,445,75,14393,445,83,14401],
[M,445,59,14377,445,85,14403],
[M,445,66,14384,445,84,14402],
[M,445,51,14369,445,86,14404],
[M,445,2,14320,445,87,14405],
[M,445,2,14320,446,15,14421],
[M,445,2,14320,446,13,14419],
[M,445,2,14320,446,26,14432],
[M,445,2,14320,446,22,14428],
[M,447,4,14440,447,59,14495],
[M,449,2,14499,449,75,14572],
[M,449,2,14499,449,28,14525],
[M,449,2,14499,449,39,14536],
[M,449,2,14499,449,37,14534],
[M,449,2,14499,449,50,14547],
[M,449,2,14499,449,46,14543],
[M,449,54,14551,449,75,14572],
[M,462,22,14841,462,50,14869],
[M,462,53,14872,462,65,14884],
[M,462,53,14872,462,59,14878],
[M,462,22,14841,462,90,14909],
[M,462,68,14887,462,89,14908],
[M,462,68,14887,462,87,14906],
[M,462,68,14887,462,78,14897],
[M,457,6,14706,457,24,14724],
[M,457,14,14714,457,23,14723],
[M,458,6,14731,458,20,14745],
[M,459,6,14752,459,34,14780],
[M,459,6,14752,459,16,14762],
[M,467,4,14987,467,43,15026],
[M,467,27,15010,467,42,15025],
[M,467,4,14987,467,26,15009],
[M,468,4,15031,468,16,15043],
[M,410,17,13168,410,61,13212],
[M,410,30,13181,410,60,13211],
[M,410,39,13190,410,59,13210],
[M,410,17,13168,410,29,13180],
[M,410,6,13157,410,82,13233],
[M,410,66,13217,410,81,13232],
[M,410,17,13168,410,65,13216],
[M,411,13,13247,411,42,13276],
[M,411,20,13254,411,31,13265],
[M,411,6,13240,411,12,13246],
[M,362,45,11735,362,86,11776],
[M,362,61,11751,362,85,11775],
[M,362,69,11759,362,79,11769],
[M,362,45,11735,362,60,11750],
[M,362,45,11735,362,56,11746],
[M,362,34,11724,362,43,11733],
[M,362,19,11709,362,32,11722],
[M,362,8,11698,362,17,11707],
[M,351,6,11372,357,9,11580],
[M,351,19,11385,351,30,11396],
[M,352,8,11407,352,52,11451],
[M,352,8,11407,352,43,11442],
[M,352,8,11407,352,25,11424],
[M,352,8,11407,352,19,11418],
[M,351,11,11377,351,31,11397],
[M,352,8,11407,356,11,11570],
[M,353,24,11476,353,40,11492],
[M,353,24,11476,353,35,11487],
[M,353,8,11460,356,11,11570],
[M,354,10,11505,354,24,11519],
[M,355,10,11530,355,29,11549],
[M,346,45,11232,346,72,11259],
[M,346,59,11246,346,71,11258],
[M,346,45,11232,346,58,11245],
[M,346,45,11232,346,54,11241],
[M,346,34,11221,346,43,11230],
[M,346,19,11206,346,32,11219],
[M,346,8,11195,346,17,11204],
[M,334,6,10830,341,9,11077],
[M,334,19,10843,334,28,10852],
[M,335,8,10863,335,50,10905],
[M,335,8,10863,335,41,10896],
[M,335,8,10863,335,23,10878],
[M,335,8,10863,335,17,10872],
[M,334,11,10835,334,29,10853],
[M,335,8,10863,340,11,11067],
[M,336,24,10930,336,38,10944],
[M,336,24,10930,336,33,10939],
[M,336,8,10914,340,11,11067],
[M,337,10,10957,337,22,10969],
[M,338,32,11002,338,45,11015],
[M,338,10,10980,338,46,11016],
[M,338,15,10985,338,30,11000],
[M,339,10,11027,339,29,11046],
[M,329,40,10663,329,61,10684],
[M,329,40,10663,329,59,10682],
[M,329,40,10663,329,50,10673],
[M,329,29,10652,329,38,10661],
[M,329,6,10629,329,17,10640],
[M,329,6,10629,329,73,10696],
[M,329,63,10686,329,72,10695],
[M,328,29,10601,329,74,10697],
[M,324,6,10487,324,18,10499],
[M,325,6,10506,325,43,10543],
[M,325,6,10506,325,34,10534],
[M,325,6,10506,325,16,10516],
[M,320,53,10306,320,72,10325],
[M,320,53,10306,320,70,10323],
[M,320,53,10306,320,61,10314],
[M,320,74,10327,320,92,10345],
[M,320,81,10334,320,91,10344],
[M,320,74,10327,320,80,10333],
[M,317,6,10205,317,18,10217],
[M,318,14,10232,318,24,10242],
[M,312,64,9973,312,83,9992],
[M,312,64,9973,312,81,9990],
[M,312,64,9973,312,72,9981],
[M,312,85,9994,312,102,10011],
[M,312,92,10001,312,101,10010],
[M,312,85,9994,312,91,10000],
[M,312,31,9940,312,103,10012],
[M,312,106,10015,312,118,10027],
[M,312,106,10015,312,112,10021],
[M,312,31,9940,312,153,10062],
[M,312,133,10042,312,152,10061],
[M,312,133,10042,312,150,10059],
[M,312,133,10042,312,141,10050],
[M,312,15,9924,312,153,10062],
[M,306,6,9779,306,18,9791],
[M,307,6,9798,307,24,9816],
[M,307,14,9806,307,23,9815],
[M,308,6,9823,308,20,9837],
[M,309,6,9844,309,32,9870],
[M,309,6,9844,309,14,9852],
[M,300,31,9487,301,46,9616],
[M,300,53,9509,300,62,9518],
[M,300,65,9521,300,86,9542],
[M,300,65,9521,300,84,9540],
[M,300,65,9521,300,75,9531],
[M,300,89,9545,300,98,9554],
[M,300,101,9557,300,113,9569],
[M,300,101,9557,300,107,9563],
[M,301,26,9596,301,45,9615],
[M,301,26,9596,301,43,9613],
[M,301,26,9596,301,34,9604],
[M,300,15,9471,301,46,9616],
[M,293,6,9288,293,18,9300],
[M,294,6,9307,294,43,9344],
[M,294,6,9307,294,34,9335],
[M,294,6,9307,294,16,9317],
[M,295,6,9351,295,18,9363],
[M,296,6,9370,296,20,9384],
[M,297,6,9391,297,32,9417],
[M,297,6,9391,297,14,9399],
[M,288,51,9074,288,63,9086],
[M,288,51,9074,288,57,9080],
[M,288,31,9054,288,98,9121],
[M,288,78,9101,288,97,9120],
[M,288,78,9101,288,95,9118],
[M,288,78,9101,288,86,9109],
[M,288,15,9038,288,98,9121],
[M,284,6,8937,284,20,8951],
[M,285,6,8958,285,32,8984],
[M,285,6,8958,285,14,8966],
[M,278,40,8637,278,51,8648],
[M,278,40,8637,278,46,8643],
[M,278,12,8609,278,19,8616],
[M,278,28,8625,278,105,8702],
[M,278,82,8679,278,103,8700],
[M,278,82,8679,278,101,8698],
[M,278,82,8679,278,92,8689],
[M,278,66,8663,278,73,8670],
[M,278,66,8663,278,104,8701],
[M,278,12,8609,278,105,8702],
[M,277,8,8576,279,107,8810],
[M,279,40,8743,279,51,8754],
[M,279,40,8743,279,46,8749],
[M,279,12,8715,279,19,8722],
[M,279,28,8731,279,106,8809],
[M,279,82,8785,279,104,8807],
[M,279,82,8785,279,102,8805],
[M,279,82,8785,279,93,8796],
[M,279,66,8769,279,73,8776],
[M,279,66,8769,279,105,8808],
[M,279,12,8715,279,106,8809],
[M,270,6,8401,270,18,8413],
[M,271,6,8420,271,43,8457],
[M,271,6,8420,271,34,8448],
[M,271,6,8420,271,16,8430],
[M,272,6,8464,272,18,8476],
[M,273,6,8483,273,35,8512],
[M,273,6,8483,273,17,8494],
[M,263,48,8077,263,67,8096],
[M,263,48,8077,263,65,8094],
[M,263,48,8077,263,56,8085],
[M,263,69,8098,263,86,8115],
[M,263,76,8105,263,85,8114],
[M,263,69,8098,263,75,8104],
[M,263,15,8044,263,87,8116],
[M,265,39,8194,265,78,8233],
[M,265,53,8208,265,77,8232],
[M,265,61,8216,265,71,8226],
[M,265,39,8194,265,52,8207],
[M,265,39,8194,265,48,8203],
[M,265,24,8179,265,37,8192],
[M,265,12,8167,265,23,8178],
[M,264,22,8139,264,29,8146],
[M,264,12,8129,264,21,8138],
[M,265,12,8167,265,79,8234],
[M,264,22,8139,265,80,8235],
[M,264,12,8129,265,81,8236],
[M,263,15,8044,265,82,8237],
[M,250,6,7717,250,18,7729],
[M,251,6,7736,251,24,7754],
[M,251,14,7744,251,23,7753],
[M,252,6,7761,252,18,7773],
[M,253,6,7780,259,9,7980],
[M,253,19,7793,253,28,7802],
[M,254,8,7813,254,50,7855],
[M,254,8,7813,254,41,7846],
[M,254,8,7813,254,23,7828],
[M,254,8,7813,254,17,7822],
[M,253,11,7785,253,29,7803],
[M,254,8,7813,258,11,7970],
[M,255,24,7880,255,38,7894],
[M,255,24,7880,255,33,7889],
[M,255,8,7864,258,11,7970],
[M,256,10,7907,256,22,7919],
[M,257,10,7930,257,29,7949],
[M,245,39,7509,245,78,7548],
[M,245,53,7523,245,77,7547],
[M,245,61,7531,245,71,7541],
[M,245,39,7509,245,52,7522],
[M,245,39,7509,245,48,7518],
[M,245,24,7494,245,37,7507],
[M,245,12,7482,245,23,7493],
[M,244,22,7454,244,29,7461],
[M,244,12,7444,244,21,7453],
[M,245,12,7482,245,79,7549],
[M,244,22,7454,245,80,7550],
[M,244,12,7444,245,81,7551],
[M,243,15,7411,245,82,7552],
[M,232,6,7128,232,18,7140],
[M,233,6,7147,239,9,7347],
[M,233,19,7160,233,28,7169],
[M,234,8,7180,234,50,7222],
[M,234,8,7180,234,41,7213],
[M,234,8,7180,234,23,7195],
[M,234,8,7180,234,17,7189],
[M,233,11,7152,233,29,7170],
[M,234,8,7180,238,11,7337],
[M,235,24,7247,235,38,7261],
[M,235,24,7247,235,33,7256],
[M,235,8,7231,238,11,7337],
[M,236,10,7274,236,22,7286],
[M,237,10,7297,237,29,7316],
[M,225,124,6816,225,145,6837],
[M,225,138,6830,225,144,6836],
[M,225,124,6816,225,137,6829],
[M,225,124,6816,225,133,6825],
[M,225,113,6805,225,122,6814],
[M,225,98,6790,225,111,6803],
[M,225,87,6779,225,96,6788],
[M,225,32,6724,225,146,6838],
[M,225,6,6698,225,147,6839],
[M,226,24,6864,226,42,6882],
[M,226,24,6864,226,30,6870],
[M,226,15,6855,226,23,6863],
[M,226,24,6864,226,53,6893],
[M,226,6,6846,226,53,6893],
[M,227,38,6932,227,50,6944],
[M,227,38,6932,227,44,6938],
[M,227,6,6900,227,17,6911],
[M,227,29,6923,227,51,6945],
[M,227,52,6946,227,72,6966],
[M,227,52,6946,227,70,6964],
[M,227,52,6946,227,61,6955],
[M,227,74,6968,227,85,6979],
[M,227,74,6968,227,80,6974],
[M,219,14,6551,219,37,6574],
[M,219,14,6551,219,32,6569],
[M,219,14,6551,219,23,6560],
[M,219,6,6543,219,38,6575],
[M,220,6,6582,220,22,6598],
[M,221,6,6605,221,42,6641],
[M,221,6,6605,221,33,6632],
[M,221,6,6605,221,15,6614],
[M,215,57,6370,215,75,6388],
[M,215,57,6370,215,73,6386],
[M,215,57,6370,215,64,6377],
[M,215,77,6390,215,98,6411],
[M,215,77,6390,215,96,6409],
[M,215,77,6390,215,87,6400],
[M,210,6,6187,210,18,6199],
[M,211,6,6206,211,40,6240],
[M,211,6,6206,211,31,6231],
[M,211,6,6206,211,13,6213],
[M,212,6,6247,212,18,6259],
[M,213,6,6266,213,34,6294],
[M,213,6,6266,213,16,6276],
[M,204,39,5999,204,58,6018],
[M,204,39,5999,204,56,6016],
[M,204,39,5999,204,47,6007],
[M,203,47,5941,203,65,5959],
[M,203,47,5941,203,63,5957],
[M,203,47,5941,203,54,5948],
[M,202,46,5875,202,64,5893],
[M,202,46,5875,202,62,5891],
[M,202,46,5875,202,53,5882],
[M,197,10,5726,197,36,5752],
[M,197,10,5726,197,18,5734],
[M,194,10,5618,194,35,5643],
[M,194,10,5618,194,17,5625],
[M,191,10,5502,191,35,5527],
[M,191,10,5502,191,17,5509],
[M,184,42,5270,184,61,5289],
[M,184,42,5270,184,59,5287],
[M,184,42,5270,184,50,5278],
[M,184,63,5291,184,74,5302],
[M,184,63,5291,184,69,5297],
[M,180,6,5144,180,41,5179],
[M,180,6,5144,180,32,5170],
[M,180,6,5144,180,14,5152],
[M,416,4,13355,416,43,13394],
[M,416,27,13378,416,42,13393],
[M,416,4,13355,416,26,13377],
[M,417,4,13399,417,16,13411],
[M,128,29,3686,128,40,3697],
[M,128,29,3686,128,35,3692],
[M,120,50,3452,120,69,3471],
[M,120,50,3452,120,67,3469],
[M,120,50,3452,120,58,3460],
[M,120,31,3433,120,70,3472],
[M,120,15,3417,120,70,3472],
[M,120,6,3408,120,71,3473],
[M,120,74,3476,120,85,3487],
[M,120,74,3476,120,80,3482],
[M,116,6,3318,116,41,3353],
[M,116,6,3318,116,32,3344],
[M,116,6,3318,116,14,3326],
[M,110,46,3072,110,66,3092],
[M,110,46,3072,110,64,3090],
[M,110,46,3072,110,55,3081],
[M,110,6,3032,110,78,3104],
[M,110,68,3094,110,77,3103],
[M,111,40,3145,111,69,3174],
[M,111,52,3157,111,60,3165],
[M,111,33,3138,111,39,3144],
[M,111,10,3115,111,21,3126],
[M,111,33,3138,111,69,3174],
[M,111,71,3176,111,92,3197],
[M,111,71,3176,111,90,3195],
[M,111,71,3176,111,81,3186],
[M,111,10,3115,111,104,3209],
[M,111,94,3199,111,103,3208],
[M,104,6,2846,104,42,2882],
[M,104,6,2846,104,33,2873],
[M,104,6,2846,104,15,2855],
[M,105,14,2897,105,48,2931],
[M,105,29,2912,105,37,2920],
[M,105,6,2889,105,48,2931],
[M,106,6,2938,106,43,2975],
[M,106,6,2938,106,34,2966],
[M,106,6,2938,106,16,2948],
[M,99,26,2665,99,46,2685],
[M,99,26,2665,99,44,2683],
[M,99,26,2665,99,35,2674],
[M,99,6,2645,99,60,2699],
[M,99,49,2688,99,60,2699],
[M,99,49,2688,99,55,2694],
[M,95,6,2554,95,42,2590],
[M,95,6,2554,95,33,2581],
[M,95,6,2554,95,15,2563],
[M,85,33,2160,85,42,2169],
[M,86,14,2184,86,30,2200],
[M,86,14,2184,86,20,2190],
[M,85,11,2138,85,32,2159],
[M,88,15,2284,88,27,2296],
[M,88,15,2284,88,21,2290],
[M,88,6,2275,88,14,2283],
[M,85,22,2149,85,31,2158],
[M,86,33,2203,86,86,2256],
[M,86,76,2246,86,85,2255],
[M,86,56,2226,86,65,2235],
[M,86,33,2203,86,44,2214],
[M,86,14,2184,86,86,2256],
[M,88,40,2309,88,60,2329],
[M,88,40,2309,88,58,2327],
[M,88,40,2309,88,49,2318],
[M,88,30,2299,88,39,2308],
[M,88,30,2299,88,61,2330],
[M,88,15,2284,88,62,2331],
[M,88,6,2275,88,62,2331],
[M,88,65,2334,88,76,2345],
[M,88,65,2334,88,71,2340],
[M,88,6,2275,90,18,2442],
[M,89,44,2390,89,65,2411],
[M,89,44,2390,89,63,2409],
[M,89,44,2390,89,54,2400],
[M,89,33,2379,89,42,2388],
[M,89,10,2356,89,21,2367],
[M,89,10,2356,89,77,2423],
[M,89,67,2413,89,76,2422],
[M,75,6,1848,75,42,1884],
[M,75,6,1848,75,33,1875],
[M,75,6,1848,75,15,1857],
[M,76,6,1891,76,22,1907],
[M,77,6,1914,77,43,1951],
[M,77,6,1914,77,34,1942],
[M,77,6,1914,77,16,1924],
[M,78,6,1958,78,29,1981],
[M,79,6,1988,79,41,2023],
[M,79,6,1988,79,32,2014],
[M,79,6,1988,79,14,1996],
[M,69,40,1598,69,60,1618],
[M,69,40,1598,69,58,1616],
[M,69,40,1598,69,49,1607],
[M,69,30,1588,69,39,1597],
[M,69,30,1588,69,61,1619],
[M,69,15,1573,69,62,1620],
[M,69,6,1564,69,62,1620],
[M,69,65,1623,69,76,1634],
[M,69,65,1623,69,71,1629],
[M,69,6,1564,70,77,1712],
[M,70,44,1679,70,65,1700],
[M,70,44,1679,70,63,1698],
[M,70,44,1679,70,54,1689],
[M,70,33,1668,70,42,1677],
[M,70,10,1645,70,21,1656],
[M,70,10,1645,70,77,1712],
[M,70,67,1702,70,76,1711],
[M,63,6,1404,63,42,1440],
[M,63,6,1404,63,33,1431],
[M,63,6,1404,63,15,1413],
[M,64,6,1447,64,22,1463],
[M,65,6,1470,65,43,1507],
[M,65,6,1470,65,34,1498],
[M,65,6,1470,65,16,1480],
[M,57,50,1184,57,67,1201],
[M,57,57,1191,57,66,1200],
[M,57,50,1184,57,56,1190],
[M,57,34,1168,57,41,1175],
[M,57,25,1159,57,33,1167],
[M,58,12,1216,58,24,1228],
[M,58,12,1216,58,18,1222],
[M,57,50,1184,58,62,1266],
[M,58,27,1231,58,39,1243],
[M,58,27,1231,58,36,1240],
[M,58,42,1246,58,61,1265],
[M,58,42,1246,58,59,1263],
[M,58,42,1246,58,50,1254],
[M,57,34,1168,58,62,1266],
[M,57,25,1159,58,63,1267],
[M,57,8,1142,58,78,1282],
[M,58,66,1270,58,77,1281],
[M,58,66,1270,58,72,1276],
[M,51,6,992,51,41,1027],
[M,52,6,1034,52,41,1069],
[M,52,6,1034,52,32,1060],
[M,52,6,1034,52,14,1042],
[M,133,4,3775,133,43,3814],
[M,133,27,3798,133,42,3813],
[M,133,4,3775,133,26,3797],
[M,134,4,3819,134,16,3831],
[M,27,8,405,27,51,448],
[M,27,8,405,27,42,439],
[M,27,8,405,27,24,421],
[M,27,8,405,27,18,415],
[M,26,11,376,26,30,395],
[M,27,8,405,31,11,565],
[M,28,24,473,28,39,488],
[M,28,24,473,28,34,483],
[M,28,8,457,31,11,565],
[M,29,10,501,29,23,514],
[M,30,10,525,30,29,544],
[M,43,4,820,43,43,859],
[M,43,27,843,43,42,858],
[M,43,4,820,43,26,842],
[M,44,4,864,44,16,876],
[M,3,0,13,470,3,15055],
[M,11,0,109,11,24,133],
[M,11,12,121,11,21,130],
[M,8,9,88,8,17,96]];
var _plus14 = NAMESPACE.get("_plus");
var builtins15 = NAMESPACE.get("builtins");
var nothing16 = NAMESPACE.get("nothing");
var raise17 = NAMESPACE.get("raise");
var torepr18 = NAMESPACE.get("torepr");
var tostring19 = NAMESPACE.get("tostring");
var $type$Boolean20 = NAMESPACE.get("$type$Boolean");
var $type$Number21 = NAMESPACE.get("$type$Number");
var $type$String22 = NAMESPACE.get("$type$String");
var $Hbreak_DASH_one281345 = function(break_DASH_one7846,INDENT7747,JBinop6848,JBinopT46949,JBlock6450,JBlockT26551,JExpr7252,JExprT67353,JField7454,JFieldT77555,JStmt6656,JStmtT36757,JUnop7058,JUnopT57159,List1560,PP123,each4361,format7662,is_DASH_link2563,list2364,_plus14,builtins15,nothing16,raise17,torepr18,tostring19,$type$Boolean20,$type$Number21,$type$String22) {
var anf_fun275 = G(PP123,"blank",L[1]);
var $z6768 = D;
var $f7374 = function(_) {
return R.isFunction(anf_fun275)?anf_fun275.app((1)):R.ffi.throwNonFunApp(L[0],anf_fun275,[(1)]);
};
try {
if(--R.GAS > 0) {
$z6768 = $f7374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7374,
"from":L[0]});
}
} catch($e6566) {
if(R.isCont($e6566)) {
var $ss6970 = {"from":L[0],
"go":function(blank_DASH_one7976) {
return $Hblank_DASH_one281277(blank_DASH_one7976,INDENT7747,JBinop6848,JBinopT46949,JBlock6450,JBlockT26551,JExpr7252,JExprT67353,JField7454,JFieldT77555,JStmt6656,JStmtT36757,JUnop7058,JUnopT57159,List1560,PP123,break_DASH_one7846,each4361,format7662,is_DASH_link2563,list2364,_plus14,builtins15,nothing16,raise17,torepr18,tostring19,$type$Boolean20,$type$Number21,$type$String22);
}};
$e6566.stack[R.EXN_STACKHEIGHT++] = $ss6970;
}
if(R.isPyretException($e6566)) {
$e6566.pyretStack.push(L[0]);
}
throw $e6566;
}
var $ret7172 = $Hblank_DASH_one281277($z6768,INDENT7747,JBinop6848,JBinopT46949,JBlock6450,JBlockT26551,JExpr7252,JExprT67353,JField7454,JFieldT77555,JStmt6656,JStmtT36757,JUnop7058,JUnopT57159,List1560,PP123,break_DASH_one7846,each4361,format7662,is_DASH_link2563,list2364,_plus14,builtins15,nothing16,raise17,torepr18,tostring19,$type$Boolean20,$type$Number21,$type$String22);
++R.GAS;
return $ret7172;
};
var $Hblank_DASH_one281277 = function(blank_DASH_one7976,INDENT7747,JBinop6848,JBinopT46949,JBlock6450,JBlockT26551,JExpr7252,JExprT67353,JField7454,JFieldT77555,JStmt6656,JStmtT36757,JUnop7058,JUnopT57159,List1560,PP123,break_DASH_one7846,each4361,format7662,is_DASH_link2563,list2364,_plus14,builtins15,nothing16,raise17,torepr18,tostring19,$type$Boolean20,$type$Number21,$type$String22) {
var string_DASH_printer8078 = {"$var":D,
"$name":"string-printer"};
var JBlock88180 = {"$var":D,
"$name":"JBlock8"};
var JBlock8282 = {"$var":D,
"$name":"JBlock"};
var is_DASH_JBlock8384 = {"$var":D,
"$name":"is-JBlock"};
var is_DASH_j_DASH_block8486 = {"$var":D,
"$name":"is-j-block"};
var j_DASH_block8588 = {"$var":D,
"$name":"j-block"};
var JStmt98690 = {"$var":D,
"$name":"JStmt9"};
var JStmt8792 = {"$var":D,
"$name":"JStmt"};
var is_DASH_JStmt8894 = {"$var":D,
"$name":"is-JStmt"};
var is_DASH_j_DASH_var8996 = {"$var":D,
"$name":"is-j-var"};
var j_DASH_var9098 = {"$var":D,
"$name":"j-var"};
var is_DASH_j_DASH_if191100 = {"$var":D,
"$name":"is-j-if1"};
var j_DASH_if192102 = {"$var":D,
"$name":"j-if1"};
var is_DASH_j_DASH_if93104 = {"$var":D,
"$name":"is-j-if"};
var j_DASH_if94106 = {"$var":D,
"$name":"j-if"};
var is_DASH_j_DASH_return95108 = {"$var":D,
"$name":"is-j-return"};
var j_DASH_return96110 = {"$var":D,
"$name":"j-return"};
var is_DASH_j_DASH_try_DASH_catch97112 = {"$var":D,
"$name":"is-j-try-catch"};
var j_DASH_try_DASH_catch98114 = {"$var":D,
"$name":"j-try-catch"};
var is_DASH_j_DASH_throw99116 = {"$var":D,
"$name":"is-j-throw"};
var j_DASH_throw100118 = {"$var":D,
"$name":"j-throw"};
var is_DASH_j_DASH_expr101120 = {"$var":D,
"$name":"is-j-expr"};
var j_DASH_expr102122 = {"$var":D,
"$name":"j-expr"};
var JBinop10103124 = {"$var":D,
"$name":"JBinop10"};
var JBinop104126 = {"$var":D,
"$name":"JBinop"};
var is_DASH_JBinop105128 = {"$var":D,
"$name":"is-JBinop"};
var is_DASH_j_DASH_plus106130 = {"$var":D,
"$name":"is-j-plus"};
var j_DASH_plus107132 = {"$var":D,
"$name":"j-plus"};
var is_DASH_j_DASH_minus108134 = {"$var":D,
"$name":"is-j-minus"};
var j_DASH_minus109136 = {"$var":D,
"$name":"j-minus"};
var is_DASH_j_DASH_times110138 = {"$var":D,
"$name":"is-j-times"};
var j_DASH_times111140 = {"$var":D,
"$name":"j-times"};
var is_DASH_j_DASH_divide112142 = {"$var":D,
"$name":"is-j-divide"};
var j_DASH_divide113144 = {"$var":D,
"$name":"j-divide"};
var is_DASH_j_DASH_and114146 = {"$var":D,
"$name":"is-j-and"};
var j_DASH_and115148 = {"$var":D,
"$name":"j-and"};
var is_DASH_j_DASH_or116150 = {"$var":D,
"$name":"is-j-or"};
var j_DASH_or117152 = {"$var":D,
"$name":"j-or"};
var is_DASH_j_DASH_lt118154 = {"$var":D,
"$name":"is-j-lt"};
var j_DASH_lt119156 = {"$var":D,
"$name":"j-lt"};
var is_DASH_j_DASH_leq120158 = {"$var":D,
"$name":"is-j-leq"};
var j_DASH_leq121160 = {"$var":D,
"$name":"j-leq"};
var is_DASH_j_DASH_gt122162 = {"$var":D,
"$name":"is-j-gt"};
var j_DASH_gt123164 = {"$var":D,
"$name":"j-gt"};
var is_DASH_j_DASH_geq124166 = {"$var":D,
"$name":"is-j-geq"};
var j_DASH_geq125168 = {"$var":D,
"$name":"j-geq"};
var is_DASH_j_DASH_eq126170 = {"$var":D,
"$name":"is-j-eq"};
var j_DASH_eq127172 = {"$var":D,
"$name":"j-eq"};
var is_DASH_j_DASH_equals128174 = {"$var":D,
"$name":"is-j-equals"};
var j_DASH_equals129176 = {"$var":D,
"$name":"j-equals"};
var is_DASH_j_DASH_neq130178 = {"$var":D,
"$name":"is-j-neq"};
var j_DASH_neq131180 = {"$var":D,
"$name":"j-neq"};
var is_DASH_j_DASH_nequals132182 = {"$var":D,
"$name":"is-j-nequals"};
var j_DASH_nequals133184 = {"$var":D,
"$name":"j-nequals"};
var JUnop11134186 = {"$var":D,
"$name":"JUnop11"};
var JUnop135188 = {"$var":D,
"$name":"JUnop"};
var is_DASH_JUnop136190 = {"$var":D,
"$name":"is-JUnop"};
var is_DASH_j_DASH_incr137192 = {"$var":D,
"$name":"is-j-incr"};
var j_DASH_incr138194 = {"$var":D,
"$name":"j-incr"};
var is_DASH_j_DASH_decr139196 = {"$var":D,
"$name":"is-j-decr"};
var j_DASH_decr140198 = {"$var":D,
"$name":"j-decr"};
var is_DASH_j_DASH_postincr141200 = {"$var":D,
"$name":"is-j-postincr"};
var j_DASH_postincr142202 = {"$var":D,
"$name":"j-postincr"};
var is_DASH_j_DASH_postdecr143204 = {"$var":D,
"$name":"is-j-postdecr"};
var j_DASH_postdecr144206 = {"$var":D,
"$name":"j-postdecr"};
var JExpr12145208 = {"$var":D,
"$name":"JExpr12"};
var JExpr146210 = {"$var":D,
"$name":"JExpr"};
var is_DASH_JExpr147212 = {"$var":D,
"$name":"is-JExpr"};
var is_DASH_j_DASH_parens148214 = {"$var":D,
"$name":"is-j-parens"};
var j_DASH_parens149216 = {"$var":D,
"$name":"j-parens"};
var is_DASH_j_DASH_unop150218 = {"$var":D,
"$name":"is-j-unop"};
var j_DASH_unop151220 = {"$var":D,
"$name":"j-unop"};
var is_DASH_j_DASH_binop152222 = {"$var":D,
"$name":"is-j-binop"};
var j_DASH_binop153224 = {"$var":D,
"$name":"j-binop"};
var is_DASH_j_DASH_fun154226 = {"$var":D,
"$name":"is-j-fun"};
var j_DASH_fun155228 = {"$var":D,
"$name":"j-fun"};
var is_DASH_j_DASH_app156230 = {"$var":D,
"$name":"is-j-app"};
var j_DASH_app157232 = {"$var":D,
"$name":"j-app"};
var is_DASH_j_DASH_method158234 = {"$var":D,
"$name":"is-j-method"};
var j_DASH_method159236 = {"$var":D,
"$name":"j-method"};
var is_DASH_j_DASH_ternary160238 = {"$var":D,
"$name":"is-j-ternary"};
var j_DASH_ternary161240 = {"$var":D,
"$name":"j-ternary"};
var is_DASH_j_DASH_assign162242 = {"$var":D,
"$name":"is-j-assign"};
var j_DASH_assign163244 = {"$var":D,
"$name":"j-assign"};
var is_DASH_j_DASH_bracket_DASH_assign164246 = {"$var":D,
"$name":"is-j-bracket-assign"};
var j_DASH_bracket_DASH_assign165248 = {"$var":D,
"$name":"j-bracket-assign"};
var is_DASH_j_DASH_dot_DASH_assign166250 = {"$var":D,
"$name":"is-j-dot-assign"};
var j_DASH_dot_DASH_assign167252 = {"$var":D,
"$name":"j-dot-assign"};
var is_DASH_j_DASH_dot168254 = {"$var":D,
"$name":"is-j-dot"};
var j_DASH_dot169256 = {"$var":D,
"$name":"j-dot"};
var is_DASH_j_DASH_bracket170258 = {"$var":D,
"$name":"is-j-bracket"};
var j_DASH_bracket171260 = {"$var":D,
"$name":"j-bracket"};
var is_DASH_j_DASH_list172262 = {"$var":D,
"$name":"is-j-list"};
var j_DASH_list173264 = {"$var":D,
"$name":"j-list"};
var is_DASH_j_DASH_obj174266 = {"$var":D,
"$name":"is-j-obj"};
var j_DASH_obj175268 = {"$var":D,
"$name":"j-obj"};
var is_DASH_j_DASH_id176270 = {"$var":D,
"$name":"is-j-id"};
var j_DASH_id177272 = {"$var":D,
"$name":"j-id"};
var is_DASH_j_DASH_str178274 = {"$var":D,
"$name":"is-j-str"};
var j_DASH_str179276 = {"$var":D,
"$name":"j-str"};
var is_DASH_j_DASH_num180278 = {"$var":D,
"$name":"is-j-num"};
var j_DASH_num181280 = {"$var":D,
"$name":"j-num"};
var is_DASH_j_DASH_true182282 = {"$var":D,
"$name":"is-j-true"};
var j_DASH_true183284 = {"$var":D,
"$name":"j-true"};
var is_DASH_j_DASH_false184286 = {"$var":D,
"$name":"is-j-false"};
var j_DASH_false185288 = {"$var":D,
"$name":"j-false"};
var is_DASH_j_DASH_null186290 = {"$var":D,
"$name":"is-j-null"};
var j_DASH_null187292 = {"$var":D,
"$name":"j-null"};
var is_DASH_j_DASH_undefined188294 = {"$var":D,
"$name":"is-j-undefined"};
var j_DASH_undefined189296 = {"$var":D,
"$name":"j-undefined"};
var is_DASH_j_DASH_raw190298 = {"$var":D,
"$name":"is-j-raw"};
var j_DASH_raw191300 = {"$var":D,
"$name":"j-raw"};
var is_DASH_j_DASH_raw_DASH_holes192302 = {"$var":D,
"$name":"is-j-raw-holes"};
var j_DASH_raw_DASH_holes193304 = {"$var":D,
"$name":"j-raw-holes"};
var JField13194306 = {"$var":D,
"$name":"JField13"};
var JField195308 = {"$var":D,
"$name":"JField"};
var is_DASH_JField196310 = {"$var":D,
"$name":"is-JField"};
var is_DASH_j_DASH_field197312 = {"$var":D,
"$name":"is-j-field"};
var j_DASH_field198314 = {"$var":D,
"$name":"j-field"};
var anf_assign979 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[479],0,arguments);
}
var str1994357 = {"$var":(""),
"$name":"str"};
var anf_obj64354 = R.makeFunction(function(s2004358) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[481],1,arguments);
}
var $z43614362 = D;
var $f43674368 = function(_) {
return R.isFunction(_plus14)?_plus14.app(str1994357.$var,s2004358):R.ffi.throwNonFunApp(L[482],_plus14,[str1994357.$var,s2004358]);
};
try {
if(--R.GAS > 0) {
$z43614362 = $f43674368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43674368,
"from":L[482]});
}
} catch($e43594360) {
if(R.isCont($e43594360)) {
var $ss43634364 = {"from":L[482],
"go":function(anf_assign54369) {
return $Hanf_assign19904370(anf_assign54369,str1994357);
}};
$e43594360.stack[R.EXN_STACKHEIGHT++] = $ss43634364;
}
if(R.isPyretException($e43594360)) {
$e43594360.pyretStack.push(L[482]);
}
throw $e43594360;
}
var $ret43654366 = $Hanf_assign19904370($z43614362,str1994357);
++R.GAS;
return $ret43654366;
});
var anf_obj84355 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[480],0,arguments);
}
var ann_DASH_check_DASH_temp74356 = str1994357.$var;
return ann_DASH_check_DASH_temp74356;
});
var ann_DASH_check_DASH_temp34353 = R.makeObject({"append":anf_obj64354,
"get":anf_obj84355});
return ann_DASH_check_DASH_temp34353;
});
string_DASH_printer8078.$var = anf_assign979;
var anf_shared144216 = R.makeMethod(function(self2064351) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[478],0,arguments);
}
var $z43424343 = D;
var $f43484349 = function(_) {
return R.isFunction(string_DASH_printer8078.$var)?string_DASH_printer8078.$var.app():R.ffi.throwNonFunApp(L[477],string_DASH_printer8078.$var,[]);
};
try {
if(--R.GAS > 0) {
$z43424343 = $f43484349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43484349,
"from":L[477]});
}
} catch($e43404341) {
if(R.isCont($e43404341)) {
var $ss43444345 = {"from":L[477],
"go":function(strprint2074350) {
return $Hstrprint19944352(strprint2074350,self2064351);
}};
$e43404341.stack[R.EXN_STACKHEIGHT++] = $ss43444345;
}
if(R.isPyretException($e43404341)) {
$e43404341.pyretStack.push(L[477]);
}
throw $e43404341;
}
var $ret43464347 = $Hstrprint19944352($z43424343,self2064351);
++R.GAS;
return $ret43464347;
};
},{"length":1});
var anf_variant_member264222 = R.makeMethod(function(self24318) {
return function(cases_DASH_funs34319,else_DASH_clause44330) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[460],2,arguments);
}
var if_DASH_64333 = R.hasField(cases_DASH_funs34319,("j-block"));
var if_helper164316 = R.makeFunction(function(if_helper_arg174338) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[460],1,arguments);
}
var ann_DASH_check_DASH_temp154339 = if_helper_arg174338;
return ann_DASH_check_DASH_temp154339;
});
var anf_if204337 = R.isBoolean(if_DASH_64333);
if(R.isPyretTrue(anf_if204337)) {
if(R.isPyretTrue(if_DASH_64333)) {
var call_DASH_j_DASH_block14313 = G(cases_DASH_funs34319,"j-block",L[460]);
var anf_arg234314 = G(self24318,"stmts",L[476]);
var $z43054306 = D;
var $f43114312 = function(_) {
return R.isFunction(call_DASH_j_DASH_block14313)?call_DASH_j_DASH_block14313.app(anf_arg234314):R.ffi.throwNonFunApp(L[460],call_DASH_j_DASH_block14313,[anf_arg234314]);
};
try {
if(--R.GAS > 0) {
$z43054306 = $f43114312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43114312,
"from":L[460]});
}
} catch($e43034304) {
if(R.isCont($e43034304)) {
var $ss43074308 = {"from":L[460],
"go":function(cont_tail_arg244315) {
return $Hcont_tail_arg19954317(cont_tail_arg244315,if_helper164316);
}};
$e43034304.stack[R.EXN_STACKHEIGHT++] = $ss43074308;
}
if(R.isPyretException($e43034304)) {
$e43034304.pyretStack.push(L[460]);
}
throw $e43034304;
}
var $ret43094310 = $Hcont_tail_arg19954317($z43054306,if_helper164316);
++R.GAS;
return $ret43094310;
} else {
var $z43224323 = D;
var $f43284329 = function(_) {
return R.isFunction(else_DASH_clause44330)?else_DASH_clause44330.app():R.ffi.throwNonFunApp(L[460],else_DASH_clause44330,[]);
};
try {
if(--R.GAS > 0) {
$z43224323 = $f43284329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43284329,
"from":L[460]});
}
} catch($e43204321) {
if(R.isCont($e43204321)) {
var $ss43244325 = {"from":L[460],
"go":function(cont_tail_arg214331) {
return $Hcont_tail_arg19964332(cont_tail_arg214331,if_helper164316);
}};
$e43204321.stack[R.EXN_STACKHEIGHT++] = $ss43244325;
}
if(R.isPyretException($e43204321)) {
$e43204321.pyretStack.push(L[460]);
}
throw $e43204321;
}
var $ret43264327 = $Hcont_tail_arg19964332($z43224323,if_helper164316);
++R.GAS;
return $ret43264327;
}
} else {
var cont_tail_arg184336 = R.throwNonBooleanCondition(L[460],("if"),if_DASH_64333);
if(--R.GAS > 0) {
$z43344335 = R.isFunction(if_helper164316)?if_helper164316.app(cont_tail_arg184336):R.ffi.throwNonFunApp(L[460],if_helper164316,[cont_tail_arg184336]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper164316)?if_helper164316.app(cont_tail_arg184336):R.ffi.throwNonFunApp(L[460],if_helper164316,[cont_tail_arg184336]);
},
"from":L[460]});
}
++R.GAS;
return $z43344335;
}
};
},{"length":3});
var anf_variant_member324223 = R.makeMethod(function(self54302) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[460],0,arguments);
}
var anf_arg284299 = G(self54302,"stmts",L[460]);
var $z42914292 = D;
var $f42974298 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg284299):R.ffi.throwNonFunApp(L[460],torepr18,[anf_arg284299]);
};
try {
if(--R.GAS > 0) {
$z42914292 = $f42974298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42974298,
"from":L[460]});
}
} catch($e42894290) {
if(R.isCont($e42894290)) {
var $ss42934294 = {"from":L[460],
"go":function(anf_arg294300) {
return $Hanf_arg20004301(anf_arg294300,_plus14);
}};
$e42894290.stack[R.EXN_STACKHEIGHT++] = $ss42934294;
}
if(R.isPyretException($e42894290)) {
$e42894290.pyretStack.push(L[460]);
}
throw $e42894290;
}
var $ret42954296 = $Hanf_arg20004301($z42914292,_plus14);
++R.GAS;
return $ret42954296;
};
},{"length":1});
var anf_variant_member504224 = R.makeMethod(function(self2022019) {
return function(printer2034287) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[475],1,arguments);
}
var anf_arg344285 = G(self2022019,"stmts",L[474]);
var $z42774278 = D;
var $f42834284 = function(_) {
return R.isFunction(is_DASH_link2563)?is_DASH_link2563.app(anf_arg344285):R.ffi.throwNonFunApp(L[473],is_DASH_link2563,[anf_arg344285]);
};
try {
if(--R.GAS > 0) {
$z42774278 = $f42834284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42834284,
"from":L[473]});
}
} catch($e42754276) {
if(R.isCont($e42754276)) {
var $ss42794280 = {"from":L[473],
"go":function(when_DASH_74286) {
return $Hwhen_DASH_20104288(when_DASH_74286,each4361,printer2034287,self2022019,nothing16);
}};
$e42754276.stack[R.EXN_STACKHEIGHT++] = $ss42794280;
}
if(R.isPyretException($e42754276)) {
$e42754276.pyretStack.push(L[473]);
}
throw $e42754276;
}
var $ret42814282 = $Hwhen_DASH_20104288($z42774278,each4361,printer2034287,self2022019,nothing16);
++R.GAS;
return $ret42814282;
};
},{"length":2});
var anf_variant_member644225 = R.makeMethod(function(self2052000) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[464],0,arguments);
}
var cases_DASH_val94274 = G(self2052000,"stmts",L[472]);
var anf_fun524237 = G(cases_DASH_val94274,"_match",L[465]);
var anf_obj544272 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[470],0,arguments);
}
var ann_DASH_check_DASH_temp534273 = G(PP123,"mt-doc",L[471]);
return ann_DASH_check_DASH_temp534273;
});
var anf_arg554238 = R.makeObject({"empty":anf_obj544272});
var anf_arg634239 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[465],0,arguments);
}
var anf_fun574252 = G(PP123,"flow-map",L[469]);
var anf_arg584253 = G(PP123,"hardline",L[468]);
var anf_arg614254 = R.makeFunction(function(recv_DASH_84258) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[467],1,arguments);
}
var anf_fun604269 = G(recv_DASH_84258,"tosource",L[467]);
var $z42614262 = D;
var $f42674268 = function(_) {
return R.isFunction(anf_fun604269)?anf_fun604269.app():R.ffi.throwNonFunApp(L[467],anf_fun604269,[]);
};
try {
if(--R.GAS > 0) {
$z42614262 = $f42674268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42674268,
"from":L[467]});
}
} catch($e42594260) {
if(R.isCont($e42594260)) {
var $ss42634264 = {"from":L[467],
"go":function(ann_DASH_check_DASH_temp594270) {
return $Hann_DASH_check_DASH_temp20114271(ann_DASH_check_DASH_temp594270);
}};
$e42594260.stack[R.EXN_STACKHEIGHT++] = $ss42634264;
}
if(R.isPyretException($e42594260)) {
$e42594260.pyretStack.push(L[467]);
}
throw $e42594260;
}
var $ret42654266 = $Hann_DASH_check_DASH_temp20114271($z42614262);
++R.GAS;
return $ret42654266;
});
var anf_arg624255 = G(self2052000,"stmts",L[466]);
var $z42444245 = D;
var $f42504251 = function(_) {
return R.isFunction(anf_fun574252)?anf_fun574252.app(anf_arg584253,anf_arg614254,anf_arg624255):R.ffi.throwNonFunApp(L[465],anf_fun574252,[anf_arg584253,anf_arg614254,anf_arg624255]);
};
try {
if(--R.GAS > 0) {
$z42444245 = $f42504251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42504251,
"from":L[465]});
}
} catch($e42424243) {
if(R.isCont($e42424243)) {
var $ss42464247 = {"from":L[465],
"go":function(ann_DASH_check_DASH_temp564256) {
return $Hann_DASH_check_DASH_temp20124257(ann_DASH_check_DASH_temp564256);
}};
$e42424243.stack[R.EXN_STACKHEIGHT++] = $ss42464247;
}
if(R.isPyretException($e42424243)) {
$e42424243.pyretStack.push(L[465]);
}
throw $e42424243;
}
var $ret42484249 = $Hann_DASH_check_DASH_temp20124257($z42444245);
++R.GAS;
return $ret42484249;
});
var $z42294230 = D;
var $f42354236 = function(_) {
return R.isFunction(anf_fun524237)?anf_fun524237.app(anf_arg554238,anf_arg634239):R.ffi.throwNonFunApp(L[464],anf_fun524237,[anf_arg554238,anf_arg634239]);
};
try {
if(--R.GAS > 0) {
$z42294230 = $f42354236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42354236,
"from":L[464]});
}
} catch($e42274228) {
if(R.isCont($e42274228)) {
var $ss42314232 = {"from":L[464],
"go":function(ann_DASH_check_DASH_temp514240) {
return $Hann_DASH_check_DASH_temp20134241(ann_DASH_check_DASH_temp514240);
}};
$e42274228.stack[R.EXN_STACKHEIGHT++] = $ss42314232;
}
if(R.isPyretException($e42274228)) {
$e42274228.pyretStack.push(L[464]);
}
throw $e42274228;
}
var $ret42334234 = $Hann_DASH_check_DASH_temp20134241($z42294230);
++R.GAS;
return $ret42334234;
};
},{"length":1});
var anf_assign6581 = (function() {
var $j_DASH_block_DASH_base42174218 = {"to-ugly-source":anf_shared144216,
"_match":anf_variant_member264222,
"_torepr":anf_variant_member324223,
"print-ugly-source":anf_variant_member504224,
"tosource":anf_variant_member644225};
var $j_DASH_block_DASH_brands42204221 = {"$brand-j-block4219":true};
$j_DASH_block_DASH_brands42204221[JBlockT26551._brand] = true
return R.makeObject({"JBlock":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[461],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,JBlockT26551._brand));
}),
"is-j-block":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[460],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-block4219"));
}),
"j-block":R.makeFunction(function(stmts2014226) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[462],1,arguments);
}
return R.checkAnnArgs([List1560],[stmts2014226],[L[463]],function() {
var dict = R.create($j_DASH_block_DASH_base42174218);
dict["stmts"] = stmts2014226
return R.makeBrandedObject(dict,$j_DASH_block_DASH_brands42204221);
});
})});
})();
JBlock88180.$var = anf_assign6581;
var anf_assign6683 = G(JBlock88180.$var,"JBlock",L[461]);
JBlock8282.$var = anf_assign6683;
var anf_assign6785 = G(JBlock88180.$var,"JBlock",L[461]);
is_DASH_JBlock8384.$var = anf_assign6785;
var anf_assign6887 = G(JBlock88180.$var,"is-j-block",L[460]);
is_DASH_j_DASH_block8486.$var = anf_assign6887;
var anf_assign6989 = G(JBlock88180.$var,"j-block",L[460]);
j_DASH_block8588.$var = anf_assign6989;
var anf_shared743562 = R.makeMethod(function(self2444214) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[459],0,arguments);
}
var $z42054206 = D;
var $f42114212 = function(_) {
return R.isFunction(string_DASH_printer8078.$var)?string_DASH_printer8078.$var.app():R.ffi.throwNonFunApp(L[458],string_DASH_printer8078.$var,[]);
};
try {
if(--R.GAS > 0) {
$z42054206 = $f42114212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42114212,
"from":L[458]});
}
} catch($e42034204) {
if(R.isCont($e42034204)) {
var $ss42074208 = {"from":L[458],
"go":function(strprint2454213) {
return $Hstrprint20174215(strprint2454213,self2444214);
}};
$e42034204.stack[R.EXN_STACKHEIGHT++] = $ss42074208;
}
if(R.isPyretException($e42034204)) {
$e42034204.pyretStack.push(L[458]);
}
throw $e42034204;
}
var $ret42094210 = $Hstrprint20174215($z42054206,self2444214);
++R.GAS;
return $ret42094210;
};
},{"length":1});
var anf_variant_member873568 = R.makeMethod(function(self114181) {
return function(cases_DASH_funs124182,else_DASH_clause134193) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[378],2,arguments);
}
var if_DASH_154196 = R.hasField(cases_DASH_funs124182,("j-var"));
var if_helper764179 = R.makeFunction(function(if_helper_arg774201) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[378],1,arguments);
}
var ann_DASH_check_DASH_temp754202 = if_helper_arg774201;
return ann_DASH_check_DASH_temp754202;
});
var anf_if804200 = R.isBoolean(if_DASH_154196);
if(R.isPyretTrue(anf_if804200)) {
if(R.isPyretTrue(if_DASH_154196)) {
var call_DASH_j_DASH_var104175 = G(cases_DASH_funs124182,"j-var",L[378]);
var anf_arg834176 = G(self114181,"name",L[457]);
var anf_arg844177 = G(self114181,"rhs",L[456]);
var $z41674168 = D;
var $f41734174 = function(_) {
return R.isFunction(call_DASH_j_DASH_var104175)?call_DASH_j_DASH_var104175.app(anf_arg834176,anf_arg844177):R.ffi.throwNonFunApp(L[378],call_DASH_j_DASH_var104175,[anf_arg834176,anf_arg844177]);
};
try {
if(--R.GAS > 0) {
$z41674168 = $f41734174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41734174,
"from":L[378]});
}
} catch($e41654166) {
if(R.isCont($e41654166)) {
var $ss41694170 = {"from":L[378],
"go":function(cont_tail_arg854178) {
return $Hcont_tail_arg20184180(cont_tail_arg854178,if_helper764179);
}};
$e41654166.stack[R.EXN_STACKHEIGHT++] = $ss41694170;
}
if(R.isPyretException($e41654166)) {
$e41654166.pyretStack.push(L[378]);
}
throw $e41654166;
}
var $ret41714172 = $Hcont_tail_arg20184180($z41674168,if_helper764179);
++R.GAS;
return $ret41714172;
} else {
var $z41854186 = D;
var $f41914192 = function(_) {
return R.isFunction(else_DASH_clause134193)?else_DASH_clause134193.app():R.ffi.throwNonFunApp(L[378],else_DASH_clause134193,[]);
};
try {
if(--R.GAS > 0) {
$z41854186 = $f41914192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41914192,
"from":L[378]});
}
} catch($e41834184) {
if(R.isCont($e41834184)) {
var $ss41874188 = {"from":L[378],
"go":function(cont_tail_arg814194) {
return $Hcont_tail_arg20194195(cont_tail_arg814194,if_helper764179);
}};
$e41834184.stack[R.EXN_STACKHEIGHT++] = $ss41874188;
}
if(R.isPyretException($e41834184)) {
$e41834184.pyretStack.push(L[378]);
}
throw $e41834184;
}
var $ret41894190 = $Hcont_tail_arg20194195($z41854186,if_helper764179);
++R.GAS;
return $ret41894190;
}
} else {
var cont_tail_arg784199 = R.throwNonBooleanCondition(L[378],("if"),if_DASH_154196);
if(--R.GAS > 0) {
$z41974198 = R.isFunction(if_helper764179)?if_helper764179.app(cont_tail_arg784199):R.ffi.throwNonFunApp(L[378],if_helper764179,[cont_tail_arg784199]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper764179)?if_helper764179.app(cont_tail_arg784199):R.ffi.throwNonFunApp(L[378],if_helper764179,[cont_tail_arg784199]);
},
"from":L[378]});
}
++R.GAS;
return $z41974198;
}
};
},{"length":3});
var anf_variant_member973569 = R.makeMethod(function(self144163) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[378],0,arguments);
}
var anf_arg894161 = G(self144163,"name",L[378]);
var $z41534154 = D;
var $f41594160 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg894161):R.ffi.throwNonFunApp(L[378],torepr18,[anf_arg894161]);
};
try {
if(--R.GAS > 0) {
$z41534154 = $f41594160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41594160,
"from":L[378]});
}
} catch($e41514152) {
if(R.isCont($e41514152)) {
var $ss41554156 = {"from":L[378],
"go":function(anf_arg904162) {
return $Hanf_arg20264164(anf_arg904162,self144163,_plus14,torepr18);
}};
$e41514152.stack[R.EXN_STACKHEIGHT++] = $ss41554156;
}
if(R.isPyretException($e41514152)) {
$e41514152.pyretStack.push(L[378]);
}
throw $e41514152;
}
var $ret41574158 = $Hanf_arg20264164($z41534154,self144163,_plus14,torepr18);
++R.GAS;
return $ret41574158;
};
},{"length":1});
var anf_variant_member1043570 = R.makeMethod(function(self2104149) {
return function(printer2114148) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[455],1,arguments);
}
var anf_arg994146 = G(self2104149,"name",L[454]);
var $z41384139 = D;
var $f41444145 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("var "),anf_arg994146):R.ffi.throwNonFunApp(L[453],_plus14,[("var "),anf_arg994146]);
};
try {
if(--R.GAS > 0) {
$z41384139 = $f41444145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41444145,
"from":L[453]});
}
} catch($e41364137) {
if(R.isCont($e41364137)) {
var $ss41404141 = {"from":L[453],
"go":function(anf_arg1004147) {
return $Hanf_arg20334150(anf_arg1004147,printer2114148,self2104149,_plus14);
}};
$e41364137.stack[R.EXN_STACKHEIGHT++] = $ss41404141;
}
if(R.isPyretException($e41364137)) {
$e41364137.pyretStack.push(L[453]);
}
throw $e41364137;
}
var $ret41424143 = $Hanf_arg20334150($z41384139,printer2114148,self2104149,_plus14);
++R.GAS;
return $ret41424143;
};
},{"length":2});
var anf_variant_member1303571 = R.makeMethod(function(self2124134) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[452],0,arguments);
}
var anf_fun1064133 = G(PP123,"group",L[451]);
var anf_fun1074131 = G(PP123,"str",L[450]);
var $z41234124 = D;
var $f41294130 = function(_) {
return R.isFunction(anf_fun1074131)?anf_fun1074131.app(("var ")):R.ffi.throwNonFunApp(L[449],anf_fun1074131,[("var ")]);
};
try {
if(--R.GAS > 0) {
$z41234124 = $f41294130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41294130,
"from":L[449]});
}
} catch($e41214122) {
if(R.isCont($e41214122)) {
var $ss41254126 = {"from":L[449],
"go":function(anf_arg1084132) {
return $Hanf_arg20474135(anf_arg1084132,INDENT7747,PP123,anf_fun1064133,self2124134,_plus14);
}};
$e41214122.stack[R.EXN_STACKHEIGHT++] = $ss41254126;
}
if(R.isPyretException($e41214122)) {
$e41214122.pyretStack.push(L[449]);
}
throw $e41214122;
}
var $ret41274128 = $Hanf_arg20474135($z41234124,INDENT7747,PP123,anf_fun1064133,self2124134,_plus14);
++R.GAS;
return $ret41274128;
};
},{"length":1});
var anf_variant_member1433579 = R.makeMethod(function(self174099) {
return function(cases_DASH_funs184100,else_DASH_clause194111) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[377],2,arguments);
}
var if_DASH_214114 = R.hasField(cases_DASH_funs184100,("j-if1"));
var if_helper1324097 = R.makeFunction(function(if_helper_arg1334119) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[377],1,arguments);
}
var ann_DASH_check_DASH_temp1314120 = if_helper_arg1334119;
return ann_DASH_check_DASH_temp1314120;
});
var anf_if1364118 = R.isBoolean(if_DASH_214114);
if(R.isPyretTrue(anf_if1364118)) {
if(R.isPyretTrue(if_DASH_214114)) {
var call_DASH_j_DASH_if1164093 = G(cases_DASH_funs184100,"j-if1",L[377]);
var anf_arg1394094 = G(self174099,"cond",L[448]);
var anf_arg1404095 = G(self174099,"consq",L[447]);
var $z40854086 = D;
var $f40914092 = function(_) {
return R.isFunction(call_DASH_j_DASH_if1164093)?call_DASH_j_DASH_if1164093.app(anf_arg1394094,anf_arg1404095):R.ffi.throwNonFunApp(L[377],call_DASH_j_DASH_if1164093,[anf_arg1394094,anf_arg1404095]);
};
try {
if(--R.GAS > 0) {
$z40854086 = $f40914092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40914092,
"from":L[377]});
}
} catch($e40834084) {
if(R.isCont($e40834084)) {
var $ss40874088 = {"from":L[377],
"go":function(cont_tail_arg1414096) {
return $Hcont_tail_arg20484098(cont_tail_arg1414096,if_helper1324097);
}};
$e40834084.stack[R.EXN_STACKHEIGHT++] = $ss40874088;
}
if(R.isPyretException($e40834084)) {
$e40834084.pyretStack.push(L[377]);
}
throw $e40834084;
}
var $ret40894090 = $Hcont_tail_arg20484098($z40854086,if_helper1324097);
++R.GAS;
return $ret40894090;
} else {
var $z41034104 = D;
var $f41094110 = function(_) {
return R.isFunction(else_DASH_clause194111)?else_DASH_clause194111.app():R.ffi.throwNonFunApp(L[377],else_DASH_clause194111,[]);
};
try {
if(--R.GAS > 0) {
$z41034104 = $f41094110();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41094110,
"from":L[377]});
}
} catch($e41014102) {
if(R.isCont($e41014102)) {
var $ss41054106 = {"from":L[377],
"go":function(cont_tail_arg1374112) {
return $Hcont_tail_arg20494113(cont_tail_arg1374112,if_helper1324097);
}};
$e41014102.stack[R.EXN_STACKHEIGHT++] = $ss41054106;
}
if(R.isPyretException($e41014102)) {
$e41014102.pyretStack.push(L[377]);
}
throw $e41014102;
}
var $ret41074108 = $Hcont_tail_arg20494113($z41034104,if_helper1324097);
++R.GAS;
return $ret41074108;
}
} else {
var cont_tail_arg1344117 = R.throwNonBooleanCondition(L[377],("if"),if_DASH_214114);
if(--R.GAS > 0) {
$z41154116 = R.isFunction(if_helper1324097)?if_helper1324097.app(cont_tail_arg1344117):R.ffi.throwNonFunApp(L[377],if_helper1324097,[cont_tail_arg1344117]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1324097)?if_helper1324097.app(cont_tail_arg1344117):R.ffi.throwNonFunApp(L[377],if_helper1324097,[cont_tail_arg1344117]);
},
"from":L[377]});
}
++R.GAS;
return $z41154116;
}
};
},{"length":3});
var anf_variant_member1533580 = R.makeMethod(function(self204081) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[377],0,arguments);
}
var anf_arg1454079 = G(self204081,"cond",L[377]);
var $z40714072 = D;
var $f40774078 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg1454079):R.ffi.throwNonFunApp(L[377],torepr18,[anf_arg1454079]);
};
try {
if(--R.GAS > 0) {
$z40714072 = $f40774078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40774078,
"from":L[377]});
}
} catch($e40694070) {
if(R.isCont($e40694070)) {
var $ss40734074 = {"from":L[377],
"go":function(anf_arg1464080) {
return $Hanf_arg20564082(anf_arg1464080,self204081,_plus14,torepr18);
}};
$e40694070.stack[R.EXN_STACKHEIGHT++] = $ss40734074;
}
if(R.isPyretException($e40694070)) {
$e40694070.pyretStack.push(L[377]);
}
throw $e40694070;
}
var $ret40754076 = $Hanf_arg20564082($z40714072,self204081,_plus14,torepr18);
++R.GAS;
return $ret40754076;
};
},{"length":1});
var anf_variant_member1593581 = R.makeMethod(function(self2154067) {
return function(printer2164065) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[446],1,arguments);
}
var $z40574058 = D;
var $f40634064 = function(_) {
return R.isFunction(printer2164065)?printer2164065.app(("if(")):R.ffi.throwNonFunApp(L[445],printer2164065,[("if(")]);
};
try {
if(--R.GAS > 0) {
$z40574058 = $f40634064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40634064,
"from":L[445]});
}
} catch($e40554056) {
if(R.isCont($e40554056)) {
var $ss40594060 = {"from":L[445],
"go":function(anf_begin_app_dropped20574066) {
return $Hanf_begin_app_dropped20654068(anf_begin_app_dropped20574066,printer2164065,self2154067);
}};
$e40554056.stack[R.EXN_STACKHEIGHT++] = $ss40594060;
}
if(R.isPyretException($e40554056)) {
$e40554056.pyretStack.push(L[445]);
}
throw $e40554056;
}
var $ret40614062 = $Hanf_begin_app_dropped20654068($z40574058,printer2164065,self2154067);
++R.GAS;
return $ret40614062;
};
},{"length":2});
var anf_variant_member1813582 = R.makeMethod(function(self2171831) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[444],0,arguments);
}
var anf_fun1614053 = G(PP123,"group",L[443]);
var anf_fun1624051 = G(PP123,"str",L[442]);
var $z40434044 = D;
var $f40494050 = function(_) {
return R.isFunction(anf_fun1624051)?anf_fun1624051.app(("if")):R.ffi.throwNonFunApp(L[441],anf_fun1624051,[("if")]);
};
try {
if(--R.GAS > 0) {
$z40434044 = $f40494050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40494050,
"from":L[441]});
}
} catch($e40414042) {
if(R.isCont($e40414042)) {
var $ss40454046 = {"from":L[441],
"go":function(anf_arg1634052) {
return $Hanf_arg20754054(anf_arg1634052,INDENT7747,PP123,anf_fun1614053,self2171831,_plus14);
}};
$e40414042.stack[R.EXN_STACKHEIGHT++] = $ss40454046;
}
if(R.isPyretException($e40414042)) {
$e40414042.pyretStack.push(L[441]);
}
throw $e40414042;
}
var $ret40474048 = $Hanf_arg20754054($z40434044,INDENT7747,PP123,anf_fun1614053,self2171831,_plus14);
++R.GAS;
return $ret40474048;
};
},{"length":1});
var anf_variant_member1953590 = R.makeMethod(function(self234019) {
return function(cases_DASH_funs244020,else_DASH_clause254031) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[376],2,arguments);
}
var if_DASH_274034 = R.hasField(cases_DASH_funs244020,("j-if"));
var if_helper1834017 = R.makeFunction(function(if_helper_arg1844039) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[376],1,arguments);
}
var ann_DASH_check_DASH_temp1824040 = if_helper_arg1844039;
return ann_DASH_check_DASH_temp1824040;
});
var anf_if1874038 = R.isBoolean(if_DASH_274034);
if(R.isPyretTrue(anf_if1874038)) {
if(R.isPyretTrue(if_DASH_274034)) {
var call_DASH_j_DASH_if224012 = G(cases_DASH_funs244020,"j-if",L[376]);
var anf_arg1904013 = G(self234019,"cond",L[440]);
var anf_arg1914014 = G(self234019,"consq",L[439]);
var anf_arg1924015 = G(self234019,"alt",L[438]);
var $z40044005 = D;
var $f40104011 = function(_) {
return R.isFunction(call_DASH_j_DASH_if224012)?call_DASH_j_DASH_if224012.app(anf_arg1904013,anf_arg1914014,anf_arg1924015):R.ffi.throwNonFunApp(L[376],call_DASH_j_DASH_if224012,[anf_arg1904013,anf_arg1914014,anf_arg1924015]);
};
try {
if(--R.GAS > 0) {
$z40044005 = $f40104011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40104011,
"from":L[376]});
}
} catch($e40024003) {
if(R.isCont($e40024003)) {
var $ss40064007 = {"from":L[376],
"go":function(cont_tail_arg1934016) {
return $Hcont_tail_arg20764018(cont_tail_arg1934016,if_helper1834017);
}};
$e40024003.stack[R.EXN_STACKHEIGHT++] = $ss40064007;
}
if(R.isPyretException($e40024003)) {
$e40024003.pyretStack.push(L[376]);
}
throw $e40024003;
}
var $ret40084009 = $Hcont_tail_arg20764018($z40044005,if_helper1834017);
++R.GAS;
return $ret40084009;
} else {
var $z40234024 = D;
var $f40294030 = function(_) {
return R.isFunction(else_DASH_clause254031)?else_DASH_clause254031.app():R.ffi.throwNonFunApp(L[376],else_DASH_clause254031,[]);
};
try {
if(--R.GAS > 0) {
$z40234024 = $f40294030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40294030,
"from":L[376]});
}
} catch($e40214022) {
if(R.isCont($e40214022)) {
var $ss40254026 = {"from":L[376],
"go":function(cont_tail_arg1884032) {
return $Hcont_tail_arg20774033(cont_tail_arg1884032,if_helper1834017);
}};
$e40214022.stack[R.EXN_STACKHEIGHT++] = $ss40254026;
}
if(R.isPyretException($e40214022)) {
$e40214022.pyretStack.push(L[376]);
}
throw $e40214022;
}
var $ret40274028 = $Hcont_tail_arg20774033($z40234024,if_helper1834017);
++R.GAS;
return $ret40274028;
}
} else {
var cont_tail_arg1854037 = R.throwNonBooleanCondition(L[376],("if"),if_DASH_274034);
if(--R.GAS > 0) {
$z40354036 = R.isFunction(if_helper1834017)?if_helper1834017.app(cont_tail_arg1854037):R.ffi.throwNonFunApp(L[376],if_helper1834017,[cont_tail_arg1854037]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1834017)?if_helper1834017.app(cont_tail_arg1854037):R.ffi.throwNonFunApp(L[376],if_helper1834017,[cont_tail_arg1854037]);
},
"from":L[376]});
}
++R.GAS;
return $z40354036;
}
};
},{"length":3});
var anf_variant_member2093591 = R.makeMethod(function(self264000) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[376],0,arguments);
}
var anf_arg1973998 = G(self264000,"cond",L[376]);
var $z39903991 = D;
var $f39963997 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg1973998):R.ffi.throwNonFunApp(L[376],torepr18,[anf_arg1973998]);
};
try {
if(--R.GAS > 0) {
$z39903991 = $f39963997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39963997,
"from":L[376]});
}
} catch($e39883989) {
if(R.isCont($e39883989)) {
var $ss39923993 = {"from":L[376],
"go":function(anf_arg1983999) {
return $Hanf_arg20874001(anf_arg1983999,self264000,_plus14,torepr18);
}};
$e39883989.stack[R.EXN_STACKHEIGHT++] = $ss39923993;
}
if(R.isPyretException($e39883989)) {
$e39883989.pyretStack.push(L[376]);
}
throw $e39883989;
}
var $ret39943995 = $Hanf_arg20874001($z39903991,self264000,_plus14,torepr18);
++R.GAS;
return $ret39943995;
};
},{"length":1});
var anf_variant_member2173592 = R.makeMethod(function(self2213986) {
return function(printer2223984) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[437],1,arguments);
}
var $z39763977 = D;
var $f39823983 = function(_) {
return R.isFunction(printer2223984)?printer2223984.app(("if(")):R.ffi.throwNonFunApp(L[436],printer2223984,[("if(")]);
};
try {
if(--R.GAS > 0) {
$z39763977 = $f39823983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39823983,
"from":L[436]});
}
} catch($e39743975) {
if(R.isCont($e39743975)) {
var $ss39783979 = {"from":L[436],
"go":function(anf_begin_app_dropped20883985) {
return $Hanf_begin_app_dropped21003987(anf_begin_app_dropped20883985,printer2223984,self2213986);
}};
$e39743975.stack[R.EXN_STACKHEIGHT++] = $ss39783979;
}
if(R.isPyretException($e39743975)) {
$e39743975.pyretStack.push(L[436]);
}
throw $e39743975;
}
var $ret39803981 = $Hanf_begin_app_dropped21003987($z39763977,printer2223984,self2213986);
++R.GAS;
return $ret39803981;
};
},{"length":2});
var anf_variant_member2583593 = R.makeMethod(function(self2231745) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[435],0,arguments);
}
var anf_bracket2193973 = G(self2231745,"alt",L[434]);
var anf_fun2203970 = G(anf_bracket2193973,"tosource",L[433]);
var $z39623963 = D;
var $f39683969 = function(_) {
return R.isFunction(anf_fun2203970)?anf_fun2203970.app():R.ffi.throwNonFunApp(L[432],anf_fun2203970,[]);
};
try {
if(--R.GAS > 0) {
$z39623963 = $f39683969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39683969,
"from":L[432]});
}
} catch($e39603961) {
if(R.isCont($e39603961)) {
var $ss39643965 = {"from":L[432],
"go":function(alt_DASH_doc2243971) {
return $Halt_DASH_doc21153972(alt_DASH_doc2243971,INDENT7747,PP123,self2231745,_plus14);
}};
$e39603961.stack[R.EXN_STACKHEIGHT++] = $ss39643965;
}
if(R.isPyretException($e39603961)) {
$e39603961.pyretStack.push(L[432]);
}
throw $e39603961;
}
var $ret39663967 = $Halt_DASH_doc21153972($z39623963,INDENT7747,PP123,self2231745,_plus14);
++R.GAS;
return $ret39663967;
};
},{"length":1});
var anf_variant_member2703602 = R.makeMethod(function(self303938) {
return function(cases_DASH_funs313939,else_DASH_clause323950) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[375],2,arguments);
}
var if_DASH_343953 = R.hasField(cases_DASH_funs313939,("j-return"));
var if_helper2603936 = R.makeFunction(function(if_helper_arg2613958) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[375],1,arguments);
}
var ann_DASH_check_DASH_temp2593959 = if_helper_arg2613958;
return ann_DASH_check_DASH_temp2593959;
});
var anf_if2643957 = R.isBoolean(if_DASH_343953);
if(R.isPyretTrue(anf_if2643957)) {
if(R.isPyretTrue(if_DASH_343953)) {
var call_DASH_j_DASH_return293933 = G(cases_DASH_funs313939,"j-return",L[375]);
var anf_arg2673934 = G(self303938,"expr",L[431]);
var $z39253926 = D;
var $f39313932 = function(_) {
return R.isFunction(call_DASH_j_DASH_return293933)?call_DASH_j_DASH_return293933.app(anf_arg2673934):R.ffi.throwNonFunApp(L[375],call_DASH_j_DASH_return293933,[anf_arg2673934]);
};
try {
if(--R.GAS > 0) {
$z39253926 = $f39313932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39313932,
"from":L[375]});
}
} catch($e39233924) {
if(R.isCont($e39233924)) {
var $ss39273928 = {"from":L[375],
"go":function(cont_tail_arg2683935) {
return $Hcont_tail_arg21163937(cont_tail_arg2683935,if_helper2603936);
}};
$e39233924.stack[R.EXN_STACKHEIGHT++] = $ss39273928;
}
if(R.isPyretException($e39233924)) {
$e39233924.pyretStack.push(L[375]);
}
throw $e39233924;
}
var $ret39293930 = $Hcont_tail_arg21163937($z39253926,if_helper2603936);
++R.GAS;
return $ret39293930;
} else {
var $z39423943 = D;
var $f39483949 = function(_) {
return R.isFunction(else_DASH_clause323950)?else_DASH_clause323950.app():R.ffi.throwNonFunApp(L[375],else_DASH_clause323950,[]);
};
try {
if(--R.GAS > 0) {
$z39423943 = $f39483949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39483949,
"from":L[375]});
}
} catch($e39403941) {
if(R.isCont($e39403941)) {
var $ss39443945 = {"from":L[375],
"go":function(cont_tail_arg2653951) {
return $Hcont_tail_arg21173952(cont_tail_arg2653951,if_helper2603936);
}};
$e39403941.stack[R.EXN_STACKHEIGHT++] = $ss39443945;
}
if(R.isPyretException($e39403941)) {
$e39403941.pyretStack.push(L[375]);
}
throw $e39403941;
}
var $ret39463947 = $Hcont_tail_arg21173952($z39423943,if_helper2603936);
++R.GAS;
return $ret39463947;
}
} else {
var cont_tail_arg2623956 = R.throwNonBooleanCondition(L[375],("if"),if_DASH_343953);
if(--R.GAS > 0) {
$z39543955 = R.isFunction(if_helper2603936)?if_helper2603936.app(cont_tail_arg2623956):R.ffi.throwNonFunApp(L[375],if_helper2603936,[cont_tail_arg2623956]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper2603936)?if_helper2603936.app(cont_tail_arg2623956):R.ffi.throwNonFunApp(L[375],if_helper2603936,[cont_tail_arg2623956]);
},
"from":L[375]});
}
++R.GAS;
return $z39543955;
}
};
},{"length":3});
var anf_variant_member2763603 = R.makeMethod(function(self333922) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[375],0,arguments);
}
var anf_arg2723919 = G(self333922,"expr",L[375]);
var $z39113912 = D;
var $f39173918 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg2723919):R.ffi.throwNonFunApp(L[375],torepr18,[anf_arg2723919]);
};
try {
if(--R.GAS > 0) {
$z39113912 = $f39173918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39173918,
"from":L[375]});
}
} catch($e39093910) {
if(R.isCont($e39093910)) {
var $ss39133914 = {"from":L[375],
"go":function(anf_arg2733920) {
return $Hanf_arg21213921(anf_arg2733920,_plus14);
}};
$e39093910.stack[R.EXN_STACKHEIGHT++] = $ss39133914;
}
if(R.isPyretException($e39093910)) {
$e39093910.pyretStack.push(L[375]);
}
throw $e39093910;
}
var $ret39153916 = $Hanf_arg21213921($z39113912,_plus14);
++R.GAS;
return $ret39153916;
};
},{"length":1});
var anf_variant_member2803604 = R.makeMethod(function(self2273907) {
return function(printer2283905) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[430],1,arguments);
}
var $z38973898 = D;
var $f39033904 = function(_) {
return R.isFunction(printer2283905)?printer2283905.app(("return ")):R.ffi.throwNonFunApp(L[429],printer2283905,[("return ")]);
};
try {
if(--R.GAS > 0) {
$z38973898 = $f39033904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39033904,
"from":L[429]});
}
} catch($e38953896) {
if(R.isCont($e38953896)) {
var $ss38993900 = {"from":L[429],
"go":function(anf_begin_app_dropped21223906) {
return $Hanf_begin_app_dropped21263908(anf_begin_app_dropped21223906,printer2283905,self2273907);
}};
$e38953896.stack[R.EXN_STACKHEIGHT++] = $ss38993900;
}
if(R.isPyretException($e38953896)) {
$e38953896.pyretStack.push(L[429]);
}
throw $e38953896;
}
var $ret39013902 = $Hanf_begin_app_dropped21263908($z38973898,printer2283905,self2273907);
++R.GAS;
return $ret39013902;
};
},{"length":2});
var anf_variant_member2903605 = R.makeMethod(function(self2291660) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[428],0,arguments);
}
var anf_fun2823892 = G(PP123,"str",L[427]);
var $z38843885 = D;
var $f38903891 = function(_) {
return R.isFunction(anf_fun2823892)?anf_fun2823892.app(("return ")):R.ffi.throwNonFunApp(L[426],anf_fun2823892,[("return ")]);
};
try {
if(--R.GAS > 0) {
$z38843885 = $f38903891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38903891,
"from":L[426]});
}
} catch($e38823883) {
if(R.isCont($e38823883)) {
var $ss38863887 = {"from":L[426],
"go":function(anf_arg2833893) {
return $Hanf_arg21313894(anf_arg2833893,PP123,self2291660,_plus14);
}};
$e38823883.stack[R.EXN_STACKHEIGHT++] = $ss38863887;
}
if(R.isPyretException($e38823883)) {
$e38823883.pyretStack.push(L[426]);
}
throw $e38823883;
}
var $ret38883889 = $Hanf_arg21313894($z38843885,PP123,self2291660,_plus14);
++R.GAS;
return $ret38883889;
};
},{"length":1});
var anf_variant_member3043612 = R.makeMethod(function(self363860) {
return function(cases_DASH_funs373861,else_DASH_clause383872) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[374],2,arguments);
}
var if_DASH_403875 = R.hasField(cases_DASH_funs373861,("j-try-catch"));
var if_helper2923858 = R.makeFunction(function(if_helper_arg2933880) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[374],1,arguments);
}
var ann_DASH_check_DASH_temp2913881 = if_helper_arg2933880;
return ann_DASH_check_DASH_temp2913881;
});
var anf_if2963879 = R.isBoolean(if_DASH_403875);
if(R.isPyretTrue(anf_if2963879)) {
if(R.isPyretTrue(if_DASH_403875)) {
var call_DASH_j_DASH_try_DASH_catch353853 = G(cases_DASH_funs373861,"j-try-catch",L[374]);
var anf_arg2993854 = G(self363860,"body",L[425]);
var anf_arg3003855 = G(self363860,"exn",L[424]);
var anf_arg3013856 = G(self363860,"catch",L[423]);
var $z38453846 = D;
var $f38513852 = function(_) {
return R.isFunction(call_DASH_j_DASH_try_DASH_catch353853)?call_DASH_j_DASH_try_DASH_catch353853.app(anf_arg2993854,anf_arg3003855,anf_arg3013856):R.ffi.throwNonFunApp(L[374],call_DASH_j_DASH_try_DASH_catch353853,[anf_arg2993854,anf_arg3003855,anf_arg3013856]);
};
try {
if(--R.GAS > 0) {
$z38453846 = $f38513852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38513852,
"from":L[374]});
}
} catch($e38433844) {
if(R.isCont($e38433844)) {
var $ss38473848 = {"from":L[374],
"go":function(cont_tail_arg3023857) {
return $Hcont_tail_arg21323859(cont_tail_arg3023857,if_helper2923858);
}};
$e38433844.stack[R.EXN_STACKHEIGHT++] = $ss38473848;
}
if(R.isPyretException($e38433844)) {
$e38433844.pyretStack.push(L[374]);
}
throw $e38433844;
}
var $ret38493850 = $Hcont_tail_arg21323859($z38453846,if_helper2923858);
++R.GAS;
return $ret38493850;
} else {
var $z38643865 = D;
var $f38703871 = function(_) {
return R.isFunction(else_DASH_clause383872)?else_DASH_clause383872.app():R.ffi.throwNonFunApp(L[374],else_DASH_clause383872,[]);
};
try {
if(--R.GAS > 0) {
$z38643865 = $f38703871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38703871,
"from":L[374]});
}
} catch($e38623863) {
if(R.isCont($e38623863)) {
var $ss38663867 = {"from":L[374],
"go":function(cont_tail_arg2973873) {
return $Hcont_tail_arg21333874(cont_tail_arg2973873,if_helper2923858);
}};
$e38623863.stack[R.EXN_STACKHEIGHT++] = $ss38663867;
}
if(R.isPyretException($e38623863)) {
$e38623863.pyretStack.push(L[374]);
}
throw $e38623863;
}
var $ret38683869 = $Hcont_tail_arg21333874($z38643865,if_helper2923858);
++R.GAS;
return $ret38683869;
}
} else {
var cont_tail_arg2943878 = R.throwNonBooleanCondition(L[374],("if"),if_DASH_403875);
if(--R.GAS > 0) {
$z38763877 = R.isFunction(if_helper2923858)?if_helper2923858.app(cont_tail_arg2943878):R.ffi.throwNonFunApp(L[374],if_helper2923858,[cont_tail_arg2943878]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper2923858)?if_helper2923858.app(cont_tail_arg2943878):R.ffi.throwNonFunApp(L[374],if_helper2923858,[cont_tail_arg2943878]);
},
"from":L[374]});
}
++R.GAS;
return $z38763877;
}
};
},{"length":3});
var anf_variant_member3183613 = R.makeMethod(function(self393841) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[374],0,arguments);
}
var anf_arg3063839 = G(self393841,"body",L[374]);
var $z38313832 = D;
var $f38373838 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg3063839):R.ffi.throwNonFunApp(L[374],torepr18,[anf_arg3063839]);
};
try {
if(--R.GAS > 0) {
$z38313832 = $f38373838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38373838,
"from":L[374]});
}
} catch($e38293830) {
if(R.isCont($e38293830)) {
var $ss38333834 = {"from":L[374],
"go":function(anf_arg3073840) {
return $Hanf_arg21433842(anf_arg3073840,self393841,_plus14,torepr18);
}};
$e38293830.stack[R.EXN_STACKHEIGHT++] = $ss38333834;
}
if(R.isPyretException($e38293830)) {
$e38293830.pyretStack.push(L[374]);
}
throw $e38293830;
}
var $ret38353836 = $Hanf_arg21433842($z38313832,self393841,_plus14,torepr18);
++R.GAS;
return $ret38353836;
};
},{"length":1});
var anf_variant_member3273614 = R.makeMethod(function(self2333827) {
return function(printer2343825) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[422],1,arguments);
}
var $z38173818 = D;
var $f38233824 = function(_) {
return R.isFunction(printer2343825)?printer2343825.app(("try {\n")):R.ffi.throwNonFunApp(L[421],printer2343825,[("try {\n")]);
};
try {
if(--R.GAS > 0) {
$z38173818 = $f38233824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38233824,
"from":L[421]});
}
} catch($e38153816) {
if(R.isCont($e38153816)) {
var $ss38193820 = {"from":L[421],
"go":function(anf_begin_app_dropped21443826) {
return $Hanf_begin_app_dropped21543828(anf_begin_app_dropped21443826,printer2343825,self2333827,_plus14);
}};
$e38153816.stack[R.EXN_STACKHEIGHT++] = $ss38193820;
}
if(R.isPyretException($e38153816)) {
$e38153816.pyretStack.push(L[421]);
}
throw $e38153816;
}
var $ret38213822 = $Hanf_begin_app_dropped21543828($z38173818,printer2343825,self2333827,_plus14);
++R.GAS;
return $ret38213822;
};
},{"length":2});
var anf_variant_member3483615 = R.makeMethod(function(self2351577) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[420],0,arguments);
}
var anf_fun3293813 = G(PP123,"surround",L[419]);
var anf_fun3303811 = G(PP123,"str",L[418]);
var $z38033804 = D;
var $f38093810 = function(_) {
return R.isFunction(anf_fun3303811)?anf_fun3303811.app(("try {")):R.ffi.throwNonFunApp(L[417],anf_fun3303811,[("try {")]);
};
try {
if(--R.GAS > 0) {
$z38033804 = $f38093810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38093810,
"from":L[417]});
}
} catch($e38013802) {
if(R.isCont($e38013802)) {
var $ss38053806 = {"from":L[417],
"go":function(anf_arg3313812) {
return $Hanf_arg21633814(anf_arg3313812,INDENT7747,PP123,anf_fun3293813,self2351577,_plus14);
}};
$e38013802.stack[R.EXN_STACKHEIGHT++] = $ss38053806;
}
if(R.isPyretException($e38013802)) {
$e38013802.pyretStack.push(L[417]);
}
throw $e38013802;
}
var $ret38073808 = $Hanf_arg21633814($z38033804,INDENT7747,PP123,anf_fun3293813,self2351577,_plus14);
++R.GAS;
return $ret38073808;
};
},{"length":1});
var anf_variant_member3603624 = R.makeMethod(function(self423779) {
return function(cases_DASH_funs433780,else_DASH_clause443791) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[373],2,arguments);
}
var if_DASH_463794 = R.hasField(cases_DASH_funs433780,("j-throw"));
var if_helper3503777 = R.makeFunction(function(if_helper_arg3513799) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[373],1,arguments);
}
var ann_DASH_check_DASH_temp3493800 = if_helper_arg3513799;
return ann_DASH_check_DASH_temp3493800;
});
var anf_if3543798 = R.isBoolean(if_DASH_463794);
if(R.isPyretTrue(anf_if3543798)) {
if(R.isPyretTrue(if_DASH_463794)) {
var call_DASH_j_DASH_throw413774 = G(cases_DASH_funs433780,"j-throw",L[373]);
var anf_arg3573775 = G(self423779,"exp",L[416]);
var $z37663767 = D;
var $f37723773 = function(_) {
return R.isFunction(call_DASH_j_DASH_throw413774)?call_DASH_j_DASH_throw413774.app(anf_arg3573775):R.ffi.throwNonFunApp(L[373],call_DASH_j_DASH_throw413774,[anf_arg3573775]);
};
try {
if(--R.GAS > 0) {
$z37663767 = $f37723773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37723773,
"from":L[373]});
}
} catch($e37643765) {
if(R.isCont($e37643765)) {
var $ss37683769 = {"from":L[373],
"go":function(cont_tail_arg3583776) {
return $Hcont_tail_arg21643778(cont_tail_arg3583776,if_helper3503777);
}};
$e37643765.stack[R.EXN_STACKHEIGHT++] = $ss37683769;
}
if(R.isPyretException($e37643765)) {
$e37643765.pyretStack.push(L[373]);
}
throw $e37643765;
}
var $ret37703771 = $Hcont_tail_arg21643778($z37663767,if_helper3503777);
++R.GAS;
return $ret37703771;
} else {
var $z37833784 = D;
var $f37893790 = function(_) {
return R.isFunction(else_DASH_clause443791)?else_DASH_clause443791.app():R.ffi.throwNonFunApp(L[373],else_DASH_clause443791,[]);
};
try {
if(--R.GAS > 0) {
$z37833784 = $f37893790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37893790,
"from":L[373]});
}
} catch($e37813782) {
if(R.isCont($e37813782)) {
var $ss37853786 = {"from":L[373],
"go":function(cont_tail_arg3553792) {
return $Hcont_tail_arg21653793(cont_tail_arg3553792,if_helper3503777);
}};
$e37813782.stack[R.EXN_STACKHEIGHT++] = $ss37853786;
}
if(R.isPyretException($e37813782)) {
$e37813782.pyretStack.push(L[373]);
}
throw $e37813782;
}
var $ret37873788 = $Hcont_tail_arg21653793($z37833784,if_helper3503777);
++R.GAS;
return $ret37873788;
}
} else {
var cont_tail_arg3523797 = R.throwNonBooleanCondition(L[373],("if"),if_DASH_463794);
if(--R.GAS > 0) {
$z37953796 = R.isFunction(if_helper3503777)?if_helper3503777.app(cont_tail_arg3523797):R.ffi.throwNonFunApp(L[373],if_helper3503777,[cont_tail_arg3523797]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper3503777)?if_helper3503777.app(cont_tail_arg3523797):R.ffi.throwNonFunApp(L[373],if_helper3503777,[cont_tail_arg3523797]);
},
"from":L[373]});
}
++R.GAS;
return $z37953796;
}
};
},{"length":3});
var anf_variant_member3663625 = R.makeMethod(function(self453763) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[373],0,arguments);
}
var anf_arg3623760 = G(self453763,"exp",L[373]);
var $z37523753 = D;
var $f37583759 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg3623760):R.ffi.throwNonFunApp(L[373],torepr18,[anf_arg3623760]);
};
try {
if(--R.GAS > 0) {
$z37523753 = $f37583759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37583759,
"from":L[373]});
}
} catch($e37503751) {
if(R.isCont($e37503751)) {
var $ss37543755 = {"from":L[373],
"go":function(anf_arg3633761) {
return $Hanf_arg21693762(anf_arg3633761,_plus14);
}};
$e37503751.stack[R.EXN_STACKHEIGHT++] = $ss37543755;
}
if(R.isPyretException($e37503751)) {
$e37503751.pyretStack.push(L[373]);
}
throw $e37503751;
}
var $ret37563757 = $Hanf_arg21693762($z37523753,_plus14);
++R.GAS;
return $ret37563757;
};
},{"length":1});
var anf_variant_member3703626 = R.makeMethod(function(self2373748) {
return function(printer2383746) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[415],1,arguments);
}
var $z37383739 = D;
var $f37443745 = function(_) {
return R.isFunction(printer2383746)?printer2383746.app(("throw ")):R.ffi.throwNonFunApp(L[414],printer2383746,[("throw ")]);
};
try {
if(--R.GAS > 0) {
$z37383739 = $f37443745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37443745,
"from":L[414]});
}
} catch($e37363737) {
if(R.isCont($e37363737)) {
var $ss37403741 = {"from":L[414],
"go":function(anf_begin_app_dropped21703747) {
return $Hanf_begin_app_dropped21743749(anf_begin_app_dropped21703747,printer2383746,self2373748);
}};
$e37363737.stack[R.EXN_STACKHEIGHT++] = $ss37403741;
}
if(R.isPyretException($e37363737)) {
$e37363737.pyretStack.push(L[414]);
}
throw $e37363737;
}
var $ret37423743 = $Hanf_begin_app_dropped21743749($z37383739,printer2383746,self2373748);
++R.GAS;
return $ret37423743;
};
},{"length":2});
var anf_variant_member3843627 = R.makeMethod(function(self2393734) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[413],0,arguments);
}
var anf_fun3723732 = G(PP123,"group",L[412]);
var anf_fun3733733 = G(PP123,"nest",L[411]);
var anf_fun3743730 = G(PP123,"str",L[410]);
var $z37223723 = D;
var $f37283729 = function(_) {
return R.isFunction(anf_fun3743730)?anf_fun3743730.app(("throw ")):R.ffi.throwNonFunApp(L[409],anf_fun3743730,[("throw ")]);
};
try {
if(--R.GAS > 0) {
$z37223723 = $f37283729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37283729,
"from":L[409]});
}
} catch($e37203721) {
if(R.isCont($e37203721)) {
var $ss37243725 = {"from":L[409],
"go":function(anf_arg3753731) {
return $Hanf_arg21813735(anf_arg3753731,INDENT7747,PP123,anf_fun3723732,anf_fun3733733,self2393734,_plus14);
}};
$e37203721.stack[R.EXN_STACKHEIGHT++] = $ss37243725;
}
if(R.isPyretException($e37203721)) {
$e37203721.pyretStack.push(L[409]);
}
throw $e37203721;
}
var $ret37263727 = $Hanf_arg21813735($z37223723,INDENT7747,PP123,anf_fun3723732,anf_fun3733733,self2393734,_plus14);
++R.GAS;
return $ret37263727;
};
},{"length":1});
var anf_variant_member3963634 = R.makeMethod(function(self483698) {
return function(cases_DASH_funs493699,else_DASH_clause503710) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[372],2,arguments);
}
var if_DASH_523713 = R.hasField(cases_DASH_funs493699,("j-expr"));
var if_helper3863696 = R.makeFunction(function(if_helper_arg3873718) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[372],1,arguments);
}
var ann_DASH_check_DASH_temp3853719 = if_helper_arg3873718;
return ann_DASH_check_DASH_temp3853719;
});
var anf_if3903717 = R.isBoolean(if_DASH_523713);
if(R.isPyretTrue(anf_if3903717)) {
if(R.isPyretTrue(if_DASH_523713)) {
var call_DASH_j_DASH_expr473693 = G(cases_DASH_funs493699,"j-expr",L[372]);
var anf_arg3933694 = G(self483698,"expr",L[408]);
var $z36853686 = D;
var $f36913692 = function(_) {
return R.isFunction(call_DASH_j_DASH_expr473693)?call_DASH_j_DASH_expr473693.app(anf_arg3933694):R.ffi.throwNonFunApp(L[372],call_DASH_j_DASH_expr473693,[anf_arg3933694]);
};
try {
if(--R.GAS > 0) {
$z36853686 = $f36913692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36913692,
"from":L[372]});
}
} catch($e36833684) {
if(R.isCont($e36833684)) {
var $ss36873688 = {"from":L[372],
"go":function(cont_tail_arg3943695) {
return $Hcont_tail_arg21823697(cont_tail_arg3943695,if_helper3863696);
}};
$e36833684.stack[R.EXN_STACKHEIGHT++] = $ss36873688;
}
if(R.isPyretException($e36833684)) {
$e36833684.pyretStack.push(L[372]);
}
throw $e36833684;
}
var $ret36893690 = $Hcont_tail_arg21823697($z36853686,if_helper3863696);
++R.GAS;
return $ret36893690;
} else {
var $z37023703 = D;
var $f37083709 = function(_) {
return R.isFunction(else_DASH_clause503710)?else_DASH_clause503710.app():R.ffi.throwNonFunApp(L[372],else_DASH_clause503710,[]);
};
try {
if(--R.GAS > 0) {
$z37023703 = $f37083709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37083709,
"from":L[372]});
}
} catch($e37003701) {
if(R.isCont($e37003701)) {
var $ss37043705 = {"from":L[372],
"go":function(cont_tail_arg3913711) {
return $Hcont_tail_arg21833712(cont_tail_arg3913711,if_helper3863696);
}};
$e37003701.stack[R.EXN_STACKHEIGHT++] = $ss37043705;
}
if(R.isPyretException($e37003701)) {
$e37003701.pyretStack.push(L[372]);
}
throw $e37003701;
}
var $ret37063707 = $Hcont_tail_arg21833712($z37023703,if_helper3863696);
++R.GAS;
return $ret37063707;
}
} else {
var cont_tail_arg3883716 = R.throwNonBooleanCondition(L[372],("if"),if_DASH_523713);
if(--R.GAS > 0) {
$z37143715 = R.isFunction(if_helper3863696)?if_helper3863696.app(cont_tail_arg3883716):R.ffi.throwNonFunApp(L[372],if_helper3863696,[cont_tail_arg3883716]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper3863696)?if_helper3863696.app(cont_tail_arg3883716):R.ffi.throwNonFunApp(L[372],if_helper3863696,[cont_tail_arg3883716]);
},
"from":L[372]});
}
++R.GAS;
return $z37143715;
}
};
},{"length":3});
var anf_variant_member4023635 = R.makeMethod(function(self513682) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[372],0,arguments);
}
var anf_arg3983679 = G(self513682,"expr",L[372]);
var $z36713672 = D;
var $f36773678 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg3983679):R.ffi.throwNonFunApp(L[372],torepr18,[anf_arg3983679]);
};
try {
if(--R.GAS > 0) {
$z36713672 = $f36773678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36773678,
"from":L[372]});
}
} catch($e36693670) {
if(R.isCont($e36693670)) {
var $ss36733674 = {"from":L[372],
"go":function(anf_arg3993680) {
return $Hanf_arg21873681(anf_arg3993680,_plus14);
}};
$e36693670.stack[R.EXN_STACKHEIGHT++] = $ss36733674;
}
if(R.isPyretException($e36693670)) {
$e36693670.pyretStack.push(L[372]);
}
throw $e36693670;
}
var $ret36753676 = $Hanf_arg21873681($z36713672,_plus14);
++R.GAS;
return $ret36753676;
};
},{"length":1});
var anf_variant_member4063636 = R.makeMethod(function(self2411493) {
return function(printer2423665) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[407],1,arguments);
}
var anf_bracket4043668 = G(self2411493,"expr",L[406]);
var anf_fun4053664 = G(anf_bracket4043668,"print-ugly-source",L[405]);
var $z36563657 = D;
var $f36623663 = function(_) {
return R.isFunction(anf_fun4053664)?anf_fun4053664.app(printer2423665):R.ffi.throwNonFunApp(L[404],anf_fun4053664,[printer2423665]);
};
try {
if(--R.GAS > 0) {
$z36563657 = $f36623663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36623663,
"from":L[404]});
}
} catch($e36543655) {
if(R.isCont($e36543655)) {
var $ss36583659 = {"from":L[404],
"go":function(anf_begin_app_dropped21883666) {
return $Hanf_begin_app_dropped21903667(anf_begin_app_dropped21883666,printer2423665);
}};
$e36543655.stack[R.EXN_STACKHEIGHT++] = $ss36583659;
}
if(R.isPyretException($e36543655)) {
$e36543655.pyretStack.push(L[404]);
}
throw $e36543655;
}
var $ret36603661 = $Hanf_begin_app_dropped21903667($z36563657,printer2423665);
++R.GAS;
return $ret36603661;
};
},{"length":2});
var anf_variant_member4133637 = R.makeMethod(function(self2433653) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[403],0,arguments);
}
var anf_bracket4083652 = G(self2433653,"expr",L[402]);
var anf_fun4093649 = G(anf_bracket4083652,"tosource",L[401]);
var $z36413642 = D;
var $f36473648 = function(_) {
return R.isFunction(anf_fun4093649)?anf_fun4093649.app():R.ffi.throwNonFunApp(L[400],anf_fun4093649,[]);
};
try {
if(--R.GAS > 0) {
$z36413642 = $f36473648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36473648,
"from":L[400]});
}
} catch($e36393640) {
if(R.isCont($e36393640)) {
var $ss36433644 = {"from":L[400],
"go":function(anf_arg4103650) {
return $Hanf_arg21933651(anf_arg4103650,PP123,_plus14);
}};
$e36393640.stack[R.EXN_STACKHEIGHT++] = $ss36433644;
}
if(R.isPyretException($e36393640)) {
$e36393640.pyretStack.push(L[400]);
}
throw $e36393640;
}
var $ret36453646 = $Hanf_arg21933651($z36413642,PP123,_plus14);
++R.GAS;
return $ret36453646;
};
},{"length":1});
var anf_assign41491 = (function() {
var $j_DASH_var_DASH_base35633564 = {"to-ugly-source":anf_shared743562,
"_match":anf_variant_member873568,
"_torepr":anf_variant_member973569,
"print-ugly-source":anf_variant_member1043570,
"tosource":anf_variant_member1303571};
var $j_DASH_var_DASH_brands35663567 = {"$brand-j-var3565":true};
$j_DASH_var_DASH_brands35663567[JStmtT36757._brand] = true
var $j_DASH_if1_DASH_base35743575 = {"to-ugly-source":anf_shared743562,
"_match":anf_variant_member1433579,
"_torepr":anf_variant_member1533580,
"print-ugly-source":anf_variant_member1593581,
"tosource":anf_variant_member1813582};
var $j_DASH_if1_DASH_brands35773578 = {"$brand-j-if13576":true};
$j_DASH_if1_DASH_brands35773578[JStmtT36757._brand] = true
var $j_DASH_if_DASH_base35853586 = {"to-ugly-source":anf_shared743562,
"_match":anf_variant_member1953590,
"_torepr":anf_variant_member2093591,
"print-ugly-source":anf_variant_member2173592,
"tosource":anf_variant_member2583593};
var $j_DASH_if_DASH_brands35883589 = {"$brand-j-if3587":true};
$j_DASH_if_DASH_brands35883589[JStmtT36757._brand] = true
var $j_DASH_return_DASH_base35973598 = {"to-ugly-source":anf_shared743562,
"_match":anf_variant_member2703602,
"_torepr":anf_variant_member2763603,
"print-ugly-source":anf_variant_member2803604,
"tosource":anf_variant_member2903605};
var $j_DASH_return_DASH_brands36003601 = {"$brand-j-return3599":true};
$j_DASH_return_DASH_brands36003601[JStmtT36757._brand] = true
var $j_DASH_try_DASH_catch_DASH_base36073608 = {"to-ugly-source":anf_shared743562,
"_match":anf_variant_member3043612,
"_torepr":anf_variant_member3183613,
"print-ugly-source":anf_variant_member3273614,
"tosource":anf_variant_member3483615};
var $j_DASH_try_DASH_catch_DASH_brands36103611 = {"$brand-j-try-catch3609":true};
$j_DASH_try_DASH_catch_DASH_brands36103611[JStmtT36757._brand] = true
var $j_DASH_throw_DASH_base36193620 = {"to-ugly-source":anf_shared743562,
"_match":anf_variant_member3603624,
"_torepr":anf_variant_member3663625,
"print-ugly-source":anf_variant_member3703626,
"tosource":anf_variant_member3843627};
var $j_DASH_throw_DASH_brands36223623 = {"$brand-j-throw3621":true};
$j_DASH_throw_DASH_brands36223623[JStmtT36757._brand] = true
var $j_DASH_expr_DASH_base36293630 = {"to-ugly-source":anf_shared743562,
"_match":anf_variant_member3963634,
"_torepr":anf_variant_member4023635,
"print-ugly-source":anf_variant_member4063636,
"tosource":anf_variant_member4133637};
var $j_DASH_expr_DASH_brands36323633 = {"$brand-j-expr3631":true};
$j_DASH_expr_DASH_brands36323633[JStmtT36757._brand] = true
return R.makeObject({"JStmt":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[379],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,JStmtT36757._brand));
}),
"is-j-var":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[378],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-var3565"));
}),
"j-var":R.makeFunction(function(name2083572,rhs2093573) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[380],2,arguments);
}
return R.checkAnnArgs([$type$String22,JExpr7252],[name2083572,rhs2093573],[L[381],L[382]],function() {
var dict = R.create($j_DASH_var_DASH_base35633564);
dict["name"] = name2083572
dict["rhs"] = rhs2093573
return R.makeBrandedObject(dict,$j_DASH_var_DASH_brands35663567);
});
}),
"is-j-if1":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[377],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-if13576"));
}),
"j-if1":R.makeFunction(function(cond2133583,consq2143584) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[383],2,arguments);
}
return R.checkAnnArgs([JExpr7252,JBlock6450],[cond2133583,consq2143584],[L[384],L[385]],function() {
var dict = R.create($j_DASH_if1_DASH_base35743575);
dict["cond"] = cond2133583
dict["consq"] = consq2143584
return R.makeBrandedObject(dict,$j_DASH_if1_DASH_brands35773578);
});
}),
"is-j-if":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[376],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-if3587"));
}),
"j-if":R.makeFunction(function(cond2183594,consq2193595,alt2203596) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[386],3,arguments);
}
return R.checkAnnArgs([JExpr7252,JBlock6450,JBlock6450],[cond2183594,consq2193595,alt2203596],[L[387],L[388],L[389]],function() {
var dict = R.create($j_DASH_if_DASH_base35853586);
dict["cond"] = cond2183594
dict["consq"] = consq2193595
dict["alt"] = alt2203596
return R.makeBrandedObject(dict,$j_DASH_if_DASH_brands35883589);
});
}),
"is-j-return":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[375],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-return3599"));
}),
"j-return":R.makeFunction(function(expr2263606) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[390],1,arguments);
}
return R.checkAnnArgs([JExpr7252],[expr2263606],[L[391]],function() {
var dict = R.create($j_DASH_return_DASH_base35973598);
dict["expr"] = expr2263606
return R.makeBrandedObject(dict,$j_DASH_return_DASH_brands36003601);
});
}),
"is-j-try-catch":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[374],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-try-catch3609"));
}),
"j-try-catch":R.makeFunction(function(body2303616,exn2313617,catch2323618) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[392],3,arguments);
}
return R.checkAnnArgs([JStmt6656,$type$String22,JBlock6450],[body2303616,exn2313617,catch2323618],[L[393],L[394],L[395]],function() {
var dict = R.create($j_DASH_try_DASH_catch_DASH_base36073608);
dict["body"] = body2303616
dict["exn"] = exn2313617
dict["catch"] = catch2323618
return R.makeBrandedObject(dict,$j_DASH_try_DASH_catch_DASH_brands36103611);
});
}),
"is-j-throw":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[373],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-throw3621"));
}),
"j-throw":R.makeFunction(function(exp2363628) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[396],1,arguments);
}
return R.checkAnnArgs([JExpr7252],[exp2363628],[L[397]],function() {
var dict = R.create($j_DASH_throw_DASH_base36193620);
dict["exp"] = exp2363628
return R.makeBrandedObject(dict,$j_DASH_throw_DASH_brands36223623);
});
}),
"is-j-expr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[372],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-expr3631"));
}),
"j-expr":R.makeFunction(function(expr2403638) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[398],1,arguments);
}
return R.checkAnnArgs([JExpr7252],[expr2403638],[L[399]],function() {
var dict = R.create($j_DASH_expr_DASH_base36293630);
dict["expr"] = expr2403638
return R.makeBrandedObject(dict,$j_DASH_expr_DASH_brands36323633);
});
})});
})();
JStmt98690.$var = anf_assign41491;
var anf_assign41593 = G(JStmt98690.$var,"JStmt",L[379]);
JStmt8792.$var = anf_assign41593;
var anf_assign41695 = G(JStmt98690.$var,"JStmt",L[379]);
is_DASH_JStmt8894.$var = anf_assign41695;
var anf_assign41797 = G(JStmt98690.$var,"is-j-var",L[378]);
is_DASH_j_DASH_var8996.$var = anf_assign41797;
var anf_assign41899 = G(JStmt98690.$var,"j-var",L[378]);
j_DASH_var9098.$var = anf_assign41899;
var anf_assign419101 = G(JStmt98690.$var,"is-j-if1",L[377]);
is_DASH_j_DASH_if191100.$var = anf_assign419101;
var anf_assign420103 = G(JStmt98690.$var,"j-if1",L[377]);
j_DASH_if192102.$var = anf_assign420103;
var anf_assign421105 = G(JStmt98690.$var,"is-j-if",L[376]);
is_DASH_j_DASH_if93104.$var = anf_assign421105;
var anf_assign422107 = G(JStmt98690.$var,"j-if",L[376]);
j_DASH_if94106.$var = anf_assign422107;
var anf_assign423109 = G(JStmt98690.$var,"is-j-return",L[375]);
is_DASH_j_DASH_return95108.$var = anf_assign423109;
var anf_assign424111 = G(JStmt98690.$var,"j-return",L[375]);
j_DASH_return96110.$var = anf_assign424111;
var anf_assign425113 = G(JStmt98690.$var,"is-j-try-catch",L[374]);
is_DASH_j_DASH_try_DASH_catch97112.$var = anf_assign425113;
var anf_assign426115 = G(JStmt98690.$var,"j-try-catch",L[374]);
j_DASH_try_DASH_catch98114.$var = anf_assign426115;
var anf_assign427117 = G(JStmt98690.$var,"is-j-throw",L[373]);
is_DASH_j_DASH_throw99116.$var = anf_assign427117;
var anf_assign428119 = G(JStmt98690.$var,"j-throw",L[373]);
j_DASH_throw100118.$var = anf_assign428119;
var anf_assign429121 = G(JStmt98690.$var,"is-j-expr",L[372]);
is_DASH_j_DASH_expr101120.$var = anf_assign429121;
var anf_assign430123 = G(JStmt98690.$var,"j-expr",L[372]);
j_DASH_expr102122.$var = anf_assign430123;
var anf_shared4342863 = R.makeMethod(function(self2601267) {
return function(printer2613560) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[371],1,arguments);
}
var anf_fun4323558 = G(self2601267,"to-ugly-source",L[370]);
var $z35503551 = D;
var $f35563557 = function(_) {
return R.isFunction(anf_fun4323558)?anf_fun4323558.app():R.ffi.throwNonFunApp(L[369],anf_fun4323558,[]);
};
try {
if(--R.GAS > 0) {
$z35503551 = $f35563557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35563557,
"from":L[369]});
}
} catch($e35483549) {
if(R.isCont($e35483549)) {
var $ss35523553 = {"from":L[369],
"go":function(anf_arg4333559) {
return $Hanf_arg21953561(anf_arg4333559,printer2613560);
}};
$e35483549.stack[R.EXN_STACKHEIGHT++] = $ss35523553;
}
if(R.isPyretException($e35483549)) {
$e35483549.pyretStack.push(L[369]);
}
throw $e35483549;
}
var $ret35543555 = $Hanf_arg21953561($z35503551,printer2613560);
++R.GAS;
return $ret35543555;
};
},{"length":2});
var anf_shared4392864 = R.makeMethod(function(self2623547) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[368],0,arguments);
}
var anf_fun4363545 = G(PP123,"str",L[367]);
var anf_fun4373543 = G(self2623547,"to-ugly-source",L[366]);
var $z35353536 = D;
var $f35413542 = function(_) {
return R.isFunction(anf_fun4373543)?anf_fun4373543.app():R.ffi.throwNonFunApp(L[365],anf_fun4373543,[]);
};
try {
if(--R.GAS > 0) {
$z35353536 = $f35413542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35413542,
"from":L[365]});
}
} catch($e35333534) {
if(R.isCont($e35333534)) {
var $ss35373538 = {"from":L[365],
"go":function(anf_arg4383544) {
return $Hanf_arg21973546(anf_arg4383544,anf_fun4363545);
}};
$e35333534.stack[R.EXN_STACKHEIGHT++] = $ss35373538;
}
if(R.isPyretException($e35333534)) {
$e35333534.pyretStack.push(L[365]);
}
throw $e35333534;
}
var $ret35393540 = $Hanf_arg21973546($z35353536,anf_fun4363545);
++R.GAS;
return $ret35393540;
};
},{"length":1});
var anf_singleton_variant_member4502870 = R.makeMethod(function(self543532) {
return function(cases_DASH_funs553511,else_DASH_clause563522) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[349],2,arguments);
}
var if_DASH_583525 = R.hasField(cases_DASH_funs553511,("j-plus"));
var if_helper4413509 = R.makeFunction(function(if_helper_arg4423530) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[349],1,arguments);
}
var ann_DASH_check_DASH_temp4403531 = if_helper_arg4423530;
return ann_DASH_check_DASH_temp4403531;
});
var anf_if4453529 = R.isBoolean(if_DASH_583525);
if(R.isPyretTrue(anf_if4453529)) {
if(R.isPyretTrue(if_DASH_583525)) {
var call_DASH_j_DASH_plus533507 = G(cases_DASH_funs553511,"j-plus",L[349]);
var $z34993500 = D;
var $f35053506 = function(_) {
return R.isFunction(call_DASH_j_DASH_plus533507)?call_DASH_j_DASH_plus533507.app():R.ffi.throwNonFunApp(L[349],call_DASH_j_DASH_plus533507,[]);
};
try {
if(--R.GAS > 0) {
$z34993500 = $f35053506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35053506,
"from":L[349]});
}
} catch($e34973498) {
if(R.isCont($e34973498)) {
var $ss35013502 = {"from":L[349],
"go":function(cont_tail_arg4483508) {
return $Hcont_tail_arg21983510(cont_tail_arg4483508,if_helper4413509);
}};
$e34973498.stack[R.EXN_STACKHEIGHT++] = $ss35013502;
}
if(R.isPyretException($e34973498)) {
$e34973498.pyretStack.push(L[349]);
}
throw $e34973498;
}
var $ret35033504 = $Hcont_tail_arg21983510($z34993500,if_helper4413509);
++R.GAS;
return $ret35033504;
} else {
var $z35143515 = D;
var $f35203521 = function(_) {
return R.isFunction(else_DASH_clause563522)?else_DASH_clause563522.app():R.ffi.throwNonFunApp(L[349],else_DASH_clause563522,[]);
};
try {
if(--R.GAS > 0) {
$z35143515 = $f35203521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35203521,
"from":L[349]});
}
} catch($e35123513) {
if(R.isCont($e35123513)) {
var $ss35163517 = {"from":L[349],
"go":function(cont_tail_arg4463523) {
return $Hcont_tail_arg21993524(cont_tail_arg4463523,if_helper4413509);
}};
$e35123513.stack[R.EXN_STACKHEIGHT++] = $ss35163517;
}
if(R.isPyretException($e35123513)) {
$e35123513.pyretStack.push(L[349]);
}
throw $e35123513;
}
var $ret35183519 = $Hcont_tail_arg21993524($z35143515,if_helper4413509);
++R.GAS;
return $ret35183519;
}
} else {
var cont_tail_arg4433528 = R.throwNonBooleanCondition(L[349],("if"),if_DASH_583525);
if(--R.GAS > 0) {
$z35263527 = R.isFunction(if_helper4413509)?if_helper4413509.app(cont_tail_arg4433528):R.ffi.throwNonFunApp(L[349],if_helper4413509,[cont_tail_arg4433528]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4413509)?if_helper4413509.app(cont_tail_arg4433528):R.ffi.throwNonFunApp(L[349],if_helper4413509,[cont_tail_arg4433528]);
},
"from":L[349]});
}
++R.GAS;
return $z35263527;
}
};
},{"length":3});
var anf_singleton_variant_member4522871 = R.makeMethod(function(self573496) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[349],0,arguments);
}
var ann_DASH_check_DASH_temp4513495 = ("j-plus");
return ann_DASH_check_DASH_temp4513495;
};
},{"length":1});
var anf_singleton_variant_member4542872 = R.makeMethod(function(self2463494) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[364],0,arguments);
}
var ann_DASH_check_DASH_temp4533493 = ("+");
return ann_DASH_check_DASH_temp4533493;
};
},{"length":1});
var anf_singleton_variant_member4652878 = R.makeMethod(function(self603492) {
return function(cases_DASH_funs613471,else_DASH_clause623482) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[348],2,arguments);
}
var if_DASH_643485 = R.hasField(cases_DASH_funs613471,("j-minus"));
var if_helper4563469 = R.makeFunction(function(if_helper_arg4573490) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[348],1,arguments);
}
var ann_DASH_check_DASH_temp4553491 = if_helper_arg4573490;
return ann_DASH_check_DASH_temp4553491;
});
var anf_if4603489 = R.isBoolean(if_DASH_643485);
if(R.isPyretTrue(anf_if4603489)) {
if(R.isPyretTrue(if_DASH_643485)) {
var call_DASH_j_DASH_minus593467 = G(cases_DASH_funs613471,"j-minus",L[348]);
var $z34593460 = D;
var $f34653466 = function(_) {
return R.isFunction(call_DASH_j_DASH_minus593467)?call_DASH_j_DASH_minus593467.app():R.ffi.throwNonFunApp(L[348],call_DASH_j_DASH_minus593467,[]);
};
try {
if(--R.GAS > 0) {
$z34593460 = $f34653466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34653466,
"from":L[348]});
}
} catch($e34573458) {
if(R.isCont($e34573458)) {
var $ss34613462 = {"from":L[348],
"go":function(cont_tail_arg4633468) {
return $Hcont_tail_arg22003470(cont_tail_arg4633468,if_helper4563469);
}};
$e34573458.stack[R.EXN_STACKHEIGHT++] = $ss34613462;
}
if(R.isPyretException($e34573458)) {
$e34573458.pyretStack.push(L[348]);
}
throw $e34573458;
}
var $ret34633464 = $Hcont_tail_arg22003470($z34593460,if_helper4563469);
++R.GAS;
return $ret34633464;
} else {
var $z34743475 = D;
var $f34803481 = function(_) {
return R.isFunction(else_DASH_clause623482)?else_DASH_clause623482.app():R.ffi.throwNonFunApp(L[348],else_DASH_clause623482,[]);
};
try {
if(--R.GAS > 0) {
$z34743475 = $f34803481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34803481,
"from":L[348]});
}
} catch($e34723473) {
if(R.isCont($e34723473)) {
var $ss34763477 = {"from":L[348],
"go":function(cont_tail_arg4613483) {
return $Hcont_tail_arg22013484(cont_tail_arg4613483,if_helper4563469);
}};
$e34723473.stack[R.EXN_STACKHEIGHT++] = $ss34763477;
}
if(R.isPyretException($e34723473)) {
$e34723473.pyretStack.push(L[348]);
}
throw $e34723473;
}
var $ret34783479 = $Hcont_tail_arg22013484($z34743475,if_helper4563469);
++R.GAS;
return $ret34783479;
}
} else {
var cont_tail_arg4583488 = R.throwNonBooleanCondition(L[348],("if"),if_DASH_643485);
if(--R.GAS > 0) {
$z34863487 = R.isFunction(if_helper4563469)?if_helper4563469.app(cont_tail_arg4583488):R.ffi.throwNonFunApp(L[348],if_helper4563469,[cont_tail_arg4583488]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4563469)?if_helper4563469.app(cont_tail_arg4583488):R.ffi.throwNonFunApp(L[348],if_helper4563469,[cont_tail_arg4583488]);
},
"from":L[348]});
}
++R.GAS;
return $z34863487;
}
};
},{"length":3});
var anf_singleton_variant_member4672879 = R.makeMethod(function(self633456) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[348],0,arguments);
}
var ann_DASH_check_DASH_temp4663455 = ("j-minus");
return ann_DASH_check_DASH_temp4663455;
};
},{"length":1});
var anf_singleton_variant_member4692880 = R.makeMethod(function(self2471429) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[363],0,arguments);
}
var ann_DASH_check_DASH_temp4683454 = ("-");
return ann_DASH_check_DASH_temp4683454;
};
},{"length":1});
var anf_singleton_variant_member4802886 = R.makeMethod(function(self663453) {
return function(cases_DASH_funs673432,else_DASH_clause683443) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[347],2,arguments);
}
var if_DASH_703446 = R.hasField(cases_DASH_funs673432,("j-times"));
var if_helper4713430 = R.makeFunction(function(if_helper_arg4723451) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[347],1,arguments);
}
var ann_DASH_check_DASH_temp4703452 = if_helper_arg4723451;
return ann_DASH_check_DASH_temp4703452;
});
var anf_if4753450 = R.isBoolean(if_DASH_703446);
if(R.isPyretTrue(anf_if4753450)) {
if(R.isPyretTrue(if_DASH_703446)) {
var call_DASH_j_DASH_times653428 = G(cases_DASH_funs673432,"j-times",L[347]);
var $z34203421 = D;
var $f34263427 = function(_) {
return R.isFunction(call_DASH_j_DASH_times653428)?call_DASH_j_DASH_times653428.app():R.ffi.throwNonFunApp(L[347],call_DASH_j_DASH_times653428,[]);
};
try {
if(--R.GAS > 0) {
$z34203421 = $f34263427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34263427,
"from":L[347]});
}
} catch($e34183419) {
if(R.isCont($e34183419)) {
var $ss34223423 = {"from":L[347],
"go":function(cont_tail_arg4783429) {
return $Hcont_tail_arg22023431(cont_tail_arg4783429,if_helper4713430);
}};
$e34183419.stack[R.EXN_STACKHEIGHT++] = $ss34223423;
}
if(R.isPyretException($e34183419)) {
$e34183419.pyretStack.push(L[347]);
}
throw $e34183419;
}
var $ret34243425 = $Hcont_tail_arg22023431($z34203421,if_helper4713430);
++R.GAS;
return $ret34243425;
} else {
var $z34353436 = D;
var $f34413442 = function(_) {
return R.isFunction(else_DASH_clause683443)?else_DASH_clause683443.app():R.ffi.throwNonFunApp(L[347],else_DASH_clause683443,[]);
};
try {
if(--R.GAS > 0) {
$z34353436 = $f34413442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34413442,
"from":L[347]});
}
} catch($e34333434) {
if(R.isCont($e34333434)) {
var $ss34373438 = {"from":L[347],
"go":function(cont_tail_arg4763444) {
return $Hcont_tail_arg22033445(cont_tail_arg4763444,if_helper4713430);
}};
$e34333434.stack[R.EXN_STACKHEIGHT++] = $ss34373438;
}
if(R.isPyretException($e34333434)) {
$e34333434.pyretStack.push(L[347]);
}
throw $e34333434;
}
var $ret34393440 = $Hcont_tail_arg22033445($z34353436,if_helper4713430);
++R.GAS;
return $ret34393440;
}
} else {
var cont_tail_arg4733449 = R.throwNonBooleanCondition(L[347],("if"),if_DASH_703446);
if(--R.GAS > 0) {
$z34473448 = R.isFunction(if_helper4713430)?if_helper4713430.app(cont_tail_arg4733449):R.ffi.throwNonFunApp(L[347],if_helper4713430,[cont_tail_arg4733449]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4713430)?if_helper4713430.app(cont_tail_arg4733449):R.ffi.throwNonFunApp(L[347],if_helper4713430,[cont_tail_arg4733449]);
},
"from":L[347]});
}
++R.GAS;
return $z34473448;
}
};
},{"length":3});
var anf_singleton_variant_member4822887 = R.makeMethod(function(self693417) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[347],0,arguments);
}
var ann_DASH_check_DASH_temp4813416 = ("j-times");
return ann_DASH_check_DASH_temp4813416;
};
},{"length":1});
var anf_singleton_variant_member4842888 = R.makeMethod(function(self2483415) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[362],0,arguments);
}
var ann_DASH_check_DASH_temp4833414 = ("*");
return ann_DASH_check_DASH_temp4833414;
};
},{"length":1});
var anf_singleton_variant_member4952894 = R.makeMethod(function(self723413) {
return function(cases_DASH_funs733392,else_DASH_clause743403) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[346],2,arguments);
}
var if_DASH_763406 = R.hasField(cases_DASH_funs733392,("j-divide"));
var if_helper4863390 = R.makeFunction(function(if_helper_arg4873411) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[346],1,arguments);
}
var ann_DASH_check_DASH_temp4853412 = if_helper_arg4873411;
return ann_DASH_check_DASH_temp4853412;
});
var anf_if4903410 = R.isBoolean(if_DASH_763406);
if(R.isPyretTrue(anf_if4903410)) {
if(R.isPyretTrue(if_DASH_763406)) {
var call_DASH_j_DASH_divide713388 = G(cases_DASH_funs733392,"j-divide",L[346]);
var $z33803381 = D;
var $f33863387 = function(_) {
return R.isFunction(call_DASH_j_DASH_divide713388)?call_DASH_j_DASH_divide713388.app():R.ffi.throwNonFunApp(L[346],call_DASH_j_DASH_divide713388,[]);
};
try {
if(--R.GAS > 0) {
$z33803381 = $f33863387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33863387,
"from":L[346]});
}
} catch($e33783379) {
if(R.isCont($e33783379)) {
var $ss33823383 = {"from":L[346],
"go":function(cont_tail_arg4933389) {
return $Hcont_tail_arg22043391(cont_tail_arg4933389,if_helper4863390);
}};
$e33783379.stack[R.EXN_STACKHEIGHT++] = $ss33823383;
}
if(R.isPyretException($e33783379)) {
$e33783379.pyretStack.push(L[346]);
}
throw $e33783379;
}
var $ret33843385 = $Hcont_tail_arg22043391($z33803381,if_helper4863390);
++R.GAS;
return $ret33843385;
} else {
var $z33953396 = D;
var $f34013402 = function(_) {
return R.isFunction(else_DASH_clause743403)?else_DASH_clause743403.app():R.ffi.throwNonFunApp(L[346],else_DASH_clause743403,[]);
};
try {
if(--R.GAS > 0) {
$z33953396 = $f34013402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34013402,
"from":L[346]});
}
} catch($e33933394) {
if(R.isCont($e33933394)) {
var $ss33973398 = {"from":L[346],
"go":function(cont_tail_arg4913404) {
return $Hcont_tail_arg22053405(cont_tail_arg4913404,if_helper4863390);
}};
$e33933394.stack[R.EXN_STACKHEIGHT++] = $ss33973398;
}
if(R.isPyretException($e33933394)) {
$e33933394.pyretStack.push(L[346]);
}
throw $e33933394;
}
var $ret33993400 = $Hcont_tail_arg22053405($z33953396,if_helper4863390);
++R.GAS;
return $ret33993400;
}
} else {
var cont_tail_arg4883409 = R.throwNonBooleanCondition(L[346],("if"),if_DASH_763406);
if(--R.GAS > 0) {
$z34073408 = R.isFunction(if_helper4863390)?if_helper4863390.app(cont_tail_arg4883409):R.ffi.throwNonFunApp(L[346],if_helper4863390,[cont_tail_arg4883409]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4863390)?if_helper4863390.app(cont_tail_arg4883409):R.ffi.throwNonFunApp(L[346],if_helper4863390,[cont_tail_arg4883409]);
},
"from":L[346]});
}
++R.GAS;
return $z34073408;
}
};
},{"length":3});
var anf_singleton_variant_member4972895 = R.makeMethod(function(self753377) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[346],0,arguments);
}
var ann_DASH_check_DASH_temp4963376 = ("j-divide");
return ann_DASH_check_DASH_temp4963376;
};
},{"length":1});
var anf_singleton_variant_member4992896 = R.makeMethod(function(self2493375) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[361],0,arguments);
}
var ann_DASH_check_DASH_temp4983374 = ("/");
return ann_DASH_check_DASH_temp4983374;
};
},{"length":1});
var anf_singleton_variant_member5102902 = R.makeMethod(function(self783373) {
return function(cases_DASH_funs793352,else_DASH_clause803363) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[345],2,arguments);
}
var if_DASH_823366 = R.hasField(cases_DASH_funs793352,("j-and"));
var if_helper5013350 = R.makeFunction(function(if_helper_arg5023371) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[345],1,arguments);
}
var ann_DASH_check_DASH_temp5003372 = if_helper_arg5023371;
return ann_DASH_check_DASH_temp5003372;
});
var anf_if5053370 = R.isBoolean(if_DASH_823366);
if(R.isPyretTrue(anf_if5053370)) {
if(R.isPyretTrue(if_DASH_823366)) {
var call_DASH_j_DASH_and773348 = G(cases_DASH_funs793352,"j-and",L[345]);
var $z33403341 = D;
var $f33463347 = function(_) {
return R.isFunction(call_DASH_j_DASH_and773348)?call_DASH_j_DASH_and773348.app():R.ffi.throwNonFunApp(L[345],call_DASH_j_DASH_and773348,[]);
};
try {
if(--R.GAS > 0) {
$z33403341 = $f33463347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33463347,
"from":L[345]});
}
} catch($e33383339) {
if(R.isCont($e33383339)) {
var $ss33423343 = {"from":L[345],
"go":function(cont_tail_arg5083349) {
return $Hcont_tail_arg22063351(cont_tail_arg5083349,if_helper5013350);
}};
$e33383339.stack[R.EXN_STACKHEIGHT++] = $ss33423343;
}
if(R.isPyretException($e33383339)) {
$e33383339.pyretStack.push(L[345]);
}
throw $e33383339;
}
var $ret33443345 = $Hcont_tail_arg22063351($z33403341,if_helper5013350);
++R.GAS;
return $ret33443345;
} else {
var $z33553356 = D;
var $f33613362 = function(_) {
return R.isFunction(else_DASH_clause803363)?else_DASH_clause803363.app():R.ffi.throwNonFunApp(L[345],else_DASH_clause803363,[]);
};
try {
if(--R.GAS > 0) {
$z33553356 = $f33613362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33613362,
"from":L[345]});
}
} catch($e33533354) {
if(R.isCont($e33533354)) {
var $ss33573358 = {"from":L[345],
"go":function(cont_tail_arg5063364) {
return $Hcont_tail_arg22073365(cont_tail_arg5063364,if_helper5013350);
}};
$e33533354.stack[R.EXN_STACKHEIGHT++] = $ss33573358;
}
if(R.isPyretException($e33533354)) {
$e33533354.pyretStack.push(L[345]);
}
throw $e33533354;
}
var $ret33593360 = $Hcont_tail_arg22073365($z33553356,if_helper5013350);
++R.GAS;
return $ret33593360;
}
} else {
var cont_tail_arg5033369 = R.throwNonBooleanCondition(L[345],("if"),if_DASH_823366);
if(--R.GAS > 0) {
$z33673368 = R.isFunction(if_helper5013350)?if_helper5013350.app(cont_tail_arg5033369):R.ffi.throwNonFunApp(L[345],if_helper5013350,[cont_tail_arg5033369]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5013350)?if_helper5013350.app(cont_tail_arg5033369):R.ffi.throwNonFunApp(L[345],if_helper5013350,[cont_tail_arg5033369]);
},
"from":L[345]});
}
++R.GAS;
return $z33673368;
}
};
},{"length":3});
var anf_singleton_variant_member5122903 = R.makeMethod(function(self813337) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[345],0,arguments);
}
var ann_DASH_check_DASH_temp5113336 = ("j-and");
return ann_DASH_check_DASH_temp5113336;
};
},{"length":1});
var anf_singleton_variant_member5142904 = R.makeMethod(function(self2501413) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[360],0,arguments);
}
var ann_DASH_check_DASH_temp5133335 = ("&&");
return ann_DASH_check_DASH_temp5133335;
};
},{"length":1});
var anf_singleton_variant_member5252910 = R.makeMethod(function(self843334) {
return function(cases_DASH_funs853313,else_DASH_clause863324) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[344],2,arguments);
}
var if_DASH_883327 = R.hasField(cases_DASH_funs853313,("j-or"));
var if_helper5163311 = R.makeFunction(function(if_helper_arg5173332) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[344],1,arguments);
}
var ann_DASH_check_DASH_temp5153333 = if_helper_arg5173332;
return ann_DASH_check_DASH_temp5153333;
});
var anf_if5203331 = R.isBoolean(if_DASH_883327);
if(R.isPyretTrue(anf_if5203331)) {
if(R.isPyretTrue(if_DASH_883327)) {
var call_DASH_j_DASH_or833309 = G(cases_DASH_funs853313,"j-or",L[344]);
var $z33013302 = D;
var $f33073308 = function(_) {
return R.isFunction(call_DASH_j_DASH_or833309)?call_DASH_j_DASH_or833309.app():R.ffi.throwNonFunApp(L[344],call_DASH_j_DASH_or833309,[]);
};
try {
if(--R.GAS > 0) {
$z33013302 = $f33073308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33073308,
"from":L[344]});
}
} catch($e32993300) {
if(R.isCont($e32993300)) {
var $ss33033304 = {"from":L[344],
"go":function(cont_tail_arg5233310) {
return $Hcont_tail_arg22083312(cont_tail_arg5233310,if_helper5163311);
}};
$e32993300.stack[R.EXN_STACKHEIGHT++] = $ss33033304;
}
if(R.isPyretException($e32993300)) {
$e32993300.pyretStack.push(L[344]);
}
throw $e32993300;
}
var $ret33053306 = $Hcont_tail_arg22083312($z33013302,if_helper5163311);
++R.GAS;
return $ret33053306;
} else {
var $z33163317 = D;
var $f33223323 = function(_) {
return R.isFunction(else_DASH_clause863324)?else_DASH_clause863324.app():R.ffi.throwNonFunApp(L[344],else_DASH_clause863324,[]);
};
try {
if(--R.GAS > 0) {
$z33163317 = $f33223323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33223323,
"from":L[344]});
}
} catch($e33143315) {
if(R.isCont($e33143315)) {
var $ss33183319 = {"from":L[344],
"go":function(cont_tail_arg5213325) {
return $Hcont_tail_arg22093326(cont_tail_arg5213325,if_helper5163311);
}};
$e33143315.stack[R.EXN_STACKHEIGHT++] = $ss33183319;
}
if(R.isPyretException($e33143315)) {
$e33143315.pyretStack.push(L[344]);
}
throw $e33143315;
}
var $ret33203321 = $Hcont_tail_arg22093326($z33163317,if_helper5163311);
++R.GAS;
return $ret33203321;
}
} else {
var cont_tail_arg5183330 = R.throwNonBooleanCondition(L[344],("if"),if_DASH_883327);
if(--R.GAS > 0) {
$z33283329 = R.isFunction(if_helper5163311)?if_helper5163311.app(cont_tail_arg5183330):R.ffi.throwNonFunApp(L[344],if_helper5163311,[cont_tail_arg5183330]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5163311)?if_helper5163311.app(cont_tail_arg5183330):R.ffi.throwNonFunApp(L[344],if_helper5163311,[cont_tail_arg5183330]);
},
"from":L[344]});
}
++R.GAS;
return $z33283329;
}
};
},{"length":3});
var anf_singleton_variant_member5272911 = R.makeMethod(function(self873298) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[344],0,arguments);
}
var ann_DASH_check_DASH_temp5263297 = ("j-or");
return ann_DASH_check_DASH_temp5263297;
};
},{"length":1});
var anf_singleton_variant_member5292912 = R.makeMethod(function(self2513296) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[359],0,arguments);
}
var ann_DASH_check_DASH_temp5283295 = ("||");
return ann_DASH_check_DASH_temp5283295;
};
},{"length":1});
var anf_singleton_variant_member5402918 = R.makeMethod(function(self903294) {
return function(cases_DASH_funs913273,else_DASH_clause923284) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[343],2,arguments);
}
var if_DASH_943287 = R.hasField(cases_DASH_funs913273,("j-lt"));
var if_helper5313271 = R.makeFunction(function(if_helper_arg5323292) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[343],1,arguments);
}
var ann_DASH_check_DASH_temp5303293 = if_helper_arg5323292;
return ann_DASH_check_DASH_temp5303293;
});
var anf_if5353291 = R.isBoolean(if_DASH_943287);
if(R.isPyretTrue(anf_if5353291)) {
if(R.isPyretTrue(if_DASH_943287)) {
var call_DASH_j_DASH_lt893269 = G(cases_DASH_funs913273,"j-lt",L[343]);
var $z32613262 = D;
var $f32673268 = function(_) {
return R.isFunction(call_DASH_j_DASH_lt893269)?call_DASH_j_DASH_lt893269.app():R.ffi.throwNonFunApp(L[343],call_DASH_j_DASH_lt893269,[]);
};
try {
if(--R.GAS > 0) {
$z32613262 = $f32673268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32673268,
"from":L[343]});
}
} catch($e32593260) {
if(R.isCont($e32593260)) {
var $ss32633264 = {"from":L[343],
"go":function(cont_tail_arg5383270) {
return $Hcont_tail_arg22103272(cont_tail_arg5383270,if_helper5313271);
}};
$e32593260.stack[R.EXN_STACKHEIGHT++] = $ss32633264;
}
if(R.isPyretException($e32593260)) {
$e32593260.pyretStack.push(L[343]);
}
throw $e32593260;
}
var $ret32653266 = $Hcont_tail_arg22103272($z32613262,if_helper5313271);
++R.GAS;
return $ret32653266;
} else {
var $z32763277 = D;
var $f32823283 = function(_) {
return R.isFunction(else_DASH_clause923284)?else_DASH_clause923284.app():R.ffi.throwNonFunApp(L[343],else_DASH_clause923284,[]);
};
try {
if(--R.GAS > 0) {
$z32763277 = $f32823283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32823283,
"from":L[343]});
}
} catch($e32743275) {
if(R.isCont($e32743275)) {
var $ss32783279 = {"from":L[343],
"go":function(cont_tail_arg5363285) {
return $Hcont_tail_arg22113286(cont_tail_arg5363285,if_helper5313271);
}};
$e32743275.stack[R.EXN_STACKHEIGHT++] = $ss32783279;
}
if(R.isPyretException($e32743275)) {
$e32743275.pyretStack.push(L[343]);
}
throw $e32743275;
}
var $ret32803281 = $Hcont_tail_arg22113286($z32763277,if_helper5313271);
++R.GAS;
return $ret32803281;
}
} else {
var cont_tail_arg5333290 = R.throwNonBooleanCondition(L[343],("if"),if_DASH_943287);
if(--R.GAS > 0) {
$z32883289 = R.isFunction(if_helper5313271)?if_helper5313271.app(cont_tail_arg5333290):R.ffi.throwNonFunApp(L[343],if_helper5313271,[cont_tail_arg5333290]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5313271)?if_helper5313271.app(cont_tail_arg5333290):R.ffi.throwNonFunApp(L[343],if_helper5313271,[cont_tail_arg5333290]);
},
"from":L[343]});
}
++R.GAS;
return $z32883289;
}
};
},{"length":3});
var anf_singleton_variant_member5422919 = R.makeMethod(function(self933258) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[343],0,arguments);
}
var ann_DASH_check_DASH_temp5413257 = ("j-lt");
return ann_DASH_check_DASH_temp5413257;
};
},{"length":1});
var anf_singleton_variant_member5442920 = R.makeMethod(function(self2523256) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[358],0,arguments);
}
var ann_DASH_check_DASH_temp5433255 = ("<");
return ann_DASH_check_DASH_temp5433255;
};
},{"length":1});
var anf_singleton_variant_member5552926 = R.makeMethod(function(self963254) {
return function(cases_DASH_funs973233,else_DASH_clause983244) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[342],2,arguments);
}
var if_DASH_1003247 = R.hasField(cases_DASH_funs973233,("j-leq"));
var if_helper5463231 = R.makeFunction(function(if_helper_arg5473252) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[342],1,arguments);
}
var ann_DASH_check_DASH_temp5453253 = if_helper_arg5473252;
return ann_DASH_check_DASH_temp5453253;
});
var anf_if5503251 = R.isBoolean(if_DASH_1003247);
if(R.isPyretTrue(anf_if5503251)) {
if(R.isPyretTrue(if_DASH_1003247)) {
var call_DASH_j_DASH_leq953229 = G(cases_DASH_funs973233,"j-leq",L[342]);
var $z32213222 = D;
var $f32273228 = function(_) {
return R.isFunction(call_DASH_j_DASH_leq953229)?call_DASH_j_DASH_leq953229.app():R.ffi.throwNonFunApp(L[342],call_DASH_j_DASH_leq953229,[]);
};
try {
if(--R.GAS > 0) {
$z32213222 = $f32273228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32273228,
"from":L[342]});
}
} catch($e32193220) {
if(R.isCont($e32193220)) {
var $ss32233224 = {"from":L[342],
"go":function(cont_tail_arg5533230) {
return $Hcont_tail_arg22123232(cont_tail_arg5533230,if_helper5463231);
}};
$e32193220.stack[R.EXN_STACKHEIGHT++] = $ss32233224;
}
if(R.isPyretException($e32193220)) {
$e32193220.pyretStack.push(L[342]);
}
throw $e32193220;
}
var $ret32253226 = $Hcont_tail_arg22123232($z32213222,if_helper5463231);
++R.GAS;
return $ret32253226;
} else {
var $z32363237 = D;
var $f32423243 = function(_) {
return R.isFunction(else_DASH_clause983244)?else_DASH_clause983244.app():R.ffi.throwNonFunApp(L[342],else_DASH_clause983244,[]);
};
try {
if(--R.GAS > 0) {
$z32363237 = $f32423243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32423243,
"from":L[342]});
}
} catch($e32343235) {
if(R.isCont($e32343235)) {
var $ss32383239 = {"from":L[342],
"go":function(cont_tail_arg5513245) {
return $Hcont_tail_arg22133246(cont_tail_arg5513245,if_helper5463231);
}};
$e32343235.stack[R.EXN_STACKHEIGHT++] = $ss32383239;
}
if(R.isPyretException($e32343235)) {
$e32343235.pyretStack.push(L[342]);
}
throw $e32343235;
}
var $ret32403241 = $Hcont_tail_arg22133246($z32363237,if_helper5463231);
++R.GAS;
return $ret32403241;
}
} else {
var cont_tail_arg5483250 = R.throwNonBooleanCondition(L[342],("if"),if_DASH_1003247);
if(--R.GAS > 0) {
$z32483249 = R.isFunction(if_helper5463231)?if_helper5463231.app(cont_tail_arg5483250):R.ffi.throwNonFunApp(L[342],if_helper5463231,[cont_tail_arg5483250]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5463231)?if_helper5463231.app(cont_tail_arg5483250):R.ffi.throwNonFunApp(L[342],if_helper5463231,[cont_tail_arg5483250]);
},
"from":L[342]});
}
++R.GAS;
return $z32483249;
}
};
},{"length":3});
var anf_singleton_variant_member5572927 = R.makeMethod(function(self993218) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[342],0,arguments);
}
var ann_DASH_check_DASH_temp5563217 = ("j-leq");
return ann_DASH_check_DASH_temp5563217;
};
},{"length":1});
var anf_singleton_variant_member5592928 = R.makeMethod(function(self2533216) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[357],0,arguments);
}
var ann_DASH_check_DASH_temp5583215 = ("<=");
return ann_DASH_check_DASH_temp5583215;
};
},{"length":1});
var anf_singleton_variant_member5702934 = R.makeMethod(function(self1023214) {
return function(cases_DASH_funs1033193,else_DASH_clause1043204) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[341],2,arguments);
}
var if_DASH_1063207 = R.hasField(cases_DASH_funs1033193,("j-gt"));
var if_helper5613191 = R.makeFunction(function(if_helper_arg5623212) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[341],1,arguments);
}
var ann_DASH_check_DASH_temp5603213 = if_helper_arg5623212;
return ann_DASH_check_DASH_temp5603213;
});
var anf_if5653211 = R.isBoolean(if_DASH_1063207);
if(R.isPyretTrue(anf_if5653211)) {
if(R.isPyretTrue(if_DASH_1063207)) {
var call_DASH_j_DASH_gt1013189 = G(cases_DASH_funs1033193,"j-gt",L[341]);
var $z31813182 = D;
var $f31873188 = function(_) {
return R.isFunction(call_DASH_j_DASH_gt1013189)?call_DASH_j_DASH_gt1013189.app():R.ffi.throwNonFunApp(L[341],call_DASH_j_DASH_gt1013189,[]);
};
try {
if(--R.GAS > 0) {
$z31813182 = $f31873188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31873188,
"from":L[341]});
}
} catch($e31793180) {
if(R.isCont($e31793180)) {
var $ss31833184 = {"from":L[341],
"go":function(cont_tail_arg5683190) {
return $Hcont_tail_arg22143192(cont_tail_arg5683190,if_helper5613191);
}};
$e31793180.stack[R.EXN_STACKHEIGHT++] = $ss31833184;
}
if(R.isPyretException($e31793180)) {
$e31793180.pyretStack.push(L[341]);
}
throw $e31793180;
}
var $ret31853186 = $Hcont_tail_arg22143192($z31813182,if_helper5613191);
++R.GAS;
return $ret31853186;
} else {
var $z31963197 = D;
var $f32023203 = function(_) {
return R.isFunction(else_DASH_clause1043204)?else_DASH_clause1043204.app():R.ffi.throwNonFunApp(L[341],else_DASH_clause1043204,[]);
};
try {
if(--R.GAS > 0) {
$z31963197 = $f32023203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32023203,
"from":L[341]});
}
} catch($e31943195) {
if(R.isCont($e31943195)) {
var $ss31983199 = {"from":L[341],
"go":function(cont_tail_arg5663205) {
return $Hcont_tail_arg22153206(cont_tail_arg5663205,if_helper5613191);
}};
$e31943195.stack[R.EXN_STACKHEIGHT++] = $ss31983199;
}
if(R.isPyretException($e31943195)) {
$e31943195.pyretStack.push(L[341]);
}
throw $e31943195;
}
var $ret32003201 = $Hcont_tail_arg22153206($z31963197,if_helper5613191);
++R.GAS;
return $ret32003201;
}
} else {
var cont_tail_arg5633210 = R.throwNonBooleanCondition(L[341],("if"),if_DASH_1063207);
if(--R.GAS > 0) {
$z32083209 = R.isFunction(if_helper5613191)?if_helper5613191.app(cont_tail_arg5633210):R.ffi.throwNonFunApp(L[341],if_helper5613191,[cont_tail_arg5633210]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5613191)?if_helper5613191.app(cont_tail_arg5633210):R.ffi.throwNonFunApp(L[341],if_helper5613191,[cont_tail_arg5633210]);
},
"from":L[341]});
}
++R.GAS;
return $z32083209;
}
};
},{"length":3});
var anf_singleton_variant_member5722935 = R.makeMethod(function(self1053178) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[341],0,arguments);
}
var ann_DASH_check_DASH_temp5713177 = ("j-gt");
return ann_DASH_check_DASH_temp5713177;
};
},{"length":1});
var anf_singleton_variant_member5742936 = R.makeMethod(function(self2541348) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[356],0,arguments);
}
var ann_DASH_check_DASH_temp5733176 = (">");
return ann_DASH_check_DASH_temp5733176;
};
},{"length":1});
var anf_singleton_variant_member5852942 = R.makeMethod(function(self1083175) {
return function(cases_DASH_funs1093154,else_DASH_clause1103165) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[340],2,arguments);
}
var if_DASH_1123168 = R.hasField(cases_DASH_funs1093154,("j-geq"));
var if_helper5763152 = R.makeFunction(function(if_helper_arg5773173) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[340],1,arguments);
}
var ann_DASH_check_DASH_temp5753174 = if_helper_arg5773173;
return ann_DASH_check_DASH_temp5753174;
});
var anf_if5803172 = R.isBoolean(if_DASH_1123168);
if(R.isPyretTrue(anf_if5803172)) {
if(R.isPyretTrue(if_DASH_1123168)) {
var call_DASH_j_DASH_geq1073150 = G(cases_DASH_funs1093154,"j-geq",L[340]);
var $z31423143 = D;
var $f31483149 = function(_) {
return R.isFunction(call_DASH_j_DASH_geq1073150)?call_DASH_j_DASH_geq1073150.app():R.ffi.throwNonFunApp(L[340],call_DASH_j_DASH_geq1073150,[]);
};
try {
if(--R.GAS > 0) {
$z31423143 = $f31483149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31483149,
"from":L[340]});
}
} catch($e31403141) {
if(R.isCont($e31403141)) {
var $ss31443145 = {"from":L[340],
"go":function(cont_tail_arg5833151) {
return $Hcont_tail_arg22163153(cont_tail_arg5833151,if_helper5763152);
}};
$e31403141.stack[R.EXN_STACKHEIGHT++] = $ss31443145;
}
if(R.isPyretException($e31403141)) {
$e31403141.pyretStack.push(L[340]);
}
throw $e31403141;
}
var $ret31463147 = $Hcont_tail_arg22163153($z31423143,if_helper5763152);
++R.GAS;
return $ret31463147;
} else {
var $z31573158 = D;
var $f31633164 = function(_) {
return R.isFunction(else_DASH_clause1103165)?else_DASH_clause1103165.app():R.ffi.throwNonFunApp(L[340],else_DASH_clause1103165,[]);
};
try {
if(--R.GAS > 0) {
$z31573158 = $f31633164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31633164,
"from":L[340]});
}
} catch($e31553156) {
if(R.isCont($e31553156)) {
var $ss31593160 = {"from":L[340],
"go":function(cont_tail_arg5813166) {
return $Hcont_tail_arg22173167(cont_tail_arg5813166,if_helper5763152);
}};
$e31553156.stack[R.EXN_STACKHEIGHT++] = $ss31593160;
}
if(R.isPyretException($e31553156)) {
$e31553156.pyretStack.push(L[340]);
}
throw $e31553156;
}
var $ret31613162 = $Hcont_tail_arg22173167($z31573158,if_helper5763152);
++R.GAS;
return $ret31613162;
}
} else {
var cont_tail_arg5783171 = R.throwNonBooleanCondition(L[340],("if"),if_DASH_1123168);
if(--R.GAS > 0) {
$z31693170 = R.isFunction(if_helper5763152)?if_helper5763152.app(cont_tail_arg5783171):R.ffi.throwNonFunApp(L[340],if_helper5763152,[cont_tail_arg5783171]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5763152)?if_helper5763152.app(cont_tail_arg5783171):R.ffi.throwNonFunApp(L[340],if_helper5763152,[cont_tail_arg5783171]);
},
"from":L[340]});
}
++R.GAS;
return $z31693170;
}
};
},{"length":3});
var anf_singleton_variant_member5872943 = R.makeMethod(function(self1113139) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[340],0,arguments);
}
var ann_DASH_check_DASH_temp5863138 = ("j-geq");
return ann_DASH_check_DASH_temp5863138;
};
},{"length":1});
var anf_singleton_variant_member5892944 = R.makeMethod(function(self2553137) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[355],0,arguments);
}
var ann_DASH_check_DASH_temp5883136 = (">=");
return ann_DASH_check_DASH_temp5883136;
};
},{"length":1});
var anf_singleton_variant_member6002950 = R.makeMethod(function(self1143135) {
return function(cases_DASH_funs1153114,else_DASH_clause1163125) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[339],2,arguments);
}
var if_DASH_1183128 = R.hasField(cases_DASH_funs1153114,("j-eq"));
var if_helper5913112 = R.makeFunction(function(if_helper_arg5923133) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[339],1,arguments);
}
var ann_DASH_check_DASH_temp5903134 = if_helper_arg5923133;
return ann_DASH_check_DASH_temp5903134;
});
var anf_if5953132 = R.isBoolean(if_DASH_1183128);
if(R.isPyretTrue(anf_if5953132)) {
if(R.isPyretTrue(if_DASH_1183128)) {
var call_DASH_j_DASH_eq1133110 = G(cases_DASH_funs1153114,"j-eq",L[339]);
var $z31023103 = D;
var $f31083109 = function(_) {
return R.isFunction(call_DASH_j_DASH_eq1133110)?call_DASH_j_DASH_eq1133110.app():R.ffi.throwNonFunApp(L[339],call_DASH_j_DASH_eq1133110,[]);
};
try {
if(--R.GAS > 0) {
$z31023103 = $f31083109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31083109,
"from":L[339]});
}
} catch($e31003101) {
if(R.isCont($e31003101)) {
var $ss31043105 = {"from":L[339],
"go":function(cont_tail_arg5983111) {
return $Hcont_tail_arg22183113(cont_tail_arg5983111,if_helper5913112);
}};
$e31003101.stack[R.EXN_STACKHEIGHT++] = $ss31043105;
}
if(R.isPyretException($e31003101)) {
$e31003101.pyretStack.push(L[339]);
}
throw $e31003101;
}
var $ret31063107 = $Hcont_tail_arg22183113($z31023103,if_helper5913112);
++R.GAS;
return $ret31063107;
} else {
var $z31173118 = D;
var $f31233124 = function(_) {
return R.isFunction(else_DASH_clause1163125)?else_DASH_clause1163125.app():R.ffi.throwNonFunApp(L[339],else_DASH_clause1163125,[]);
};
try {
if(--R.GAS > 0) {
$z31173118 = $f31233124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31233124,
"from":L[339]});
}
} catch($e31153116) {
if(R.isCont($e31153116)) {
var $ss31193120 = {"from":L[339],
"go":function(cont_tail_arg5963126) {
return $Hcont_tail_arg22193127(cont_tail_arg5963126,if_helper5913112);
}};
$e31153116.stack[R.EXN_STACKHEIGHT++] = $ss31193120;
}
if(R.isPyretException($e31153116)) {
$e31153116.pyretStack.push(L[339]);
}
throw $e31153116;
}
var $ret31213122 = $Hcont_tail_arg22193127($z31173118,if_helper5913112);
++R.GAS;
return $ret31213122;
}
} else {
var cont_tail_arg5933131 = R.throwNonBooleanCondition(L[339],("if"),if_DASH_1183128);
if(--R.GAS > 0) {
$z31293130 = R.isFunction(if_helper5913112)?if_helper5913112.app(cont_tail_arg5933131):R.ffi.throwNonFunApp(L[339],if_helper5913112,[cont_tail_arg5933131]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5913112)?if_helper5913112.app(cont_tail_arg5933131):R.ffi.throwNonFunApp(L[339],if_helper5913112,[cont_tail_arg5933131]);
},
"from":L[339]});
}
++R.GAS;
return $z31293130;
}
};
},{"length":3});
var anf_singleton_variant_member6022951 = R.makeMethod(function(self1173099) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[339],0,arguments);
}
var ann_DASH_check_DASH_temp6013098 = ("j-eq");
return ann_DASH_check_DASH_temp6013098;
};
},{"length":1});
var anf_singleton_variant_member6042952 = R.makeMethod(function(self2563097) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[354],0,arguments);
}
var ann_DASH_check_DASH_temp6033096 = ("===");
return ann_DASH_check_DASH_temp6033096;
};
},{"length":1});
var anf_singleton_variant_member6152958 = R.makeMethod(function(self1203095) {
return function(cases_DASH_funs1213074,else_DASH_clause1223085) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[338],2,arguments);
}
var if_DASH_1243088 = R.hasField(cases_DASH_funs1213074,("j-equals"));
var if_helper6063072 = R.makeFunction(function(if_helper_arg6073093) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[338],1,arguments);
}
var ann_DASH_check_DASH_temp6053094 = if_helper_arg6073093;
return ann_DASH_check_DASH_temp6053094;
});
var anf_if6103092 = R.isBoolean(if_DASH_1243088);
if(R.isPyretTrue(anf_if6103092)) {
if(R.isPyretTrue(if_DASH_1243088)) {
var call_DASH_j_DASH_equals1193070 = G(cases_DASH_funs1213074,"j-equals",L[338]);
var $z30623063 = D;
var $f30683069 = function(_) {
return R.isFunction(call_DASH_j_DASH_equals1193070)?call_DASH_j_DASH_equals1193070.app():R.ffi.throwNonFunApp(L[338],call_DASH_j_DASH_equals1193070,[]);
};
try {
if(--R.GAS > 0) {
$z30623063 = $f30683069();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30683069,
"from":L[338]});
}
} catch($e30603061) {
if(R.isCont($e30603061)) {
var $ss30643065 = {"from":L[338],
"go":function(cont_tail_arg6133071) {
return $Hcont_tail_arg22203073(cont_tail_arg6133071,if_helper6063072);
}};
$e30603061.stack[R.EXN_STACKHEIGHT++] = $ss30643065;
}
if(R.isPyretException($e30603061)) {
$e30603061.pyretStack.push(L[338]);
}
throw $e30603061;
}
var $ret30663067 = $Hcont_tail_arg22203073($z30623063,if_helper6063072);
++R.GAS;
return $ret30663067;
} else {
var $z30773078 = D;
var $f30833084 = function(_) {
return R.isFunction(else_DASH_clause1223085)?else_DASH_clause1223085.app():R.ffi.throwNonFunApp(L[338],else_DASH_clause1223085,[]);
};
try {
if(--R.GAS > 0) {
$z30773078 = $f30833084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30833084,
"from":L[338]});
}
} catch($e30753076) {
if(R.isCont($e30753076)) {
var $ss30793080 = {"from":L[338],
"go":function(cont_tail_arg6113086) {
return $Hcont_tail_arg22213087(cont_tail_arg6113086,if_helper6063072);
}};
$e30753076.stack[R.EXN_STACKHEIGHT++] = $ss30793080;
}
if(R.isPyretException($e30753076)) {
$e30753076.pyretStack.push(L[338]);
}
throw $e30753076;
}
var $ret30813082 = $Hcont_tail_arg22213087($z30773078,if_helper6063072);
++R.GAS;
return $ret30813082;
}
} else {
var cont_tail_arg6083091 = R.throwNonBooleanCondition(L[338],("if"),if_DASH_1243088);
if(--R.GAS > 0) {
$z30893090 = R.isFunction(if_helper6063072)?if_helper6063072.app(cont_tail_arg6083091):R.ffi.throwNonFunApp(L[338],if_helper6063072,[cont_tail_arg6083091]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6063072)?if_helper6063072.app(cont_tail_arg6083091):R.ffi.throwNonFunApp(L[338],if_helper6063072,[cont_tail_arg6083091]);
},
"from":L[338]});
}
++R.GAS;
return $z30893090;
}
};
},{"length":3});
var anf_singleton_variant_member6172959 = R.makeMethod(function(self1233059) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[338],0,arguments);
}
var ann_DASH_check_DASH_temp6163058 = ("j-equals");
return ann_DASH_check_DASH_temp6163058;
};
},{"length":1});
var anf_singleton_variant_member6192960 = R.makeMethod(function(self2571332) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[353],0,arguments);
}
var ann_DASH_check_DASH_temp6183057 = ("==");
return ann_DASH_check_DASH_temp6183057;
};
},{"length":1});
var anf_singleton_variant_member6302966 = R.makeMethod(function(self1263056) {
return function(cases_DASH_funs1273035,else_DASH_clause1283046) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[337],2,arguments);
}
var if_DASH_1303049 = R.hasField(cases_DASH_funs1273035,("j-neq"));
var if_helper6213033 = R.makeFunction(function(if_helper_arg6223054) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[337],1,arguments);
}
var ann_DASH_check_DASH_temp6203055 = if_helper_arg6223054;
return ann_DASH_check_DASH_temp6203055;
});
var anf_if6253053 = R.isBoolean(if_DASH_1303049);
if(R.isPyretTrue(anf_if6253053)) {
if(R.isPyretTrue(if_DASH_1303049)) {
var call_DASH_j_DASH_neq1253031 = G(cases_DASH_funs1273035,"j-neq",L[337]);
var $z30233024 = D;
var $f30293030 = function(_) {
return R.isFunction(call_DASH_j_DASH_neq1253031)?call_DASH_j_DASH_neq1253031.app():R.ffi.throwNonFunApp(L[337],call_DASH_j_DASH_neq1253031,[]);
};
try {
if(--R.GAS > 0) {
$z30233024 = $f30293030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30293030,
"from":L[337]});
}
} catch($e30213022) {
if(R.isCont($e30213022)) {
var $ss30253026 = {"from":L[337],
"go":function(cont_tail_arg6283032) {
return $Hcont_tail_arg22223034(cont_tail_arg6283032,if_helper6213033);
}};
$e30213022.stack[R.EXN_STACKHEIGHT++] = $ss30253026;
}
if(R.isPyretException($e30213022)) {
$e30213022.pyretStack.push(L[337]);
}
throw $e30213022;
}
var $ret30273028 = $Hcont_tail_arg22223034($z30233024,if_helper6213033);
++R.GAS;
return $ret30273028;
} else {
var $z30383039 = D;
var $f30443045 = function(_) {
return R.isFunction(else_DASH_clause1283046)?else_DASH_clause1283046.app():R.ffi.throwNonFunApp(L[337],else_DASH_clause1283046,[]);
};
try {
if(--R.GAS > 0) {
$z30383039 = $f30443045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30443045,
"from":L[337]});
}
} catch($e30363037) {
if(R.isCont($e30363037)) {
var $ss30403041 = {"from":L[337],
"go":function(cont_tail_arg6263047) {
return $Hcont_tail_arg22233048(cont_tail_arg6263047,if_helper6213033);
}};
$e30363037.stack[R.EXN_STACKHEIGHT++] = $ss30403041;
}
if(R.isPyretException($e30363037)) {
$e30363037.pyretStack.push(L[337]);
}
throw $e30363037;
}
var $ret30423043 = $Hcont_tail_arg22233048($z30383039,if_helper6213033);
++R.GAS;
return $ret30423043;
}
} else {
var cont_tail_arg6233052 = R.throwNonBooleanCondition(L[337],("if"),if_DASH_1303049);
if(--R.GAS > 0) {
$z30503051 = R.isFunction(if_helper6213033)?if_helper6213033.app(cont_tail_arg6233052):R.ffi.throwNonFunApp(L[337],if_helper6213033,[cont_tail_arg6233052]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6213033)?if_helper6213033.app(cont_tail_arg6233052):R.ffi.throwNonFunApp(L[337],if_helper6213033,[cont_tail_arg6233052]);
},
"from":L[337]});
}
++R.GAS;
return $z30503051;
}
};
},{"length":3});
var anf_singleton_variant_member6322967 = R.makeMethod(function(self1293020) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[337],0,arguments);
}
var ann_DASH_check_DASH_temp6313019 = ("j-neq");
return ann_DASH_check_DASH_temp6313019;
};
},{"length":1});
var anf_singleton_variant_member6342968 = R.makeMethod(function(self2583018) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[352],0,arguments);
}
var ann_DASH_check_DASH_temp6333017 = ("!==");
return ann_DASH_check_DASH_temp6333017;
};
},{"length":1});
var anf_singleton_variant_member6452974 = R.makeMethod(function(self1323016) {
return function(cases_DASH_funs1332995,else_DASH_clause1343006) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[336],2,arguments);
}
var if_DASH_1363009 = R.hasField(cases_DASH_funs1332995,("j-nequals"));
var if_helper6362993 = R.makeFunction(function(if_helper_arg6373014) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[336],1,arguments);
}
var ann_DASH_check_DASH_temp6353015 = if_helper_arg6373014;
return ann_DASH_check_DASH_temp6353015;
});
var anf_if6403013 = R.isBoolean(if_DASH_1363009);
if(R.isPyretTrue(anf_if6403013)) {
if(R.isPyretTrue(if_DASH_1363009)) {
var call_DASH_j_DASH_nequals1312991 = G(cases_DASH_funs1332995,"j-nequals",L[336]);
var $z29832984 = D;
var $f29892990 = function(_) {
return R.isFunction(call_DASH_j_DASH_nequals1312991)?call_DASH_j_DASH_nequals1312991.app():R.ffi.throwNonFunApp(L[336],call_DASH_j_DASH_nequals1312991,[]);
};
try {
if(--R.GAS > 0) {
$z29832984 = $f29892990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29892990,
"from":L[336]});
}
} catch($e29812982) {
if(R.isCont($e29812982)) {
var $ss29852986 = {"from":L[336],
"go":function(cont_tail_arg6432992) {
return $Hcont_tail_arg22242994(cont_tail_arg6432992,if_helper6362993);
}};
$e29812982.stack[R.EXN_STACKHEIGHT++] = $ss29852986;
}
if(R.isPyretException($e29812982)) {
$e29812982.pyretStack.push(L[336]);
}
throw $e29812982;
}
var $ret29872988 = $Hcont_tail_arg22242994($z29832984,if_helper6362993);
++R.GAS;
return $ret29872988;
} else {
var $z29982999 = D;
var $f30043005 = function(_) {
return R.isFunction(else_DASH_clause1343006)?else_DASH_clause1343006.app():R.ffi.throwNonFunApp(L[336],else_DASH_clause1343006,[]);
};
try {
if(--R.GAS > 0) {
$z29982999 = $f30043005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30043005,
"from":L[336]});
}
} catch($e29962997) {
if(R.isCont($e29962997)) {
var $ss30003001 = {"from":L[336],
"go":function(cont_tail_arg6413007) {
return $Hcont_tail_arg22253008(cont_tail_arg6413007,if_helper6362993);
}};
$e29962997.stack[R.EXN_STACKHEIGHT++] = $ss30003001;
}
if(R.isPyretException($e29962997)) {
$e29962997.pyretStack.push(L[336]);
}
throw $e29962997;
}
var $ret30023003 = $Hcont_tail_arg22253008($z29982999,if_helper6362993);
++R.GAS;
return $ret30023003;
}
} else {
var cont_tail_arg6383012 = R.throwNonBooleanCondition(L[336],("if"),if_DASH_1363009);
if(--R.GAS > 0) {
$z30103011 = R.isFunction(if_helper6362993)?if_helper6362993.app(cont_tail_arg6383012):R.ffi.throwNonFunApp(L[336],if_helper6362993,[cont_tail_arg6383012]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6362993)?if_helper6362993.app(cont_tail_arg6383012):R.ffi.throwNonFunApp(L[336],if_helper6362993,[cont_tail_arg6383012]);
},
"from":L[336]});
}
++R.GAS;
return $z30103011;
}
};
},{"length":3});
var anf_singleton_variant_member6472975 = R.makeMethod(function(self1352980) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[336],0,arguments);
}
var ann_DASH_check_DASH_temp6462979 = ("j-nequals");
return ann_DASH_check_DASH_temp6462979;
};
},{"length":1});
var anf_singleton_variant_member6492976 = R.makeMethod(function(self2592978) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[351],0,arguments);
}
var ann_DASH_check_DASH_temp6482977 = ("!=");
return ann_DASH_check_DASH_temp6482977;
};
},{"length":1});
var anf_assign650125 = (function() {
var $j_DASH_plus_DASH_base28652866 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member4502870,
"_torepr":anf_singleton_variant_member4522871,
"to-ugly-source":anf_singleton_variant_member4542872};
var $j_DASH_plus_DASH_brands28682869 = {"$brand-j-plus2867":true};
$j_DASH_plus_DASH_brands28682869[JBinopT46949._brand] = true
var $j_DASH_minus_DASH_base28732874 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member4652878,
"_torepr":anf_singleton_variant_member4672879,
"to-ugly-source":anf_singleton_variant_member4692880};
var $j_DASH_minus_DASH_brands28762877 = {"$brand-j-minus2875":true};
$j_DASH_minus_DASH_brands28762877[JBinopT46949._brand] = true
var $j_DASH_times_DASH_base28812882 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member4802886,
"_torepr":anf_singleton_variant_member4822887,
"to-ugly-source":anf_singleton_variant_member4842888};
var $j_DASH_times_DASH_brands28842885 = {"$brand-j-times2883":true};
$j_DASH_times_DASH_brands28842885[JBinopT46949._brand] = true
var $j_DASH_divide_DASH_base28892890 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member4952894,
"_torepr":anf_singleton_variant_member4972895,
"to-ugly-source":anf_singleton_variant_member4992896};
var $j_DASH_divide_DASH_brands28922893 = {"$brand-j-divide2891":true};
$j_DASH_divide_DASH_brands28922893[JBinopT46949._brand] = true
var $j_DASH_and_DASH_base28972898 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member5102902,
"_torepr":anf_singleton_variant_member5122903,
"to-ugly-source":anf_singleton_variant_member5142904};
var $j_DASH_and_DASH_brands29002901 = {"$brand-j-and2899":true};
$j_DASH_and_DASH_brands29002901[JBinopT46949._brand] = true
var $j_DASH_or_DASH_base29052906 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member5252910,
"_torepr":anf_singleton_variant_member5272911,
"to-ugly-source":anf_singleton_variant_member5292912};
var $j_DASH_or_DASH_brands29082909 = {"$brand-j-or2907":true};
$j_DASH_or_DASH_brands29082909[JBinopT46949._brand] = true
var $j_DASH_lt_DASH_base29132914 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member5402918,
"_torepr":anf_singleton_variant_member5422919,
"to-ugly-source":anf_singleton_variant_member5442920};
var $j_DASH_lt_DASH_brands29162917 = {"$brand-j-lt2915":true};
$j_DASH_lt_DASH_brands29162917[JBinopT46949._brand] = true
var $j_DASH_leq_DASH_base29212922 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member5552926,
"_torepr":anf_singleton_variant_member5572927,
"to-ugly-source":anf_singleton_variant_member5592928};
var $j_DASH_leq_DASH_brands29242925 = {"$brand-j-leq2923":true};
$j_DASH_leq_DASH_brands29242925[JBinopT46949._brand] = true
var $j_DASH_gt_DASH_base29292930 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member5702934,
"_torepr":anf_singleton_variant_member5722935,
"to-ugly-source":anf_singleton_variant_member5742936};
var $j_DASH_gt_DASH_brands29322933 = {"$brand-j-gt2931":true};
$j_DASH_gt_DASH_brands29322933[JBinopT46949._brand] = true
var $j_DASH_geq_DASH_base29372938 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member5852942,
"_torepr":anf_singleton_variant_member5872943,
"to-ugly-source":anf_singleton_variant_member5892944};
var $j_DASH_geq_DASH_brands29402941 = {"$brand-j-geq2939":true};
$j_DASH_geq_DASH_brands29402941[JBinopT46949._brand] = true
var $j_DASH_eq_DASH_base29452946 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member6002950,
"_torepr":anf_singleton_variant_member6022951,
"to-ugly-source":anf_singleton_variant_member6042952};
var $j_DASH_eq_DASH_brands29482949 = {"$brand-j-eq2947":true};
$j_DASH_eq_DASH_brands29482949[JBinopT46949._brand] = true
var $j_DASH_equals_DASH_base29532954 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member6152958,
"_torepr":anf_singleton_variant_member6172959,
"to-ugly-source":anf_singleton_variant_member6192960};
var $j_DASH_equals_DASH_brands29562957 = {"$brand-j-equals2955":true};
$j_DASH_equals_DASH_brands29562957[JBinopT46949._brand] = true
var $j_DASH_neq_DASH_base29612962 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member6302966,
"_torepr":anf_singleton_variant_member6322967,
"to-ugly-source":anf_singleton_variant_member6342968};
var $j_DASH_neq_DASH_brands29642965 = {"$brand-j-neq2963":true};
$j_DASH_neq_DASH_brands29642965[JBinopT46949._brand] = true
var $j_DASH_nequals_DASH_base29692970 = {"print-ugly-source":anf_shared4342863,
"tosource":anf_shared4392864,
"_match":anf_singleton_variant_member6452974,
"_torepr":anf_singleton_variant_member6472975,
"to-ugly-source":anf_singleton_variant_member6492976};
var $j_DASH_nequals_DASH_brands29722973 = {"$brand-j-nequals2971":true};
$j_DASH_nequals_DASH_brands29722973[JBinopT46949._brand] = true
return R.makeObject({"JBinop":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[350],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,JBinopT46949._brand));
}),
"is-j-plus":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[349],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-plus2867"));
}),
"j-plus":R.makeBrandedObject($j_DASH_plus_DASH_base28652866,$j_DASH_plus_DASH_brands28682869),
"is-j-minus":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[348],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-minus2875"));
}),
"j-minus":R.makeBrandedObject($j_DASH_minus_DASH_base28732874,$j_DASH_minus_DASH_brands28762877),
"is-j-times":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[347],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-times2883"));
}),
"j-times":R.makeBrandedObject($j_DASH_times_DASH_base28812882,$j_DASH_times_DASH_brands28842885),
"is-j-divide":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[346],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-divide2891"));
}),
"j-divide":R.makeBrandedObject($j_DASH_divide_DASH_base28892890,$j_DASH_divide_DASH_brands28922893),
"is-j-and":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[345],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-and2899"));
}),
"j-and":R.makeBrandedObject($j_DASH_and_DASH_base28972898,$j_DASH_and_DASH_brands29002901),
"is-j-or":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[344],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-or2907"));
}),
"j-or":R.makeBrandedObject($j_DASH_or_DASH_base29052906,$j_DASH_or_DASH_brands29082909),
"is-j-lt":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[343],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-lt2915"));
}),
"j-lt":R.makeBrandedObject($j_DASH_lt_DASH_base29132914,$j_DASH_lt_DASH_brands29162917),
"is-j-leq":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[342],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-leq2923"));
}),
"j-leq":R.makeBrandedObject($j_DASH_leq_DASH_base29212922,$j_DASH_leq_DASH_brands29242925),
"is-j-gt":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[341],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-gt2931"));
}),
"j-gt":R.makeBrandedObject($j_DASH_gt_DASH_base29292930,$j_DASH_gt_DASH_brands29322933),
"is-j-geq":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[340],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-geq2939"));
}),
"j-geq":R.makeBrandedObject($j_DASH_geq_DASH_base29372938,$j_DASH_geq_DASH_brands29402941),
"is-j-eq":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[339],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-eq2947"));
}),
"j-eq":R.makeBrandedObject($j_DASH_eq_DASH_base29452946,$j_DASH_eq_DASH_brands29482949),
"is-j-equals":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[338],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-equals2955"));
}),
"j-equals":R.makeBrandedObject($j_DASH_equals_DASH_base29532954,$j_DASH_equals_DASH_brands29562957),
"is-j-neq":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[337],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-neq2963"));
}),
"j-neq":R.makeBrandedObject($j_DASH_neq_DASH_base29612962,$j_DASH_neq_DASH_brands29642965),
"is-j-nequals":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[336],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-nequals2971"));
}),
"j-nequals":R.makeBrandedObject($j_DASH_nequals_DASH_base29692970,$j_DASH_nequals_DASH_brands29722973)});
})();
JBinop10103124.$var = anf_assign650125;
var anf_assign651127 = G(JBinop10103124.$var,"JBinop",L[350]);
JBinop104126.$var = anf_assign651127;
var anf_assign652129 = G(JBinop10103124.$var,"JBinop",L[350]);
is_DASH_JBinop105128.$var = anf_assign652129;
var anf_assign653131 = G(JBinop10103124.$var,"is-j-plus",L[349]);
is_DASH_j_DASH_plus106130.$var = anf_assign653131;
var anf_assign654133 = G(JBinop10103124.$var,"j-plus",L[349]);
j_DASH_plus107132.$var = anf_assign654133;
var anf_assign655135 = G(JBinop10103124.$var,"is-j-minus",L[348]);
is_DASH_j_DASH_minus108134.$var = anf_assign655135;
var anf_assign656137 = G(JBinop10103124.$var,"j-minus",L[348]);
j_DASH_minus109136.$var = anf_assign656137;
var anf_assign657139 = G(JBinop10103124.$var,"is-j-times",L[347]);
is_DASH_j_DASH_times110138.$var = anf_assign657139;
var anf_assign658141 = G(JBinop10103124.$var,"j-times",L[347]);
j_DASH_times111140.$var = anf_assign658141;
var anf_assign659143 = G(JBinop10103124.$var,"is-j-divide",L[346]);
is_DASH_j_DASH_divide112142.$var = anf_assign659143;
var anf_assign660145 = G(JBinop10103124.$var,"j-divide",L[346]);
j_DASH_divide113144.$var = anf_assign660145;
var anf_assign661147 = G(JBinop10103124.$var,"is-j-and",L[345]);
is_DASH_j_DASH_and114146.$var = anf_assign661147;
var anf_assign662149 = G(JBinop10103124.$var,"j-and",L[345]);
j_DASH_and115148.$var = anf_assign662149;
var anf_assign663151 = G(JBinop10103124.$var,"is-j-or",L[344]);
is_DASH_j_DASH_or116150.$var = anf_assign663151;
var anf_assign664153 = G(JBinop10103124.$var,"j-or",L[344]);
j_DASH_or117152.$var = anf_assign664153;
var anf_assign665155 = G(JBinop10103124.$var,"is-j-lt",L[343]);
is_DASH_j_DASH_lt118154.$var = anf_assign665155;
var anf_assign666157 = G(JBinop10103124.$var,"j-lt",L[343]);
j_DASH_lt119156.$var = anf_assign666157;
var anf_assign667159 = G(JBinop10103124.$var,"is-j-leq",L[342]);
is_DASH_j_DASH_leq120158.$var = anf_assign667159;
var anf_assign668161 = G(JBinop10103124.$var,"j-leq",L[342]);
j_DASH_leq121160.$var = anf_assign668161;
var anf_assign669163 = G(JBinop10103124.$var,"is-j-gt",L[341]);
is_DASH_j_DASH_gt122162.$var = anf_assign669163;
var anf_assign670165 = G(JBinop10103124.$var,"j-gt",L[341]);
j_DASH_gt123164.$var = anf_assign670165;
var anf_assign671167 = G(JBinop10103124.$var,"is-j-geq",L[340]);
is_DASH_j_DASH_geq124166.$var = anf_assign671167;
var anf_assign672169 = G(JBinop10103124.$var,"j-geq",L[340]);
j_DASH_geq125168.$var = anf_assign672169;
var anf_assign673171 = G(JBinop10103124.$var,"is-j-eq",L[339]);
is_DASH_j_DASH_eq126170.$var = anf_assign673171;
var anf_assign674173 = G(JBinop10103124.$var,"j-eq",L[339]);
j_DASH_eq127172.$var = anf_assign674173;
var anf_assign675175 = G(JBinop10103124.$var,"is-j-equals",L[338]);
is_DASH_j_DASH_equals128174.$var = anf_assign675175;
var anf_assign676177 = G(JBinop10103124.$var,"j-equals",L[338]);
j_DASH_equals129176.$var = anf_assign676177;
var anf_assign677179 = G(JBinop10103124.$var,"is-j-neq",L[337]);
is_DASH_j_DASH_neq130178.$var = anf_assign677179;
var anf_assign678181 = G(JBinop10103124.$var,"j-neq",L[337]);
j_DASH_neq131180.$var = anf_assign678181;
var anf_assign679183 = G(JBinop10103124.$var,"is-j-nequals",L[336]);
is_DASH_j_DASH_nequals132182.$var = anf_assign679183;
var anf_assign680185 = G(JBinop10103124.$var,"j-nequals",L[336]);
j_DASH_nequals133184.$var = anf_assign680185;
var anf_shared6842642 = R.makeMethod(function(self2672862) {
return function(printer2682860) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[335],1,arguments);
}
var anf_fun6822858 = G(self2672862,"to-ugly-source",L[334]);
var $z28502851 = D;
var $f28562857 = function(_) {
return R.isFunction(anf_fun6822858)?anf_fun6822858.app():R.ffi.throwNonFunApp(L[333],anf_fun6822858,[]);
};
try {
if(--R.GAS > 0) {
$z28502851 = $f28562857();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28562857,
"from":L[333]});
}
} catch($e28482849) {
if(R.isCont($e28482849)) {
var $ss28522853 = {"from":L[333],
"go":function(anf_arg6832859) {
return $Hanf_arg22272861(anf_arg6832859,printer2682860);
}};
$e28482849.stack[R.EXN_STACKHEIGHT++] = $ss28522853;
}
if(R.isPyretException($e28482849)) {
$e28482849.pyretStack.push(L[333]);
}
throw $e28482849;
}
var $ret28542855 = $Hanf_arg22272861($z28502851,printer2682860);
++R.GAS;
return $ret28542855;
};
},{"length":2});
var anf_shared6892643 = R.makeMethod(function(self2691170) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[332],0,arguments);
}
var anf_fun6862846 = G(PP123,"str",L[331]);
var anf_fun6872844 = G(self2691170,"to-ugly-source",L[330]);
var $z28362837 = D;
var $f28422843 = function(_) {
return R.isFunction(anf_fun6872844)?anf_fun6872844.app():R.ffi.throwNonFunApp(L[329],anf_fun6872844,[]);
};
try {
if(--R.GAS > 0) {
$z28362837 = $f28422843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28422843,
"from":L[329]});
}
} catch($e28342835) {
if(R.isCont($e28342835)) {
var $ss28382839 = {"from":L[329],
"go":function(anf_arg6882845) {
return $Hanf_arg22292847(anf_arg6882845,anf_fun6862846);
}};
$e28342835.stack[R.EXN_STACKHEIGHT++] = $ss28382839;
}
if(R.isPyretException($e28342835)) {
$e28342835.pyretStack.push(L[329]);
}
throw $e28342835;
}
var $ret28402841 = $Hanf_arg22292847($z28362837,anf_fun6862846);
++R.GAS;
return $ret28402841;
};
},{"length":1});
var anf_singleton_variant_member7002649 = R.makeMethod(function(self1382833) {
return function(cases_DASH_funs1392812,else_DASH_clause1402823) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[323],2,arguments);
}
var if_DASH_1422826 = R.hasField(cases_DASH_funs1392812,("j-incr"));
var if_helper6912810 = R.makeFunction(function(if_helper_arg6922831) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[323],1,arguments);
}
var ann_DASH_check_DASH_temp6902832 = if_helper_arg6922831;
return ann_DASH_check_DASH_temp6902832;
});
var anf_if6952830 = R.isBoolean(if_DASH_1422826);
if(R.isPyretTrue(anf_if6952830)) {
if(R.isPyretTrue(if_DASH_1422826)) {
var call_DASH_j_DASH_incr1372808 = G(cases_DASH_funs1392812,"j-incr",L[323]);
var $z28002801 = D;
var $f28062807 = function(_) {
return R.isFunction(call_DASH_j_DASH_incr1372808)?call_DASH_j_DASH_incr1372808.app():R.ffi.throwNonFunApp(L[323],call_DASH_j_DASH_incr1372808,[]);
};
try {
if(--R.GAS > 0) {
$z28002801 = $f28062807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28062807,
"from":L[323]});
}
} catch($e27982799) {
if(R.isCont($e27982799)) {
var $ss28022803 = {"from":L[323],
"go":function(cont_tail_arg6982809) {
return $Hcont_tail_arg22302811(cont_tail_arg6982809,if_helper6912810);
}};
$e27982799.stack[R.EXN_STACKHEIGHT++] = $ss28022803;
}
if(R.isPyretException($e27982799)) {
$e27982799.pyretStack.push(L[323]);
}
throw $e27982799;
}
var $ret28042805 = $Hcont_tail_arg22302811($z28002801,if_helper6912810);
++R.GAS;
return $ret28042805;
} else {
var $z28152816 = D;
var $f28212822 = function(_) {
return R.isFunction(else_DASH_clause1402823)?else_DASH_clause1402823.app():R.ffi.throwNonFunApp(L[323],else_DASH_clause1402823,[]);
};
try {
if(--R.GAS > 0) {
$z28152816 = $f28212822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28212822,
"from":L[323]});
}
} catch($e28132814) {
if(R.isCont($e28132814)) {
var $ss28172818 = {"from":L[323],
"go":function(cont_tail_arg6962824) {
return $Hcont_tail_arg22312825(cont_tail_arg6962824,if_helper6912810);
}};
$e28132814.stack[R.EXN_STACKHEIGHT++] = $ss28172818;
}
if(R.isPyretException($e28132814)) {
$e28132814.pyretStack.push(L[323]);
}
throw $e28132814;
}
var $ret28192820 = $Hcont_tail_arg22312825($z28152816,if_helper6912810);
++R.GAS;
return $ret28192820;
}
} else {
var cont_tail_arg6932829 = R.throwNonBooleanCondition(L[323],("if"),if_DASH_1422826);
if(--R.GAS > 0) {
$z28272828 = R.isFunction(if_helper6912810)?if_helper6912810.app(cont_tail_arg6932829):R.ffi.throwNonFunApp(L[323],if_helper6912810,[cont_tail_arg6932829]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6912810)?if_helper6912810.app(cont_tail_arg6932829):R.ffi.throwNonFunApp(L[323],if_helper6912810,[cont_tail_arg6932829]);
},
"from":L[323]});
}
++R.GAS;
return $z28272828;
}
};
},{"length":3});
var anf_singleton_variant_member7022650 = R.makeMethod(function(self1412797) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[323],0,arguments);
}
var ann_DASH_check_DASH_temp7012796 = ("j-incr");
return ann_DASH_check_DASH_temp7012796;
};
},{"length":1});
var anf_singleton_variant_member7042651 = R.makeMethod(function(self2631251) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[328],0,arguments);
}
var ann_DASH_check_DASH_temp7032795 = ("++");
return ann_DASH_check_DASH_temp7032795;
};
},{"length":1});
var anf_singleton_variant_member7152657 = R.makeMethod(function(self1442794) {
return function(cases_DASH_funs1452773,else_DASH_clause1462784) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[322],2,arguments);
}
var if_DASH_1482787 = R.hasField(cases_DASH_funs1452773,("j-decr"));
var if_helper7062771 = R.makeFunction(function(if_helper_arg7072792) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[322],1,arguments);
}
var ann_DASH_check_DASH_temp7052793 = if_helper_arg7072792;
return ann_DASH_check_DASH_temp7052793;
});
var anf_if7102791 = R.isBoolean(if_DASH_1482787);
if(R.isPyretTrue(anf_if7102791)) {
if(R.isPyretTrue(if_DASH_1482787)) {
var call_DASH_j_DASH_decr1432769 = G(cases_DASH_funs1452773,"j-decr",L[322]);
var $z27612762 = D;
var $f27672768 = function(_) {
return R.isFunction(call_DASH_j_DASH_decr1432769)?call_DASH_j_DASH_decr1432769.app():R.ffi.throwNonFunApp(L[322],call_DASH_j_DASH_decr1432769,[]);
};
try {
if(--R.GAS > 0) {
$z27612762 = $f27672768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27672768,
"from":L[322]});
}
} catch($e27592760) {
if(R.isCont($e27592760)) {
var $ss27632764 = {"from":L[322],
"go":function(cont_tail_arg7132770) {
return $Hcont_tail_arg22322772(cont_tail_arg7132770,if_helper7062771);
}};
$e27592760.stack[R.EXN_STACKHEIGHT++] = $ss27632764;
}
if(R.isPyretException($e27592760)) {
$e27592760.pyretStack.push(L[322]);
}
throw $e27592760;
}
var $ret27652766 = $Hcont_tail_arg22322772($z27612762,if_helper7062771);
++R.GAS;
return $ret27652766;
} else {
var $z27762777 = D;
var $f27822783 = function(_) {
return R.isFunction(else_DASH_clause1462784)?else_DASH_clause1462784.app():R.ffi.throwNonFunApp(L[322],else_DASH_clause1462784,[]);
};
try {
if(--R.GAS > 0) {
$z27762777 = $f27822783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27822783,
"from":L[322]});
}
} catch($e27742775) {
if(R.isCont($e27742775)) {
var $ss27782779 = {"from":L[322],
"go":function(cont_tail_arg7112785) {
return $Hcont_tail_arg22332786(cont_tail_arg7112785,if_helper7062771);
}};
$e27742775.stack[R.EXN_STACKHEIGHT++] = $ss27782779;
}
if(R.isPyretException($e27742775)) {
$e27742775.pyretStack.push(L[322]);
}
throw $e27742775;
}
var $ret27802781 = $Hcont_tail_arg22332786($z27762777,if_helper7062771);
++R.GAS;
return $ret27802781;
}
} else {
var cont_tail_arg7082790 = R.throwNonBooleanCondition(L[322],("if"),if_DASH_1482787);
if(--R.GAS > 0) {
$z27882789 = R.isFunction(if_helper7062771)?if_helper7062771.app(cont_tail_arg7082790):R.ffi.throwNonFunApp(L[322],if_helper7062771,[cont_tail_arg7082790]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7062771)?if_helper7062771.app(cont_tail_arg7082790):R.ffi.throwNonFunApp(L[322],if_helper7062771,[cont_tail_arg7082790]);
},
"from":L[322]});
}
++R.GAS;
return $z27882789;
}
};
},{"length":3});
var anf_singleton_variant_member7172658 = R.makeMethod(function(self1472758) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[322],0,arguments);
}
var ann_DASH_check_DASH_temp7162757 = ("j-decr");
return ann_DASH_check_DASH_temp7162757;
};
},{"length":1});
var anf_singleton_variant_member7192659 = R.makeMethod(function(self2642756) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[327],0,arguments);
}
var ann_DASH_check_DASH_temp7182755 = ("--");
return ann_DASH_check_DASH_temp7182755;
};
},{"length":1});
var anf_singleton_variant_member7302665 = R.makeMethod(function(self1502754) {
return function(cases_DASH_funs1512733,else_DASH_clause1522744) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[321],2,arguments);
}
var if_DASH_1542747 = R.hasField(cases_DASH_funs1512733,("j-postincr"));
var if_helper7212731 = R.makeFunction(function(if_helper_arg7222752) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[321],1,arguments);
}
var ann_DASH_check_DASH_temp7202753 = if_helper_arg7222752;
return ann_DASH_check_DASH_temp7202753;
});
var anf_if7252751 = R.isBoolean(if_DASH_1542747);
if(R.isPyretTrue(anf_if7252751)) {
if(R.isPyretTrue(if_DASH_1542747)) {
var call_DASH_j_DASH_postincr1492729 = G(cases_DASH_funs1512733,"j-postincr",L[321]);
var $z27212722 = D;
var $f27272728 = function(_) {
return R.isFunction(call_DASH_j_DASH_postincr1492729)?call_DASH_j_DASH_postincr1492729.app():R.ffi.throwNonFunApp(L[321],call_DASH_j_DASH_postincr1492729,[]);
};
try {
if(--R.GAS > 0) {
$z27212722 = $f27272728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27272728,
"from":L[321]});
}
} catch($e27192720) {
if(R.isCont($e27192720)) {
var $ss27232724 = {"from":L[321],
"go":function(cont_tail_arg7282730) {
return $Hcont_tail_arg22342732(cont_tail_arg7282730,if_helper7212731);
}};
$e27192720.stack[R.EXN_STACKHEIGHT++] = $ss27232724;
}
if(R.isPyretException($e27192720)) {
$e27192720.pyretStack.push(L[321]);
}
throw $e27192720;
}
var $ret27252726 = $Hcont_tail_arg22342732($z27212722,if_helper7212731);
++R.GAS;
return $ret27252726;
} else {
var $z27362737 = D;
var $f27422743 = function(_) {
return R.isFunction(else_DASH_clause1522744)?else_DASH_clause1522744.app():R.ffi.throwNonFunApp(L[321],else_DASH_clause1522744,[]);
};
try {
if(--R.GAS > 0) {
$z27362737 = $f27422743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27422743,
"from":L[321]});
}
} catch($e27342735) {
if(R.isCont($e27342735)) {
var $ss27382739 = {"from":L[321],
"go":function(cont_tail_arg7262745) {
return $Hcont_tail_arg22352746(cont_tail_arg7262745,if_helper7212731);
}};
$e27342735.stack[R.EXN_STACKHEIGHT++] = $ss27382739;
}
if(R.isPyretException($e27342735)) {
$e27342735.pyretStack.push(L[321]);
}
throw $e27342735;
}
var $ret27402741 = $Hcont_tail_arg22352746($z27362737,if_helper7212731);
++R.GAS;
return $ret27402741;
}
} else {
var cont_tail_arg7232750 = R.throwNonBooleanCondition(L[321],("if"),if_DASH_1542747);
if(--R.GAS > 0) {
$z27482749 = R.isFunction(if_helper7212731)?if_helper7212731.app(cont_tail_arg7232750):R.ffi.throwNonFunApp(L[321],if_helper7212731,[cont_tail_arg7232750]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7212731)?if_helper7212731.app(cont_tail_arg7232750):R.ffi.throwNonFunApp(L[321],if_helper7212731,[cont_tail_arg7232750]);
},
"from":L[321]});
}
++R.GAS;
return $z27482749;
}
};
},{"length":3});
var anf_singleton_variant_member7322666 = R.makeMethod(function(self1532718) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[321],0,arguments);
}
var ann_DASH_check_DASH_temp7312717 = ("j-postincr");
return ann_DASH_check_DASH_temp7312717;
};
},{"length":1});
var anf_singleton_variant_member7342667 = R.makeMethod(function(self2652716) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[326],0,arguments);
}
var ann_DASH_check_DASH_temp7332715 = ("++");
return ann_DASH_check_DASH_temp7332715;
};
},{"length":1});
var anf_singleton_variant_member7452673 = R.makeMethod(function(self1562714) {
return function(cases_DASH_funs1572693,else_DASH_clause1582704) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[320],2,arguments);
}
var if_DASH_1602707 = R.hasField(cases_DASH_funs1572693,("j-postdecr"));
var if_helper7362691 = R.makeFunction(function(if_helper_arg7372712) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[320],1,arguments);
}
var ann_DASH_check_DASH_temp7352713 = if_helper_arg7372712;
return ann_DASH_check_DASH_temp7352713;
});
var anf_if7402711 = R.isBoolean(if_DASH_1602707);
if(R.isPyretTrue(anf_if7402711)) {
if(R.isPyretTrue(if_DASH_1602707)) {
var call_DASH_j_DASH_postdecr1552689 = G(cases_DASH_funs1572693,"j-postdecr",L[320]);
var $z26812682 = D;
var $f26872688 = function(_) {
return R.isFunction(call_DASH_j_DASH_postdecr1552689)?call_DASH_j_DASH_postdecr1552689.app():R.ffi.throwNonFunApp(L[320],call_DASH_j_DASH_postdecr1552689,[]);
};
try {
if(--R.GAS > 0) {
$z26812682 = $f26872688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26872688,
"from":L[320]});
}
} catch($e26792680) {
if(R.isCont($e26792680)) {
var $ss26832684 = {"from":L[320],
"go":function(cont_tail_arg7432690) {
return $Hcont_tail_arg22362692(cont_tail_arg7432690,if_helper7362691);
}};
$e26792680.stack[R.EXN_STACKHEIGHT++] = $ss26832684;
}
if(R.isPyretException($e26792680)) {
$e26792680.pyretStack.push(L[320]);
}
throw $e26792680;
}
var $ret26852686 = $Hcont_tail_arg22362692($z26812682,if_helper7362691);
++R.GAS;
return $ret26852686;
} else {
var $z26962697 = D;
var $f27022703 = function(_) {
return R.isFunction(else_DASH_clause1582704)?else_DASH_clause1582704.app():R.ffi.throwNonFunApp(L[320],else_DASH_clause1582704,[]);
};
try {
if(--R.GAS > 0) {
$z26962697 = $f27022703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27022703,
"from":L[320]});
}
} catch($e26942695) {
if(R.isCont($e26942695)) {
var $ss26982699 = {"from":L[320],
"go":function(cont_tail_arg7412705) {
return $Hcont_tail_arg22372706(cont_tail_arg7412705,if_helper7362691);
}};
$e26942695.stack[R.EXN_STACKHEIGHT++] = $ss26982699;
}
if(R.isPyretException($e26942695)) {
$e26942695.pyretStack.push(L[320]);
}
throw $e26942695;
}
var $ret27002701 = $Hcont_tail_arg22372706($z26962697,if_helper7362691);
++R.GAS;
return $ret27002701;
}
} else {
var cont_tail_arg7382710 = R.throwNonBooleanCondition(L[320],("if"),if_DASH_1602707);
if(--R.GAS > 0) {
$z27082709 = R.isFunction(if_helper7362691)?if_helper7362691.app(cont_tail_arg7382710):R.ffi.throwNonFunApp(L[320],if_helper7362691,[cont_tail_arg7382710]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7362691)?if_helper7362691.app(cont_tail_arg7382710):R.ffi.throwNonFunApp(L[320],if_helper7362691,[cont_tail_arg7382710]);
},
"from":L[320]});
}
++R.GAS;
return $z27082709;
}
};
},{"length":3});
var anf_singleton_variant_member7472674 = R.makeMethod(function(self1592678) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[320],0,arguments);
}
var ann_DASH_check_DASH_temp7462677 = ("j-postdecr");
return ann_DASH_check_DASH_temp7462677;
};
},{"length":1});
var anf_singleton_variant_member7492675 = R.makeMethod(function(self2661186) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[325],0,arguments);
}
var ann_DASH_check_DASH_temp7482676 = ("--");
return ann_DASH_check_DASH_temp7482676;
};
},{"length":1});
var anf_assign750187 = (function() {
var $j_DASH_incr_DASH_base26442645 = {"print-ugly-source":anf_shared6842642,
"tosource":anf_shared6892643,
"_match":anf_singleton_variant_member7002649,
"_torepr":anf_singleton_variant_member7022650,
"to-ugly-source":anf_singleton_variant_member7042651};
var $j_DASH_incr_DASH_brands26472648 = {"$brand-j-incr2646":true};
$j_DASH_incr_DASH_brands26472648[JUnopT57159._brand] = true
var $j_DASH_decr_DASH_base26522653 = {"print-ugly-source":anf_shared6842642,
"tosource":anf_shared6892643,
"_match":anf_singleton_variant_member7152657,
"_torepr":anf_singleton_variant_member7172658,
"to-ugly-source":anf_singleton_variant_member7192659};
var $j_DASH_decr_DASH_brands26552656 = {"$brand-j-decr2654":true};
$j_DASH_decr_DASH_brands26552656[JUnopT57159._brand] = true
var $j_DASH_postincr_DASH_base26602661 = {"print-ugly-source":anf_shared6842642,
"tosource":anf_shared6892643,
"_match":anf_singleton_variant_member7302665,
"_torepr":anf_singleton_variant_member7322666,
"to-ugly-source":anf_singleton_variant_member7342667};
var $j_DASH_postincr_DASH_brands26632664 = {"$brand-j-postincr2662":true};
$j_DASH_postincr_DASH_brands26632664[JUnopT57159._brand] = true
var $j_DASH_postdecr_DASH_base26682669 = {"print-ugly-source":anf_shared6842642,
"tosource":anf_shared6892643,
"_match":anf_singleton_variant_member7452673,
"_torepr":anf_singleton_variant_member7472674,
"to-ugly-source":anf_singleton_variant_member7492675};
var $j_DASH_postdecr_DASH_brands26712672 = {"$brand-j-postdecr2670":true};
$j_DASH_postdecr_DASH_brands26712672[JUnopT57159._brand] = true
return R.makeObject({"JUnop":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[324],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,JUnopT57159._brand));
}),
"is-j-incr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[323],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-incr2646"));
}),
"j-incr":R.makeBrandedObject($j_DASH_incr_DASH_base26442645,$j_DASH_incr_DASH_brands26472648),
"is-j-decr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[322],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-decr2654"));
}),
"j-decr":R.makeBrandedObject($j_DASH_decr_DASH_base26522653,$j_DASH_decr_DASH_brands26552656),
"is-j-postincr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[321],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-postincr2662"));
}),
"j-postincr":R.makeBrandedObject($j_DASH_postincr_DASH_base26602661,$j_DASH_postincr_DASH_brands26632664),
"is-j-postdecr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[320],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-postdecr2670"));
}),
"j-postdecr":R.makeBrandedObject($j_DASH_postdecr_DASH_base26682669,$j_DASH_postdecr_DASH_brands26712672)});
})();
JUnop11134186.$var = anf_assign750187;
var anf_assign751189 = G(JUnop11134186.$var,"JUnop",L[324]);
JUnop135188.$var = anf_assign751189;
var anf_assign752191 = G(JUnop11134186.$var,"JUnop",L[324]);
is_DASH_JUnop136190.$var = anf_assign752191;
var anf_assign753193 = G(JUnop11134186.$var,"is-j-incr",L[323]);
is_DASH_j_DASH_incr137192.$var = anf_assign753193;
var anf_assign754195 = G(JUnop11134186.$var,"j-incr",L[323]);
j_DASH_incr138194.$var = anf_assign754195;
var anf_assign755197 = G(JUnop11134186.$var,"is-j-decr",L[322]);
is_DASH_j_DASH_decr139196.$var = anf_assign755197;
var anf_assign756199 = G(JUnop11134186.$var,"j-decr",L[322]);
j_DASH_decr140198.$var = anf_assign756199;
var anf_assign757201 = G(JUnop11134186.$var,"is-j-postincr",L[321]);
is_DASH_j_DASH_postincr141200.$var = anf_assign757201;
var anf_assign758203 = G(JUnop11134186.$var,"j-postincr",L[321]);
j_DASH_postincr142202.$var = anf_assign758203;
var anf_assign759205 = G(JUnop11134186.$var,"is-j-postdecr",L[320]);
is_DASH_j_DASH_postdecr143204.$var = anf_assign759205;
var anf_assign760207 = G(JUnop11134186.$var,"j-postdecr",L[320]);
j_DASH_postdecr144206.$var = anf_assign760207;
var anf_shared765439 = R.makeMethod(function(self3882640) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[319],0,arguments);
}
var $z26312632 = D;
var $f26372638 = function(_) {
return R.isFunction(string_DASH_printer8078.$var)?string_DASH_printer8078.$var.app():R.ffi.throwNonFunApp(L[318],string_DASH_printer8078.$var,[]);
};
try {
if(--R.GAS > 0) {
$z26312632 = $f26372638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26372638,
"from":L[318]});
}
} catch($e26292630) {
if(R.isCont($e26292630)) {
var $ss26332634 = {"from":L[318],
"go":function(strprint3892639) {
return $Hstrprint22412641(strprint3892639,self3882640);
}};
$e26292630.stack[R.EXN_STACKHEIGHT++] = $ss26332634;
}
if(R.isPyretException($e26292630)) {
$e26292630.pyretStack.push(L[318]);
}
throw $e26292630;
}
var $ret26352636 = $Hstrprint22412641($z26312632,self3882640);
++R.GAS;
return $ret26352636;
};
},{"length":1});
var anf_variant_member777445 = R.makeMethod(function(self1622607) {
return function(cases_DASH_funs1632608,else_DASH_clause1642619) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[42],2,arguments);
}
var if_DASH_1662622 = R.hasField(cases_DASH_funs1632608,("j-parens"));
var if_helper7672605 = R.makeFunction(function(if_helper_arg7682627) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[42],1,arguments);
}
var ann_DASH_check_DASH_temp7662628 = if_helper_arg7682627;
return ann_DASH_check_DASH_temp7662628;
});
var anf_if7712626 = R.isBoolean(if_DASH_1662622);
if(R.isPyretTrue(anf_if7712626)) {
if(R.isPyretTrue(if_DASH_1662622)) {
var call_DASH_j_DASH_parens1612602 = G(cases_DASH_funs1632608,"j-parens",L[42]);
var anf_arg7742603 = G(self1622607,"exp",L[317]);
var $z25942595 = D;
var $f26002601 = function(_) {
return R.isFunction(call_DASH_j_DASH_parens1612602)?call_DASH_j_DASH_parens1612602.app(anf_arg7742603):R.ffi.throwNonFunApp(L[42],call_DASH_j_DASH_parens1612602,[anf_arg7742603]);
};
try {
if(--R.GAS > 0) {
$z25942595 = $f26002601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26002601,
"from":L[42]});
}
} catch($e25922593) {
if(R.isCont($e25922593)) {
var $ss25962597 = {"from":L[42],
"go":function(cont_tail_arg7752604) {
return $Hcont_tail_arg22422606(cont_tail_arg7752604,if_helper7672605);
}};
$e25922593.stack[R.EXN_STACKHEIGHT++] = $ss25962597;
}
if(R.isPyretException($e25922593)) {
$e25922593.pyretStack.push(L[42]);
}
throw $e25922593;
}
var $ret25982599 = $Hcont_tail_arg22422606($z25942595,if_helper7672605);
++R.GAS;
return $ret25982599;
} else {
var $z26112612 = D;
var $f26172618 = function(_) {
return R.isFunction(else_DASH_clause1642619)?else_DASH_clause1642619.app():R.ffi.throwNonFunApp(L[42],else_DASH_clause1642619,[]);
};
try {
if(--R.GAS > 0) {
$z26112612 = $f26172618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26172618,
"from":L[42]});
}
} catch($e26092610) {
if(R.isCont($e26092610)) {
var $ss26132614 = {"from":L[42],
"go":function(cont_tail_arg7722620) {
return $Hcont_tail_arg22432621(cont_tail_arg7722620,if_helper7672605);
}};
$e26092610.stack[R.EXN_STACKHEIGHT++] = $ss26132614;
}
if(R.isPyretException($e26092610)) {
$e26092610.pyretStack.push(L[42]);
}
throw $e26092610;
}
var $ret26152616 = $Hcont_tail_arg22432621($z26112612,if_helper7672605);
++R.GAS;
return $ret26152616;
}
} else {
var cont_tail_arg7692625 = R.throwNonBooleanCondition(L[42],("if"),if_DASH_1662622);
if(--R.GAS > 0) {
$z26232624 = R.isFunction(if_helper7672605)?if_helper7672605.app(cont_tail_arg7692625):R.ffi.throwNonFunApp(L[42],if_helper7672605,[cont_tail_arg7692625]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7672605)?if_helper7672605.app(cont_tail_arg7692625):R.ffi.throwNonFunApp(L[42],if_helper7672605,[cont_tail_arg7692625]);
},
"from":L[42]});
}
++R.GAS;
return $z26232624;
}
};
},{"length":3});
var anf_variant_member783446 = R.makeMethod(function(self1652591) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[42],0,arguments);
}
var anf_arg7792588 = G(self1652591,"exp",L[42]);
var $z25802581 = D;
var $f25862587 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg7792588):R.ffi.throwNonFunApp(L[42],torepr18,[anf_arg7792588]);
};
try {
if(--R.GAS > 0) {
$z25802581 = $f25862587();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25862587,
"from":L[42]});
}
} catch($e25782579) {
if(R.isCont($e25782579)) {
var $ss25822583 = {"from":L[42],
"go":function(anf_arg7802589) {
return $Hanf_arg22472590(anf_arg7802589,_plus14);
}};
$e25782579.stack[R.EXN_STACKHEIGHT++] = $ss25822583;
}
if(R.isPyretException($e25782579)) {
$e25782579.pyretStack.push(L[42]);
}
throw $e25782579;
}
var $ret25842585 = $Hanf_arg22472590($z25802581,_plus14);
++R.GAS;
return $ret25842585;
};
},{"length":1});
var anf_variant_member787447 = R.makeMethod(function(self2712576) {
return function(printer2722574) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[316],1,arguments);
}
var $z25662567 = D;
var $f25722573 = function(_) {
return R.isFunction(printer2722574)?printer2722574.app(("(")):R.ffi.throwNonFunApp(L[315],printer2722574,[("(")]);
};
try {
if(--R.GAS > 0) {
$z25662567 = $f25722573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25722573,
"from":L[315]});
}
} catch($e25642565) {
if(R.isCont($e25642565)) {
var $ss25682569 = {"from":L[315],
"go":function(anf_begin_app_dropped22482575) {
return $Hanf_begin_app_dropped22522577(anf_begin_app_dropped22482575,printer2722574,self2712576);
}};
$e25642565.stack[R.EXN_STACKHEIGHT++] = $ss25682569;
}
if(R.isPyretException($e25642565)) {
$e25642565.pyretStack.push(L[315]);
}
throw $e25642565;
}
var $ret25702571 = $Hanf_begin_app_dropped22522577($z25662567,printer2722574,self2712576);
++R.GAS;
return $ret25702571;
};
},{"length":2});
var anf_variant_member797448 = R.makeMethod(function(self2732562) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[314],0,arguments);
}
var anf_fun7892561 = G(PP123,"surround",L[313]);
var anf_fun7902559 = G(PP123,"str",L[312]);
var $z25512552 = D;
var $f25572558 = function(_) {
return R.isFunction(anf_fun7902559)?anf_fun7902559.app(("(")):R.ffi.throwNonFunApp(L[311],anf_fun7902559,[("(")]);
};
try {
if(--R.GAS > 0) {
$z25512552 = $f25572558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25572558,
"from":L[311]});
}
} catch($e25492550) {
if(R.isCont($e25492550)) {
var $ss25532554 = {"from":L[311],
"go":function(anf_arg7912560) {
return $Hanf_arg22562563(anf_arg7912560,INDENT7747,PP123,anf_fun7892561,self2732562);
}};
$e25492550.stack[R.EXN_STACKHEIGHT++] = $ss25532554;
}
if(R.isPyretException($e25492550)) {
$e25492550.pyretStack.push(L[311]);
}
throw $e25492550;
}
var $ret25552556 = $Hanf_arg22562563($z25512552,INDENT7747,PP123,anf_fun7892561,self2732562);
++R.GAS;
return $ret25552556;
};
},{"length":1});
var anf_variant_member810455 = R.makeMethod(function(self1682527) {
return function(cases_DASH_funs1692528,else_DASH_clause1702539) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[41],2,arguments);
}
var if_DASH_1722542 = R.hasField(cases_DASH_funs1692528,("j-unop"));
var if_helper7992525 = R.makeFunction(function(if_helper_arg8002547) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[41],1,arguments);
}
var ann_DASH_check_DASH_temp7982548 = if_helper_arg8002547;
return ann_DASH_check_DASH_temp7982548;
});
var anf_if8032546 = R.isBoolean(if_DASH_1722542);
if(R.isPyretTrue(anf_if8032546)) {
if(R.isPyretTrue(if_DASH_1722542)) {
var call_DASH_j_DASH_unop1672521 = G(cases_DASH_funs1692528,"j-unop",L[41]);
var anf_arg8062522 = G(self1682527,"exp",L[310]);
var anf_arg8072523 = G(self1682527,"op",L[309]);
var $z25132514 = D;
var $f25192520 = function(_) {
return R.isFunction(call_DASH_j_DASH_unop1672521)?call_DASH_j_DASH_unop1672521.app(anf_arg8062522,anf_arg8072523):R.ffi.throwNonFunApp(L[41],call_DASH_j_DASH_unop1672521,[anf_arg8062522,anf_arg8072523]);
};
try {
if(--R.GAS > 0) {
$z25132514 = $f25192520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25192520,
"from":L[41]});
}
} catch($e25112512) {
if(R.isCont($e25112512)) {
var $ss25152516 = {"from":L[41],
"go":function(cont_tail_arg8082524) {
return $Hcont_tail_arg22572526(cont_tail_arg8082524,if_helper7992525);
}};
$e25112512.stack[R.EXN_STACKHEIGHT++] = $ss25152516;
}
if(R.isPyretException($e25112512)) {
$e25112512.pyretStack.push(L[41]);
}
throw $e25112512;
}
var $ret25172518 = $Hcont_tail_arg22572526($z25132514,if_helper7992525);
++R.GAS;
return $ret25172518;
} else {
var $z25312532 = D;
var $f25372538 = function(_) {
return R.isFunction(else_DASH_clause1702539)?else_DASH_clause1702539.app():R.ffi.throwNonFunApp(L[41],else_DASH_clause1702539,[]);
};
try {
if(--R.GAS > 0) {
$z25312532 = $f25372538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25372538,
"from":L[41]});
}
} catch($e25292530) {
if(R.isCont($e25292530)) {
var $ss25332534 = {"from":L[41],
"go":function(cont_tail_arg8042540) {
return $Hcont_tail_arg22582541(cont_tail_arg8042540,if_helper7992525);
}};
$e25292530.stack[R.EXN_STACKHEIGHT++] = $ss25332534;
}
if(R.isPyretException($e25292530)) {
$e25292530.pyretStack.push(L[41]);
}
throw $e25292530;
}
var $ret25352536 = $Hcont_tail_arg22582541($z25312532,if_helper7992525);
++R.GAS;
return $ret25352536;
}
} else {
var cont_tail_arg8012545 = R.throwNonBooleanCondition(L[41],("if"),if_DASH_1722542);
if(--R.GAS > 0) {
$z25432544 = R.isFunction(if_helper7992525)?if_helper7992525.app(cont_tail_arg8012545):R.ffi.throwNonFunApp(L[41],if_helper7992525,[cont_tail_arg8012545]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7992525)?if_helper7992525.app(cont_tail_arg8012545):R.ffi.throwNonFunApp(L[41],if_helper7992525,[cont_tail_arg8012545]);
},
"from":L[41]});
}
++R.GAS;
return $z25432544;
}
};
},{"length":3});
var anf_variant_member820456 = R.makeMethod(function(self1712509) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[41],0,arguments);
}
var anf_arg8122507 = G(self1712509,"exp",L[41]);
var $z24992500 = D;
var $f25052506 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg8122507):R.ffi.throwNonFunApp(L[41],torepr18,[anf_arg8122507]);
};
try {
if(--R.GAS > 0) {
$z24992500 = $f25052506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25052506,
"from":L[41]});
}
} catch($e24972498) {
if(R.isCont($e24972498)) {
var $ss25012502 = {"from":L[41],
"go":function(anf_arg8132508) {
return $Hanf_arg22652510(anf_arg8132508,self1712509,_plus14,torepr18);
}};
$e24972498.stack[R.EXN_STACKHEIGHT++] = $ss25012502;
}
if(R.isPyretException($e24972498)) {
$e24972498.pyretStack.push(L[41]);
}
throw $e24972498;
}
var $ret25032504 = $Hanf_arg22652510($z24992500,self1712509,_plus14,torepr18);
++R.GAS;
return $ret25032504;
};
},{"length":1});
var anf_variant_member842457 = R.makeMethod(function(self2762463) {
return function(printer2772461) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[295],1,arguments);
}
var cases_DASH_val1732496 = G(self2762463,"op",L[308]);
var anf_fun8222445 = G(cases_DASH_val1732496,"_match",L[296]);
var anf_obj8282466 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[304],0,arguments);
}
var anf_bracket8242495 = G(self2762463,"exp",L[307]);
var anf_fun8252492 = G(anf_bracket8242495,"print-ugly-source",L[306]);
var $z24842485 = D;
var $f24902491 = function(_) {
return R.isFunction(anf_fun8252492)?anf_fun8252492.app(printer2772461):R.ffi.throwNonFunApp(L[305],anf_fun8252492,[printer2772461]);
};
try {
if(--R.GAS > 0) {
$z24842485 = $f24902491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24902491,
"from":L[305]});
}
} catch($e24822483) {
if(R.isCont($e24822483)) {
var $ss24862487 = {"from":L[305],
"go":function(anf_begin_app_dropped22662493) {
return $Hanf_begin_app_dropped22682494(anf_begin_app_dropped22662493,printer2772461,self2762463);
}};
$e24822483.stack[R.EXN_STACKHEIGHT++] = $ss24862487;
}
if(R.isPyretException($e24822483)) {
$e24822483.pyretStack.push(L[305]);
}
throw $e24822483;
}
var $ret24882489 = $Hanf_begin_app_dropped22682494($z24842485,printer2772461,self2762463);
++R.GAS;
return $ret24882489;
});
var anf_obj8342467 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[300],0,arguments);
}
var anf_bracket8302481 = G(self2762463,"exp",L[303]);
var anf_fun8312478 = G(anf_bracket8302481,"print-ugly-source",L[302]);
var $z24702471 = D;
var $f24762477 = function(_) {
return R.isFunction(anf_fun8312478)?anf_fun8312478.app(printer2772461):R.ffi.throwNonFunApp(L[301],anf_fun8312478,[printer2772461]);
};
try {
if(--R.GAS > 0) {
$z24702471 = $f24762477();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24762477,
"from":L[301]});
}
} catch($e24682469) {
if(R.isCont($e24682469)) {
var $ss24722473 = {"from":L[301],
"go":function(anf_begin_app_dropped22692479) {
return $Hanf_begin_app_dropped22712480(anf_begin_app_dropped22692479,printer2772461,self2762463);
}};
$e24682469.stack[R.EXN_STACKHEIGHT++] = $ss24722473;
}
if(R.isPyretException($e24682469)) {
$e24682469.pyretStack.push(L[301]);
}
throw $e24682469;
}
var $ret24742475 = $Hanf_begin_app_dropped22712480($z24702471,printer2772461,self2762463);
++R.GAS;
return $ret24742475;
});
var anf_arg8352446 = R.makeObject({"j-postincr":anf_obj8282466,
"j-postdeccr":anf_obj8342467});
var anf_arg8412447 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[296],0,arguments);
}
var anf_bracket8372465 = G(self2762463,"op",L[299]);
var anf_fun8382460 = G(anf_bracket8372465,"print-ugly-source",L[298]);
var $z24522453 = D;
var $f24582459 = function(_) {
return R.isFunction(anf_fun8382460)?anf_fun8382460.app(printer2772461):R.ffi.throwNonFunApp(L[297],anf_fun8382460,[printer2772461]);
};
try {
if(--R.GAS > 0) {
$z24522453 = $f24582459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24582459,
"from":L[297]});
}
} catch($e24502451) {
if(R.isCont($e24502451)) {
var $ss24542455 = {"from":L[297],
"go":function(anf_begin_app_dropped22722462) {
return $Hanf_begin_app_dropped22742464(anf_begin_app_dropped22722462,printer2772461,self2762463);
}};
$e24502451.stack[R.EXN_STACKHEIGHT++] = $ss24542455;
}
if(R.isPyretException($e24502451)) {
$e24502451.pyretStack.push(L[297]);
}
throw $e24502451;
}
var $ret24562457 = $Hanf_begin_app_dropped22742464($z24522453,printer2772461,self2762463);
++R.GAS;
return $ret24562457;
});
var $z24372438 = D;
var $f24432444 = function(_) {
return R.isFunction(anf_fun8222445)?anf_fun8222445.app(anf_arg8352446,anf_arg8412447):R.ffi.throwNonFunApp(L[295],anf_fun8222445,[anf_arg8352446,anf_arg8412447]);
};
try {
if(--R.GAS > 0) {
$z24372438 = $f24432444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24432444,
"from":L[295]});
}
} catch($e24352436) {
if(R.isCont($e24352436)) {
var $ss24392440 = {"from":L[295],
"go":function(ann_DASH_check_DASH_temp8212448) {
return $Hann_DASH_check_DASH_temp22752449(ann_DASH_check_DASH_temp8212448);
}};
$e24352436.stack[R.EXN_STACKHEIGHT++] = $ss24392440;
}
if(R.isPyretException($e24352436)) {
$e24352436.pyretStack.push(L[295]);
}
throw $e24352436;
}
var $ret24412442 = $Hann_DASH_check_DASH_temp22752449($z24372438);
++R.GAS;
return $ret24412442;
};
},{"length":2});
var anf_variant_member870458 = R.makeMethod(function(self2781060) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[281],0,arguments);
}
var cases_DASH_val1742434 = G(self2781060,"op",L[294]);
var anf_fun8442385 = G(cases_DASH_val1742434,"_match",L[282]);
var anf_obj8522404 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[290],0,arguments);
}
var anf_bracket8462433 = G(self2781060,"exp",L[293]);
var anf_fun8472430 = G(anf_bracket8462433,"tosource",L[292]);
var $z24222423 = D;
var $f24282429 = function(_) {
return R.isFunction(anf_fun8472430)?anf_fun8472430.app():R.ffi.throwNonFunApp(L[291],anf_fun8472430,[]);
};
try {
if(--R.GAS > 0) {
$z24222423 = $f24282429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24282429,
"from":L[291]});
}
} catch($e24202421) {
if(R.isCont($e24202421)) {
var $ss24242425 = {"from":L[291],
"go":function(anf_arg8482431) {
return $Hanf_arg22782432(anf_arg8482431,self2781060,_plus14);
}};
$e24202421.stack[R.EXN_STACKHEIGHT++] = $ss24242425;
}
if(R.isPyretException($e24202421)) {
$e24202421.pyretStack.push(L[291]);
}
throw $e24202421;
}
var $ret24262427 = $Hanf_arg22782432($z24222423,self2781060,_plus14);
++R.GAS;
return $ret24262427;
});
var anf_obj8602405 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[286],0,arguments);
}
var anf_bracket8542419 = G(self2781060,"exp",L[289]);
var anf_fun8552416 = G(anf_bracket8542419,"tosource",L[288]);
var $z24082409 = D;
var $f24142415 = function(_) {
return R.isFunction(anf_fun8552416)?anf_fun8552416.app():R.ffi.throwNonFunApp(L[287],anf_fun8552416,[]);
};
try {
if(--R.GAS > 0) {
$z24082409 = $f24142415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24142415,
"from":L[287]});
}
} catch($e24062407) {
if(R.isCont($e24062407)) {
var $ss24102411 = {"from":L[287],
"go":function(anf_arg8562417) {
return $Hanf_arg22812418(anf_arg8562417,self2781060,_plus14);
}};
$e24062407.stack[R.EXN_STACKHEIGHT++] = $ss24102411;
}
if(R.isPyretException($e24062407)) {
$e24062407.pyretStack.push(L[287]);
}
throw $e24062407;
}
var $ret24122413 = $Hanf_arg22812418($z24082409,self2781060,_plus14);
++R.GAS;
return $ret24122413;
});
var anf_arg8612386 = R.makeObject({"j-postincr":anf_obj8522404,
"j-postdeccr":anf_obj8602405});
var anf_arg8692387 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[282],0,arguments);
}
var anf_bracket8632403 = G(self2781060,"op",L[285]);
var anf_fun8642400 = G(anf_bracket8632403,"tosource",L[284]);
var $z23922393 = D;
var $f23982399 = function(_) {
return R.isFunction(anf_fun8642400)?anf_fun8642400.app():R.ffi.throwNonFunApp(L[283],anf_fun8642400,[]);
};
try {
if(--R.GAS > 0) {
$z23922393 = $f23982399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23982399,
"from":L[283]});
}
} catch($e23902391) {
if(R.isCont($e23902391)) {
var $ss23942395 = {"from":L[283],
"go":function(anf_arg8652401) {
return $Hanf_arg22842402(anf_arg8652401,self2781060,_plus14);
}};
$e23902391.stack[R.EXN_STACKHEIGHT++] = $ss23942395;
}
if(R.isPyretException($e23902391)) {
$e23902391.pyretStack.push(L[283]);
}
throw $e23902391;
}
var $ret23962397 = $Hanf_arg22842402($z23922393,self2781060,_plus14);
++R.GAS;
return $ret23962397;
});
var $z23772378 = D;
var $f23832384 = function(_) {
return R.isFunction(anf_fun8442385)?anf_fun8442385.app(anf_arg8612386,anf_arg8692387):R.ffi.throwNonFunApp(L[281],anf_fun8442385,[anf_arg8612386,anf_arg8692387]);
};
try {
if(--R.GAS > 0) {
$z23772378 = $f23832384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23832384,
"from":L[281]});
}
} catch($e23752376) {
if(R.isCont($e23752376)) {
var $ss23792380 = {"from":L[281],
"go":function(ann_DASH_check_DASH_temp8432388) {
return $Hann_DASH_check_DASH_temp22852389(ann_DASH_check_DASH_temp8432388);
}};
$e23752376.stack[R.EXN_STACKHEIGHT++] = $ss23792380;
}
if(R.isPyretException($e23752376)) {
$e23752376.pyretStack.push(L[281]);
}
throw $e23752376;
}
var $ret23812382 = $Hann_DASH_check_DASH_temp22852389($z23772378);
++R.GAS;
return $ret23812382;
};
},{"length":1});
var anf_variant_member884466 = R.makeMethod(function(self1762353) {
return function(cases_DASH_funs1772354,else_DASH_clause1782365) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[40],2,arguments);
}
var if_DASH_1802368 = R.hasField(cases_DASH_funs1772354,("j-binop"));
var if_helper8722351 = R.makeFunction(function(if_helper_arg8732373) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[40],1,arguments);
}
var ann_DASH_check_DASH_temp8712374 = if_helper_arg8732373;
return ann_DASH_check_DASH_temp8712374;
});
var anf_if8762372 = R.isBoolean(if_DASH_1802368);
if(R.isPyretTrue(anf_if8762372)) {
if(R.isPyretTrue(if_DASH_1802368)) {
var call_DASH_j_DASH_binop1752346 = G(cases_DASH_funs1772354,"j-binop",L[40]);
var anf_arg8792347 = G(self1762353,"left",L[280]);
var anf_arg8802348 = G(self1762353,"op",L[279]);
var anf_arg8812349 = G(self1762353,"right",L[278]);
var $z23382339 = D;
var $f23442345 = function(_) {
return R.isFunction(call_DASH_j_DASH_binop1752346)?call_DASH_j_DASH_binop1752346.app(anf_arg8792347,anf_arg8802348,anf_arg8812349):R.ffi.throwNonFunApp(L[40],call_DASH_j_DASH_binop1752346,[anf_arg8792347,anf_arg8802348,anf_arg8812349]);
};
try {
if(--R.GAS > 0) {
$z23382339 = $f23442345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23442345,
"from":L[40]});
}
} catch($e23362337) {
if(R.isCont($e23362337)) {
var $ss23402341 = {"from":L[40],
"go":function(cont_tail_arg8822350) {
return $Hcont_tail_arg22862352(cont_tail_arg8822350,if_helper8722351);
}};
$e23362337.stack[R.EXN_STACKHEIGHT++] = $ss23402341;
}
if(R.isPyretException($e23362337)) {
$e23362337.pyretStack.push(L[40]);
}
throw $e23362337;
}
var $ret23422343 = $Hcont_tail_arg22862352($z23382339,if_helper8722351);
++R.GAS;
return $ret23422343;
} else {
var $z23572358 = D;
var $f23632364 = function(_) {
return R.isFunction(else_DASH_clause1782365)?else_DASH_clause1782365.app():R.ffi.throwNonFunApp(L[40],else_DASH_clause1782365,[]);
};
try {
if(--R.GAS > 0) {
$z23572358 = $f23632364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23632364,
"from":L[40]});
}
} catch($e23552356) {
if(R.isCont($e23552356)) {
var $ss23592360 = {"from":L[40],
"go":function(cont_tail_arg8772366) {
return $Hcont_tail_arg22872367(cont_tail_arg8772366,if_helper8722351);
}};
$e23552356.stack[R.EXN_STACKHEIGHT++] = $ss23592360;
}
if(R.isPyretException($e23552356)) {
$e23552356.pyretStack.push(L[40]);
}
throw $e23552356;
}
var $ret23612362 = $Hcont_tail_arg22872367($z23572358,if_helper8722351);
++R.GAS;
return $ret23612362;
}
} else {
var cont_tail_arg8742371 = R.throwNonBooleanCondition(L[40],("if"),if_DASH_1802368);
if(--R.GAS > 0) {
$z23692370 = R.isFunction(if_helper8722351)?if_helper8722351.app(cont_tail_arg8742371):R.ffi.throwNonFunApp(L[40],if_helper8722351,[cont_tail_arg8742371]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper8722351)?if_helper8722351.app(cont_tail_arg8742371):R.ffi.throwNonFunApp(L[40],if_helper8722351,[cont_tail_arg8742371]);
},
"from":L[40]});
}
++R.GAS;
return $z23692370;
}
};
},{"length":3});
var anf_variant_member898467 = R.makeMethod(function(self1792334) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[40],0,arguments);
}
var anf_arg8862332 = G(self1792334,"left",L[40]);
var $z23242325 = D;
var $f23302331 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg8862332):R.ffi.throwNonFunApp(L[40],torepr18,[anf_arg8862332]);
};
try {
if(--R.GAS > 0) {
$z23242325 = $f23302331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23302331,
"from":L[40]});
}
} catch($e23222323) {
if(R.isCont($e23222323)) {
var $ss23262327 = {"from":L[40],
"go":function(anf_arg8872333) {
return $Hanf_arg22972335(anf_arg8872333,self1792334,_plus14,torepr18);
}};
$e23222323.stack[R.EXN_STACKHEIGHT++] = $ss23262327;
}
if(R.isPyretException($e23222323)) {
$e23222323.pyretStack.push(L[40]);
}
throw $e23222323;
}
var $ret23282329 = $Hanf_arg22972335($z23242325,self1792334,_plus14,torepr18);
++R.GAS;
return $ret23282329;
};
},{"length":1});
var anf_variant_member906468 = R.makeMethod(function(self2822319) {
return function(printer2832317) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[277],1,arguments);
}
var anf_bracket9002321 = G(self2822319,"left",L[276]);
var anf_fun9012316 = G(anf_bracket9002321,"print-ugly-source",L[275]);
var $z23082309 = D;
var $f23142315 = function(_) {
return R.isFunction(anf_fun9012316)?anf_fun9012316.app(printer2832317):R.ffi.throwNonFunApp(L[274],anf_fun9012316,[printer2832317]);
};
try {
if(--R.GAS > 0) {
$z23082309 = $f23142315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23142315,
"from":L[274]});
}
} catch($e23062307) {
if(R.isCont($e23062307)) {
var $ss23102311 = {"from":L[274],
"go":function(anf_begin_app_dropped22982318) {
return $Hanf_begin_app_dropped23062320(anf_begin_app_dropped22982318,printer2832317,self2822319);
}};
$e23062307.stack[R.EXN_STACKHEIGHT++] = $ss23102311;
}
if(R.isPyretException($e23062307)) {
$e23062307.pyretStack.push(L[274]);
}
throw $e23062307;
}
var $ret23122313 = $Hanf_begin_app_dropped23062320($z23082309,printer2832317,self2822319);
++R.GAS;
return $ret23122313;
};
},{"length":2});
var anf_variant_member920469 = R.makeMethod(function(self284994) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[273],0,arguments);
}
var anf_fun9082302 = G(PP123,"flow",L[272]);
var anf_fun9092303 = G(list2364,"make",L[271]);
var anf_bracket9102305 = G(self284994,"left",L[270]);
var anf_fun9112300 = G(anf_bracket9102305,"tosource",L[269]);
var $z22922293 = D;
var $f22982299 = function(_) {
return R.isFunction(anf_fun9112300)?anf_fun9112300.app():R.ffi.throwNonFunApp(L[268],anf_fun9112300,[]);
};
try {
if(--R.GAS > 0) {
$z22922293 = $f22982299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22982299,
"from":L[268]});
}
} catch($e22902291) {
if(R.isCont($e22902291)) {
var $ss22942295 = {"from":L[268],
"go":function(anf_array_val9122301) {
return $Hanf_array_val23112304(anf_array_val9122301,anf_fun9082302,anf_fun9092303,self284994);
}};
$e22902291.stack[R.EXN_STACKHEIGHT++] = $ss22942295;
}
if(R.isPyretException($e22902291)) {
$e22902291.pyretStack.push(L[268]);
}
throw $e22902291;
}
var $ret22962297 = $Hanf_array_val23112304($z22922293,anf_fun9082302,anf_fun9092303,self284994);
++R.GAS;
return $ret22962297;
};
},{"length":1});
var anf_variant_member933478 = R.makeMethod(function(self1822268) {
return function(cases_DASH_funs1832269,else_DASH_clause1842280) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[39],2,arguments);
}
var if_DASH_1862283 = R.hasField(cases_DASH_funs1832269,("j-fun"));
var if_helper9222266 = R.makeFunction(function(if_helper_arg9232288) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[39],1,arguments);
}
var ann_DASH_check_DASH_temp9212289 = if_helper_arg9232288;
return ann_DASH_check_DASH_temp9212289;
});
var anf_if9262287 = R.isBoolean(if_DASH_1862283);
if(R.isPyretTrue(anf_if9262287)) {
if(R.isPyretTrue(if_DASH_1862283)) {
var call_DASH_j_DASH_fun1812262 = G(cases_DASH_funs1832269,"j-fun",L[39]);
var anf_arg9292263 = G(self1822268,"args",L[267]);
var anf_arg9302264 = G(self1822268,"body",L[266]);
var $z22542255 = D;
var $f22602261 = function(_) {
return R.isFunction(call_DASH_j_DASH_fun1812262)?call_DASH_j_DASH_fun1812262.app(anf_arg9292263,anf_arg9302264):R.ffi.throwNonFunApp(L[39],call_DASH_j_DASH_fun1812262,[anf_arg9292263,anf_arg9302264]);
};
try {
if(--R.GAS > 0) {
$z22542255 = $f22602261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22602261,
"from":L[39]});
}
} catch($e22522253) {
if(R.isCont($e22522253)) {
var $ss22562257 = {"from":L[39],
"go":function(cont_tail_arg9312265) {
return $Hcont_tail_arg23122267(cont_tail_arg9312265,if_helper9222266);
}};
$e22522253.stack[R.EXN_STACKHEIGHT++] = $ss22562257;
}
if(R.isPyretException($e22522253)) {
$e22522253.pyretStack.push(L[39]);
}
throw $e22522253;
}
var $ret22582259 = $Hcont_tail_arg23122267($z22542255,if_helper9222266);
++R.GAS;
return $ret22582259;
} else {
var $z22722273 = D;
var $f22782279 = function(_) {
return R.isFunction(else_DASH_clause1842280)?else_DASH_clause1842280.app():R.ffi.throwNonFunApp(L[39],else_DASH_clause1842280,[]);
};
try {
if(--R.GAS > 0) {
$z22722273 = $f22782279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22782279,
"from":L[39]});
}
} catch($e22702271) {
if(R.isCont($e22702271)) {
var $ss22742275 = {"from":L[39],
"go":function(cont_tail_arg9272281) {
return $Hcont_tail_arg23132282(cont_tail_arg9272281,if_helper9222266);
}};
$e22702271.stack[R.EXN_STACKHEIGHT++] = $ss22742275;
}
if(R.isPyretException($e22702271)) {
$e22702271.pyretStack.push(L[39]);
}
throw $e22702271;
}
var $ret22762277 = $Hcont_tail_arg23132282($z22722273,if_helper9222266);
++R.GAS;
return $ret22762277;
}
} else {
var cont_tail_arg9242286 = R.throwNonBooleanCondition(L[39],("if"),if_DASH_1862283);
if(--R.GAS > 0) {
$z22842285 = R.isFunction(if_helper9222266)?if_helper9222266.app(cont_tail_arg9242286):R.ffi.throwNonFunApp(L[39],if_helper9222266,[cont_tail_arg9242286]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper9222266)?if_helper9222266.app(cont_tail_arg9242286):R.ffi.throwNonFunApp(L[39],if_helper9222266,[cont_tail_arg9242286]);
},
"from":L[39]});
}
++R.GAS;
return $z22842285;
}
};
},{"length":3});
var anf_variant_member943479 = R.makeMethod(function(self1852250) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[39],0,arguments);
}
var anf_arg9352248 = G(self1852250,"args",L[39]);
var $z22402241 = D;
var $f22462247 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg9352248):R.ffi.throwNonFunApp(L[39],torepr18,[anf_arg9352248]);
};
try {
if(--R.GAS > 0) {
$z22402241 = $f22462247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22462247,
"from":L[39]});
}
} catch($e22382239) {
if(R.isCont($e22382239)) {
var $ss22422243 = {"from":L[39],
"go":function(anf_arg9362249) {
return $Hanf_arg23202251(anf_arg9362249,self1852250,_plus14,torepr18);
}};
$e22382239.stack[R.EXN_STACKHEIGHT++] = $ss22422243;
}
if(R.isPyretException($e22382239)) {
$e22382239.pyretStack.push(L[39]);
}
throw $e22382239;
}
var $ret22442245 = $Hanf_arg23202251($z22402241,self1852250,_plus14,torepr18);
++R.GAS;
return $ret22442245;
};
},{"length":1});
var anf_variant_member950480 = R.makeMethod(function(self287958) {
return function(printer2882235) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[265],1,arguments);
}
var $z22272228 = D;
var $f22332234 = function(_) {
return R.isFunction(printer2882235)?printer2882235.app(("function(")):R.ffi.throwNonFunApp(L[264],printer2882235,[("function(")]);
};
try {
if(--R.GAS > 0) {
$z22272228 = $f22332234();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22332234,
"from":L[264]});
}
} catch($e22252226) {
if(R.isCont($e22252226)) {
var $ss22292230 = {"from":L[264],
"go":function(anf_begin_app_dropped23212236) {
return $Hanf_begin_app_dropped23302237(anf_begin_app_dropped23212236,printer2882235,self287958);
}};
$e22252226.stack[R.EXN_STACKHEIGHT++] = $ss22292230;
}
if(R.isPyretException($e22252226)) {
$e22252226.pyretStack.push(L[264]);
}
throw $e22252226;
}
var $ret22312232 = $Hanf_begin_app_dropped23302237($z22272228,printer2882235,self287958);
++R.GAS;
return $ret22312232;
};
},{"length":2});
var anf_variant_member978481 = R.makeMethod(function(self2892223) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[263],0,arguments);
}
var anf_fun9522221 = G(PP123,"nest",L[262]);
var anf_fun9532222 = G(PP123,"surround-separate",L[261]);
var anf_arg9542218 = G(PP123,"lparen",L[260]);
var anf_arg9552219 = G(PP123,"rparen",L[259]);
var $z22102211 = D;
var $f22162217 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg9542218,anf_arg9552219):R.ffi.throwNonFunApp(L[258],_plus14,[anf_arg9542218,anf_arg9552219]);
};
try {
if(--R.GAS > 0) {
$z22102211 = $f22162217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22162217,
"from":L[258]});
}
} catch($e22082209) {
if(R.isCont($e22082209)) {
var $ss22122213 = {"from":L[258],
"go":function(anf_arg9562220) {
return $Hanf_arg23422224(anf_arg9562220,INDENT7747,PP123,anf_fun9522221,anf_fun9532222,self2892223,_plus14);
}};
$e22082209.stack[R.EXN_STACKHEIGHT++] = $ss22122213;
}
if(R.isPyretException($e22082209)) {
$e22082209.pyretStack.push(L[258]);
}
throw $e22082209;
}
var $ret22142215 = $Hanf_arg23422224($z22102211,INDENT7747,PP123,anf_fun9522221,anf_fun9532222,self2892223,_plus14);
++R.GAS;
return $ret22142215;
};
},{"length":1});
var anf_variant_member991489 = R.makeMethod(function(self1882186) {
return function(cases_DASH_funs1892187,else_DASH_clause1902198) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[38],2,arguments);
}
var if_DASH_1922201 = R.hasField(cases_DASH_funs1892187,("j-app"));
var if_helper9802184 = R.makeFunction(function(if_helper_arg9812206) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[38],1,arguments);
}
var ann_DASH_check_DASH_temp9792207 = if_helper_arg9812206;
return ann_DASH_check_DASH_temp9792207;
});
var anf_if9842205 = R.isBoolean(if_DASH_1922201);
if(R.isPyretTrue(anf_if9842205)) {
if(R.isPyretTrue(if_DASH_1922201)) {
var call_DASH_j_DASH_app1872180 = G(cases_DASH_funs1892187,"j-app",L[38]);
var anf_arg9872181 = G(self1882186,"func",L[257]);
var anf_arg9882182 = G(self1882186,"args",L[256]);
var $z21722173 = D;
var $f21782179 = function(_) {
return R.isFunction(call_DASH_j_DASH_app1872180)?call_DASH_j_DASH_app1872180.app(anf_arg9872181,anf_arg9882182):R.ffi.throwNonFunApp(L[38],call_DASH_j_DASH_app1872180,[anf_arg9872181,anf_arg9882182]);
};
try {
if(--R.GAS > 0) {
$z21722173 = $f21782179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21782179,
"from":L[38]});
}
} catch($e21702171) {
if(R.isCont($e21702171)) {
var $ss21742175 = {"from":L[38],
"go":function(cont_tail_arg9892183) {
return $Hcont_tail_arg23432185(cont_tail_arg9892183,if_helper9802184);
}};
$e21702171.stack[R.EXN_STACKHEIGHT++] = $ss21742175;
}
if(R.isPyretException($e21702171)) {
$e21702171.pyretStack.push(L[38]);
}
throw $e21702171;
}
var $ret21762177 = $Hcont_tail_arg23432185($z21722173,if_helper9802184);
++R.GAS;
return $ret21762177;
} else {
var $z21902191 = D;
var $f21962197 = function(_) {
return R.isFunction(else_DASH_clause1902198)?else_DASH_clause1902198.app():R.ffi.throwNonFunApp(L[38],else_DASH_clause1902198,[]);
};
try {
if(--R.GAS > 0) {
$z21902191 = $f21962197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21962197,
"from":L[38]});
}
} catch($e21882189) {
if(R.isCont($e21882189)) {
var $ss21922193 = {"from":L[38],
"go":function(cont_tail_arg9852199) {
return $Hcont_tail_arg23442200(cont_tail_arg9852199,if_helper9802184);
}};
$e21882189.stack[R.EXN_STACKHEIGHT++] = $ss21922193;
}
if(R.isPyretException($e21882189)) {
$e21882189.pyretStack.push(L[38]);
}
throw $e21882189;
}
var $ret21942195 = $Hcont_tail_arg23442200($z21902191,if_helper9802184);
++R.GAS;
return $ret21942195;
}
} else {
var cont_tail_arg9822204 = R.throwNonBooleanCondition(L[38],("if"),if_DASH_1922201);
if(--R.GAS > 0) {
$z22022203 = R.isFunction(if_helper9802184)?if_helper9802184.app(cont_tail_arg9822204):R.ffi.throwNonFunApp(L[38],if_helper9802184,[cont_tail_arg9822204]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper9802184)?if_helper9802184.app(cont_tail_arg9822204):R.ffi.throwNonFunApp(L[38],if_helper9802184,[cont_tail_arg9822204]);
},
"from":L[38]});
}
++R.GAS;
return $z22022203;
}
};
},{"length":3});
var anf_variant_member1001490 = R.makeMethod(function(self1912168) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[38],0,arguments);
}
var anf_arg9932166 = G(self1912168,"func",L[38]);
var $z21582159 = D;
var $f21642165 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg9932166):R.ffi.throwNonFunApp(L[38],torepr18,[anf_arg9932166]);
};
try {
if(--R.GAS > 0) {
$z21582159 = $f21642165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21642165,
"from":L[38]});
}
} catch($e21562157) {
if(R.isCont($e21562157)) {
var $ss21602161 = {"from":L[38],
"go":function(anf_arg9942167) {
return $Hanf_arg23512169(anf_arg9942167,self1912168,_plus14,torepr18);
}};
$e21562157.stack[R.EXN_STACKHEIGHT++] = $ss21602161;
}
if(R.isPyretException($e21562157)) {
$e21562157.pyretStack.push(L[38]);
}
throw $e21562157;
}
var $ret21622163 = $Hanf_arg23512169($z21582159,self1912168,_plus14,torepr18);
++R.GAS;
return $ret21622163;
};
},{"length":1});
var anf_variant_member1021491 = R.makeMethod(function(self2942153) {
return function(printer2952151) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[255],1,arguments);
}
var anf_bracket10032155 = G(self2942153,"func",L[254]);
var anf_fun10042150 = G(anf_bracket10032155,"print-ugly-source",L[253]);
var $z21422143 = D;
var $f21482149 = function(_) {
return R.isFunction(anf_fun10042150)?anf_fun10042150.app(printer2952151):R.ffi.throwNonFunApp(L[252],anf_fun10042150,[printer2952151]);
};
try {
if(--R.GAS > 0) {
$z21422143 = $f21482149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21482149,
"from":L[252]});
}
} catch($e21402141) {
if(R.isCont($e21402141)) {
var $ss21442145 = {"from":L[252],
"go":function(anf_begin_app_dropped23522152) {
return $Hanf_begin_app_dropped23662154(anf_begin_app_dropped23522152,each4361,is_DASH_link2563,printer2952151,self2942153,nothing16);
}};
$e21402141.stack[R.EXN_STACKHEIGHT++] = $ss21442145;
}
if(R.isPyretException($e21402141)) {
$e21402141.pyretStack.push(L[252]);
}
throw $e21402141;
}
var $ret21462147 = $Hanf_begin_app_dropped23662154($z21422143,each4361,is_DASH_link2563,printer2952151,self2942153,nothing16);
++R.GAS;
return $ret21462147;
};
},{"length":2});
var anf_variant_member1041492 = R.makeMethod(function(self2972137) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[251],0,arguments);
}
var anf_fun10232136 = G(PP123,"group",L[250]);
var anf_bracket10242139 = G(self2972137,"func",L[249]);
var anf_fun10252134 = G(anf_bracket10242139,"tosource",L[248]);
var $z21262127 = D;
var $f21322133 = function(_) {
return R.isFunction(anf_fun10252134)?anf_fun10252134.app():R.ffi.throwNonFunApp(L[247],anf_fun10252134,[]);
};
try {
if(--R.GAS > 0) {
$z21262127 = $f21322133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21322133,
"from":L[247]});
}
} catch($e21242125) {
if(R.isCont($e21242125)) {
var $ss21282129 = {"from":L[247],
"go":function(anf_arg10262135) {
return $Hanf_arg23742138(anf_arg10262135,INDENT7747,PP123,anf_fun10232136,self2972137,_plus14);
}};
$e21242125.stack[R.EXN_STACKHEIGHT++] = $ss21282129;
}
if(R.isPyretException($e21242125)) {
$e21242125.pyretStack.push(L[247]);
}
throw $e21242125;
}
var $ret21302131 = $Hanf_arg23742138($z21262127,INDENT7747,PP123,anf_fun10232136,self2972137,_plus14);
++R.GAS;
return $ret21302131;
};
},{"length":1});
var anf_variant_member1055500 = R.makeMethod(function(self1952102) {
return function(cases_DASH_funs1962103,else_DASH_clause1972114) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[37],2,arguments);
}
var if_DASH_1992117 = R.hasField(cases_DASH_funs1962103,("j-method"));
var if_helper10432100 = R.makeFunction(function(if_helper_arg10442122) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[37],1,arguments);
}
var ann_DASH_check_DASH_temp10422123 = if_helper_arg10442122;
return ann_DASH_check_DASH_temp10422123;
});
var anf_if10472121 = R.isBoolean(if_DASH_1992117);
if(R.isPyretTrue(anf_if10472121)) {
if(R.isPyretTrue(if_DASH_1992117)) {
var call_DASH_j_DASH_method1942095 = G(cases_DASH_funs1962103,"j-method",L[37]);
var anf_arg10502096 = G(self1952102,"obj",L[246]);
var anf_arg10512097 = G(self1952102,"meth",L[245]);
var anf_arg10522098 = G(self1952102,"args",L[244]);
var $z20872088 = D;
var $f20932094 = function(_) {
return R.isFunction(call_DASH_j_DASH_method1942095)?call_DASH_j_DASH_method1942095.app(anf_arg10502096,anf_arg10512097,anf_arg10522098):R.ffi.throwNonFunApp(L[37],call_DASH_j_DASH_method1942095,[anf_arg10502096,anf_arg10512097,anf_arg10522098]);
};
try {
if(--R.GAS > 0) {
$z20872088 = $f20932094();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20932094,
"from":L[37]});
}
} catch($e20852086) {
if(R.isCont($e20852086)) {
var $ss20892090 = {"from":L[37],
"go":function(cont_tail_arg10532099) {
return $Hcont_tail_arg23752101(cont_tail_arg10532099,if_helper10432100);
}};
$e20852086.stack[R.EXN_STACKHEIGHT++] = $ss20892090;
}
if(R.isPyretException($e20852086)) {
$e20852086.pyretStack.push(L[37]);
}
throw $e20852086;
}
var $ret20912092 = $Hcont_tail_arg23752101($z20872088,if_helper10432100);
++R.GAS;
return $ret20912092;
} else {
var $z21062107 = D;
var $f21122113 = function(_) {
return R.isFunction(else_DASH_clause1972114)?else_DASH_clause1972114.app():R.ffi.throwNonFunApp(L[37],else_DASH_clause1972114,[]);
};
try {
if(--R.GAS > 0) {
$z21062107 = $f21122113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21122113,
"from":L[37]});
}
} catch($e21042105) {
if(R.isCont($e21042105)) {
var $ss21082109 = {"from":L[37],
"go":function(cont_tail_arg10482115) {
return $Hcont_tail_arg23762116(cont_tail_arg10482115,if_helper10432100);
}};
$e21042105.stack[R.EXN_STACKHEIGHT++] = $ss21082109;
}
if(R.isPyretException($e21042105)) {
$e21042105.pyretStack.push(L[37]);
}
throw $e21042105;
}
var $ret21102111 = $Hcont_tail_arg23762116($z21062107,if_helper10432100);
++R.GAS;
return $ret21102111;
}
} else {
var cont_tail_arg10452120 = R.throwNonBooleanCondition(L[37],("if"),if_DASH_1992117);
if(--R.GAS > 0) {
$z21182119 = R.isFunction(if_helper10432100)?if_helper10432100.app(cont_tail_arg10452120):R.ffi.throwNonFunApp(L[37],if_helper10432100,[cont_tail_arg10452120]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper10432100)?if_helper10432100.app(cont_tail_arg10452120):R.ffi.throwNonFunApp(L[37],if_helper10432100,[cont_tail_arg10452120]);
},
"from":L[37]});
}
++R.GAS;
return $z21182119;
}
};
},{"length":3});
var anf_variant_member1069501 = R.makeMethod(function(self1982083) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[37],0,arguments);
}
var anf_arg10572081 = G(self1982083,"obj",L[37]);
var $z20732074 = D;
var $f20792080 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg10572081):R.ffi.throwNonFunApp(L[37],torepr18,[anf_arg10572081]);
};
try {
if(--R.GAS > 0) {
$z20732074 = $f20792080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20792080,
"from":L[37]});
}
} catch($e20712072) {
if(R.isCont($e20712072)) {
var $ss20752076 = {"from":L[37],
"go":function(anf_arg10582082) {
return $Hanf_arg23862084(anf_arg10582082,self1982083,_plus14,torepr18);
}};
$e20712072.stack[R.EXN_STACKHEIGHT++] = $ss20752076;
}
if(R.isPyretException($e20712072)) {
$e20712072.pyretStack.push(L[37]);
}
throw $e20712072;
}
var $ret20772078 = $Hanf_arg23862084($z20732074,self1982083,_plus14,torepr18);
++R.GAS;
return $ret20772078;
};
},{"length":1});
var anf_variant_member1090502 = R.makeMethod(function(self302760) {
return function(printer3032067) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[243],1,arguments);
}
var anf_bracket10712070 = G(self302760,"obj",L[242]);
var anf_fun10722066 = G(anf_bracket10712070,"print-ugly-source",L[241]);
var $z20582059 = D;
var $f20642065 = function(_) {
return R.isFunction(anf_fun10722066)?anf_fun10722066.app(printer3032067):R.ffi.throwNonFunApp(L[240],anf_fun10722066,[printer3032067]);
};
try {
if(--R.GAS > 0) {
$z20582059 = $f20642065();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20642065,
"from":L[240]});
}
} catch($e20562057) {
if(R.isCont($e20562057)) {
var $ss20602061 = {"from":L[240],
"go":function(anf_begin_app_dropped23872068) {
return $Hanf_begin_app_dropped24052069(anf_begin_app_dropped23872068,each4361,is_DASH_link2563,printer3032067,self302760,nothing16);
}};
$e20562057.stack[R.EXN_STACKHEIGHT++] = $ss20602061;
}
if(R.isPyretException($e20562057)) {
$e20562057.pyretStack.push(L[240]);
}
throw $e20562057;
}
var $ret20622063 = $Hanf_begin_app_dropped24052069($z20582059,each4361,is_DASH_link2563,printer3032067,self302760,nothing16);
++R.GAS;
return $ret20622063;
};
},{"length":2});
var anf_variant_member1117503 = R.makeMethod(function(self305741) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[239],0,arguments);
}
var anf_fun10922053 = G(PP123,"group",L[238]);
var anf_fun10932054 = G(PP123,"infix",L[237]);
var anf_fun10942051 = G(PP123,"str",L[236]);
var $z20432044 = D;
var $f20492050 = function(_) {
return R.isFunction(anf_fun10942051)?anf_fun10942051.app((".")):R.ffi.throwNonFunApp(L[235],anf_fun10942051,[(".")]);
};
try {
if(--R.GAS > 0) {
$z20432044 = $f20492050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20492050,
"from":L[235]});
}
} catch($e20412042) {
if(R.isCont($e20412042)) {
var $ss20452046 = {"from":L[235],
"go":function(anf_arg10952052) {
return $Hanf_arg24162055(anf_arg10952052,INDENT7747,PP123,anf_fun10922053,anf_fun10932054,self305741,_plus14);
}};
$e20412042.stack[R.EXN_STACKHEIGHT++] = $ss20452046;
}
if(R.isPyretException($e20412042)) {
$e20412042.pyretStack.push(L[235]);
}
throw $e20412042;
}
var $ret20472048 = $Hanf_arg24162055($z20432044,INDENT7747,PP123,anf_fun10922053,anf_fun10932054,self305741,_plus14);
++R.GAS;
return $ret20472048;
};
},{"length":1});
var anf_variant_member1131512 = R.makeMethod(function(self2022019) {
return function(cases_DASH_funs2032020,else_DASH_clause2042031) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[36],2,arguments);
}
var if_DASH_2062034 = R.hasField(cases_DASH_funs2032020,("j-ternary"));
var if_helper11192017 = R.makeFunction(function(if_helper_arg11202039) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[36],1,arguments);
}
var ann_DASH_check_DASH_temp11182040 = if_helper_arg11202039;
return ann_DASH_check_DASH_temp11182040;
});
var anf_if11232038 = R.isBoolean(if_DASH_2062034);
if(R.isPyretTrue(anf_if11232038)) {
if(R.isPyretTrue(if_DASH_2062034)) {
var call_DASH_j_DASH_ternary2012012 = G(cases_DASH_funs2032020,"j-ternary",L[36]);
var anf_arg11262013 = G(self2022019,"test",L[234]);
var anf_arg11272014 = G(self2022019,"consq",L[233]);
var anf_arg11282015 = G(self2022019,"altern",L[232]);
var $z20042005 = D;
var $f20102011 = function(_) {
return R.isFunction(call_DASH_j_DASH_ternary2012012)?call_DASH_j_DASH_ternary2012012.app(anf_arg11262013,anf_arg11272014,anf_arg11282015):R.ffi.throwNonFunApp(L[36],call_DASH_j_DASH_ternary2012012,[anf_arg11262013,anf_arg11272014,anf_arg11282015]);
};
try {
if(--R.GAS > 0) {
$z20042005 = $f20102011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20102011,
"from":L[36]});
}
} catch($e20022003) {
if(R.isCont($e20022003)) {
var $ss20062007 = {"from":L[36],
"go":function(cont_tail_arg11292016) {
return $Hcont_tail_arg24172018(cont_tail_arg11292016,if_helper11192017);
}};
$e20022003.stack[R.EXN_STACKHEIGHT++] = $ss20062007;
}
if(R.isPyretException($e20022003)) {
$e20022003.pyretStack.push(L[36]);
}
throw $e20022003;
}
var $ret20082009 = $Hcont_tail_arg24172018($z20042005,if_helper11192017);
++R.GAS;
return $ret20082009;
} else {
var $z20232024 = D;
var $f20292030 = function(_) {
return R.isFunction(else_DASH_clause2042031)?else_DASH_clause2042031.app():R.ffi.throwNonFunApp(L[36],else_DASH_clause2042031,[]);
};
try {
if(--R.GAS > 0) {
$z20232024 = $f20292030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20292030,
"from":L[36]});
}
} catch($e20212022) {
if(R.isCont($e20212022)) {
var $ss20252026 = {"from":L[36],
"go":function(cont_tail_arg11242032) {
return $Hcont_tail_arg24182033(cont_tail_arg11242032,if_helper11192017);
}};
$e20212022.stack[R.EXN_STACKHEIGHT++] = $ss20252026;
}
if(R.isPyretException($e20212022)) {
$e20212022.pyretStack.push(L[36]);
}
throw $e20212022;
}
var $ret20272028 = $Hcont_tail_arg24182033($z20232024,if_helper11192017);
++R.GAS;
return $ret20272028;
}
} else {
var cont_tail_arg11212037 = R.throwNonBooleanCondition(L[36],("if"),if_DASH_2062034);
if(--R.GAS > 0) {
$z20352036 = R.isFunction(if_helper11192017)?if_helper11192017.app(cont_tail_arg11212037):R.ffi.throwNonFunApp(L[36],if_helper11192017,[cont_tail_arg11212037]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper11192017)?if_helper11192017.app(cont_tail_arg11212037):R.ffi.throwNonFunApp(L[36],if_helper11192017,[cont_tail_arg11212037]);
},
"from":L[36]});
}
++R.GAS;
return $z20352036;
}
};
},{"length":3});
var anf_variant_member1145513 = R.makeMethod(function(self2052000) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[36],0,arguments);
}
var anf_arg11331998 = G(self2052000,"test",L[36]);
var $z19901991 = D;
var $f19961997 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg11331998):R.ffi.throwNonFunApp(L[36],torepr18,[anf_arg11331998]);
};
try {
if(--R.GAS > 0) {
$z19901991 = $f19961997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19961997,
"from":L[36]});
}
} catch($e19881989) {
if(R.isCont($e19881989)) {
var $ss19921993 = {"from":L[36],
"go":function(anf_arg11341999) {
return $Hanf_arg24282001(anf_arg11341999,self2052000,_plus14,torepr18);
}};
$e19881989.stack[R.EXN_STACKHEIGHT++] = $ss19921993;
}
if(R.isPyretException($e19881989)) {
$e19881989.pyretStack.push(L[36]);
}
throw $e19881989;
}
var $ret19941995 = $Hanf_arg24282001($z19901991,self2052000,_plus14,torepr18);
++R.GAS;
return $ret19941995;
};
},{"length":1});
var anf_variant_member1153514 = R.makeMethod(function(self3101985) {
return function(printer3111983) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[231],1,arguments);
}
var anf_bracket11471987 = G(self3101985,"test",L[230]);
var anf_fun11481982 = G(anf_bracket11471987,"print-ugly-source",L[229]);
var $z19741975 = D;
var $f19801981 = function(_) {
return R.isFunction(anf_fun11481982)?anf_fun11481982.app(printer3111983):R.ffi.throwNonFunApp(L[228],anf_fun11481982,[printer3111983]);
};
try {
if(--R.GAS > 0) {
$z19741975 = $f19801981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19801981,
"from":L[228]});
}
} catch($e19721973) {
if(R.isCont($e19721973)) {
var $ss19761977 = {"from":L[228],
"go":function(anf_begin_app_dropped24291984) {
return $Hanf_begin_app_dropped24371986(anf_begin_app_dropped24291984,printer3111983,self3101985);
}};
$e19721973.stack[R.EXN_STACKHEIGHT++] = $ss19761977;
}
if(R.isPyretException($e19721973)) {
$e19721973.pyretStack.push(L[228]);
}
throw $e19721973;
}
var $ret19781979 = $Hanf_begin_app_dropped24371986($z19741975,printer3111983,self3101985);
++R.GAS;
return $ret19781979;
};
},{"length":2});
var anf_variant_member1185515 = R.makeMethod(function(self3121969) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[227],0,arguments);
}
var anf_fun11551968 = G(PP123,"parens",L[226]);
var anf_bracket11561971 = G(self3121969,"test",L[225]);
var anf_fun11571966 = G(anf_bracket11561971,"tosource",L[224]);
var $z19581959 = D;
var $f19641965 = function(_) {
return R.isFunction(anf_fun11571966)?anf_fun11571966.app():R.ffi.throwNonFunApp(L[223],anf_fun11571966,[]);
};
try {
if(--R.GAS > 0) {
$z19581959 = $f19641965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19641965,
"from":L[223]});
}
} catch($e19561957) {
if(R.isCont($e19561957)) {
var $ss19601961 = {"from":L[223],
"go":function(anf_arg11581967) {
return $Hanf_arg24551970(anf_arg11581967,INDENT7747,PP123,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e19561957.stack[R.EXN_STACKHEIGHT++] = $ss19601961;
}
if(R.isPyretException($e19561957)) {
$e19561957.pyretStack.push(L[223]);
}
throw $e19561957;
}
var $ret19621963 = $Hanf_arg24551970($z19581959,INDENT7747,PP123,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret19621963;
};
},{"length":1});
var anf_variant_member1198524 = R.makeMethod(function(self2081934) {
return function(cases_DASH_funs2091935,else_DASH_clause2101946) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[35],2,arguments);
}
var if_DASH_2121949 = R.hasField(cases_DASH_funs2091935,("j-assign"));
var if_helper11871932 = R.makeFunction(function(if_helper_arg11881954) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[35],1,arguments);
}
var ann_DASH_check_DASH_temp11861955 = if_helper_arg11881954;
return ann_DASH_check_DASH_temp11861955;
});
var anf_if11911953 = R.isBoolean(if_DASH_2121949);
if(R.isPyretTrue(anf_if11911953)) {
if(R.isPyretTrue(if_DASH_2121949)) {
var call_DASH_j_DASH_assign2071928 = G(cases_DASH_funs2091935,"j-assign",L[35]);
var anf_arg11941929 = G(self2081934,"name",L[222]);
var anf_arg11951930 = G(self2081934,"rhs",L[221]);
var $z19201921 = D;
var $f19261927 = function(_) {
return R.isFunction(call_DASH_j_DASH_assign2071928)?call_DASH_j_DASH_assign2071928.app(anf_arg11941929,anf_arg11951930):R.ffi.throwNonFunApp(L[35],call_DASH_j_DASH_assign2071928,[anf_arg11941929,anf_arg11951930]);
};
try {
if(--R.GAS > 0) {
$z19201921 = $f19261927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19261927,
"from":L[35]});
}
} catch($e19181919) {
if(R.isCont($e19181919)) {
var $ss19221923 = {"from":L[35],
"go":function(cont_tail_arg11961931) {
return $Hcont_tail_arg24561933(cont_tail_arg11961931,if_helper11871932);
}};
$e19181919.stack[R.EXN_STACKHEIGHT++] = $ss19221923;
}
if(R.isPyretException($e19181919)) {
$e19181919.pyretStack.push(L[35]);
}
throw $e19181919;
}
var $ret19241925 = $Hcont_tail_arg24561933($z19201921,if_helper11871932);
++R.GAS;
return $ret19241925;
} else {
var $z19381939 = D;
var $f19441945 = function(_) {
return R.isFunction(else_DASH_clause2101946)?else_DASH_clause2101946.app():R.ffi.throwNonFunApp(L[35],else_DASH_clause2101946,[]);
};
try {
if(--R.GAS > 0) {
$z19381939 = $f19441945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19441945,
"from":L[35]});
}
} catch($e19361937) {
if(R.isCont($e19361937)) {
var $ss19401941 = {"from":L[35],
"go":function(cont_tail_arg11921947) {
return $Hcont_tail_arg24571948(cont_tail_arg11921947,if_helper11871932);
}};
$e19361937.stack[R.EXN_STACKHEIGHT++] = $ss19401941;
}
if(R.isPyretException($e19361937)) {
$e19361937.pyretStack.push(L[35]);
}
throw $e19361937;
}
var $ret19421943 = $Hcont_tail_arg24571948($z19381939,if_helper11871932);
++R.GAS;
return $ret19421943;
}
} else {
var cont_tail_arg11891952 = R.throwNonBooleanCondition(L[35],("if"),if_DASH_2121949);
if(--R.GAS > 0) {
$z19501951 = R.isFunction(if_helper11871932)?if_helper11871932.app(cont_tail_arg11891952):R.ffi.throwNonFunApp(L[35],if_helper11871932,[cont_tail_arg11891952]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper11871932)?if_helper11871932.app(cont_tail_arg11891952):R.ffi.throwNonFunApp(L[35],if_helper11871932,[cont_tail_arg11891952]);
},
"from":L[35]});
}
++R.GAS;
return $z19501951;
}
};
},{"length":3});
var anf_variant_member1208525 = R.makeMethod(function(self2111916) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[35],0,arguments);
}
var anf_arg12001914 = G(self2111916,"name",L[35]);
var $z19061907 = D;
var $f19121913 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg12001914):R.ffi.throwNonFunApp(L[35],torepr18,[anf_arg12001914]);
};
try {
if(--R.GAS > 0) {
$z19061907 = $f19121913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19121913,
"from":L[35]});
}
} catch($e19041905) {
if(R.isCont($e19041905)) {
var $ss19081909 = {"from":L[35],
"go":function(anf_arg12011915) {
return $Hanf_arg24641917(anf_arg12011915,self2111916,_plus14,torepr18);
}};
$e19041905.stack[R.EXN_STACKHEIGHT++] = $ss19081909;
}
if(R.isPyretException($e19041905)) {
$e19041905.pyretStack.push(L[35]);
}
throw $e19041905;
}
var $ret19101911 = $Hanf_arg24641917($z19061907,self2111916,_plus14,torepr18);
++R.GAS;
return $ret19101911;
};
},{"length":1});
var anf_variant_member1213526 = R.makeMethod(function(self3151902) {
return function(printer3161899) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[220],1,arguments);
}
var anf_arg12101900 = G(self3151902,"name",L[219]);
var $z18911892 = D;
var $f18971898 = function(_) {
return R.isFunction(printer3161899)?printer3161899.app(anf_arg12101900):R.ffi.throwNonFunApp(L[218],printer3161899,[anf_arg12101900]);
};
try {
if(--R.GAS > 0) {
$z18911892 = $f18971898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18971898,
"from":L[218]});
}
} catch($e18891890) {
if(R.isCont($e18891890)) {
var $ss18931894 = {"from":L[218],
"go":function(anf_begin_app_dropped24651901) {
return $Hanf_begin_app_dropped24691903(anf_begin_app_dropped24651901,printer3161899,self3151902);
}};
$e18891890.stack[R.EXN_STACKHEIGHT++] = $ss18931894;
}
if(R.isPyretException($e18891890)) {
$e18891890.pyretStack.push(L[218]);
}
throw $e18891890;
}
var $ret18951896 = $Hanf_begin_app_dropped24691903($z18911892,printer3161899,self3151902);
++R.GAS;
return $ret18951896;
};
},{"length":2});
var anf_variant_member1229527 = R.makeMethod(function(self3171887) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[217],0,arguments);
}
var anf_fun12151885 = G(PP123,"group",L[216]);
var anf_fun12161886 = G(PP123,"nest",L[215]);
var anf_fun12171882 = G(PP123,"str",L[214]);
var anf_arg12181883 = G(self3171887,"name",L[213]);
var $z18741875 = D;
var $f18801881 = function(_) {
return R.isFunction(anf_fun12171882)?anf_fun12171882.app(anf_arg12181883):R.ffi.throwNonFunApp(L[212],anf_fun12171882,[anf_arg12181883]);
};
try {
if(--R.GAS > 0) {
$z18741875 = $f18801881();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18801881,
"from":L[212]});
}
} catch($e18721873) {
if(R.isCont($e18721873)) {
var $ss18761877 = {"from":L[212],
"go":function(anf_arg12191884) {
return $Hanf_arg24771888(anf_arg12191884,INDENT7747,PP123,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14);
}};
$e18721873.stack[R.EXN_STACKHEIGHT++] = $ss18761877;
}
if(R.isPyretException($e18721873)) {
$e18721873.pyretStack.push(L[212]);
}
throw $e18721873;
}
var $ret18781879 = $Hanf_arg24771888($z18741875,INDENT7747,PP123,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14);
++R.GAS;
return $ret18781879;
};
},{"length":1});
var anf_variant_member1243535 = R.makeMethod(function(self2141850) {
return function(cases_DASH_funs2151851,else_DASH_clause2161862) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[34],2,arguments);
}
var if_DASH_2181865 = R.hasField(cases_DASH_funs2151851,("j-bracket-assign"));
var if_helper12311848 = R.makeFunction(function(if_helper_arg12321870) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[34],1,arguments);
}
var ann_DASH_check_DASH_temp12301871 = if_helper_arg12321870;
return ann_DASH_check_DASH_temp12301871;
});
var anf_if12351869 = R.isBoolean(if_DASH_2181865);
if(R.isPyretTrue(anf_if12351869)) {
if(R.isPyretTrue(if_DASH_2181865)) {
var call_DASH_j_DASH_bracket_DASH_assign2131843 = G(cases_DASH_funs2151851,"j-bracket-assign",L[34]);
var anf_arg12381844 = G(self2141850,"obj",L[211]);
var anf_arg12391845 = G(self2141850,"field",L[210]);
var anf_arg12401846 = G(self2141850,"rhs",L[209]);
var $z18351836 = D;
var $f18411842 = function(_) {
return R.isFunction(call_DASH_j_DASH_bracket_DASH_assign2131843)?call_DASH_j_DASH_bracket_DASH_assign2131843.app(anf_arg12381844,anf_arg12391845,anf_arg12401846):R.ffi.throwNonFunApp(L[34],call_DASH_j_DASH_bracket_DASH_assign2131843,[anf_arg12381844,anf_arg12391845,anf_arg12401846]);
};
try {
if(--R.GAS > 0) {
$z18351836 = $f18411842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18411842,
"from":L[34]});
}
} catch($e18331834) {
if(R.isCont($e18331834)) {
var $ss18371838 = {"from":L[34],
"go":function(cont_tail_arg12411847) {
return $Hcont_tail_arg24781849(cont_tail_arg12411847,if_helper12311848);
}};
$e18331834.stack[R.EXN_STACKHEIGHT++] = $ss18371838;
}
if(R.isPyretException($e18331834)) {
$e18331834.pyretStack.push(L[34]);
}
throw $e18331834;
}
var $ret18391840 = $Hcont_tail_arg24781849($z18351836,if_helper12311848);
++R.GAS;
return $ret18391840;
} else {
var $z18541855 = D;
var $f18601861 = function(_) {
return R.isFunction(else_DASH_clause2161862)?else_DASH_clause2161862.app():R.ffi.throwNonFunApp(L[34],else_DASH_clause2161862,[]);
};
try {
if(--R.GAS > 0) {
$z18541855 = $f18601861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18601861,
"from":L[34]});
}
} catch($e18521853) {
if(R.isCont($e18521853)) {
var $ss18561857 = {"from":L[34],
"go":function(cont_tail_arg12361863) {
return $Hcont_tail_arg24791864(cont_tail_arg12361863,if_helper12311848);
}};
$e18521853.stack[R.EXN_STACKHEIGHT++] = $ss18561857;
}
if(R.isPyretException($e18521853)) {
$e18521853.pyretStack.push(L[34]);
}
throw $e18521853;
}
var $ret18581859 = $Hcont_tail_arg24791864($z18541855,if_helper12311848);
++R.GAS;
return $ret18581859;
}
} else {
var cont_tail_arg12331868 = R.throwNonBooleanCondition(L[34],("if"),if_DASH_2181865);
if(--R.GAS > 0) {
$z18661867 = R.isFunction(if_helper12311848)?if_helper12311848.app(cont_tail_arg12331868):R.ffi.throwNonFunApp(L[34],if_helper12311848,[cont_tail_arg12331868]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper12311848)?if_helper12311848.app(cont_tail_arg12331868):R.ffi.throwNonFunApp(L[34],if_helper12311848,[cont_tail_arg12331868]);
},
"from":L[34]});
}
++R.GAS;
return $z18661867;
}
};
},{"length":3});
var anf_variant_member1257536 = R.makeMethod(function(self2171831) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[34],0,arguments);
}
var anf_arg12451829 = G(self2171831,"obj",L[34]);
var $z18211822 = D;
var $f18271828 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg12451829):R.ffi.throwNonFunApp(L[34],torepr18,[anf_arg12451829]);
};
try {
if(--R.GAS > 0) {
$z18211822 = $f18271828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18271828,
"from":L[34]});
}
} catch($e18191820) {
if(R.isCont($e18191820)) {
var $ss18231824 = {"from":L[34],
"go":function(anf_arg12461830) {
return $Hanf_arg24891832(anf_arg12461830,self2171831,_plus14,torepr18);
}};
$e18191820.stack[R.EXN_STACKHEIGHT++] = $ss18231824;
}
if(R.isPyretException($e18191820)) {
$e18191820.pyretStack.push(L[34]);
}
throw $e18191820;
}
var $ret18251826 = $Hanf_arg24891832($z18211822,self2171831,_plus14,torepr18);
++R.GAS;
return $ret18251826;
};
},{"length":1});
var anf_variant_member1265537 = R.makeMethod(function(self3211816) {
return function(printer3221814) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[208],1,arguments);
}
var anf_bracket12591818 = G(self3211816,"obj",L[207]);
var anf_fun12601813 = G(anf_bracket12591818,"print-ugly-source",L[206]);
var $z18051806 = D;
var $f18111812 = function(_) {
return R.isFunction(anf_fun12601813)?anf_fun12601813.app(printer3221814):R.ffi.throwNonFunApp(L[205],anf_fun12601813,[printer3221814]);
};
try {
if(--R.GAS > 0) {
$z18051806 = $f18111812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18111812,
"from":L[205]});
}
} catch($e18031804) {
if(R.isCont($e18031804)) {
var $ss18071808 = {"from":L[205],
"go":function(anf_begin_app_dropped24901815) {
return $Hanf_begin_app_dropped25001817(anf_begin_app_dropped24901815,printer3221814,self3211816);
}};
$e18031804.stack[R.EXN_STACKHEIGHT++] = $ss18071808;
}
if(R.isPyretException($e18031804)) {
$e18031804.pyretStack.push(L[205]);
}
throw $e18031804;
}
var $ret18091810 = $Hanf_begin_app_dropped25001817($z18051806,printer3221814,self3211816);
++R.GAS;
return $ret18091810;
};
},{"length":2});
var anf_variant_member1289538 = R.makeMethod(function(self3231800) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[204],0,arguments);
}
var anf_fun12671798 = G(PP123,"group",L[203]);
var anf_fun12681799 = G(PP123,"nest",L[202]);
var anf_bracket12691802 = G(self3231800,"obj",L[201]);
var anf_fun12701796 = G(anf_bracket12691802,"tosource",L[200]);
var $z17881789 = D;
var $f17941795 = function(_) {
return R.isFunction(anf_fun12701796)?anf_fun12701796.app():R.ffi.throwNonFunApp(L[199],anf_fun12701796,[]);
};
try {
if(--R.GAS > 0) {
$z17881789 = $f17941795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17941795,
"from":L[199]});
}
} catch($e17861787) {
if(R.isCont($e17861787)) {
var $ss17901791 = {"from":L[199],
"go":function(anf_arg12711797) {
return $Hanf_arg25121801(anf_arg12711797,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
}};
$e17861787.stack[R.EXN_STACKHEIGHT++] = $ss17901791;
}
if(R.isPyretException($e17861787)) {
$e17861787.pyretStack.push(L[199]);
}
throw $e17861787;
}
var $ret17921793 = $Hanf_arg25121801($z17881789,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
++R.GAS;
return $ret17921793;
};
},{"length":1});
var anf_variant_member1303547 = R.makeMethod(function(self2201764) {
return function(cases_DASH_funs2211765,else_DASH_clause2221776) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[33],2,arguments);
}
var if_DASH_2241779 = R.hasField(cases_DASH_funs2211765,("j-dot-assign"));
var if_helper12911762 = R.makeFunction(function(if_helper_arg12921784) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[33],1,arguments);
}
var ann_DASH_check_DASH_temp12901785 = if_helper_arg12921784;
return ann_DASH_check_DASH_temp12901785;
});
var anf_if12951783 = R.isBoolean(if_DASH_2241779);
if(R.isPyretTrue(anf_if12951783)) {
if(R.isPyretTrue(if_DASH_2241779)) {
var call_DASH_j_DASH_dot_DASH_assign2191757 = G(cases_DASH_funs2211765,"j-dot-assign",L[33]);
var anf_arg12981758 = G(self2201764,"obj",L[198]);
var anf_arg12991759 = G(self2201764,"name",L[197]);
var anf_arg13001760 = G(self2201764,"rhs",L[196]);
var $z17491750 = D;
var $f17551756 = function(_) {
return R.isFunction(call_DASH_j_DASH_dot_DASH_assign2191757)?call_DASH_j_DASH_dot_DASH_assign2191757.app(anf_arg12981758,anf_arg12991759,anf_arg13001760):R.ffi.throwNonFunApp(L[33],call_DASH_j_DASH_dot_DASH_assign2191757,[anf_arg12981758,anf_arg12991759,anf_arg13001760]);
};
try {
if(--R.GAS > 0) {
$z17491750 = $f17551756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17551756,
"from":L[33]});
}
} catch($e17471748) {
if(R.isCont($e17471748)) {
var $ss17511752 = {"from":L[33],
"go":function(cont_tail_arg13011761) {
return $Hcont_tail_arg25131763(cont_tail_arg13011761,if_helper12911762);
}};
$e17471748.stack[R.EXN_STACKHEIGHT++] = $ss17511752;
}
if(R.isPyretException($e17471748)) {
$e17471748.pyretStack.push(L[33]);
}
throw $e17471748;
}
var $ret17531754 = $Hcont_tail_arg25131763($z17491750,if_helper12911762);
++R.GAS;
return $ret17531754;
} else {
var $z17681769 = D;
var $f17741775 = function(_) {
return R.isFunction(else_DASH_clause2221776)?else_DASH_clause2221776.app():R.ffi.throwNonFunApp(L[33],else_DASH_clause2221776,[]);
};
try {
if(--R.GAS > 0) {
$z17681769 = $f17741775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17741775,
"from":L[33]});
}
} catch($e17661767) {
if(R.isCont($e17661767)) {
var $ss17701771 = {"from":L[33],
"go":function(cont_tail_arg12961777) {
return $Hcont_tail_arg25141778(cont_tail_arg12961777,if_helper12911762);
}};
$e17661767.stack[R.EXN_STACKHEIGHT++] = $ss17701771;
}
if(R.isPyretException($e17661767)) {
$e17661767.pyretStack.push(L[33]);
}
throw $e17661767;
}
var $ret17721773 = $Hcont_tail_arg25141778($z17681769,if_helper12911762);
++R.GAS;
return $ret17721773;
}
} else {
var cont_tail_arg12931782 = R.throwNonBooleanCondition(L[33],("if"),if_DASH_2241779);
if(--R.GAS > 0) {
$z17801781 = R.isFunction(if_helper12911762)?if_helper12911762.app(cont_tail_arg12931782):R.ffi.throwNonFunApp(L[33],if_helper12911762,[cont_tail_arg12931782]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper12911762)?if_helper12911762.app(cont_tail_arg12931782):R.ffi.throwNonFunApp(L[33],if_helper12911762,[cont_tail_arg12931782]);
},
"from":L[33]});
}
++R.GAS;
return $z17801781;
}
};
},{"length":3});
var anf_variant_member1317548 = R.makeMethod(function(self2231745) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[33],0,arguments);
}
var anf_arg13051743 = G(self2231745,"obj",L[33]);
var $z17351736 = D;
var $f17411742 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg13051743):R.ffi.throwNonFunApp(L[33],torepr18,[anf_arg13051743]);
};
try {
if(--R.GAS > 0) {
$z17351736 = $f17411742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17411742,
"from":L[33]});
}
} catch($e17331734) {
if(R.isCont($e17331734)) {
var $ss17371738 = {"from":L[33],
"go":function(anf_arg13061744) {
return $Hanf_arg25241746(anf_arg13061744,self2231745,_plus14,torepr18);
}};
$e17331734.stack[R.EXN_STACKHEIGHT++] = $ss17371738;
}
if(R.isPyretException($e17331734)) {
$e17331734.pyretStack.push(L[33]);
}
throw $e17331734;
}
var $ret17391740 = $Hanf_arg25241746($z17351736,self2231745,_plus14,torepr18);
++R.GAS;
return $ret17391740;
};
},{"length":1});
var anf_variant_member1324549 = R.makeMethod(function(self3271730) {
return function(printer3281728) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[195],1,arguments);
}
var anf_bracket13191732 = G(self3271730,"obj",L[194]);
var anf_fun13201727 = G(anf_bracket13191732,"print-ugly-source",L[193]);
var $z17191720 = D;
var $f17251726 = function(_) {
return R.isFunction(anf_fun13201727)?anf_fun13201727.app(printer3281728):R.ffi.throwNonFunApp(L[192],anf_fun13201727,[printer3281728]);
};
try {
if(--R.GAS > 0) {
$z17191720 = $f17251726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17251726,
"from":L[192]});
}
} catch($e17171718) {
if(R.isCont($e17171718)) {
var $ss17211722 = {"from":L[192],
"go":function(anf_begin_app_dropped25251729) {
return $Hanf_begin_app_dropped25331731(anf_begin_app_dropped25251729,printer3281728,self3271730);
}};
$e17171718.stack[R.EXN_STACKHEIGHT++] = $ss17211722;
}
if(R.isPyretException($e17171718)) {
$e17171718.pyretStack.push(L[192]);
}
throw $e17171718;
}
var $ret17231724 = $Hanf_begin_app_dropped25331731($z17191720,printer3281728,self3271730);
++R.GAS;
return $ret17231724;
};
},{"length":2});
var anf_variant_member1347550 = R.makeMethod(function(self3291715) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[191],0,arguments);
}
var anf_fun13261712 = G(PP123,"group",L[190]);
var anf_fun13271713 = G(PP123,"nest",L[189]);
var anf_fun13281714 = G(PP123,"infix",L[188]);
var anf_fun13291710 = G(PP123,"str",L[187]);
var $z17021703 = D;
var $f17081709 = function(_) {
return R.isFunction(anf_fun13291710)?anf_fun13291710.app((".")):R.ffi.throwNonFunApp(L[186],anf_fun13291710,[(".")]);
};
try {
if(--R.GAS > 0) {
$z17021703 = $f17081709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17081709,
"from":L[186]});
}
} catch($e17001701) {
if(R.isCont($e17001701)) {
var $ss17041705 = {"from":L[186],
"go":function(anf_arg13301711) {
return $Hanf_arg25441716(anf_arg13301711,INDENT7747,PP123,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14);
}};
$e17001701.stack[R.EXN_STACKHEIGHT++] = $ss17041705;
}
if(R.isPyretException($e17001701)) {
$e17001701.pyretStack.push(L[186]);
}
throw $e17001701;
}
var $ret17061707 = $Hanf_arg25441716($z17021703,INDENT7747,PP123,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14);
++R.GAS;
return $ret17061707;
};
},{"length":1});
var anf_variant_member1360559 = R.makeMethod(function(self2261678) {
return function(cases_DASH_funs2271679,else_DASH_clause2281690) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[32],2,arguments);
}
var if_DASH_2301693 = R.hasField(cases_DASH_funs2271679,("j-dot"));
var if_helper13491676 = R.makeFunction(function(if_helper_arg13501698) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[32],1,arguments);
}
var ann_DASH_check_DASH_temp13481699 = if_helper_arg13501698;
return ann_DASH_check_DASH_temp13481699;
});
var anf_if13531697 = R.isBoolean(if_DASH_2301693);
if(R.isPyretTrue(anf_if13531697)) {
if(R.isPyretTrue(if_DASH_2301693)) {
var call_DASH_j_DASH_dot2251672 = G(cases_DASH_funs2271679,"j-dot",L[32]);
var anf_arg13561673 = G(self2261678,"obj",L[185]);
var anf_arg13571674 = G(self2261678,"field",L[184]);
var $z16641665 = D;
var $f16701671 = function(_) {
return R.isFunction(call_DASH_j_DASH_dot2251672)?call_DASH_j_DASH_dot2251672.app(anf_arg13561673,anf_arg13571674):R.ffi.throwNonFunApp(L[32],call_DASH_j_DASH_dot2251672,[anf_arg13561673,anf_arg13571674]);
};
try {
if(--R.GAS > 0) {
$z16641665 = $f16701671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16701671,
"from":L[32]});
}
} catch($e16621663) {
if(R.isCont($e16621663)) {
var $ss16661667 = {"from":L[32],
"go":function(cont_tail_arg13581675) {
return $Hcont_tail_arg25451677(cont_tail_arg13581675,if_helper13491676);
}};
$e16621663.stack[R.EXN_STACKHEIGHT++] = $ss16661667;
}
if(R.isPyretException($e16621663)) {
$e16621663.pyretStack.push(L[32]);
}
throw $e16621663;
}
var $ret16681669 = $Hcont_tail_arg25451677($z16641665,if_helper13491676);
++R.GAS;
return $ret16681669;
} else {
var $z16821683 = D;
var $f16881689 = function(_) {
return R.isFunction(else_DASH_clause2281690)?else_DASH_clause2281690.app():R.ffi.throwNonFunApp(L[32],else_DASH_clause2281690,[]);
};
try {
if(--R.GAS > 0) {
$z16821683 = $f16881689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16881689,
"from":L[32]});
}
} catch($e16801681) {
if(R.isCont($e16801681)) {
var $ss16841685 = {"from":L[32],
"go":function(cont_tail_arg13541691) {
return $Hcont_tail_arg25461692(cont_tail_arg13541691,if_helper13491676);
}};
$e16801681.stack[R.EXN_STACKHEIGHT++] = $ss16841685;
}
if(R.isPyretException($e16801681)) {
$e16801681.pyretStack.push(L[32]);
}
throw $e16801681;
}
var $ret16861687 = $Hcont_tail_arg25461692($z16821683,if_helper13491676);
++R.GAS;
return $ret16861687;
}
} else {
var cont_tail_arg13511696 = R.throwNonBooleanCondition(L[32],("if"),if_DASH_2301693);
if(--R.GAS > 0) {
$z16941695 = R.isFunction(if_helper13491676)?if_helper13491676.app(cont_tail_arg13511696):R.ffi.throwNonFunApp(L[32],if_helper13491676,[cont_tail_arg13511696]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper13491676)?if_helper13491676.app(cont_tail_arg13511696):R.ffi.throwNonFunApp(L[32],if_helper13491676,[cont_tail_arg13511696]);
},
"from":L[32]});
}
++R.GAS;
return $z16941695;
}
};
},{"length":3});
var anf_variant_member1370560 = R.makeMethod(function(self2291660) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[32],0,arguments);
}
var anf_arg13621658 = G(self2291660,"obj",L[32]);
var $z16501651 = D;
var $f16561657 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg13621658):R.ffi.throwNonFunApp(L[32],torepr18,[anf_arg13621658]);
};
try {
if(--R.GAS > 0) {
$z16501651 = $f16561657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16561657,
"from":L[32]});
}
} catch($e16481649) {
if(R.isCont($e16481649)) {
var $ss16521653 = {"from":L[32],
"go":function(anf_arg13631659) {
return $Hanf_arg25531661(anf_arg13631659,self2291660,_plus14,torepr18);
}};
$e16481649.stack[R.EXN_STACKHEIGHT++] = $ss16521653;
}
if(R.isPyretException($e16481649)) {
$e16481649.pyretStack.push(L[32]);
}
throw $e16481649;
}
var $ret16541655 = $Hanf_arg25531661($z16501651,self2291660,_plus14,torepr18);
++R.GAS;
return $ret16541655;
};
},{"length":1});
var anf_variant_member1375561 = R.makeMethod(function(self3321645) {
return function(printer3331643) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[183],1,arguments);
}
var anf_bracket13721647 = G(self3321645,"obj",L[182]);
var anf_fun13731642 = G(anf_bracket13721647,"print-ugly-source",L[181]);
var $z16341635 = D;
var $f16401641 = function(_) {
return R.isFunction(anf_fun13731642)?anf_fun13731642.app(printer3331643):R.ffi.throwNonFunApp(L[180],anf_fun13731642,[printer3331643]);
};
try {
if(--R.GAS > 0) {
$z16341635 = $f16401641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16401641,
"from":L[180]});
}
} catch($e16321633) {
if(R.isCont($e16321633)) {
var $ss16361637 = {"from":L[180],
"go":function(anf_begin_app_dropped25541644) {
return $Hanf_begin_app_dropped25581646(anf_begin_app_dropped25541644,printer3331643,self3321645);
}};
$e16321633.stack[R.EXN_STACKHEIGHT++] = $ss16361637;
}
if(R.isPyretException($e16321633)) {
$e16321633.pyretStack.push(L[180]);
}
throw $e16321633;
}
var $ret16381639 = $Hanf_begin_app_dropped25581646($z16341635,printer3331643,self3321645);
++R.GAS;
return $ret16381639;
};
},{"length":2});
var anf_variant_member1386562 = R.makeMethod(function(self3341630) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[179],0,arguments);
}
var anf_fun13771629 = G(PP123,"infix",L[178]);
var anf_fun13781627 = G(PP123,"str",L[177]);
var $z16191620 = D;
var $f16251626 = function(_) {
return R.isFunction(anf_fun13781627)?anf_fun13781627.app((".")):R.ffi.throwNonFunApp(L[176],anf_fun13781627,[(".")]);
};
try {
if(--R.GAS > 0) {
$z16191620 = $f16251626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16251626,
"from":L[176]});
}
} catch($e16171618) {
if(R.isCont($e16171618)) {
var $ss16211622 = {"from":L[176],
"go":function(anf_arg13791628) {
return $Hanf_arg25621631(anf_arg13791628,INDENT7747,PP123,anf_fun13771629,self3341630);
}};
$e16171618.stack[R.EXN_STACKHEIGHT++] = $ss16211622;
}
if(R.isPyretException($e16171618)) {
$e16171618.pyretStack.push(L[176]);
}
throw $e16171618;
}
var $ret16231624 = $Hanf_arg25621631($z16191620,INDENT7747,PP123,anf_fun13771629,self3341630);
++R.GAS;
return $ret16231624;
};
},{"length":1});
var anf_variant_member1399570 = R.makeMethod(function(self2321595) {
return function(cases_DASH_funs2331596,else_DASH_clause2341607) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[31],2,arguments);
}
var if_DASH_2361610 = R.hasField(cases_DASH_funs2331596,("j-bracket"));
var if_helper13881593 = R.makeFunction(function(if_helper_arg13891615) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[31],1,arguments);
}
var ann_DASH_check_DASH_temp13871616 = if_helper_arg13891615;
return ann_DASH_check_DASH_temp13871616;
});
var anf_if13921614 = R.isBoolean(if_DASH_2361610);
if(R.isPyretTrue(anf_if13921614)) {
if(R.isPyretTrue(if_DASH_2361610)) {
var call_DASH_j_DASH_bracket2311589 = G(cases_DASH_funs2331596,"j-bracket",L[31]);
var anf_arg13951590 = G(self2321595,"obj",L[175]);
var anf_arg13961591 = G(self2321595,"field",L[174]);
var $z15811582 = D;
var $f15871588 = function(_) {
return R.isFunction(call_DASH_j_DASH_bracket2311589)?call_DASH_j_DASH_bracket2311589.app(anf_arg13951590,anf_arg13961591):R.ffi.throwNonFunApp(L[31],call_DASH_j_DASH_bracket2311589,[anf_arg13951590,anf_arg13961591]);
};
try {
if(--R.GAS > 0) {
$z15811582 = $f15871588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15871588,
"from":L[31]});
}
} catch($e15791580) {
if(R.isCont($e15791580)) {
var $ss15831584 = {"from":L[31],
"go":function(cont_tail_arg13971592) {
return $Hcont_tail_arg25631594(cont_tail_arg13971592,if_helper13881593);
}};
$e15791580.stack[R.EXN_STACKHEIGHT++] = $ss15831584;
}
if(R.isPyretException($e15791580)) {
$e15791580.pyretStack.push(L[31]);
}
throw $e15791580;
}
var $ret15851586 = $Hcont_tail_arg25631594($z15811582,if_helper13881593);
++R.GAS;
return $ret15851586;
} else {
var $z15991600 = D;
var $f16051606 = function(_) {
return R.isFunction(else_DASH_clause2341607)?else_DASH_clause2341607.app():R.ffi.throwNonFunApp(L[31],else_DASH_clause2341607,[]);
};
try {
if(--R.GAS > 0) {
$z15991600 = $f16051606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16051606,
"from":L[31]});
}
} catch($e15971598) {
if(R.isCont($e15971598)) {
var $ss16011602 = {"from":L[31],
"go":function(cont_tail_arg13931608) {
return $Hcont_tail_arg25641609(cont_tail_arg13931608,if_helper13881593);
}};
$e15971598.stack[R.EXN_STACKHEIGHT++] = $ss16011602;
}
if(R.isPyretException($e15971598)) {
$e15971598.pyretStack.push(L[31]);
}
throw $e15971598;
}
var $ret16031604 = $Hcont_tail_arg25641609($z15991600,if_helper13881593);
++R.GAS;
return $ret16031604;
}
} else {
var cont_tail_arg13901613 = R.throwNonBooleanCondition(L[31],("if"),if_DASH_2361610);
if(--R.GAS > 0) {
$z16111612 = R.isFunction(if_helper13881593)?if_helper13881593.app(cont_tail_arg13901613):R.ffi.throwNonFunApp(L[31],if_helper13881593,[cont_tail_arg13901613]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper13881593)?if_helper13881593.app(cont_tail_arg13901613):R.ffi.throwNonFunApp(L[31],if_helper13881593,[cont_tail_arg13901613]);
},
"from":L[31]});
}
++R.GAS;
return $z16111612;
}
};
},{"length":3});
var anf_variant_member1409571 = R.makeMethod(function(self2351577) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[31],0,arguments);
}
var anf_arg14011575 = G(self2351577,"obj",L[31]);
var $z15671568 = D;
var $f15731574 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg14011575):R.ffi.throwNonFunApp(L[31],torepr18,[anf_arg14011575]);
};
try {
if(--R.GAS > 0) {
$z15671568 = $f15731574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15731574,
"from":L[31]});
}
} catch($e15651566) {
if(R.isCont($e15651566)) {
var $ss15691570 = {"from":L[31],
"go":function(anf_arg14021576) {
return $Hanf_arg25711578(anf_arg14021576,self2351577,_plus14,torepr18);
}};
$e15651566.stack[R.EXN_STACKHEIGHT++] = $ss15691570;
}
if(R.isPyretException($e15651566)) {
$e15651566.pyretStack.push(L[31]);
}
throw $e15651566;
}
var $ret15711572 = $Hanf_arg25711578($z15671568,self2351577,_plus14,torepr18);
++R.GAS;
return $ret15711572;
};
},{"length":1});
var anf_variant_member1415572 = R.makeMethod(function(self3371562) {
return function(printer3381560) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[173],1,arguments);
}
var anf_bracket14111564 = G(self3371562,"obj",L[172]);
var anf_fun14121559 = G(anf_bracket14111564,"print-ugly-source",L[171]);
var $z15511552 = D;
var $f15571558 = function(_) {
return R.isFunction(anf_fun14121559)?anf_fun14121559.app(printer3381560):R.ffi.throwNonFunApp(L[170],anf_fun14121559,[printer3381560]);
};
try {
if(--R.GAS > 0) {
$z15511552 = $f15571558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15571558,
"from":L[170]});
}
} catch($e15491550) {
if(R.isCont($e15491550)) {
var $ss15531554 = {"from":L[170],
"go":function(anf_begin_app_dropped25721561) {
return $Hanf_begin_app_dropped25781563(anf_begin_app_dropped25721561,printer3381560,self3371562);
}};
$e15491550.stack[R.EXN_STACKHEIGHT++] = $ss15531554;
}
if(R.isPyretException($e15491550)) {
$e15491550.pyretStack.push(L[170]);
}
throw $e15491550;
}
var $ret15551556 = $Hanf_begin_app_dropped25781563($z15511552,printer3381560,self3371562);
++R.GAS;
return $ret15551556;
};
},{"length":2});
var anf_variant_member1429573 = R.makeMethod(function(self3391546) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[169],0,arguments);
}
var anf_fun14171545 = G(PP123,"group",L[168]);
var anf_bracket14181548 = G(self3391546,"obj",L[167]);
var anf_fun14191543 = G(anf_bracket14181548,"tosource",L[166]);
var $z15351536 = D;
var $f15411542 = function(_) {
return R.isFunction(anf_fun14191543)?anf_fun14191543.app():R.ffi.throwNonFunApp(L[165],anf_fun14191543,[]);
};
try {
if(--R.GAS > 0) {
$z15351536 = $f15411542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15411542,
"from":L[165]});
}
} catch($e15331534) {
if(R.isCont($e15331534)) {
var $ss15371538 = {"from":L[165],
"go":function(anf_arg14201544) {
return $Hanf_arg25831547(anf_arg14201544,INDENT7747,PP123,anf_fun14171545,self3391546,_plus14);
}};
$e15331534.stack[R.EXN_STACKHEIGHT++] = $ss15371538;
}
if(R.isPyretException($e15331534)) {
$e15331534.pyretStack.push(L[165]);
}
throw $e15331534;
}
var $ret15391540 = $Hanf_arg25831547($z15351536,INDENT7747,PP123,anf_fun14171545,self3391546,_plus14);
++R.GAS;
return $ret15391540;
};
},{"length":1});
var anf_variant_member1442581 = R.makeMethod(function(self2381511) {
return function(cases_DASH_funs2391512,else_DASH_clause2401523) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[30],2,arguments);
}
var if_DASH_2421526 = R.hasField(cases_DASH_funs2391512,("j-list"));
var if_helper14311509 = R.makeFunction(function(if_helper_arg14321531) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
var ann_DASH_check_DASH_temp14301532 = if_helper_arg14321531;
return ann_DASH_check_DASH_temp14301532;
});
var anf_if14351530 = R.isBoolean(if_DASH_2421526);
if(R.isPyretTrue(anf_if14351530)) {
if(R.isPyretTrue(if_DASH_2421526)) {
var call_DASH_j_DASH_list2371505 = G(cases_DASH_funs2391512,"j-list",L[30]);
var anf_arg14381506 = G(self2381511,"multi-line",L[164]);
var anf_arg14391507 = G(self2381511,"elts",L[163]);
var $z14971498 = D;
var $f15031504 = function(_) {
return R.isFunction(call_DASH_j_DASH_list2371505)?call_DASH_j_DASH_list2371505.app(anf_arg14381506,anf_arg14391507):R.ffi.throwNonFunApp(L[30],call_DASH_j_DASH_list2371505,[anf_arg14381506,anf_arg14391507]);
};
try {
if(--R.GAS > 0) {
$z14971498 = $f15031504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15031504,
"from":L[30]});
}
} catch($e14951496) {
if(R.isCont($e14951496)) {
var $ss14991500 = {"from":L[30],
"go":function(cont_tail_arg14401508) {
return $Hcont_tail_arg25841510(cont_tail_arg14401508,if_helper14311509);
}};
$e14951496.stack[R.EXN_STACKHEIGHT++] = $ss14991500;
}
if(R.isPyretException($e14951496)) {
$e14951496.pyretStack.push(L[30]);
}
throw $e14951496;
}
var $ret15011502 = $Hcont_tail_arg25841510($z14971498,if_helper14311509);
++R.GAS;
return $ret15011502;
} else {
var $z15151516 = D;
var $f15211522 = function(_) {
return R.isFunction(else_DASH_clause2401523)?else_DASH_clause2401523.app():R.ffi.throwNonFunApp(L[30],else_DASH_clause2401523,[]);
};
try {
if(--R.GAS > 0) {
$z15151516 = $f15211522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15211522,
"from":L[30]});
}
} catch($e15131514) {
if(R.isCont($e15131514)) {
var $ss15171518 = {"from":L[30],
"go":function(cont_tail_arg14361524) {
return $Hcont_tail_arg25851525(cont_tail_arg14361524,if_helper14311509);
}};
$e15131514.stack[R.EXN_STACKHEIGHT++] = $ss15171518;
}
if(R.isPyretException($e15131514)) {
$e15131514.pyretStack.push(L[30]);
}
throw $e15131514;
}
var $ret15191520 = $Hcont_tail_arg25851525($z15151516,if_helper14311509);
++R.GAS;
return $ret15191520;
}
} else {
var cont_tail_arg14331529 = R.throwNonBooleanCondition(L[30],("if"),if_DASH_2421526);
if(--R.GAS > 0) {
$z15271528 = R.isFunction(if_helper14311509)?if_helper14311509.app(cont_tail_arg14331529):R.ffi.throwNonFunApp(L[30],if_helper14311509,[cont_tail_arg14331529]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper14311509)?if_helper14311509.app(cont_tail_arg14331529):R.ffi.throwNonFunApp(L[30],if_helper14311509,[cont_tail_arg14331529]);
},
"from":L[30]});
}
++R.GAS;
return $z15271528;
}
};
},{"length":3});
var anf_variant_member1452582 = R.makeMethod(function(self2411493) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[30],0,arguments);
}
var anf_arg14441491 = G(self2411493,"multi-line",L[30]);
var $z14831484 = D;
var $f14891490 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg14441491):R.ffi.throwNonFunApp(L[30],torepr18,[anf_arg14441491]);
};
try {
if(--R.GAS > 0) {
$z14831484 = $f14891490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14891490,
"from":L[30]});
}
} catch($e14811482) {
if(R.isCont($e14811482)) {
var $ss14851486 = {"from":L[30],
"go":function(anf_arg14451492) {
return $Hanf_arg25921494(anf_arg14451492,self2411493,_plus14,torepr18);
}};
$e14811482.stack[R.EXN_STACKHEIGHT++] = $ss14851486;
}
if(R.isPyretException($e14811482)) {
$e14811482.pyretStack.push(L[30]);
}
throw $e14811482;
}
var $ret14871488 = $Hanf_arg25921494($z14831484,self2411493,_plus14,torepr18);
++R.GAS;
return $ret14871488;
};
},{"length":1});
var anf_variant_member1477583 = R.makeMethod(function(self3421479) {
return function(printer3431477) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[162],1,arguments);
}
var $z14691470 = D;
var $f14751476 = function(_) {
return R.isFunction(printer3431477)?printer3431477.app(("[")):R.ffi.throwNonFunApp(L[161],printer3431477,[("[")]);
};
try {
if(--R.GAS > 0) {
$z14691470 = $f14751476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14751476,
"from":L[161]});
}
} catch($e14671468) {
if(R.isCont($e14671468)) {
var $ss14711472 = {"from":L[161],
"go":function(anf_begin_app_dropped25931478) {
return $Hanf_begin_app_dropped26091480(anf_begin_app_dropped25931478,each4361,is_DASH_link2563,printer3431477,self3421479,nothing16);
}};
$e14671468.stack[R.EXN_STACKHEIGHT++] = $ss14711472;
}
if(R.isPyretException($e14671468)) {
$e14671468.pyretStack.push(L[161]);
}
throw $e14671468;
}
var $ret14731474 = $Hanf_begin_app_dropped26091480($z14691470,each4361,is_DASH_link2563,printer3431477,self3421479,nothing16);
++R.GAS;
return $ret14731474;
};
},{"length":2});
var anf_variant_member1492584 = R.makeMethod(function(self3451465) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[160],0,arguments);
}
var anf_fun14791464 = G(PP123,"surround-separate",L[159]);
var anf_arg14801461 = G(PP123,"lbrack",L[158]);
var anf_arg14811462 = G(PP123,"rbrack",L[157]);
var $z14531454 = D;
var $f14591460 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg14801461,anf_arg14811462):R.ffi.throwNonFunApp(L[156],_plus14,[anf_arg14801461,anf_arg14811462]);
};
try {
if(--R.GAS > 0) {
$z14531454 = $f14591460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14591460,
"from":L[156]});
}
} catch($e14511452) {
if(R.isCont($e14511452)) {
var $ss14551456 = {"from":L[156],
"go":function(anf_arg14821463) {
return $Hanf_arg26131466(anf_arg14821463,INDENT7747,PP123,anf_fun14791464,self3451465);
}};
$e14511452.stack[R.EXN_STACKHEIGHT++] = $ss14551456;
}
if(R.isPyretException($e14511452)) {
$e14511452.pyretStack.push(L[156]);
}
throw $e14511452;
}
var $ret14571458 = $Hanf_arg26131466($z14531454,INDENT7747,PP123,anf_fun14791464,self3451465);
++R.GAS;
return $ret14571458;
};
},{"length":1});
var anf_variant_member1504592 = R.makeMethod(function(self2471429) {
return function(cases_DASH_funs2481430,else_DASH_clause2491441) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[29],2,arguments);
}
var if_DASH_2511444 = R.hasField(cases_DASH_funs2481430,("j-obj"));
var if_helper14941427 = R.makeFunction(function(if_helper_arg14951449) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[29],1,arguments);
}
var ann_DASH_check_DASH_temp14931450 = if_helper_arg14951449;
return ann_DASH_check_DASH_temp14931450;
});
var anf_if14981448 = R.isBoolean(if_DASH_2511444);
if(R.isPyretTrue(anf_if14981448)) {
if(R.isPyretTrue(if_DASH_2511444)) {
var call_DASH_j_DASH_obj2461424 = G(cases_DASH_funs2481430,"j-obj",L[29]);
var anf_arg15011425 = G(self2471429,"fields",L[155]);
var $z14161417 = D;
var $f14221423 = function(_) {
return R.isFunction(call_DASH_j_DASH_obj2461424)?call_DASH_j_DASH_obj2461424.app(anf_arg15011425):R.ffi.throwNonFunApp(L[29],call_DASH_j_DASH_obj2461424,[anf_arg15011425]);
};
try {
if(--R.GAS > 0) {
$z14161417 = $f14221423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14221423,
"from":L[29]});
}
} catch($e14141415) {
if(R.isCont($e14141415)) {
var $ss14181419 = {"from":L[29],
"go":function(cont_tail_arg15021426) {
return $Hcont_tail_arg26141428(cont_tail_arg15021426,if_helper14941427);
}};
$e14141415.stack[R.EXN_STACKHEIGHT++] = $ss14181419;
}
if(R.isPyretException($e14141415)) {
$e14141415.pyretStack.push(L[29]);
}
throw $e14141415;
}
var $ret14201421 = $Hcont_tail_arg26141428($z14161417,if_helper14941427);
++R.GAS;
return $ret14201421;
} else {
var $z14331434 = D;
var $f14391440 = function(_) {
return R.isFunction(else_DASH_clause2491441)?else_DASH_clause2491441.app():R.ffi.throwNonFunApp(L[29],else_DASH_clause2491441,[]);
};
try {
if(--R.GAS > 0) {
$z14331434 = $f14391440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14391440,
"from":L[29]});
}
} catch($e14311432) {
if(R.isCont($e14311432)) {
var $ss14351436 = {"from":L[29],
"go":function(cont_tail_arg14991442) {
return $Hcont_tail_arg26151443(cont_tail_arg14991442,if_helper14941427);
}};
$e14311432.stack[R.EXN_STACKHEIGHT++] = $ss14351436;
}
if(R.isPyretException($e14311432)) {
$e14311432.pyretStack.push(L[29]);
}
throw $e14311432;
}
var $ret14371438 = $Hcont_tail_arg26151443($z14331434,if_helper14941427);
++R.GAS;
return $ret14371438;
}
} else {
var cont_tail_arg14961447 = R.throwNonBooleanCondition(L[29],("if"),if_DASH_2511444);
if(--R.GAS > 0) {
$z14451446 = R.isFunction(if_helper14941427)?if_helper14941427.app(cont_tail_arg14961447):R.ffi.throwNonFunApp(L[29],if_helper14941427,[cont_tail_arg14961447]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper14941427)?if_helper14941427.app(cont_tail_arg14961447):R.ffi.throwNonFunApp(L[29],if_helper14941427,[cont_tail_arg14961447]);
},
"from":L[29]});
}
++R.GAS;
return $z14451446;
}
};
},{"length":3});
var anf_variant_member1510593 = R.makeMethod(function(self2501413) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[29],0,arguments);
}
var anf_arg15061410 = G(self2501413,"fields",L[29]);
var $z14021403 = D;
var $f14081409 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg15061410):R.ffi.throwNonFunApp(L[29],torepr18,[anf_arg15061410]);
};
try {
if(--R.GAS > 0) {
$z14021403 = $f14081409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14081409,
"from":L[29]});
}
} catch($e14001401) {
if(R.isCont($e14001401)) {
var $ss14041405 = {"from":L[29],
"go":function(anf_arg15071411) {
return $Hanf_arg26191412(anf_arg15071411,_plus14);
}};
$e14001401.stack[R.EXN_STACKHEIGHT++] = $ss14041405;
}
if(R.isPyretException($e14001401)) {
$e14001401.pyretStack.push(L[29]);
}
throw $e14001401;
}
var $ret14061407 = $Hanf_arg26191412($z14021403,_plus14);
++R.GAS;
return $ret14061407;
};
},{"length":1});
var anf_variant_member1528594 = R.makeMethod(function(self3471398) {
return function(printer3481396) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[154],1,arguments);
}
var $z13881389 = D;
var $f13941395 = function(_) {
return R.isFunction(printer3481396)?printer3481396.app(("{")):R.ffi.throwNonFunApp(L[153],printer3481396,[("{")]);
};
try {
if(--R.GAS > 0) {
$z13881389 = $f13941395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13941395,
"from":L[153]});
}
} catch($e13861387) {
if(R.isCont($e13861387)) {
var $ss13901391 = {"from":L[153],
"go":function(anf_begin_app_dropped26201397) {
return $Hanf_begin_app_dropped26321399(anf_begin_app_dropped26201397,each4361,is_DASH_link2563,printer3481396,self3471398,nothing16);
}};
$e13861387.stack[R.EXN_STACKHEIGHT++] = $ss13901391;
}
if(R.isPyretException($e13861387)) {
$e13861387.pyretStack.push(L[153]);
}
throw $e13861387;
}
var $ret13921393 = $Hanf_begin_app_dropped26321399($z13881389,each4361,is_DASH_link2563,printer3481396,self3471398,nothing16);
++R.GAS;
return $ret13921393;
};
},{"length":2});
var anf_variant_member1543595 = R.makeMethod(function(self3501384) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[152],0,arguments);
}
var anf_fun15301383 = G(PP123,"surround-separate",L[151]);
var anf_arg15311380 = G(PP123,"lbrace",L[150]);
var anf_arg15321381 = G(PP123,"rbrace",L[149]);
var $z13721373 = D;
var $f13781379 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg15311380,anf_arg15321381):R.ffi.throwNonFunApp(L[148],_plus14,[anf_arg15311380,anf_arg15321381]);
};
try {
if(--R.GAS > 0) {
$z13721373 = $f13781379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13781379,
"from":L[148]});
}
} catch($e13701371) {
if(R.isCont($e13701371)) {
var $ss13741375 = {"from":L[148],
"go":function(anf_arg15331382) {
return $Hanf_arg26361385(anf_arg15331382,INDENT7747,PP123,anf_fun15301383,self3501384);
}};
$e13701371.stack[R.EXN_STACKHEIGHT++] = $ss13741375;
}
if(R.isPyretException($e13701371)) {
$e13701371.pyretStack.push(L[148]);
}
throw $e13701371;
}
var $ret13761377 = $Hanf_arg26361385($z13721373,INDENT7747,PP123,anf_fun15301383,self3501384);
++R.GAS;
return $ret13761377;
};
},{"length":1});
var anf_variant_member1555602 = R.makeMethod(function(self2541348) {
return function(cases_DASH_funs2551349,else_DASH_clause2561360) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[28],2,arguments);
}
var if_DASH_2581363 = R.hasField(cases_DASH_funs2551349,("j-id"));
var if_helper15451346 = R.makeFunction(function(if_helper_arg15461368) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[28],1,arguments);
}
var ann_DASH_check_DASH_temp15441369 = if_helper_arg15461368;
return ann_DASH_check_DASH_temp15441369;
});
var anf_if15491367 = R.isBoolean(if_DASH_2581363);
if(R.isPyretTrue(anf_if15491367)) {
if(R.isPyretTrue(if_DASH_2581363)) {
var call_DASH_j_DASH_id2531343 = G(cases_DASH_funs2551349,"j-id",L[28]);
var anf_arg15521344 = G(self2541348,"id",L[147]);
var $z13351336 = D;
var $f13411342 = function(_) {
return R.isFunction(call_DASH_j_DASH_id2531343)?call_DASH_j_DASH_id2531343.app(anf_arg15521344):R.ffi.throwNonFunApp(L[28],call_DASH_j_DASH_id2531343,[anf_arg15521344]);
};
try {
if(--R.GAS > 0) {
$z13351336 = $f13411342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13411342,
"from":L[28]});
}
} catch($e13331334) {
if(R.isCont($e13331334)) {
var $ss13371338 = {"from":L[28],
"go":function(cont_tail_arg15531345) {
return $Hcont_tail_arg26371347(cont_tail_arg15531345,if_helper15451346);
}};
$e13331334.stack[R.EXN_STACKHEIGHT++] = $ss13371338;
}
if(R.isPyretException($e13331334)) {
$e13331334.pyretStack.push(L[28]);
}
throw $e13331334;
}
var $ret13391340 = $Hcont_tail_arg26371347($z13351336,if_helper15451346);
++R.GAS;
return $ret13391340;
} else {
var $z13521353 = D;
var $f13581359 = function(_) {
return R.isFunction(else_DASH_clause2561360)?else_DASH_clause2561360.app():R.ffi.throwNonFunApp(L[28],else_DASH_clause2561360,[]);
};
try {
if(--R.GAS > 0) {
$z13521353 = $f13581359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13581359,
"from":L[28]});
}
} catch($e13501351) {
if(R.isCont($e13501351)) {
var $ss13541355 = {"from":L[28],
"go":function(cont_tail_arg15501361) {
return $Hcont_tail_arg26381362(cont_tail_arg15501361,if_helper15451346);
}};
$e13501351.stack[R.EXN_STACKHEIGHT++] = $ss13541355;
}
if(R.isPyretException($e13501351)) {
$e13501351.pyretStack.push(L[28]);
}
throw $e13501351;
}
var $ret13561357 = $Hcont_tail_arg26381362($z13521353,if_helper15451346);
++R.GAS;
return $ret13561357;
}
} else {
var cont_tail_arg15471366 = R.throwNonBooleanCondition(L[28],("if"),if_DASH_2581363);
if(--R.GAS > 0) {
$z13641365 = R.isFunction(if_helper15451346)?if_helper15451346.app(cont_tail_arg15471366):R.ffi.throwNonFunApp(L[28],if_helper15451346,[cont_tail_arg15471366]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15451346)?if_helper15451346.app(cont_tail_arg15471366):R.ffi.throwNonFunApp(L[28],if_helper15451346,[cont_tail_arg15471366]);
},
"from":L[28]});
}
++R.GAS;
return $z13641365;
}
};
},{"length":3});
var anf_variant_member1561603 = R.makeMethod(function(self2571332) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[28],0,arguments);
}
var anf_arg15571329 = G(self2571332,"id",L[28]);
var $z13211322 = D;
var $f13271328 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg15571329):R.ffi.throwNonFunApp(L[28],torepr18,[anf_arg15571329]);
};
try {
if(--R.GAS > 0) {
$z13211322 = $f13271328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13271328,
"from":L[28]});
}
} catch($e13191320) {
if(R.isCont($e13191320)) {
var $ss13231324 = {"from":L[28],
"go":function(anf_arg15581330) {
return $Hanf_arg26421331(anf_arg15581330,_plus14);
}};
$e13191320.stack[R.EXN_STACKHEIGHT++] = $ss13231324;
}
if(R.isPyretException($e13191320)) {
$e13191320.pyretStack.push(L[28]);
}
throw $e13191320;
}
var $ret13251326 = $Hanf_arg26421331($z13211322,_plus14);
++R.GAS;
return $ret13251326;
};
},{"length":1});
var anf_variant_member1564604 = R.makeMethod(function(self3531318) {
return function(printer3541314) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[145],1,arguments);
}
var anf_arg15631315 = G(self3531318,"id",L[146]);
var $z13061307 = D;
var $f13121313 = function(_) {
return R.isFunction(printer3541314)?printer3541314.app(anf_arg15631315):R.ffi.throwNonFunApp(L[145],printer3541314,[anf_arg15631315]);
};
try {
if(--R.GAS > 0) {
$z13061307 = $f13121313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13121313,
"from":L[145]});
}
} catch($e13041305) {
if(R.isCont($e13041305)) {
var $ss13081309 = {"from":L[145],
"go":function(ann_DASH_check_DASH_temp15621316) {
return $Hann_DASH_check_DASH_temp26431317(ann_DASH_check_DASH_temp15621316);
}};
$e13041305.stack[R.EXN_STACKHEIGHT++] = $ss13081309;
}
if(R.isPyretException($e13041305)) {
$e13041305.pyretStack.push(L[145]);
}
throw $e13041305;
}
var $ret13101311 = $Hann_DASH_check_DASH_temp26431317($z13061307);
++R.GAS;
return $ret13101311;
};
},{"length":2});
var anf_variant_member1568605 = R.makeMethod(function(self3551303) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[142],0,arguments);
}
var anf_fun15661299 = G(PP123,"str",L[144]);
var anf_arg15671300 = G(self3551303,"id",L[143]);
var $z12911292 = D;
var $f12971298 = function(_) {
return R.isFunction(anf_fun15661299)?anf_fun15661299.app(anf_arg15671300):R.ffi.throwNonFunApp(L[142],anf_fun15661299,[anf_arg15671300]);
};
try {
if(--R.GAS > 0) {
$z12911292 = $f12971298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12971298,
"from":L[142]});
}
} catch($e12891290) {
if(R.isCont($e12891290)) {
var $ss12931294 = {"from":L[142],
"go":function(ann_DASH_check_DASH_temp15651301) {
return $Hann_DASH_check_DASH_temp26441302(ann_DASH_check_DASH_temp15651301);
}};
$e12891290.stack[R.EXN_STACKHEIGHT++] = $ss12931294;
}
if(R.isPyretException($e12891290)) {
$e12891290.pyretStack.push(L[142]);
}
throw $e12891290;
}
var $ret12951296 = $Hann_DASH_check_DASH_temp26441302($z12911292);
++R.GAS;
return $ret12951296;
};
},{"length":1});
var anf_variant_member1580612 = R.makeMethod(function(self2601267) {
return function(cases_DASH_funs2611268,else_DASH_clause2621279) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[27],2,arguments);
}
var if_DASH_2641282 = R.hasField(cases_DASH_funs2611268,("j-str"));
var if_helper15701265 = R.makeFunction(function(if_helper_arg15711287) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[27],1,arguments);
}
var ann_DASH_check_DASH_temp15691288 = if_helper_arg15711287;
return ann_DASH_check_DASH_temp15691288;
});
var anf_if15741286 = R.isBoolean(if_DASH_2641282);
if(R.isPyretTrue(anf_if15741286)) {
if(R.isPyretTrue(if_DASH_2641282)) {
var call_DASH_j_DASH_str2591262 = G(cases_DASH_funs2611268,"j-str",L[27]);
var anf_arg15771263 = G(self2601267,"s",L[141]);
var $z12541255 = D;
var $f12601261 = function(_) {
return R.isFunction(call_DASH_j_DASH_str2591262)?call_DASH_j_DASH_str2591262.app(anf_arg15771263):R.ffi.throwNonFunApp(L[27],call_DASH_j_DASH_str2591262,[anf_arg15771263]);
};
try {
if(--R.GAS > 0) {
$z12541255 = $f12601261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12601261,
"from":L[27]});
}
} catch($e12521253) {
if(R.isCont($e12521253)) {
var $ss12561257 = {"from":L[27],
"go":function(cont_tail_arg15781264) {
return $Hcont_tail_arg26451266(cont_tail_arg15781264,if_helper15701265);
}};
$e12521253.stack[R.EXN_STACKHEIGHT++] = $ss12561257;
}
if(R.isPyretException($e12521253)) {
$e12521253.pyretStack.push(L[27]);
}
throw $e12521253;
}
var $ret12581259 = $Hcont_tail_arg26451266($z12541255,if_helper15701265);
++R.GAS;
return $ret12581259;
} else {
var $z12711272 = D;
var $f12771278 = function(_) {
return R.isFunction(else_DASH_clause2621279)?else_DASH_clause2621279.app():R.ffi.throwNonFunApp(L[27],else_DASH_clause2621279,[]);
};
try {
if(--R.GAS > 0) {
$z12711272 = $f12771278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12771278,
"from":L[27]});
}
} catch($e12691270) {
if(R.isCont($e12691270)) {
var $ss12731274 = {"from":L[27],
"go":function(cont_tail_arg15751280) {
return $Hcont_tail_arg26461281(cont_tail_arg15751280,if_helper15701265);
}};
$e12691270.stack[R.EXN_STACKHEIGHT++] = $ss12731274;
}
if(R.isPyretException($e12691270)) {
$e12691270.pyretStack.push(L[27]);
}
throw $e12691270;
}
var $ret12751276 = $Hcont_tail_arg26461281($z12711272,if_helper15701265);
++R.GAS;
return $ret12751276;
}
} else {
var cont_tail_arg15721285 = R.throwNonBooleanCondition(L[27],("if"),if_DASH_2641282);
if(--R.GAS > 0) {
$z12831284 = R.isFunction(if_helper15701265)?if_helper15701265.app(cont_tail_arg15721285):R.ffi.throwNonFunApp(L[27],if_helper15701265,[cont_tail_arg15721285]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15701265)?if_helper15701265.app(cont_tail_arg15721285):R.ffi.throwNonFunApp(L[27],if_helper15701265,[cont_tail_arg15721285]);
},
"from":L[27]});
}
++R.GAS;
return $z12831284;
}
};
},{"length":3});
var anf_variant_member1586613 = R.makeMethod(function(self2631251) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[27],0,arguments);
}
var anf_arg15821248 = G(self2631251,"s",L[27]);
var $z12401241 = D;
var $f12461247 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg15821248):R.ffi.throwNonFunApp(L[27],torepr18,[anf_arg15821248]);
};
try {
if(--R.GAS > 0) {
$z12401241 = $f12461247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12461247,
"from":L[27]});
}
} catch($e12381239) {
if(R.isCont($e12381239)) {
var $ss12421243 = {"from":L[27],
"go":function(anf_arg15831249) {
return $Hanf_arg26501250(anf_arg15831249,_plus14);
}};
$e12381239.stack[R.EXN_STACKHEIGHT++] = $ss12421243;
}
if(R.isPyretException($e12381239)) {
$e12381239.pyretStack.push(L[27]);
}
throw $e12381239;
}
var $ret12441245 = $Hanf_arg26501250($z12401241,_plus14);
++R.GAS;
return $ret12441245;
};
},{"length":1});
var anf_variant_member1590614 = R.makeMethod(function(self3571237) {
return function(printer3581235) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[140],1,arguments);
}
var anf_arg15881233 = G(self3571237,"s",L[139]);
var $z12251226 = D;
var $f12311232 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg15881233):R.ffi.throwNonFunApp(L[138],torepr18,[anf_arg15881233]);
};
try {
if(--R.GAS > 0) {
$z12251226 = $f12311232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12311232,
"from":L[138]});
}
} catch($e12231224) {
if(R.isCont($e12231224)) {
var $ss12271228 = {"from":L[138],
"go":function(anf_arg15891234) {
return $Hanf_arg26521236(anf_arg15891234,printer3581235);
}};
$e12231224.stack[R.EXN_STACKHEIGHT++] = $ss12271228;
}
if(R.isPyretException($e12231224)) {
$e12231224.pyretStack.push(L[138]);
}
throw $e12231224;
}
var $ret12291230 = $Hanf_arg26521236($z12251226,printer3581235);
++R.GAS;
return $ret12291230;
};
},{"length":2});
var anf_variant_member1595615 = R.makeMethod(function(self3591222) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[137],0,arguments);
}
var anf_fun15921220 = G(PP123,"str",L[136]);
var anf_arg15931218 = G(self3591222,"s",L[135]);
var $z12101211 = D;
var $f12161217 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg15931218):R.ffi.throwNonFunApp(L[134],torepr18,[anf_arg15931218]);
};
try {
if(--R.GAS > 0) {
$z12101211 = $f12161217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12161217,
"from":L[134]});
}
} catch($e12081209) {
if(R.isCont($e12081209)) {
var $ss12121213 = {"from":L[134],
"go":function(anf_arg15941219) {
return $Hanf_arg26541221(anf_arg15941219,anf_fun15921220);
}};
$e12081209.stack[R.EXN_STACKHEIGHT++] = $ss12121213;
}
if(R.isPyretException($e12081209)) {
$e12081209.pyretStack.push(L[134]);
}
throw $e12081209;
}
var $ret12141215 = $Hanf_arg26541221($z12101211,anf_fun15921220);
++R.GAS;
return $ret12141215;
};
},{"length":1});
var anf_variant_member1607622 = R.makeMethod(function(self2661186) {
return function(cases_DASH_funs2671187,else_DASH_clause2681198) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[26],2,arguments);
}
var if_DASH_2701201 = R.hasField(cases_DASH_funs2671187,("j-num"));
var if_helper15971184 = R.makeFunction(function(if_helper_arg15981206) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[26],1,arguments);
}
var ann_DASH_check_DASH_temp15961207 = if_helper_arg15981206;
return ann_DASH_check_DASH_temp15961207;
});
var anf_if16011205 = R.isBoolean(if_DASH_2701201);
if(R.isPyretTrue(anf_if16011205)) {
if(R.isPyretTrue(if_DASH_2701201)) {
var call_DASH_j_DASH_num2651181 = G(cases_DASH_funs2671187,"j-num",L[26]);
var anf_arg16041182 = G(self2661186,"n",L[133]);
var $z11731174 = D;
var $f11791180 = function(_) {
return R.isFunction(call_DASH_j_DASH_num2651181)?call_DASH_j_DASH_num2651181.app(anf_arg16041182):R.ffi.throwNonFunApp(L[26],call_DASH_j_DASH_num2651181,[anf_arg16041182]);
};
try {
if(--R.GAS > 0) {
$z11731174 = $f11791180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11791180,
"from":L[26]});
}
} catch($e11711172) {
if(R.isCont($e11711172)) {
var $ss11751176 = {"from":L[26],
"go":function(cont_tail_arg16051183) {
return $Hcont_tail_arg26551185(cont_tail_arg16051183,if_helper15971184);
}};
$e11711172.stack[R.EXN_STACKHEIGHT++] = $ss11751176;
}
if(R.isPyretException($e11711172)) {
$e11711172.pyretStack.push(L[26]);
}
throw $e11711172;
}
var $ret11771178 = $Hcont_tail_arg26551185($z11731174,if_helper15971184);
++R.GAS;
return $ret11771178;
} else {
var $z11901191 = D;
var $f11961197 = function(_) {
return R.isFunction(else_DASH_clause2681198)?else_DASH_clause2681198.app():R.ffi.throwNonFunApp(L[26],else_DASH_clause2681198,[]);
};
try {
if(--R.GAS > 0) {
$z11901191 = $f11961197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11961197,
"from":L[26]});
}
} catch($e11881189) {
if(R.isCont($e11881189)) {
var $ss11921193 = {"from":L[26],
"go":function(cont_tail_arg16021199) {
return $Hcont_tail_arg26561200(cont_tail_arg16021199,if_helper15971184);
}};
$e11881189.stack[R.EXN_STACKHEIGHT++] = $ss11921193;
}
if(R.isPyretException($e11881189)) {
$e11881189.pyretStack.push(L[26]);
}
throw $e11881189;
}
var $ret11941195 = $Hcont_tail_arg26561200($z11901191,if_helper15971184);
++R.GAS;
return $ret11941195;
}
} else {
var cont_tail_arg15991204 = R.throwNonBooleanCondition(L[26],("if"),if_DASH_2701201);
if(--R.GAS > 0) {
$z12021203 = R.isFunction(if_helper15971184)?if_helper15971184.app(cont_tail_arg15991204):R.ffi.throwNonFunApp(L[26],if_helper15971184,[cont_tail_arg15991204]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15971184)?if_helper15971184.app(cont_tail_arg15991204):R.ffi.throwNonFunApp(L[26],if_helper15971184,[cont_tail_arg15991204]);
},
"from":L[26]});
}
++R.GAS;
return $z12021203;
}
};
},{"length":3});
var anf_variant_member1613623 = R.makeMethod(function(self2691170) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[26],0,arguments);
}
var anf_arg16091167 = G(self2691170,"n",L[26]);
var $z11591160 = D;
var $f11651166 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg16091167):R.ffi.throwNonFunApp(L[26],torepr18,[anf_arg16091167]);
};
try {
if(--R.GAS > 0) {
$z11591160 = $f11651166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11651166,
"from":L[26]});
}
} catch($e11571158) {
if(R.isCont($e11571158)) {
var $ss11611162 = {"from":L[26],
"go":function(anf_arg16101168) {
return $Hanf_arg26601169(anf_arg16101168,_plus14);
}};
$e11571158.stack[R.EXN_STACKHEIGHT++] = $ss11611162;
}
if(R.isPyretException($e11571158)) {
$e11571158.pyretStack.push(L[26]);
}
throw $e11571158;
}
var $ret11631164 = $Hanf_arg26601169($z11591160,_plus14);
++R.GAS;
return $ret11631164;
};
},{"length":1});
var anf_variant_member1617624 = R.makeMethod(function(self3611156) {
return function(printer3621154) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[132],1,arguments);
}
var anf_arg16151152 = G(self3611156,"n",L[131]);
var $z11441145 = D;
var $f11501151 = function(_) {
return R.isFunction(tostring19)?tostring19.app(anf_arg16151152):R.ffi.throwNonFunApp(L[130],tostring19,[anf_arg16151152]);
};
try {
if(--R.GAS > 0) {
$z11441145 = $f11501151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11501151,
"from":L[130]});
}
} catch($e11421143) {
if(R.isCont($e11421143)) {
var $ss11461147 = {"from":L[130],
"go":function(anf_arg16161153) {
return $Hanf_arg26621155(anf_arg16161153,printer3621154);
}};
$e11421143.stack[R.EXN_STACKHEIGHT++] = $ss11461147;
}
if(R.isPyretException($e11421143)) {
$e11421143.pyretStack.push(L[130]);
}
throw $e11421143;
}
var $ret11481149 = $Hanf_arg26621155($z11441145,printer3621154);
++R.GAS;
return $ret11481149;
};
},{"length":2});
var anf_variant_member1621625 = R.makeMethod(function(self3631141) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[127],0,arguments);
}
var anf_fun16191137 = G(PP123,"number",L[129]);
var anf_arg16201138 = G(self3631141,"n",L[128]);
var $z11291130 = D;
var $f11351136 = function(_) {
return R.isFunction(anf_fun16191137)?anf_fun16191137.app(anf_arg16201138):R.ffi.throwNonFunApp(L[127],anf_fun16191137,[anf_arg16201138]);
};
try {
if(--R.GAS > 0) {
$z11291130 = $f11351136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11351136,
"from":L[127]});
}
} catch($e11271128) {
if(R.isCont($e11271128)) {
var $ss11311132 = {"from":L[127],
"go":function(ann_DASH_check_DASH_temp16181139) {
return $Hann_DASH_check_DASH_temp26631140(ann_DASH_check_DASH_temp16181139);
}};
$e11271128.stack[R.EXN_STACKHEIGHT++] = $ss11311132;
}
if(R.isPyretException($e11271128)) {
$e11271128.pyretStack.push(L[127]);
}
throw $e11271128;
}
var $ret11331134 = $Hann_DASH_check_DASH_temp26631140($z11291130);
++R.GAS;
return $ret11331134;
};
},{"length":1});
var anf_singleton_variant_member1632632 = R.makeMethod(function(self2721126) {
return function(cases_DASH_funs2731105,else_DASH_clause2741116) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[25],2,arguments);
}
var if_DASH_2761119 = R.hasField(cases_DASH_funs2731105,("j-true"));
var if_helper16231103 = R.makeFunction(function(if_helper_arg16241124) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[25],1,arguments);
}
var ann_DASH_check_DASH_temp16221125 = if_helper_arg16241124;
return ann_DASH_check_DASH_temp16221125;
});
var anf_if16271123 = R.isBoolean(if_DASH_2761119);
if(R.isPyretTrue(anf_if16271123)) {
if(R.isPyretTrue(if_DASH_2761119)) {
var call_DASH_j_DASH_true2711101 = G(cases_DASH_funs2731105,"j-true",L[25]);
var $z10931094 = D;
var $f10991100 = function(_) {
return R.isFunction(call_DASH_j_DASH_true2711101)?call_DASH_j_DASH_true2711101.app():R.ffi.throwNonFunApp(L[25],call_DASH_j_DASH_true2711101,[]);
};
try {
if(--R.GAS > 0) {
$z10931094 = $f10991100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10991100,
"from":L[25]});
}
} catch($e10911092) {
if(R.isCont($e10911092)) {
var $ss10951096 = {"from":L[25],
"go":function(cont_tail_arg16301102) {
return $Hcont_tail_arg26641104(cont_tail_arg16301102,if_helper16231103);
}};
$e10911092.stack[R.EXN_STACKHEIGHT++] = $ss10951096;
}
if(R.isPyretException($e10911092)) {
$e10911092.pyretStack.push(L[25]);
}
throw $e10911092;
}
var $ret10971098 = $Hcont_tail_arg26641104($z10931094,if_helper16231103);
++R.GAS;
return $ret10971098;
} else {
var $z11081109 = D;
var $f11141115 = function(_) {
return R.isFunction(else_DASH_clause2741116)?else_DASH_clause2741116.app():R.ffi.throwNonFunApp(L[25],else_DASH_clause2741116,[]);
};
try {
if(--R.GAS > 0) {
$z11081109 = $f11141115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11141115,
"from":L[25]});
}
} catch($e11061107) {
if(R.isCont($e11061107)) {
var $ss11101111 = {"from":L[25],
"go":function(cont_tail_arg16281117) {
return $Hcont_tail_arg26651118(cont_tail_arg16281117,if_helper16231103);
}};
$e11061107.stack[R.EXN_STACKHEIGHT++] = $ss11101111;
}
if(R.isPyretException($e11061107)) {
$e11061107.pyretStack.push(L[25]);
}
throw $e11061107;
}
var $ret11121113 = $Hcont_tail_arg26651118($z11081109,if_helper16231103);
++R.GAS;
return $ret11121113;
}
} else {
var cont_tail_arg16251122 = R.throwNonBooleanCondition(L[25],("if"),if_DASH_2761119);
if(--R.GAS > 0) {
$z11201121 = R.isFunction(if_helper16231103)?if_helper16231103.app(cont_tail_arg16251122):R.ffi.throwNonFunApp(L[25],if_helper16231103,[cont_tail_arg16251122]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper16231103)?if_helper16231103.app(cont_tail_arg16251122):R.ffi.throwNonFunApp(L[25],if_helper16231103,[cont_tail_arg16251122]);
},
"from":L[25]});
}
++R.GAS;
return $z11201121;
}
};
},{"length":3});
var anf_singleton_variant_member1634633 = R.makeMethod(function(self2751090) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[25],0,arguments);
}
var ann_DASH_check_DASH_temp16331089 = ("j-true");
return ann_DASH_check_DASH_temp16331089;
};
},{"length":1});
var anf_singleton_variant_member1636634 = R.makeMethod(function(self3641088) {
return function(printer3651085) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[126],1,arguments);
}
var $z10771078 = D;
var $f10831084 = function(_) {
return R.isFunction(printer3651085)?printer3651085.app(("true")):R.ffi.throwNonFunApp(L[126],printer3651085,[("true")]);
};
try {
if(--R.GAS > 0) {
$z10771078 = $f10831084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10831084,
"from":L[126]});
}
} catch($e10751076) {
if(R.isCont($e10751076)) {
var $ss10791080 = {"from":L[126],
"go":function(ann_DASH_check_DASH_temp16351086) {
return $Hann_DASH_check_DASH_temp26661087(ann_DASH_check_DASH_temp16351086);
}};
$e10751076.stack[R.EXN_STACKHEIGHT++] = $ss10791080;
}
if(R.isPyretException($e10751076)) {
$e10751076.pyretStack.push(L[126]);
}
throw $e10751076;
}
var $ret10811082 = $Hann_DASH_check_DASH_temp26661087($z10771078);
++R.GAS;
return $ret10811082;
};
},{"length":2});
var anf_singleton_variant_member1639635 = R.makeMethod(function(self3661074) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[124],0,arguments);
}
var anf_fun16381071 = G(PP123,"str",L[125]);
var $z10631064 = D;
var $f10691070 = function(_) {
return R.isFunction(anf_fun16381071)?anf_fun16381071.app(("true")):R.ffi.throwNonFunApp(L[124],anf_fun16381071,[("true")]);
};
try {
if(--R.GAS > 0) {
$z10631064 = $f10691070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10691070,
"from":L[124]});
}
} catch($e10611062) {
if(R.isCont($e10611062)) {
var $ss10651066 = {"from":L[124],
"go":function(ann_DASH_check_DASH_temp16371072) {
return $Hann_DASH_check_DASH_temp26671073(ann_DASH_check_DASH_temp16371072);
}};
$e10611062.stack[R.EXN_STACKHEIGHT++] = $ss10651066;
}
if(R.isPyretException($e10611062)) {
$e10611062.pyretStack.push(L[124]);
}
throw $e10611062;
}
var $ret10671068 = $Hann_DASH_check_DASH_temp26671073($z10631064);
++R.GAS;
return $ret10671068;
};
},{"length":1});
var anf_singleton_variant_member1650641 = R.makeMethod(function(self2781060) {
return function(cases_DASH_funs2791039,else_DASH_clause2801050) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[24],2,arguments);
}
var if_DASH_2821053 = R.hasField(cases_DASH_funs2791039,("j-false"));
var if_helper16411037 = R.makeFunction(function(if_helper_arg16421058) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[24],1,arguments);
}
var ann_DASH_check_DASH_temp16401059 = if_helper_arg16421058;
return ann_DASH_check_DASH_temp16401059;
});
var anf_if16451057 = R.isBoolean(if_DASH_2821053);
if(R.isPyretTrue(anf_if16451057)) {
if(R.isPyretTrue(if_DASH_2821053)) {
var call_DASH_j_DASH_false2771035 = G(cases_DASH_funs2791039,"j-false",L[24]);
var $z10271028 = D;
var $f10331034 = function(_) {
return R.isFunction(call_DASH_j_DASH_false2771035)?call_DASH_j_DASH_false2771035.app():R.ffi.throwNonFunApp(L[24],call_DASH_j_DASH_false2771035,[]);
};
try {
if(--R.GAS > 0) {
$z10271028 = $f10331034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10331034,
"from":L[24]});
}
} catch($e10251026) {
if(R.isCont($e10251026)) {
var $ss10291030 = {"from":L[24],
"go":function(cont_tail_arg16481036) {
return $Hcont_tail_arg26681038(cont_tail_arg16481036,if_helper16411037);
}};
$e10251026.stack[R.EXN_STACKHEIGHT++] = $ss10291030;
}
if(R.isPyretException($e10251026)) {
$e10251026.pyretStack.push(L[24]);
}
throw $e10251026;
}
var $ret10311032 = $Hcont_tail_arg26681038($z10271028,if_helper16411037);
++R.GAS;
return $ret10311032;
} else {
var $z10421043 = D;
var $f10481049 = function(_) {
return R.isFunction(else_DASH_clause2801050)?else_DASH_clause2801050.app():R.ffi.throwNonFunApp(L[24],else_DASH_clause2801050,[]);
};
try {
if(--R.GAS > 0) {
$z10421043 = $f10481049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10481049,
"from":L[24]});
}
} catch($e10401041) {
if(R.isCont($e10401041)) {
var $ss10441045 = {"from":L[24],
"go":function(cont_tail_arg16461051) {
return $Hcont_tail_arg26691052(cont_tail_arg16461051,if_helper16411037);
}};
$e10401041.stack[R.EXN_STACKHEIGHT++] = $ss10441045;
}
if(R.isPyretException($e10401041)) {
$e10401041.pyretStack.push(L[24]);
}
throw $e10401041;
}
var $ret10461047 = $Hcont_tail_arg26691052($z10421043,if_helper16411037);
++R.GAS;
return $ret10461047;
}
} else {
var cont_tail_arg16431056 = R.throwNonBooleanCondition(L[24],("if"),if_DASH_2821053);
if(--R.GAS > 0) {
$z10541055 = R.isFunction(if_helper16411037)?if_helper16411037.app(cont_tail_arg16431056):R.ffi.throwNonFunApp(L[24],if_helper16411037,[cont_tail_arg16431056]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper16411037)?if_helper16411037.app(cont_tail_arg16431056):R.ffi.throwNonFunApp(L[24],if_helper16411037,[cont_tail_arg16431056]);
},
"from":L[24]});
}
++R.GAS;
return $z10541055;
}
};
},{"length":3});
var anf_singleton_variant_member1652642 = R.makeMethod(function(self2811024) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[24],0,arguments);
}
var ann_DASH_check_DASH_temp16511023 = ("j-false");
return ann_DASH_check_DASH_temp16511023;
};
},{"length":1});
var anf_singleton_variant_member1654643 = R.makeMethod(function(self3671022) {
return function(printer3681019) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[123],1,arguments);
}
var $z10111012 = D;
var $f10171018 = function(_) {
return R.isFunction(printer3681019)?printer3681019.app(("false")):R.ffi.throwNonFunApp(L[123],printer3681019,[("false")]);
};
try {
if(--R.GAS > 0) {
$z10111012 = $f10171018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10171018,
"from":L[123]});
}
} catch($e10091010) {
if(R.isCont($e10091010)) {
var $ss10131014 = {"from":L[123],
"go":function(ann_DASH_check_DASH_temp16531020) {
return $Hann_DASH_check_DASH_temp26701021(ann_DASH_check_DASH_temp16531020);
}};
$e10091010.stack[R.EXN_STACKHEIGHT++] = $ss10131014;
}
if(R.isPyretException($e10091010)) {
$e10091010.pyretStack.push(L[123]);
}
throw $e10091010;
}
var $ret10151016 = $Hann_DASH_check_DASH_temp26701021($z10111012);
++R.GAS;
return $ret10151016;
};
},{"length":2});
var anf_singleton_variant_member1657644 = R.makeMethod(function(self3691008) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[121],0,arguments);
}
var anf_fun16561005 = G(PP123,"str",L[122]);
var $z997998 = D;
var $f10031004 = function(_) {
return R.isFunction(anf_fun16561005)?anf_fun16561005.app(("false")):R.ffi.throwNonFunApp(L[121],anf_fun16561005,[("false")]);
};
try {
if(--R.GAS > 0) {
$z997998 = $f10031004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10031004,
"from":L[121]});
}
} catch($e995996) {
if(R.isCont($e995996)) {
var $ss9991000 = {"from":L[121],
"go":function(ann_DASH_check_DASH_temp16551006) {
return $Hann_DASH_check_DASH_temp26711007(ann_DASH_check_DASH_temp16551006);
}};
$e995996.stack[R.EXN_STACKHEIGHT++] = $ss9991000;
}
if(R.isPyretException($e995996)) {
$e995996.pyretStack.push(L[121]);
}
throw $e995996;
}
var $ret10011002 = $Hann_DASH_check_DASH_temp26711007($z997998);
++R.GAS;
return $ret10011002;
};
},{"length":1});
var anf_singleton_variant_member1668650 = R.makeMethod(function(self284994) {
return function(cases_DASH_funs285973,else_DASH_clause286984) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[23],2,arguments);
}
var if_DASH_288987 = R.hasField(cases_DASH_funs285973,("j-null"));
var if_helper1659971 = R.makeFunction(function(if_helper_arg1660992) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
var ann_DASH_check_DASH_temp1658993 = if_helper_arg1660992;
return ann_DASH_check_DASH_temp1658993;
});
var anf_if1663991 = R.isBoolean(if_DASH_288987);
if(R.isPyretTrue(anf_if1663991)) {
if(R.isPyretTrue(if_DASH_288987)) {
var call_DASH_j_DASH_null283969 = G(cases_DASH_funs285973,"j-null",L[23]);
var $z961962 = D;
var $f967968 = function(_) {
return R.isFunction(call_DASH_j_DASH_null283969)?call_DASH_j_DASH_null283969.app():R.ffi.throwNonFunApp(L[23],call_DASH_j_DASH_null283969,[]);
};
try {
if(--R.GAS > 0) {
$z961962 = $f967968();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f967968,
"from":L[23]});
}
} catch($e959960) {
if(R.isCont($e959960)) {
var $ss963964 = {"from":L[23],
"go":function(cont_tail_arg1666970) {
return $Hcont_tail_arg2672972(cont_tail_arg1666970,if_helper1659971);
}};
$e959960.stack[R.EXN_STACKHEIGHT++] = $ss963964;
}
if(R.isPyretException($e959960)) {
$e959960.pyretStack.push(L[23]);
}
throw $e959960;
}
var $ret965966 = $Hcont_tail_arg2672972($z961962,if_helper1659971);
++R.GAS;
return $ret965966;
} else {
var $z976977 = D;
var $f982983 = function(_) {
return R.isFunction(else_DASH_clause286984)?else_DASH_clause286984.app():R.ffi.throwNonFunApp(L[23],else_DASH_clause286984,[]);
};
try {
if(--R.GAS > 0) {
$z976977 = $f982983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f982983,
"from":L[23]});
}
} catch($e974975) {
if(R.isCont($e974975)) {
var $ss978979 = {"from":L[23],
"go":function(cont_tail_arg1664985) {
return $Hcont_tail_arg2673986(cont_tail_arg1664985,if_helper1659971);
}};
$e974975.stack[R.EXN_STACKHEIGHT++] = $ss978979;
}
if(R.isPyretException($e974975)) {
$e974975.pyretStack.push(L[23]);
}
throw $e974975;
}
var $ret980981 = $Hcont_tail_arg2673986($z976977,if_helper1659971);
++R.GAS;
return $ret980981;
}
} else {
var cont_tail_arg1661990 = R.throwNonBooleanCondition(L[23],("if"),if_DASH_288987);
if(--R.GAS > 0) {
$z988989 = R.isFunction(if_helper1659971)?if_helper1659971.app(cont_tail_arg1661990):R.ffi.throwNonFunApp(L[23],if_helper1659971,[cont_tail_arg1661990]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1659971)?if_helper1659971.app(cont_tail_arg1661990):R.ffi.throwNonFunApp(L[23],if_helper1659971,[cont_tail_arg1661990]);
},
"from":L[23]});
}
++R.GAS;
return $z988989;
}
};
},{"length":3});
var anf_singleton_variant_member1670651 = R.makeMethod(function(self287958) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[23],0,arguments);
}
var ann_DASH_check_DASH_temp1669957 = ("j-null");
return ann_DASH_check_DASH_temp1669957;
};
},{"length":1});
var anf_singleton_variant_member1672652 = R.makeMethod(function(self370956) {
return function(printer371953) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[120],1,arguments);
}
var $z945946 = D;
var $f951952 = function(_) {
return R.isFunction(printer371953)?printer371953.app(("null")):R.ffi.throwNonFunApp(L[120],printer371953,[("null")]);
};
try {
if(--R.GAS > 0) {
$z945946 = $f951952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f951952,
"from":L[120]});
}
} catch($e943944) {
if(R.isCont($e943944)) {
var $ss947948 = {"from":L[120],
"go":function(ann_DASH_check_DASH_temp1671954) {
return $Hann_DASH_check_DASH_temp2674955(ann_DASH_check_DASH_temp1671954);
}};
$e943944.stack[R.EXN_STACKHEIGHT++] = $ss947948;
}
if(R.isPyretException($e943944)) {
$e943944.pyretStack.push(L[120]);
}
throw $e943944;
}
var $ret949950 = $Hann_DASH_check_DASH_temp2674955($z945946);
++R.GAS;
return $ret949950;
};
},{"length":2});
var anf_singleton_variant_member1675653 = R.makeMethod(function(self372942) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[118],0,arguments);
}
var anf_fun1674939 = G(PP123,"str",L[119]);
var $z931932 = D;
var $f937938 = function(_) {
return R.isFunction(anf_fun1674939)?anf_fun1674939.app(("null")):R.ffi.throwNonFunApp(L[118],anf_fun1674939,[("null")]);
};
try {
if(--R.GAS > 0) {
$z931932 = $f937938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f937938,
"from":L[118]});
}
} catch($e929930) {
if(R.isCont($e929930)) {
var $ss933934 = {"from":L[118],
"go":function(ann_DASH_check_DASH_temp1673940) {
return $Hann_DASH_check_DASH_temp2675941(ann_DASH_check_DASH_temp1673940);
}};
$e929930.stack[R.EXN_STACKHEIGHT++] = $ss933934;
}
if(R.isPyretException($e929930)) {
$e929930.pyretStack.push(L[118]);
}
throw $e929930;
}
var $ret935936 = $Hann_DASH_check_DASH_temp2675941($z931932);
++R.GAS;
return $ret935936;
};
},{"length":1});
var anf_singleton_variant_member1686659 = R.makeMethod(function(self290928) {
return function(cases_DASH_funs291907,else_DASH_clause292918) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[22],2,arguments);
}
var if_DASH_294921 = R.hasField(cases_DASH_funs291907,("j-undefined"));
var if_helper1677905 = R.makeFunction(function(if_helper_arg1678926) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
var ann_DASH_check_DASH_temp1676927 = if_helper_arg1678926;
return ann_DASH_check_DASH_temp1676927;
});
var anf_if1681925 = R.isBoolean(if_DASH_294921);
if(R.isPyretTrue(anf_if1681925)) {
if(R.isPyretTrue(if_DASH_294921)) {
var call_DASH_j_DASH_undefined289903 = G(cases_DASH_funs291907,"j-undefined",L[22]);
var $z895896 = D;
var $f901902 = function(_) {
return R.isFunction(call_DASH_j_DASH_undefined289903)?call_DASH_j_DASH_undefined289903.app():R.ffi.throwNonFunApp(L[22],call_DASH_j_DASH_undefined289903,[]);
};
try {
if(--R.GAS > 0) {
$z895896 = $f901902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f901902,
"from":L[22]});
}
} catch($e893894) {
if(R.isCont($e893894)) {
var $ss897898 = {"from":L[22],
"go":function(cont_tail_arg1684904) {
return $Hcont_tail_arg2676906(cont_tail_arg1684904,if_helper1677905);
}};
$e893894.stack[R.EXN_STACKHEIGHT++] = $ss897898;
}
if(R.isPyretException($e893894)) {
$e893894.pyretStack.push(L[22]);
}
throw $e893894;
}
var $ret899900 = $Hcont_tail_arg2676906($z895896,if_helper1677905);
++R.GAS;
return $ret899900;
} else {
var $z910911 = D;
var $f916917 = function(_) {
return R.isFunction(else_DASH_clause292918)?else_DASH_clause292918.app():R.ffi.throwNonFunApp(L[22],else_DASH_clause292918,[]);
};
try {
if(--R.GAS > 0) {
$z910911 = $f916917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f916917,
"from":L[22]});
}
} catch($e908909) {
if(R.isCont($e908909)) {
var $ss912913 = {"from":L[22],
"go":function(cont_tail_arg1682919) {
return $Hcont_tail_arg2677920(cont_tail_arg1682919,if_helper1677905);
}};
$e908909.stack[R.EXN_STACKHEIGHT++] = $ss912913;
}
if(R.isPyretException($e908909)) {
$e908909.pyretStack.push(L[22]);
}
throw $e908909;
}
var $ret914915 = $Hcont_tail_arg2677920($z910911,if_helper1677905);
++R.GAS;
return $ret914915;
}
} else {
var cont_tail_arg1679924 = R.throwNonBooleanCondition(L[22],("if"),if_DASH_294921);
if(--R.GAS > 0) {
$z922923 = R.isFunction(if_helper1677905)?if_helper1677905.app(cont_tail_arg1679924):R.ffi.throwNonFunApp(L[22],if_helper1677905,[cont_tail_arg1679924]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1677905)?if_helper1677905.app(cont_tail_arg1679924):R.ffi.throwNonFunApp(L[22],if_helper1677905,[cont_tail_arg1679924]);
},
"from":L[22]});
}
++R.GAS;
return $z922923;
}
};
},{"length":3});
var anf_singleton_variant_member1688660 = R.makeMethod(function(self293892) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[22],0,arguments);
}
var ann_DASH_check_DASH_temp1687891 = ("j-undefined");
return ann_DASH_check_DASH_temp1687891;
};
},{"length":1});
var anf_singleton_variant_member1690661 = R.makeMethod(function(self373890) {
return function(printer374887) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
var $z879880 = D;
var $f885886 = function(_) {
return R.isFunction(printer374887)?printer374887.app(("undefined")):R.ffi.throwNonFunApp(L[117],printer374887,[("undefined")]);
};
try {
if(--R.GAS > 0) {
$z879880 = $f885886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f885886,
"from":L[117]});
}
} catch($e877878) {
if(R.isCont($e877878)) {
var $ss881882 = {"from":L[117],
"go":function(ann_DASH_check_DASH_temp1689888) {
return $Hann_DASH_check_DASH_temp2678889(ann_DASH_check_DASH_temp1689888);
}};
$e877878.stack[R.EXN_STACKHEIGHT++] = $ss881882;
}
if(R.isPyretException($e877878)) {
$e877878.pyretStack.push(L[117]);
}
throw $e877878;
}
var $ret883884 = $Hann_DASH_check_DASH_temp2678889($z879880);
++R.GAS;
return $ret883884;
};
},{"length":2});
var anf_singleton_variant_member1693662 = R.makeMethod(function(self375876) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[115],0,arguments);
}
var anf_fun1692873 = G(PP123,"str",L[116]);
var $z865866 = D;
var $f871872 = function(_) {
return R.isFunction(anf_fun1692873)?anf_fun1692873.app(("undefined")):R.ffi.throwNonFunApp(L[115],anf_fun1692873,[("undefined")]);
};
try {
if(--R.GAS > 0) {
$z865866 = $f871872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f871872,
"from":L[115]});
}
} catch($e863864) {
if(R.isCont($e863864)) {
var $ss867868 = {"from":L[115],
"go":function(ann_DASH_check_DASH_temp1691874) {
return $Hann_DASH_check_DASH_temp2679875(ann_DASH_check_DASH_temp1691874);
}};
$e863864.stack[R.EXN_STACKHEIGHT++] = $ss867868;
}
if(R.isPyretException($e863864)) {
$e863864.pyretStack.push(L[115]);
}
throw $e863864;
}
var $ret869870 = $Hann_DASH_check_DASH_temp2679875($z865866);
++R.GAS;
return $ret869870;
};
},{"length":1});
var anf_variant_member1705668 = R.makeMethod(function(self296841) {
return function(cases_DASH_funs297842,else_DASH_clause298853) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[21],2,arguments);
}
var if_DASH_300856 = R.hasField(cases_DASH_funs297842,("j-raw"));
var if_helper1695839 = R.makeFunction(function(if_helper_arg1696861) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[21],1,arguments);
}
var ann_DASH_check_DASH_temp1694862 = if_helper_arg1696861;
return ann_DASH_check_DASH_temp1694862;
});
var anf_if1699860 = R.isBoolean(if_DASH_300856);
if(R.isPyretTrue(anf_if1699860)) {
if(R.isPyretTrue(if_DASH_300856)) {
var call_DASH_j_DASH_raw295836 = G(cases_DASH_funs297842,"j-raw",L[21]);
var anf_arg1702837 = G(self296841,"raw-js",L[114]);
var $z828829 = D;
var $f834835 = function(_) {
return R.isFunction(call_DASH_j_DASH_raw295836)?call_DASH_j_DASH_raw295836.app(anf_arg1702837):R.ffi.throwNonFunApp(L[21],call_DASH_j_DASH_raw295836,[anf_arg1702837]);
};
try {
if(--R.GAS > 0) {
$z828829 = $f834835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f834835,
"from":L[21]});
}
} catch($e826827) {
if(R.isCont($e826827)) {
var $ss830831 = {"from":L[21],
"go":function(cont_tail_arg1703838) {
return $Hcont_tail_arg2680840(cont_tail_arg1703838,if_helper1695839);
}};
$e826827.stack[R.EXN_STACKHEIGHT++] = $ss830831;
}
if(R.isPyretException($e826827)) {
$e826827.pyretStack.push(L[21]);
}
throw $e826827;
}
var $ret832833 = $Hcont_tail_arg2680840($z828829,if_helper1695839);
++R.GAS;
return $ret832833;
} else {
var $z845846 = D;
var $f851852 = function(_) {
return R.isFunction(else_DASH_clause298853)?else_DASH_clause298853.app():R.ffi.throwNonFunApp(L[21],else_DASH_clause298853,[]);
};
try {
if(--R.GAS > 0) {
$z845846 = $f851852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f851852,
"from":L[21]});
}
} catch($e843844) {
if(R.isCont($e843844)) {
var $ss847848 = {"from":L[21],
"go":function(cont_tail_arg1700854) {
return $Hcont_tail_arg2681855(cont_tail_arg1700854,if_helper1695839);
}};
$e843844.stack[R.EXN_STACKHEIGHT++] = $ss847848;
}
if(R.isPyretException($e843844)) {
$e843844.pyretStack.push(L[21]);
}
throw $e843844;
}
var $ret849850 = $Hcont_tail_arg2681855($z845846,if_helper1695839);
++R.GAS;
return $ret849850;
}
} else {
var cont_tail_arg1697859 = R.throwNonBooleanCondition(L[21],("if"),if_DASH_300856);
if(--R.GAS > 0) {
$z857858 = R.isFunction(if_helper1695839)?if_helper1695839.app(cont_tail_arg1697859):R.ffi.throwNonFunApp(L[21],if_helper1695839,[cont_tail_arg1697859]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1695839)?if_helper1695839.app(cont_tail_arg1697859):R.ffi.throwNonFunApp(L[21],if_helper1695839,[cont_tail_arg1697859]);
},
"from":L[21]});
}
++R.GAS;
return $z857858;
}
};
},{"length":3});
var anf_variant_member1711669 = R.makeMethod(function(self299825) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[21],0,arguments);
}
var anf_arg1707822 = G(self299825,"raw-js",L[21]);
var $z814815 = D;
var $f820821 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg1707822):R.ffi.throwNonFunApp(L[21],torepr18,[anf_arg1707822]);
};
try {
if(--R.GAS > 0) {
$z814815 = $f820821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f820821,
"from":L[21]});
}
} catch($e812813) {
if(R.isCont($e812813)) {
var $ss816817 = {"from":L[21],
"go":function(anf_arg1708823) {
return $Hanf_arg2685824(anf_arg1708823,_plus14);
}};
$e812813.stack[R.EXN_STACKHEIGHT++] = $ss816817;
}
if(R.isPyretException($e812813)) {
$e812813.pyretStack.push(L[21]);
}
throw $e812813;
}
var $ret818819 = $Hanf_arg2685824($z814815,_plus14);
++R.GAS;
return $ret818819;
};
},{"length":1});
var anf_variant_member1714670 = R.makeMethod(function(self377811) {
return function(printer378807) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[112],1,arguments);
}
var anf_arg1713808 = G(self377811,"raw-js",L[113]);
var $z799800 = D;
var $f805806 = function(_) {
return R.isFunction(printer378807)?printer378807.app(anf_arg1713808):R.ffi.throwNonFunApp(L[112],printer378807,[anf_arg1713808]);
};
try {
if(--R.GAS > 0) {
$z799800 = $f805806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f805806,
"from":L[112]});
}
} catch($e797798) {
if(R.isCont($e797798)) {
var $ss801802 = {"from":L[112],
"go":function(ann_DASH_check_DASH_temp1712809) {
return $Hann_DASH_check_DASH_temp2686810(ann_DASH_check_DASH_temp1712809);
}};
$e797798.stack[R.EXN_STACKHEIGHT++] = $ss801802;
}
if(R.isPyretException($e797798)) {
$e797798.pyretStack.push(L[112]);
}
throw $e797798;
}
var $ret803804 = $Hann_DASH_check_DASH_temp2686810($z799800);
++R.GAS;
return $ret803804;
};
},{"length":2});
var anf_variant_member1718671 = R.makeMethod(function(self379796) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[109],0,arguments);
}
var anf_fun1716792 = G(PP123,"str",L[111]);
var anf_arg1717793 = G(self379796,"raw-js",L[110]);
var $z784785 = D;
var $f790791 = function(_) {
return R.isFunction(anf_fun1716792)?anf_fun1716792.app(anf_arg1717793):R.ffi.throwNonFunApp(L[109],anf_fun1716792,[anf_arg1717793]);
};
try {
if(--R.GAS > 0) {
$z784785 = $f790791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f790791,
"from":L[109]});
}
} catch($e782783) {
if(R.isCont($e782783)) {
var $ss786787 = {"from":L[109],
"go":function(ann_DASH_check_DASH_temp1715794) {
return $Hann_DASH_check_DASH_temp2687795(ann_DASH_check_DASH_temp1715794);
}};
$e782783.stack[R.EXN_STACKHEIGHT++] = $ss786787;
}
if(R.isPyretException($e782783)) {
$e782783.pyretStack.push(L[109]);
}
throw $e782783;
}
var $ret788789 = $Hann_DASH_check_DASH_temp2687795($z784785);
++R.GAS;
return $ret788789;
};
},{"length":1});
var anf_variant_member1732678 = R.makeMethod(function(self302760) {
return function(cases_DASH_funs303761,else_DASH_clause304772) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[20],2,arguments);
}
var if_DASH_306775 = R.hasField(cases_DASH_funs303761,("j-raw-holes"));
var if_helper1720758 = R.makeFunction(function(if_helper_arg1721780) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[20],1,arguments);
}
var ann_DASH_check_DASH_temp1719781 = if_helper_arg1721780;
return ann_DASH_check_DASH_temp1719781;
});
var anf_if1724779 = R.isBoolean(if_DASH_306775);
if(R.isPyretTrue(anf_if1724779)) {
if(R.isPyretTrue(if_DASH_306775)) {
var call_DASH_j_DASH_raw_DASH_holes301753 = G(cases_DASH_funs303761,"j-raw-holes",L[20]);
var anf_arg1727754 = G(self302760,"raw-js",L[108]);
var anf_arg1728755 = G(self302760,"fills",L[107]);
var anf_arg1729756 = G(self302760,"width-tolerance",L[106]);
var $z745746 = D;
var $f751752 = function(_) {
return R.isFunction(call_DASH_j_DASH_raw_DASH_holes301753)?call_DASH_j_DASH_raw_DASH_holes301753.app(anf_arg1727754,anf_arg1728755,anf_arg1729756):R.ffi.throwNonFunApp(L[20],call_DASH_j_DASH_raw_DASH_holes301753,[anf_arg1727754,anf_arg1728755,anf_arg1729756]);
};
try {
if(--R.GAS > 0) {
$z745746 = $f751752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f751752,
"from":L[20]});
}
} catch($e743744) {
if(R.isCont($e743744)) {
var $ss747748 = {"from":L[20],
"go":function(cont_tail_arg1730757) {
return $Hcont_tail_arg2688759(cont_tail_arg1730757,if_helper1720758);
}};
$e743744.stack[R.EXN_STACKHEIGHT++] = $ss747748;
}
if(R.isPyretException($e743744)) {
$e743744.pyretStack.push(L[20]);
}
throw $e743744;
}
var $ret749750 = $Hcont_tail_arg2688759($z745746,if_helper1720758);
++R.GAS;
return $ret749750;
} else {
var $z764765 = D;
var $f770771 = function(_) {
return R.isFunction(else_DASH_clause304772)?else_DASH_clause304772.app():R.ffi.throwNonFunApp(L[20],else_DASH_clause304772,[]);
};
try {
if(--R.GAS > 0) {
$z764765 = $f770771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f770771,
"from":L[20]});
}
} catch($e762763) {
if(R.isCont($e762763)) {
var $ss766767 = {"from":L[20],
"go":function(cont_tail_arg1725773) {
return $Hcont_tail_arg2689774(cont_tail_arg1725773,if_helper1720758);
}};
$e762763.stack[R.EXN_STACKHEIGHT++] = $ss766767;
}
if(R.isPyretException($e762763)) {
$e762763.pyretStack.push(L[20]);
}
throw $e762763;
}
var $ret768769 = $Hcont_tail_arg2689774($z764765,if_helper1720758);
++R.GAS;
return $ret768769;
}
} else {
var cont_tail_arg1722778 = R.throwNonBooleanCondition(L[20],("if"),if_DASH_306775);
if(--R.GAS > 0) {
$z776777 = R.isFunction(if_helper1720758)?if_helper1720758.app(cont_tail_arg1722778):R.ffi.throwNonFunApp(L[20],if_helper1720758,[cont_tail_arg1722778]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1720758)?if_helper1720758.app(cont_tail_arg1722778):R.ffi.throwNonFunApp(L[20],if_helper1720758,[cont_tail_arg1722778]);
},
"from":L[20]});
}
++R.GAS;
return $z776777;
}
};
},{"length":3});
var anf_variant_member1746679 = R.makeMethod(function(self305741) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[20],0,arguments);
}
var anf_arg1734739 = G(self305741,"raw-js",L[20]);
var $z731732 = D;
var $f737738 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg1734739):R.ffi.throwNonFunApp(L[20],torepr18,[anf_arg1734739]);
};
try {
if(--R.GAS > 0) {
$z731732 = $f737738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f737738,
"from":L[20]});
}
} catch($e729730) {
if(R.isCont($e729730)) {
var $ss733734 = {"from":L[20],
"go":function(anf_arg1735740) {
return $Hanf_arg2699742(anf_arg1735740,self305741,_plus14,torepr18);
}};
$e729730.stack[R.EXN_STACKHEIGHT++] = $ss733734;
}
if(R.isPyretException($e729730)) {
$e729730.pyretStack.push(L[20]);
}
throw $e729730;
}
var $ret735736 = $Hanf_arg2699742($z731732,self305741,_plus14,torepr18);
++R.GAS;
return $ret735736;
};
},{"length":1});
var anf_variant_member1748680 = R.makeMethod(function(self383727) {
return function(printer384728) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[105],1,arguments);
}
var $z717718 = D;
var $f723724 = function(_) {
return R.isFunction(raise17)?raise17.app(("Cannot print with raw holes, not fancy enough")):R.ffi.throwNonFunApp(L[105],raise17,[("Cannot print with raw holes, not fancy enough")]);
};
try {
if(--R.GAS > 0) {
$z717718 = $f723724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f723724,
"from":L[105]});
}
} catch($e715716) {
if(R.isCont($e715716)) {
var $ss719720 = {"from":L[105],
"go":function(ann_DASH_check_DASH_temp1747725) {
return $Hann_DASH_check_DASH_temp2700726(ann_DASH_check_DASH_temp1747725);
}};
$e715716.stack[R.EXN_STACKHEIGHT++] = $ss719720;
}
if(R.isPyretException($e715716)) {
$e715716.pyretStack.push(L[105]);
}
throw $e715716;
}
var $ret721722 = $Hann_DASH_check_DASH_temp2700726($z717718);
++R.GAS;
return $ret721722;
};
},{"length":2});
var anf_variant_member1768681 = R.makeMethod(function(self385698) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[104],0,arguments);
}
var anf_bracket1750714 = G(self385698,"fills",L[103]);
var anf_fun1751695 = G(anf_bracket1750714,"map",L[102]);
var anf_arg1754696 = R.makeFunction(function(recv_DASH_307700) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[101],1,arguments);
}
var anf_fun1753711 = G(recv_DASH_307700,"tosource",L[101]);
var $z703704 = D;
var $f709710 = function(_) {
return R.isFunction(anf_fun1753711)?anf_fun1753711.app():R.ffi.throwNonFunApp(L[101],anf_fun1753711,[]);
};
try {
if(--R.GAS > 0) {
$z703704 = $f709710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f709710,
"from":L[101]});
}
} catch($e701702) {
if(R.isCont($e701702)) {
var $ss705706 = {"from":L[101],
"go":function(ann_DASH_check_DASH_temp1752712) {
return $Hann_DASH_check_DASH_temp2701713(ann_DASH_check_DASH_temp1752712);
}};
$e701702.stack[R.EXN_STACKHEIGHT++] = $ss705706;
}
if(R.isPyretException($e701702)) {
$e701702.pyretStack.push(L[101]);
}
throw $e701702;
}
var $ret707708 = $Hann_DASH_check_DASH_temp2701713($z703704);
++R.GAS;
return $ret707708;
});
var $z687688 = D;
var $f693694 = function(_) {
return R.isFunction(anf_fun1751695)?anf_fun1751695.app(anf_arg1754696):R.ffi.throwNonFunApp(L[100],anf_fun1751695,[anf_arg1754696]);
};
try {
if(--R.GAS > 0) {
$z687688 = $f693694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f693694,
"from":L[100]});
}
} catch($e685686) {
if(R.isCont($e685686)) {
var $ss689690 = {"from":L[100],
"go":function(filldocs386697) {
return $Hfilldocs2708699(filldocs386697,PP123,format7662,self385698);
}};
$e685686.stack[R.EXN_STACKHEIGHT++] = $ss689690;
}
if(R.isPyretException($e685686)) {
$e685686.pyretStack.push(L[100]);
}
throw $e685686;
}
var $ret691692 = $Hfilldocs2708699($z687688,PP123,format7662,self385698);
++R.GAS;
return $ret691692;
};
},{"length":1});
var anf_assign1769209 = (function() {
var $j_DASH_parens_DASH_base440441 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member777445,
"_torepr":anf_variant_member783446,
"print-ugly-source":anf_variant_member787447,
"tosource":anf_variant_member797448};
var $j_DASH_parens_DASH_brands443444 = {"$brand-j-parens442":true};
$j_DASH_parens_DASH_brands443444[JExprT67353._brand] = true
var $j_DASH_unop_DASH_base450451 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member810455,
"_torepr":anf_variant_member820456,
"print-ugly-source":anf_variant_member842457,
"tosource":anf_variant_member870458};
var $j_DASH_unop_DASH_brands453454 = {"$brand-j-unop452":true};
$j_DASH_unop_DASH_brands453454[JExprT67353._brand] = true
var $j_DASH_binop_DASH_base461462 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member884466,
"_torepr":anf_variant_member898467,
"print-ugly-source":anf_variant_member906468,
"tosource":anf_variant_member920469};
var $j_DASH_binop_DASH_brands464465 = {"$brand-j-binop463":true};
$j_DASH_binop_DASH_brands464465[JExprT67353._brand] = true
var $j_DASH_fun_DASH_base473474 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member933478,
"_torepr":anf_variant_member943479,
"print-ugly-source":anf_variant_member950480,
"tosource":anf_variant_member978481};
var $j_DASH_fun_DASH_brands476477 = {"$brand-j-fun475":true};
$j_DASH_fun_DASH_brands476477[JExprT67353._brand] = true
var $j_DASH_app_DASH_base484485 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member991489,
"_torepr":anf_variant_member1001490,
"print-ugly-source":anf_variant_member1021491,
"tosource":anf_variant_member1041492};
var $j_DASH_app_DASH_brands487488 = {"$brand-j-app486":true};
$j_DASH_app_DASH_brands487488[JExprT67353._brand] = true
var $j_DASH_method_DASH_base495496 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1055500,
"_torepr":anf_variant_member1069501,
"print-ugly-source":anf_variant_member1090502,
"tosource":anf_variant_member1117503};
var $j_DASH_method_DASH_brands498499 = {"$brand-j-method497":true};
$j_DASH_method_DASH_brands498499[JExprT67353._brand] = true
var $j_DASH_ternary_DASH_base507508 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1131512,
"_torepr":anf_variant_member1145513,
"print-ugly-source":anf_variant_member1153514,
"tosource":anf_variant_member1185515};
var $j_DASH_ternary_DASH_brands510511 = {"$brand-j-ternary509":true};
$j_DASH_ternary_DASH_brands510511[JExprT67353._brand] = true
var $j_DASH_assign_DASH_base519520 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1198524,
"_torepr":anf_variant_member1208525,
"print-ugly-source":anf_variant_member1213526,
"tosource":anf_variant_member1229527};
var $j_DASH_assign_DASH_brands522523 = {"$brand-j-assign521":true};
$j_DASH_assign_DASH_brands522523[JExprT67353._brand] = true
var $j_DASH_bracket_DASH_assign_DASH_base530531 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1243535,
"_torepr":anf_variant_member1257536,
"print-ugly-source":anf_variant_member1265537,
"tosource":anf_variant_member1289538};
var $j_DASH_bracket_DASH_assign_DASH_brands533534 = {"$brand-j-bracket-assign532":true};
$j_DASH_bracket_DASH_assign_DASH_brands533534[JExprT67353._brand] = true
var $j_DASH_dot_DASH_assign_DASH_base542543 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1303547,
"_torepr":anf_variant_member1317548,
"print-ugly-source":anf_variant_member1324549,
"tosource":anf_variant_member1347550};
var $j_DASH_dot_DASH_assign_DASH_brands545546 = {"$brand-j-dot-assign544":true};
$j_DASH_dot_DASH_assign_DASH_brands545546[JExprT67353._brand] = true
var $j_DASH_dot_DASH_base554555 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1360559,
"_torepr":anf_variant_member1370560,
"print-ugly-source":anf_variant_member1375561,
"tosource":anf_variant_member1386562};
var $j_DASH_dot_DASH_brands557558 = {"$brand-j-dot556":true};
$j_DASH_dot_DASH_brands557558[JExprT67353._brand] = true
var $j_DASH_bracket_DASH_base565566 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1399570,
"_torepr":anf_variant_member1409571,
"print-ugly-source":anf_variant_member1415572,
"tosource":anf_variant_member1429573};
var $j_DASH_bracket_DASH_brands568569 = {"$brand-j-bracket567":true};
$j_DASH_bracket_DASH_brands568569[JExprT67353._brand] = true
var $j_DASH_list_DASH_base576577 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1442581,
"_torepr":anf_variant_member1452582,
"print-ugly-source":anf_variant_member1477583,
"tosource":anf_variant_member1492584};
var $j_DASH_list_DASH_brands579580 = {"$brand-j-list578":true};
$j_DASH_list_DASH_brands579580[JExprT67353._brand] = true
var $j_DASH_obj_DASH_base587588 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1504592,
"_torepr":anf_variant_member1510593,
"print-ugly-source":anf_variant_member1528594,
"tosource":anf_variant_member1543595};
var $j_DASH_obj_DASH_brands590591 = {"$brand-j-obj589":true};
$j_DASH_obj_DASH_brands590591[JExprT67353._brand] = true
var $j_DASH_id_DASH_base597598 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1555602,
"_torepr":anf_variant_member1561603,
"print-ugly-source":anf_variant_member1564604,
"tosource":anf_variant_member1568605};
var $j_DASH_id_DASH_brands600601 = {"$brand-j-id599":true};
$j_DASH_id_DASH_brands600601[JExprT67353._brand] = true
var $j_DASH_str_DASH_base607608 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1580612,
"_torepr":anf_variant_member1586613,
"print-ugly-source":anf_variant_member1590614,
"tosource":anf_variant_member1595615};
var $j_DASH_str_DASH_brands610611 = {"$brand-j-str609":true};
$j_DASH_str_DASH_brands610611[JExprT67353._brand] = true
var $j_DASH_num_DASH_base617618 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1607622,
"_torepr":anf_variant_member1613623,
"print-ugly-source":anf_variant_member1617624,
"tosource":anf_variant_member1621625};
var $j_DASH_num_DASH_brands620621 = {"$brand-j-num619":true};
$j_DASH_num_DASH_brands620621[JExprT67353._brand] = true
var $j_DASH_true_DASH_base627628 = {"to-ugly-source":anf_shared765439,
"_match":anf_singleton_variant_member1632632,
"_torepr":anf_singleton_variant_member1634633,
"print-ugly-source":anf_singleton_variant_member1636634,
"tosource":anf_singleton_variant_member1639635};
var $j_DASH_true_DASH_brands630631 = {"$brand-j-true629":true};
$j_DASH_true_DASH_brands630631[JExprT67353._brand] = true
var $j_DASH_false_DASH_base636637 = {"to-ugly-source":anf_shared765439,
"_match":anf_singleton_variant_member1650641,
"_torepr":anf_singleton_variant_member1652642,
"print-ugly-source":anf_singleton_variant_member1654643,
"tosource":anf_singleton_variant_member1657644};
var $j_DASH_false_DASH_brands639640 = {"$brand-j-false638":true};
$j_DASH_false_DASH_brands639640[JExprT67353._brand] = true
var $j_DASH_null_DASH_base645646 = {"to-ugly-source":anf_shared765439,
"_match":anf_singleton_variant_member1668650,
"_torepr":anf_singleton_variant_member1670651,
"print-ugly-source":anf_singleton_variant_member1672652,
"tosource":anf_singleton_variant_member1675653};
var $j_DASH_null_DASH_brands648649 = {"$brand-j-null647":true};
$j_DASH_null_DASH_brands648649[JExprT67353._brand] = true
var $j_DASH_undefined_DASH_base654655 = {"to-ugly-source":anf_shared765439,
"_match":anf_singleton_variant_member1686659,
"_torepr":anf_singleton_variant_member1688660,
"print-ugly-source":anf_singleton_variant_member1690661,
"tosource":anf_singleton_variant_member1693662};
var $j_DASH_undefined_DASH_brands657658 = {"$brand-j-undefined656":true};
$j_DASH_undefined_DASH_brands657658[JExprT67353._brand] = true
var $j_DASH_raw_DASH_base663664 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1705668,
"_torepr":anf_variant_member1711669,
"print-ugly-source":anf_variant_member1714670,
"tosource":anf_variant_member1718671};
var $j_DASH_raw_DASH_brands666667 = {"$brand-j-raw665":true};
$j_DASH_raw_DASH_brands666667[JExprT67353._brand] = true
var $j_DASH_raw_DASH_holes_DASH_base673674 = {"to-ugly-source":anf_shared765439,
"_match":anf_variant_member1732678,
"_torepr":anf_variant_member1746679,
"print-ugly-source":anf_variant_member1748680,
"tosource":anf_variant_member1768681};
var $j_DASH_raw_DASH_holes_DASH_brands676677 = {"$brand-j-raw-holes675":true};
$j_DASH_raw_DASH_holes_DASH_brands676677[JExprT67353._brand] = true
return R.makeObject({"JExpr":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[43],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,JExprT67353._brand));
}),
"is-j-parens":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[42],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-parens442"));
}),
"j-parens":R.makeFunction(function(exp270449) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[44],1,arguments);
}
return R.checkAnnArgs([JExpr7252],[exp270449],[L[45]],function() {
var dict = R.create($j_DASH_parens_DASH_base440441);
dict["exp"] = exp270449
return R.makeBrandedObject(dict,$j_DASH_parens_DASH_brands443444);
});
}),
"is-j-unop":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[41],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-unop452"));
}),
"j-unop":R.makeFunction(function(exp274459,op275460) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[46],2,arguments);
}
return R.checkAnnArgs([JExpr7252,JUnop7058],[exp274459,op275460],[L[47],L[48]],function() {
var dict = R.create($j_DASH_unop_DASH_base450451);
dict["exp"] = exp274459
dict["op"] = op275460
return R.makeBrandedObject(dict,$j_DASH_unop_DASH_brands453454);
});
}),
"is-j-binop":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[40],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-binop463"));
}),
"j-binop":R.makeFunction(function(left279470,op280471,right281472) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[49],3,arguments);
}
return R.checkAnnArgs([JExpr7252,JBinop6848,JExpr7252],[left279470,op280471,right281472],[L[50],L[51],L[52]],function() {
var dict = R.create($j_DASH_binop_DASH_base461462);
dict["left"] = left279470
dict["op"] = op280471
dict["right"] = right281472
return R.makeBrandedObject(dict,$j_DASH_binop_DASH_brands464465);
});
}),
"is-j-fun":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[39],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-fun475"));
}),
"j-fun":R.makeFunction(function(args285482,body286483) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[53],2,arguments);
}
return R.checkAnnArgs([List1560,JBlock6450],[args285482,body286483],[L[54],L[55]],function() {
var dict = R.create($j_DASH_fun_DASH_base473474);
dict["args"] = args285482
dict["body"] = body286483
return R.makeBrandedObject(dict,$j_DASH_fun_DASH_brands476477);
});
}),
"is-j-app":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[38],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-app486"));
}),
"j-app":R.makeFunction(function(func292493,args293494) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[56],2,arguments);
}
return R.checkAnnArgs([JExpr7252,List1560],[func292493,args293494],[L[57],L[58]],function() {
var dict = R.create($j_DASH_app_DASH_base484485);
dict["func"] = func292493
dict["args"] = args293494
return R.makeBrandedObject(dict,$j_DASH_app_DASH_brands487488);
});
}),
"is-j-method":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[37],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-method497"));
}),
"j-method":R.makeFunction(function(obj299504,meth300505,args301506) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[59],3,arguments);
}
return R.checkAnnArgs([JExpr7252,$type$String22,List1560],[obj299504,meth300505,args301506],[L[60],L[61],L[62]],function() {
var dict = R.create($j_DASH_method_DASH_base495496);
dict["obj"] = obj299504
dict["meth"] = meth300505
dict["args"] = args301506
return R.makeBrandedObject(dict,$j_DASH_method_DASH_brands498499);
});
}),
"is-j-ternary":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[36],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-ternary509"));
}),
"j-ternary":R.makeFunction(function(test307516,consq308517,altern309518) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[63],3,arguments);
}
return R.checkAnnArgs([JExpr7252,JExpr7252,JExpr7252],[test307516,consq308517,altern309518],[L[64],L[65],L[66]],function() {
var dict = R.create($j_DASH_ternary_DASH_base507508);
dict["test"] = test307516
dict["consq"] = consq308517
dict["altern"] = altern309518
return R.makeBrandedObject(dict,$j_DASH_ternary_DASH_brands510511);
});
}),
"is-j-assign":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[35],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-assign521"));
}),
"j-assign":R.makeFunction(function(name313528,rhs314529) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[67],2,arguments);
}
return R.checkAnnArgs([$type$String22,JExpr7252],[name313528,rhs314529],[L[68],L[69]],function() {
var dict = R.create($j_DASH_assign_DASH_base519520);
dict["name"] = name313528
dict["rhs"] = rhs314529
return R.makeBrandedObject(dict,$j_DASH_assign_DASH_brands522523);
});
}),
"is-j-bracket-assign":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[34],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-bracket-assign532"));
}),
"j-bracket-assign":R.makeFunction(function(obj318539,field319540,rhs320541) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[70],3,arguments);
}
return R.checkAnnArgs([JExpr7252,JExpr7252,JExpr7252],[obj318539,field319540,rhs320541],[L[71],L[72],L[73]],function() {
var dict = R.create($j_DASH_bracket_DASH_assign_DASH_base530531);
dict["obj"] = obj318539
dict["field"] = field319540
dict["rhs"] = rhs320541
return R.makeBrandedObject(dict,$j_DASH_bracket_DASH_assign_DASH_brands533534);
});
}),
"is-j-dot-assign":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[33],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-dot-assign544"));
}),
"j-dot-assign":R.makeFunction(function(obj324551,name325552,rhs326553) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[74],3,arguments);
}
return R.checkAnnArgs([JExpr7252,$type$String22,JExpr7252],[obj324551,name325552,rhs326553],[L[75],L[76],L[77]],function() {
var dict = R.create($j_DASH_dot_DASH_assign_DASH_base542543);
dict["obj"] = obj324551
dict["name"] = name325552
dict["rhs"] = rhs326553
return R.makeBrandedObject(dict,$j_DASH_dot_DASH_assign_DASH_brands545546);
});
}),
"is-j-dot":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[32],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-dot556"));
}),
"j-dot":R.makeFunction(function(obj330563,field331564) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[78],2,arguments);
}
return R.checkAnnArgs([JExpr7252,$type$String22],[obj330563,field331564],[L[79],L[80]],function() {
var dict = R.create($j_DASH_dot_DASH_base554555);
dict["obj"] = obj330563
dict["field"] = field331564
return R.makeBrandedObject(dict,$j_DASH_dot_DASH_brands557558);
});
}),
"is-j-bracket":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[31],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-bracket567"));
}),
"j-bracket":R.makeFunction(function(obj335574,field336575) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[81],2,arguments);
}
return R.checkAnnArgs([JExpr7252,JExpr7252],[obj335574,field336575],[L[82],L[83]],function() {
var dict = R.create($j_DASH_bracket_DASH_base565566);
dict["obj"] = obj335574
dict["field"] = field336575
return R.makeBrandedObject(dict,$j_DASH_bracket_DASH_brands568569);
});
}),
"is-j-list":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-list578"));
}),
"j-list":R.makeFunction(function(multi_DASH_line340585,elts341586) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[84],2,arguments);
}
return R.checkAnnArgs([$type$Boolean20,List1560],[multi_DASH_line340585,elts341586],[L[85],L[86]],function() {
var dict = R.create($j_DASH_list_DASH_base576577);
dict["multi-line"] = multi_DASH_line340585
dict["elts"] = elts341586
return R.makeBrandedObject(dict,$j_DASH_list_DASH_brands579580);
});
}),
"is-j-obj":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[29],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-obj589"));
}),
"j-obj":R.makeFunction(function(fields346596) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[87],1,arguments);
}
return R.checkAnnArgs([List1560],[fields346596],[L[88]],function() {
var dict = R.create($j_DASH_obj_DASH_base587588);
dict["fields"] = fields346596
return R.makeBrandedObject(dict,$j_DASH_obj_DASH_brands590591);
});
}),
"is-j-id":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[28],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-id599"));
}),
"j-id":R.makeFunction(function(id352606) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[89],1,arguments);
}
return R.checkAnnArgs([$type$String22],[id352606],[L[90]],function() {
var dict = R.create($j_DASH_id_DASH_base597598);
dict["id"] = id352606
return R.makeBrandedObject(dict,$j_DASH_id_DASH_brands600601);
});
}),
"is-j-str":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[27],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-str609"));
}),
"j-str":R.makeFunction(function(s356616) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[91],1,arguments);
}
return R.checkAnnArgs([$type$String22],[s356616],[L[92]],function() {
var dict = R.create($j_DASH_str_DASH_base607608);
dict["s"] = s356616
return R.makeBrandedObject(dict,$j_DASH_str_DASH_brands610611);
});
}),
"is-j-num":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[26],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-num619"));
}),
"j-num":R.makeFunction(function(n360626) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[93],1,arguments);
}
return R.checkAnnArgs([$type$Number21],[n360626],[L[94]],function() {
var dict = R.create($j_DASH_num_DASH_base617618);
dict["n"] = n360626
return R.makeBrandedObject(dict,$j_DASH_num_DASH_brands620621);
});
}),
"is-j-true":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[25],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-true629"));
}),
"j-true":R.makeBrandedObject($j_DASH_true_DASH_base627628,$j_DASH_true_DASH_brands630631),
"is-j-false":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[24],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-false638"));
}),
"j-false":R.makeBrandedObject($j_DASH_false_DASH_base636637,$j_DASH_false_DASH_brands639640),
"is-j-null":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-null647"));
}),
"j-null":R.makeBrandedObject($j_DASH_null_DASH_base645646,$j_DASH_null_DASH_brands648649),
"is-j-undefined":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-undefined656"));
}),
"j-undefined":R.makeBrandedObject($j_DASH_undefined_DASH_base654655,$j_DASH_undefined_DASH_brands657658),
"is-j-raw":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[21],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-raw665"));
}),
"j-raw":R.makeFunction(function(raw_DASH_js376672) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[95],1,arguments);
}
return R.checkAnnArgs([$type$String22],[raw_DASH_js376672],[L[96]],function() {
var dict = R.create($j_DASH_raw_DASH_base663664);
dict["raw-js"] = raw_DASH_js376672
return R.makeBrandedObject(dict,$j_DASH_raw_DASH_brands666667);
});
}),
"is-j-raw-holes":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[20],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-raw-holes675"));
}),
"j-raw-holes":R.makeFunction(function(raw_DASH_js380682,fills381683,width_DASH_tolerance382684) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[97],3,arguments);
}
return R.checkAnnArgs([$type$String22,List1560],[raw_DASH_js380682,fills381683],[L[98],L[99]],function() {
var dict = R.create($j_DASH_raw_DASH_holes_DASH_base673674);
dict["raw-js"] = raw_DASH_js380682
dict["fills"] = fills381683
dict["width-tolerance"] = width_DASH_tolerance382684
return R.makeBrandedObject(dict,$j_DASH_raw_DASH_holes_DASH_brands676677);
});
})});
})();
JExpr12145208.$var = anf_assign1769209;
var anf_assign1770211 = G(JExpr12145208.$var,"JExpr",L[43]);
JExpr146210.$var = anf_assign1770211;
var anf_assign1771213 = G(JExpr12145208.$var,"JExpr",L[43]);
is_DASH_JExpr147212.$var = anf_assign1771213;
var anf_assign1772215 = G(JExpr12145208.$var,"is-j-parens",L[42]);
is_DASH_j_DASH_parens148214.$var = anf_assign1772215;
var anf_assign1773217 = G(JExpr12145208.$var,"j-parens",L[42]);
j_DASH_parens149216.$var = anf_assign1773217;
var anf_assign1774219 = G(JExpr12145208.$var,"is-j-unop",L[41]);
is_DASH_j_DASH_unop150218.$var = anf_assign1774219;
var anf_assign1775221 = G(JExpr12145208.$var,"j-unop",L[41]);
j_DASH_unop151220.$var = anf_assign1775221;
var anf_assign1776223 = G(JExpr12145208.$var,"is-j-binop",L[40]);
is_DASH_j_DASH_binop152222.$var = anf_assign1776223;
var anf_assign1777225 = G(JExpr12145208.$var,"j-binop",L[40]);
j_DASH_binop153224.$var = anf_assign1777225;
var anf_assign1778227 = G(JExpr12145208.$var,"is-j-fun",L[39]);
is_DASH_j_DASH_fun154226.$var = anf_assign1778227;
var anf_assign1779229 = G(JExpr12145208.$var,"j-fun",L[39]);
j_DASH_fun155228.$var = anf_assign1779229;
var anf_assign1780231 = G(JExpr12145208.$var,"is-j-app",L[38]);
is_DASH_j_DASH_app156230.$var = anf_assign1780231;
var anf_assign1781233 = G(JExpr12145208.$var,"j-app",L[38]);
j_DASH_app157232.$var = anf_assign1781233;
var anf_assign1782235 = G(JExpr12145208.$var,"is-j-method",L[37]);
is_DASH_j_DASH_method158234.$var = anf_assign1782235;
var anf_assign1783237 = G(JExpr12145208.$var,"j-method",L[37]);
j_DASH_method159236.$var = anf_assign1783237;
var anf_assign1784239 = G(JExpr12145208.$var,"is-j-ternary",L[36]);
is_DASH_j_DASH_ternary160238.$var = anf_assign1784239;
var anf_assign1785241 = G(JExpr12145208.$var,"j-ternary",L[36]);
j_DASH_ternary161240.$var = anf_assign1785241;
var anf_assign1786243 = G(JExpr12145208.$var,"is-j-assign",L[35]);
is_DASH_j_DASH_assign162242.$var = anf_assign1786243;
var anf_assign1787245 = G(JExpr12145208.$var,"j-assign",L[35]);
j_DASH_assign163244.$var = anf_assign1787245;
var anf_assign1788247 = G(JExpr12145208.$var,"is-j-bracket-assign",L[34]);
is_DASH_j_DASH_bracket_DASH_assign164246.$var = anf_assign1788247;
var anf_assign1789249 = G(JExpr12145208.$var,"j-bracket-assign",L[34]);
j_DASH_bracket_DASH_assign165248.$var = anf_assign1789249;
var anf_assign1790251 = G(JExpr12145208.$var,"is-j-dot-assign",L[33]);
is_DASH_j_DASH_dot_DASH_assign166250.$var = anf_assign1790251;
var anf_assign1791253 = G(JExpr12145208.$var,"j-dot-assign",L[33]);
j_DASH_dot_DASH_assign167252.$var = anf_assign1791253;
var anf_assign1792255 = G(JExpr12145208.$var,"is-j-dot",L[32]);
is_DASH_j_DASH_dot168254.$var = anf_assign1792255;
var anf_assign1793257 = G(JExpr12145208.$var,"j-dot",L[32]);
j_DASH_dot169256.$var = anf_assign1793257;
var anf_assign1794259 = G(JExpr12145208.$var,"is-j-bracket",L[31]);
is_DASH_j_DASH_bracket170258.$var = anf_assign1794259;
var anf_assign1795261 = G(JExpr12145208.$var,"j-bracket",L[31]);
j_DASH_bracket171260.$var = anf_assign1795261;
var anf_assign1796263 = G(JExpr12145208.$var,"is-j-list",L[30]);
is_DASH_j_DASH_list172262.$var = anf_assign1796263;
var anf_assign1797265 = G(JExpr12145208.$var,"j-list",L[30]);
j_DASH_list173264.$var = anf_assign1797265;
var anf_assign1798267 = G(JExpr12145208.$var,"is-j-obj",L[29]);
is_DASH_j_DASH_obj174266.$var = anf_assign1798267;
var anf_assign1799269 = G(JExpr12145208.$var,"j-obj",L[29]);
j_DASH_obj175268.$var = anf_assign1799269;
var anf_assign1800271 = G(JExpr12145208.$var,"is-j-id",L[28]);
is_DASH_j_DASH_id176270.$var = anf_assign1800271;
var anf_assign1801273 = G(JExpr12145208.$var,"j-id",L[28]);
j_DASH_id177272.$var = anf_assign1801273;
var anf_assign1802275 = G(JExpr12145208.$var,"is-j-str",L[27]);
is_DASH_j_DASH_str178274.$var = anf_assign1802275;
var anf_assign1803277 = G(JExpr12145208.$var,"j-str",L[27]);
j_DASH_str179276.$var = anf_assign1803277;
var anf_assign1804279 = G(JExpr12145208.$var,"is-j-num",L[26]);
is_DASH_j_DASH_num180278.$var = anf_assign1804279;
var anf_assign1805281 = G(JExpr12145208.$var,"j-num",L[26]);
j_DASH_num181280.$var = anf_assign1805281;
var anf_assign1806283 = G(JExpr12145208.$var,"is-j-true",L[25]);
is_DASH_j_DASH_true182282.$var = anf_assign1806283;
var anf_assign1807285 = G(JExpr12145208.$var,"j-true",L[25]);
j_DASH_true183284.$var = anf_assign1807285;
var anf_assign1808287 = G(JExpr12145208.$var,"is-j-false",L[24]);
is_DASH_j_DASH_false184286.$var = anf_assign1808287;
var anf_assign1809289 = G(JExpr12145208.$var,"j-false",L[24]);
j_DASH_false185288.$var = anf_assign1809289;
var anf_assign1810291 = G(JExpr12145208.$var,"is-j-null",L[23]);
is_DASH_j_DASH_null186290.$var = anf_assign1810291;
var anf_assign1811293 = G(JExpr12145208.$var,"j-null",L[23]);
j_DASH_null187292.$var = anf_assign1811293;
var anf_assign1812295 = G(JExpr12145208.$var,"is-j-undefined",L[22]);
is_DASH_j_DASH_undefined188294.$var = anf_assign1812295;
var anf_assign1813297 = G(JExpr12145208.$var,"j-undefined",L[22]);
j_DASH_undefined189296.$var = anf_assign1813297;
var anf_assign1814299 = G(JExpr12145208.$var,"is-j-raw",L[21]);
is_DASH_j_DASH_raw190298.$var = anf_assign1814299;
var anf_assign1815301 = G(JExpr12145208.$var,"j-raw",L[21]);
j_DASH_raw191300.$var = anf_assign1815301;
var anf_assign1816303 = G(JExpr12145208.$var,"is-j-raw-holes",L[20]);
is_DASH_j_DASH_raw_DASH_holes192302.$var = anf_assign1816303;
var anf_assign1817305 = G(JExpr12145208.$var,"j-raw-holes",L[20]);
j_DASH_raw_DASH_holes193304.$var = anf_assign1817305;
var anf_shared1822330 = R.makeMethod(function(self395437) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[19],0,arguments);
}
var $z428429 = D;
var $f434435 = function(_) {
return R.isFunction(string_DASH_printer8078.$var)?string_DASH_printer8078.$var.app():R.ffi.throwNonFunApp(L[18],string_DASH_printer8078.$var,[]);
};
try {
if(--R.GAS > 0) {
$z428429 = $f434435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f434435,
"from":L[18]});
}
} catch($e426427) {
if(R.isCont($e426427)) {
var $ss430431 = {"from":L[18],
"go":function(strprint396436) {
return $Hstrprint2712438(strprint396436,self395437);
}};
$e426427.stack[R.EXN_STACKHEIGHT++] = $ss430431;
}
if(R.isPyretException($e426427)) {
$e426427.pyretStack.push(L[18]);
}
throw $e426427;
}
var $ret432433 = $Hstrprint2712438($z428429,self395437);
++R.GAS;
return $ret432433;
};
},{"length":1});
var anf_variant_member1835336 = R.makeMethod(function(self311403) {
return function(cases_DASH_funs312404,else_DASH_clause313415) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3],2,arguments);
}
var if_DASH_315418 = R.hasField(cases_DASH_funs312404,("j-field"));
var if_helper1824401 = R.makeFunction(function(if_helper_arg1825424) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
var ann_DASH_check_DASH_temp1823425 = if_helper_arg1825424;
return ann_DASH_check_DASH_temp1823425;
});
var anf_if1828423 = R.isBoolean(if_DASH_315418);
if(R.isPyretTrue(anf_if1828423)) {
if(R.isPyretTrue(if_DASH_315418)) {
var call_DASH_j_DASH_field310397 = G(cases_DASH_funs312404,"j-field",L[3]);
var anf_arg1831398 = G(self311403,"name",L[17]);
var anf_arg1832399 = G(self311403,"value",L[16]);
var $z389390 = D;
var $f395396 = function(_) {
return R.isFunction(call_DASH_j_DASH_field310397)?call_DASH_j_DASH_field310397.app(anf_arg1831398,anf_arg1832399):R.ffi.throwNonFunApp(L[3],call_DASH_j_DASH_field310397,[anf_arg1831398,anf_arg1832399]);
};
try {
if(--R.GAS > 0) {
$z389390 = $f395396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f395396,
"from":L[3]});
}
} catch($e387388) {
if(R.isCont($e387388)) {
var $ss391392 = {"from":L[3],
"go":function(cont_tail_arg1833400) {
return $Hcont_tail_arg2713402(cont_tail_arg1833400,if_helper1824401);
}};
$e387388.stack[R.EXN_STACKHEIGHT++] = $ss391392;
}
if(R.isPyretException($e387388)) {
$e387388.pyretStack.push(L[3]);
}
throw $e387388;
}
var $ret393394 = $Hcont_tail_arg2713402($z389390,if_helper1824401);
++R.GAS;
return $ret393394;
} else {
var $z407408 = D;
var $f413414 = function(_) {
return R.isFunction(else_DASH_clause313415)?else_DASH_clause313415.app():R.ffi.throwNonFunApp(L[3],else_DASH_clause313415,[]);
};
try {
if(--R.GAS > 0) {
$z407408 = $f413414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f413414,
"from":L[3]});
}
} catch($e405406) {
if(R.isCont($e405406)) {
var $ss409410 = {"from":L[3],
"go":function(cont_tail_arg1829416) {
return $Hcont_tail_arg2714417(cont_tail_arg1829416,if_helper1824401);
}};
$e405406.stack[R.EXN_STACKHEIGHT++] = $ss409410;
}
if(R.isPyretException($e405406)) {
$e405406.pyretStack.push(L[3]);
}
throw $e405406;
}
var $ret411412 = $Hcont_tail_arg2714417($z407408,if_helper1824401);
++R.GAS;
return $ret411412;
}
} else {
var cont_tail_arg1826421 = R.throwNonBooleanCondition(L[3],("if"),if_DASH_315418);
if(--R.GAS > 0) {
$z419420 = R.isFunction(if_helper1824401)?if_helper1824401.app(cont_tail_arg1826421):R.ffi.throwNonFunApp(L[3],if_helper1824401,[cont_tail_arg1826421]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1824401)?if_helper1824401.app(cont_tail_arg1826421):R.ffi.throwNonFunApp(L[3],if_helper1824401,[cont_tail_arg1826421]);
},
"from":L[3]});
}
++R.GAS;
return $z419420;
}
};
},{"length":3});
var anf_variant_member1845337 = R.makeMethod(function(self314385) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[3],0,arguments);
}
var anf_arg1837383 = G(self314385,"name",L[3]);
var $z375376 = D;
var $f381382 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg1837383):R.ffi.throwNonFunApp(L[3],torepr18,[anf_arg1837383]);
};
try {
if(--R.GAS > 0) {
$z375376 = $f381382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f381382,
"from":L[3]});
}
} catch($e373374) {
if(R.isCont($e373374)) {
var $ss377378 = {"from":L[3],
"go":function(anf_arg1838384) {
return $Hanf_arg2721386(anf_arg1838384,self314385,_plus14,torepr18);
}};
$e373374.stack[R.EXN_STACKHEIGHT++] = $ss377378;
}
if(R.isPyretException($e373374)) {
$e373374.pyretStack.push(L[3]);
}
throw $e373374;
}
var $ret379380 = $Hanf_arg2721386($z375376,self314385,_plus14,torepr18);
++R.GAS;
return $ret379380;
};
},{"length":1});
var anf_variant_member1850338 = R.makeMethod(function(self392371) {
return function(printer393369) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[15],1,arguments);
}
var $z361362 = D;
var $f367368 = function(_) {
return R.isFunction(printer393369)?printer393369.app(("\"")):R.ffi.throwNonFunApp(L[14],printer393369,[("\"")]);
};
try {
if(--R.GAS > 0) {
$z361362 = $f367368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f367368,
"from":L[14]});
}
} catch($e359360) {
if(R.isCont($e359360)) {
var $ss363364 = {"from":L[14],
"go":function(anf_begin_app_dropped2722370) {
return $Hanf_begin_app_dropped2728372(anf_begin_app_dropped2722370,printer393369,self392371);
}};
$e359360.stack[R.EXN_STACKHEIGHT++] = $ss363364;
}
if(R.isPyretException($e359360)) {
$e359360.pyretStack.push(L[14]);
}
throw $e359360;
}
var $ret365366 = $Hanf_begin_app_dropped2728372($z361362,printer393369,self392371);
++R.GAS;
return $ret365366;
};
},{"length":2});
var anf_variant_member1865339 = R.makeMethod(function(self394357) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[13],0,arguments);
}
var anf_fun1852355 = G(PP123,"nest",L[12]);
var anf_fun1853356 = G(PP123,"dquote",L[11]);
var anf_fun1854352 = G(PP123,"str",L[10]);
var anf_arg1855353 = G(self394357,"name",L[9]);
var $z344345 = D;
var $f350351 = function(_) {
return R.isFunction(anf_fun1854352)?anf_fun1854352.app(anf_arg1855353):R.ffi.throwNonFunApp(L[8],anf_fun1854352,[anf_arg1855353]);
};
try {
if(--R.GAS > 0) {
$z344345 = $f350351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f350351,
"from":L[8]});
}
} catch($e342343) {
if(R.isCont($e342343)) {
var $ss346347 = {"from":L[8],
"go":function(anf_arg1856354) {
return $Hanf_arg2735358(anf_arg1856354,INDENT7747,PP123,anf_fun1852355,anf_fun1853356,self394357,_plus14);
}};
$e342343.stack[R.EXN_STACKHEIGHT++] = $ss346347;
}
if(R.isPyretException($e342343)) {
$e342343.pyretStack.push(L[8]);
}
throw $e342343;
}
var $ret348349 = $Hanf_arg2735358($z344345,INDENT7747,PP123,anf_fun1852355,anf_fun1853356,self394357,_plus14);
++R.GAS;
return $ret348349;
};
},{"length":1});
var anf_assign1866307 = (function() {
var $j_DASH_field_DASH_base331332 = {"to-ugly-source":anf_shared1822330,
"_match":anf_variant_member1835336,
"_torepr":anf_variant_member1845337,
"print-ugly-source":anf_variant_member1850338,
"tosource":anf_variant_member1865339};
var $j_DASH_field_DASH_brands334335 = {"$brand-j-field333":true};
$j_DASH_field_DASH_brands334335[JFieldT77555._brand] = true
return R.makeObject({"JField":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,JFieldT77555._brand));
}),
"is-j-field":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-j-field333"));
}),
"j-field":R.makeFunction(function(name390340,value391341) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[5],2,arguments);
}
return R.checkAnnArgs([$type$String22,JExpr7252],[name390340,value391341],[L[6],L[7]],function() {
var dict = R.create($j_DASH_field_DASH_base331332);
dict["name"] = name390340
dict["value"] = value391341
return R.makeBrandedObject(dict,$j_DASH_field_DASH_brands334335);
});
})});
})();
JField13194306.$var = anf_assign1866307;
var anf_assign1867309 = G(JField13194306.$var,"JField",L[4]);
JField195308.$var = anf_assign1867309;
var anf_assign1868311 = G(JField13194306.$var,"JField",L[4]);
is_DASH_JField196310.$var = anf_assign1868311;
var anf_assign1869313 = G(JField13194306.$var,"is-j-field",L[3]);
is_DASH_j_DASH_field197312.$var = anf_assign1869313;
var anf_assign1870315 = G(JField13194306.$var,"j-field",L[3]);
j_DASH_field198314.$var = anf_assign1870315;
var result_DASH_after_DASH_checks1397328 = nothing16;
var anf_fun1871326 = G(builtins15,"current-checker",L[2]);
var $z318319 = D;
var $f324325 = function(_) {
return R.isFunction(anf_fun1871326)?anf_fun1871326.app():R.ffi.throwNonFunApp(L[2],anf_fun1871326,[]);
};
try {
if(--R.GAS > 0) {
$z318319 = $f324325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f324325,
"from":L[2]});
}
} catch($e316317) {
if(R.isCont($e316317)) {
var $ss320321 = {"from":L[2],
"go":function(anf_bracket1872327) {
return $Hanf_bracket2811329(anf_bracket1872327,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,list2364,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15);
}};
$e316317.stack[R.EXN_STACKHEIGHT++] = $ss320321;
}
if(R.isPyretException($e316317)) {
$e316317.pyretStack.push(L[2]);
}
throw $e316317;
}
var $ret322323 = $Hanf_bracket2811329($z318319,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,list2364,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15);
++R.GAS;
return $ret322323;
};
var $Hanf_bracket2811329 = function(anf_bracket1872327,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,list2364,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15) {
var anf_fun18734384 = G(anf_bracket1872327,"run-checks",L[2]);
var anf_fun18744381 = G(list2364,"make",L[2]);
var anf_obj19814386 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[43],0,arguments);
}
var anf_fun18764398 = G(builtins15,"current-checker",L[483]);
var $z43904391 = D;
var $f43964397 = function(_) {
return R.isFunction(anf_fun18764398)?anf_fun18764398.app():R.ffi.throwNonFunApp(L[483],anf_fun18764398,[]);
};
try {
if(--R.GAS > 0) {
$z43904391 = $f43964397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43964397,
"from":L[483]});
}
} catch($e43884389) {
if(R.isCont($e43884389)) {
var $ss43924393 = {"from":L[483],
"go":function(anf_bracket18774399) {
return $Hanf_bracket28054400(anf_bracket18774399,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e43884389.stack[R.EXN_STACKHEIGHT++] = $ss43924393;
}
if(R.isPyretException($e43884389)) {
$e43884389.pyretStack.push(L[483]);
}
throw $e43884389;
}
var $ret43944395 = $Hanf_bracket28054400($z43904391,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret43944395;
});
var anf_obj19824387 = R.makeSrcloc(L[43]);
var anf_array_val19834382 = R.makeObject({"name":("JExpr"),
"run":anf_obj19814386,
"location":anf_obj19824387});
var $z43734374 = D;
var $f43794380 = function(_) {
return R.isFunction(anf_fun18744381)?anf_fun18744381.app([anf_array_val19834382]):R.ffi.throwNonFunApp(L[2],anf_fun18744381,[[anf_array_val19834382]]);
};
try {
if(--R.GAS > 0) {
$z43734374 = $f43794380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43794380,
"from":L[2]});
}
} catch($e43714372) {
if(R.isCont($e43714372)) {
var $ss43754376 = {"from":L[2],
"go":function(anf_arg19844383) {
return $Hanf_arg28104385(anf_arg19844383,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,anf_fun18734384,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15);
}};
$e43714372.stack[R.EXN_STACKHEIGHT++] = $ss43754376;
}
if(R.isPyretException($e43714372)) {
$e43714372.pyretStack.push(L[2]);
}
throw $e43714372;
}
var $ret43774378 = $Hanf_arg28104385($z43734374,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,anf_fun18734384,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15);
++R.GAS;
return $ret43774378;
};
var $Hanf_arg28104385 = function(anf_arg19844383,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,anf_fun18734384,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15) {
var $z44034404 = D;
var $f44094410 = function(_) {
return R.isFunction(anf_fun18734384)?anf_fun18734384.app(("src/arr/compiler/js-ast.arr"),anf_arg19844383):R.ffi.throwNonFunApp(L[2],anf_fun18734384,[("src/arr/compiler/js-ast.arr"),anf_arg19844383]);
};
try {
if(--R.GAS > 0) {
$z44034404 = $f44094410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44094410,
"from":L[2]});
}
} catch($e44014402) {
if(R.isCont($e44014402)) {
var $ss44054406 = {"from":L[2],
"go":function(anf_begin_app_dropped28064411) {
return $Hanf_begin_app_dropped28094412(anf_begin_app_dropped28064411,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15);
}};
$e44014402.stack[R.EXN_STACKHEIGHT++] = $ss44054406;
}
if(R.isPyretException($e44014402)) {
$e44014402.pyretStack.push(L[2]);
}
throw $e44014402;
}
var $ret44074408 = $Hanf_begin_app_dropped28094412($z44034404,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15);
++R.GAS;
return $ret44074408;
};
var $Hanf_begin_app_dropped28094412 = function(anf_begin_app_dropped28064411,INDENT7747,JBinop104126,JBinop6848,JBlock6450,JBlock8282,JExpr146210,JExpr7252,JField195308,JField7454,JStmt6656,JStmt8792,JUnop135188,JUnop7058,blank_DASH_one7976,break_DASH_one7846,format7662,is_DASH_JBinop105128,is_DASH_JBlock8384,is_DASH_JExpr147212,is_DASH_JField196310,is_DASH_JStmt8894,is_DASH_JUnop136190,is_DASH_j_DASH_and114146,is_DASH_j_DASH_app156230,is_DASH_j_DASH_assign162242,is_DASH_j_DASH_binop152222,is_DASH_j_DASH_block8486,is_DASH_j_DASH_bracket_DASH_assign164246,is_DASH_j_DASH_bracket170258,is_DASH_j_DASH_decr139196,is_DASH_j_DASH_divide112142,is_DASH_j_DASH_dot_DASH_assign166250,is_DASH_j_DASH_dot168254,is_DASH_j_DASH_eq126170,is_DASH_j_DASH_equals128174,is_DASH_j_DASH_expr101120,is_DASH_j_DASH_false184286,is_DASH_j_DASH_field197312,is_DASH_j_DASH_fun154226,is_DASH_j_DASH_geq124166,is_DASH_j_DASH_gt122162,is_DASH_j_DASH_id176270,is_DASH_j_DASH_if191100,is_DASH_j_DASH_if93104,is_DASH_j_DASH_incr137192,is_DASH_j_DASH_leq120158,is_DASH_j_DASH_list172262,is_DASH_j_DASH_lt118154,is_DASH_j_DASH_method158234,is_DASH_j_DASH_minus108134,is_DASH_j_DASH_neq130178,is_DASH_j_DASH_nequals132182,is_DASH_j_DASH_null186290,is_DASH_j_DASH_num180278,is_DASH_j_DASH_obj174266,is_DASH_j_DASH_or116150,is_DASH_j_DASH_parens148214,is_DASH_j_DASH_plus106130,is_DASH_j_DASH_postdecr143204,is_DASH_j_DASH_postincr141200,is_DASH_j_DASH_raw_DASH_holes192302,is_DASH_j_DASH_raw190298,is_DASH_j_DASH_return95108,is_DASH_j_DASH_str178274,is_DASH_j_DASH_ternary160238,is_DASH_j_DASH_throw99116,is_DASH_j_DASH_times110138,is_DASH_j_DASH_true182282,is_DASH_j_DASH_try_DASH_catch97112,is_DASH_j_DASH_undefined188294,is_DASH_j_DASH_unop150218,is_DASH_j_DASH_var8996,j_DASH_and115148,j_DASH_app157232,j_DASH_assign163244,j_DASH_binop153224,j_DASH_block8588,j_DASH_bracket_DASH_assign165248,j_DASH_bracket171260,j_DASH_decr140198,j_DASH_divide113144,j_DASH_dot_DASH_assign167252,j_DASH_dot169256,j_DASH_eq127172,j_DASH_equals129176,j_DASH_expr102122,j_DASH_false185288,j_DASH_field198314,j_DASH_fun155228,j_DASH_geq125168,j_DASH_gt123164,j_DASH_id177272,j_DASH_if192102,j_DASH_if94106,j_DASH_incr138194,j_DASH_leq121160,j_DASH_list173264,j_DASH_lt119156,j_DASH_method159236,j_DASH_minus109136,j_DASH_neq131180,j_DASH_nequals133184,j_DASH_null187292,j_DASH_num181280,j_DASH_obj175268,j_DASH_or117152,j_DASH_parens149216,j_DASH_plus107132,j_DASH_postdecr144206,j_DASH_postincr142202,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_ternary161240,j_DASH_throw100118,j_DASH_times111140,j_DASH_true183284,j_DASH_try_DASH_catch98114,j_DASH_undefined189296,j_DASH_unop151220,j_DASH_var9098,result_DASH_after_DASH_checks1397328,string_DASH_printer8078,builtins15) {
var provides19854425 = R.makeObject({"format":format7662,
"INDENT":INDENT7747,
"break-one":break_DASH_one7846,
"blank-one":blank_DASH_one7976,
"string-printer":string_DASH_printer8078.$var,
"JBlock":JBlock8282.$var,
"is-JBlock":is_DASH_JBlock8384.$var,
"j-block":j_DASH_block8588.$var,
"is-j-block":is_DASH_j_DASH_block8486.$var,
"JStmt":JStmt8792.$var,
"is-JStmt":is_DASH_JStmt8894.$var,
"j-var":j_DASH_var9098.$var,
"is-j-var":is_DASH_j_DASH_var8996.$var,
"j-if1":j_DASH_if192102.$var,
"is-j-if1":is_DASH_j_DASH_if191100.$var,
"j-if":j_DASH_if94106.$var,
"is-j-if":is_DASH_j_DASH_if93104.$var,
"j-return":j_DASH_return96110.$var,
"is-j-return":is_DASH_j_DASH_return95108.$var,
"j-try-catch":j_DASH_try_DASH_catch98114.$var,
"is-j-try-catch":is_DASH_j_DASH_try_DASH_catch97112.$var,
"j-throw":j_DASH_throw100118.$var,
"is-j-throw":is_DASH_j_DASH_throw99116.$var,
"j-expr":j_DASH_expr102122.$var,
"is-j-expr":is_DASH_j_DASH_expr101120.$var,
"JBinop":JBinop104126.$var,
"is-JBinop":is_DASH_JBinop105128.$var,
"j-plus":j_DASH_plus107132.$var,
"is-j-plus":is_DASH_j_DASH_plus106130.$var,
"j-minus":j_DASH_minus109136.$var,
"is-j-minus":is_DASH_j_DASH_minus108134.$var,
"j-times":j_DASH_times111140.$var,
"is-j-times":is_DASH_j_DASH_times110138.$var,
"j-divide":j_DASH_divide113144.$var,
"is-j-divide":is_DASH_j_DASH_divide112142.$var,
"j-and":j_DASH_and115148.$var,
"is-j-and":is_DASH_j_DASH_and114146.$var,
"j-or":j_DASH_or117152.$var,
"is-j-or":is_DASH_j_DASH_or116150.$var,
"j-lt":j_DASH_lt119156.$var,
"is-j-lt":is_DASH_j_DASH_lt118154.$var,
"j-leq":j_DASH_leq121160.$var,
"is-j-leq":is_DASH_j_DASH_leq120158.$var,
"j-gt":j_DASH_gt123164.$var,
"is-j-gt":is_DASH_j_DASH_gt122162.$var,
"j-geq":j_DASH_geq125168.$var,
"is-j-geq":is_DASH_j_DASH_geq124166.$var,
"j-eq":j_DASH_eq127172.$var,
"is-j-eq":is_DASH_j_DASH_eq126170.$var,
"j-equals":j_DASH_equals129176.$var,
"is-j-equals":is_DASH_j_DASH_equals128174.$var,
"j-neq":j_DASH_neq131180.$var,
"is-j-neq":is_DASH_j_DASH_neq130178.$var,
"j-nequals":j_DASH_nequals133184.$var,
"is-j-nequals":is_DASH_j_DASH_nequals132182.$var,
"JUnop":JUnop135188.$var,
"is-JUnop":is_DASH_JUnop136190.$var,
"j-incr":j_DASH_incr138194.$var,
"is-j-incr":is_DASH_j_DASH_incr137192.$var,
"j-decr":j_DASH_decr140198.$var,
"is-j-decr":is_DASH_j_DASH_decr139196.$var,
"j-postincr":j_DASH_postincr142202.$var,
"is-j-postincr":is_DASH_j_DASH_postincr141200.$var,
"j-postdecr":j_DASH_postdecr144206.$var,
"is-j-postdecr":is_DASH_j_DASH_postdecr143204.$var,
"JExpr":JExpr146210.$var,
"is-JExpr":is_DASH_JExpr147212.$var,
"j-parens":j_DASH_parens149216.$var,
"is-j-parens":is_DASH_j_DASH_parens148214.$var,
"j-unop":j_DASH_unop151220.$var,
"is-j-unop":is_DASH_j_DASH_unop150218.$var,
"j-binop":j_DASH_binop153224.$var,
"is-j-binop":is_DASH_j_DASH_binop152222.$var,
"j-fun":j_DASH_fun155228.$var,
"is-j-fun":is_DASH_j_DASH_fun154226.$var,
"j-app":j_DASH_app157232.$var,
"is-j-app":is_DASH_j_DASH_app156230.$var,
"j-method":j_DASH_method159236.$var,
"is-j-method":is_DASH_j_DASH_method158234.$var,
"j-ternary":j_DASH_ternary161240.$var,
"is-j-ternary":is_DASH_j_DASH_ternary160238.$var,
"j-assign":j_DASH_assign163244.$var,
"is-j-assign":is_DASH_j_DASH_assign162242.$var,
"j-bracket-assign":j_DASH_bracket_DASH_assign165248.$var,
"is-j-bracket-assign":is_DASH_j_DASH_bracket_DASH_assign164246.$var,
"j-dot-assign":j_DASH_dot_DASH_assign167252.$var,
"is-j-dot-assign":is_DASH_j_DASH_dot_DASH_assign166250.$var,
"j-dot":j_DASH_dot169256.$var,
"is-j-dot":is_DASH_j_DASH_dot168254.$var,
"j-bracket":j_DASH_bracket171260.$var,
"is-j-bracket":is_DASH_j_DASH_bracket170258.$var,
"j-list":j_DASH_list173264.$var,
"is-j-list":is_DASH_j_DASH_list172262.$var,
"j-obj":j_DASH_obj175268.$var,
"is-j-obj":is_DASH_j_DASH_obj174266.$var,
"j-id":j_DASH_id177272.$var,
"is-j-id":is_DASH_j_DASH_id176270.$var,
"j-str":j_DASH_str179276.$var,
"is-j-str":is_DASH_j_DASH_str178274.$var,
"j-num":j_DASH_num181280.$var,
"is-j-num":is_DASH_j_DASH_num180278.$var,
"j-true":j_DASH_true183284.$var,
"is-j-true":is_DASH_j_DASH_true182282.$var,
"j-false":j_DASH_false185288.$var,
"is-j-false":is_DASH_j_DASH_false184286.$var,
"j-null":j_DASH_null187292.$var,
"is-j-null":is_DASH_j_DASH_null186290.$var,
"j-undefined":j_DASH_undefined189296.$var,
"is-j-undefined":is_DASH_j_DASH_undefined188294.$var,
"j-raw":j_DASH_raw191300.$var,
"is-j-raw":is_DASH_j_DASH_raw190298.$var,
"j-raw-holes":j_DASH_raw_DASH_holes193304.$var,
"is-j-raw-holes":is_DASH_j_DASH_raw_DASH_holes192302.$var,
"JField":JField195308.$var,
"is-JField":is_DASH_JField196310.$var,
"j-field":j_DASH_field198314.$var,
"is-j-field":is_DASH_j_DASH_field197312.$var,
"result-after-checks1":result_DASH_after_DASH_checks1397328});
var anf_fun19864423 = G(builtins15,"current-checker",L[461]);
var $z44154416 = D;
var $f44214422 = function(_) {
return R.isFunction(anf_fun19864423)?anf_fun19864423.app():R.ffi.throwNonFunApp(L[461],anf_fun19864423,[]);
};
try {
if(--R.GAS > 0) {
$z44154416 = $f44214422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44214422,
"from":L[461]});
}
} catch($e44134414) {
if(R.isCont($e44134414)) {
var $ss44174418 = {"from":L[461],
"go":function(anf_bracket19874424) {
return $Hanf_bracket28084426(anf_bracket19874424,JBinop6848,JBlock6450,JExpr7252,JField7454,JStmt6656,JUnop7058,provides19854425,result_DASH_after_DASH_checks1397328);
}};
$e44134414.stack[R.EXN_STACKHEIGHT++] = $ss44174418;
}
if(R.isPyretException($e44134414)) {
$e44134414.pyretStack.push(L[461]);
}
throw $e44134414;
}
var $ret44194420 = $Hanf_bracket28084426($z44154416,JBinop6848,JBlock6450,JExpr7252,JField7454,JStmt6656,JUnop7058,provides19854425,result_DASH_after_DASH_checks1397328);
++R.GAS;
return $ret44194420;
};
var $Hanf_bracket28084426 = function(anf_bracket19874424,JBinop6848,JBlock6450,JExpr7252,JField7454,JStmt6656,JUnop7058,provides19854425,result_DASH_after_DASH_checks1397328) {
var anf_fun19884437 = G(anf_bracket19874424,"results",L[461]);
var $z44294430 = D;
var $f44354436 = function(_) {
return R.isFunction(anf_fun19884437)?anf_fun19884437.app():R.ffi.throwNonFunApp(L[461],anf_fun19884437,[]);
};
try {
if(--R.GAS > 0) {
$z44294430 = $f44354436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44354436,
"from":L[461]});
}
} catch($e44274428) {
if(R.isCont($e44274428)) {
var $ss44314432 = {"from":L[461],
"go":function(checks19894438) {
return $Hchecks28074439(checks19894438,JBinop6848,JBlock6450,JExpr7252,JField7454,JStmt6656,JUnop7058,provides19854425,result_DASH_after_DASH_checks1397328);
}};
$e44274428.stack[R.EXN_STACKHEIGHT++] = $ss44314432;
}
if(R.isPyretException($e44274428)) {
$e44274428.pyretStack.push(L[461]);
}
throw $e44274428;
}
var $ret44334434 = $Hchecks28074439($z44294430,JBinop6848,JBlock6450,JExpr7252,JField7454,JStmt6656,JUnop7058,provides19854425,result_DASH_after_DASH_checks1397328);
++R.GAS;
return $ret44334434;
};
var $Hchecks28074439 = function(checks19894438,JBinop6848,JBlock6450,JExpr7252,JField7454,JStmt6656,JUnop7058,provides19854425,result_DASH_after_DASH_checks1397328) {
return R.makeObject({"answer":result_DASH_after_DASH_checks1397328,
"provide-plus-types":R.makeObject({"values":provides19854425,
"types":{"JBlock":JBlock6450,
"JStmt":JStmt6656,
"JBinop":JBinop6848,
"JUnop":JUnop7058,
"JExpr":JExpr7252,
"JField":JField7454}}),
"checks":checks19894438});
};
var $Hanf_bracket28054400 = function(anf_bracket18774399,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun18784452 = G(anf_bracket18774399,"check-is",L[483]);
var anf_fun18794450 = G(list2364,"make",L[484]);
var $z44424443 = D;
var $f44484449 = function(_) {
return R.isFunction(anf_fun18794450)?anf_fun18794450.app([("a"),("b")]):R.ffi.throwNonFunApp(L[484],anf_fun18794450,[[("a"),("b")]]);
};
try {
if(--R.GAS > 0) {
$z44424443 = $f44484449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44484449,
"from":L[484]});
}
} catch($e44404441) {
if(R.isCont($e44404441)) {
var $ss44444445 = {"from":L[484],
"go":function(anf_arg18804451) {
return $Hanf_arg28044453(anf_arg18804451,anf_fun18784452,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e44404441.stack[R.EXN_STACKHEIGHT++] = $ss44444445;
}
if(R.isPyretException($e44404441)) {
$e44404441.pyretStack.push(L[484]);
}
throw $e44404441;
}
var $ret44464447 = $Hanf_arg28044453($z44424443,anf_fun18784452,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret44464447;
};
var $Hanf_arg28044453 = function(anf_arg18804451,anf_fun18784452,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun18814465 = G(list2364,"make",L[486]);
var $z44564457 = D;
var $f44624463 = function(_) {
return R.isFunction(j_DASH_id177272.$var)?j_DASH_id177272.$var.app(("a")):R.ffi.throwNonFunApp(L[485],j_DASH_id177272.$var,[("a")]);
};
try {
if(--R.GAS > 0) {
$z44564457 = $f44624463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44624463,
"from":L[485]});
}
} catch($e44544455) {
if(R.isCont($e44544455)) {
var $ss44584459 = {"from":L[485],
"go":function(anf_arg18824464) {
return $Hanf_arg28034466(anf_arg18824464,anf_arg18804451,anf_fun18784452,anf_fun18814465,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e44544455.stack[R.EXN_STACKHEIGHT++] = $ss44584459;
}
if(R.isPyretException($e44544455)) {
$e44544455.pyretStack.push(L[485]);
}
throw $e44544455;
}
var $ret44604461 = $Hanf_arg28034466($z44564457,anf_arg18804451,anf_fun18784452,anf_fun18814465,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret44604461;
};
var $Hanf_arg28034466 = function(anf_arg18824464,anf_arg18804451,anf_fun18784452,anf_fun18814465,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun18834478 = G(list2364,"make",L[488]);
var $z44694470 = D;
var $f44754476 = function(_) {
return R.isFunction(j_DASH_id177272.$var)?j_DASH_id177272.$var.app(("b")):R.ffi.throwNonFunApp(L[487],j_DASH_id177272.$var,[("b")]);
};
try {
if(--R.GAS > 0) {
$z44694470 = $f44754476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44754476,
"from":L[487]});
}
} catch($e44674468) {
if(R.isCont($e44674468)) {
var $ss44714472 = {"from":L[487],
"go":function(anf_array_val18844477) {
return $Hanf_array_val28024479(anf_array_val18844477,anf_arg18804451,anf_arg18824464,anf_fun18784452,anf_fun18814465,anf_fun18834478,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e44674468.stack[R.EXN_STACKHEIGHT++] = $ss44714472;
}
if(R.isPyretException($e44674468)) {
$e44674468.pyretStack.push(L[487]);
}
throw $e44674468;
}
var $ret44734474 = $Hanf_array_val28024479($z44694470,anf_arg18804451,anf_arg18824464,anf_fun18784452,anf_fun18814465,anf_fun18834478,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret44734474;
};
var $Hanf_array_val28024479 = function(anf_array_val18844477,anf_arg18804451,anf_arg18824464,anf_fun18784452,anf_fun18814465,anf_fun18834478,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z44824483 = D;
var $f44884489 = function(_) {
return R.isFunction(anf_fun18834478)?anf_fun18834478.app([anf_array_val18844477]):R.ffi.throwNonFunApp(L[488],anf_fun18834478,[[anf_array_val18844477]]);
};
try {
if(--R.GAS > 0) {
$z44824483 = $f44884489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44884489,
"from":L[488]});
}
} catch($e44804481) {
if(R.isCont($e44804481)) {
var $ss44844485 = {"from":L[488],
"go":function(anf_arg18854490) {
return $Hanf_arg28014491(anf_arg18854490,anf_arg18804451,anf_arg18824464,anf_fun18784452,anf_fun18814465,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e44804481.stack[R.EXN_STACKHEIGHT++] = $ss44844485;
}
if(R.isPyretException($e44804481)) {
$e44804481.pyretStack.push(L[488]);
}
throw $e44804481;
}
var $ret44864487 = $Hanf_arg28014491($z44824483,anf_arg18804451,anf_arg18824464,anf_fun18784452,anf_fun18814465,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret44864487;
};
var $Hanf_arg28014491 = function(anf_arg18854490,anf_arg18804451,anf_arg18824464,anf_fun18784452,anf_fun18814465,j_DASH_app157232,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z44944495 = D;
var $f45004501 = function(_) {
return R.isFunction(j_DASH_app157232.$var)?j_DASH_app157232.$var.app(anf_arg18824464,anf_arg18854490):R.ffi.throwNonFunApp(L[489],j_DASH_app157232.$var,[anf_arg18824464,anf_arg18854490]);
};
try {
if(--R.GAS > 0) {
$z44944495 = $f45004501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45004501,
"from":L[489]});
}
} catch($e44924493) {
if(R.isCont($e44924493)) {
var $ss44964497 = {"from":L[489],
"go":function(anf_array_val18864502) {
return $Hanf_array_val28004503(anf_array_val18864502,anf_arg18804451,anf_fun18784452,anf_fun18814465,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e44924493.stack[R.EXN_STACKHEIGHT++] = $ss44964497;
}
if(R.isPyretException($e44924493)) {
$e44924493.pyretStack.push(L[489]);
}
throw $e44924493;
}
var $ret44984499 = $Hanf_array_val28004503($z44944495,anf_arg18804451,anf_fun18784452,anf_fun18814465,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret44984499;
};
var $Hanf_array_val28004503 = function(anf_array_val18864502,anf_arg18804451,anf_fun18784452,anf_fun18814465,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z45064507 = D;
var $f45124513 = function(_) {
return R.isFunction(anf_fun18814465)?anf_fun18814465.app([anf_array_val18864502]):R.ffi.throwNonFunApp(L[486],anf_fun18814465,[[anf_array_val18864502]]);
};
try {
if(--R.GAS > 0) {
$z45064507 = $f45124513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45124513,
"from":L[486]});
}
} catch($e45044505) {
if(R.isCont($e45044505)) {
var $ss45084509 = {"from":L[486],
"go":function(anf_arg18874514) {
return $Hanf_arg27994515(anf_arg18874514,anf_arg18804451,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e45044505.stack[R.EXN_STACKHEIGHT++] = $ss45084509;
}
if(R.isPyretException($e45044505)) {
$e45044505.pyretStack.push(L[486]);
}
throw $e45044505;
}
var $ret45104511 = $Hanf_arg27994515($z45064507,anf_arg18804451,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret45104511;
};
var $Hanf_arg27994515 = function(anf_arg18874514,anf_arg18804451,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z45184519 = D;
var $f45244525 = function(_) {
return R.isFunction(j_DASH_block8588.$var)?j_DASH_block8588.$var.app(anf_arg18874514):R.ffi.throwNonFunApp(L[490],j_DASH_block8588.$var,[anf_arg18874514]);
};
try {
if(--R.GAS > 0) {
$z45184519 = $f45244525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45244525,
"from":L[490]});
}
} catch($e45164517) {
if(R.isCont($e45164517)) {
var $ss45204521 = {"from":L[490],
"go":function(anf_arg18884526) {
return $Hanf_arg27984527(anf_arg18884526,anf_arg18804451,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e45164517.stack[R.EXN_STACKHEIGHT++] = $ss45204521;
}
if(R.isPyretException($e45164517)) {
$e45164517.pyretStack.push(L[490]);
}
throw $e45164517;
}
var $ret45224523 = $Hanf_arg27984527($z45184519,anf_arg18804451,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret45224523;
};
var $Hanf_arg27984527 = function(anf_arg18884526,anf_arg18804451,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z45304531 = D;
var $f45364537 = function(_) {
return R.isFunction(j_DASH_fun155228.$var)?j_DASH_fun155228.$var.app(anf_arg18804451,anf_arg18884526):R.ffi.throwNonFunApp(L[491],j_DASH_fun155228.$var,[anf_arg18804451,anf_arg18884526]);
};
try {
if(--R.GAS > 0) {
$z45304531 = $f45364537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45364537,
"from":L[491]});
}
} catch($e45284529) {
if(R.isCont($e45284529)) {
var $ss45324533 = {"from":L[491],
"go":function(anf_bracket18894538) {
return $Hanf_bracket27974539(anf_bracket18894538,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e45284529.stack[R.EXN_STACKHEIGHT++] = $ss45324533;
}
if(R.isPyretException($e45284529)) {
$e45284529.pyretStack.push(L[491]);
}
throw $e45284529;
}
var $ret45344535 = $Hanf_bracket27974539($z45304531,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret45344535;
};
var $Hanf_bracket27974539 = function(anf_bracket18894538,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun18904550 = G(anf_bracket18894538,"tosource",L[493]);
var $z45424543 = D;
var $f45484549 = function(_) {
return R.isFunction(anf_fun18904550)?anf_fun18904550.app():R.ffi.throwNonFunApp(L[492],anf_fun18904550,[]);
};
try {
if(--R.GAS > 0) {
$z45424543 = $f45484549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45484549,
"from":L[492]});
}
} catch($e45404541) {
if(R.isCont($e45404541)) {
var $ss45444545 = {"from":L[492],
"go":function(anf_bracket18914551) {
return $Hanf_bracket27964552(anf_bracket18914551,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e45404541.stack[R.EXN_STACKHEIGHT++] = $ss45444545;
}
if(R.isPyretException($e45404541)) {
$e45404541.pyretStack.push(L[492]);
}
throw $e45404541;
}
var $ret45464547 = $Hanf_bracket27964552($z45424543,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret45464547;
};
var $Hanf_bracket27964552 = function(anf_bracket18914551,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun18924563 = G(anf_bracket18914551,"pretty",L[495]);
var $z45554556 = D;
var $f45614562 = function(_) {
return R.isFunction(anf_fun18924563)?anf_fun18924563.app((80)):R.ffi.throwNonFunApp(L[494],anf_fun18924563,[(80)]);
};
try {
if(--R.GAS > 0) {
$z45554556 = $f45614562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45614562,
"from":L[494]});
}
} catch($e45534554) {
if(R.isCont($e45534554)) {
var $ss45574558 = {"from":L[494],
"go":function(anf_arg18934564) {
return $Hanf_arg27954565(anf_arg18934564,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e45534554.stack[R.EXN_STACKHEIGHT++] = $ss45574558;
}
if(R.isPyretException($e45534554)) {
$e45534554.pyretStack.push(L[494]);
}
throw $e45534554;
}
var $ret45594560 = $Hanf_arg27954565($z45554556,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret45594560;
};
var $Hanf_arg27954565 = function(anf_arg18934564,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun18944576 = G(list2364,"make",L[496]);
var $z45684569 = D;
var $f45744575 = function(_) {
return R.isFunction(anf_fun18944576)?anf_fun18944576.app([("function(a, b) { a(b) }")]):R.ffi.throwNonFunApp(L[496],anf_fun18944576,[[("function(a, b) { a(b) }")]]);
};
try {
if(--R.GAS > 0) {
$z45684569 = $f45744575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45744575,
"from":L[496]});
}
} catch($e45664567) {
if(R.isCont($e45664567)) {
var $ss45704571 = {"from":L[496],
"go":function(anf_arg18954577) {
return $Hanf_arg27944578(anf_arg18954577,anf_arg18934564,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e45664567.stack[R.EXN_STACKHEIGHT++] = $ss45704571;
}
if(R.isPyretException($e45664567)) {
$e45664567.pyretStack.push(L[496]);
}
throw $e45664567;
}
var $ret45724573 = $Hanf_arg27944578($z45684569,anf_arg18934564,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret45724573;
};
var $Hanf_arg27944578 = function(anf_arg18954577,anf_arg18934564,anf_fun18784452,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_arg18964589 = R.makeSrcloc(L[483]);
var $z45814582 = D;
var $f45874588 = function(_) {
return R.isFunction(anf_fun18784452)?anf_fun18784452.app(("j-fun([list: \"a\", \"b\"], j-block([list: j-app(j-id(\"a\"), [list: j-id(\"b\")])]))\n  .tosource()\n  .pretty(80) is\n  [list: \"function(a, b) { a(b) }\"]"),anf_arg18934564,anf_arg18954577,anf_arg18964589):R.ffi.throwNonFunApp(L[483],anf_fun18784452,[("j-fun([list: \"a\", \"b\"], j-block([list: j-app(j-id(\"a\"), [list: j-id(\"b\")])]))\n  .tosource()\n  .pretty(80) is\n  [list: \"function(a, b) { a(b) }\"]"),anf_arg18934564,anf_arg18954577,anf_arg18964589]);
};
try {
if(--R.GAS > 0) {
$z45814582 = $f45874588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45874588,
"from":L[483]});
}
} catch($e45794580) {
if(R.isCont($e45794580)) {
var $ss45834584 = {"from":L[483],
"go":function(anf_begin_app_dropped27364590) {
return $Hanf_begin_app_dropped27934591(anf_begin_app_dropped27364590,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e45794580.stack[R.EXN_STACKHEIGHT++] = $ss45834584;
}
if(R.isPyretException($e45794580)) {
$e45794580.pyretStack.push(L[483]);
}
throw $e45794580;
}
var $ret45854586 = $Hanf_begin_app_dropped27934591($z45814582,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret45854586;
};
var $Hanf_begin_app_dropped27934591 = function(anf_begin_app_dropped27364590,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun18974602 = G(builtins15,"current-checker",L[497]);
var $z45944595 = D;
var $f46004601 = function(_) {
return R.isFunction(anf_fun18974602)?anf_fun18974602.app():R.ffi.throwNonFunApp(L[497],anf_fun18974602,[]);
};
try {
if(--R.GAS > 0) {
$z45944595 = $f46004601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46004601,
"from":L[497]});
}
} catch($e45924593) {
if(R.isCont($e45924593)) {
var $ss45964597 = {"from":L[497],
"go":function(anf_bracket18984603) {
return $Hanf_bracket27924604(anf_bracket18984603,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e45924593.stack[R.EXN_STACKHEIGHT++] = $ss45964597;
}
if(R.isPyretException($e45924593)) {
$e45924593.pyretStack.push(L[497]);
}
throw $e45924593;
}
var $ret45984599 = $Hanf_bracket27924604($z45944595,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret45984599;
};
var $Hanf_bracket27924604 = function(anf_bracket18984603,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun18994617 = G(anf_bracket18984603,"check-is",L[497]);
var anf_fun19004615 = G(list2364,"make",L[498]);
var $z46074608 = D;
var $f46134614 = function(_) {
return R.isFunction(anf_fun19004615)?anf_fun19004615.app([("RUNTIME"),("NAMESPACE")]):R.ffi.throwNonFunApp(L[498],anf_fun19004615,[[("RUNTIME"),("NAMESPACE")]]);
};
try {
if(--R.GAS > 0) {
$z46074608 = $f46134614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46134614,
"from":L[498]});
}
} catch($e46054606) {
if(R.isCont($e46054606)) {
var $ss46094610 = {"from":L[498],
"go":function(anf_arg19014616) {
return $Hanf_arg27914618(anf_arg19014616,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e46054606.stack[R.EXN_STACKHEIGHT++] = $ss46094610;
}
if(R.isPyretException($e46054606)) {
$e46054606.pyretStack.push(L[498]);
}
throw $e46054606;
}
var $ret46114612 = $Hanf_arg27914618($z46074608,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret46114612;
};
var $Hanf_arg27914618 = function(anf_arg19014616,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun19024630 = G(list2364,"make",L[500]);
var $z46214622 = D;
var $f46274628 = function(_) {
return R.isFunction(j_DASH_id177272.$var)?j_DASH_id177272.$var.app(("NAMESPACE")):R.ffi.throwNonFunApp(L[499],j_DASH_id177272.$var,[("NAMESPACE")]);
};
try {
if(--R.GAS > 0) {
$z46214622 = $f46274628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46274628,
"from":L[499]});
}
} catch($e46194620) {
if(R.isCont($e46194620)) {
var $ss46234624 = {"from":L[499],
"go":function(anf_arg19034629) {
return $Hanf_arg27904631(anf_arg19034629,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e46194620.stack[R.EXN_STACKHEIGHT++] = $ss46234624;
}
if(R.isPyretException($e46194620)) {
$e46194620.pyretStack.push(L[499]);
}
throw $e46194620;
}
var $ret46254626 = $Hanf_arg27904631($z46214622,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret46254626;
};
var $Hanf_arg27904631 = function(anf_arg19034629,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun19044643 = G(list2364,"make",L[502]);
var $z46344635 = D;
var $f46404641 = function(_) {
return R.isFunction(j_DASH_str179276.$var)?j_DASH_str179276.$var.app(("print")):R.ffi.throwNonFunApp(L[501],j_DASH_str179276.$var,[("print")]);
};
try {
if(--R.GAS > 0) {
$z46344635 = $f46404641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46404641,
"from":L[501]});
}
} catch($e46324633) {
if(R.isCont($e46324633)) {
var $ss46364637 = {"from":L[501],
"go":function(anf_array_val19054642) {
return $Hanf_array_val27894644(anf_array_val19054642,anf_arg19014616,anf_arg19034629,anf_fun18994617,anf_fun19024630,anf_fun19044643,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e46324633.stack[R.EXN_STACKHEIGHT++] = $ss46364637;
}
if(R.isPyretException($e46324633)) {
$e46324633.pyretStack.push(L[501]);
}
throw $e46324633;
}
var $ret46384639 = $Hanf_array_val27894644($z46344635,anf_arg19014616,anf_arg19034629,anf_fun18994617,anf_fun19024630,anf_fun19044643,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret46384639;
};
var $Hanf_array_val27894644 = function(anf_array_val19054642,anf_arg19014616,anf_arg19034629,anf_fun18994617,anf_fun19024630,anf_fun19044643,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z46474648 = D;
var $f46534654 = function(_) {
return R.isFunction(anf_fun19044643)?anf_fun19044643.app([anf_array_val19054642]):R.ffi.throwNonFunApp(L[502],anf_fun19044643,[[anf_array_val19054642]]);
};
try {
if(--R.GAS > 0) {
$z46474648 = $f46534654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46534654,
"from":L[502]});
}
} catch($e46454646) {
if(R.isCont($e46454646)) {
var $ss46494650 = {"from":L[502],
"go":function(anf_arg19064655) {
return $Hanf_arg27884656(anf_arg19064655,anf_arg19014616,anf_arg19034629,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e46454646.stack[R.EXN_STACKHEIGHT++] = $ss46494650;
}
if(R.isPyretException($e46454646)) {
$e46454646.pyretStack.push(L[502]);
}
throw $e46454646;
}
var $ret46514652 = $Hanf_arg27884656($z46474648,anf_arg19014616,anf_arg19034629,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret46514652;
};
var $Hanf_arg27884656 = function(anf_arg19064655,anf_arg19014616,anf_arg19034629,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z46594660 = D;
var $f46654666 = function(_) {
return R.isFunction(j_DASH_method159236.$var)?j_DASH_method159236.$var.app(anf_arg19034629,("get"),anf_arg19064655):R.ffi.throwNonFunApp(L[503],j_DASH_method159236.$var,[anf_arg19034629,("get"),anf_arg19064655]);
};
try {
if(--R.GAS > 0) {
$z46594660 = $f46654666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46654666,
"from":L[503]});
}
} catch($e46574658) {
if(R.isCont($e46574658)) {
var $ss46614662 = {"from":L[503],
"go":function(anf_arg19074667) {
return $Hanf_arg27874668(anf_arg19074667,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e46574658.stack[R.EXN_STACKHEIGHT++] = $ss46614662;
}
if(R.isPyretException($e46574658)) {
$e46574658.pyretStack.push(L[503]);
}
throw $e46574658;
}
var $ret46634664 = $Hanf_arg27874668($z46594660,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret46634664;
};
var $Hanf_arg27874668 = function(anf_arg19074667,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z46714672 = D;
var $f46774678 = function(_) {
return R.isFunction(j_DASH_var9098.$var)?j_DASH_var9098.$var.app(("print"),anf_arg19074667):R.ffi.throwNonFunApp(L[504],j_DASH_var9098.$var,[("print"),anf_arg19074667]);
};
try {
if(--R.GAS > 0) {
$z46714672 = $f46774678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46774678,
"from":L[504]});
}
} catch($e46694670) {
if(R.isCont($e46694670)) {
var $ss46734674 = {"from":L[504],
"go":function(anf_array_val19084679) {
return $Hanf_array_val27864680(anf_array_val19084679,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e46694670.stack[R.EXN_STACKHEIGHT++] = $ss46734674;
}
if(R.isPyretException($e46694670)) {
$e46694670.pyretStack.push(L[504]);
}
throw $e46694670;
}
var $ret46754676 = $Hanf_array_val27864680($z46714672,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret46754676;
};
var $Hanf_array_val27864680 = function(anf_array_val19084679,anf_arg19014616,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z46834684 = D;
var $f46894690 = function(_) {
return R.isFunction(j_DASH_id177272.$var)?j_DASH_id177272.$var.app(("NAMESPACE")):R.ffi.throwNonFunApp(L[505],j_DASH_id177272.$var,[("NAMESPACE")]);
};
try {
if(--R.GAS > 0) {
$z46834684 = $f46894690();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46894690,
"from":L[505]});
}
} catch($e46814682) {
if(R.isCont($e46814682)) {
var $ss46854686 = {"from":L[505],
"go":function(anf_arg19094691) {
return $Hanf_arg27854692(anf_arg19094691,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e46814682.stack[R.EXN_STACKHEIGHT++] = $ss46854686;
}
if(R.isPyretException($e46814682)) {
$e46814682.pyretStack.push(L[505]);
}
throw $e46814682;
}
var $ret46874688 = $Hanf_arg27854692($z46834684,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret46874688;
};
var $Hanf_arg27854692 = function(anf_arg19094691,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_str179276,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var anf_fun19104704 = G(list2364,"make",L[507]);
var $z46954696 = D;
var $f47014702 = function(_) {
return R.isFunction(j_DASH_str179276.$var)?j_DASH_str179276.$var.app(("brand")):R.ffi.throwNonFunApp(L[506],j_DASH_str179276.$var,[("brand")]);
};
try {
if(--R.GAS > 0) {
$z46954696 = $f47014702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47014702,
"from":L[506]});
}
} catch($e46934694) {
if(R.isCont($e46934694)) {
var $ss46974698 = {"from":L[506],
"go":function(anf_array_val19114703) {
return $Hanf_array_val27844705(anf_array_val19114703,anf_arg19014616,anf_arg19094691,anf_array_val19084679,anf_fun18994617,anf_fun19024630,anf_fun19104704,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e46934694.stack[R.EXN_STACKHEIGHT++] = $ss46974698;
}
if(R.isPyretException($e46934694)) {
$e46934694.pyretStack.push(L[506]);
}
throw $e46934694;
}
var $ret46994700 = $Hanf_array_val27844705($z46954696,anf_arg19014616,anf_arg19094691,anf_array_val19084679,anf_fun18994617,anf_fun19024630,anf_fun19104704,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret46994700;
};
var $Hanf_array_val27844705 = function(anf_array_val19114703,anf_arg19014616,anf_arg19094691,anf_array_val19084679,anf_fun18994617,anf_fun19024630,anf_fun19104704,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z47084709 = D;
var $f47144715 = function(_) {
return R.isFunction(anf_fun19104704)?anf_fun19104704.app([anf_array_val19114703]):R.ffi.throwNonFunApp(L[507],anf_fun19104704,[[anf_array_val19114703]]);
};
try {
if(--R.GAS > 0) {
$z47084709 = $f47144715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47144715,
"from":L[507]});
}
} catch($e47064707) {
if(R.isCont($e47064707)) {
var $ss47104711 = {"from":L[507],
"go":function(anf_arg19124716) {
return $Hanf_arg27834717(anf_arg19124716,anf_arg19014616,anf_arg19094691,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e47064707.stack[R.EXN_STACKHEIGHT++] = $ss47104711;
}
if(R.isPyretException($e47064707)) {
$e47064707.pyretStack.push(L[507]);
}
throw $e47064707;
}
var $ret47124713 = $Hanf_arg27834717($z47084709,anf_arg19014616,anf_arg19094691,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret47124713;
};
var $Hanf_arg27834717 = function(anf_arg19124716,anf_arg19014616,anf_arg19094691,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_method159236,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z47204721 = D;
var $f47264727 = function(_) {
return R.isFunction(j_DASH_method159236.$var)?j_DASH_method159236.$var.app(anf_arg19094691,("get"),anf_arg19124716):R.ffi.throwNonFunApp(L[508],j_DASH_method159236.$var,[anf_arg19094691,("get"),anf_arg19124716]);
};
try {
if(--R.GAS > 0) {
$z47204721 = $f47264727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47264727,
"from":L[508]});
}
} catch($e47184719) {
if(R.isCont($e47184719)) {
var $ss47224723 = {"from":L[508],
"go":function(anf_arg19134728) {
return $Hanf_arg27824729(anf_arg19134728,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
}};
$e47184719.stack[R.EXN_STACKHEIGHT++] = $ss47224723;
}
if(R.isPyretException($e47184719)) {
$e47184719.pyretStack.push(L[508]);
}
throw $e47184719;
}
var $ret47244725 = $Hanf_arg27824729($z47204721,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15);
++R.GAS;
return $ret47244725;
};
var $Hanf_arg27824729 = function(anf_arg19134728,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,j_DASH_var9098,list2364,builtins15) {
var $z47324733 = D;
var $f47384739 = function(_) {
return R.isFunction(j_DASH_var9098.$var)?j_DASH_var9098.$var.app(("brand"),anf_arg19134728):R.ffi.throwNonFunApp(L[509],j_DASH_var9098.$var,[("brand"),anf_arg19134728]);
};
try {
if(--R.GAS > 0) {
$z47324733 = $f47384739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47384739,
"from":L[509]});
}
} catch($e47304731) {
if(R.isCont($e47304731)) {
var $ss47344735 = {"from":L[509],
"go":function(anf_array_val19144740) {
return $Hanf_array_val27814741(anf_array_val19144740,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e47304731.stack[R.EXN_STACKHEIGHT++] = $ss47344735;
}
if(R.isPyretException($e47304731)) {
$e47304731.pyretStack.push(L[509]);
}
throw $e47304731;
}
var $ret47364737 = $Hanf_array_val27814741($z47324733,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret47364737;
};
var $Hanf_array_val27814741 = function(anf_array_val19144740,anf_arg19014616,anf_array_val19084679,anf_fun18994617,anf_fun19024630,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z47444745 = D;
var $f47504751 = function(_) {
return R.isFunction(anf_fun19024630)?anf_fun19024630.app([anf_array_val19084679,anf_array_val19144740]):R.ffi.throwNonFunApp(L[500],anf_fun19024630,[[anf_array_val19084679,anf_array_val19144740]]);
};
try {
if(--R.GAS > 0) {
$z47444745 = $f47504751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47504751,
"from":L[500]});
}
} catch($e47424743) {
if(R.isCont($e47424743)) {
var $ss47464747 = {"from":L[500],
"go":function(anf_arg19154752) {
return $Hanf_arg27804753(anf_arg19154752,anf_arg19014616,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e47424743.stack[R.EXN_STACKHEIGHT++] = $ss47464747;
}
if(R.isPyretException($e47424743)) {
$e47424743.pyretStack.push(L[500]);
}
throw $e47424743;
}
var $ret47484749 = $Hanf_arg27804753($z47444745,anf_arg19014616,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret47484749;
};
var $Hanf_arg27804753 = function(anf_arg19154752,anf_arg19014616,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z47564757 = D;
var $f47624763 = function(_) {
return R.isFunction(j_DASH_block8588.$var)?j_DASH_block8588.$var.app(anf_arg19154752):R.ffi.throwNonFunApp(L[510],j_DASH_block8588.$var,[anf_arg19154752]);
};
try {
if(--R.GAS > 0) {
$z47564757 = $f47624763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47624763,
"from":L[510]});
}
} catch($e47544755) {
if(R.isCont($e47544755)) {
var $ss47584759 = {"from":L[510],
"go":function(anf_arg19164764) {
return $Hanf_arg27794765(anf_arg19164764,anf_arg19014616,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e47544755.stack[R.EXN_STACKHEIGHT++] = $ss47584759;
}
if(R.isPyretException($e47544755)) {
$e47544755.pyretStack.push(L[510]);
}
throw $e47544755;
}
var $ret47604761 = $Hanf_arg27794765($z47564757,anf_arg19014616,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret47604761;
};
var $Hanf_arg27794765 = function(anf_arg19164764,anf_arg19014616,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_fun155228,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z47684769 = D;
var $f47744775 = function(_) {
return R.isFunction(j_DASH_fun155228.$var)?j_DASH_fun155228.$var.app(anf_arg19014616,anf_arg19164764):R.ffi.throwNonFunApp(L[511],j_DASH_fun155228.$var,[anf_arg19014616,anf_arg19164764]);
};
try {
if(--R.GAS > 0) {
$z47684769 = $f47744775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47744775,
"from":L[511]});
}
} catch($e47664767) {
if(R.isCont($e47664767)) {
var $ss47704771 = {"from":L[511],
"go":function(anf_bracket19174776) {
return $Hanf_bracket27784777(anf_bracket19174776,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e47664767.stack[R.EXN_STACKHEIGHT++] = $ss47704771;
}
if(R.isPyretException($e47664767)) {
$e47664767.pyretStack.push(L[511]);
}
throw $e47664767;
}
var $ret47724773 = $Hanf_bracket27784777($z47684769,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret47724773;
};
var $Hanf_bracket27784777 = function(anf_bracket19174776,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19184788 = G(anf_bracket19174776,"tosource",L[513]);
var $z47804781 = D;
var $f47864787 = function(_) {
return R.isFunction(anf_fun19184788)?anf_fun19184788.app():R.ffi.throwNonFunApp(L[512],anf_fun19184788,[]);
};
try {
if(--R.GAS > 0) {
$z47804781 = $f47864787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47864787,
"from":L[512]});
}
} catch($e47784779) {
if(R.isCont($e47784779)) {
var $ss47824783 = {"from":L[512],
"go":function(anf_bracket19194789) {
return $Hanf_bracket27774790(anf_bracket19194789,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e47784779.stack[R.EXN_STACKHEIGHT++] = $ss47824783;
}
if(R.isPyretException($e47784779)) {
$e47784779.pyretStack.push(L[512]);
}
throw $e47784779;
}
var $ret47844785 = $Hanf_bracket27774790($z47804781,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret47844785;
};
var $Hanf_bracket27774790 = function(anf_bracket19194789,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19204801 = G(anf_bracket19194789,"pretty",L[515]);
var $z47934794 = D;
var $f47994800 = function(_) {
return R.isFunction(anf_fun19204801)?anf_fun19204801.app((80)):R.ffi.throwNonFunApp(L[514],anf_fun19204801,[(80)]);
};
try {
if(--R.GAS > 0) {
$z47934794 = $f47994800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47994800,
"from":L[514]});
}
} catch($e47914792) {
if(R.isCont($e47914792)) {
var $ss47954796 = {"from":L[514],
"go":function(anf_arg19214802) {
return $Hanf_arg27764803(anf_arg19214802,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e47914792.stack[R.EXN_STACKHEIGHT++] = $ss47954796;
}
if(R.isPyretException($e47914792)) {
$e47914792.pyretStack.push(L[514]);
}
throw $e47914792;
}
var $ret47974798 = $Hanf_arg27764803($z47934794,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret47974798;
};
var $Hanf_arg27764803 = function(anf_arg19214802,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19224814 = G(list2364,"make",L[516]);
var $z48064807 = D;
var $f48124813 = function(_) {
return R.isFunction(anf_fun19224814)?anf_fun19224814.app([("function(RUNTIME, NAMESPACE) {"),("  var print = NAMESPACE.get(\"print\");"),("  var brand = NAMESPACE.get(\"brand\");"),("}")]):R.ffi.throwNonFunApp(L[516],anf_fun19224814,[[("function(RUNTIME, NAMESPACE) {"),("  var print = NAMESPACE.get(\"print\");"),("  var brand = NAMESPACE.get(\"brand\");"),("}")]]);
};
try {
if(--R.GAS > 0) {
$z48064807 = $f48124813();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48124813,
"from":L[516]});
}
} catch($e48044805) {
if(R.isCont($e48044805)) {
var $ss48084809 = {"from":L[516],
"go":function(anf_arg19234815) {
return $Hanf_arg27754816(anf_arg19234815,anf_arg19214802,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e48044805.stack[R.EXN_STACKHEIGHT++] = $ss48084809;
}
if(R.isPyretException($e48044805)) {
$e48044805.pyretStack.push(L[516]);
}
throw $e48044805;
}
var $ret48104811 = $Hanf_arg27754816($z48064807,anf_arg19214802,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret48104811;
};
var $Hanf_arg27754816 = function(anf_arg19234815,anf_arg19214802,anf_fun18994617,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_arg19244827 = R.makeSrcloc(L[497]);
var $z48194820 = D;
var $f48254826 = function(_) {
return R.isFunction(anf_fun18994617)?anf_fun18994617.app(("j-fun([list: \"RUNTIME\", \"NAMESPACE\"],\n  j-block([list: \n      j-var(\"print\", j-method(j-id(\"NAMESPACE\"), \"get\", [list: j-str(\"print\")])),\n      j-var(\"brand\", j-method(j-id(\"NAMESPACE\"), \"get\", [list: j-str(\"brand\")]))\n    ]))\n  .tosource()\n  .pretty(80) is\n  [list: \n    \"function(RUNTIME, NAMESPACE) {\",\n    \"  var print = NAMESPACE.get(\\\"print\\\");\",\n    \"  var brand = NAMESPACE.get(\\\"brand\\\");\",\n    \"}\"\n  ]"),anf_arg19214802,anf_arg19234815,anf_arg19244827):R.ffi.throwNonFunApp(L[497],anf_fun18994617,[("j-fun([list: \"RUNTIME\", \"NAMESPACE\"],\n  j-block([list: \n      j-var(\"print\", j-method(j-id(\"NAMESPACE\"), \"get\", [list: j-str(\"print\")])),\n      j-var(\"brand\", j-method(j-id(\"NAMESPACE\"), \"get\", [list: j-str(\"brand\")]))\n    ]))\n  .tosource()\n  .pretty(80) is\n  [list: \n    \"function(RUNTIME, NAMESPACE) {\",\n    \"  var print = NAMESPACE.get(\\\"print\\\");\",\n    \"  var brand = NAMESPACE.get(\\\"brand\\\");\",\n    \"}\"\n  ]"),anf_arg19214802,anf_arg19234815,anf_arg19244827]);
};
try {
if(--R.GAS > 0) {
$z48194820 = $f48254826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48254826,
"from":L[497]});
}
} catch($e48174818) {
if(R.isCont($e48174818)) {
var $ss48214822 = {"from":L[497],
"go":function(anf_begin_app_dropped27374828) {
return $Hanf_begin_app_dropped27744829(anf_begin_app_dropped27374828,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e48174818.stack[R.EXN_STACKHEIGHT++] = $ss48214822;
}
if(R.isPyretException($e48174818)) {
$e48174818.pyretStack.push(L[497]);
}
throw $e48174818;
}
var $ret48234824 = $Hanf_begin_app_dropped27744829($z48194820,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret48234824;
};
var $Hanf_begin_app_dropped27744829 = function(anf_begin_app_dropped27374828,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19254840 = G(builtins15,"current-checker",L[517]);
var $z48324833 = D;
var $f48384839 = function(_) {
return R.isFunction(anf_fun19254840)?anf_fun19254840.app():R.ffi.throwNonFunApp(L[517],anf_fun19254840,[]);
};
try {
if(--R.GAS > 0) {
$z48324833 = $f48384839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48384839,
"from":L[517]});
}
} catch($e48304831) {
if(R.isCont($e48304831)) {
var $ss48344835 = {"from":L[517],
"go":function(anf_bracket19264841) {
return $Hanf_bracket27734842(anf_bracket19264841,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e48304831.stack[R.EXN_STACKHEIGHT++] = $ss48344835;
}
if(R.isPyretException($e48304831)) {
$e48304831.pyretStack.push(L[517]);
}
throw $e48304831;
}
var $ret48364837 = $Hanf_bracket27734842($z48324833,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret48364837;
};
var $Hanf_bracket27734842 = function(anf_bracket19264841,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_null187292,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19274855 = G(anf_bracket19264841,"check-is",L[517]);
var anf_fun19284853 = G(j_DASH_null187292.$var,"tosource",L[519]);
var $z48454846 = D;
var $f48514852 = function(_) {
return R.isFunction(anf_fun19284853)?anf_fun19284853.app():R.ffi.throwNonFunApp(L[518],anf_fun19284853,[]);
};
try {
if(--R.GAS > 0) {
$z48454846 = $f48514852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48514852,
"from":L[518]});
}
} catch($e48434844) {
if(R.isCont($e48434844)) {
var $ss48474848 = {"from":L[518],
"go":function(anf_bracket19294854) {
return $Hanf_bracket27724856(anf_bracket19294854,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e48434844.stack[R.EXN_STACKHEIGHT++] = $ss48474848;
}
if(R.isPyretException($e48434844)) {
$e48434844.pyretStack.push(L[518]);
}
throw $e48434844;
}
var $ret48494850 = $Hanf_bracket27724856($z48454846,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret48494850;
};
var $Hanf_bracket27724856 = function(anf_bracket19294854,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19304867 = G(anf_bracket19294854,"pretty",L[521]);
var $z48594860 = D;
var $f48654866 = function(_) {
return R.isFunction(anf_fun19304867)?anf_fun19304867.app((5)):R.ffi.throwNonFunApp(L[520],anf_fun19304867,[(5)]);
};
try {
if(--R.GAS > 0) {
$z48594860 = $f48654866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48654866,
"from":L[520]});
}
} catch($e48574858) {
if(R.isCont($e48574858)) {
var $ss48614862 = {"from":L[520],
"go":function(anf_arg19314868) {
return $Hanf_arg27714869(anf_arg19314868,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e48574858.stack[R.EXN_STACKHEIGHT++] = $ss48614862;
}
if(R.isPyretException($e48574858)) {
$e48574858.pyretStack.push(L[520]);
}
throw $e48574858;
}
var $ret48634864 = $Hanf_arg27714869($z48594860,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret48634864;
};
var $Hanf_arg27714869 = function(anf_arg19314868,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19324880 = G(list2364,"make",L[522]);
var $z48724873 = D;
var $f48784879 = function(_) {
return R.isFunction(anf_fun19324880)?anf_fun19324880.app([("null")]):R.ffi.throwNonFunApp(L[522],anf_fun19324880,[[("null")]]);
};
try {
if(--R.GAS > 0) {
$z48724873 = $f48784879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48784879,
"from":L[522]});
}
} catch($e48704871) {
if(R.isCont($e48704871)) {
var $ss48744875 = {"from":L[522],
"go":function(anf_arg19334881) {
return $Hanf_arg27704882(anf_arg19334881,anf_arg19314868,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e48704871.stack[R.EXN_STACKHEIGHT++] = $ss48744875;
}
if(R.isPyretException($e48704871)) {
$e48704871.pyretStack.push(L[522]);
}
throw $e48704871;
}
var $ret48764877 = $Hanf_arg27704882($z48724873,anf_arg19314868,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret48764877;
};
var $Hanf_arg27704882 = function(anf_arg19334881,anf_arg19314868,anf_fun19274855,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_arg19344893 = R.makeSrcloc(L[517]);
var $z48854886 = D;
var $f48914892 = function(_) {
return R.isFunction(anf_fun19274855)?anf_fun19274855.app(("j-null.tosource().pretty(5) is [list: \"null\"]"),anf_arg19314868,anf_arg19334881,anf_arg19344893):R.ffi.throwNonFunApp(L[517],anf_fun19274855,[("j-null.tosource().pretty(5) is [list: \"null\"]"),anf_arg19314868,anf_arg19334881,anf_arg19344893]);
};
try {
if(--R.GAS > 0) {
$z48854886 = $f48914892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48914892,
"from":L[517]});
}
} catch($e48834884) {
if(R.isCont($e48834884)) {
var $ss48874888 = {"from":L[517],
"go":function(anf_begin_app_dropped27384894) {
return $Hanf_begin_app_dropped27694895(anf_begin_app_dropped27384894,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e48834884.stack[R.EXN_STACKHEIGHT++] = $ss48874888;
}
if(R.isPyretException($e48834884)) {
$e48834884.pyretStack.push(L[517]);
}
throw $e48834884;
}
var $ret48894890 = $Hanf_begin_app_dropped27694895($z48854886,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret48894890;
};
var $Hanf_begin_app_dropped27694895 = function(anf_begin_app_dropped27384894,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19354906 = G(builtins15,"current-checker",L[523]);
var $z48984899 = D;
var $f49044905 = function(_) {
return R.isFunction(anf_fun19354906)?anf_fun19354906.app():R.ffi.throwNonFunApp(L[523],anf_fun19354906,[]);
};
try {
if(--R.GAS > 0) {
$z48984899 = $f49044905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49044905,
"from":L[523]});
}
} catch($e48964897) {
if(R.isCont($e48964897)) {
var $ss49004901 = {"from":L[523],
"go":function(anf_bracket19364907) {
return $Hanf_bracket27684908(anf_bracket19364907,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e48964897.stack[R.EXN_STACKHEIGHT++] = $ss49004901;
}
if(R.isPyretException($e48964897)) {
$e48964897.pyretStack.push(L[523]);
}
throw $e48964897;
}
var $ret49024903 = $Hanf_bracket27684908($z48984899,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret49024903;
};
var $Hanf_bracket27684908 = function(anf_bracket19364907,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_raw191300,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19374920 = G(anf_bracket19364907,"check-is",L[523]);
var anf_fun19384921 = G(list2364,"make",L[525]);
var $z49114912 = D;
var $f49174918 = function(_) {
return R.isFunction(j_DASH_raw191300.$var)?j_DASH_raw191300.$var.app(("x + y")):R.ffi.throwNonFunApp(L[524],j_DASH_raw191300.$var,[("x + y")]);
};
try {
if(--R.GAS > 0) {
$z49114912 = $f49174918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49174918,
"from":L[524]});
}
} catch($e49094910) {
if(R.isCont($e49094910)) {
var $ss49134914 = {"from":L[524],
"go":function(anf_array_val19394919) {
return $Hanf_array_val27674922(anf_array_val19394919,anf_fun19374920,anf_fun19384921,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e49094910.stack[R.EXN_STACKHEIGHT++] = $ss49134914;
}
if(R.isPyretException($e49094910)) {
$e49094910.pyretStack.push(L[524]);
}
throw $e49094910;
}
var $ret49154916 = $Hanf_array_val27674922($z49114912,anf_fun19374920,anf_fun19384921,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret49154916;
};
var $Hanf_array_val27674922 = function(anf_array_val19394919,anf_fun19374920,anf_fun19384921,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_id177272,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z49254926 = D;
var $f49314932 = function(_) {
return R.isFunction(j_DASH_id177272.$var)?j_DASH_id177272.$var.app(("z")):R.ffi.throwNonFunApp(L[526],j_DASH_id177272.$var,[("z")]);
};
try {
if(--R.GAS > 0) {
$z49254926 = $f49314932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49314932,
"from":L[526]});
}
} catch($e49234924) {
if(R.isCont($e49234924)) {
var $ss49274928 = {"from":L[526],
"go":function(anf_array_val19404933) {
return $Hanf_array_val27664934(anf_array_val19404933,anf_array_val19394919,anf_fun19374920,anf_fun19384921,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e49234924.stack[R.EXN_STACKHEIGHT++] = $ss49274928;
}
if(R.isPyretException($e49234924)) {
$e49234924.pyretStack.push(L[526]);
}
throw $e49234924;
}
var $ret49294930 = $Hanf_array_val27664934($z49254926,anf_array_val19394919,anf_fun19374920,anf_fun19384921,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret49294930;
};
var $Hanf_array_val27664934 = function(anf_array_val19404933,anf_array_val19394919,anf_fun19374920,anf_fun19384921,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z49374938 = D;
var $f49434944 = function(_) {
return R.isFunction(anf_fun19384921)?anf_fun19384921.app([anf_array_val19394919,anf_array_val19404933]):R.ffi.throwNonFunApp(L[525],anf_fun19384921,[[anf_array_val19394919,anf_array_val19404933]]);
};
try {
if(--R.GAS > 0) {
$z49374938 = $f49434944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49434944,
"from":L[525]});
}
} catch($e49354936) {
if(R.isCont($e49354936)) {
var $ss49394940 = {"from":L[525],
"go":function(anf_arg19414945) {
return $Hanf_arg27654946(anf_arg19414945,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e49354936.stack[R.EXN_STACKHEIGHT++] = $ss49394940;
}
if(R.isPyretException($e49354936)) {
$e49354936.pyretStack.push(L[525]);
}
throw $e49354936;
}
var $ret49414942 = $Hanf_arg27654946($z49374938,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret49414942;
};
var $Hanf_arg27654946 = function(anf_arg19414945,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_raw_DASH_holes193304,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z49494950 = D;
var $f49554956 = function(_) {
return R.isFunction(j_DASH_raw_DASH_holes193304.$var)?j_DASH_raw_DASH_holes193304.$var.app(("try { ~a } catch(e) { ~a }"),anf_arg19414945,(100000)):R.ffi.throwNonFunApp(L[527],j_DASH_raw_DASH_holes193304.$var,[("try { ~a } catch(e) { ~a }"),anf_arg19414945,(100000)]);
};
try {
if(--R.GAS > 0) {
$z49494950 = $f49554956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49554956,
"from":L[527]});
}
} catch($e49474948) {
if(R.isCont($e49474948)) {
var $ss49514952 = {"from":L[527],
"go":function(anf_bracket19424957) {
return $Hanf_bracket27644958(anf_bracket19424957,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e49474948.stack[R.EXN_STACKHEIGHT++] = $ss49514952;
}
if(R.isPyretException($e49474948)) {
$e49474948.pyretStack.push(L[527]);
}
throw $e49474948;
}
var $ret49534954 = $Hanf_bracket27644958($z49494950,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret49534954;
};
var $Hanf_bracket27644958 = function(anf_bracket19424957,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19434969 = G(anf_bracket19424957,"tosource",L[529]);
var $z49614962 = D;
var $f49674968 = function(_) {
return R.isFunction(anf_fun19434969)?anf_fun19434969.app():R.ffi.throwNonFunApp(L[528],anf_fun19434969,[]);
};
try {
if(--R.GAS > 0) {
$z49614962 = $f49674968();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49674968,
"from":L[528]});
}
} catch($e49594960) {
if(R.isCont($e49594960)) {
var $ss49634964 = {"from":L[528],
"go":function(anf_bracket19444970) {
return $Hanf_bracket27634971(anf_bracket19444970,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e49594960.stack[R.EXN_STACKHEIGHT++] = $ss49634964;
}
if(R.isPyretException($e49594960)) {
$e49594960.pyretStack.push(L[528]);
}
throw $e49594960;
}
var $ret49654966 = $Hanf_bracket27634971($z49614962,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret49654966;
};
var $Hanf_bracket27634971 = function(anf_bracket19444970,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19454982 = G(anf_bracket19444970,"pretty",L[531]);
var $z49744975 = D;
var $f49804981 = function(_) {
return R.isFunction(anf_fun19454982)?anf_fun19454982.app((80)):R.ffi.throwNonFunApp(L[530],anf_fun19454982,[(80)]);
};
try {
if(--R.GAS > 0) {
$z49744975 = $f49804981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49804981,
"from":L[530]});
}
} catch($e49724973) {
if(R.isCont($e49724973)) {
var $ss49764977 = {"from":L[530],
"go":function(anf_arg19464983) {
return $Hanf_arg27624984(anf_arg19464983,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e49724973.stack[R.EXN_STACKHEIGHT++] = $ss49764977;
}
if(R.isPyretException($e49724973)) {
$e49724973.pyretStack.push(L[530]);
}
throw $e49724973;
}
var $ret49784979 = $Hanf_arg27624984($z49744975,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret49784979;
};
var $Hanf_arg27624984 = function(anf_arg19464983,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19474995 = G(list2364,"make",L[532]);
var $z49874988 = D;
var $f49934994 = function(_) {
return R.isFunction(anf_fun19474995)?anf_fun19474995.app([("try { x + y } catch(e) { z }")]):R.ffi.throwNonFunApp(L[532],anf_fun19474995,[[("try { x + y } catch(e) { z }")]]);
};
try {
if(--R.GAS > 0) {
$z49874988 = $f49934994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49934994,
"from":L[532]});
}
} catch($e49854986) {
if(R.isCont($e49854986)) {
var $ss49894990 = {"from":L[532],
"go":function(anf_arg19484996) {
return $Hanf_arg27614997(anf_arg19484996,anf_arg19464983,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e49854986.stack[R.EXN_STACKHEIGHT++] = $ss49894990;
}
if(R.isPyretException($e49854986)) {
$e49854986.pyretStack.push(L[532]);
}
throw $e49854986;
}
var $ret49914992 = $Hanf_arg27614997($z49874988,anf_arg19464983,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret49914992;
};
var $Hanf_arg27614997 = function(anf_arg19484996,anf_arg19464983,anf_fun19374920,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_arg19495008 = R.makeSrcloc(L[523]);
var $z50005001 = D;
var $f50065007 = function(_) {
return R.isFunction(anf_fun19374920)?anf_fun19374920.app(("j-raw-holes(\"try { ~a } catch(e) { ~a }\",\n  [list: j-raw(\"x + y\"), j-id(\"z\")],\n  100000)\n  .tosource()\n  .pretty(80) is\n  [list: \"try { x + y } catch(e) { z }\"]"),anf_arg19464983,anf_arg19484996,anf_arg19495008):R.ffi.throwNonFunApp(L[523],anf_fun19374920,[("j-raw-holes(\"try { ~a } catch(e) { ~a }\",\n  [list: j-raw(\"x + y\"), j-id(\"z\")],\n  100000)\n  .tosource()\n  .pretty(80) is\n  [list: \"try { x + y } catch(e) { z }\"]"),anf_arg19464983,anf_arg19484996,anf_arg19495008]);
};
try {
if(--R.GAS > 0) {
$z50005001 = $f50065007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50065007,
"from":L[523]});
}
} catch($e49984999) {
if(R.isCont($e49984999)) {
var $ss50025003 = {"from":L[523],
"go":function(anf_begin_app_dropped27395009) {
return $Hanf_begin_app_dropped27605010(anf_begin_app_dropped27395009,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e49984999.stack[R.EXN_STACKHEIGHT++] = $ss50025003;
}
if(R.isPyretException($e49984999)) {
$e49984999.pyretStack.push(L[523]);
}
throw $e49984999;
}
var $ret50045005 = $Hanf_begin_app_dropped27605010($z50005001,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret50045005;
};
var $Hanf_begin_app_dropped27605010 = function(anf_begin_app_dropped27395009,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19505021 = G(builtins15,"current-checker",L[533]);
var $z50135014 = D;
var $f50195020 = function(_) {
return R.isFunction(anf_fun19505021)?anf_fun19505021.app():R.ffi.throwNonFunApp(L[533],anf_fun19505021,[]);
};
try {
if(--R.GAS > 0) {
$z50135014 = $f50195020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50195020,
"from":L[533]});
}
} catch($e50115012) {
if(R.isCont($e50115012)) {
var $ss50155016 = {"from":L[533],
"go":function(anf_bracket19515022) {
return $Hanf_bracket27595023(anf_bracket19515022,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e50115012.stack[R.EXN_STACKHEIGHT++] = $ss50155016;
}
if(R.isPyretException($e50115012)) {
$e50115012.pyretStack.push(L[533]);
}
throw $e50115012;
}
var $ret50175018 = $Hanf_bracket27595023($z50135014,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret50175018;
};
var $Hanf_bracket27595023 = function(anf_bracket19515022,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19525035 = G(anf_bracket19515022,"check-is",L[533]);
var anf_fun19535036 = G(list2364,"make",L[535]);
var $z50265027 = D;
var $f50325033 = function(_) {
return R.isFunction(j_DASH_return96110.$var)?j_DASH_return96110.$var.app(j_DASH_false185288.$var):R.ffi.throwNonFunApp(L[534],j_DASH_return96110.$var,[j_DASH_false185288.$var]);
};
try {
if(--R.GAS > 0) {
$z50265027 = $f50325033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50325033,
"from":L[534]});
}
} catch($e50245025) {
if(R.isCont($e50245025)) {
var $ss50285029 = {"from":L[534],
"go":function(anf_array_val19545034) {
return $Hanf_array_val27585037(anf_array_val19545034,anf_fun19525035,anf_fun19535036,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e50245025.stack[R.EXN_STACKHEIGHT++] = $ss50285029;
}
if(R.isPyretException($e50245025)) {
$e50245025.pyretStack.push(L[534]);
}
throw $e50245025;
}
var $ret50305031 = $Hanf_array_val27585037($z50265027,anf_fun19525035,anf_fun19535036,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret50305031;
};
var $Hanf_array_val27585037 = function(anf_array_val19545034,anf_fun19525035,anf_fun19535036,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z50405041 = D;
var $f50465047 = function(_) {
return R.isFunction(anf_fun19535036)?anf_fun19535036.app([anf_array_val19545034]):R.ffi.throwNonFunApp(L[535],anf_fun19535036,[[anf_array_val19545034]]);
};
try {
if(--R.GAS > 0) {
$z50405041 = $f50465047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50465047,
"from":L[535]});
}
} catch($e50385039) {
if(R.isCont($e50385039)) {
var $ss50425043 = {"from":L[535],
"go":function(anf_arg19555048) {
return $Hanf_arg27575049(anf_arg19555048,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e50385039.stack[R.EXN_STACKHEIGHT++] = $ss50425043;
}
if(R.isPyretException($e50385039)) {
$e50385039.pyretStack.push(L[535]);
}
throw $e50385039;
}
var $ret50445045 = $Hanf_arg27575049($z50405041,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret50445045;
};
var $Hanf_arg27575049 = function(anf_arg19555048,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z50525053 = D;
var $f50585059 = function(_) {
return R.isFunction(j_DASH_block8588.$var)?j_DASH_block8588.$var.app(anf_arg19555048):R.ffi.throwNonFunApp(L[536],j_DASH_block8588.$var,[anf_arg19555048]);
};
try {
if(--R.GAS > 0) {
$z50525053 = $f50585059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50585059,
"from":L[536]});
}
} catch($e50505051) {
if(R.isCont($e50505051)) {
var $ss50545055 = {"from":L[536],
"go":function(anf_arg19565060) {
return $Hanf_arg27565061(anf_arg19565060,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e50505051.stack[R.EXN_STACKHEIGHT++] = $ss50545055;
}
if(R.isPyretException($e50505051)) {
$e50505051.pyretStack.push(L[536]);
}
throw $e50505051;
}
var $ret50565057 = $Hanf_arg27565061($z50525053,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret50565057;
};
var $Hanf_arg27565061 = function(anf_arg19565060,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_num181280,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var anf_fun19575073 = G(list2364,"make",L[538]);
var $z50645065 = D;
var $f50705071 = function(_) {
return R.isFunction(j_DASH_num181280.$var)?j_DASH_num181280.$var.app((5)):R.ffi.throwNonFunApp(L[537],j_DASH_num181280.$var,[(5)]);
};
try {
if(--R.GAS > 0) {
$z50645065 = $f50705071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50705071,
"from":L[537]});
}
} catch($e50625063) {
if(R.isCont($e50625063)) {
var $ss50665067 = {"from":L[537],
"go":function(anf_arg19585072) {
return $Hanf_arg27555074(anf_arg19585072,anf_arg19565060,anf_fun19525035,anf_fun19575073,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
}};
$e50625063.stack[R.EXN_STACKHEIGHT++] = $ss50665067;
}
if(R.isPyretException($e50625063)) {
$e50625063.pyretStack.push(L[537]);
}
throw $e50625063;
}
var $ret50685069 = $Hanf_arg27555074($z50645065,anf_arg19565060,anf_fun19525035,anf_fun19575073,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_return96110,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret50685069;
};
var $Hanf_arg27555074 = function(anf_arg19585072,anf_arg19565060,anf_fun19525035,anf_fun19575073,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_return96110,j_DASH_true183284,list2364,builtins15) {
var $z50775078 = D;
var $f50835084 = function(_) {
return R.isFunction(j_DASH_return96110.$var)?j_DASH_return96110.$var.app(anf_arg19585072):R.ffi.throwNonFunApp(L[539],j_DASH_return96110.$var,[anf_arg19585072]);
};
try {
if(--R.GAS > 0) {
$z50775078 = $f50835084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50835084,
"from":L[539]});
}
} catch($e50755076) {
if(R.isCont($e50755076)) {
var $ss50795080 = {"from":L[539],
"go":function(anf_array_val19595085) {
return $Hanf_array_val27545086(anf_array_val19595085,anf_arg19565060,anf_fun19525035,anf_fun19575073,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15);
}};
$e50755076.stack[R.EXN_STACKHEIGHT++] = $ss50795080;
}
if(R.isPyretException($e50755076)) {
$e50755076.pyretStack.push(L[539]);
}
throw $e50755076;
}
var $ret50815082 = $Hanf_array_val27545086($z50775078,anf_arg19565060,anf_fun19525035,anf_fun19575073,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret50815082;
};
var $Hanf_array_val27545086 = function(anf_array_val19595085,anf_arg19565060,anf_fun19525035,anf_fun19575073,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15) {
var $z50895090 = D;
var $f50955096 = function(_) {
return R.isFunction(anf_fun19575073)?anf_fun19575073.app([anf_array_val19595085]):R.ffi.throwNonFunApp(L[538],anf_fun19575073,[[anf_array_val19595085]]);
};
try {
if(--R.GAS > 0) {
$z50895090 = $f50955096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50955096,
"from":L[538]});
}
} catch($e50875088) {
if(R.isCont($e50875088)) {
var $ss50915092 = {"from":L[538],
"go":function(anf_arg19605097) {
return $Hanf_arg27535098(anf_arg19605097,anf_arg19565060,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15);
}};
$e50875088.stack[R.EXN_STACKHEIGHT++] = $ss50915092;
}
if(R.isPyretException($e50875088)) {
$e50875088.pyretStack.push(L[538]);
}
throw $e50875088;
}
var $ret50935094 = $Hanf_arg27535098($z50895090,anf_arg19565060,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret50935094;
};
var $Hanf_arg27535098 = function(anf_arg19605097,anf_arg19565060,anf_fun19525035,j_DASH_block8588,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15) {
var $z51015102 = D;
var $f51075108 = function(_) {
return R.isFunction(j_DASH_block8588.$var)?j_DASH_block8588.$var.app(anf_arg19605097):R.ffi.throwNonFunApp(L[540],j_DASH_block8588.$var,[anf_arg19605097]);
};
try {
if(--R.GAS > 0) {
$z51015102 = $f51075108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51075108,
"from":L[540]});
}
} catch($e50995100) {
if(R.isCont($e50995100)) {
var $ss51035104 = {"from":L[540],
"go":function(anf_arg19615109) {
return $Hanf_arg27525110(anf_arg19615109,anf_arg19565060,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15);
}};
$e50995100.stack[R.EXN_STACKHEIGHT++] = $ss51035104;
}
if(R.isPyretException($e50995100)) {
$e50995100.pyretStack.push(L[540]);
}
throw $e50995100;
}
var $ret51055106 = $Hanf_arg27525110($z51015102,anf_arg19565060,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret51055106;
};
var $Hanf_arg27525110 = function(anf_arg19615109,anf_arg19565060,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_if94106,j_DASH_true183284,list2364,builtins15) {
var $z51135114 = D;
var $f51195120 = function(_) {
return R.isFunction(j_DASH_if94106.$var)?j_DASH_if94106.$var.app(j_DASH_true183284.$var,anf_arg19565060,anf_arg19615109):R.ffi.throwNonFunApp(L[541],j_DASH_if94106.$var,[j_DASH_true183284.$var,anf_arg19565060,anf_arg19615109]);
};
try {
if(--R.GAS > 0) {
$z51135114 = $f51195120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51195120,
"from":L[541]});
}
} catch($e51115112) {
if(R.isCont($e51115112)) {
var $ss51155116 = {"from":L[541],
"go":function(anf_bracket19625121) {
return $Hanf_bracket27515122(anf_bracket19625121,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
}};
$e51115112.stack[R.EXN_STACKHEIGHT++] = $ss51155116;
}
if(R.isPyretException($e51115112)) {
$e51115112.pyretStack.push(L[541]);
}
throw $e51115112;
}
var $ret51175118 = $Hanf_bracket27515122($z51135114,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret51175118;
};
var $Hanf_bracket27515122 = function(anf_bracket19625121,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15) {
var anf_fun19635133 = G(anf_bracket19625121,"tosource",L[543]);
var $z51255126 = D;
var $f51315132 = function(_) {
return R.isFunction(anf_fun19635133)?anf_fun19635133.app():R.ffi.throwNonFunApp(L[542],anf_fun19635133,[]);
};
try {
if(--R.GAS > 0) {
$z51255126 = $f51315132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51315132,
"from":L[542]});
}
} catch($e51235124) {
if(R.isCont($e51235124)) {
var $ss51275128 = {"from":L[542],
"go":function(anf_bracket19645134) {
return $Hanf_bracket27505135(anf_bracket19645134,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
}};
$e51235124.stack[R.EXN_STACKHEIGHT++] = $ss51275128;
}
if(R.isPyretException($e51235124)) {
$e51235124.pyretStack.push(L[542]);
}
throw $e51235124;
}
var $ret51295130 = $Hanf_bracket27505135($z51255126,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret51295130;
};
var $Hanf_bracket27505135 = function(anf_bracket19645134,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15) {
var anf_fun19655146 = G(anf_bracket19645134,"pretty",L[545]);
var $z51385139 = D;
var $f51445145 = function(_) {
return R.isFunction(anf_fun19655146)?anf_fun19655146.app((80)):R.ffi.throwNonFunApp(L[544],anf_fun19655146,[(80)]);
};
try {
if(--R.GAS > 0) {
$z51385139 = $f51445145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51445145,
"from":L[544]});
}
} catch($e51365137) {
if(R.isCont($e51365137)) {
var $ss51405141 = {"from":L[544],
"go":function(anf_arg19665147) {
return $Hanf_arg27495148(anf_arg19665147,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
}};
$e51365137.stack[R.EXN_STACKHEIGHT++] = $ss51405141;
}
if(R.isPyretException($e51365137)) {
$e51365137.pyretStack.push(L[544]);
}
throw $e51365137;
}
var $ret51425143 = $Hanf_arg27495148($z51385139,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret51425143;
};
var $Hanf_arg27495148 = function(anf_arg19665147,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15) {
var anf_fun19675159 = G(list2364,"make",L[546]);
var $z51515152 = D;
var $f51575158 = function(_) {
return R.isFunction(anf_fun19675159)?anf_fun19675159.app([("if(true) { return false; } else { return 5; }")]):R.ffi.throwNonFunApp(L[546],anf_fun19675159,[[("if(true) { return false; } else { return 5; }")]]);
};
try {
if(--R.GAS > 0) {
$z51515152 = $f51575158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51575158,
"from":L[546]});
}
} catch($e51495150) {
if(R.isCont($e51495150)) {
var $ss51535154 = {"from":L[546],
"go":function(anf_arg19685160) {
return $Hanf_arg27485161(anf_arg19685160,anf_arg19665147,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
}};
$e51495150.stack[R.EXN_STACKHEIGHT++] = $ss51535154;
}
if(R.isPyretException($e51495150)) {
$e51495150.pyretStack.push(L[546]);
}
throw $e51495150;
}
var $ret51555156 = $Hanf_arg27485161($z51515152,anf_arg19665147,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret51555156;
};
var $Hanf_arg27485161 = function(anf_arg19685160,anf_arg19665147,anf_fun19525035,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15) {
var anf_arg19695172 = R.makeSrcloc(L[533]);
var $z51645165 = D;
var $f51705171 = function(_) {
return R.isFunction(anf_fun19525035)?anf_fun19525035.app(("j-if(j-true,\n  j-block([list: j-return(j-false)]),\n  j-block([list: j-return(j-num(5))]))\n  .tosource()\n  .pretty(80) is\n  [list: \"if(true) { return false; } else { return 5; }\"]"),anf_arg19665147,anf_arg19685160,anf_arg19695172):R.ffi.throwNonFunApp(L[533],anf_fun19525035,[("j-if(j-true,\n  j-block([list: j-return(j-false)]),\n  j-block([list: j-return(j-num(5))]))\n  .tosource()\n  .pretty(80) is\n  [list: \"if(true) { return false; } else { return 5; }\"]"),anf_arg19665147,anf_arg19685160,anf_arg19695172]);
};
try {
if(--R.GAS > 0) {
$z51645165 = $f51705171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51705171,
"from":L[533]});
}
} catch($e51625163) {
if(R.isCont($e51625163)) {
var $ss51665167 = {"from":L[533],
"go":function(anf_begin_app_dropped27405173) {
return $Hanf_begin_app_dropped27475174(anf_begin_app_dropped27405173,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
}};
$e51625163.stack[R.EXN_STACKHEIGHT++] = $ss51665167;
}
if(R.isPyretException($e51625163)) {
$e51625163.pyretStack.push(L[533]);
}
throw $e51625163;
}
var $ret51685169 = $Hanf_begin_app_dropped27475174($z51645165,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15);
++R.GAS;
return $ret51685169;
};
var $Hanf_begin_app_dropped27475174 = function(anf_begin_app_dropped27405173,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364,builtins15) {
var anf_fun19705185 = G(builtins15,"current-checker",L[547]);
var $z51775178 = D;
var $f51835184 = function(_) {
return R.isFunction(anf_fun19705185)?anf_fun19705185.app():R.ffi.throwNonFunApp(L[547],anf_fun19705185,[]);
};
try {
if(--R.GAS > 0) {
$z51775178 = $f51835184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51835184,
"from":L[547]});
}
} catch($e51755176) {
if(R.isCont($e51755176)) {
var $ss51795180 = {"from":L[547],
"go":function(anf_bracket19715186) {
return $Hanf_bracket27465187(anf_bracket19715186,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364);
}};
$e51755176.stack[R.EXN_STACKHEIGHT++] = $ss51795180;
}
if(R.isPyretException($e51755176)) {
$e51755176.pyretStack.push(L[547]);
}
throw $e51755176;
}
var $ret51815182 = $Hanf_bracket27465187($z51775178,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364);
++R.GAS;
return $ret51815182;
};
var $Hanf_bracket27465187 = function(anf_bracket19715186,j_DASH_bracket171260,j_DASH_false185288,j_DASH_true183284,list2364) {
var anf_fun19725199 = G(anf_bracket19715186,"check-is",L[547]);
var $z51905191 = D;
var $f51965197 = function(_) {
return R.isFunction(j_DASH_bracket171260.$var)?j_DASH_bracket171260.$var.app(j_DASH_true183284.$var,j_DASH_false185288.$var):R.ffi.throwNonFunApp(L[548],j_DASH_bracket171260.$var,[j_DASH_true183284.$var,j_DASH_false185288.$var]);
};
try {
if(--R.GAS > 0) {
$z51905191 = $f51965197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51965197,
"from":L[548]});
}
} catch($e51885189) {
if(R.isCont($e51885189)) {
var $ss51925193 = {"from":L[548],
"go":function(anf_bracket19735198) {
return $Hanf_bracket27455200(anf_bracket19735198,anf_fun19725199,list2364);
}};
$e51885189.stack[R.EXN_STACKHEIGHT++] = $ss51925193;
}
if(R.isPyretException($e51885189)) {
$e51885189.pyretStack.push(L[548]);
}
throw $e51885189;
}
var $ret51945195 = $Hanf_bracket27455200($z51905191,anf_fun19725199,list2364);
++R.GAS;
return $ret51945195;
};
var $Hanf_bracket27455200 = function(anf_bracket19735198,anf_fun19725199,list2364) {
var anf_fun19745211 = G(anf_bracket19735198,"tosource",L[550]);
var $z52035204 = D;
var $f52095210 = function(_) {
return R.isFunction(anf_fun19745211)?anf_fun19745211.app():R.ffi.throwNonFunApp(L[549],anf_fun19745211,[]);
};
try {
if(--R.GAS > 0) {
$z52035204 = $f52095210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52095210,
"from":L[549]});
}
} catch($e52015202) {
if(R.isCont($e52015202)) {
var $ss52055206 = {"from":L[549],
"go":function(anf_bracket19755212) {
return $Hanf_bracket27445213(anf_bracket19755212,anf_fun19725199,list2364);
}};
$e52015202.stack[R.EXN_STACKHEIGHT++] = $ss52055206;
}
if(R.isPyretException($e52015202)) {
$e52015202.pyretStack.push(L[549]);
}
throw $e52015202;
}
var $ret52075208 = $Hanf_bracket27445213($z52035204,anf_fun19725199,list2364);
++R.GAS;
return $ret52075208;
};
var $Hanf_bracket27445213 = function(anf_bracket19755212,anf_fun19725199,list2364) {
var anf_fun19765224 = G(anf_bracket19755212,"pretty",L[552]);
var $z52165217 = D;
var $f52225223 = function(_) {
return R.isFunction(anf_fun19765224)?anf_fun19765224.app((20)):R.ffi.throwNonFunApp(L[551],anf_fun19765224,[(20)]);
};
try {
if(--R.GAS > 0) {
$z52165217 = $f52225223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52225223,
"from":L[551]});
}
} catch($e52145215) {
if(R.isCont($e52145215)) {
var $ss52185219 = {"from":L[551],
"go":function(anf_arg19775225) {
return $Hanf_arg27435226(anf_arg19775225,anf_fun19725199,list2364);
}};
$e52145215.stack[R.EXN_STACKHEIGHT++] = $ss52185219;
}
if(R.isPyretException($e52145215)) {
$e52145215.pyretStack.push(L[551]);
}
throw $e52145215;
}
var $ret52205221 = $Hanf_arg27435226($z52165217,anf_fun19725199,list2364);
++R.GAS;
return $ret52205221;
};
var $Hanf_arg27435226 = function(anf_arg19775225,anf_fun19725199,list2364) {
var anf_fun19785237 = G(list2364,"make",L[553]);
var $z52295230 = D;
var $f52355236 = function(_) {
return R.isFunction(anf_fun19785237)?anf_fun19785237.app([("true[false]")]):R.ffi.throwNonFunApp(L[553],anf_fun19785237,[[("true[false]")]]);
};
try {
if(--R.GAS > 0) {
$z52295230 = $f52355236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52355236,
"from":L[553]});
}
} catch($e52275228) {
if(R.isCont($e52275228)) {
var $ss52315232 = {"from":L[553],
"go":function(anf_arg19795238) {
return $Hanf_arg27425239(anf_arg19795238,anf_arg19775225,anf_fun19725199);
}};
$e52275228.stack[R.EXN_STACKHEIGHT++] = $ss52315232;
}
if(R.isPyretException($e52275228)) {
$e52275228.pyretStack.push(L[553]);
}
throw $e52275228;
}
var $ret52335234 = $Hanf_arg27425239($z52295230,anf_arg19775225,anf_fun19725199);
++R.GAS;
return $ret52335234;
};
var $Hanf_arg27425239 = function(anf_arg19795238,anf_arg19775225,anf_fun19725199) {
var anf_arg19805250 = R.makeSrcloc(L[547]);
var $z52425243 = D;
var $f52485249 = function(_) {
return R.isFunction(anf_fun19725199)?anf_fun19725199.app(("j-bracket(j-true, j-false).tosource().pretty(20) is [list: \"true[false]\"]"),anf_arg19775225,anf_arg19795238,anf_arg19805250):R.ffi.throwNonFunApp(L[43],anf_fun19725199,[("j-bracket(j-true, j-false).tosource().pretty(20) is [list: \"true[false]\"]"),anf_arg19775225,anf_arg19795238,anf_arg19805250]);
};
try {
if(--R.GAS > 0) {
$z52425243 = $f52485249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52485249,
"from":L[43]});
}
} catch($e52405241) {
if(R.isCont($e52405241)) {
var $ss52445245 = {"from":L[43],
"go":function(ann_DASH_check_DASH_temp18755251) {
return $Hann_DASH_check_DASH_temp27415252(ann_DASH_check_DASH_temp18755251);
}};
$e52405241.stack[R.EXN_STACKHEIGHT++] = $ss52445245;
}
if(R.isPyretException($e52405241)) {
$e52405241.pyretStack.push(L[43]);
}
throw $e52405241;
}
var $ret52465247 = $Hann_DASH_check_DASH_temp27415252($z52425243);
++R.GAS;
return $ret52465247;
};
var $Hann_DASH_check_DASH_temp27415252 = function(ann_DASH_check_DASH_temp18755251) {
return ann_DASH_check_DASH_temp18755251;
};
var $Hanf_arg2735358 = function(anf_arg1856354,INDENT7747,PP123,anf_fun1852355,anf_fun1853356,self394357,_plus14) {
var $z52555256 = D;
var $f52615262 = function(_) {
return R.isFunction(anf_fun1853356)?anf_fun1853356.app(anf_arg1856354):R.ffi.throwNonFunApp(L[554],anf_fun1853356,[anf_arg1856354]);
};
try {
if(--R.GAS > 0) {
$z52555256 = $f52615262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52615262,
"from":L[554]});
}
} catch($e52535254) {
if(R.isCont($e52535254)) {
var $ss52575258 = {"from":L[554],
"go":function(anf_arg18575263) {
return $Hanf_arg27345264(anf_arg18575263,INDENT7747,PP123,anf_fun1852355,self394357,_plus14);
}};
$e52535254.stack[R.EXN_STACKHEIGHT++] = $ss52575258;
}
if(R.isPyretException($e52535254)) {
$e52535254.pyretStack.push(L[554]);
}
throw $e52535254;
}
var $ret52595260 = $Hanf_arg27345264($z52555256,INDENT7747,PP123,anf_fun1852355,self394357,_plus14);
++R.GAS;
return $ret52595260;
};
var $Hanf_arg27345264 = function(anf_arg18575263,INDENT7747,PP123,anf_fun1852355,self394357,_plus14) {
var anf_fun18585275 = G(PP123,"str",L[556]);
var $z52675268 = D;
var $f52735274 = function(_) {
return R.isFunction(anf_fun18585275)?anf_fun18585275.app((": ")):R.ffi.throwNonFunApp(L[555],anf_fun18585275,[(": ")]);
};
try {
if(--R.GAS > 0) {
$z52675268 = $f52735274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52735274,
"from":L[555]});
}
} catch($e52655266) {
if(R.isCont($e52655266)) {
var $ss52695270 = {"from":L[555],
"go":function(anf_arg18595276) {
return $Hanf_arg27335277(anf_arg18595276,INDENT7747,anf_arg18575263,anf_fun1852355,self394357,_plus14);
}};
$e52655266.stack[R.EXN_STACKHEIGHT++] = $ss52695270;
}
if(R.isPyretException($e52655266)) {
$e52655266.pyretStack.push(L[555]);
}
throw $e52655266;
}
var $ret52715272 = $Hanf_arg27335277($z52675268,INDENT7747,anf_arg18575263,anf_fun1852355,self394357,_plus14);
++R.GAS;
return $ret52715272;
};
var $Hanf_arg27335277 = function(anf_arg18595276,INDENT7747,anf_arg18575263,anf_fun1852355,self394357,_plus14) {
var $z52805281 = D;
var $f52865287 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg18575263,anf_arg18595276):R.ffi.throwNonFunApp(L[557],_plus14,[anf_arg18575263,anf_arg18595276]);
};
try {
if(--R.GAS > 0) {
$z52805281 = $f52865287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52865287,
"from":L[557]});
}
} catch($e52785279) {
if(R.isCont($e52785279)) {
var $ss52825283 = {"from":L[557],
"go":function(anf_arg18605288) {
return $Hanf_arg27325289(anf_arg18605288,INDENT7747,anf_fun1852355,self394357,_plus14);
}};
$e52785279.stack[R.EXN_STACKHEIGHT++] = $ss52825283;
}
if(R.isPyretException($e52785279)) {
$e52785279.pyretStack.push(L[557]);
}
throw $e52785279;
}
var $ret52845285 = $Hanf_arg27325289($z52805281,INDENT7747,anf_fun1852355,self394357,_plus14);
++R.GAS;
return $ret52845285;
};
var $Hanf_arg27325289 = function(anf_arg18605288,INDENT7747,anf_fun1852355,self394357,_plus14) {
var anf_bracket18615303 = G(self394357,"value",L[560]);
var anf_fun18625300 = G(anf_bracket18615303,"tosource",L[559]);
var $z52925293 = D;
var $f52985299 = function(_) {
return R.isFunction(anf_fun18625300)?anf_fun18625300.app():R.ffi.throwNonFunApp(L[558],anf_fun18625300,[]);
};
try {
if(--R.GAS > 0) {
$z52925293 = $f52985299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52985299,
"from":L[558]});
}
} catch($e52905291) {
if(R.isCont($e52905291)) {
var $ss52945295 = {"from":L[558],
"go":function(anf_arg18635301) {
return $Hanf_arg27315302(anf_arg18635301,INDENT7747,anf_arg18605288,anf_fun1852355,_plus14);
}};
$e52905291.stack[R.EXN_STACKHEIGHT++] = $ss52945295;
}
if(R.isPyretException($e52905291)) {
$e52905291.pyretStack.push(L[558]);
}
throw $e52905291;
}
var $ret52965297 = $Hanf_arg27315302($z52925293,INDENT7747,anf_arg18605288,anf_fun1852355,_plus14);
++R.GAS;
return $ret52965297;
};
var $Hanf_arg27315302 = function(anf_arg18635301,INDENT7747,anf_arg18605288,anf_fun1852355,_plus14) {
var $z53065307 = D;
var $f53125313 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg18605288,anf_arg18635301):R.ffi.throwNonFunApp(L[557],_plus14,[anf_arg18605288,anf_arg18635301]);
};
try {
if(--R.GAS > 0) {
$z53065307 = $f53125313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53125313,
"from":L[557]});
}
} catch($e53045305) {
if(R.isCont($e53045305)) {
var $ss53085309 = {"from":L[557],
"go":function(anf_arg18645314) {
return $Hanf_arg27305315(anf_arg18645314,INDENT7747,anf_fun1852355);
}};
$e53045305.stack[R.EXN_STACKHEIGHT++] = $ss53085309;
}
if(R.isPyretException($e53045305)) {
$e53045305.pyretStack.push(L[557]);
}
throw $e53045305;
}
var $ret53105311 = $Hanf_arg27305315($z53065307,INDENT7747,anf_fun1852355);
++R.GAS;
return $ret53105311;
};
var $Hanf_arg27305315 = function(anf_arg18645314,INDENT7747,anf_fun1852355) {
var $z53185319 = D;
var $f53245325 = function(_) {
return R.isFunction(anf_fun1852355)?anf_fun1852355.app(INDENT7747,anf_arg18645314):R.ffi.throwNonFunApp(L[13],anf_fun1852355,[INDENT7747,anf_arg18645314]);
};
try {
if(--R.GAS > 0) {
$z53185319 = $f53245325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53245325,
"from":L[13]});
}
} catch($e53165317) {
if(R.isCont($e53165317)) {
var $ss53205321 = {"from":L[13],
"go":function(ann_DASH_check_DASH_temp18515326) {
return $Hann_DASH_check_DASH_temp27295327(ann_DASH_check_DASH_temp18515326);
}};
$e53165317.stack[R.EXN_STACKHEIGHT++] = $ss53205321;
}
if(R.isPyretException($e53165317)) {
$e53165317.pyretStack.push(L[13]);
}
throw $e53165317;
}
var $ret53225323 = $Hann_DASH_check_DASH_temp27295327($z53185319);
++R.GAS;
return $ret53225323;
};
var $Hann_DASH_check_DASH_temp27295327 = function(ann_DASH_check_DASH_temp18515326) {
return ann_DASH_check_DASH_temp18515326;
};
var $Hanf_begin_app_dropped2728372 = function(anf_begin_app_dropped2722370,printer393369,self392371) {
var anf_arg18475338 = G(self392371,"name",L[562]);
var $z53305331 = D;
var $f53365337 = function(_) {
return R.isFunction(printer393369)?printer393369.app(anf_arg18475338):R.ffi.throwNonFunApp(L[561],printer393369,[anf_arg18475338]);
};
try {
if(--R.GAS > 0) {
$z53305331 = $f53365337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53365337,
"from":L[561]});
}
} catch($e53285329) {
if(R.isCont($e53285329)) {
var $ss53325333 = {"from":L[561],
"go":function(anf_begin_app_dropped27235339) {
return $Hanf_begin_app_dropped27275340(anf_begin_app_dropped27235339,printer393369,self392371);
}};
$e53285329.stack[R.EXN_STACKHEIGHT++] = $ss53325333;
}
if(R.isPyretException($e53285329)) {
$e53285329.pyretStack.push(L[561]);
}
throw $e53285329;
}
var $ret53345335 = $Hanf_begin_app_dropped27275340($z53305331,printer393369,self392371);
++R.GAS;
return $ret53345335;
};
var $Hanf_begin_app_dropped27275340 = function(anf_begin_app_dropped27235339,printer393369,self392371) {
var $z53435344 = D;
var $f53495350 = function(_) {
return R.isFunction(printer393369)?printer393369.app(("\":")):R.ffi.throwNonFunApp(L[563],printer393369,[("\":")]);
};
try {
if(--R.GAS > 0) {
$z53435344 = $f53495350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53495350,
"from":L[563]});
}
} catch($e53415342) {
if(R.isCont($e53415342)) {
var $ss53455346 = {"from":L[563],
"go":function(anf_begin_app_dropped27245351) {
return $Hanf_begin_app_dropped27265352(anf_begin_app_dropped27245351,printer393369,self392371);
}};
$e53415342.stack[R.EXN_STACKHEIGHT++] = $ss53455346;
}
if(R.isPyretException($e53415342)) {
$e53415342.pyretStack.push(L[563]);
}
throw $e53415342;
}
var $ret53475348 = $Hanf_begin_app_dropped27265352($z53435344,printer393369,self392371);
++R.GAS;
return $ret53475348;
};
var $Hanf_begin_app_dropped27265352 = function(anf_begin_app_dropped27245351,printer393369,self392371) {
var anf_bracket18485366 = G(self392371,"value",L[565]);
var anf_fun18495363 = G(anf_bracket18485366,"print-ugly-source",L[564]);
var $z53555356 = D;
var $f53615362 = function(_) {
return R.isFunction(anf_fun18495363)?anf_fun18495363.app(printer393369):R.ffi.throwNonFunApp(L[15],anf_fun18495363,[printer393369]);
};
try {
if(--R.GAS > 0) {
$z53555356 = $f53615362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53615362,
"from":L[15]});
}
} catch($e53535354) {
if(R.isCont($e53535354)) {
var $ss53575358 = {"from":L[15],
"go":function(ann_DASH_check_DASH_temp18465364) {
return $Hann_DASH_check_DASH_temp27255365(ann_DASH_check_DASH_temp18465364);
}};
$e53535354.stack[R.EXN_STACKHEIGHT++] = $ss53575358;
}
if(R.isPyretException($e53535354)) {
$e53535354.pyretStack.push(L[15]);
}
throw $e53535354;
}
var $ret53595360 = $Hann_DASH_check_DASH_temp27255365($z53555356);
++R.GAS;
return $ret53595360;
};
var $Hann_DASH_check_DASH_temp27255365 = function(ann_DASH_check_DASH_temp18465364) {
return ann_DASH_check_DASH_temp18465364;
};
var $Hanf_arg2721386 = function(anf_arg1838384,self314385,_plus14,torepr18) {
var anf_arg18395377 = G(self314385,"value",L[3]);
var $z53695370 = D;
var $f53755376 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg18395377):R.ffi.throwNonFunApp(L[3],torepr18,[anf_arg18395377]);
};
try {
if(--R.GAS > 0) {
$z53695370 = $f53755376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53755376,
"from":L[3]});
}
} catch($e53675368) {
if(R.isCont($e53675368)) {
var $ss53715372 = {"from":L[3],
"go":function(anf_arg18405378) {
return $Hanf_arg27205379(anf_arg18405378,anf_arg1838384,_plus14);
}};
$e53675368.stack[R.EXN_STACKHEIGHT++] = $ss53715372;
}
if(R.isPyretException($e53675368)) {
$e53675368.pyretStack.push(L[3]);
}
throw $e53675368;
}
var $ret53735374 = $Hanf_arg27205379($z53695370,anf_arg1838384,_plus14);
++R.GAS;
return $ret53735374;
};
var $Hanf_arg27205379 = function(anf_arg18405378,anf_arg1838384,_plus14) {
var $z53825383 = D;
var $f53885389 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg18405378):R.ffi.throwNonFunApp(L[3],_plus14,[(", "),anf_arg18405378]);
};
try {
if(--R.GAS > 0) {
$z53825383 = $f53885389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53885389,
"from":L[3]});
}
} catch($e53805381) {
if(R.isCont($e53805381)) {
var $ss53845385 = {"from":L[3],
"go":function(anf_arg18415390) {
return $Hanf_arg27195391(anf_arg18415390,anf_arg1838384,_plus14);
}};
$e53805381.stack[R.EXN_STACKHEIGHT++] = $ss53845385;
}
if(R.isPyretException($e53805381)) {
$e53805381.pyretStack.push(L[3]);
}
throw $e53805381;
}
var $ret53865387 = $Hanf_arg27195391($z53825383,anf_arg1838384,_plus14);
++R.GAS;
return $ret53865387;
};
var $Hanf_arg27195391 = function(anf_arg18415390,anf_arg1838384,_plus14) {
var $z53945395 = D;
var $f54005401 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg1838384,anf_arg18415390):R.ffi.throwNonFunApp(L[3],_plus14,[anf_arg1838384,anf_arg18415390]);
};
try {
if(--R.GAS > 0) {
$z53945395 = $f54005401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54005401,
"from":L[3]});
}
} catch($e53925393) {
if(R.isCont($e53925393)) {
var $ss53965397 = {"from":L[3],
"go":function(anf_arg18425402) {
return $Hanf_arg27185403(anf_arg18425402,_plus14);
}};
$e53925393.stack[R.EXN_STACKHEIGHT++] = $ss53965397;
}
if(R.isPyretException($e53925393)) {
$e53925393.pyretStack.push(L[3]);
}
throw $e53925393;
}
var $ret53985399 = $Hanf_arg27185403($z53945395,_plus14);
++R.GAS;
return $ret53985399;
};
var $Hanf_arg27185403 = function(anf_arg18425402,_plus14) {
var $z54065407 = D;
var $f54125413 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg18425402,(")")):R.ffi.throwNonFunApp(L[3],_plus14,[anf_arg18425402,(")")]);
};
try {
if(--R.GAS > 0) {
$z54065407 = $f54125413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54125413,
"from":L[3]});
}
} catch($e54045405) {
if(R.isCont($e54045405)) {
var $ss54085409 = {"from":L[3],
"go":function(anf_arg18435414) {
return $Hanf_arg27175415(anf_arg18435414,_plus14);
}};
$e54045405.stack[R.EXN_STACKHEIGHT++] = $ss54085409;
}
if(R.isPyretException($e54045405)) {
$e54045405.pyretStack.push(L[3]);
}
throw $e54045405;
}
var $ret54105411 = $Hanf_arg27175415($z54065407,_plus14);
++R.GAS;
return $ret54105411;
};
var $Hanf_arg27175415 = function(anf_arg18435414,_plus14) {
var $z54185419 = D;
var $f54245425 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg18435414):R.ffi.throwNonFunApp(L[3],_plus14,[("("),anf_arg18435414]);
};
try {
if(--R.GAS > 0) {
$z54185419 = $f54245425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54245425,
"from":L[3]});
}
} catch($e54165417) {
if(R.isCont($e54165417)) {
var $ss54205421 = {"from":L[3],
"go":function(anf_arg18445426) {
return $Hanf_arg27165427(anf_arg18445426,_plus14);
}};
$e54165417.stack[R.EXN_STACKHEIGHT++] = $ss54205421;
}
if(R.isPyretException($e54165417)) {
$e54165417.pyretStack.push(L[3]);
}
throw $e54165417;
}
var $ret54225423 = $Hanf_arg27165427($z54185419,_plus14);
++R.GAS;
return $ret54225423;
};
var $Hanf_arg27165427 = function(anf_arg18445426,_plus14) {
var $z54305431 = D;
var $f54365437 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-field"),anf_arg18445426):R.ffi.throwNonFunApp(L[3],_plus14,[("j-field"),anf_arg18445426]);
};
try {
if(--R.GAS > 0) {
$z54305431 = $f54365437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54365437,
"from":L[3]});
}
} catch($e54285429) {
if(R.isCont($e54285429)) {
var $ss54325433 = {"from":L[3],
"go":function(ann_DASH_check_DASH_temp18365438) {
return $Hann_DASH_check_DASH_temp27155439(ann_DASH_check_DASH_temp18365438);
}};
$e54285429.stack[R.EXN_STACKHEIGHT++] = $ss54325433;
}
if(R.isPyretException($e54285429)) {
$e54285429.pyretStack.push(L[3]);
}
throw $e54285429;
}
var $ret54345435 = $Hann_DASH_check_DASH_temp27155439($z54305431);
++R.GAS;
return $ret54345435;
};
var $Hann_DASH_check_DASH_temp27155439 = function(ann_DASH_check_DASH_temp18365438) {
return ann_DASH_check_DASH_temp18365438;
};
var $Hcont_tail_arg2713402 = function(cont_tail_arg1833400,if_helper1824401) {
if(--R.GAS > 0) {
$z54405441 = R.isFunction(if_helper1824401)?if_helper1824401.app(cont_tail_arg1833400):R.ffi.throwNonFunApp(L[3],if_helper1824401,[cont_tail_arg1833400]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1824401)?if_helper1824401.app(cont_tail_arg1833400):R.ffi.throwNonFunApp(L[3],if_helper1824401,[cont_tail_arg1833400]);
},
"from":L[3]});
}
++R.GAS;
return $z54405441;
};
var $Hcont_tail_arg2714417 = function(cont_tail_arg1829416,if_helper1824401) {
if(--R.GAS > 0) {
$z54425443 = R.isFunction(if_helper1824401)?if_helper1824401.app(cont_tail_arg1829416):R.ffi.throwNonFunApp(L[3],if_helper1824401,[cont_tail_arg1829416]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1824401)?if_helper1824401.app(cont_tail_arg1829416):R.ffi.throwNonFunApp(L[3],if_helper1824401,[cont_tail_arg1829416]);
},
"from":L[3]});
}
++R.GAS;
return $z54425443;
};
var $Hstrprint2712438 = function(strprint396436,self395437) {
var anf_fun18195454 = G(self395437,"print-ugly-source",L[568]);
var anf_arg18205455 = G(strprint396436,"append",L[567]);
var $z54465447 = D;
var $f54525453 = function(_) {
return R.isFunction(anf_fun18195454)?anf_fun18195454.app(anf_arg18205455):R.ffi.throwNonFunApp(L[566],anf_fun18195454,[anf_arg18205455]);
};
try {
if(--R.GAS > 0) {
$z54465447 = $f54525453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54525453,
"from":L[566]});
}
} catch($e54445445) {
if(R.isCont($e54445445)) {
var $ss54485449 = {"from":L[566],
"go":function(anf_begin_app_dropped27095456) {
return $Hanf_begin_app_dropped27115457(anf_begin_app_dropped27095456,strprint396436);
}};
$e54445445.stack[R.EXN_STACKHEIGHT++] = $ss54485449;
}
if(R.isPyretException($e54445445)) {
$e54445445.pyretStack.push(L[566]);
}
throw $e54445445;
}
var $ret54505451 = $Hanf_begin_app_dropped27115457($z54465447,strprint396436);
++R.GAS;
return $ret54505451;
};
var $Hanf_begin_app_dropped27115457 = function(anf_begin_app_dropped27095456,strprint396436) {
var anf_fun18215468 = G(strprint396436,"get",L[569]);
var $z54605461 = D;
var $f54665467 = function(_) {
return R.isFunction(anf_fun18215468)?anf_fun18215468.app():R.ffi.throwNonFunApp(L[19],anf_fun18215468,[]);
};
try {
if(--R.GAS > 0) {
$z54605461 = $f54665467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54665467,
"from":L[19]});
}
} catch($e54585459) {
if(R.isCont($e54585459)) {
var $ss54625463 = {"from":L[19],
"go":function(ann_DASH_check_DASH_temp18185469) {
return $Hann_DASH_check_DASH_temp27105470(ann_DASH_check_DASH_temp18185469);
}};
$e54585459.stack[R.EXN_STACKHEIGHT++] = $ss54625463;
}
if(R.isPyretException($e54585459)) {
$e54585459.pyretStack.push(L[19]);
}
throw $e54585459;
}
var $ret54645465 = $Hann_DASH_check_DASH_temp27105470($z54605461);
++R.GAS;
return $ret54645465;
};
var $Hann_DASH_check_DASH_temp27105470 = function(ann_DASH_check_DASH_temp18185469) {
return ann_DASH_check_DASH_temp18185469;
};
var $Hfilldocs2708699 = function(filldocs386697,PP123,format7662,self385698) {
var anf_fun17555481 = G(filldocs386697,"map",L[573]);
var anf_arg17595482 = R.makeFunction(function(recv_DASH_3095485) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[571],1,arguments);
}
var anf_fun17575496 = G(recv_DASH_3095485,"pretty",L[571]);
var anf_arg17585497 = G(self385698,"width-tolerance",L[572]);
var $z54885489 = D;
var $f54945495 = function(_) {
return R.isFunction(anf_fun17575496)?anf_fun17575496.app(anf_arg17585497):R.ffi.throwNonFunApp(L[571],anf_fun17575496,[anf_arg17585497]);
};
try {
if(--R.GAS > 0) {
$z54885489 = $f54945495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54945495,
"from":L[571]});
}
} catch($e54865487) {
if(R.isCont($e54865487)) {
var $ss54905491 = {"from":L[571],
"go":function(ann_DASH_check_DASH_temp17565498) {
return $Hann_DASH_check_DASH_temp27025499(ann_DASH_check_DASH_temp17565498);
}};
$e54865487.stack[R.EXN_STACKHEIGHT++] = $ss54905491;
}
if(R.isPyretException($e54865487)) {
$e54865487.pyretStack.push(L[571]);
}
throw $e54865487;
}
var $ret54925493 = $Hann_DASH_check_DASH_temp27025499($z54885489);
++R.GAS;
return $ret54925493;
});
var $z54735474 = D;
var $f54795480 = function(_) {
return R.isFunction(anf_fun17555481)?anf_fun17555481.app(anf_arg17595482):R.ffi.throwNonFunApp(L[570],anf_fun17555481,[anf_arg17595482]);
};
try {
if(--R.GAS > 0) {
$z54735474 = $f54795480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54795480,
"from":L[570]});
}
} catch($e54715472) {
if(R.isCont($e54715472)) {
var $ss54755476 = {"from":L[570],
"go":function(anf_bracket17605483) {
return $Hanf_bracket27075484(anf_bracket17605483,PP123,format7662,self385698);
}};
$e54715472.stack[R.EXN_STACKHEIGHT++] = $ss54755476;
}
if(R.isPyretException($e54715472)) {
$e54715472.pyretStack.push(L[570]);
}
throw $e54715472;
}
var $ret54775478 = $Hanf_bracket27075484($z54735474,PP123,format7662,self385698);
++R.GAS;
return $ret54775478;
};
var $Hanf_bracket27075484 = function(anf_bracket17605483,PP123,format7662,self385698) {
var anf_fun17615510 = G(anf_bracket17605483,"map",L[576]);
var anf_arg17645511 = R.makeFunction(function(recv_DASH_3085514) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[575],1,arguments);
}
var anf_fun17635525 = G(recv_DASH_3085514,"join-str",L[575]);
var $z55175518 = D;
var $f55235524 = function(_) {
return R.isFunction(anf_fun17635525)?anf_fun17635525.app((" ")):R.ffi.throwNonFunApp(L[575],anf_fun17635525,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z55175518 = $f55235524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55235524,
"from":L[575]});
}
} catch($e55155516) {
if(R.isCont($e55155516)) {
var $ss55195520 = {"from":L[575],
"go":function(ann_DASH_check_DASH_temp17625526) {
return $Hann_DASH_check_DASH_temp27035527(ann_DASH_check_DASH_temp17625526);
}};
$e55155516.stack[R.EXN_STACKHEIGHT++] = $ss55195520;
}
if(R.isPyretException($e55155516)) {
$e55155516.pyretStack.push(L[575]);
}
throw $e55155516;
}
var $ret55215522 = $Hann_DASH_check_DASH_temp27035527($z55175518);
++R.GAS;
return $ret55215522;
});
var $z55025503 = D;
var $f55085509 = function(_) {
return R.isFunction(anf_fun17615510)?anf_fun17615510.app(anf_arg17645511):R.ffi.throwNonFunApp(L[574],anf_fun17615510,[anf_arg17645511]);
};
try {
if(--R.GAS > 0) {
$z55025503 = $f55085509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55085509,
"from":L[574]});
}
} catch($e55005501) {
if(R.isCont($e55005501)) {
var $ss55045505 = {"from":L[574],
"go":function(fillstrs3875512) {
return $Hfillstrs27065513(fillstrs3875512,PP123,format7662,self385698);
}};
$e55005501.stack[R.EXN_STACKHEIGHT++] = $ss55045505;
}
if(R.isPyretException($e55005501)) {
$e55005501.pyretStack.push(L[574]);
}
throw $e55005501;
}
var $ret55065507 = $Hfillstrs27065513($z55025503,PP123,format7662,self385698);
++R.GAS;
return $ret55065507;
};
var $Hfillstrs27065513 = function(fillstrs3875512,PP123,format7662,self385698) {
var anf_fun17655540 = G(PP123,"str",L[579]);
var anf_arg17665538 = G(self385698,"raw-js",L[578]);
var $z55305531 = D;
var $f55365537 = function(_) {
return R.isFunction(format7662)?format7662.app(anf_arg17665538,fillstrs3875512):R.ffi.throwNonFunApp(L[577],format7662,[anf_arg17665538,fillstrs3875512]);
};
try {
if(--R.GAS > 0) {
$z55305531 = $f55365537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55365537,
"from":L[577]});
}
} catch($e55285529) {
if(R.isCont($e55285529)) {
var $ss55325533 = {"from":L[577],
"go":function(anf_arg17675539) {
return $Hanf_arg27055541(anf_arg17675539,anf_fun17655540);
}};
$e55285529.stack[R.EXN_STACKHEIGHT++] = $ss55325533;
}
if(R.isPyretException($e55285529)) {
$e55285529.pyretStack.push(L[577]);
}
throw $e55285529;
}
var $ret55345535 = $Hanf_arg27055541($z55305531,anf_fun17655540);
++R.GAS;
return $ret55345535;
};
var $Hanf_arg27055541 = function(anf_arg17675539,anf_fun17655540) {
var $z55445545 = D;
var $f55505551 = function(_) {
return R.isFunction(anf_fun17655540)?anf_fun17655540.app(anf_arg17675539):R.ffi.throwNonFunApp(L[104],anf_fun17655540,[anf_arg17675539]);
};
try {
if(--R.GAS > 0) {
$z55445545 = $f55505551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55505551,
"from":L[104]});
}
} catch($e55425543) {
if(R.isCont($e55425543)) {
var $ss55465547 = {"from":L[104],
"go":function(ann_DASH_check_DASH_temp17495552) {
return $Hann_DASH_check_DASH_temp27045553(ann_DASH_check_DASH_temp17495552);
}};
$e55425543.stack[R.EXN_STACKHEIGHT++] = $ss55465547;
}
if(R.isPyretException($e55425543)) {
$e55425543.pyretStack.push(L[104]);
}
throw $e55425543;
}
var $ret55485549 = $Hann_DASH_check_DASH_temp27045553($z55445545);
++R.GAS;
return $ret55485549;
};
var $Hann_DASH_check_DASH_temp27045553 = function(ann_DASH_check_DASH_temp17495552) {
return ann_DASH_check_DASH_temp17495552;
};
var $Hann_DASH_check_DASH_temp27035527 = function(ann_DASH_check_DASH_temp17625526) {
return ann_DASH_check_DASH_temp17625526;
};
var $Hann_DASH_check_DASH_temp27025499 = function(ann_DASH_check_DASH_temp17565498) {
return ann_DASH_check_DASH_temp17565498;
};
var $Hann_DASH_check_DASH_temp2701713 = function(ann_DASH_check_DASH_temp1752712) {
return ann_DASH_check_DASH_temp1752712;
};
var $Hann_DASH_check_DASH_temp2700726 = function(ann_DASH_check_DASH_temp1747725) {
return ann_DASH_check_DASH_temp1747725;
};
var $Hanf_arg2699742 = function(anf_arg1735740,self305741,_plus14,torepr18) {
var anf_arg17365564 = G(self305741,"fills",L[20]);
var $z55565557 = D;
var $f55625563 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg17365564):R.ffi.throwNonFunApp(L[20],torepr18,[anf_arg17365564]);
};
try {
if(--R.GAS > 0) {
$z55565557 = $f55625563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55625563,
"from":L[20]});
}
} catch($e55545555) {
if(R.isCont($e55545555)) {
var $ss55585559 = {"from":L[20],
"go":function(anf_arg17375565) {
return $Hanf_arg26985566(anf_arg17375565,anf_arg1735740,self305741,_plus14,torepr18);
}};
$e55545555.stack[R.EXN_STACKHEIGHT++] = $ss55585559;
}
if(R.isPyretException($e55545555)) {
$e55545555.pyretStack.push(L[20]);
}
throw $e55545555;
}
var $ret55605561 = $Hanf_arg26985566($z55565557,anf_arg1735740,self305741,_plus14,torepr18);
++R.GAS;
return $ret55605561;
};
var $Hanf_arg26985566 = function(anf_arg17375565,anf_arg1735740,self305741,_plus14,torepr18) {
var $z55695570 = D;
var $f55755576 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg17375565):R.ffi.throwNonFunApp(L[20],_plus14,[(", "),anf_arg17375565]);
};
try {
if(--R.GAS > 0) {
$z55695570 = $f55755576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55755576,
"from":L[20]});
}
} catch($e55675568) {
if(R.isCont($e55675568)) {
var $ss55715572 = {"from":L[20],
"go":function(anf_arg17385577) {
return $Hanf_arg26975578(anf_arg17385577,anf_arg1735740,self305741,_plus14,torepr18);
}};
$e55675568.stack[R.EXN_STACKHEIGHT++] = $ss55715572;
}
if(R.isPyretException($e55675568)) {
$e55675568.pyretStack.push(L[20]);
}
throw $e55675568;
}
var $ret55735574 = $Hanf_arg26975578($z55695570,anf_arg1735740,self305741,_plus14,torepr18);
++R.GAS;
return $ret55735574;
};
var $Hanf_arg26975578 = function(anf_arg17385577,anf_arg1735740,self305741,_plus14,torepr18) {
var $z55815582 = D;
var $f55875588 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg1735740,anf_arg17385577):R.ffi.throwNonFunApp(L[20],_plus14,[anf_arg1735740,anf_arg17385577]);
};
try {
if(--R.GAS > 0) {
$z55815582 = $f55875588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55875588,
"from":L[20]});
}
} catch($e55795580) {
if(R.isCont($e55795580)) {
var $ss55835584 = {"from":L[20],
"go":function(anf_arg17395589) {
return $Hanf_arg26965590(anf_arg17395589,self305741,_plus14,torepr18);
}};
$e55795580.stack[R.EXN_STACKHEIGHT++] = $ss55835584;
}
if(R.isPyretException($e55795580)) {
$e55795580.pyretStack.push(L[20]);
}
throw $e55795580;
}
var $ret55855586 = $Hanf_arg26965590($z55815582,self305741,_plus14,torepr18);
++R.GAS;
return $ret55855586;
};
var $Hanf_arg26965590 = function(anf_arg17395589,self305741,_plus14,torepr18) {
var anf_arg17405601 = G(self305741,"width-tolerance",L[20]);
var $z55935594 = D;
var $f55995600 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg17405601):R.ffi.throwNonFunApp(L[20],torepr18,[anf_arg17405601]);
};
try {
if(--R.GAS > 0) {
$z55935594 = $f55995600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55995600,
"from":L[20]});
}
} catch($e55915592) {
if(R.isCont($e55915592)) {
var $ss55955596 = {"from":L[20],
"go":function(anf_arg17415602) {
return $Hanf_arg26955603(anf_arg17415602,anf_arg17395589,_plus14);
}};
$e55915592.stack[R.EXN_STACKHEIGHT++] = $ss55955596;
}
if(R.isPyretException($e55915592)) {
$e55915592.pyretStack.push(L[20]);
}
throw $e55915592;
}
var $ret55975598 = $Hanf_arg26955603($z55935594,anf_arg17395589,_plus14);
++R.GAS;
return $ret55975598;
};
var $Hanf_arg26955603 = function(anf_arg17415602,anf_arg17395589,_plus14) {
var $z56065607 = D;
var $f56125613 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg17415602):R.ffi.throwNonFunApp(L[20],_plus14,[(", "),anf_arg17415602]);
};
try {
if(--R.GAS > 0) {
$z56065607 = $f56125613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56125613,
"from":L[20]});
}
} catch($e56045605) {
if(R.isCont($e56045605)) {
var $ss56085609 = {"from":L[20],
"go":function(anf_arg17425614) {
return $Hanf_arg26945615(anf_arg17425614,anf_arg17395589,_plus14);
}};
$e56045605.stack[R.EXN_STACKHEIGHT++] = $ss56085609;
}
if(R.isPyretException($e56045605)) {
$e56045605.pyretStack.push(L[20]);
}
throw $e56045605;
}
var $ret56105611 = $Hanf_arg26945615($z56065607,anf_arg17395589,_plus14);
++R.GAS;
return $ret56105611;
};
var $Hanf_arg26945615 = function(anf_arg17425614,anf_arg17395589,_plus14) {
var $z56185619 = D;
var $f56245625 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg17395589,anf_arg17425614):R.ffi.throwNonFunApp(L[20],_plus14,[anf_arg17395589,anf_arg17425614]);
};
try {
if(--R.GAS > 0) {
$z56185619 = $f56245625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56245625,
"from":L[20]});
}
} catch($e56165617) {
if(R.isCont($e56165617)) {
var $ss56205621 = {"from":L[20],
"go":function(anf_arg17435626) {
return $Hanf_arg26935627(anf_arg17435626,_plus14);
}};
$e56165617.stack[R.EXN_STACKHEIGHT++] = $ss56205621;
}
if(R.isPyretException($e56165617)) {
$e56165617.pyretStack.push(L[20]);
}
throw $e56165617;
}
var $ret56225623 = $Hanf_arg26935627($z56185619,_plus14);
++R.GAS;
return $ret56225623;
};
var $Hanf_arg26935627 = function(anf_arg17435626,_plus14) {
var $z56305631 = D;
var $f56365637 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg17435626,(")")):R.ffi.throwNonFunApp(L[20],_plus14,[anf_arg17435626,(")")]);
};
try {
if(--R.GAS > 0) {
$z56305631 = $f56365637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56365637,
"from":L[20]});
}
} catch($e56285629) {
if(R.isCont($e56285629)) {
var $ss56325633 = {"from":L[20],
"go":function(anf_arg17445638) {
return $Hanf_arg26925639(anf_arg17445638,_plus14);
}};
$e56285629.stack[R.EXN_STACKHEIGHT++] = $ss56325633;
}
if(R.isPyretException($e56285629)) {
$e56285629.pyretStack.push(L[20]);
}
throw $e56285629;
}
var $ret56345635 = $Hanf_arg26925639($z56305631,_plus14);
++R.GAS;
return $ret56345635;
};
var $Hanf_arg26925639 = function(anf_arg17445638,_plus14) {
var $z56425643 = D;
var $f56485649 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg17445638):R.ffi.throwNonFunApp(L[20],_plus14,[("("),anf_arg17445638]);
};
try {
if(--R.GAS > 0) {
$z56425643 = $f56485649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56485649,
"from":L[20]});
}
} catch($e56405641) {
if(R.isCont($e56405641)) {
var $ss56445645 = {"from":L[20],
"go":function(anf_arg17455650) {
return $Hanf_arg26915651(anf_arg17455650,_plus14);
}};
$e56405641.stack[R.EXN_STACKHEIGHT++] = $ss56445645;
}
if(R.isPyretException($e56405641)) {
$e56405641.pyretStack.push(L[20]);
}
throw $e56405641;
}
var $ret56465647 = $Hanf_arg26915651($z56425643,_plus14);
++R.GAS;
return $ret56465647;
};
var $Hanf_arg26915651 = function(anf_arg17455650,_plus14) {
var $z56545655 = D;
var $f56605661 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-raw-holes"),anf_arg17455650):R.ffi.throwNonFunApp(L[20],_plus14,[("j-raw-holes"),anf_arg17455650]);
};
try {
if(--R.GAS > 0) {
$z56545655 = $f56605661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56605661,
"from":L[20]});
}
} catch($e56525653) {
if(R.isCont($e56525653)) {
var $ss56565657 = {"from":L[20],
"go":function(ann_DASH_check_DASH_temp17335662) {
return $Hann_DASH_check_DASH_temp26905663(ann_DASH_check_DASH_temp17335662);
}};
$e56525653.stack[R.EXN_STACKHEIGHT++] = $ss56565657;
}
if(R.isPyretException($e56525653)) {
$e56525653.pyretStack.push(L[20]);
}
throw $e56525653;
}
var $ret56585659 = $Hann_DASH_check_DASH_temp26905663($z56545655);
++R.GAS;
return $ret56585659;
};
var $Hann_DASH_check_DASH_temp26905663 = function(ann_DASH_check_DASH_temp17335662) {
return ann_DASH_check_DASH_temp17335662;
};
var $Hcont_tail_arg2688759 = function(cont_tail_arg1730757,if_helper1720758) {
if(--R.GAS > 0) {
$z56645665 = R.isFunction(if_helper1720758)?if_helper1720758.app(cont_tail_arg1730757):R.ffi.throwNonFunApp(L[20],if_helper1720758,[cont_tail_arg1730757]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1720758)?if_helper1720758.app(cont_tail_arg1730757):R.ffi.throwNonFunApp(L[20],if_helper1720758,[cont_tail_arg1730757]);
},
"from":L[20]});
}
++R.GAS;
return $z56645665;
};
var $Hcont_tail_arg2689774 = function(cont_tail_arg1725773,if_helper1720758) {
if(--R.GAS > 0) {
$z56665667 = R.isFunction(if_helper1720758)?if_helper1720758.app(cont_tail_arg1725773):R.ffi.throwNonFunApp(L[20],if_helper1720758,[cont_tail_arg1725773]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1720758)?if_helper1720758.app(cont_tail_arg1725773):R.ffi.throwNonFunApp(L[20],if_helper1720758,[cont_tail_arg1725773]);
},
"from":L[20]});
}
++R.GAS;
return $z56665667;
};
var $Hann_DASH_check_DASH_temp2687795 = function(ann_DASH_check_DASH_temp1715794) {
return ann_DASH_check_DASH_temp1715794;
};
var $Hann_DASH_check_DASH_temp2686810 = function(ann_DASH_check_DASH_temp1712809) {
return ann_DASH_check_DASH_temp1712809;
};
var $Hanf_arg2685824 = function(anf_arg1708823,_plus14) {
var $z56705671 = D;
var $f56765677 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg1708823,(")")):R.ffi.throwNonFunApp(L[21],_plus14,[anf_arg1708823,(")")]);
};
try {
if(--R.GAS > 0) {
$z56705671 = $f56765677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56765677,
"from":L[21]});
}
} catch($e56685669) {
if(R.isCont($e56685669)) {
var $ss56725673 = {"from":L[21],
"go":function(anf_arg17095678) {
return $Hanf_arg26845679(anf_arg17095678,_plus14);
}};
$e56685669.stack[R.EXN_STACKHEIGHT++] = $ss56725673;
}
if(R.isPyretException($e56685669)) {
$e56685669.pyretStack.push(L[21]);
}
throw $e56685669;
}
var $ret56745675 = $Hanf_arg26845679($z56705671,_plus14);
++R.GAS;
return $ret56745675;
};
var $Hanf_arg26845679 = function(anf_arg17095678,_plus14) {
var $z56825683 = D;
var $f56885689 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg17095678):R.ffi.throwNonFunApp(L[21],_plus14,[("("),anf_arg17095678]);
};
try {
if(--R.GAS > 0) {
$z56825683 = $f56885689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56885689,
"from":L[21]});
}
} catch($e56805681) {
if(R.isCont($e56805681)) {
var $ss56845685 = {"from":L[21],
"go":function(anf_arg17105690) {
return $Hanf_arg26835691(anf_arg17105690,_plus14);
}};
$e56805681.stack[R.EXN_STACKHEIGHT++] = $ss56845685;
}
if(R.isPyretException($e56805681)) {
$e56805681.pyretStack.push(L[21]);
}
throw $e56805681;
}
var $ret56865687 = $Hanf_arg26835691($z56825683,_plus14);
++R.GAS;
return $ret56865687;
};
var $Hanf_arg26835691 = function(anf_arg17105690,_plus14) {
var $z56945695 = D;
var $f57005701 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-raw"),anf_arg17105690):R.ffi.throwNonFunApp(L[21],_plus14,[("j-raw"),anf_arg17105690]);
};
try {
if(--R.GAS > 0) {
$z56945695 = $f57005701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57005701,
"from":L[21]});
}
} catch($e56925693) {
if(R.isCont($e56925693)) {
var $ss56965697 = {"from":L[21],
"go":function(ann_DASH_check_DASH_temp17065702) {
return $Hann_DASH_check_DASH_temp26825703(ann_DASH_check_DASH_temp17065702);
}};
$e56925693.stack[R.EXN_STACKHEIGHT++] = $ss56965697;
}
if(R.isPyretException($e56925693)) {
$e56925693.pyretStack.push(L[21]);
}
throw $e56925693;
}
var $ret56985699 = $Hann_DASH_check_DASH_temp26825703($z56945695);
++R.GAS;
return $ret56985699;
};
var $Hann_DASH_check_DASH_temp26825703 = function(ann_DASH_check_DASH_temp17065702) {
return ann_DASH_check_DASH_temp17065702;
};
var $Hcont_tail_arg2680840 = function(cont_tail_arg1703838,if_helper1695839) {
if(--R.GAS > 0) {
$z57045705 = R.isFunction(if_helper1695839)?if_helper1695839.app(cont_tail_arg1703838):R.ffi.throwNonFunApp(L[21],if_helper1695839,[cont_tail_arg1703838]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1695839)?if_helper1695839.app(cont_tail_arg1703838):R.ffi.throwNonFunApp(L[21],if_helper1695839,[cont_tail_arg1703838]);
},
"from":L[21]});
}
++R.GAS;
return $z57045705;
};
var $Hcont_tail_arg2681855 = function(cont_tail_arg1700854,if_helper1695839) {
if(--R.GAS > 0) {
$z57065707 = R.isFunction(if_helper1695839)?if_helper1695839.app(cont_tail_arg1700854):R.ffi.throwNonFunApp(L[21],if_helper1695839,[cont_tail_arg1700854]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1695839)?if_helper1695839.app(cont_tail_arg1700854):R.ffi.throwNonFunApp(L[21],if_helper1695839,[cont_tail_arg1700854]);
},
"from":L[21]});
}
++R.GAS;
return $z57065707;
};
var $Hann_DASH_check_DASH_temp2679875 = function(ann_DASH_check_DASH_temp1691874) {
return ann_DASH_check_DASH_temp1691874;
};
var $Hann_DASH_check_DASH_temp2678889 = function(ann_DASH_check_DASH_temp1689888) {
return ann_DASH_check_DASH_temp1689888;
};
var $Hcont_tail_arg2676906 = function(cont_tail_arg1684904,if_helper1677905) {
if(--R.GAS > 0) {
$z57085709 = R.isFunction(if_helper1677905)?if_helper1677905.app(cont_tail_arg1684904):R.ffi.throwNonFunApp(L[22],if_helper1677905,[cont_tail_arg1684904]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1677905)?if_helper1677905.app(cont_tail_arg1684904):R.ffi.throwNonFunApp(L[22],if_helper1677905,[cont_tail_arg1684904]);
},
"from":L[22]});
}
++R.GAS;
return $z57085709;
};
var $Hcont_tail_arg2677920 = function(cont_tail_arg1682919,if_helper1677905) {
if(--R.GAS > 0) {
$z57105711 = R.isFunction(if_helper1677905)?if_helper1677905.app(cont_tail_arg1682919):R.ffi.throwNonFunApp(L[22],if_helper1677905,[cont_tail_arg1682919]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1677905)?if_helper1677905.app(cont_tail_arg1682919):R.ffi.throwNonFunApp(L[22],if_helper1677905,[cont_tail_arg1682919]);
},
"from":L[22]});
}
++R.GAS;
return $z57105711;
};
var $Hann_DASH_check_DASH_temp2675941 = function(ann_DASH_check_DASH_temp1673940) {
return ann_DASH_check_DASH_temp1673940;
};
var $Hann_DASH_check_DASH_temp2674955 = function(ann_DASH_check_DASH_temp1671954) {
return ann_DASH_check_DASH_temp1671954;
};
var $Hcont_tail_arg2672972 = function(cont_tail_arg1666970,if_helper1659971) {
if(--R.GAS > 0) {
$z57125713 = R.isFunction(if_helper1659971)?if_helper1659971.app(cont_tail_arg1666970):R.ffi.throwNonFunApp(L[23],if_helper1659971,[cont_tail_arg1666970]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1659971)?if_helper1659971.app(cont_tail_arg1666970):R.ffi.throwNonFunApp(L[23],if_helper1659971,[cont_tail_arg1666970]);
},
"from":L[23]});
}
++R.GAS;
return $z57125713;
};
var $Hcont_tail_arg2673986 = function(cont_tail_arg1664985,if_helper1659971) {
if(--R.GAS > 0) {
$z57145715 = R.isFunction(if_helper1659971)?if_helper1659971.app(cont_tail_arg1664985):R.ffi.throwNonFunApp(L[23],if_helper1659971,[cont_tail_arg1664985]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1659971)?if_helper1659971.app(cont_tail_arg1664985):R.ffi.throwNonFunApp(L[23],if_helper1659971,[cont_tail_arg1664985]);
},
"from":L[23]});
}
++R.GAS;
return $z57145715;
};
var $Hann_DASH_check_DASH_temp26711007 = function(ann_DASH_check_DASH_temp16551006) {
return ann_DASH_check_DASH_temp16551006;
};
var $Hann_DASH_check_DASH_temp26701021 = function(ann_DASH_check_DASH_temp16531020) {
return ann_DASH_check_DASH_temp16531020;
};
var $Hcont_tail_arg26681038 = function(cont_tail_arg16481036,if_helper16411037) {
if(--R.GAS > 0) {
$z57165717 = R.isFunction(if_helper16411037)?if_helper16411037.app(cont_tail_arg16481036):R.ffi.throwNonFunApp(L[24],if_helper16411037,[cont_tail_arg16481036]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper16411037)?if_helper16411037.app(cont_tail_arg16481036):R.ffi.throwNonFunApp(L[24],if_helper16411037,[cont_tail_arg16481036]);
},
"from":L[24]});
}
++R.GAS;
return $z57165717;
};
var $Hcont_tail_arg26691052 = function(cont_tail_arg16461051,if_helper16411037) {
if(--R.GAS > 0) {
$z57185719 = R.isFunction(if_helper16411037)?if_helper16411037.app(cont_tail_arg16461051):R.ffi.throwNonFunApp(L[24],if_helper16411037,[cont_tail_arg16461051]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper16411037)?if_helper16411037.app(cont_tail_arg16461051):R.ffi.throwNonFunApp(L[24],if_helper16411037,[cont_tail_arg16461051]);
},
"from":L[24]});
}
++R.GAS;
return $z57185719;
};
var $Hann_DASH_check_DASH_temp26671073 = function(ann_DASH_check_DASH_temp16371072) {
return ann_DASH_check_DASH_temp16371072;
};
var $Hann_DASH_check_DASH_temp26661087 = function(ann_DASH_check_DASH_temp16351086) {
return ann_DASH_check_DASH_temp16351086;
};
var $Hcont_tail_arg26641104 = function(cont_tail_arg16301102,if_helper16231103) {
if(--R.GAS > 0) {
$z57205721 = R.isFunction(if_helper16231103)?if_helper16231103.app(cont_tail_arg16301102):R.ffi.throwNonFunApp(L[25],if_helper16231103,[cont_tail_arg16301102]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper16231103)?if_helper16231103.app(cont_tail_arg16301102):R.ffi.throwNonFunApp(L[25],if_helper16231103,[cont_tail_arg16301102]);
},
"from":L[25]});
}
++R.GAS;
return $z57205721;
};
var $Hcont_tail_arg26651118 = function(cont_tail_arg16281117,if_helper16231103) {
if(--R.GAS > 0) {
$z57225723 = R.isFunction(if_helper16231103)?if_helper16231103.app(cont_tail_arg16281117):R.ffi.throwNonFunApp(L[25],if_helper16231103,[cont_tail_arg16281117]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper16231103)?if_helper16231103.app(cont_tail_arg16281117):R.ffi.throwNonFunApp(L[25],if_helper16231103,[cont_tail_arg16281117]);
},
"from":L[25]});
}
++R.GAS;
return $z57225723;
};
var $Hann_DASH_check_DASH_temp26631140 = function(ann_DASH_check_DASH_temp16181139) {
return ann_DASH_check_DASH_temp16181139;
};
var $Hanf_arg26621155 = function(anf_arg16161153,printer3621154) {
var $z57265727 = D;
var $f57325733 = function(_) {
return R.isFunction(printer3621154)?printer3621154.app(anf_arg16161153):R.ffi.throwNonFunApp(L[132],printer3621154,[anf_arg16161153]);
};
try {
if(--R.GAS > 0) {
$z57265727 = $f57325733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57325733,
"from":L[132]});
}
} catch($e57245725) {
if(R.isCont($e57245725)) {
var $ss57285729 = {"from":L[132],
"go":function(ann_DASH_check_DASH_temp16145734) {
return $Hann_DASH_check_DASH_temp26615735(ann_DASH_check_DASH_temp16145734);
}};
$e57245725.stack[R.EXN_STACKHEIGHT++] = $ss57285729;
}
if(R.isPyretException($e57245725)) {
$e57245725.pyretStack.push(L[132]);
}
throw $e57245725;
}
var $ret57305731 = $Hann_DASH_check_DASH_temp26615735($z57265727);
++R.GAS;
return $ret57305731;
};
var $Hann_DASH_check_DASH_temp26615735 = function(ann_DASH_check_DASH_temp16145734) {
return ann_DASH_check_DASH_temp16145734;
};
var $Hanf_arg26601169 = function(anf_arg16101168,_plus14) {
var $z57385739 = D;
var $f57445745 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg16101168,(")")):R.ffi.throwNonFunApp(L[26],_plus14,[anf_arg16101168,(")")]);
};
try {
if(--R.GAS > 0) {
$z57385739 = $f57445745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57445745,
"from":L[26]});
}
} catch($e57365737) {
if(R.isCont($e57365737)) {
var $ss57405741 = {"from":L[26],
"go":function(anf_arg16115746) {
return $Hanf_arg26595747(anf_arg16115746,_plus14);
}};
$e57365737.stack[R.EXN_STACKHEIGHT++] = $ss57405741;
}
if(R.isPyretException($e57365737)) {
$e57365737.pyretStack.push(L[26]);
}
throw $e57365737;
}
var $ret57425743 = $Hanf_arg26595747($z57385739,_plus14);
++R.GAS;
return $ret57425743;
};
var $Hanf_arg26595747 = function(anf_arg16115746,_plus14) {
var $z57505751 = D;
var $f57565757 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg16115746):R.ffi.throwNonFunApp(L[26],_plus14,[("("),anf_arg16115746]);
};
try {
if(--R.GAS > 0) {
$z57505751 = $f57565757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57565757,
"from":L[26]});
}
} catch($e57485749) {
if(R.isCont($e57485749)) {
var $ss57525753 = {"from":L[26],
"go":function(anf_arg16125758) {
return $Hanf_arg26585759(anf_arg16125758,_plus14);
}};
$e57485749.stack[R.EXN_STACKHEIGHT++] = $ss57525753;
}
if(R.isPyretException($e57485749)) {
$e57485749.pyretStack.push(L[26]);
}
throw $e57485749;
}
var $ret57545755 = $Hanf_arg26585759($z57505751,_plus14);
++R.GAS;
return $ret57545755;
};
var $Hanf_arg26585759 = function(anf_arg16125758,_plus14) {
var $z57625763 = D;
var $f57685769 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-num"),anf_arg16125758):R.ffi.throwNonFunApp(L[26],_plus14,[("j-num"),anf_arg16125758]);
};
try {
if(--R.GAS > 0) {
$z57625763 = $f57685769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57685769,
"from":L[26]});
}
} catch($e57605761) {
if(R.isCont($e57605761)) {
var $ss57645765 = {"from":L[26],
"go":function(ann_DASH_check_DASH_temp16085770) {
return $Hann_DASH_check_DASH_temp26575771(ann_DASH_check_DASH_temp16085770);
}};
$e57605761.stack[R.EXN_STACKHEIGHT++] = $ss57645765;
}
if(R.isPyretException($e57605761)) {
$e57605761.pyretStack.push(L[26]);
}
throw $e57605761;
}
var $ret57665767 = $Hann_DASH_check_DASH_temp26575771($z57625763);
++R.GAS;
return $ret57665767;
};
var $Hann_DASH_check_DASH_temp26575771 = function(ann_DASH_check_DASH_temp16085770) {
return ann_DASH_check_DASH_temp16085770;
};
var $Hcont_tail_arg26551185 = function(cont_tail_arg16051183,if_helper15971184) {
if(--R.GAS > 0) {
$z57725773 = R.isFunction(if_helper15971184)?if_helper15971184.app(cont_tail_arg16051183):R.ffi.throwNonFunApp(L[26],if_helper15971184,[cont_tail_arg16051183]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15971184)?if_helper15971184.app(cont_tail_arg16051183):R.ffi.throwNonFunApp(L[26],if_helper15971184,[cont_tail_arg16051183]);
},
"from":L[26]});
}
++R.GAS;
return $z57725773;
};
var $Hcont_tail_arg26561200 = function(cont_tail_arg16021199,if_helper15971184) {
if(--R.GAS > 0) {
$z57745775 = R.isFunction(if_helper15971184)?if_helper15971184.app(cont_tail_arg16021199):R.ffi.throwNonFunApp(L[26],if_helper15971184,[cont_tail_arg16021199]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15971184)?if_helper15971184.app(cont_tail_arg16021199):R.ffi.throwNonFunApp(L[26],if_helper15971184,[cont_tail_arg16021199]);
},
"from":L[26]});
}
++R.GAS;
return $z57745775;
};
var $Hanf_arg26541221 = function(anf_arg15941219,anf_fun15921220) {
var $z57785779 = D;
var $f57845785 = function(_) {
return R.isFunction(anf_fun15921220)?anf_fun15921220.app(anf_arg15941219):R.ffi.throwNonFunApp(L[137],anf_fun15921220,[anf_arg15941219]);
};
try {
if(--R.GAS > 0) {
$z57785779 = $f57845785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57845785,
"from":L[137]});
}
} catch($e57765777) {
if(R.isCont($e57765777)) {
var $ss57805781 = {"from":L[137],
"go":function(ann_DASH_check_DASH_temp15915786) {
return $Hann_DASH_check_DASH_temp26535787(ann_DASH_check_DASH_temp15915786);
}};
$e57765777.stack[R.EXN_STACKHEIGHT++] = $ss57805781;
}
if(R.isPyretException($e57765777)) {
$e57765777.pyretStack.push(L[137]);
}
throw $e57765777;
}
var $ret57825783 = $Hann_DASH_check_DASH_temp26535787($z57785779);
++R.GAS;
return $ret57825783;
};
var $Hann_DASH_check_DASH_temp26535787 = function(ann_DASH_check_DASH_temp15915786) {
return ann_DASH_check_DASH_temp15915786;
};
var $Hanf_arg26521236 = function(anf_arg15891234,printer3581235) {
var $z57905791 = D;
var $f57965797 = function(_) {
return R.isFunction(printer3581235)?printer3581235.app(anf_arg15891234):R.ffi.throwNonFunApp(L[140],printer3581235,[anf_arg15891234]);
};
try {
if(--R.GAS > 0) {
$z57905791 = $f57965797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57965797,
"from":L[140]});
}
} catch($e57885789) {
if(R.isCont($e57885789)) {
var $ss57925793 = {"from":L[140],
"go":function(ann_DASH_check_DASH_temp15875798) {
return $Hann_DASH_check_DASH_temp26515799(ann_DASH_check_DASH_temp15875798);
}};
$e57885789.stack[R.EXN_STACKHEIGHT++] = $ss57925793;
}
if(R.isPyretException($e57885789)) {
$e57885789.pyretStack.push(L[140]);
}
throw $e57885789;
}
var $ret57945795 = $Hann_DASH_check_DASH_temp26515799($z57905791);
++R.GAS;
return $ret57945795;
};
var $Hann_DASH_check_DASH_temp26515799 = function(ann_DASH_check_DASH_temp15875798) {
return ann_DASH_check_DASH_temp15875798;
};
var $Hanf_arg26501250 = function(anf_arg15831249,_plus14) {
var $z58025803 = D;
var $f58085809 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg15831249,(")")):R.ffi.throwNonFunApp(L[27],_plus14,[anf_arg15831249,(")")]);
};
try {
if(--R.GAS > 0) {
$z58025803 = $f58085809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58085809,
"from":L[27]});
}
} catch($e58005801) {
if(R.isCont($e58005801)) {
var $ss58045805 = {"from":L[27],
"go":function(anf_arg15845810) {
return $Hanf_arg26495811(anf_arg15845810,_plus14);
}};
$e58005801.stack[R.EXN_STACKHEIGHT++] = $ss58045805;
}
if(R.isPyretException($e58005801)) {
$e58005801.pyretStack.push(L[27]);
}
throw $e58005801;
}
var $ret58065807 = $Hanf_arg26495811($z58025803,_plus14);
++R.GAS;
return $ret58065807;
};
var $Hanf_arg26495811 = function(anf_arg15845810,_plus14) {
var $z58145815 = D;
var $f58205821 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg15845810):R.ffi.throwNonFunApp(L[27],_plus14,[("("),anf_arg15845810]);
};
try {
if(--R.GAS > 0) {
$z58145815 = $f58205821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58205821,
"from":L[27]});
}
} catch($e58125813) {
if(R.isCont($e58125813)) {
var $ss58165817 = {"from":L[27],
"go":function(anf_arg15855822) {
return $Hanf_arg26485823(anf_arg15855822,_plus14);
}};
$e58125813.stack[R.EXN_STACKHEIGHT++] = $ss58165817;
}
if(R.isPyretException($e58125813)) {
$e58125813.pyretStack.push(L[27]);
}
throw $e58125813;
}
var $ret58185819 = $Hanf_arg26485823($z58145815,_plus14);
++R.GAS;
return $ret58185819;
};
var $Hanf_arg26485823 = function(anf_arg15855822,_plus14) {
var $z58265827 = D;
var $f58325833 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-str"),anf_arg15855822):R.ffi.throwNonFunApp(L[27],_plus14,[("j-str"),anf_arg15855822]);
};
try {
if(--R.GAS > 0) {
$z58265827 = $f58325833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58325833,
"from":L[27]});
}
} catch($e58245825) {
if(R.isCont($e58245825)) {
var $ss58285829 = {"from":L[27],
"go":function(ann_DASH_check_DASH_temp15815834) {
return $Hann_DASH_check_DASH_temp26475835(ann_DASH_check_DASH_temp15815834);
}};
$e58245825.stack[R.EXN_STACKHEIGHT++] = $ss58285829;
}
if(R.isPyretException($e58245825)) {
$e58245825.pyretStack.push(L[27]);
}
throw $e58245825;
}
var $ret58305831 = $Hann_DASH_check_DASH_temp26475835($z58265827);
++R.GAS;
return $ret58305831;
};
var $Hann_DASH_check_DASH_temp26475835 = function(ann_DASH_check_DASH_temp15815834) {
return ann_DASH_check_DASH_temp15815834;
};
var $Hcont_tail_arg26451266 = function(cont_tail_arg15781264,if_helper15701265) {
if(--R.GAS > 0) {
$z58365837 = R.isFunction(if_helper15701265)?if_helper15701265.app(cont_tail_arg15781264):R.ffi.throwNonFunApp(L[27],if_helper15701265,[cont_tail_arg15781264]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15701265)?if_helper15701265.app(cont_tail_arg15781264):R.ffi.throwNonFunApp(L[27],if_helper15701265,[cont_tail_arg15781264]);
},
"from":L[27]});
}
++R.GAS;
return $z58365837;
};
var $Hcont_tail_arg26461281 = function(cont_tail_arg15751280,if_helper15701265) {
if(--R.GAS > 0) {
$z58385839 = R.isFunction(if_helper15701265)?if_helper15701265.app(cont_tail_arg15751280):R.ffi.throwNonFunApp(L[27],if_helper15701265,[cont_tail_arg15751280]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15701265)?if_helper15701265.app(cont_tail_arg15751280):R.ffi.throwNonFunApp(L[27],if_helper15701265,[cont_tail_arg15751280]);
},
"from":L[27]});
}
++R.GAS;
return $z58385839;
};
var $Hann_DASH_check_DASH_temp26441302 = function(ann_DASH_check_DASH_temp15651301) {
return ann_DASH_check_DASH_temp15651301;
};
var $Hann_DASH_check_DASH_temp26431317 = function(ann_DASH_check_DASH_temp15621316) {
return ann_DASH_check_DASH_temp15621316;
};
var $Hanf_arg26421331 = function(anf_arg15581330,_plus14) {
var $z58425843 = D;
var $f58485849 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg15581330,(")")):R.ffi.throwNonFunApp(L[28],_plus14,[anf_arg15581330,(")")]);
};
try {
if(--R.GAS > 0) {
$z58425843 = $f58485849();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58485849,
"from":L[28]});
}
} catch($e58405841) {
if(R.isCont($e58405841)) {
var $ss58445845 = {"from":L[28],
"go":function(anf_arg15595850) {
return $Hanf_arg26415851(anf_arg15595850,_plus14);
}};
$e58405841.stack[R.EXN_STACKHEIGHT++] = $ss58445845;
}
if(R.isPyretException($e58405841)) {
$e58405841.pyretStack.push(L[28]);
}
throw $e58405841;
}
var $ret58465847 = $Hanf_arg26415851($z58425843,_plus14);
++R.GAS;
return $ret58465847;
};
var $Hanf_arg26415851 = function(anf_arg15595850,_plus14) {
var $z58545855 = D;
var $f58605861 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg15595850):R.ffi.throwNonFunApp(L[28],_plus14,[("("),anf_arg15595850]);
};
try {
if(--R.GAS > 0) {
$z58545855 = $f58605861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58605861,
"from":L[28]});
}
} catch($e58525853) {
if(R.isCont($e58525853)) {
var $ss58565857 = {"from":L[28],
"go":function(anf_arg15605862) {
return $Hanf_arg26405863(anf_arg15605862,_plus14);
}};
$e58525853.stack[R.EXN_STACKHEIGHT++] = $ss58565857;
}
if(R.isPyretException($e58525853)) {
$e58525853.pyretStack.push(L[28]);
}
throw $e58525853;
}
var $ret58585859 = $Hanf_arg26405863($z58545855,_plus14);
++R.GAS;
return $ret58585859;
};
var $Hanf_arg26405863 = function(anf_arg15605862,_plus14) {
var $z58665867 = D;
var $f58725873 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-id"),anf_arg15605862):R.ffi.throwNonFunApp(L[28],_plus14,[("j-id"),anf_arg15605862]);
};
try {
if(--R.GAS > 0) {
$z58665867 = $f58725873();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58725873,
"from":L[28]});
}
} catch($e58645865) {
if(R.isCont($e58645865)) {
var $ss58685869 = {"from":L[28],
"go":function(ann_DASH_check_DASH_temp15565874) {
return $Hann_DASH_check_DASH_temp26395875(ann_DASH_check_DASH_temp15565874);
}};
$e58645865.stack[R.EXN_STACKHEIGHT++] = $ss58685869;
}
if(R.isPyretException($e58645865)) {
$e58645865.pyretStack.push(L[28]);
}
throw $e58645865;
}
var $ret58705871 = $Hann_DASH_check_DASH_temp26395875($z58665867);
++R.GAS;
return $ret58705871;
};
var $Hann_DASH_check_DASH_temp26395875 = function(ann_DASH_check_DASH_temp15565874) {
return ann_DASH_check_DASH_temp15565874;
};
var $Hcont_tail_arg26371347 = function(cont_tail_arg15531345,if_helper15451346) {
if(--R.GAS > 0) {
$z58765877 = R.isFunction(if_helper15451346)?if_helper15451346.app(cont_tail_arg15531345):R.ffi.throwNonFunApp(L[28],if_helper15451346,[cont_tail_arg15531345]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15451346)?if_helper15451346.app(cont_tail_arg15531345):R.ffi.throwNonFunApp(L[28],if_helper15451346,[cont_tail_arg15531345]);
},
"from":L[28]});
}
++R.GAS;
return $z58765877;
};
var $Hcont_tail_arg26381362 = function(cont_tail_arg15501361,if_helper15451346) {
if(--R.GAS > 0) {
$z58785879 = R.isFunction(if_helper15451346)?if_helper15451346.app(cont_tail_arg15501361):R.ffi.throwNonFunApp(L[28],if_helper15451346,[cont_tail_arg15501361]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15451346)?if_helper15451346.app(cont_tail_arg15501361):R.ffi.throwNonFunApp(L[28],if_helper15451346,[cont_tail_arg15501361]);
},
"from":L[28]});
}
++R.GAS;
return $z58785879;
};
var $Hanf_arg26361385 = function(anf_arg15331382,INDENT7747,PP123,anf_fun15301383,self3501384) {
var anf_arg15345893 = G(PP123,"lbrace",L[587]);
var anf_arg15355894 = G(PP123,"commabreak",L[586]);
var anf_arg15365895 = G(PP123,"rbrace",L[585]);
var anf_bracket15375911 = G(self3501384,"fields",L[584]);
var anf_fun15385890 = G(anf_bracket15375911,"map",L[583]);
var anf_arg15415891 = R.makeFunction(function(f3515897) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[581],1,arguments);
}
var anf_fun15405908 = G(f3515897,"tosource",L[582]);
var $z59005901 = D;
var $f59065907 = function(_) {
return R.isFunction(anf_fun15405908)?anf_fun15405908.app():R.ffi.throwNonFunApp(L[581],anf_fun15405908,[]);
};
try {
if(--R.GAS > 0) {
$z59005901 = $f59065907();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59065907,
"from":L[581]});
}
} catch($e58985899) {
if(R.isCont($e58985899)) {
var $ss59025903 = {"from":L[581],
"go":function(ann_DASH_check_DASH_temp15395909) {
return $Hann_DASH_check_DASH_temp26335910(ann_DASH_check_DASH_temp15395909);
}};
$e58985899.stack[R.EXN_STACKHEIGHT++] = $ss59025903;
}
if(R.isPyretException($e58985899)) {
$e58985899.pyretStack.push(L[581]);
}
throw $e58985899;
}
var $ret59045905 = $Hann_DASH_check_DASH_temp26335910($z59005901);
++R.GAS;
return $ret59045905;
});
var $z58825883 = D;
var $f58885889 = function(_) {
return R.isFunction(anf_fun15385890)?anf_fun15385890.app(anf_arg15415891):R.ffi.throwNonFunApp(L[580],anf_fun15385890,[anf_arg15415891]);
};
try {
if(--R.GAS > 0) {
$z58825883 = $f58885889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58885889,
"from":L[580]});
}
} catch($e58805881) {
if(R.isCont($e58805881)) {
var $ss58845885 = {"from":L[580],
"go":function(anf_arg15425892) {
return $Hanf_arg26355896(anf_arg15425892,INDENT7747,anf_arg15331382,anf_arg15345893,anf_arg15355894,anf_arg15365895,anf_fun15301383);
}};
$e58805881.stack[R.EXN_STACKHEIGHT++] = $ss58845885;
}
if(R.isPyretException($e58805881)) {
$e58805881.pyretStack.push(L[580]);
}
throw $e58805881;
}
var $ret58865887 = $Hanf_arg26355896($z58825883,INDENT7747,anf_arg15331382,anf_arg15345893,anf_arg15355894,anf_arg15365895,anf_fun15301383);
++R.GAS;
return $ret58865887;
};
var $Hanf_arg26355896 = function(anf_arg15425892,INDENT7747,anf_arg15331382,anf_arg15345893,anf_arg15355894,anf_arg15365895,anf_fun15301383) {
var $z59145915 = D;
var $f59205921 = function(_) {
return R.isFunction(anf_fun15301383)?anf_fun15301383.app(INDENT7747,(1),anf_arg15331382,anf_arg15345893,anf_arg15355894,anf_arg15365895,anf_arg15425892):R.ffi.throwNonFunApp(L[152],anf_fun15301383,[INDENT7747,(1),anf_arg15331382,anf_arg15345893,anf_arg15355894,anf_arg15365895,anf_arg15425892]);
};
try {
if(--R.GAS > 0) {
$z59145915 = $f59205921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59205921,
"from":L[152]});
}
} catch($e59125913) {
if(R.isCont($e59125913)) {
var $ss59165917 = {"from":L[152],
"go":function(ann_DASH_check_DASH_temp15295922) {
return $Hann_DASH_check_DASH_temp26345923(ann_DASH_check_DASH_temp15295922);
}};
$e59125913.stack[R.EXN_STACKHEIGHT++] = $ss59165917;
}
if(R.isPyretException($e59125913)) {
$e59125913.pyretStack.push(L[152]);
}
throw $e59125913;
}
var $ret59185919 = $Hann_DASH_check_DASH_temp26345923($z59145915);
++R.GAS;
return $ret59185919;
};
var $Hann_DASH_check_DASH_temp26345923 = function(ann_DASH_check_DASH_temp15295922) {
return ann_DASH_check_DASH_temp15295922;
};
var $Hann_DASH_check_DASH_temp26335910 = function(ann_DASH_check_DASH_temp15395909) {
return ann_DASH_check_DASH_temp15395909;
};
var $Hanf_begin_app_dropped26321399 = function(anf_begin_app_dropped26201397,each4361,is_DASH_link2563,printer3481396,self3471398,nothing16) {
var anf_arg15125934 = G(self3471398,"fields",L[589]);
var $z59265927 = D;
var $f59325933 = function(_) {
return R.isFunction(is_DASH_link2563)?is_DASH_link2563.app(anf_arg15125934):R.ffi.throwNonFunApp(L[588],is_DASH_link2563,[anf_arg15125934]);
};
try {
if(--R.GAS > 0) {
$z59265927 = $f59325933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59325933,
"from":L[588]});
}
} catch($e59245925) {
if(R.isCont($e59245925)) {
var $ss59285929 = {"from":L[588],
"go":function(when_DASH_2525935) {
return $Hwhen_DASH_26315936(when_DASH_2525935,each4361,printer3481396,self3471398,nothing16);
}};
$e59245925.stack[R.EXN_STACKHEIGHT++] = $ss59285929;
}
if(R.isPyretException($e59245925)) {
$e59245925.pyretStack.push(L[588]);
}
throw $e59245925;
}
var $ret59305931 = $Hwhen_DASH_26315936($z59265927,each4361,printer3481396,self3471398,nothing16);
++R.GAS;
return $ret59305931;
};
var $Hwhen_DASH_26315936 = function(when_DASH_2525935,each4361,printer3481396,self3471398,nothing16) {
var if_helper15135949 = R.makeFunction(function(if_helper_arg15145969) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[588],1,arguments);
}
if_helper_arg15145969;
var $z59725973 = D;
var $f59785979 = function(_) {
return R.isFunction(printer3481396)?printer3481396.app(("}")):R.ffi.throwNonFunApp(L[154],printer3481396,[("}")]);
};
try {
if(--R.GAS > 0) {
$z59725973 = $f59785979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59785979,
"from":L[154]});
}
} catch($e59705971) {
if(R.isCont($e59705971)) {
var $ss59745975 = {"from":L[154],
"go":function(ann_DASH_check_DASH_temp15115980) {
return $Hann_DASH_check_DASH_temp26215981(ann_DASH_check_DASH_temp15115980);
}};
$e59705971.stack[R.EXN_STACKHEIGHT++] = $ss59745975;
}
if(R.isPyretException($e59705971)) {
$e59705971.pyretStack.push(L[154]);
}
throw $e59705971;
}
var $ret59765977 = $Hann_DASH_check_DASH_temp26215981($z59725973);
++R.GAS;
return $ret59765977;
});
var anf_if15175968 = R.isBoolean(when_DASH_2525935);
if(R.isPyretTrue(anf_if15175968)) {
if(R.isPyretTrue(when_DASH_2525935)) {
var anf_bracket15195952 = G(self3471398,"fields",L[593]);
var anf_bracket15205951 = G(anf_bracket15195952,"first",L[592]);
var anf_fun15215947 = G(anf_bracket15205951,"print-ugly-source",L[591]);
var $z59395940 = D;
var $f59455946 = function(_) {
return R.isFunction(anf_fun15215947)?anf_fun15215947.app(printer3481396):R.ffi.throwNonFunApp(L[590],anf_fun15215947,[printer3481396]);
};
try {
if(--R.GAS > 0) {
$z59395940 = $f59455946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59455946,
"from":L[590]});
}
} catch($e59375938) {
if(R.isCont($e59375938)) {
var $ss59415942 = {"from":L[590],
"go":function(anf_begin_app_dropped26225948) {
return $Hanf_begin_app_dropped26295950(anf_begin_app_dropped26225948,each4361,if_helper15135949,printer3481396,self3471398,nothing16);
}};
$e59375938.stack[R.EXN_STACKHEIGHT++] = $ss59415942;
}
if(R.isPyretException($e59375938)) {
$e59375938.pyretStack.push(L[590]);
}
throw $e59375938;
}
var $ret59435944 = $Hanf_begin_app_dropped26295950($z59395940,each4361,if_helper15135949,printer3481396,self3471398,nothing16);
++R.GAS;
return $ret59435944;
} else {
var $z59555956 = D;
var $f59615962 = function(_) {
return R.isFunction(if_helper15135949)?if_helper15135949.app(nothing16):R.ffi.throwNonFunApp(L[588],if_helper15135949,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z59555956 = $f59615962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59615962,
"from":L[588]});
}
} catch($e59535954) {
if(R.isCont($e59535954)) {
var $ss59575958 = {"from":L[588],
"go":function(cont_tail_app15185963) {
return $Hcont_tail_app26305964(cont_tail_app15185963);
}};
$e59535954.stack[R.EXN_STACKHEIGHT++] = $ss59575958;
}
if(R.isPyretException($e59535954)) {
$e59535954.pyretStack.push(L[588]);
}
throw $e59535954;
}
var $ret59595960 = $Hcont_tail_app26305964($z59555956);
++R.GAS;
return $ret59595960;
}
} else {
var cont_tail_arg15155967 = R.throwNonBooleanCondition(L[594],("when"),when_DASH_2525935);
if(--R.GAS > 0) {
$z59655966 = R.isFunction(if_helper15135949)?if_helper15135949.app(cont_tail_arg15155967):R.ffi.throwNonFunApp(L[594],if_helper15135949,[cont_tail_arg15155967]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper15135949)?if_helper15135949.app(cont_tail_arg15155967):R.ffi.throwNonFunApp(L[594],if_helper15135949,[cont_tail_arg15155967]);
},
"from":L[594]});
}
++R.GAS;
return $z59655966;
}
};
var $Hanf_begin_app_dropped26295950 = function(anf_begin_app_dropped26225948,each4361,if_helper15135949,printer3481396,self3471398,nothing16) {
var anf_arg15245992 = R.makeFunction(function(f3495997) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[598],1,arguments);
}
var $z60006001 = D;
var $f60066007 = function(_) {
return R.isFunction(printer3481396)?printer3481396.app((",\n")):R.ffi.throwNonFunApp(L[599],printer3481396,[(",\n")]);
};
try {
if(--R.GAS > 0) {
$z60006001 = $f60066007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60066007,
"from":L[599]});
}
} catch($e59985999) {
if(R.isCont($e59985999)) {
var $ss60026003 = {"from":L[599],
"go":function(anf_begin_app_dropped26236008) {
return $Hanf_begin_app_dropped26256009(anf_begin_app_dropped26236008,f3495997,printer3481396);
}};
$e59985999.stack[R.EXN_STACKHEIGHT++] = $ss60026003;
}
if(R.isPyretException($e59985999)) {
$e59985999.pyretStack.push(L[599]);
}
throw $e59985999;
}
var $ret60046005 = $Hanf_begin_app_dropped26256009($z60006001,f3495997,printer3481396);
++R.GAS;
return $ret60046005;
});
var anf_bracket15255996 = G(self3471398,"fields",L[597]);
var anf_arg15265993 = G(anf_bracket15255996,"rest",L[596]);
var $z59845985 = D;
var $f59905991 = function(_) {
return R.isFunction(each4361)?each4361.app(anf_arg15245992,anf_arg15265993):R.ffi.throwNonFunApp(L[595],each4361,[anf_arg15245992,anf_arg15265993]);
};
try {
if(--R.GAS > 0) {
$z59845985 = $f59905991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59905991,
"from":L[595]});
}
} catch($e59825983) {
if(R.isCont($e59825983)) {
var $ss59865987 = {"from":L[595],
"go":function(anf_begin_app_dropped26265994) {
return $Hanf_begin_app_dropped26285995(anf_begin_app_dropped26265994,if_helper15135949,nothing16);
}};
$e59825983.stack[R.EXN_STACKHEIGHT++] = $ss59865987;
}
if(R.isPyretException($e59825983)) {
$e59825983.pyretStack.push(L[595]);
}
throw $e59825983;
}
var $ret59885989 = $Hanf_begin_app_dropped26285995($z59845985,if_helper15135949,nothing16);
++R.GAS;
return $ret59885989;
};
var $Hanf_begin_app_dropped26285995 = function(anf_begin_app_dropped26265994,if_helper15135949,nothing16) {
var $z60126013 = D;
var $f60186019 = function(_) {
return R.isFunction(if_helper15135949)?if_helper15135949.app(nothing16):R.ffi.throwNonFunApp(L[588],if_helper15135949,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z60126013 = $f60186019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60186019,
"from":L[588]});
}
} catch($e60106011) {
if(R.isCont($e60106011)) {
var $ss60146015 = {"from":L[588],
"go":function(cont_tail_app15276020) {
return $Hcont_tail_app26276021(cont_tail_app15276020);
}};
$e60106011.stack[R.EXN_STACKHEIGHT++] = $ss60146015;
}
if(R.isPyretException($e60106011)) {
$e60106011.pyretStack.push(L[588]);
}
throw $e60106011;
}
var $ret60166017 = $Hcont_tail_app26276021($z60126013);
++R.GAS;
return $ret60166017;
};
var $Hcont_tail_app26276021 = function(cont_tail_app15276020) {
return cont_tail_app15276020;
};
var $Hanf_begin_app_dropped26256009 = function(anf_begin_app_dropped26236008,f3495997,printer3481396) {
var anf_fun15236032 = G(f3495997,"print-ugly-source",L[600]);
var $z60246025 = D;
var $f60306031 = function(_) {
return R.isFunction(anf_fun15236032)?anf_fun15236032.app(printer3481396):R.ffi.throwNonFunApp(L[598],anf_fun15236032,[printer3481396]);
};
try {
if(--R.GAS > 0) {
$z60246025 = $f60306031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60306031,
"from":L[598]});
}
} catch($e60226023) {
if(R.isCont($e60226023)) {
var $ss60266027 = {"from":L[598],
"go":function(ann_DASH_check_DASH_temp15226033) {
return $Hann_DASH_check_DASH_temp26246034(ann_DASH_check_DASH_temp15226033);
}};
$e60226023.stack[R.EXN_STACKHEIGHT++] = $ss60266027;
}
if(R.isPyretException($e60226023)) {
$e60226023.pyretStack.push(L[598]);
}
throw $e60226023;
}
var $ret60286029 = $Hann_DASH_check_DASH_temp26246034($z60246025);
++R.GAS;
return $ret60286029;
};
var $Hann_DASH_check_DASH_temp26246034 = function(ann_DASH_check_DASH_temp15226033) {
return ann_DASH_check_DASH_temp15226033;
};
var $Hcont_tail_app26305964 = function(cont_tail_app15185963) {
return cont_tail_app15185963;
};
var $Hann_DASH_check_DASH_temp26215981 = function(ann_DASH_check_DASH_temp15115980) {
return ann_DASH_check_DASH_temp15115980;
};
var $Hanf_arg26191412 = function(anf_arg15071411,_plus14) {
var $z60376038 = D;
var $f60436044 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg15071411,(")")):R.ffi.throwNonFunApp(L[29],_plus14,[anf_arg15071411,(")")]);
};
try {
if(--R.GAS > 0) {
$z60376038 = $f60436044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60436044,
"from":L[29]});
}
} catch($e60356036) {
if(R.isCont($e60356036)) {
var $ss60396040 = {"from":L[29],
"go":function(anf_arg15086045) {
return $Hanf_arg26186046(anf_arg15086045,_plus14);
}};
$e60356036.stack[R.EXN_STACKHEIGHT++] = $ss60396040;
}
if(R.isPyretException($e60356036)) {
$e60356036.pyretStack.push(L[29]);
}
throw $e60356036;
}
var $ret60416042 = $Hanf_arg26186046($z60376038,_plus14);
++R.GAS;
return $ret60416042;
};
var $Hanf_arg26186046 = function(anf_arg15086045,_plus14) {
var $z60496050 = D;
var $f60556056 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg15086045):R.ffi.throwNonFunApp(L[29],_plus14,[("("),anf_arg15086045]);
};
try {
if(--R.GAS > 0) {
$z60496050 = $f60556056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60556056,
"from":L[29]});
}
} catch($e60476048) {
if(R.isCont($e60476048)) {
var $ss60516052 = {"from":L[29],
"go":function(anf_arg15096057) {
return $Hanf_arg26176058(anf_arg15096057,_plus14);
}};
$e60476048.stack[R.EXN_STACKHEIGHT++] = $ss60516052;
}
if(R.isPyretException($e60476048)) {
$e60476048.pyretStack.push(L[29]);
}
throw $e60476048;
}
var $ret60536054 = $Hanf_arg26176058($z60496050,_plus14);
++R.GAS;
return $ret60536054;
};
var $Hanf_arg26176058 = function(anf_arg15096057,_plus14) {
var $z60616062 = D;
var $f60676068 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-obj"),anf_arg15096057):R.ffi.throwNonFunApp(L[29],_plus14,[("j-obj"),anf_arg15096057]);
};
try {
if(--R.GAS > 0) {
$z60616062 = $f60676068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60676068,
"from":L[29]});
}
} catch($e60596060) {
if(R.isCont($e60596060)) {
var $ss60636064 = {"from":L[29],
"go":function(ann_DASH_check_DASH_temp15056069) {
return $Hann_DASH_check_DASH_temp26166070(ann_DASH_check_DASH_temp15056069);
}};
$e60596060.stack[R.EXN_STACKHEIGHT++] = $ss60636064;
}
if(R.isPyretException($e60596060)) {
$e60596060.pyretStack.push(L[29]);
}
throw $e60596060;
}
var $ret60656066 = $Hann_DASH_check_DASH_temp26166070($z60616062);
++R.GAS;
return $ret60656066;
};
var $Hann_DASH_check_DASH_temp26166070 = function(ann_DASH_check_DASH_temp15056069) {
return ann_DASH_check_DASH_temp15056069;
};
var $Hcont_tail_arg26141428 = function(cont_tail_arg15021426,if_helper14941427) {
if(--R.GAS > 0) {
$z60716072 = R.isFunction(if_helper14941427)?if_helper14941427.app(cont_tail_arg15021426):R.ffi.throwNonFunApp(L[29],if_helper14941427,[cont_tail_arg15021426]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper14941427)?if_helper14941427.app(cont_tail_arg15021426):R.ffi.throwNonFunApp(L[29],if_helper14941427,[cont_tail_arg15021426]);
},
"from":L[29]});
}
++R.GAS;
return $z60716072;
};
var $Hcont_tail_arg26151443 = function(cont_tail_arg14991442,if_helper14941427) {
if(--R.GAS > 0) {
$z60736074 = R.isFunction(if_helper14941427)?if_helper14941427.app(cont_tail_arg14991442):R.ffi.throwNonFunApp(L[29],if_helper14941427,[cont_tail_arg14991442]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper14941427)?if_helper14941427.app(cont_tail_arg14991442):R.ffi.throwNonFunApp(L[29],if_helper14941427,[cont_tail_arg14991442]);
},
"from":L[29]});
}
++R.GAS;
return $z60736074;
};
var $Hanf_arg26131466 = function(anf_arg14821463,INDENT7747,PP123,anf_fun14791464,self3451465) {
var anf_arg14836088 = G(PP123,"lbrack",L[607]);
var anf_arg14846089 = G(PP123,"commabreak",L[606]);
var anf_arg14856090 = G(PP123,"rbrack",L[605]);
var anf_bracket14866106 = G(self3451465,"elts",L[604]);
var anf_fun14876085 = G(anf_bracket14866106,"map",L[603]);
var anf_arg14906086 = R.makeFunction(function(recv_DASH_2456092) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[602],1,arguments);
}
var anf_fun14896103 = G(recv_DASH_2456092,"tosource",L[602]);
var $z60956096 = D;
var $f61016102 = function(_) {
return R.isFunction(anf_fun14896103)?anf_fun14896103.app():R.ffi.throwNonFunApp(L[602],anf_fun14896103,[]);
};
try {
if(--R.GAS > 0) {
$z60956096 = $f61016102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61016102,
"from":L[602]});
}
} catch($e60936094) {
if(R.isCont($e60936094)) {
var $ss60976098 = {"from":L[602],
"go":function(ann_DASH_check_DASH_temp14886104) {
return $Hann_DASH_check_DASH_temp26106105(ann_DASH_check_DASH_temp14886104);
}};
$e60936094.stack[R.EXN_STACKHEIGHT++] = $ss60976098;
}
if(R.isPyretException($e60936094)) {
$e60936094.pyretStack.push(L[602]);
}
throw $e60936094;
}
var $ret60996100 = $Hann_DASH_check_DASH_temp26106105($z60956096);
++R.GAS;
return $ret60996100;
});
var $z60776078 = D;
var $f60836084 = function(_) {
return R.isFunction(anf_fun14876085)?anf_fun14876085.app(anf_arg14906086):R.ffi.throwNonFunApp(L[601],anf_fun14876085,[anf_arg14906086]);
};
try {
if(--R.GAS > 0) {
$z60776078 = $f60836084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60836084,
"from":L[601]});
}
} catch($e60756076) {
if(R.isCont($e60756076)) {
var $ss60796080 = {"from":L[601],
"go":function(anf_arg14916087) {
return $Hanf_arg26126091(anf_arg14916087,INDENT7747,anf_arg14821463,anf_arg14836088,anf_arg14846089,anf_arg14856090,anf_fun14791464);
}};
$e60756076.stack[R.EXN_STACKHEIGHT++] = $ss60796080;
}
if(R.isPyretException($e60756076)) {
$e60756076.pyretStack.push(L[601]);
}
throw $e60756076;
}
var $ret60816082 = $Hanf_arg26126091($z60776078,INDENT7747,anf_arg14821463,anf_arg14836088,anf_arg14846089,anf_arg14856090,anf_fun14791464);
++R.GAS;
return $ret60816082;
};
var $Hanf_arg26126091 = function(anf_arg14916087,INDENT7747,anf_arg14821463,anf_arg14836088,anf_arg14846089,anf_arg14856090,anf_fun14791464) {
var $z61096110 = D;
var $f61156116 = function(_) {
return R.isFunction(anf_fun14791464)?anf_fun14791464.app(INDENT7747,(1),anf_arg14821463,anf_arg14836088,anf_arg14846089,anf_arg14856090,anf_arg14916087):R.ffi.throwNonFunApp(L[160],anf_fun14791464,[INDENT7747,(1),anf_arg14821463,anf_arg14836088,anf_arg14846089,anf_arg14856090,anf_arg14916087]);
};
try {
if(--R.GAS > 0) {
$z61096110 = $f61156116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61156116,
"from":L[160]});
}
} catch($e61076108) {
if(R.isCont($e61076108)) {
var $ss61116112 = {"from":L[160],
"go":function(ann_DASH_check_DASH_temp14786117) {
return $Hann_DASH_check_DASH_temp26116118(ann_DASH_check_DASH_temp14786117);
}};
$e61076108.stack[R.EXN_STACKHEIGHT++] = $ss61116112;
}
if(R.isPyretException($e61076108)) {
$e61076108.pyretStack.push(L[160]);
}
throw $e61076108;
}
var $ret61136114 = $Hann_DASH_check_DASH_temp26116118($z61096110);
++R.GAS;
return $ret61136114;
};
var $Hann_DASH_check_DASH_temp26116118 = function(ann_DASH_check_DASH_temp14786117) {
return ann_DASH_check_DASH_temp14786117;
};
var $Hann_DASH_check_DASH_temp26106105 = function(ann_DASH_check_DASH_temp14886104) {
return ann_DASH_check_DASH_temp14886104;
};
var $Hanf_begin_app_dropped26091480 = function(anf_begin_app_dropped25931478,each4361,is_DASH_link2563,printer3431477,self3421479,nothing16) {
var anf_arg14546129 = G(self3421479,"elts",L[609]);
var $z61216122 = D;
var $f61276128 = function(_) {
return R.isFunction(is_DASH_link2563)?is_DASH_link2563.app(anf_arg14546129):R.ffi.throwNonFunApp(L[608],is_DASH_link2563,[anf_arg14546129]);
};
try {
if(--R.GAS > 0) {
$z61216122 = $f61276128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61276128,
"from":L[608]});
}
} catch($e61196120) {
if(R.isCont($e61196120)) {
var $ss61236124 = {"from":L[608],
"go":function(when_DASH_2436130) {
return $Hwhen_DASH_26086131(when_DASH_2436130,each4361,printer3431477,self3421479,nothing16);
}};
$e61196120.stack[R.EXN_STACKHEIGHT++] = $ss61236124;
}
if(R.isPyretException($e61196120)) {
$e61196120.pyretStack.push(L[608]);
}
throw $e61196120;
}
var $ret61256126 = $Hwhen_DASH_26086131($z61216122,each4361,printer3431477,self3421479,nothing16);
++R.GAS;
return $ret61256126;
};
var $Hwhen_DASH_26086131 = function(when_DASH_2436130,each4361,printer3431477,self3421479,nothing16) {
var if_helper14556144 = R.makeFunction(function(if_helper_arg14566164) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[608],1,arguments);
}
if_helper_arg14566164;
var $z61676168 = D;
var $f61736174 = function(_) {
return R.isFunction(printer3431477)?printer3431477.app(("]")):R.ffi.throwNonFunApp(L[162],printer3431477,[("]")]);
};
try {
if(--R.GAS > 0) {
$z61676168 = $f61736174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61736174,
"from":L[162]});
}
} catch($e61656166) {
if(R.isCont($e61656166)) {
var $ss61696170 = {"from":L[162],
"go":function(ann_DASH_check_DASH_temp14536175) {
return $Hann_DASH_check_DASH_temp25946176(ann_DASH_check_DASH_temp14536175);
}};
$e61656166.stack[R.EXN_STACKHEIGHT++] = $ss61696170;
}
if(R.isPyretException($e61656166)) {
$e61656166.pyretStack.push(L[162]);
}
throw $e61656166;
}
var $ret61716172 = $Hann_DASH_check_DASH_temp25946176($z61676168);
++R.GAS;
return $ret61716172;
});
var anf_if14596163 = R.isBoolean(when_DASH_2436130);
if(R.isPyretTrue(anf_if14596163)) {
if(R.isPyretTrue(when_DASH_2436130)) {
var anf_bracket14616147 = G(self3421479,"elts",L[613]);
var anf_bracket14626146 = G(anf_bracket14616147,"first",L[612]);
var anf_fun14636142 = G(anf_bracket14626146,"print-ugly-source",L[611]);
var $z61346135 = D;
var $f61406141 = function(_) {
return R.isFunction(anf_fun14636142)?anf_fun14636142.app(printer3431477):R.ffi.throwNonFunApp(L[610],anf_fun14636142,[printer3431477]);
};
try {
if(--R.GAS > 0) {
$z61346135 = $f61406141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61406141,
"from":L[610]});
}
} catch($e61326133) {
if(R.isCont($e61326133)) {
var $ss61366137 = {"from":L[610],
"go":function(anf_begin_app_dropped25956143) {
return $Hanf_begin_app_dropped26066145(anf_begin_app_dropped25956143,each4361,if_helper14556144,printer3431477,self3421479,nothing16);
}};
$e61326133.stack[R.EXN_STACKHEIGHT++] = $ss61366137;
}
if(R.isPyretException($e61326133)) {
$e61326133.pyretStack.push(L[610]);
}
throw $e61326133;
}
var $ret61386139 = $Hanf_begin_app_dropped26066145($z61346135,each4361,if_helper14556144,printer3431477,self3421479,nothing16);
++R.GAS;
return $ret61386139;
} else {
var $z61506151 = D;
var $f61566157 = function(_) {
return R.isFunction(if_helper14556144)?if_helper14556144.app(nothing16):R.ffi.throwNonFunApp(L[608],if_helper14556144,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z61506151 = $f61566157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61566157,
"from":L[608]});
}
} catch($e61486149) {
if(R.isCont($e61486149)) {
var $ss61526153 = {"from":L[608],
"go":function(cont_tail_app14606158) {
return $Hcont_tail_app26076159(cont_tail_app14606158);
}};
$e61486149.stack[R.EXN_STACKHEIGHT++] = $ss61526153;
}
if(R.isPyretException($e61486149)) {
$e61486149.pyretStack.push(L[608]);
}
throw $e61486149;
}
var $ret61546155 = $Hcont_tail_app26076159($z61506151);
++R.GAS;
return $ret61546155;
}
} else {
var cont_tail_arg14576162 = R.throwNonBooleanCondition(L[614],("when"),when_DASH_2436130);
if(--R.GAS > 0) {
$z61606161 = R.isFunction(if_helper14556144)?if_helper14556144.app(cont_tail_arg14576162):R.ffi.throwNonFunApp(L[614],if_helper14556144,[cont_tail_arg14576162]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper14556144)?if_helper14556144.app(cont_tail_arg14576162):R.ffi.throwNonFunApp(L[614],if_helper14556144,[cont_tail_arg14576162]);
},
"from":L[614]});
}
++R.GAS;
return $z61606161;
}
};
var $Hanf_begin_app_dropped26066145 = function(anf_begin_app_dropped25956143,each4361,if_helper14556144,printer3431477,self3421479,nothing16) {
var anf_arg14736187 = R.makeFunction(function(f3446192) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[618],1,arguments);
}
var $z61956196 = D;
var $f62016202 = function(_) {
return R.isFunction(printer3431477)?printer3431477.app((",")):R.ffi.throwNonFunApp(L[619],printer3431477,[(",")]);
};
try {
if(--R.GAS > 0) {
$z61956196 = $f62016202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62016202,
"from":L[619]});
}
} catch($e61936194) {
if(R.isCont($e61936194)) {
var $ss61976198 = {"from":L[619],
"go":function(anf_begin_app_dropped25966203) {
return $Hanf_begin_app_dropped26026204(anf_begin_app_dropped25966203,f3446192,printer3431477,self3421479,nothing16);
}};
$e61936194.stack[R.EXN_STACKHEIGHT++] = $ss61976198;
}
if(R.isPyretException($e61936194)) {
$e61936194.pyretStack.push(L[619]);
}
throw $e61936194;
}
var $ret61996200 = $Hanf_begin_app_dropped26026204($z61956196,f3446192,printer3431477,self3421479,nothing16);
++R.GAS;
return $ret61996200;
});
var anf_bracket14746191 = G(self3421479,"elts",L[617]);
var anf_arg14756188 = G(anf_bracket14746191,"rest",L[616]);
var $z61796180 = D;
var $f61856186 = function(_) {
return R.isFunction(each4361)?each4361.app(anf_arg14736187,anf_arg14756188):R.ffi.throwNonFunApp(L[615],each4361,[anf_arg14736187,anf_arg14756188]);
};
try {
if(--R.GAS > 0) {
$z61796180 = $f61856186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61856186,
"from":L[615]});
}
} catch($e61776178) {
if(R.isCont($e61776178)) {
var $ss61816182 = {"from":L[615],
"go":function(anf_begin_app_dropped26036189) {
return $Hanf_begin_app_dropped26056190(anf_begin_app_dropped26036189,if_helper14556144,nothing16);
}};
$e61776178.stack[R.EXN_STACKHEIGHT++] = $ss61816182;
}
if(R.isPyretException($e61776178)) {
$e61776178.pyretStack.push(L[615]);
}
throw $e61776178;
}
var $ret61836184 = $Hanf_begin_app_dropped26056190($z61796180,if_helper14556144,nothing16);
++R.GAS;
return $ret61836184;
};
var $Hanf_begin_app_dropped26056190 = function(anf_begin_app_dropped26036189,if_helper14556144,nothing16) {
var $z62076208 = D;
var $f62136214 = function(_) {
return R.isFunction(if_helper14556144)?if_helper14556144.app(nothing16):R.ffi.throwNonFunApp(L[608],if_helper14556144,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z62076208 = $f62136214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62136214,
"from":L[608]});
}
} catch($e62056206) {
if(R.isCont($e62056206)) {
var $ss62096210 = {"from":L[608],
"go":function(cont_tail_app14766215) {
return $Hcont_tail_app26046216(cont_tail_app14766215);
}};
$e62056206.stack[R.EXN_STACKHEIGHT++] = $ss62096210;
}
if(R.isPyretException($e62056206)) {
$e62056206.pyretStack.push(L[608]);
}
throw $e62056206;
}
var $ret62116212 = $Hcont_tail_app26046216($z62076208);
++R.GAS;
return $ret62116212;
};
var $Hcont_tail_app26046216 = function(cont_tail_app14766215) {
return cont_tail_app14766215;
};
var $Hanf_begin_app_dropped26026204 = function(anf_begin_app_dropped25966203,f3446192,printer3431477,self3421479,nothing16) {
var when_DASH_2446242 = G(self3421479,"multi-line",L[622]);
var if_helper14656228 = R.makeFunction(function(if_helper_arg14666247) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[621],1,arguments);
}
if_helper_arg14666247;
var anf_fun14676258 = G(f3446192,"print-ugly-source",L[623]);
var $z62506251 = D;
var $f62566257 = function(_) {
return R.isFunction(anf_fun14676258)?anf_fun14676258.app(printer3431477):R.ffi.throwNonFunApp(L[618],anf_fun14676258,[printer3431477]);
};
try {
if(--R.GAS > 0) {
$z62506251 = $f62566257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62566257,
"from":L[618]});
}
} catch($e62486249) {
if(R.isCont($e62486249)) {
var $ss62526253 = {"from":L[618],
"go":function(ann_DASH_check_DASH_temp14646259) {
return $Hann_DASH_check_DASH_temp25976260(ann_DASH_check_DASH_temp14646259);
}};
$e62486249.stack[R.EXN_STACKHEIGHT++] = $ss62526253;
}
if(R.isPyretException($e62486249)) {
$e62486249.pyretStack.push(L[618]);
}
throw $e62486249;
}
var $ret62546255 = $Hann_DASH_check_DASH_temp25976260($z62506251);
++R.GAS;
return $ret62546255;
});
var anf_if14706246 = R.isBoolean(when_DASH_2446242);
if(R.isPyretTrue(anf_if14706246)) {
if(R.isPyretTrue(when_DASH_2446242)) {
var $z62196220 = D;
var $f62256226 = function(_) {
return R.isFunction(printer3431477)?printer3431477.app(("\n")):R.ffi.throwNonFunApp(L[620],printer3431477,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z62196220 = $f62256226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62256226,
"from":L[620]});
}
} catch($e62176218) {
if(R.isCont($e62176218)) {
var $ss62216222 = {"from":L[620],
"go":function(anf_begin_app_dropped25986227) {
return $Hanf_begin_app_dropped26006229(anf_begin_app_dropped25986227,if_helper14656228,nothing16);
}};
$e62176218.stack[R.EXN_STACKHEIGHT++] = $ss62216222;
}
if(R.isPyretException($e62176218)) {
$e62176218.pyretStack.push(L[620]);
}
throw $e62176218;
}
var $ret62236224 = $Hanf_begin_app_dropped26006229($z62196220,if_helper14656228,nothing16);
++R.GAS;
return $ret62236224;
} else {
var $z62326233 = D;
var $f62386239 = function(_) {
return R.isFunction(if_helper14656228)?if_helper14656228.app(nothing16):R.ffi.throwNonFunApp(L[621],if_helper14656228,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z62326233 = $f62386239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62386239,
"from":L[621]});
}
} catch($e62306231) {
if(R.isCont($e62306231)) {
var $ss62346235 = {"from":L[621],
"go":function(cont_tail_app14716240) {
return $Hcont_tail_app26016241(cont_tail_app14716240);
}};
$e62306231.stack[R.EXN_STACKHEIGHT++] = $ss62346235;
}
if(R.isPyretException($e62306231)) {
$e62306231.pyretStack.push(L[621]);
}
throw $e62306231;
}
var $ret62366237 = $Hcont_tail_app26016241($z62326233);
++R.GAS;
return $ret62366237;
}
} else {
var cont_tail_arg14686245 = R.throwNonBooleanCondition(L[622],("when"),when_DASH_2446242);
if(--R.GAS > 0) {
$z62436244 = R.isFunction(if_helper14656228)?if_helper14656228.app(cont_tail_arg14686245):R.ffi.throwNonFunApp(L[622],if_helper14656228,[cont_tail_arg14686245]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper14656228)?if_helper14656228.app(cont_tail_arg14686245):R.ffi.throwNonFunApp(L[622],if_helper14656228,[cont_tail_arg14686245]);
},
"from":L[622]});
}
++R.GAS;
return $z62436244;
}
};
var $Hanf_begin_app_dropped26006229 = function(anf_begin_app_dropped25986227,if_helper14656228,nothing16) {
var $z62636264 = D;
var $f62696270 = function(_) {
return R.isFunction(if_helper14656228)?if_helper14656228.app(nothing16):R.ffi.throwNonFunApp(L[621],if_helper14656228,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z62636264 = $f62696270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62696270,
"from":L[621]});
}
} catch($e62616262) {
if(R.isCont($e62616262)) {
var $ss62656266 = {"from":L[621],
"go":function(cont_tail_app14726271) {
return $Hcont_tail_app25996272(cont_tail_app14726271);
}};
$e62616262.stack[R.EXN_STACKHEIGHT++] = $ss62656266;
}
if(R.isPyretException($e62616262)) {
$e62616262.pyretStack.push(L[621]);
}
throw $e62616262;
}
var $ret62676268 = $Hcont_tail_app25996272($z62636264);
++R.GAS;
return $ret62676268;
};
var $Hcont_tail_app25996272 = function(cont_tail_app14726271) {
return cont_tail_app14726271;
};
var $Hcont_tail_app26016241 = function(cont_tail_app14716240) {
return cont_tail_app14716240;
};
var $Hann_DASH_check_DASH_temp25976260 = function(ann_DASH_check_DASH_temp14646259) {
return ann_DASH_check_DASH_temp14646259;
};
var $Hcont_tail_app26076159 = function(cont_tail_app14606158) {
return cont_tail_app14606158;
};
var $Hann_DASH_check_DASH_temp25946176 = function(ann_DASH_check_DASH_temp14536175) {
return ann_DASH_check_DASH_temp14536175;
};
var $Hanf_arg25921494 = function(anf_arg14451492,self2411493,_plus14,torepr18) {
var anf_arg14466283 = G(self2411493,"elts",L[30]);
var $z62756276 = D;
var $f62816282 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg14466283):R.ffi.throwNonFunApp(L[30],torepr18,[anf_arg14466283]);
};
try {
if(--R.GAS > 0) {
$z62756276 = $f62816282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62816282,
"from":L[30]});
}
} catch($e62736274) {
if(R.isCont($e62736274)) {
var $ss62776278 = {"from":L[30],
"go":function(anf_arg14476284) {
return $Hanf_arg25916285(anf_arg14476284,anf_arg14451492,_plus14);
}};
$e62736274.stack[R.EXN_STACKHEIGHT++] = $ss62776278;
}
if(R.isPyretException($e62736274)) {
$e62736274.pyretStack.push(L[30]);
}
throw $e62736274;
}
var $ret62796280 = $Hanf_arg25916285($z62756276,anf_arg14451492,_plus14);
++R.GAS;
return $ret62796280;
};
var $Hanf_arg25916285 = function(anf_arg14476284,anf_arg14451492,_plus14) {
var $z62886289 = D;
var $f62946295 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg14476284):R.ffi.throwNonFunApp(L[30],_plus14,[(", "),anf_arg14476284]);
};
try {
if(--R.GAS > 0) {
$z62886289 = $f62946295();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62946295,
"from":L[30]});
}
} catch($e62866287) {
if(R.isCont($e62866287)) {
var $ss62906291 = {"from":L[30],
"go":function(anf_arg14486296) {
return $Hanf_arg25906297(anf_arg14486296,anf_arg14451492,_plus14);
}};
$e62866287.stack[R.EXN_STACKHEIGHT++] = $ss62906291;
}
if(R.isPyretException($e62866287)) {
$e62866287.pyretStack.push(L[30]);
}
throw $e62866287;
}
var $ret62926293 = $Hanf_arg25906297($z62886289,anf_arg14451492,_plus14);
++R.GAS;
return $ret62926293;
};
var $Hanf_arg25906297 = function(anf_arg14486296,anf_arg14451492,_plus14) {
var $z63006301 = D;
var $f63066307 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg14451492,anf_arg14486296):R.ffi.throwNonFunApp(L[30],_plus14,[anf_arg14451492,anf_arg14486296]);
};
try {
if(--R.GAS > 0) {
$z63006301 = $f63066307();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63066307,
"from":L[30]});
}
} catch($e62986299) {
if(R.isCont($e62986299)) {
var $ss63026303 = {"from":L[30],
"go":function(anf_arg14496308) {
return $Hanf_arg25896309(anf_arg14496308,_plus14);
}};
$e62986299.stack[R.EXN_STACKHEIGHT++] = $ss63026303;
}
if(R.isPyretException($e62986299)) {
$e62986299.pyretStack.push(L[30]);
}
throw $e62986299;
}
var $ret63046305 = $Hanf_arg25896309($z63006301,_plus14);
++R.GAS;
return $ret63046305;
};
var $Hanf_arg25896309 = function(anf_arg14496308,_plus14) {
var $z63126313 = D;
var $f63186319 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg14496308,(")")):R.ffi.throwNonFunApp(L[30],_plus14,[anf_arg14496308,(")")]);
};
try {
if(--R.GAS > 0) {
$z63126313 = $f63186319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63186319,
"from":L[30]});
}
} catch($e63106311) {
if(R.isCont($e63106311)) {
var $ss63146315 = {"from":L[30],
"go":function(anf_arg14506320) {
return $Hanf_arg25886321(anf_arg14506320,_plus14);
}};
$e63106311.stack[R.EXN_STACKHEIGHT++] = $ss63146315;
}
if(R.isPyretException($e63106311)) {
$e63106311.pyretStack.push(L[30]);
}
throw $e63106311;
}
var $ret63166317 = $Hanf_arg25886321($z63126313,_plus14);
++R.GAS;
return $ret63166317;
};
var $Hanf_arg25886321 = function(anf_arg14506320,_plus14) {
var $z63246325 = D;
var $f63306331 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg14506320):R.ffi.throwNonFunApp(L[30],_plus14,[("("),anf_arg14506320]);
};
try {
if(--R.GAS > 0) {
$z63246325 = $f63306331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63306331,
"from":L[30]});
}
} catch($e63226323) {
if(R.isCont($e63226323)) {
var $ss63266327 = {"from":L[30],
"go":function(anf_arg14516332) {
return $Hanf_arg25876333(anf_arg14516332,_plus14);
}};
$e63226323.stack[R.EXN_STACKHEIGHT++] = $ss63266327;
}
if(R.isPyretException($e63226323)) {
$e63226323.pyretStack.push(L[30]);
}
throw $e63226323;
}
var $ret63286329 = $Hanf_arg25876333($z63246325,_plus14);
++R.GAS;
return $ret63286329;
};
var $Hanf_arg25876333 = function(anf_arg14516332,_plus14) {
var $z63366337 = D;
var $f63426343 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-list"),anf_arg14516332):R.ffi.throwNonFunApp(L[30],_plus14,[("j-list"),anf_arg14516332]);
};
try {
if(--R.GAS > 0) {
$z63366337 = $f63426343();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63426343,
"from":L[30]});
}
} catch($e63346335) {
if(R.isCont($e63346335)) {
var $ss63386339 = {"from":L[30],
"go":function(ann_DASH_check_DASH_temp14436344) {
return $Hann_DASH_check_DASH_temp25866345(ann_DASH_check_DASH_temp14436344);
}};
$e63346335.stack[R.EXN_STACKHEIGHT++] = $ss63386339;
}
if(R.isPyretException($e63346335)) {
$e63346335.pyretStack.push(L[30]);
}
throw $e63346335;
}
var $ret63406341 = $Hann_DASH_check_DASH_temp25866345($z63366337);
++R.GAS;
return $ret63406341;
};
var $Hann_DASH_check_DASH_temp25866345 = function(ann_DASH_check_DASH_temp14436344) {
return ann_DASH_check_DASH_temp14436344;
};
var $Hcont_tail_arg25841510 = function(cont_tail_arg14401508,if_helper14311509) {
if(--R.GAS > 0) {
$z63466347 = R.isFunction(if_helper14311509)?if_helper14311509.app(cont_tail_arg14401508):R.ffi.throwNonFunApp(L[30],if_helper14311509,[cont_tail_arg14401508]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper14311509)?if_helper14311509.app(cont_tail_arg14401508):R.ffi.throwNonFunApp(L[30],if_helper14311509,[cont_tail_arg14401508]);
},
"from":L[30]});
}
++R.GAS;
return $z63466347;
};
var $Hcont_tail_arg25851525 = function(cont_tail_arg14361524,if_helper14311509) {
if(--R.GAS > 0) {
$z63486349 = R.isFunction(if_helper14311509)?if_helper14311509.app(cont_tail_arg14361524):R.ffi.throwNonFunApp(L[30],if_helper14311509,[cont_tail_arg14361524]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper14311509)?if_helper14311509.app(cont_tail_arg14361524):R.ffi.throwNonFunApp(L[30],if_helper14311509,[cont_tail_arg14361524]);
},
"from":L[30]});
}
++R.GAS;
return $z63486349;
};
var $Hanf_arg25831547 = function(anf_arg14201544,INDENT7747,PP123,anf_fun14171545,self3391546,_plus14) {
var anf_fun14216363 = G(PP123,"surround",L[628]);
var anf_arg14226362 = G(PP123,"lbrack",L[627]);
var anf_bracket14236365 = G(self3391546,"field",L[626]);
var anf_fun14246360 = G(anf_bracket14236365,"tosource",L[625]);
var $z63526353 = D;
var $f63586359 = function(_) {
return R.isFunction(anf_fun14246360)?anf_fun14246360.app():R.ffi.throwNonFunApp(L[624],anf_fun14246360,[]);
};
try {
if(--R.GAS > 0) {
$z63526353 = $f63586359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63586359,
"from":L[624]});
}
} catch($e63506351) {
if(R.isCont($e63506351)) {
var $ss63546355 = {"from":L[624],
"go":function(anf_arg14256361) {
return $Hanf_arg25826364(anf_arg14256361,INDENT7747,PP123,anf_arg14201544,anf_arg14226362,anf_fun14171545,anf_fun14216363,_plus14);
}};
$e63506351.stack[R.EXN_STACKHEIGHT++] = $ss63546355;
}
if(R.isPyretException($e63506351)) {
$e63506351.pyretStack.push(L[624]);
}
throw $e63506351;
}
var $ret63566357 = $Hanf_arg25826364($z63526353,INDENT7747,PP123,anf_arg14201544,anf_arg14226362,anf_fun14171545,anf_fun14216363,_plus14);
++R.GAS;
return $ret63566357;
};
var $Hanf_arg25826364 = function(anf_arg14256361,INDENT7747,PP123,anf_arg14201544,anf_arg14226362,anf_fun14171545,anf_fun14216363,_plus14) {
var anf_arg14266376 = G(PP123,"rbrack",L[630]);
var $z63686369 = D;
var $f63746375 = function(_) {
return R.isFunction(anf_fun14216363)?anf_fun14216363.app(INDENT7747,(0),anf_arg14226362,anf_arg14256361,anf_arg14266376):R.ffi.throwNonFunApp(L[629],anf_fun14216363,[INDENT7747,(0),anf_arg14226362,anf_arg14256361,anf_arg14266376]);
};
try {
if(--R.GAS > 0) {
$z63686369 = $f63746375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63746375,
"from":L[629]});
}
} catch($e63666367) {
if(R.isCont($e63666367)) {
var $ss63706371 = {"from":L[629],
"go":function(anf_arg14276377) {
return $Hanf_arg25816378(anf_arg14276377,anf_arg14201544,anf_fun14171545,_plus14);
}};
$e63666367.stack[R.EXN_STACKHEIGHT++] = $ss63706371;
}
if(R.isPyretException($e63666367)) {
$e63666367.pyretStack.push(L[629]);
}
throw $e63666367;
}
var $ret63726373 = $Hanf_arg25816378($z63686369,anf_arg14201544,anf_fun14171545,_plus14);
++R.GAS;
return $ret63726373;
};
var $Hanf_arg25816378 = function(anf_arg14276377,anf_arg14201544,anf_fun14171545,_plus14) {
var $z63816382 = D;
var $f63876388 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg14201544,anf_arg14276377):R.ffi.throwNonFunApp(L[631],_plus14,[anf_arg14201544,anf_arg14276377]);
};
try {
if(--R.GAS > 0) {
$z63816382 = $f63876388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63876388,
"from":L[631]});
}
} catch($e63796380) {
if(R.isCont($e63796380)) {
var $ss63836384 = {"from":L[631],
"go":function(anf_arg14286389) {
return $Hanf_arg25806390(anf_arg14286389,anf_fun14171545);
}};
$e63796380.stack[R.EXN_STACKHEIGHT++] = $ss63836384;
}
if(R.isPyretException($e63796380)) {
$e63796380.pyretStack.push(L[631]);
}
throw $e63796380;
}
var $ret63856386 = $Hanf_arg25806390($z63816382,anf_fun14171545);
++R.GAS;
return $ret63856386;
};
var $Hanf_arg25806390 = function(anf_arg14286389,anf_fun14171545) {
var $z63936394 = D;
var $f63996400 = function(_) {
return R.isFunction(anf_fun14171545)?anf_fun14171545.app(anf_arg14286389):R.ffi.throwNonFunApp(L[169],anf_fun14171545,[anf_arg14286389]);
};
try {
if(--R.GAS > 0) {
$z63936394 = $f63996400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63996400,
"from":L[169]});
}
} catch($e63916392) {
if(R.isCont($e63916392)) {
var $ss63956396 = {"from":L[169],
"go":function(ann_DASH_check_DASH_temp14166401) {
return $Hann_DASH_check_DASH_temp25796402(ann_DASH_check_DASH_temp14166401);
}};
$e63916392.stack[R.EXN_STACKHEIGHT++] = $ss63956396;
}
if(R.isPyretException($e63916392)) {
$e63916392.pyretStack.push(L[169]);
}
throw $e63916392;
}
var $ret63976398 = $Hann_DASH_check_DASH_temp25796402($z63936394);
++R.GAS;
return $ret63976398;
};
var $Hann_DASH_check_DASH_temp25796402 = function(ann_DASH_check_DASH_temp14166401) {
return ann_DASH_check_DASH_temp14166401;
};
var $Hanf_begin_app_dropped25781563 = function(anf_begin_app_dropped25721561,printer3381560,self3371562) {
var $z64056406 = D;
var $f64116412 = function(_) {
return R.isFunction(printer3381560)?printer3381560.app(("[")):R.ffi.throwNonFunApp(L[632],printer3381560,[("[")]);
};
try {
if(--R.GAS > 0) {
$z64056406 = $f64116412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64116412,
"from":L[632]});
}
} catch($e64036404) {
if(R.isCont($e64036404)) {
var $ss64076408 = {"from":L[632],
"go":function(anf_begin_app_dropped25736413) {
return $Hanf_begin_app_dropped25776414(anf_begin_app_dropped25736413,printer3381560,self3371562);
}};
$e64036404.stack[R.EXN_STACKHEIGHT++] = $ss64076408;
}
if(R.isPyretException($e64036404)) {
$e64036404.pyretStack.push(L[632]);
}
throw $e64036404;
}
var $ret64096410 = $Hanf_begin_app_dropped25776414($z64056406,printer3381560,self3371562);
++R.GAS;
return $ret64096410;
};
var $Hanf_begin_app_dropped25776414 = function(anf_begin_app_dropped25736413,printer3381560,self3371562) {
var anf_bracket14136428 = G(self3371562,"field",L[635]);
var anf_fun14146425 = G(anf_bracket14136428,"print-ugly-source",L[634]);
var $z64176418 = D;
var $f64236424 = function(_) {
return R.isFunction(anf_fun14146425)?anf_fun14146425.app(printer3381560):R.ffi.throwNonFunApp(L[633],anf_fun14146425,[printer3381560]);
};
try {
if(--R.GAS > 0) {
$z64176418 = $f64236424();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64236424,
"from":L[633]});
}
} catch($e64156416) {
if(R.isCont($e64156416)) {
var $ss64196420 = {"from":L[633],
"go":function(anf_begin_app_dropped25746426) {
return $Hanf_begin_app_dropped25766427(anf_begin_app_dropped25746426,printer3381560);
}};
$e64156416.stack[R.EXN_STACKHEIGHT++] = $ss64196420;
}
if(R.isPyretException($e64156416)) {
$e64156416.pyretStack.push(L[633]);
}
throw $e64156416;
}
var $ret64216422 = $Hanf_begin_app_dropped25766427($z64176418,printer3381560);
++R.GAS;
return $ret64216422;
};
var $Hanf_begin_app_dropped25766427 = function(anf_begin_app_dropped25746426,printer3381560) {
var $z64316432 = D;
var $f64376438 = function(_) {
return R.isFunction(printer3381560)?printer3381560.app(("]")):R.ffi.throwNonFunApp(L[173],printer3381560,[("]")]);
};
try {
if(--R.GAS > 0) {
$z64316432 = $f64376438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64376438,
"from":L[173]});
}
} catch($e64296430) {
if(R.isCont($e64296430)) {
var $ss64336434 = {"from":L[173],
"go":function(ann_DASH_check_DASH_temp14106439) {
return $Hann_DASH_check_DASH_temp25756440(ann_DASH_check_DASH_temp14106439);
}};
$e64296430.stack[R.EXN_STACKHEIGHT++] = $ss64336434;
}
if(R.isPyretException($e64296430)) {
$e64296430.pyretStack.push(L[173]);
}
throw $e64296430;
}
var $ret64356436 = $Hann_DASH_check_DASH_temp25756440($z64316432);
++R.GAS;
return $ret64356436;
};
var $Hann_DASH_check_DASH_temp25756440 = function(ann_DASH_check_DASH_temp14106439) {
return ann_DASH_check_DASH_temp14106439;
};
var $Hanf_arg25711578 = function(anf_arg14021576,self2351577,_plus14,torepr18) {
var anf_arg14036451 = G(self2351577,"field",L[31]);
var $z64436444 = D;
var $f64496450 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg14036451):R.ffi.throwNonFunApp(L[31],torepr18,[anf_arg14036451]);
};
try {
if(--R.GAS > 0) {
$z64436444 = $f64496450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64496450,
"from":L[31]});
}
} catch($e64416442) {
if(R.isCont($e64416442)) {
var $ss64456446 = {"from":L[31],
"go":function(anf_arg14046452) {
return $Hanf_arg25706453(anf_arg14046452,anf_arg14021576,_plus14);
}};
$e64416442.stack[R.EXN_STACKHEIGHT++] = $ss64456446;
}
if(R.isPyretException($e64416442)) {
$e64416442.pyretStack.push(L[31]);
}
throw $e64416442;
}
var $ret64476448 = $Hanf_arg25706453($z64436444,anf_arg14021576,_plus14);
++R.GAS;
return $ret64476448;
};
var $Hanf_arg25706453 = function(anf_arg14046452,anf_arg14021576,_plus14) {
var $z64566457 = D;
var $f64626463 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg14046452):R.ffi.throwNonFunApp(L[31],_plus14,[(", "),anf_arg14046452]);
};
try {
if(--R.GAS > 0) {
$z64566457 = $f64626463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64626463,
"from":L[31]});
}
} catch($e64546455) {
if(R.isCont($e64546455)) {
var $ss64586459 = {"from":L[31],
"go":function(anf_arg14056464) {
return $Hanf_arg25696465(anf_arg14056464,anf_arg14021576,_plus14);
}};
$e64546455.stack[R.EXN_STACKHEIGHT++] = $ss64586459;
}
if(R.isPyretException($e64546455)) {
$e64546455.pyretStack.push(L[31]);
}
throw $e64546455;
}
var $ret64606461 = $Hanf_arg25696465($z64566457,anf_arg14021576,_plus14);
++R.GAS;
return $ret64606461;
};
var $Hanf_arg25696465 = function(anf_arg14056464,anf_arg14021576,_plus14) {
var $z64686469 = D;
var $f64746475 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg14021576,anf_arg14056464):R.ffi.throwNonFunApp(L[31],_plus14,[anf_arg14021576,anf_arg14056464]);
};
try {
if(--R.GAS > 0) {
$z64686469 = $f64746475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64746475,
"from":L[31]});
}
} catch($e64666467) {
if(R.isCont($e64666467)) {
var $ss64706471 = {"from":L[31],
"go":function(anf_arg14066476) {
return $Hanf_arg25686477(anf_arg14066476,_plus14);
}};
$e64666467.stack[R.EXN_STACKHEIGHT++] = $ss64706471;
}
if(R.isPyretException($e64666467)) {
$e64666467.pyretStack.push(L[31]);
}
throw $e64666467;
}
var $ret64726473 = $Hanf_arg25686477($z64686469,_plus14);
++R.GAS;
return $ret64726473;
};
var $Hanf_arg25686477 = function(anf_arg14066476,_plus14) {
var $z64806481 = D;
var $f64866487 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg14066476,(")")):R.ffi.throwNonFunApp(L[31],_plus14,[anf_arg14066476,(")")]);
};
try {
if(--R.GAS > 0) {
$z64806481 = $f64866487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64866487,
"from":L[31]});
}
} catch($e64786479) {
if(R.isCont($e64786479)) {
var $ss64826483 = {"from":L[31],
"go":function(anf_arg14076488) {
return $Hanf_arg25676489(anf_arg14076488,_plus14);
}};
$e64786479.stack[R.EXN_STACKHEIGHT++] = $ss64826483;
}
if(R.isPyretException($e64786479)) {
$e64786479.pyretStack.push(L[31]);
}
throw $e64786479;
}
var $ret64846485 = $Hanf_arg25676489($z64806481,_plus14);
++R.GAS;
return $ret64846485;
};
var $Hanf_arg25676489 = function(anf_arg14076488,_plus14) {
var $z64926493 = D;
var $f64986499 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg14076488):R.ffi.throwNonFunApp(L[31],_plus14,[("("),anf_arg14076488]);
};
try {
if(--R.GAS > 0) {
$z64926493 = $f64986499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64986499,
"from":L[31]});
}
} catch($e64906491) {
if(R.isCont($e64906491)) {
var $ss64946495 = {"from":L[31],
"go":function(anf_arg14086500) {
return $Hanf_arg25666501(anf_arg14086500,_plus14);
}};
$e64906491.stack[R.EXN_STACKHEIGHT++] = $ss64946495;
}
if(R.isPyretException($e64906491)) {
$e64906491.pyretStack.push(L[31]);
}
throw $e64906491;
}
var $ret64966497 = $Hanf_arg25666501($z64926493,_plus14);
++R.GAS;
return $ret64966497;
};
var $Hanf_arg25666501 = function(anf_arg14086500,_plus14) {
var $z65046505 = D;
var $f65106511 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-bracket"),anf_arg14086500):R.ffi.throwNonFunApp(L[31],_plus14,[("j-bracket"),anf_arg14086500]);
};
try {
if(--R.GAS > 0) {
$z65046505 = $f65106511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65106511,
"from":L[31]});
}
} catch($e65026503) {
if(R.isCont($e65026503)) {
var $ss65066507 = {"from":L[31],
"go":function(ann_DASH_check_DASH_temp14006512) {
return $Hann_DASH_check_DASH_temp25656513(ann_DASH_check_DASH_temp14006512);
}};
$e65026503.stack[R.EXN_STACKHEIGHT++] = $ss65066507;
}
if(R.isPyretException($e65026503)) {
$e65026503.pyretStack.push(L[31]);
}
throw $e65026503;
}
var $ret65086509 = $Hann_DASH_check_DASH_temp25656513($z65046505);
++R.GAS;
return $ret65086509;
};
var $Hann_DASH_check_DASH_temp25656513 = function(ann_DASH_check_DASH_temp14006512) {
return ann_DASH_check_DASH_temp14006512;
};
var $Hcont_tail_arg25631594 = function(cont_tail_arg13971592,if_helper13881593) {
if(--R.GAS > 0) {
$z65146515 = R.isFunction(if_helper13881593)?if_helper13881593.app(cont_tail_arg13971592):R.ffi.throwNonFunApp(L[31],if_helper13881593,[cont_tail_arg13971592]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper13881593)?if_helper13881593.app(cont_tail_arg13971592):R.ffi.throwNonFunApp(L[31],if_helper13881593,[cont_tail_arg13971592]);
},
"from":L[31]});
}
++R.GAS;
return $z65146515;
};
var $Hcont_tail_arg25641609 = function(cont_tail_arg13931608,if_helper13881593) {
if(--R.GAS > 0) {
$z65166517 = R.isFunction(if_helper13881593)?if_helper13881593.app(cont_tail_arg13931608):R.ffi.throwNonFunApp(L[31],if_helper13881593,[cont_tail_arg13931608]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper13881593)?if_helper13881593.app(cont_tail_arg13931608):R.ffi.throwNonFunApp(L[31],if_helper13881593,[cont_tail_arg13931608]);
},
"from":L[31]});
}
++R.GAS;
return $z65166517;
};
var $Hanf_arg25621631 = function(anf_arg13791628,INDENT7747,PP123,anf_fun13771629,self3341630) {
var anf_bracket13806531 = G(self3341630,"obj",L[638]);
var anf_fun13816528 = G(anf_bracket13806531,"tosource",L[637]);
var $z65206521 = D;
var $f65266527 = function(_) {
return R.isFunction(anf_fun13816528)?anf_fun13816528.app():R.ffi.throwNonFunApp(L[636],anf_fun13816528,[]);
};
try {
if(--R.GAS > 0) {
$z65206521 = $f65266527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65266527,
"from":L[636]});
}
} catch($e65186519) {
if(R.isCont($e65186519)) {
var $ss65226523 = {"from":L[636],
"go":function(anf_arg13826529) {
return $Hanf_arg25616530(anf_arg13826529,INDENT7747,PP123,anf_arg13791628,anf_fun13771629,self3341630);
}};
$e65186519.stack[R.EXN_STACKHEIGHT++] = $ss65226523;
}
if(R.isPyretException($e65186519)) {
$e65186519.pyretStack.push(L[636]);
}
throw $e65186519;
}
var $ret65246525 = $Hanf_arg25616530($z65206521,INDENT7747,PP123,anf_arg13791628,anf_fun13771629,self3341630);
++R.GAS;
return $ret65246525;
};
var $Hanf_arg25616530 = function(anf_arg13826529,INDENT7747,PP123,anf_arg13791628,anf_fun13771629,self3341630) {
var anf_fun13836542 = G(PP123,"str",L[641]);
var anf_arg13846543 = G(self3341630,"field",L[640]);
var $z65346535 = D;
var $f65406541 = function(_) {
return R.isFunction(anf_fun13836542)?anf_fun13836542.app(anf_arg13846543):R.ffi.throwNonFunApp(L[639],anf_fun13836542,[anf_arg13846543]);
};
try {
if(--R.GAS > 0) {
$z65346535 = $f65406541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65406541,
"from":L[639]});
}
} catch($e65326533) {
if(R.isCont($e65326533)) {
var $ss65366537 = {"from":L[639],
"go":function(anf_arg13856544) {
return $Hanf_arg25606545(anf_arg13856544,INDENT7747,anf_arg13791628,anf_arg13826529,anf_fun13771629);
}};
$e65326533.stack[R.EXN_STACKHEIGHT++] = $ss65366537;
}
if(R.isPyretException($e65326533)) {
$e65326533.pyretStack.push(L[639]);
}
throw $e65326533;
}
var $ret65386539 = $Hanf_arg25606545($z65346535,INDENT7747,anf_arg13791628,anf_arg13826529,anf_fun13771629);
++R.GAS;
return $ret65386539;
};
var $Hanf_arg25606545 = function(anf_arg13856544,INDENT7747,anf_arg13791628,anf_arg13826529,anf_fun13771629) {
var $z65486549 = D;
var $f65546555 = function(_) {
return R.isFunction(anf_fun13771629)?anf_fun13771629.app(INDENT7747,(0),anf_arg13791628,anf_arg13826529,anf_arg13856544):R.ffi.throwNonFunApp(L[179],anf_fun13771629,[INDENT7747,(0),anf_arg13791628,anf_arg13826529,anf_arg13856544]);
};
try {
if(--R.GAS > 0) {
$z65486549 = $f65546555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65546555,
"from":L[179]});
}
} catch($e65466547) {
if(R.isCont($e65466547)) {
var $ss65506551 = {"from":L[179],
"go":function(ann_DASH_check_DASH_temp13766556) {
return $Hann_DASH_check_DASH_temp25596557(ann_DASH_check_DASH_temp13766556);
}};
$e65466547.stack[R.EXN_STACKHEIGHT++] = $ss65506551;
}
if(R.isPyretException($e65466547)) {
$e65466547.pyretStack.push(L[179]);
}
throw $e65466547;
}
var $ret65526553 = $Hann_DASH_check_DASH_temp25596557($z65486549);
++R.GAS;
return $ret65526553;
};
var $Hann_DASH_check_DASH_temp25596557 = function(ann_DASH_check_DASH_temp13766556) {
return ann_DASH_check_DASH_temp13766556;
};
var $Hanf_begin_app_dropped25581646 = function(anf_begin_app_dropped25541644,printer3331643,self3321645) {
var $z65606561 = D;
var $f65666567 = function(_) {
return R.isFunction(printer3331643)?printer3331643.app((".")):R.ffi.throwNonFunApp(L[642],printer3331643,[(".")]);
};
try {
if(--R.GAS > 0) {
$z65606561 = $f65666567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65666567,
"from":L[642]});
}
} catch($e65586559) {
if(R.isCont($e65586559)) {
var $ss65626563 = {"from":L[642],
"go":function(anf_begin_app_dropped25556568) {
return $Hanf_begin_app_dropped25576569(anf_begin_app_dropped25556568,printer3331643,self3321645);
}};
$e65586559.stack[R.EXN_STACKHEIGHT++] = $ss65626563;
}
if(R.isPyretException($e65586559)) {
$e65586559.pyretStack.push(L[642]);
}
throw $e65586559;
}
var $ret65646565 = $Hanf_begin_app_dropped25576569($z65606561,printer3331643,self3321645);
++R.GAS;
return $ret65646565;
};
var $Hanf_begin_app_dropped25576569 = function(anf_begin_app_dropped25556568,printer3331643,self3321645) {
var anf_arg13746580 = G(self3321645,"field",L[643]);
var $z65726573 = D;
var $f65786579 = function(_) {
return R.isFunction(printer3331643)?printer3331643.app(anf_arg13746580):R.ffi.throwNonFunApp(L[183],printer3331643,[anf_arg13746580]);
};
try {
if(--R.GAS > 0) {
$z65726573 = $f65786579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65786579,
"from":L[183]});
}
} catch($e65706571) {
if(R.isCont($e65706571)) {
var $ss65746575 = {"from":L[183],
"go":function(ann_DASH_check_DASH_temp13716581) {
return $Hann_DASH_check_DASH_temp25566582(ann_DASH_check_DASH_temp13716581);
}};
$e65706571.stack[R.EXN_STACKHEIGHT++] = $ss65746575;
}
if(R.isPyretException($e65706571)) {
$e65706571.pyretStack.push(L[183]);
}
throw $e65706571;
}
var $ret65766577 = $Hann_DASH_check_DASH_temp25566582($z65726573);
++R.GAS;
return $ret65766577;
};
var $Hann_DASH_check_DASH_temp25566582 = function(ann_DASH_check_DASH_temp13716581) {
return ann_DASH_check_DASH_temp13716581;
};
var $Hanf_arg25531661 = function(anf_arg13631659,self2291660,_plus14,torepr18) {
var anf_arg13646593 = G(self2291660,"field",L[32]);
var $z65856586 = D;
var $f65916592 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg13646593):R.ffi.throwNonFunApp(L[32],torepr18,[anf_arg13646593]);
};
try {
if(--R.GAS > 0) {
$z65856586 = $f65916592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65916592,
"from":L[32]});
}
} catch($e65836584) {
if(R.isCont($e65836584)) {
var $ss65876588 = {"from":L[32],
"go":function(anf_arg13656594) {
return $Hanf_arg25526595(anf_arg13656594,anf_arg13631659,_plus14);
}};
$e65836584.stack[R.EXN_STACKHEIGHT++] = $ss65876588;
}
if(R.isPyretException($e65836584)) {
$e65836584.pyretStack.push(L[32]);
}
throw $e65836584;
}
var $ret65896590 = $Hanf_arg25526595($z65856586,anf_arg13631659,_plus14);
++R.GAS;
return $ret65896590;
};
var $Hanf_arg25526595 = function(anf_arg13656594,anf_arg13631659,_plus14) {
var $z65986599 = D;
var $f66046605 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg13656594):R.ffi.throwNonFunApp(L[32],_plus14,[(", "),anf_arg13656594]);
};
try {
if(--R.GAS > 0) {
$z65986599 = $f66046605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66046605,
"from":L[32]});
}
} catch($e65966597) {
if(R.isCont($e65966597)) {
var $ss66006601 = {"from":L[32],
"go":function(anf_arg13666606) {
return $Hanf_arg25516607(anf_arg13666606,anf_arg13631659,_plus14);
}};
$e65966597.stack[R.EXN_STACKHEIGHT++] = $ss66006601;
}
if(R.isPyretException($e65966597)) {
$e65966597.pyretStack.push(L[32]);
}
throw $e65966597;
}
var $ret66026603 = $Hanf_arg25516607($z65986599,anf_arg13631659,_plus14);
++R.GAS;
return $ret66026603;
};
var $Hanf_arg25516607 = function(anf_arg13666606,anf_arg13631659,_plus14) {
var $z66106611 = D;
var $f66166617 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg13631659,anf_arg13666606):R.ffi.throwNonFunApp(L[32],_plus14,[anf_arg13631659,anf_arg13666606]);
};
try {
if(--R.GAS > 0) {
$z66106611 = $f66166617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66166617,
"from":L[32]});
}
} catch($e66086609) {
if(R.isCont($e66086609)) {
var $ss66126613 = {"from":L[32],
"go":function(anf_arg13676618) {
return $Hanf_arg25506619(anf_arg13676618,_plus14);
}};
$e66086609.stack[R.EXN_STACKHEIGHT++] = $ss66126613;
}
if(R.isPyretException($e66086609)) {
$e66086609.pyretStack.push(L[32]);
}
throw $e66086609;
}
var $ret66146615 = $Hanf_arg25506619($z66106611,_plus14);
++R.GAS;
return $ret66146615;
};
var $Hanf_arg25506619 = function(anf_arg13676618,_plus14) {
var $z66226623 = D;
var $f66286629 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg13676618,(")")):R.ffi.throwNonFunApp(L[32],_plus14,[anf_arg13676618,(")")]);
};
try {
if(--R.GAS > 0) {
$z66226623 = $f66286629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66286629,
"from":L[32]});
}
} catch($e66206621) {
if(R.isCont($e66206621)) {
var $ss66246625 = {"from":L[32],
"go":function(anf_arg13686630) {
return $Hanf_arg25496631(anf_arg13686630,_plus14);
}};
$e66206621.stack[R.EXN_STACKHEIGHT++] = $ss66246625;
}
if(R.isPyretException($e66206621)) {
$e66206621.pyretStack.push(L[32]);
}
throw $e66206621;
}
var $ret66266627 = $Hanf_arg25496631($z66226623,_plus14);
++R.GAS;
return $ret66266627;
};
var $Hanf_arg25496631 = function(anf_arg13686630,_plus14) {
var $z66346635 = D;
var $f66406641 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg13686630):R.ffi.throwNonFunApp(L[32],_plus14,[("("),anf_arg13686630]);
};
try {
if(--R.GAS > 0) {
$z66346635 = $f66406641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66406641,
"from":L[32]});
}
} catch($e66326633) {
if(R.isCont($e66326633)) {
var $ss66366637 = {"from":L[32],
"go":function(anf_arg13696642) {
return $Hanf_arg25486643(anf_arg13696642,_plus14);
}};
$e66326633.stack[R.EXN_STACKHEIGHT++] = $ss66366637;
}
if(R.isPyretException($e66326633)) {
$e66326633.pyretStack.push(L[32]);
}
throw $e66326633;
}
var $ret66386639 = $Hanf_arg25486643($z66346635,_plus14);
++R.GAS;
return $ret66386639;
};
var $Hanf_arg25486643 = function(anf_arg13696642,_plus14) {
var $z66466647 = D;
var $f66526653 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-dot"),anf_arg13696642):R.ffi.throwNonFunApp(L[32],_plus14,[("j-dot"),anf_arg13696642]);
};
try {
if(--R.GAS > 0) {
$z66466647 = $f66526653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66526653,
"from":L[32]});
}
} catch($e66446645) {
if(R.isCont($e66446645)) {
var $ss66486649 = {"from":L[32],
"go":function(ann_DASH_check_DASH_temp13616654) {
return $Hann_DASH_check_DASH_temp25476655(ann_DASH_check_DASH_temp13616654);
}};
$e66446645.stack[R.EXN_STACKHEIGHT++] = $ss66486649;
}
if(R.isPyretException($e66446645)) {
$e66446645.pyretStack.push(L[32]);
}
throw $e66446645;
}
var $ret66506651 = $Hann_DASH_check_DASH_temp25476655($z66466647);
++R.GAS;
return $ret66506651;
};
var $Hann_DASH_check_DASH_temp25476655 = function(ann_DASH_check_DASH_temp13616654) {
return ann_DASH_check_DASH_temp13616654;
};
var $Hcont_tail_arg25451677 = function(cont_tail_arg13581675,if_helper13491676) {
if(--R.GAS > 0) {
$z66566657 = R.isFunction(if_helper13491676)?if_helper13491676.app(cont_tail_arg13581675):R.ffi.throwNonFunApp(L[32],if_helper13491676,[cont_tail_arg13581675]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper13491676)?if_helper13491676.app(cont_tail_arg13581675):R.ffi.throwNonFunApp(L[32],if_helper13491676,[cont_tail_arg13581675]);
},
"from":L[32]});
}
++R.GAS;
return $z66566657;
};
var $Hcont_tail_arg25461692 = function(cont_tail_arg13541691,if_helper13491676) {
if(--R.GAS > 0) {
$z66586659 = R.isFunction(if_helper13491676)?if_helper13491676.app(cont_tail_arg13541691):R.ffi.throwNonFunApp(L[32],if_helper13491676,[cont_tail_arg13541691]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper13491676)?if_helper13491676.app(cont_tail_arg13541691):R.ffi.throwNonFunApp(L[32],if_helper13491676,[cont_tail_arg13541691]);
},
"from":L[32]});
}
++R.GAS;
return $z66586659;
};
var $Hanf_arg25441716 = function(anf_arg13301711,INDENT7747,PP123,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14) {
var anf_bracket13316673 = G(self3291715,"obj",L[646]);
var anf_fun13326670 = G(anf_bracket13316673,"tosource",L[645]);
var $z66626663 = D;
var $f66686669 = function(_) {
return R.isFunction(anf_fun13326670)?anf_fun13326670.app():R.ffi.throwNonFunApp(L[644],anf_fun13326670,[]);
};
try {
if(--R.GAS > 0) {
$z66626663 = $f66686669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66686669,
"from":L[644]});
}
} catch($e66606661) {
if(R.isCont($e66606661)) {
var $ss66646665 = {"from":L[644],
"go":function(anf_arg13336671) {
return $Hanf_arg25436672(anf_arg13336671,INDENT7747,PP123,anf_arg13301711,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14);
}};
$e66606661.stack[R.EXN_STACKHEIGHT++] = $ss66646665;
}
if(R.isPyretException($e66606661)) {
$e66606661.pyretStack.push(L[644]);
}
throw $e66606661;
}
var $ret66666667 = $Hanf_arg25436672($z66626663,INDENT7747,PP123,anf_arg13301711,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14);
++R.GAS;
return $ret66666667;
};
var $Hanf_arg25436672 = function(anf_arg13336671,INDENT7747,PP123,anf_arg13301711,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14) {
var anf_fun13346684 = G(PP123,"str",L[649]);
var anf_arg13356685 = G(self3291715,"name",L[648]);
var $z66766677 = D;
var $f66826683 = function(_) {
return R.isFunction(anf_fun13346684)?anf_fun13346684.app(anf_arg13356685):R.ffi.throwNonFunApp(L[647],anf_fun13346684,[anf_arg13356685]);
};
try {
if(--R.GAS > 0) {
$z66766677 = $f66826683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66826683,
"from":L[647]});
}
} catch($e66746675) {
if(R.isCont($e66746675)) {
var $ss66786679 = {"from":L[647],
"go":function(anf_arg13366686) {
return $Hanf_arg25426687(anf_arg13366686,INDENT7747,PP123,anf_arg13301711,anf_arg13336671,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14);
}};
$e66746675.stack[R.EXN_STACKHEIGHT++] = $ss66786679;
}
if(R.isPyretException($e66746675)) {
$e66746675.pyretStack.push(L[647]);
}
throw $e66746675;
}
var $ret66806681 = $Hanf_arg25426687($z66766677,INDENT7747,PP123,anf_arg13301711,anf_arg13336671,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14);
++R.GAS;
return $ret66806681;
};
var $Hanf_arg25426687 = function(anf_arg13366686,INDENT7747,PP123,anf_arg13301711,anf_arg13336671,anf_fun13261712,anf_fun13271713,anf_fun13281714,break_DASH_one7846,self3291715,_plus14) {
var $z66906691 = D;
var $f66966697 = function(_) {
return R.isFunction(anf_fun13281714)?anf_fun13281714.app(INDENT7747,(0),anf_arg13301711,anf_arg13336671,anf_arg13366686):R.ffi.throwNonFunApp(L[650],anf_fun13281714,[INDENT7747,(0),anf_arg13301711,anf_arg13336671,anf_arg13366686]);
};
try {
if(--R.GAS > 0) {
$z66906691 = $f66966697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66966697,
"from":L[650]});
}
} catch($e66886689) {
if(R.isCont($e66886689)) {
var $ss66926693 = {"from":L[650],
"go":function(anf_arg13376698) {
return $Hanf_arg25416699(anf_arg13376698,INDENT7747,PP123,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14);
}};
$e66886689.stack[R.EXN_STACKHEIGHT++] = $ss66926693;
}
if(R.isPyretException($e66886689)) {
$e66886689.pyretStack.push(L[650]);
}
throw $e66886689;
}
var $ret66946695 = $Hanf_arg25416699($z66906691,INDENT7747,PP123,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14);
++R.GAS;
return $ret66946695;
};
var $Hanf_arg25416699 = function(anf_arg13376698,INDENT7747,PP123,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14) {
var anf_fun13386710 = G(PP123,"str",L[652]);
var $z67026703 = D;
var $f67086709 = function(_) {
return R.isFunction(anf_fun13386710)?anf_fun13386710.app((" =")):R.ffi.throwNonFunApp(L[651],anf_fun13386710,[(" =")]);
};
try {
if(--R.GAS > 0) {
$z67026703 = $f67086709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67086709,
"from":L[651]});
}
} catch($e67006701) {
if(R.isCont($e67006701)) {
var $ss67046705 = {"from":L[651],
"go":function(anf_arg13396711) {
return $Hanf_arg25406712(anf_arg13396711,INDENT7747,anf_arg13376698,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14);
}};
$e67006701.stack[R.EXN_STACKHEIGHT++] = $ss67046705;
}
if(R.isPyretException($e67006701)) {
$e67006701.pyretStack.push(L[651]);
}
throw $e67006701;
}
var $ret67066707 = $Hanf_arg25406712($z67026703,INDENT7747,anf_arg13376698,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14);
++R.GAS;
return $ret67066707;
};
var $Hanf_arg25406712 = function(anf_arg13396711,INDENT7747,anf_arg13376698,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14) {
var $z67156716 = D;
var $f67216722 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg13376698,anf_arg13396711):R.ffi.throwNonFunApp(L[653],_plus14,[anf_arg13376698,anf_arg13396711]);
};
try {
if(--R.GAS > 0) {
$z67156716 = $f67216722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67216722,
"from":L[653]});
}
} catch($e67136714) {
if(R.isCont($e67136714)) {
var $ss67176718 = {"from":L[653],
"go":function(anf_arg13406723) {
return $Hanf_arg25396724(anf_arg13406723,INDENT7747,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14);
}};
$e67136714.stack[R.EXN_STACKHEIGHT++] = $ss67176718;
}
if(R.isPyretException($e67136714)) {
$e67136714.pyretStack.push(L[653]);
}
throw $e67136714;
}
var $ret67196720 = $Hanf_arg25396724($z67156716,INDENT7747,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14);
++R.GAS;
return $ret67196720;
};
var $Hanf_arg25396724 = function(anf_arg13406723,INDENT7747,anf_fun13261712,anf_fun13271713,break_DASH_one7846,self3291715,_plus14) {
var $z67276728 = D;
var $f67336734 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg13406723,break_DASH_one7846):R.ffi.throwNonFunApp(L[653],_plus14,[anf_arg13406723,break_DASH_one7846]);
};
try {
if(--R.GAS > 0) {
$z67276728 = $f67336734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67336734,
"from":L[653]});
}
} catch($e67256726) {
if(R.isCont($e67256726)) {
var $ss67296730 = {"from":L[653],
"go":function(anf_arg13416735) {
return $Hanf_arg25386736(anf_arg13416735,INDENT7747,anf_fun13261712,anf_fun13271713,self3291715,_plus14);
}};
$e67256726.stack[R.EXN_STACKHEIGHT++] = $ss67296730;
}
if(R.isPyretException($e67256726)) {
$e67256726.pyretStack.push(L[653]);
}
throw $e67256726;
}
var $ret67316732 = $Hanf_arg25386736($z67276728,INDENT7747,anf_fun13261712,anf_fun13271713,self3291715,_plus14);
++R.GAS;
return $ret67316732;
};
var $Hanf_arg25386736 = function(anf_arg13416735,INDENT7747,anf_fun13261712,anf_fun13271713,self3291715,_plus14) {
var anf_bracket13426750 = G(self3291715,"rhs",L[656]);
var anf_fun13436747 = G(anf_bracket13426750,"tosource",L[655]);
var $z67396740 = D;
var $f67456746 = function(_) {
return R.isFunction(anf_fun13436747)?anf_fun13436747.app():R.ffi.throwNonFunApp(L[654],anf_fun13436747,[]);
};
try {
if(--R.GAS > 0) {
$z67396740 = $f67456746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67456746,
"from":L[654]});
}
} catch($e67376738) {
if(R.isCont($e67376738)) {
var $ss67416742 = {"from":L[654],
"go":function(anf_arg13446748) {
return $Hanf_arg25376749(anf_arg13446748,INDENT7747,anf_arg13416735,anf_fun13261712,anf_fun13271713,_plus14);
}};
$e67376738.stack[R.EXN_STACKHEIGHT++] = $ss67416742;
}
if(R.isPyretException($e67376738)) {
$e67376738.pyretStack.push(L[654]);
}
throw $e67376738;
}
var $ret67436744 = $Hanf_arg25376749($z67396740,INDENT7747,anf_arg13416735,anf_fun13261712,anf_fun13271713,_plus14);
++R.GAS;
return $ret67436744;
};
var $Hanf_arg25376749 = function(anf_arg13446748,INDENT7747,anf_arg13416735,anf_fun13261712,anf_fun13271713,_plus14) {
var $z67536754 = D;
var $f67596760 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg13416735,anf_arg13446748):R.ffi.throwNonFunApp(L[653],_plus14,[anf_arg13416735,anf_arg13446748]);
};
try {
if(--R.GAS > 0) {
$z67536754 = $f67596760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67596760,
"from":L[653]});
}
} catch($e67516752) {
if(R.isCont($e67516752)) {
var $ss67556756 = {"from":L[653],
"go":function(anf_arg13456761) {
return $Hanf_arg25366762(anf_arg13456761,INDENT7747,anf_fun13261712,anf_fun13271713);
}};
$e67516752.stack[R.EXN_STACKHEIGHT++] = $ss67556756;
}
if(R.isPyretException($e67516752)) {
$e67516752.pyretStack.push(L[653]);
}
throw $e67516752;
}
var $ret67576758 = $Hanf_arg25366762($z67536754,INDENT7747,anf_fun13261712,anf_fun13271713);
++R.GAS;
return $ret67576758;
};
var $Hanf_arg25366762 = function(anf_arg13456761,INDENT7747,anf_fun13261712,anf_fun13271713) {
var $z67656766 = D;
var $f67716772 = function(_) {
return R.isFunction(anf_fun13271713)?anf_fun13271713.app(INDENT7747,anf_arg13456761):R.ffi.throwNonFunApp(L[657],anf_fun13271713,[INDENT7747,anf_arg13456761]);
};
try {
if(--R.GAS > 0) {
$z67656766 = $f67716772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67716772,
"from":L[657]});
}
} catch($e67636764) {
if(R.isCont($e67636764)) {
var $ss67676768 = {"from":L[657],
"go":function(anf_arg13466773) {
return $Hanf_arg25356774(anf_arg13466773,anf_fun13261712);
}};
$e67636764.stack[R.EXN_STACKHEIGHT++] = $ss67676768;
}
if(R.isPyretException($e67636764)) {
$e67636764.pyretStack.push(L[657]);
}
throw $e67636764;
}
var $ret67696770 = $Hanf_arg25356774($z67656766,anf_fun13261712);
++R.GAS;
return $ret67696770;
};
var $Hanf_arg25356774 = function(anf_arg13466773,anf_fun13261712) {
var $z67776778 = D;
var $f67836784 = function(_) {
return R.isFunction(anf_fun13261712)?anf_fun13261712.app(anf_arg13466773):R.ffi.throwNonFunApp(L[191],anf_fun13261712,[anf_arg13466773]);
};
try {
if(--R.GAS > 0) {
$z67776778 = $f67836784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67836784,
"from":L[191]});
}
} catch($e67756776) {
if(R.isCont($e67756776)) {
var $ss67796780 = {"from":L[191],
"go":function(ann_DASH_check_DASH_temp13256785) {
return $Hann_DASH_check_DASH_temp25346786(ann_DASH_check_DASH_temp13256785);
}};
$e67756776.stack[R.EXN_STACKHEIGHT++] = $ss67796780;
}
if(R.isPyretException($e67756776)) {
$e67756776.pyretStack.push(L[191]);
}
throw $e67756776;
}
var $ret67816782 = $Hann_DASH_check_DASH_temp25346786($z67776778);
++R.GAS;
return $ret67816782;
};
var $Hann_DASH_check_DASH_temp25346786 = function(ann_DASH_check_DASH_temp13256785) {
return ann_DASH_check_DASH_temp13256785;
};
var $Hanf_begin_app_dropped25331731 = function(anf_begin_app_dropped25251729,printer3281728,self3271730) {
var $z67896790 = D;
var $f67956796 = function(_) {
return R.isFunction(printer3281728)?printer3281728.app((".")):R.ffi.throwNonFunApp(L[658],printer3281728,[(".")]);
};
try {
if(--R.GAS > 0) {
$z67896790 = $f67956796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67956796,
"from":L[658]});
}
} catch($e67876788) {
if(R.isCont($e67876788)) {
var $ss67916792 = {"from":L[658],
"go":function(anf_begin_app_dropped25266797) {
return $Hanf_begin_app_dropped25326798(anf_begin_app_dropped25266797,printer3281728,self3271730);
}};
$e67876788.stack[R.EXN_STACKHEIGHT++] = $ss67916792;
}
if(R.isPyretException($e67876788)) {
$e67876788.pyretStack.push(L[658]);
}
throw $e67876788;
}
var $ret67936794 = $Hanf_begin_app_dropped25326798($z67896790,printer3281728,self3271730);
++R.GAS;
return $ret67936794;
};
var $Hanf_begin_app_dropped25326798 = function(anf_begin_app_dropped25266797,printer3281728,self3271730) {
var anf_arg13216809 = G(self3271730,"name",L[660]);
var $z68016802 = D;
var $f68076808 = function(_) {
return R.isFunction(printer3281728)?printer3281728.app(anf_arg13216809):R.ffi.throwNonFunApp(L[659],printer3281728,[anf_arg13216809]);
};
try {
if(--R.GAS > 0) {
$z68016802 = $f68076808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68076808,
"from":L[659]});
}
} catch($e67996800) {
if(R.isCont($e67996800)) {
var $ss68036804 = {"from":L[659],
"go":function(anf_begin_app_dropped25276810) {
return $Hanf_begin_app_dropped25316811(anf_begin_app_dropped25276810,printer3281728,self3271730);
}};
$e67996800.stack[R.EXN_STACKHEIGHT++] = $ss68036804;
}
if(R.isPyretException($e67996800)) {
$e67996800.pyretStack.push(L[659]);
}
throw $e67996800;
}
var $ret68056806 = $Hanf_begin_app_dropped25316811($z68016802,printer3281728,self3271730);
++R.GAS;
return $ret68056806;
};
var $Hanf_begin_app_dropped25316811 = function(anf_begin_app_dropped25276810,printer3281728,self3271730) {
var $z68146815 = D;
var $f68206821 = function(_) {
return R.isFunction(printer3281728)?printer3281728.app((" = ")):R.ffi.throwNonFunApp(L[661],printer3281728,[(" = ")]);
};
try {
if(--R.GAS > 0) {
$z68146815 = $f68206821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68206821,
"from":L[661]});
}
} catch($e68126813) {
if(R.isCont($e68126813)) {
var $ss68166817 = {"from":L[661],
"go":function(anf_begin_app_dropped25286822) {
return $Hanf_begin_app_dropped25306823(anf_begin_app_dropped25286822,printer3281728,self3271730);
}};
$e68126813.stack[R.EXN_STACKHEIGHT++] = $ss68166817;
}
if(R.isPyretException($e68126813)) {
$e68126813.pyretStack.push(L[661]);
}
throw $e68126813;
}
var $ret68186819 = $Hanf_begin_app_dropped25306823($z68146815,printer3281728,self3271730);
++R.GAS;
return $ret68186819;
};
var $Hanf_begin_app_dropped25306823 = function(anf_begin_app_dropped25286822,printer3281728,self3271730) {
var anf_bracket13226837 = G(self3271730,"rhs",L[663]);
var anf_fun13236834 = G(anf_bracket13226837,"print-ugly-source",L[662]);
var $z68266827 = D;
var $f68326833 = function(_) {
return R.isFunction(anf_fun13236834)?anf_fun13236834.app(printer3281728):R.ffi.throwNonFunApp(L[195],anf_fun13236834,[printer3281728]);
};
try {
if(--R.GAS > 0) {
$z68266827 = $f68326833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68326833,
"from":L[195]});
}
} catch($e68246825) {
if(R.isCont($e68246825)) {
var $ss68286829 = {"from":L[195],
"go":function(ann_DASH_check_DASH_temp13186835) {
return $Hann_DASH_check_DASH_temp25296836(ann_DASH_check_DASH_temp13186835);
}};
$e68246825.stack[R.EXN_STACKHEIGHT++] = $ss68286829;
}
if(R.isPyretException($e68246825)) {
$e68246825.pyretStack.push(L[195]);
}
throw $e68246825;
}
var $ret68306831 = $Hann_DASH_check_DASH_temp25296836($z68266827);
++R.GAS;
return $ret68306831;
};
var $Hann_DASH_check_DASH_temp25296836 = function(ann_DASH_check_DASH_temp13186835) {
return ann_DASH_check_DASH_temp13186835;
};
var $Hanf_arg25241746 = function(anf_arg13061744,self2231745,_plus14,torepr18) {
var anf_arg13076848 = G(self2231745,"name",L[33]);
var $z68406841 = D;
var $f68466847 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg13076848):R.ffi.throwNonFunApp(L[33],torepr18,[anf_arg13076848]);
};
try {
if(--R.GAS > 0) {
$z68406841 = $f68466847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68466847,
"from":L[33]});
}
} catch($e68386839) {
if(R.isCont($e68386839)) {
var $ss68426843 = {"from":L[33],
"go":function(anf_arg13086849) {
return $Hanf_arg25236850(anf_arg13086849,anf_arg13061744,self2231745,_plus14,torepr18);
}};
$e68386839.stack[R.EXN_STACKHEIGHT++] = $ss68426843;
}
if(R.isPyretException($e68386839)) {
$e68386839.pyretStack.push(L[33]);
}
throw $e68386839;
}
var $ret68446845 = $Hanf_arg25236850($z68406841,anf_arg13061744,self2231745,_plus14,torepr18);
++R.GAS;
return $ret68446845;
};
var $Hanf_arg25236850 = function(anf_arg13086849,anf_arg13061744,self2231745,_plus14,torepr18) {
var $z68536854 = D;
var $f68596860 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg13086849):R.ffi.throwNonFunApp(L[33],_plus14,[(", "),anf_arg13086849]);
};
try {
if(--R.GAS > 0) {
$z68536854 = $f68596860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68596860,
"from":L[33]});
}
} catch($e68516852) {
if(R.isCont($e68516852)) {
var $ss68556856 = {"from":L[33],
"go":function(anf_arg13096861) {
return $Hanf_arg25226862(anf_arg13096861,anf_arg13061744,self2231745,_plus14,torepr18);
}};
$e68516852.stack[R.EXN_STACKHEIGHT++] = $ss68556856;
}
if(R.isPyretException($e68516852)) {
$e68516852.pyretStack.push(L[33]);
}
throw $e68516852;
}
var $ret68576858 = $Hanf_arg25226862($z68536854,anf_arg13061744,self2231745,_plus14,torepr18);
++R.GAS;
return $ret68576858;
};
var $Hanf_arg25226862 = function(anf_arg13096861,anf_arg13061744,self2231745,_plus14,torepr18) {
var $z68656866 = D;
var $f68716872 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg13061744,anf_arg13096861):R.ffi.throwNonFunApp(L[33],_plus14,[anf_arg13061744,anf_arg13096861]);
};
try {
if(--R.GAS > 0) {
$z68656866 = $f68716872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68716872,
"from":L[33]});
}
} catch($e68636864) {
if(R.isCont($e68636864)) {
var $ss68676868 = {"from":L[33],
"go":function(anf_arg13106873) {
return $Hanf_arg25216874(anf_arg13106873,self2231745,_plus14,torepr18);
}};
$e68636864.stack[R.EXN_STACKHEIGHT++] = $ss68676868;
}
if(R.isPyretException($e68636864)) {
$e68636864.pyretStack.push(L[33]);
}
throw $e68636864;
}
var $ret68696870 = $Hanf_arg25216874($z68656866,self2231745,_plus14,torepr18);
++R.GAS;
return $ret68696870;
};
var $Hanf_arg25216874 = function(anf_arg13106873,self2231745,_plus14,torepr18) {
var anf_arg13116885 = G(self2231745,"rhs",L[33]);
var $z68776878 = D;
var $f68836884 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg13116885):R.ffi.throwNonFunApp(L[33],torepr18,[anf_arg13116885]);
};
try {
if(--R.GAS > 0) {
$z68776878 = $f68836884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68836884,
"from":L[33]});
}
} catch($e68756876) {
if(R.isCont($e68756876)) {
var $ss68796880 = {"from":L[33],
"go":function(anf_arg13126886) {
return $Hanf_arg25206887(anf_arg13126886,anf_arg13106873,_plus14);
}};
$e68756876.stack[R.EXN_STACKHEIGHT++] = $ss68796880;
}
if(R.isPyretException($e68756876)) {
$e68756876.pyretStack.push(L[33]);
}
throw $e68756876;
}
var $ret68816882 = $Hanf_arg25206887($z68776878,anf_arg13106873,_plus14);
++R.GAS;
return $ret68816882;
};
var $Hanf_arg25206887 = function(anf_arg13126886,anf_arg13106873,_plus14) {
var $z68906891 = D;
var $f68966897 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg13126886):R.ffi.throwNonFunApp(L[33],_plus14,[(", "),anf_arg13126886]);
};
try {
if(--R.GAS > 0) {
$z68906891 = $f68966897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68966897,
"from":L[33]});
}
} catch($e68886889) {
if(R.isCont($e68886889)) {
var $ss68926893 = {"from":L[33],
"go":function(anf_arg13136898) {
return $Hanf_arg25196899(anf_arg13136898,anf_arg13106873,_plus14);
}};
$e68886889.stack[R.EXN_STACKHEIGHT++] = $ss68926893;
}
if(R.isPyretException($e68886889)) {
$e68886889.pyretStack.push(L[33]);
}
throw $e68886889;
}
var $ret68946895 = $Hanf_arg25196899($z68906891,anf_arg13106873,_plus14);
++R.GAS;
return $ret68946895;
};
var $Hanf_arg25196899 = function(anf_arg13136898,anf_arg13106873,_plus14) {
var $z69026903 = D;
var $f69086909 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg13106873,anf_arg13136898):R.ffi.throwNonFunApp(L[33],_plus14,[anf_arg13106873,anf_arg13136898]);
};
try {
if(--R.GAS > 0) {
$z69026903 = $f69086909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69086909,
"from":L[33]});
}
} catch($e69006901) {
if(R.isCont($e69006901)) {
var $ss69046905 = {"from":L[33],
"go":function(anf_arg13146910) {
return $Hanf_arg25186911(anf_arg13146910,_plus14);
}};
$e69006901.stack[R.EXN_STACKHEIGHT++] = $ss69046905;
}
if(R.isPyretException($e69006901)) {
$e69006901.pyretStack.push(L[33]);
}
throw $e69006901;
}
var $ret69066907 = $Hanf_arg25186911($z69026903,_plus14);
++R.GAS;
return $ret69066907;
};
var $Hanf_arg25186911 = function(anf_arg13146910,_plus14) {
var $z69146915 = D;
var $f69206921 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg13146910,(")")):R.ffi.throwNonFunApp(L[33],_plus14,[anf_arg13146910,(")")]);
};
try {
if(--R.GAS > 0) {
$z69146915 = $f69206921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69206921,
"from":L[33]});
}
} catch($e69126913) {
if(R.isCont($e69126913)) {
var $ss69166917 = {"from":L[33],
"go":function(anf_arg13156922) {
return $Hanf_arg25176923(anf_arg13156922,_plus14);
}};
$e69126913.stack[R.EXN_STACKHEIGHT++] = $ss69166917;
}
if(R.isPyretException($e69126913)) {
$e69126913.pyretStack.push(L[33]);
}
throw $e69126913;
}
var $ret69186919 = $Hanf_arg25176923($z69146915,_plus14);
++R.GAS;
return $ret69186919;
};
var $Hanf_arg25176923 = function(anf_arg13156922,_plus14) {
var $z69266927 = D;
var $f69326933 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg13156922):R.ffi.throwNonFunApp(L[33],_plus14,[("("),anf_arg13156922]);
};
try {
if(--R.GAS > 0) {
$z69266927 = $f69326933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69326933,
"from":L[33]});
}
} catch($e69246925) {
if(R.isCont($e69246925)) {
var $ss69286929 = {"from":L[33],
"go":function(anf_arg13166934) {
return $Hanf_arg25166935(anf_arg13166934,_plus14);
}};
$e69246925.stack[R.EXN_STACKHEIGHT++] = $ss69286929;
}
if(R.isPyretException($e69246925)) {
$e69246925.pyretStack.push(L[33]);
}
throw $e69246925;
}
var $ret69306931 = $Hanf_arg25166935($z69266927,_plus14);
++R.GAS;
return $ret69306931;
};
var $Hanf_arg25166935 = function(anf_arg13166934,_plus14) {
var $z69386939 = D;
var $f69446945 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-dot-assign"),anf_arg13166934):R.ffi.throwNonFunApp(L[33],_plus14,[("j-dot-assign"),anf_arg13166934]);
};
try {
if(--R.GAS > 0) {
$z69386939 = $f69446945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69446945,
"from":L[33]});
}
} catch($e69366937) {
if(R.isCont($e69366937)) {
var $ss69406941 = {"from":L[33],
"go":function(ann_DASH_check_DASH_temp13046946) {
return $Hann_DASH_check_DASH_temp25156947(ann_DASH_check_DASH_temp13046946);
}};
$e69366937.stack[R.EXN_STACKHEIGHT++] = $ss69406941;
}
if(R.isPyretException($e69366937)) {
$e69366937.pyretStack.push(L[33]);
}
throw $e69366937;
}
var $ret69426943 = $Hann_DASH_check_DASH_temp25156947($z69386939);
++R.GAS;
return $ret69426943;
};
var $Hann_DASH_check_DASH_temp25156947 = function(ann_DASH_check_DASH_temp13046946) {
return ann_DASH_check_DASH_temp13046946;
};
var $Hcont_tail_arg25131763 = function(cont_tail_arg13011761,if_helper12911762) {
if(--R.GAS > 0) {
$z69486949 = R.isFunction(if_helper12911762)?if_helper12911762.app(cont_tail_arg13011761):R.ffi.throwNonFunApp(L[33],if_helper12911762,[cont_tail_arg13011761]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper12911762)?if_helper12911762.app(cont_tail_arg13011761):R.ffi.throwNonFunApp(L[33],if_helper12911762,[cont_tail_arg13011761]);
},
"from":L[33]});
}
++R.GAS;
return $z69486949;
};
var $Hcont_tail_arg25141778 = function(cont_tail_arg12961777,if_helper12911762) {
if(--R.GAS > 0) {
$z69506951 = R.isFunction(if_helper12911762)?if_helper12911762.app(cont_tail_arg12961777):R.ffi.throwNonFunApp(L[33],if_helper12911762,[cont_tail_arg12961777]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper12911762)?if_helper12911762.app(cont_tail_arg12961777):R.ffi.throwNonFunApp(L[33],if_helper12911762,[cont_tail_arg12961777]);
},
"from":L[33]});
}
++R.GAS;
return $z69506951;
};
var $Hanf_arg25121801 = function(anf_arg12711797,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14) {
var anf_arg12726962 = G(PP123,"lbrack",L[665]);
var $z69546955 = D;
var $f69606961 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12711797,anf_arg12726962):R.ffi.throwNonFunApp(L[664],_plus14,[anf_arg12711797,anf_arg12726962]);
};
try {
if(--R.GAS > 0) {
$z69546955 = $f69606961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69606961,
"from":L[664]});
}
} catch($e69526953) {
if(R.isCont($e69526953)) {
var $ss69566957 = {"from":L[664],
"go":function(anf_arg12736963) {
return $Hanf_arg25116964(anf_arg12736963,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
}};
$e69526953.stack[R.EXN_STACKHEIGHT++] = $ss69566957;
}
if(R.isPyretException($e69526953)) {
$e69526953.pyretStack.push(L[664]);
}
throw $e69526953;
}
var $ret69586959 = $Hanf_arg25116964($z69546955,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
++R.GAS;
return $ret69586959;
};
var $Hanf_arg25116964 = function(anf_arg12736963,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14) {
var anf_bracket12746978 = G(self3231800,"field",L[668]);
var anf_fun12756975 = G(anf_bracket12746978,"tosource",L[667]);
var $z69676968 = D;
var $f69736974 = function(_) {
return R.isFunction(anf_fun12756975)?anf_fun12756975.app():R.ffi.throwNonFunApp(L[666],anf_fun12756975,[]);
};
try {
if(--R.GAS > 0) {
$z69676968 = $f69736974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69736974,
"from":L[666]});
}
} catch($e69656966) {
if(R.isCont($e69656966)) {
var $ss69696970 = {"from":L[666],
"go":function(anf_arg12766976) {
return $Hanf_arg25106977(anf_arg12766976,INDENT7747,PP123,anf_arg12736963,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
}};
$e69656966.stack[R.EXN_STACKHEIGHT++] = $ss69696970;
}
if(R.isPyretException($e69656966)) {
$e69656966.pyretStack.push(L[666]);
}
throw $e69656966;
}
var $ret69716972 = $Hanf_arg25106977($z69676968,INDENT7747,PP123,anf_arg12736963,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
++R.GAS;
return $ret69716972;
};
var $Hanf_arg25106977 = function(anf_arg12766976,INDENT7747,PP123,anf_arg12736963,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14) {
var $z69816982 = D;
var $f69876988 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12736963,anf_arg12766976):R.ffi.throwNonFunApp(L[664],_plus14,[anf_arg12736963,anf_arg12766976]);
};
try {
if(--R.GAS > 0) {
$z69816982 = $f69876988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69876988,
"from":L[664]});
}
} catch($e69796980) {
if(R.isCont($e69796980)) {
var $ss69836984 = {"from":L[664],
"go":function(anf_arg12776989) {
return $Hanf_arg25096990(anf_arg12776989,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
}};
$e69796980.stack[R.EXN_STACKHEIGHT++] = $ss69836984;
}
if(R.isPyretException($e69796980)) {
$e69796980.pyretStack.push(L[664]);
}
throw $e69796980;
}
var $ret69856986 = $Hanf_arg25096990($z69816982,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
++R.GAS;
return $ret69856986;
};
var $Hanf_arg25096990 = function(anf_arg12776989,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14) {
var anf_arg12787001 = G(PP123,"rbrack",L[669]);
var $z69936994 = D;
var $f69997000 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12776989,anf_arg12787001):R.ffi.throwNonFunApp(L[664],_plus14,[anf_arg12776989,anf_arg12787001]);
};
try {
if(--R.GAS > 0) {
$z69936994 = $f69997000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69997000,
"from":L[664]});
}
} catch($e69916992) {
if(R.isCont($e69916992)) {
var $ss69956996 = {"from":L[664],
"go":function(anf_arg12797002) {
return $Hanf_arg25087003(anf_arg12797002,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
}};
$e69916992.stack[R.EXN_STACKHEIGHT++] = $ss69956996;
}
if(R.isPyretException($e69916992)) {
$e69916992.pyretStack.push(L[664]);
}
throw $e69916992;
}
var $ret69976998 = $Hanf_arg25087003($z69936994,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
++R.GAS;
return $ret69976998;
};
var $Hanf_arg25087003 = function(anf_arg12797002,INDENT7747,PP123,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14) {
var anf_fun12807014 = G(PP123,"str",L[671]);
var $z70067007 = D;
var $f70127013 = function(_) {
return R.isFunction(anf_fun12807014)?anf_fun12807014.app((" =")):R.ffi.throwNonFunApp(L[670],anf_fun12807014,[(" =")]);
};
try {
if(--R.GAS > 0) {
$z70067007 = $f70127013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70127013,
"from":L[670]});
}
} catch($e70047005) {
if(R.isCont($e70047005)) {
var $ss70087009 = {"from":L[670],
"go":function(anf_arg12817015) {
return $Hanf_arg25077016(anf_arg12817015,INDENT7747,anf_arg12797002,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
}};
$e70047005.stack[R.EXN_STACKHEIGHT++] = $ss70087009;
}
if(R.isPyretException($e70047005)) {
$e70047005.pyretStack.push(L[670]);
}
throw $e70047005;
}
var $ret70107011 = $Hanf_arg25077016($z70067007,INDENT7747,anf_arg12797002,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
++R.GAS;
return $ret70107011;
};
var $Hanf_arg25077016 = function(anf_arg12817015,INDENT7747,anf_arg12797002,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14) {
var $z70197020 = D;
var $f70257026 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12797002,anf_arg12817015):R.ffi.throwNonFunApp(L[664],_plus14,[anf_arg12797002,anf_arg12817015]);
};
try {
if(--R.GAS > 0) {
$z70197020 = $f70257026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70257026,
"from":L[664]});
}
} catch($e70177018) {
if(R.isCont($e70177018)) {
var $ss70217022 = {"from":L[664],
"go":function(anf_arg12827027) {
return $Hanf_arg25067028(anf_arg12827027,INDENT7747,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
}};
$e70177018.stack[R.EXN_STACKHEIGHT++] = $ss70217022;
}
if(R.isPyretException($e70177018)) {
$e70177018.pyretStack.push(L[664]);
}
throw $e70177018;
}
var $ret70237024 = $Hanf_arg25067028($z70197020,INDENT7747,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14);
++R.GAS;
return $ret70237024;
};
var $Hanf_arg25067028 = function(anf_arg12827027,INDENT7747,anf_fun12671798,anf_fun12681799,break_DASH_one7846,self3231800,_plus14) {
var $z70317032 = D;
var $f70377038 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12827027,break_DASH_one7846):R.ffi.throwNonFunApp(L[664],_plus14,[anf_arg12827027,break_DASH_one7846]);
};
try {
if(--R.GAS > 0) {
$z70317032 = $f70377038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70377038,
"from":L[664]});
}
} catch($e70297030) {
if(R.isCont($e70297030)) {
var $ss70337034 = {"from":L[664],
"go":function(anf_arg12837039) {
return $Hanf_arg25057040(anf_arg12837039,INDENT7747,anf_fun12671798,anf_fun12681799,self3231800,_plus14);
}};
$e70297030.stack[R.EXN_STACKHEIGHT++] = $ss70337034;
}
if(R.isPyretException($e70297030)) {
$e70297030.pyretStack.push(L[664]);
}
throw $e70297030;
}
var $ret70357036 = $Hanf_arg25057040($z70317032,INDENT7747,anf_fun12671798,anf_fun12681799,self3231800,_plus14);
++R.GAS;
return $ret70357036;
};
var $Hanf_arg25057040 = function(anf_arg12837039,INDENT7747,anf_fun12671798,anf_fun12681799,self3231800,_plus14) {
var anf_bracket12847054 = G(self3231800,"rhs",L[674]);
var anf_fun12857051 = G(anf_bracket12847054,"tosource",L[673]);
var $z70437044 = D;
var $f70497050 = function(_) {
return R.isFunction(anf_fun12857051)?anf_fun12857051.app():R.ffi.throwNonFunApp(L[672],anf_fun12857051,[]);
};
try {
if(--R.GAS > 0) {
$z70437044 = $f70497050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70497050,
"from":L[672]});
}
} catch($e70417042) {
if(R.isCont($e70417042)) {
var $ss70457046 = {"from":L[672],
"go":function(anf_arg12867052) {
return $Hanf_arg25047053(anf_arg12867052,INDENT7747,anf_arg12837039,anf_fun12671798,anf_fun12681799,_plus14);
}};
$e70417042.stack[R.EXN_STACKHEIGHT++] = $ss70457046;
}
if(R.isPyretException($e70417042)) {
$e70417042.pyretStack.push(L[672]);
}
throw $e70417042;
}
var $ret70477048 = $Hanf_arg25047053($z70437044,INDENT7747,anf_arg12837039,anf_fun12671798,anf_fun12681799,_plus14);
++R.GAS;
return $ret70477048;
};
var $Hanf_arg25047053 = function(anf_arg12867052,INDENT7747,anf_arg12837039,anf_fun12671798,anf_fun12681799,_plus14) {
var $z70577058 = D;
var $f70637064 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12837039,anf_arg12867052):R.ffi.throwNonFunApp(L[664],_plus14,[anf_arg12837039,anf_arg12867052]);
};
try {
if(--R.GAS > 0) {
$z70577058 = $f70637064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70637064,
"from":L[664]});
}
} catch($e70557056) {
if(R.isCont($e70557056)) {
var $ss70597060 = {"from":L[664],
"go":function(anf_arg12877065) {
return $Hanf_arg25037066(anf_arg12877065,INDENT7747,anf_fun12671798,anf_fun12681799);
}};
$e70557056.stack[R.EXN_STACKHEIGHT++] = $ss70597060;
}
if(R.isPyretException($e70557056)) {
$e70557056.pyretStack.push(L[664]);
}
throw $e70557056;
}
var $ret70617062 = $Hanf_arg25037066($z70577058,INDENT7747,anf_fun12671798,anf_fun12681799);
++R.GAS;
return $ret70617062;
};
var $Hanf_arg25037066 = function(anf_arg12877065,INDENT7747,anf_fun12671798,anf_fun12681799) {
var $z70697070 = D;
var $f70757076 = function(_) {
return R.isFunction(anf_fun12681799)?anf_fun12681799.app(INDENT7747,anf_arg12877065):R.ffi.throwNonFunApp(L[675],anf_fun12681799,[INDENT7747,anf_arg12877065]);
};
try {
if(--R.GAS > 0) {
$z70697070 = $f70757076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70757076,
"from":L[675]});
}
} catch($e70677068) {
if(R.isCont($e70677068)) {
var $ss70717072 = {"from":L[675],
"go":function(anf_arg12887077) {
return $Hanf_arg25027078(anf_arg12887077,anf_fun12671798);
}};
$e70677068.stack[R.EXN_STACKHEIGHT++] = $ss70717072;
}
if(R.isPyretException($e70677068)) {
$e70677068.pyretStack.push(L[675]);
}
throw $e70677068;
}
var $ret70737074 = $Hanf_arg25027078($z70697070,anf_fun12671798);
++R.GAS;
return $ret70737074;
};
var $Hanf_arg25027078 = function(anf_arg12887077,anf_fun12671798) {
var $z70817082 = D;
var $f70877088 = function(_) {
return R.isFunction(anf_fun12671798)?anf_fun12671798.app(anf_arg12887077):R.ffi.throwNonFunApp(L[204],anf_fun12671798,[anf_arg12887077]);
};
try {
if(--R.GAS > 0) {
$z70817082 = $f70877088();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70877088,
"from":L[204]});
}
} catch($e70797080) {
if(R.isCont($e70797080)) {
var $ss70837084 = {"from":L[204],
"go":function(ann_DASH_check_DASH_temp12667089) {
return $Hann_DASH_check_DASH_temp25017090(ann_DASH_check_DASH_temp12667089);
}};
$e70797080.stack[R.EXN_STACKHEIGHT++] = $ss70837084;
}
if(R.isPyretException($e70797080)) {
$e70797080.pyretStack.push(L[204]);
}
throw $e70797080;
}
var $ret70857086 = $Hann_DASH_check_DASH_temp25017090($z70817082);
++R.GAS;
return $ret70857086;
};
var $Hann_DASH_check_DASH_temp25017090 = function(ann_DASH_check_DASH_temp12667089) {
return ann_DASH_check_DASH_temp12667089;
};
var $Hanf_begin_app_dropped25001817 = function(anf_begin_app_dropped24901815,printer3221814,self3211816) {
var $z70937094 = D;
var $f70997100 = function(_) {
return R.isFunction(printer3221814)?printer3221814.app(("[")):R.ffi.throwNonFunApp(L[676],printer3221814,[("[")]);
};
try {
if(--R.GAS > 0) {
$z70937094 = $f70997100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70997100,
"from":L[676]});
}
} catch($e70917092) {
if(R.isCont($e70917092)) {
var $ss70957096 = {"from":L[676],
"go":function(anf_begin_app_dropped24917101) {
return $Hanf_begin_app_dropped24997102(anf_begin_app_dropped24917101,printer3221814,self3211816);
}};
$e70917092.stack[R.EXN_STACKHEIGHT++] = $ss70957096;
}
if(R.isPyretException($e70917092)) {
$e70917092.pyretStack.push(L[676]);
}
throw $e70917092;
}
var $ret70977098 = $Hanf_begin_app_dropped24997102($z70937094,printer3221814,self3211816);
++R.GAS;
return $ret70977098;
};
var $Hanf_begin_app_dropped24997102 = function(anf_begin_app_dropped24917101,printer3221814,self3211816) {
var anf_bracket12617116 = G(self3211816,"field",L[679]);
var anf_fun12627113 = G(anf_bracket12617116,"print-ugly-source",L[678]);
var $z71057106 = D;
var $f71117112 = function(_) {
return R.isFunction(anf_fun12627113)?anf_fun12627113.app(printer3221814):R.ffi.throwNonFunApp(L[677],anf_fun12627113,[printer3221814]);
};
try {
if(--R.GAS > 0) {
$z71057106 = $f71117112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71117112,
"from":L[677]});
}
} catch($e71037104) {
if(R.isCont($e71037104)) {
var $ss71077108 = {"from":L[677],
"go":function(anf_begin_app_dropped24927114) {
return $Hanf_begin_app_dropped24987115(anf_begin_app_dropped24927114,printer3221814,self3211816);
}};
$e71037104.stack[R.EXN_STACKHEIGHT++] = $ss71077108;
}
if(R.isPyretException($e71037104)) {
$e71037104.pyretStack.push(L[677]);
}
throw $e71037104;
}
var $ret71097110 = $Hanf_begin_app_dropped24987115($z71057106,printer3221814,self3211816);
++R.GAS;
return $ret71097110;
};
var $Hanf_begin_app_dropped24987115 = function(anf_begin_app_dropped24927114,printer3221814,self3211816) {
var $z71197120 = D;
var $f71257126 = function(_) {
return R.isFunction(printer3221814)?printer3221814.app(("]")):R.ffi.throwNonFunApp(L[680],printer3221814,[("]")]);
};
try {
if(--R.GAS > 0) {
$z71197120 = $f71257126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71257126,
"from":L[680]});
}
} catch($e71177118) {
if(R.isCont($e71177118)) {
var $ss71217122 = {"from":L[680],
"go":function(anf_begin_app_dropped24937127) {
return $Hanf_begin_app_dropped24977128(anf_begin_app_dropped24937127,printer3221814,self3211816);
}};
$e71177118.stack[R.EXN_STACKHEIGHT++] = $ss71217122;
}
if(R.isPyretException($e71177118)) {
$e71177118.pyretStack.push(L[680]);
}
throw $e71177118;
}
var $ret71237124 = $Hanf_begin_app_dropped24977128($z71197120,printer3221814,self3211816);
++R.GAS;
return $ret71237124;
};
var $Hanf_begin_app_dropped24977128 = function(anf_begin_app_dropped24937127,printer3221814,self3211816) {
var $z71317132 = D;
var $f71377138 = function(_) {
return R.isFunction(printer3221814)?printer3221814.app((" = ")):R.ffi.throwNonFunApp(L[681],printer3221814,[(" = ")]);
};
try {
if(--R.GAS > 0) {
$z71317132 = $f71377138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71377138,
"from":L[681]});
}
} catch($e71297130) {
if(R.isCont($e71297130)) {
var $ss71337134 = {"from":L[681],
"go":function(anf_begin_app_dropped24947139) {
return $Hanf_begin_app_dropped24967140(anf_begin_app_dropped24947139,printer3221814,self3211816);
}};
$e71297130.stack[R.EXN_STACKHEIGHT++] = $ss71337134;
}
if(R.isPyretException($e71297130)) {
$e71297130.pyretStack.push(L[681]);
}
throw $e71297130;
}
var $ret71357136 = $Hanf_begin_app_dropped24967140($z71317132,printer3221814,self3211816);
++R.GAS;
return $ret71357136;
};
var $Hanf_begin_app_dropped24967140 = function(anf_begin_app_dropped24947139,printer3221814,self3211816) {
var anf_bracket12637154 = G(self3211816,"rhs",L[683]);
var anf_fun12647151 = G(anf_bracket12637154,"print-ugly-source",L[682]);
var $z71437144 = D;
var $f71497150 = function(_) {
return R.isFunction(anf_fun12647151)?anf_fun12647151.app(printer3221814):R.ffi.throwNonFunApp(L[208],anf_fun12647151,[printer3221814]);
};
try {
if(--R.GAS > 0) {
$z71437144 = $f71497150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71497150,
"from":L[208]});
}
} catch($e71417142) {
if(R.isCont($e71417142)) {
var $ss71457146 = {"from":L[208],
"go":function(ann_DASH_check_DASH_temp12587152) {
return $Hann_DASH_check_DASH_temp24957153(ann_DASH_check_DASH_temp12587152);
}};
$e71417142.stack[R.EXN_STACKHEIGHT++] = $ss71457146;
}
if(R.isPyretException($e71417142)) {
$e71417142.pyretStack.push(L[208]);
}
throw $e71417142;
}
var $ret71477148 = $Hann_DASH_check_DASH_temp24957153($z71437144);
++R.GAS;
return $ret71477148;
};
var $Hann_DASH_check_DASH_temp24957153 = function(ann_DASH_check_DASH_temp12587152) {
return ann_DASH_check_DASH_temp12587152;
};
var $Hanf_arg24891832 = function(anf_arg12461830,self2171831,_plus14,torepr18) {
var anf_arg12477165 = G(self2171831,"field",L[34]);
var $z71577158 = D;
var $f71637164 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg12477165):R.ffi.throwNonFunApp(L[34],torepr18,[anf_arg12477165]);
};
try {
if(--R.GAS > 0) {
$z71577158 = $f71637164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71637164,
"from":L[34]});
}
} catch($e71557156) {
if(R.isCont($e71557156)) {
var $ss71597160 = {"from":L[34],
"go":function(anf_arg12487166) {
return $Hanf_arg24887167(anf_arg12487166,anf_arg12461830,self2171831,_plus14,torepr18);
}};
$e71557156.stack[R.EXN_STACKHEIGHT++] = $ss71597160;
}
if(R.isPyretException($e71557156)) {
$e71557156.pyretStack.push(L[34]);
}
throw $e71557156;
}
var $ret71617162 = $Hanf_arg24887167($z71577158,anf_arg12461830,self2171831,_plus14,torepr18);
++R.GAS;
return $ret71617162;
};
var $Hanf_arg24887167 = function(anf_arg12487166,anf_arg12461830,self2171831,_plus14,torepr18) {
var $z71707171 = D;
var $f71767177 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg12487166):R.ffi.throwNonFunApp(L[34],_plus14,[(", "),anf_arg12487166]);
};
try {
if(--R.GAS > 0) {
$z71707171 = $f71767177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71767177,
"from":L[34]});
}
} catch($e71687169) {
if(R.isCont($e71687169)) {
var $ss71727173 = {"from":L[34],
"go":function(anf_arg12497178) {
return $Hanf_arg24877179(anf_arg12497178,anf_arg12461830,self2171831,_plus14,torepr18);
}};
$e71687169.stack[R.EXN_STACKHEIGHT++] = $ss71727173;
}
if(R.isPyretException($e71687169)) {
$e71687169.pyretStack.push(L[34]);
}
throw $e71687169;
}
var $ret71747175 = $Hanf_arg24877179($z71707171,anf_arg12461830,self2171831,_plus14,torepr18);
++R.GAS;
return $ret71747175;
};
var $Hanf_arg24877179 = function(anf_arg12497178,anf_arg12461830,self2171831,_plus14,torepr18) {
var $z71827183 = D;
var $f71887189 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12461830,anf_arg12497178):R.ffi.throwNonFunApp(L[34],_plus14,[anf_arg12461830,anf_arg12497178]);
};
try {
if(--R.GAS > 0) {
$z71827183 = $f71887189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71887189,
"from":L[34]});
}
} catch($e71807181) {
if(R.isCont($e71807181)) {
var $ss71847185 = {"from":L[34],
"go":function(anf_arg12507190) {
return $Hanf_arg24867191(anf_arg12507190,self2171831,_plus14,torepr18);
}};
$e71807181.stack[R.EXN_STACKHEIGHT++] = $ss71847185;
}
if(R.isPyretException($e71807181)) {
$e71807181.pyretStack.push(L[34]);
}
throw $e71807181;
}
var $ret71867187 = $Hanf_arg24867191($z71827183,self2171831,_plus14,torepr18);
++R.GAS;
return $ret71867187;
};
var $Hanf_arg24867191 = function(anf_arg12507190,self2171831,_plus14,torepr18) {
var anf_arg12517202 = G(self2171831,"rhs",L[34]);
var $z71947195 = D;
var $f72007201 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg12517202):R.ffi.throwNonFunApp(L[34],torepr18,[anf_arg12517202]);
};
try {
if(--R.GAS > 0) {
$z71947195 = $f72007201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72007201,
"from":L[34]});
}
} catch($e71927193) {
if(R.isCont($e71927193)) {
var $ss71967197 = {"from":L[34],
"go":function(anf_arg12527203) {
return $Hanf_arg24857204(anf_arg12527203,anf_arg12507190,_plus14);
}};
$e71927193.stack[R.EXN_STACKHEIGHT++] = $ss71967197;
}
if(R.isPyretException($e71927193)) {
$e71927193.pyretStack.push(L[34]);
}
throw $e71927193;
}
var $ret71987199 = $Hanf_arg24857204($z71947195,anf_arg12507190,_plus14);
++R.GAS;
return $ret71987199;
};
var $Hanf_arg24857204 = function(anf_arg12527203,anf_arg12507190,_plus14) {
var $z72077208 = D;
var $f72137214 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg12527203):R.ffi.throwNonFunApp(L[34],_plus14,[(", "),anf_arg12527203]);
};
try {
if(--R.GAS > 0) {
$z72077208 = $f72137214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72137214,
"from":L[34]});
}
} catch($e72057206) {
if(R.isCont($e72057206)) {
var $ss72097210 = {"from":L[34],
"go":function(anf_arg12537215) {
return $Hanf_arg24847216(anf_arg12537215,anf_arg12507190,_plus14);
}};
$e72057206.stack[R.EXN_STACKHEIGHT++] = $ss72097210;
}
if(R.isPyretException($e72057206)) {
$e72057206.pyretStack.push(L[34]);
}
throw $e72057206;
}
var $ret72117212 = $Hanf_arg24847216($z72077208,anf_arg12507190,_plus14);
++R.GAS;
return $ret72117212;
};
var $Hanf_arg24847216 = function(anf_arg12537215,anf_arg12507190,_plus14) {
var $z72197220 = D;
var $f72257226 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12507190,anf_arg12537215):R.ffi.throwNonFunApp(L[34],_plus14,[anf_arg12507190,anf_arg12537215]);
};
try {
if(--R.GAS > 0) {
$z72197220 = $f72257226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72257226,
"from":L[34]});
}
} catch($e72177218) {
if(R.isCont($e72177218)) {
var $ss72217222 = {"from":L[34],
"go":function(anf_arg12547227) {
return $Hanf_arg24837228(anf_arg12547227,_plus14);
}};
$e72177218.stack[R.EXN_STACKHEIGHT++] = $ss72217222;
}
if(R.isPyretException($e72177218)) {
$e72177218.pyretStack.push(L[34]);
}
throw $e72177218;
}
var $ret72237224 = $Hanf_arg24837228($z72197220,_plus14);
++R.GAS;
return $ret72237224;
};
var $Hanf_arg24837228 = function(anf_arg12547227,_plus14) {
var $z72317232 = D;
var $f72377238 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12547227,(")")):R.ffi.throwNonFunApp(L[34],_plus14,[anf_arg12547227,(")")]);
};
try {
if(--R.GAS > 0) {
$z72317232 = $f72377238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72377238,
"from":L[34]});
}
} catch($e72297230) {
if(R.isCont($e72297230)) {
var $ss72337234 = {"from":L[34],
"go":function(anf_arg12557239) {
return $Hanf_arg24827240(anf_arg12557239,_plus14);
}};
$e72297230.stack[R.EXN_STACKHEIGHT++] = $ss72337234;
}
if(R.isPyretException($e72297230)) {
$e72297230.pyretStack.push(L[34]);
}
throw $e72297230;
}
var $ret72357236 = $Hanf_arg24827240($z72317232,_plus14);
++R.GAS;
return $ret72357236;
};
var $Hanf_arg24827240 = function(anf_arg12557239,_plus14) {
var $z72437244 = D;
var $f72497250 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg12557239):R.ffi.throwNonFunApp(L[34],_plus14,[("("),anf_arg12557239]);
};
try {
if(--R.GAS > 0) {
$z72437244 = $f72497250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72497250,
"from":L[34]});
}
} catch($e72417242) {
if(R.isCont($e72417242)) {
var $ss72457246 = {"from":L[34],
"go":function(anf_arg12567251) {
return $Hanf_arg24817252(anf_arg12567251,_plus14);
}};
$e72417242.stack[R.EXN_STACKHEIGHT++] = $ss72457246;
}
if(R.isPyretException($e72417242)) {
$e72417242.pyretStack.push(L[34]);
}
throw $e72417242;
}
var $ret72477248 = $Hanf_arg24817252($z72437244,_plus14);
++R.GAS;
return $ret72477248;
};
var $Hanf_arg24817252 = function(anf_arg12567251,_plus14) {
var $z72557256 = D;
var $f72617262 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-bracket-assign"),anf_arg12567251):R.ffi.throwNonFunApp(L[34],_plus14,[("j-bracket-assign"),anf_arg12567251]);
};
try {
if(--R.GAS > 0) {
$z72557256 = $f72617262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72617262,
"from":L[34]});
}
} catch($e72537254) {
if(R.isCont($e72537254)) {
var $ss72577258 = {"from":L[34],
"go":function(ann_DASH_check_DASH_temp12447263) {
return $Hann_DASH_check_DASH_temp24807264(ann_DASH_check_DASH_temp12447263);
}};
$e72537254.stack[R.EXN_STACKHEIGHT++] = $ss72577258;
}
if(R.isPyretException($e72537254)) {
$e72537254.pyretStack.push(L[34]);
}
throw $e72537254;
}
var $ret72597260 = $Hann_DASH_check_DASH_temp24807264($z72557256);
++R.GAS;
return $ret72597260;
};
var $Hann_DASH_check_DASH_temp24807264 = function(ann_DASH_check_DASH_temp12447263) {
return ann_DASH_check_DASH_temp12447263;
};
var $Hcont_tail_arg24781849 = function(cont_tail_arg12411847,if_helper12311848) {
if(--R.GAS > 0) {
$z72657266 = R.isFunction(if_helper12311848)?if_helper12311848.app(cont_tail_arg12411847):R.ffi.throwNonFunApp(L[34],if_helper12311848,[cont_tail_arg12411847]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper12311848)?if_helper12311848.app(cont_tail_arg12411847):R.ffi.throwNonFunApp(L[34],if_helper12311848,[cont_tail_arg12411847]);
},
"from":L[34]});
}
++R.GAS;
return $z72657266;
};
var $Hcont_tail_arg24791864 = function(cont_tail_arg12361863,if_helper12311848) {
if(--R.GAS > 0) {
$z72677268 = R.isFunction(if_helper12311848)?if_helper12311848.app(cont_tail_arg12361863):R.ffi.throwNonFunApp(L[34],if_helper12311848,[cont_tail_arg12361863]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper12311848)?if_helper12311848.app(cont_tail_arg12361863):R.ffi.throwNonFunApp(L[34],if_helper12311848,[cont_tail_arg12361863]);
},
"from":L[34]});
}
++R.GAS;
return $z72677268;
};
var $Hanf_arg24771888 = function(anf_arg12191884,INDENT7747,PP123,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14) {
var anf_fun12207279 = G(PP123,"str",L[685]);
var $z72717272 = D;
var $f72777278 = function(_) {
return R.isFunction(anf_fun12207279)?anf_fun12207279.app((" =")):R.ffi.throwNonFunApp(L[684],anf_fun12207279,[(" =")]);
};
try {
if(--R.GAS > 0) {
$z72717272 = $f72777278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72777278,
"from":L[684]});
}
} catch($e72697270) {
if(R.isCont($e72697270)) {
var $ss72737274 = {"from":L[684],
"go":function(anf_arg12217280) {
return $Hanf_arg24767281(anf_arg12217280,INDENT7747,anf_arg12191884,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14);
}};
$e72697270.stack[R.EXN_STACKHEIGHT++] = $ss72737274;
}
if(R.isPyretException($e72697270)) {
$e72697270.pyretStack.push(L[684]);
}
throw $e72697270;
}
var $ret72757276 = $Hanf_arg24767281($z72717272,INDENT7747,anf_arg12191884,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14);
++R.GAS;
return $ret72757276;
};
var $Hanf_arg24767281 = function(anf_arg12217280,INDENT7747,anf_arg12191884,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14) {
var $z72847285 = D;
var $f72907291 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12191884,anf_arg12217280):R.ffi.throwNonFunApp(L[686],_plus14,[anf_arg12191884,anf_arg12217280]);
};
try {
if(--R.GAS > 0) {
$z72847285 = $f72907291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72907291,
"from":L[686]});
}
} catch($e72827283) {
if(R.isCont($e72827283)) {
var $ss72867287 = {"from":L[686],
"go":function(anf_arg12227292) {
return $Hanf_arg24757293(anf_arg12227292,INDENT7747,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14);
}};
$e72827283.stack[R.EXN_STACKHEIGHT++] = $ss72867287;
}
if(R.isPyretException($e72827283)) {
$e72827283.pyretStack.push(L[686]);
}
throw $e72827283;
}
var $ret72887289 = $Hanf_arg24757293($z72847285,INDENT7747,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14);
++R.GAS;
return $ret72887289;
};
var $Hanf_arg24757293 = function(anf_arg12227292,INDENT7747,anf_fun12151885,anf_fun12161886,break_DASH_one7846,self3171887,_plus14) {
var $z72967297 = D;
var $f73027303 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12227292,break_DASH_one7846):R.ffi.throwNonFunApp(L[686],_plus14,[anf_arg12227292,break_DASH_one7846]);
};
try {
if(--R.GAS > 0) {
$z72967297 = $f73027303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73027303,
"from":L[686]});
}
} catch($e72947295) {
if(R.isCont($e72947295)) {
var $ss72987299 = {"from":L[686],
"go":function(anf_arg12237304) {
return $Hanf_arg24747305(anf_arg12237304,INDENT7747,anf_fun12151885,anf_fun12161886,self3171887,_plus14);
}};
$e72947295.stack[R.EXN_STACKHEIGHT++] = $ss72987299;
}
if(R.isPyretException($e72947295)) {
$e72947295.pyretStack.push(L[686]);
}
throw $e72947295;
}
var $ret73007301 = $Hanf_arg24747305($z72967297,INDENT7747,anf_fun12151885,anf_fun12161886,self3171887,_plus14);
++R.GAS;
return $ret73007301;
};
var $Hanf_arg24747305 = function(anf_arg12237304,INDENT7747,anf_fun12151885,anf_fun12161886,self3171887,_plus14) {
var anf_bracket12247319 = G(self3171887,"rhs",L[689]);
var anf_fun12257316 = G(anf_bracket12247319,"tosource",L[688]);
var $z73087309 = D;
var $f73147315 = function(_) {
return R.isFunction(anf_fun12257316)?anf_fun12257316.app():R.ffi.throwNonFunApp(L[687],anf_fun12257316,[]);
};
try {
if(--R.GAS > 0) {
$z73087309 = $f73147315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73147315,
"from":L[687]});
}
} catch($e73067307) {
if(R.isCont($e73067307)) {
var $ss73107311 = {"from":L[687],
"go":function(anf_arg12267317) {
return $Hanf_arg24737318(anf_arg12267317,INDENT7747,anf_arg12237304,anf_fun12151885,anf_fun12161886,_plus14);
}};
$e73067307.stack[R.EXN_STACKHEIGHT++] = $ss73107311;
}
if(R.isPyretException($e73067307)) {
$e73067307.pyretStack.push(L[687]);
}
throw $e73067307;
}
var $ret73127313 = $Hanf_arg24737318($z73087309,INDENT7747,anf_arg12237304,anf_fun12151885,anf_fun12161886,_plus14);
++R.GAS;
return $ret73127313;
};
var $Hanf_arg24737318 = function(anf_arg12267317,INDENT7747,anf_arg12237304,anf_fun12151885,anf_fun12161886,_plus14) {
var $z73227323 = D;
var $f73287329 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12237304,anf_arg12267317):R.ffi.throwNonFunApp(L[686],_plus14,[anf_arg12237304,anf_arg12267317]);
};
try {
if(--R.GAS > 0) {
$z73227323 = $f73287329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73287329,
"from":L[686]});
}
} catch($e73207321) {
if(R.isCont($e73207321)) {
var $ss73247325 = {"from":L[686],
"go":function(anf_arg12277330) {
return $Hanf_arg24727331(anf_arg12277330,INDENT7747,anf_fun12151885,anf_fun12161886);
}};
$e73207321.stack[R.EXN_STACKHEIGHT++] = $ss73247325;
}
if(R.isPyretException($e73207321)) {
$e73207321.pyretStack.push(L[686]);
}
throw $e73207321;
}
var $ret73267327 = $Hanf_arg24727331($z73227323,INDENT7747,anf_fun12151885,anf_fun12161886);
++R.GAS;
return $ret73267327;
};
var $Hanf_arg24727331 = function(anf_arg12277330,INDENT7747,anf_fun12151885,anf_fun12161886) {
var $z73347335 = D;
var $f73407341 = function(_) {
return R.isFunction(anf_fun12161886)?anf_fun12161886.app(INDENT7747,anf_arg12277330):R.ffi.throwNonFunApp(L[690],anf_fun12161886,[INDENT7747,anf_arg12277330]);
};
try {
if(--R.GAS > 0) {
$z73347335 = $f73407341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73407341,
"from":L[690]});
}
} catch($e73327333) {
if(R.isCont($e73327333)) {
var $ss73367337 = {"from":L[690],
"go":function(anf_arg12287342) {
return $Hanf_arg24717343(anf_arg12287342,anf_fun12151885);
}};
$e73327333.stack[R.EXN_STACKHEIGHT++] = $ss73367337;
}
if(R.isPyretException($e73327333)) {
$e73327333.pyretStack.push(L[690]);
}
throw $e73327333;
}
var $ret73387339 = $Hanf_arg24717343($z73347335,anf_fun12151885);
++R.GAS;
return $ret73387339;
};
var $Hanf_arg24717343 = function(anf_arg12287342,anf_fun12151885) {
var $z73467347 = D;
var $f73527353 = function(_) {
return R.isFunction(anf_fun12151885)?anf_fun12151885.app(anf_arg12287342):R.ffi.throwNonFunApp(L[217],anf_fun12151885,[anf_arg12287342]);
};
try {
if(--R.GAS > 0) {
$z73467347 = $f73527353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73527353,
"from":L[217]});
}
} catch($e73447345) {
if(R.isCont($e73447345)) {
var $ss73487349 = {"from":L[217],
"go":function(ann_DASH_check_DASH_temp12147354) {
return $Hann_DASH_check_DASH_temp24707355(ann_DASH_check_DASH_temp12147354);
}};
$e73447345.stack[R.EXN_STACKHEIGHT++] = $ss73487349;
}
if(R.isPyretException($e73447345)) {
$e73447345.pyretStack.push(L[217]);
}
throw $e73447345;
}
var $ret73507351 = $Hann_DASH_check_DASH_temp24707355($z73467347);
++R.GAS;
return $ret73507351;
};
var $Hann_DASH_check_DASH_temp24707355 = function(ann_DASH_check_DASH_temp12147354) {
return ann_DASH_check_DASH_temp12147354;
};
var $Hanf_begin_app_dropped24691903 = function(anf_begin_app_dropped24651901,printer3161899,self3151902) {
var $z73587359 = D;
var $f73647365 = function(_) {
return R.isFunction(printer3161899)?printer3161899.app((" = ")):R.ffi.throwNonFunApp(L[691],printer3161899,[(" = ")]);
};
try {
if(--R.GAS > 0) {
$z73587359 = $f73647365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73647365,
"from":L[691]});
}
} catch($e73567357) {
if(R.isCont($e73567357)) {
var $ss73607361 = {"from":L[691],
"go":function(anf_begin_app_dropped24667366) {
return $Hanf_begin_app_dropped24687367(anf_begin_app_dropped24667366,printer3161899,self3151902);
}};
$e73567357.stack[R.EXN_STACKHEIGHT++] = $ss73607361;
}
if(R.isPyretException($e73567357)) {
$e73567357.pyretStack.push(L[691]);
}
throw $e73567357;
}
var $ret73627363 = $Hanf_begin_app_dropped24687367($z73587359,printer3161899,self3151902);
++R.GAS;
return $ret73627363;
};
var $Hanf_begin_app_dropped24687367 = function(anf_begin_app_dropped24667366,printer3161899,self3151902) {
var anf_bracket12117381 = G(self3151902,"rhs",L[693]);
var anf_fun12127378 = G(anf_bracket12117381,"print-ugly-source",L[692]);
var $z73707371 = D;
var $f73767377 = function(_) {
return R.isFunction(anf_fun12127378)?anf_fun12127378.app(printer3161899):R.ffi.throwNonFunApp(L[220],anf_fun12127378,[printer3161899]);
};
try {
if(--R.GAS > 0) {
$z73707371 = $f73767377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73767377,
"from":L[220]});
}
} catch($e73687369) {
if(R.isCont($e73687369)) {
var $ss73727373 = {"from":L[220],
"go":function(ann_DASH_check_DASH_temp12097379) {
return $Hann_DASH_check_DASH_temp24677380(ann_DASH_check_DASH_temp12097379);
}};
$e73687369.stack[R.EXN_STACKHEIGHT++] = $ss73727373;
}
if(R.isPyretException($e73687369)) {
$e73687369.pyretStack.push(L[220]);
}
throw $e73687369;
}
var $ret73747375 = $Hann_DASH_check_DASH_temp24677380($z73707371);
++R.GAS;
return $ret73747375;
};
var $Hann_DASH_check_DASH_temp24677380 = function(ann_DASH_check_DASH_temp12097379) {
return ann_DASH_check_DASH_temp12097379;
};
var $Hanf_arg24641917 = function(anf_arg12011915,self2111916,_plus14,torepr18) {
var anf_arg12027392 = G(self2111916,"rhs",L[35]);
var $z73847385 = D;
var $f73907391 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg12027392):R.ffi.throwNonFunApp(L[35],torepr18,[anf_arg12027392]);
};
try {
if(--R.GAS > 0) {
$z73847385 = $f73907391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73907391,
"from":L[35]});
}
} catch($e73827383) {
if(R.isCont($e73827383)) {
var $ss73867387 = {"from":L[35],
"go":function(anf_arg12037393) {
return $Hanf_arg24637394(anf_arg12037393,anf_arg12011915,_plus14);
}};
$e73827383.stack[R.EXN_STACKHEIGHT++] = $ss73867387;
}
if(R.isPyretException($e73827383)) {
$e73827383.pyretStack.push(L[35]);
}
throw $e73827383;
}
var $ret73887389 = $Hanf_arg24637394($z73847385,anf_arg12011915,_plus14);
++R.GAS;
return $ret73887389;
};
var $Hanf_arg24637394 = function(anf_arg12037393,anf_arg12011915,_plus14) {
var $z73977398 = D;
var $f74037404 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg12037393):R.ffi.throwNonFunApp(L[35],_plus14,[(", "),anf_arg12037393]);
};
try {
if(--R.GAS > 0) {
$z73977398 = $f74037404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74037404,
"from":L[35]});
}
} catch($e73957396) {
if(R.isCont($e73957396)) {
var $ss73997400 = {"from":L[35],
"go":function(anf_arg12047405) {
return $Hanf_arg24627406(anf_arg12047405,anf_arg12011915,_plus14);
}};
$e73957396.stack[R.EXN_STACKHEIGHT++] = $ss73997400;
}
if(R.isPyretException($e73957396)) {
$e73957396.pyretStack.push(L[35]);
}
throw $e73957396;
}
var $ret74017402 = $Hanf_arg24627406($z73977398,anf_arg12011915,_plus14);
++R.GAS;
return $ret74017402;
};
var $Hanf_arg24627406 = function(anf_arg12047405,anf_arg12011915,_plus14) {
var $z74097410 = D;
var $f74157416 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12011915,anf_arg12047405):R.ffi.throwNonFunApp(L[35],_plus14,[anf_arg12011915,anf_arg12047405]);
};
try {
if(--R.GAS > 0) {
$z74097410 = $f74157416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74157416,
"from":L[35]});
}
} catch($e74077408) {
if(R.isCont($e74077408)) {
var $ss74117412 = {"from":L[35],
"go":function(anf_arg12057417) {
return $Hanf_arg24617418(anf_arg12057417,_plus14);
}};
$e74077408.stack[R.EXN_STACKHEIGHT++] = $ss74117412;
}
if(R.isPyretException($e74077408)) {
$e74077408.pyretStack.push(L[35]);
}
throw $e74077408;
}
var $ret74137414 = $Hanf_arg24617418($z74097410,_plus14);
++R.GAS;
return $ret74137414;
};
var $Hanf_arg24617418 = function(anf_arg12057417,_plus14) {
var $z74217422 = D;
var $f74277428 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12057417,(")")):R.ffi.throwNonFunApp(L[35],_plus14,[anf_arg12057417,(")")]);
};
try {
if(--R.GAS > 0) {
$z74217422 = $f74277428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74277428,
"from":L[35]});
}
} catch($e74197420) {
if(R.isCont($e74197420)) {
var $ss74237424 = {"from":L[35],
"go":function(anf_arg12067429) {
return $Hanf_arg24607430(anf_arg12067429,_plus14);
}};
$e74197420.stack[R.EXN_STACKHEIGHT++] = $ss74237424;
}
if(R.isPyretException($e74197420)) {
$e74197420.pyretStack.push(L[35]);
}
throw $e74197420;
}
var $ret74257426 = $Hanf_arg24607430($z74217422,_plus14);
++R.GAS;
return $ret74257426;
};
var $Hanf_arg24607430 = function(anf_arg12067429,_plus14) {
var $z74337434 = D;
var $f74397440 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg12067429):R.ffi.throwNonFunApp(L[35],_plus14,[("("),anf_arg12067429]);
};
try {
if(--R.GAS > 0) {
$z74337434 = $f74397440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74397440,
"from":L[35]});
}
} catch($e74317432) {
if(R.isCont($e74317432)) {
var $ss74357436 = {"from":L[35],
"go":function(anf_arg12077441) {
return $Hanf_arg24597442(anf_arg12077441,_plus14);
}};
$e74317432.stack[R.EXN_STACKHEIGHT++] = $ss74357436;
}
if(R.isPyretException($e74317432)) {
$e74317432.pyretStack.push(L[35]);
}
throw $e74317432;
}
var $ret74377438 = $Hanf_arg24597442($z74337434,_plus14);
++R.GAS;
return $ret74377438;
};
var $Hanf_arg24597442 = function(anf_arg12077441,_plus14) {
var $z74457446 = D;
var $f74517452 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-assign"),anf_arg12077441):R.ffi.throwNonFunApp(L[35],_plus14,[("j-assign"),anf_arg12077441]);
};
try {
if(--R.GAS > 0) {
$z74457446 = $f74517452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74517452,
"from":L[35]});
}
} catch($e74437444) {
if(R.isCont($e74437444)) {
var $ss74477448 = {"from":L[35],
"go":function(ann_DASH_check_DASH_temp11997453) {
return $Hann_DASH_check_DASH_temp24587454(ann_DASH_check_DASH_temp11997453);
}};
$e74437444.stack[R.EXN_STACKHEIGHT++] = $ss74477448;
}
if(R.isPyretException($e74437444)) {
$e74437444.pyretStack.push(L[35]);
}
throw $e74437444;
}
var $ret74497450 = $Hann_DASH_check_DASH_temp24587454($z74457446);
++R.GAS;
return $ret74497450;
};
var $Hann_DASH_check_DASH_temp24587454 = function(ann_DASH_check_DASH_temp11997453) {
return ann_DASH_check_DASH_temp11997453;
};
var $Hcont_tail_arg24561933 = function(cont_tail_arg11961931,if_helper11871932) {
if(--R.GAS > 0) {
$z74557456 = R.isFunction(if_helper11871932)?if_helper11871932.app(cont_tail_arg11961931):R.ffi.throwNonFunApp(L[35],if_helper11871932,[cont_tail_arg11961931]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper11871932)?if_helper11871932.app(cont_tail_arg11961931):R.ffi.throwNonFunApp(L[35],if_helper11871932,[cont_tail_arg11961931]);
},
"from":L[35]});
}
++R.GAS;
return $z74557456;
};
var $Hcont_tail_arg24571948 = function(cont_tail_arg11921947,if_helper11871932) {
if(--R.GAS > 0) {
$z74577458 = R.isFunction(if_helper11871932)?if_helper11871932.app(cont_tail_arg11921947):R.ffi.throwNonFunApp(L[35],if_helper11871932,[cont_tail_arg11921947]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper11871932)?if_helper11871932.app(cont_tail_arg11921947):R.ffi.throwNonFunApp(L[35],if_helper11871932,[cont_tail_arg11921947]);
},
"from":L[35]});
}
++R.GAS;
return $z74577458;
};
var $Hanf_arg24551970 = function(anf_arg11581967,INDENT7747,PP123,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var anf_fun11597471 = G(PP123,"nest",L[696]);
var anf_fun11607469 = G(PP123,"str",L[695]);
var $z74617462 = D;
var $f74677468 = function(_) {
return R.isFunction(anf_fun11607469)?anf_fun11607469.app(("?")):R.ffi.throwNonFunApp(L[694],anf_fun11607469,[("?")]);
};
try {
if(--R.GAS > 0) {
$z74617462 = $f74677468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74677468,
"from":L[694]});
}
} catch($e74597460) {
if(R.isCont($e74597460)) {
var $ss74637464 = {"from":L[694],
"go":function(anf_arg11617470) {
return $Hanf_arg24547472(anf_arg11617470,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e74597460.stack[R.EXN_STACKHEIGHT++] = $ss74637464;
}
if(R.isPyretException($e74597460)) {
$e74597460.pyretStack.push(L[694]);
}
throw $e74597460;
}
var $ret74657466 = $Hanf_arg24547472($z74617462,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret74657466;
};
var $Hanf_arg24547472 = function(anf_arg11617470,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var $z74757476 = D;
var $f74817482 = function(_) {
return R.isFunction(_plus14)?_plus14.app(break_DASH_one7846,anf_arg11617470):R.ffi.throwNonFunApp(L[697],_plus14,[break_DASH_one7846,anf_arg11617470]);
};
try {
if(--R.GAS > 0) {
$z74757476 = $f74817482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74817482,
"from":L[697]});
}
} catch($e74737474) {
if(R.isCont($e74737474)) {
var $ss74777478 = {"from":L[697],
"go":function(anf_arg11627483) {
return $Hanf_arg24537484(anf_arg11627483,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e74737474.stack[R.EXN_STACKHEIGHT++] = $ss74777478;
}
if(R.isPyretException($e74737474)) {
$e74737474.pyretStack.push(L[697]);
}
throw $e74737474;
}
var $ret74797480 = $Hanf_arg24537484($z74757476,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret74797480;
};
var $Hanf_arg24537484 = function(anf_arg11627483,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var $z74877488 = D;
var $f74937494 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11627483,blank_DASH_one7976):R.ffi.throwNonFunApp(L[697],_plus14,[anf_arg11627483,blank_DASH_one7976]);
};
try {
if(--R.GAS > 0) {
$z74877488 = $f74937494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74937494,
"from":L[697]});
}
} catch($e74857486) {
if(R.isCont($e74857486)) {
var $ss74897490 = {"from":L[697],
"go":function(anf_arg11637495) {
return $Hanf_arg24527496(anf_arg11637495,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e74857486.stack[R.EXN_STACKHEIGHT++] = $ss74897490;
}
if(R.isPyretException($e74857486)) {
$e74857486.pyretStack.push(L[697]);
}
throw $e74857486;
}
var $ret74917492 = $Hanf_arg24527496($z74877488,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret74917492;
};
var $Hanf_arg24527496 = function(anf_arg11637495,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var anf_fun11647509 = G(PP123,"nest",L[701]);
var anf_bracket11657511 = G(self3121969,"consq",L[700]);
var anf_fun11667507 = G(anf_bracket11657511,"tosource",L[699]);
var $z74997500 = D;
var $f75057506 = function(_) {
return R.isFunction(anf_fun11667507)?anf_fun11667507.app():R.ffi.throwNonFunApp(L[698],anf_fun11667507,[]);
};
try {
if(--R.GAS > 0) {
$z74997500 = $f75057506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75057506,
"from":L[698]});
}
} catch($e74977498) {
if(R.isCont($e74977498)) {
var $ss75017502 = {"from":L[698],
"go":function(anf_arg11677508) {
return $Hanf_arg24517510(anf_arg11677508,INDENT7747,PP123,anf_arg11581967,anf_arg11637495,anf_fun11551968,anf_fun11597471,anf_fun11647509,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e74977498.stack[R.EXN_STACKHEIGHT++] = $ss75017502;
}
if(R.isPyretException($e74977498)) {
$e74977498.pyretStack.push(L[698]);
}
throw $e74977498;
}
var $ret75037504 = $Hanf_arg24517510($z74997500,INDENT7747,PP123,anf_arg11581967,anf_arg11637495,anf_fun11551968,anf_fun11597471,anf_fun11647509,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret75037504;
};
var $Hanf_arg24517510 = function(anf_arg11677508,INDENT7747,PP123,anf_arg11581967,anf_arg11637495,anf_fun11551968,anf_fun11597471,anf_fun11647509,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var $z75147515 = D;
var $f75207521 = function(_) {
return R.isFunction(anf_fun11647509)?anf_fun11647509.app(INDENT7747,anf_arg11677508):R.ffi.throwNonFunApp(L[702],anf_fun11647509,[INDENT7747,anf_arg11677508]);
};
try {
if(--R.GAS > 0) {
$z75147515 = $f75207521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75207521,
"from":L[702]});
}
} catch($e75127513) {
if(R.isCont($e75127513)) {
var $ss75167517 = {"from":L[702],
"go":function(anf_arg11687522) {
return $Hanf_arg24507523(anf_arg11687522,INDENT7747,PP123,anf_arg11581967,anf_arg11637495,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e75127513.stack[R.EXN_STACKHEIGHT++] = $ss75167517;
}
if(R.isPyretException($e75127513)) {
$e75127513.pyretStack.push(L[702]);
}
throw $e75127513;
}
var $ret75187519 = $Hanf_arg24507523($z75147515,INDENT7747,PP123,anf_arg11581967,anf_arg11637495,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret75187519;
};
var $Hanf_arg24507523 = function(anf_arg11687522,INDENT7747,PP123,anf_arg11581967,anf_arg11637495,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var $z75267527 = D;
var $f75327533 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11637495,anf_arg11687522):R.ffi.throwNonFunApp(L[697],_plus14,[anf_arg11637495,anf_arg11687522]);
};
try {
if(--R.GAS > 0) {
$z75267527 = $f75327533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75327533,
"from":L[697]});
}
} catch($e75247525) {
if(R.isCont($e75247525)) {
var $ss75287529 = {"from":L[697],
"go":function(anf_arg11697534) {
return $Hanf_arg24497535(anf_arg11697534,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e75247525.stack[R.EXN_STACKHEIGHT++] = $ss75287529;
}
if(R.isPyretException($e75247525)) {
$e75247525.pyretStack.push(L[697]);
}
throw $e75247525;
}
var $ret75307531 = $Hanf_arg24497535($z75267527,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret75307531;
};
var $Hanf_arg24497535 = function(anf_arg11697534,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,anf_fun11597471,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var $z75387539 = D;
var $f75447545 = function(_) {
return R.isFunction(anf_fun11597471)?anf_fun11597471.app(INDENT7747,anf_arg11697534):R.ffi.throwNonFunApp(L[703],anf_fun11597471,[INDENT7747,anf_arg11697534]);
};
try {
if(--R.GAS > 0) {
$z75387539 = $f75447545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75447545,
"from":L[703]});
}
} catch($e75367537) {
if(R.isCont($e75367537)) {
var $ss75407541 = {"from":L[703],
"go":function(anf_arg11707546) {
return $Hanf_arg24487547(anf_arg11707546,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e75367537.stack[R.EXN_STACKHEIGHT++] = $ss75407541;
}
if(R.isPyretException($e75367537)) {
$e75367537.pyretStack.push(L[703]);
}
throw $e75367537;
}
var $ret75427543 = $Hanf_arg24487547($z75387539,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret75427543;
};
var $Hanf_arg24487547 = function(anf_arg11707546,INDENT7747,PP123,anf_arg11581967,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var $z75507551 = D;
var $f75567557 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11581967,anf_arg11707546):R.ffi.throwNonFunApp(L[704],_plus14,[anf_arg11581967,anf_arg11707546]);
};
try {
if(--R.GAS > 0) {
$z75507551 = $f75567557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75567557,
"from":L[704]});
}
} catch($e75487549) {
if(R.isCont($e75487549)) {
var $ss75527553 = {"from":L[704],
"go":function(anf_arg11717558) {
return $Hanf_arg24477559(anf_arg11717558,INDENT7747,PP123,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e75487549.stack[R.EXN_STACKHEIGHT++] = $ss75527553;
}
if(R.isPyretException($e75487549)) {
$e75487549.pyretStack.push(L[704]);
}
throw $e75487549;
}
var $ret75547555 = $Hanf_arg24477559($z75507551,INDENT7747,PP123,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret75547555;
};
var $Hanf_arg24477559 = function(anf_arg11717558,INDENT7747,PP123,anf_fun11551968,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var anf_fun11727572 = G(PP123,"nest",L[707]);
var anf_fun11737570 = G(PP123,"str",L[706]);
var $z75627563 = D;
var $f75687569 = function(_) {
return R.isFunction(anf_fun11737570)?anf_fun11737570.app((":")):R.ffi.throwNonFunApp(L[705],anf_fun11737570,[(":")]);
};
try {
if(--R.GAS > 0) {
$z75627563 = $f75687569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75687569,
"from":L[705]});
}
} catch($e75607561) {
if(R.isCont($e75607561)) {
var $ss75647565 = {"from":L[705],
"go":function(anf_arg11747571) {
return $Hanf_arg24467573(anf_arg11747571,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
}};
$e75607561.stack[R.EXN_STACKHEIGHT++] = $ss75647565;
}
if(R.isPyretException($e75607561)) {
$e75607561.pyretStack.push(L[705]);
}
throw $e75607561;
}
var $ret75667567 = $Hanf_arg24467573($z75627563,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14);
++R.GAS;
return $ret75667567;
};
var $Hanf_arg24467573 = function(anf_arg11747571,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,blank_DASH_one7976,break_DASH_one7846,self3121969,_plus14) {
var $z75767577 = D;
var $f75827583 = function(_) {
return R.isFunction(_plus14)?_plus14.app(break_DASH_one7846,anf_arg11747571):R.ffi.throwNonFunApp(L[708],_plus14,[break_DASH_one7846,anf_arg11747571]);
};
try {
if(--R.GAS > 0) {
$z75767577 = $f75827583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75827583,
"from":L[708]});
}
} catch($e75747575) {
if(R.isCont($e75747575)) {
var $ss75787579 = {"from":L[708],
"go":function(anf_arg11757584) {
return $Hanf_arg24457585(anf_arg11757584,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,blank_DASH_one7976,self3121969,_plus14);
}};
$e75747575.stack[R.EXN_STACKHEIGHT++] = $ss75787579;
}
if(R.isPyretException($e75747575)) {
$e75747575.pyretStack.push(L[708]);
}
throw $e75747575;
}
var $ret75807581 = $Hanf_arg24457585($z75767577,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,blank_DASH_one7976,self3121969,_plus14);
++R.GAS;
return $ret75807581;
};
var $Hanf_arg24457585 = function(anf_arg11757584,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,blank_DASH_one7976,self3121969,_plus14) {
var $z75887589 = D;
var $f75947595 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11757584,blank_DASH_one7976):R.ffi.throwNonFunApp(L[708],_plus14,[anf_arg11757584,blank_DASH_one7976]);
};
try {
if(--R.GAS > 0) {
$z75887589 = $f75947595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75947595,
"from":L[708]});
}
} catch($e75867587) {
if(R.isCont($e75867587)) {
var $ss75907591 = {"from":L[708],
"go":function(anf_arg11767596) {
return $Hanf_arg24447597(anf_arg11767596,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,self3121969,_plus14);
}};
$e75867587.stack[R.EXN_STACKHEIGHT++] = $ss75907591;
}
if(R.isPyretException($e75867587)) {
$e75867587.pyretStack.push(L[708]);
}
throw $e75867587;
}
var $ret75927593 = $Hanf_arg24447597($z75887589,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,self3121969,_plus14);
++R.GAS;
return $ret75927593;
};
var $Hanf_arg24447597 = function(anf_arg11767596,INDENT7747,PP123,anf_arg11717558,anf_fun11551968,anf_fun11727572,self3121969,_plus14) {
var anf_fun11777610 = G(PP123,"nest",L[712]);
var anf_bracket11787612 = G(self3121969,"altern",L[711]);
var anf_fun11797608 = G(anf_bracket11787612,"tosource",L[710]);
var $z76007601 = D;
var $f76067607 = function(_) {
return R.isFunction(anf_fun11797608)?anf_fun11797608.app():R.ffi.throwNonFunApp(L[709],anf_fun11797608,[]);
};
try {
if(--R.GAS > 0) {
$z76007601 = $f76067607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76067607,
"from":L[709]});
}
} catch($e75987599) {
if(R.isCont($e75987599)) {
var $ss76027603 = {"from":L[709],
"go":function(anf_arg11807609) {
return $Hanf_arg24437611(anf_arg11807609,INDENT7747,anf_arg11717558,anf_arg11767596,anf_fun11551968,anf_fun11727572,anf_fun11777610,_plus14);
}};
$e75987599.stack[R.EXN_STACKHEIGHT++] = $ss76027603;
}
if(R.isPyretException($e75987599)) {
$e75987599.pyretStack.push(L[709]);
}
throw $e75987599;
}
var $ret76047605 = $Hanf_arg24437611($z76007601,INDENT7747,anf_arg11717558,anf_arg11767596,anf_fun11551968,anf_fun11727572,anf_fun11777610,_plus14);
++R.GAS;
return $ret76047605;
};
var $Hanf_arg24437611 = function(anf_arg11807609,INDENT7747,anf_arg11717558,anf_arg11767596,anf_fun11551968,anf_fun11727572,anf_fun11777610,_plus14) {
var $z76157616 = D;
var $f76217622 = function(_) {
return R.isFunction(anf_fun11777610)?anf_fun11777610.app(INDENT7747,anf_arg11807609):R.ffi.throwNonFunApp(L[713],anf_fun11777610,[INDENT7747,anf_arg11807609]);
};
try {
if(--R.GAS > 0) {
$z76157616 = $f76217622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76217622,
"from":L[713]});
}
} catch($e76137614) {
if(R.isCont($e76137614)) {
var $ss76177618 = {"from":L[713],
"go":function(anf_arg11817623) {
return $Hanf_arg24427624(anf_arg11817623,INDENT7747,anf_arg11717558,anf_arg11767596,anf_fun11551968,anf_fun11727572,_plus14);
}};
$e76137614.stack[R.EXN_STACKHEIGHT++] = $ss76177618;
}
if(R.isPyretException($e76137614)) {
$e76137614.pyretStack.push(L[713]);
}
throw $e76137614;
}
var $ret76197620 = $Hanf_arg24427624($z76157616,INDENT7747,anf_arg11717558,anf_arg11767596,anf_fun11551968,anf_fun11727572,_plus14);
++R.GAS;
return $ret76197620;
};
var $Hanf_arg24427624 = function(anf_arg11817623,INDENT7747,anf_arg11717558,anf_arg11767596,anf_fun11551968,anf_fun11727572,_plus14) {
var $z76277628 = D;
var $f76337634 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11767596,anf_arg11817623):R.ffi.throwNonFunApp(L[708],_plus14,[anf_arg11767596,anf_arg11817623]);
};
try {
if(--R.GAS > 0) {
$z76277628 = $f76337634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76337634,
"from":L[708]});
}
} catch($e76257626) {
if(R.isCont($e76257626)) {
var $ss76297630 = {"from":L[708],
"go":function(anf_arg11827635) {
return $Hanf_arg24417636(anf_arg11827635,INDENT7747,anf_arg11717558,anf_fun11551968,anf_fun11727572,_plus14);
}};
$e76257626.stack[R.EXN_STACKHEIGHT++] = $ss76297630;
}
if(R.isPyretException($e76257626)) {
$e76257626.pyretStack.push(L[708]);
}
throw $e76257626;
}
var $ret76317632 = $Hanf_arg24417636($z76277628,INDENT7747,anf_arg11717558,anf_fun11551968,anf_fun11727572,_plus14);
++R.GAS;
return $ret76317632;
};
var $Hanf_arg24417636 = function(anf_arg11827635,INDENT7747,anf_arg11717558,anf_fun11551968,anf_fun11727572,_plus14) {
var $z76397640 = D;
var $f76457646 = function(_) {
return R.isFunction(anf_fun11727572)?anf_fun11727572.app(INDENT7747,anf_arg11827635):R.ffi.throwNonFunApp(L[714],anf_fun11727572,[INDENT7747,anf_arg11827635]);
};
try {
if(--R.GAS > 0) {
$z76397640 = $f76457646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76457646,
"from":L[714]});
}
} catch($e76377638) {
if(R.isCont($e76377638)) {
var $ss76417642 = {"from":L[714],
"go":function(anf_arg11837647) {
return $Hanf_arg24407648(anf_arg11837647,anf_arg11717558,anf_fun11551968,_plus14);
}};
$e76377638.stack[R.EXN_STACKHEIGHT++] = $ss76417642;
}
if(R.isPyretException($e76377638)) {
$e76377638.pyretStack.push(L[714]);
}
throw $e76377638;
}
var $ret76437644 = $Hanf_arg24407648($z76397640,anf_arg11717558,anf_fun11551968,_plus14);
++R.GAS;
return $ret76437644;
};
var $Hanf_arg24407648 = function(anf_arg11837647,anf_arg11717558,anf_fun11551968,_plus14) {
var $z76517652 = D;
var $f76577658 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11717558,anf_arg11837647):R.ffi.throwNonFunApp(L[704],_plus14,[anf_arg11717558,anf_arg11837647]);
};
try {
if(--R.GAS > 0) {
$z76517652 = $f76577658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76577658,
"from":L[704]});
}
} catch($e76497650) {
if(R.isCont($e76497650)) {
var $ss76537654 = {"from":L[704],
"go":function(anf_arg11847659) {
return $Hanf_arg24397660(anf_arg11847659,anf_fun11551968);
}};
$e76497650.stack[R.EXN_STACKHEIGHT++] = $ss76537654;
}
if(R.isPyretException($e76497650)) {
$e76497650.pyretStack.push(L[704]);
}
throw $e76497650;
}
var $ret76557656 = $Hanf_arg24397660($z76517652,anf_fun11551968);
++R.GAS;
return $ret76557656;
};
var $Hanf_arg24397660 = function(anf_arg11847659,anf_fun11551968) {
var $z76637664 = D;
var $f76697670 = function(_) {
return R.isFunction(anf_fun11551968)?anf_fun11551968.app(anf_arg11847659):R.ffi.throwNonFunApp(L[227],anf_fun11551968,[anf_arg11847659]);
};
try {
if(--R.GAS > 0) {
$z76637664 = $f76697670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76697670,
"from":L[227]});
}
} catch($e76617662) {
if(R.isCont($e76617662)) {
var $ss76657666 = {"from":L[227],
"go":function(ann_DASH_check_DASH_temp11547671) {
return $Hann_DASH_check_DASH_temp24387672(ann_DASH_check_DASH_temp11547671);
}};
$e76617662.stack[R.EXN_STACKHEIGHT++] = $ss76657666;
}
if(R.isPyretException($e76617662)) {
$e76617662.pyretStack.push(L[227]);
}
throw $e76617662;
}
var $ret76677668 = $Hann_DASH_check_DASH_temp24387672($z76637664);
++R.GAS;
return $ret76677668;
};
var $Hann_DASH_check_DASH_temp24387672 = function(ann_DASH_check_DASH_temp11547671) {
return ann_DASH_check_DASH_temp11547671;
};
var $Hanf_begin_app_dropped24371986 = function(anf_begin_app_dropped24291984,printer3111983,self3101985) {
var $z76757676 = D;
var $f76817682 = function(_) {
return R.isFunction(printer3111983)?printer3111983.app(("?")):R.ffi.throwNonFunApp(L[715],printer3111983,[("?")]);
};
try {
if(--R.GAS > 0) {
$z76757676 = $f76817682();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76817682,
"from":L[715]});
}
} catch($e76737674) {
if(R.isCont($e76737674)) {
var $ss76777678 = {"from":L[715],
"go":function(anf_begin_app_dropped24307683) {
return $Hanf_begin_app_dropped24367684(anf_begin_app_dropped24307683,printer3111983,self3101985);
}};
$e76737674.stack[R.EXN_STACKHEIGHT++] = $ss76777678;
}
if(R.isPyretException($e76737674)) {
$e76737674.pyretStack.push(L[715]);
}
throw $e76737674;
}
var $ret76797680 = $Hanf_begin_app_dropped24367684($z76757676,printer3111983,self3101985);
++R.GAS;
return $ret76797680;
};
var $Hanf_begin_app_dropped24367684 = function(anf_begin_app_dropped24307683,printer3111983,self3101985) {
var anf_bracket11497698 = G(self3101985,"consq",L[718]);
var anf_fun11507695 = G(anf_bracket11497698,"print-ugly-source",L[717]);
var $z76877688 = D;
var $f76937694 = function(_) {
return R.isFunction(anf_fun11507695)?anf_fun11507695.app(printer3111983):R.ffi.throwNonFunApp(L[716],anf_fun11507695,[printer3111983]);
};
try {
if(--R.GAS > 0) {
$z76877688 = $f76937694();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76937694,
"from":L[716]});
}
} catch($e76857686) {
if(R.isCont($e76857686)) {
var $ss76897690 = {"from":L[716],
"go":function(anf_begin_app_dropped24317696) {
return $Hanf_begin_app_dropped24357697(anf_begin_app_dropped24317696,printer3111983,self3101985);
}};
$e76857686.stack[R.EXN_STACKHEIGHT++] = $ss76897690;
}
if(R.isPyretException($e76857686)) {
$e76857686.pyretStack.push(L[716]);
}
throw $e76857686;
}
var $ret76917692 = $Hanf_begin_app_dropped24357697($z76877688,printer3111983,self3101985);
++R.GAS;
return $ret76917692;
};
var $Hanf_begin_app_dropped24357697 = function(anf_begin_app_dropped24317696,printer3111983,self3101985) {
var $z77017702 = D;
var $f77077708 = function(_) {
return R.isFunction(printer3111983)?printer3111983.app((":")):R.ffi.throwNonFunApp(L[719],printer3111983,[(":")]);
};
try {
if(--R.GAS > 0) {
$z77017702 = $f77077708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77077708,
"from":L[719]});
}
} catch($e76997700) {
if(R.isCont($e76997700)) {
var $ss77037704 = {"from":L[719],
"go":function(anf_begin_app_dropped24327709) {
return $Hanf_begin_app_dropped24347710(anf_begin_app_dropped24327709,printer3111983,self3101985);
}};
$e76997700.stack[R.EXN_STACKHEIGHT++] = $ss77037704;
}
if(R.isPyretException($e76997700)) {
$e76997700.pyretStack.push(L[719]);
}
throw $e76997700;
}
var $ret77057706 = $Hanf_begin_app_dropped24347710($z77017702,printer3111983,self3101985);
++R.GAS;
return $ret77057706;
};
var $Hanf_begin_app_dropped24347710 = function(anf_begin_app_dropped24327709,printer3111983,self3101985) {
var anf_bracket11517724 = G(self3101985,"altern",L[721]);
var anf_fun11527721 = G(anf_bracket11517724,"print-ugly-source",L[720]);
var $z77137714 = D;
var $f77197720 = function(_) {
return R.isFunction(anf_fun11527721)?anf_fun11527721.app(printer3111983):R.ffi.throwNonFunApp(L[231],anf_fun11527721,[printer3111983]);
};
try {
if(--R.GAS > 0) {
$z77137714 = $f77197720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77197720,
"from":L[231]});
}
} catch($e77117712) {
if(R.isCont($e77117712)) {
var $ss77157716 = {"from":L[231],
"go":function(ann_DASH_check_DASH_temp11467722) {
return $Hann_DASH_check_DASH_temp24337723(ann_DASH_check_DASH_temp11467722);
}};
$e77117712.stack[R.EXN_STACKHEIGHT++] = $ss77157716;
}
if(R.isPyretException($e77117712)) {
$e77117712.pyretStack.push(L[231]);
}
throw $e77117712;
}
var $ret77177718 = $Hann_DASH_check_DASH_temp24337723($z77137714);
++R.GAS;
return $ret77177718;
};
var $Hann_DASH_check_DASH_temp24337723 = function(ann_DASH_check_DASH_temp11467722) {
return ann_DASH_check_DASH_temp11467722;
};
var $Hanf_arg24282001 = function(anf_arg11341999,self2052000,_plus14,torepr18) {
var anf_arg11357735 = G(self2052000,"consq",L[36]);
var $z77277728 = D;
var $f77337734 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg11357735):R.ffi.throwNonFunApp(L[36],torepr18,[anf_arg11357735]);
};
try {
if(--R.GAS > 0) {
$z77277728 = $f77337734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77337734,
"from":L[36]});
}
} catch($e77257726) {
if(R.isCont($e77257726)) {
var $ss77297730 = {"from":L[36],
"go":function(anf_arg11367736) {
return $Hanf_arg24277737(anf_arg11367736,anf_arg11341999,self2052000,_plus14,torepr18);
}};
$e77257726.stack[R.EXN_STACKHEIGHT++] = $ss77297730;
}
if(R.isPyretException($e77257726)) {
$e77257726.pyretStack.push(L[36]);
}
throw $e77257726;
}
var $ret77317732 = $Hanf_arg24277737($z77277728,anf_arg11341999,self2052000,_plus14,torepr18);
++R.GAS;
return $ret77317732;
};
var $Hanf_arg24277737 = function(anf_arg11367736,anf_arg11341999,self2052000,_plus14,torepr18) {
var $z77407741 = D;
var $f77467747 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg11367736):R.ffi.throwNonFunApp(L[36],_plus14,[(", "),anf_arg11367736]);
};
try {
if(--R.GAS > 0) {
$z77407741 = $f77467747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77467747,
"from":L[36]});
}
} catch($e77387739) {
if(R.isCont($e77387739)) {
var $ss77427743 = {"from":L[36],
"go":function(anf_arg11377748) {
return $Hanf_arg24267749(anf_arg11377748,anf_arg11341999,self2052000,_plus14,torepr18);
}};
$e77387739.stack[R.EXN_STACKHEIGHT++] = $ss77427743;
}
if(R.isPyretException($e77387739)) {
$e77387739.pyretStack.push(L[36]);
}
throw $e77387739;
}
var $ret77447745 = $Hanf_arg24267749($z77407741,anf_arg11341999,self2052000,_plus14,torepr18);
++R.GAS;
return $ret77447745;
};
var $Hanf_arg24267749 = function(anf_arg11377748,anf_arg11341999,self2052000,_plus14,torepr18) {
var $z77527753 = D;
var $f77587759 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11341999,anf_arg11377748):R.ffi.throwNonFunApp(L[36],_plus14,[anf_arg11341999,anf_arg11377748]);
};
try {
if(--R.GAS > 0) {
$z77527753 = $f77587759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77587759,
"from":L[36]});
}
} catch($e77507751) {
if(R.isCont($e77507751)) {
var $ss77547755 = {"from":L[36],
"go":function(anf_arg11387760) {
return $Hanf_arg24257761(anf_arg11387760,self2052000,_plus14,torepr18);
}};
$e77507751.stack[R.EXN_STACKHEIGHT++] = $ss77547755;
}
if(R.isPyretException($e77507751)) {
$e77507751.pyretStack.push(L[36]);
}
throw $e77507751;
}
var $ret77567757 = $Hanf_arg24257761($z77527753,self2052000,_plus14,torepr18);
++R.GAS;
return $ret77567757;
};
var $Hanf_arg24257761 = function(anf_arg11387760,self2052000,_plus14,torepr18) {
var anf_arg11397772 = G(self2052000,"altern",L[36]);
var $z77647765 = D;
var $f77707771 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg11397772):R.ffi.throwNonFunApp(L[36],torepr18,[anf_arg11397772]);
};
try {
if(--R.GAS > 0) {
$z77647765 = $f77707771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77707771,
"from":L[36]});
}
} catch($e77627763) {
if(R.isCont($e77627763)) {
var $ss77667767 = {"from":L[36],
"go":function(anf_arg11407773) {
return $Hanf_arg24247774(anf_arg11407773,anf_arg11387760,_plus14);
}};
$e77627763.stack[R.EXN_STACKHEIGHT++] = $ss77667767;
}
if(R.isPyretException($e77627763)) {
$e77627763.pyretStack.push(L[36]);
}
throw $e77627763;
}
var $ret77687769 = $Hanf_arg24247774($z77647765,anf_arg11387760,_plus14);
++R.GAS;
return $ret77687769;
};
var $Hanf_arg24247774 = function(anf_arg11407773,anf_arg11387760,_plus14) {
var $z77777778 = D;
var $f77837784 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg11407773):R.ffi.throwNonFunApp(L[36],_plus14,[(", "),anf_arg11407773]);
};
try {
if(--R.GAS > 0) {
$z77777778 = $f77837784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77837784,
"from":L[36]});
}
} catch($e77757776) {
if(R.isCont($e77757776)) {
var $ss77797780 = {"from":L[36],
"go":function(anf_arg11417785) {
return $Hanf_arg24237786(anf_arg11417785,anf_arg11387760,_plus14);
}};
$e77757776.stack[R.EXN_STACKHEIGHT++] = $ss77797780;
}
if(R.isPyretException($e77757776)) {
$e77757776.pyretStack.push(L[36]);
}
throw $e77757776;
}
var $ret77817782 = $Hanf_arg24237786($z77777778,anf_arg11387760,_plus14);
++R.GAS;
return $ret77817782;
};
var $Hanf_arg24237786 = function(anf_arg11417785,anf_arg11387760,_plus14) {
var $z77897790 = D;
var $f77957796 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11387760,anf_arg11417785):R.ffi.throwNonFunApp(L[36],_plus14,[anf_arg11387760,anf_arg11417785]);
};
try {
if(--R.GAS > 0) {
$z77897790 = $f77957796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77957796,
"from":L[36]});
}
} catch($e77877788) {
if(R.isCont($e77877788)) {
var $ss77917792 = {"from":L[36],
"go":function(anf_arg11427797) {
return $Hanf_arg24227798(anf_arg11427797,_plus14);
}};
$e77877788.stack[R.EXN_STACKHEIGHT++] = $ss77917792;
}
if(R.isPyretException($e77877788)) {
$e77877788.pyretStack.push(L[36]);
}
throw $e77877788;
}
var $ret77937794 = $Hanf_arg24227798($z77897790,_plus14);
++R.GAS;
return $ret77937794;
};
var $Hanf_arg24227798 = function(anf_arg11427797,_plus14) {
var $z78017802 = D;
var $f78077808 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11427797,(")")):R.ffi.throwNonFunApp(L[36],_plus14,[anf_arg11427797,(")")]);
};
try {
if(--R.GAS > 0) {
$z78017802 = $f78077808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78077808,
"from":L[36]});
}
} catch($e77997800) {
if(R.isCont($e77997800)) {
var $ss78037804 = {"from":L[36],
"go":function(anf_arg11437809) {
return $Hanf_arg24217810(anf_arg11437809,_plus14);
}};
$e77997800.stack[R.EXN_STACKHEIGHT++] = $ss78037804;
}
if(R.isPyretException($e77997800)) {
$e77997800.pyretStack.push(L[36]);
}
throw $e77997800;
}
var $ret78057806 = $Hanf_arg24217810($z78017802,_plus14);
++R.GAS;
return $ret78057806;
};
var $Hanf_arg24217810 = function(anf_arg11437809,_plus14) {
var $z78137814 = D;
var $f78197820 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg11437809):R.ffi.throwNonFunApp(L[36],_plus14,[("("),anf_arg11437809]);
};
try {
if(--R.GAS > 0) {
$z78137814 = $f78197820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78197820,
"from":L[36]});
}
} catch($e78117812) {
if(R.isCont($e78117812)) {
var $ss78157816 = {"from":L[36],
"go":function(anf_arg11447821) {
return $Hanf_arg24207822(anf_arg11447821,_plus14);
}};
$e78117812.stack[R.EXN_STACKHEIGHT++] = $ss78157816;
}
if(R.isPyretException($e78117812)) {
$e78117812.pyretStack.push(L[36]);
}
throw $e78117812;
}
var $ret78177818 = $Hanf_arg24207822($z78137814,_plus14);
++R.GAS;
return $ret78177818;
};
var $Hanf_arg24207822 = function(anf_arg11447821,_plus14) {
var $z78257826 = D;
var $f78317832 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-ternary"),anf_arg11447821):R.ffi.throwNonFunApp(L[36],_plus14,[("j-ternary"),anf_arg11447821]);
};
try {
if(--R.GAS > 0) {
$z78257826 = $f78317832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78317832,
"from":L[36]});
}
} catch($e78237824) {
if(R.isCont($e78237824)) {
var $ss78277828 = {"from":L[36],
"go":function(ann_DASH_check_DASH_temp11327833) {
return $Hann_DASH_check_DASH_temp24197834(ann_DASH_check_DASH_temp11327833);
}};
$e78237824.stack[R.EXN_STACKHEIGHT++] = $ss78277828;
}
if(R.isPyretException($e78237824)) {
$e78237824.pyretStack.push(L[36]);
}
throw $e78237824;
}
var $ret78297830 = $Hann_DASH_check_DASH_temp24197834($z78257826);
++R.GAS;
return $ret78297830;
};
var $Hann_DASH_check_DASH_temp24197834 = function(ann_DASH_check_DASH_temp11327833) {
return ann_DASH_check_DASH_temp11327833;
};
var $Hcont_tail_arg24172018 = function(cont_tail_arg11292016,if_helper11192017) {
if(--R.GAS > 0) {
$z78357836 = R.isFunction(if_helper11192017)?if_helper11192017.app(cont_tail_arg11292016):R.ffi.throwNonFunApp(L[36],if_helper11192017,[cont_tail_arg11292016]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper11192017)?if_helper11192017.app(cont_tail_arg11292016):R.ffi.throwNonFunApp(L[36],if_helper11192017,[cont_tail_arg11292016]);
},
"from":L[36]});
}
++R.GAS;
return $z78357836;
};
var $Hcont_tail_arg24182033 = function(cont_tail_arg11242032,if_helper11192017) {
if(--R.GAS > 0) {
$z78377838 = R.isFunction(if_helper11192017)?if_helper11192017.app(cont_tail_arg11242032):R.ffi.throwNonFunApp(L[36],if_helper11192017,[cont_tail_arg11242032]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper11192017)?if_helper11192017.app(cont_tail_arg11242032):R.ffi.throwNonFunApp(L[36],if_helper11192017,[cont_tail_arg11242032]);
},
"from":L[36]});
}
++R.GAS;
return $z78377838;
};
var $Hanf_arg24162055 = function(anf_arg10952052,INDENT7747,PP123,anf_fun10922053,anf_fun10932054,self305741,_plus14) {
var anf_bracket10967852 = G(self305741,"obj",L[724]);
var anf_fun10977849 = G(anf_bracket10967852,"tosource",L[723]);
var $z78417842 = D;
var $f78477848 = function(_) {
return R.isFunction(anf_fun10977849)?anf_fun10977849.app():R.ffi.throwNonFunApp(L[722],anf_fun10977849,[]);
};
try {
if(--R.GAS > 0) {
$z78417842 = $f78477848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78477848,
"from":L[722]});
}
} catch($e78397840) {
if(R.isCont($e78397840)) {
var $ss78437844 = {"from":L[722],
"go":function(anf_arg10987850) {
return $Hanf_arg24157851(anf_arg10987850,INDENT7747,PP123,anf_arg10952052,anf_fun10922053,anf_fun10932054,self305741,_plus14);
}};
$e78397840.stack[R.EXN_STACKHEIGHT++] = $ss78437844;
}
if(R.isPyretException($e78397840)) {
$e78397840.pyretStack.push(L[722]);
}
throw $e78397840;
}
var $ret78457846 = $Hanf_arg24157851($z78417842,INDENT7747,PP123,anf_arg10952052,anf_fun10922053,anf_fun10932054,self305741,_plus14);
++R.GAS;
return $ret78457846;
};
var $Hanf_arg24157851 = function(anf_arg10987850,INDENT7747,PP123,anf_arg10952052,anf_fun10922053,anf_fun10932054,self305741,_plus14) {
var anf_fun10997863 = G(PP123,"str",L[727]);
var anf_arg11007864 = G(self305741,"meth",L[726]);
var $z78557856 = D;
var $f78617862 = function(_) {
return R.isFunction(anf_fun10997863)?anf_fun10997863.app(anf_arg11007864):R.ffi.throwNonFunApp(L[725],anf_fun10997863,[anf_arg11007864]);
};
try {
if(--R.GAS > 0) {
$z78557856 = $f78617862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78617862,
"from":L[725]});
}
} catch($e78537854) {
if(R.isCont($e78537854)) {
var $ss78577858 = {"from":L[725],
"go":function(anf_arg11017865) {
return $Hanf_arg24147866(anf_arg11017865,INDENT7747,PP123,anf_arg10952052,anf_arg10987850,anf_fun10922053,anf_fun10932054,self305741,_plus14);
}};
$e78537854.stack[R.EXN_STACKHEIGHT++] = $ss78577858;
}
if(R.isPyretException($e78537854)) {
$e78537854.pyretStack.push(L[725]);
}
throw $e78537854;
}
var $ret78597860 = $Hanf_arg24147866($z78557856,INDENT7747,PP123,anf_arg10952052,anf_arg10987850,anf_fun10922053,anf_fun10932054,self305741,_plus14);
++R.GAS;
return $ret78597860;
};
var $Hanf_arg24147866 = function(anf_arg11017865,INDENT7747,PP123,anf_arg10952052,anf_arg10987850,anf_fun10922053,anf_fun10932054,self305741,_plus14) {
var $z78697870 = D;
var $f78757876 = function(_) {
return R.isFunction(anf_fun10932054)?anf_fun10932054.app(INDENT7747,(0),anf_arg10952052,anf_arg10987850,anf_arg11017865):R.ffi.throwNonFunApp(L[728],anf_fun10932054,[INDENT7747,(0),anf_arg10952052,anf_arg10987850,anf_arg11017865]);
};
try {
if(--R.GAS > 0) {
$z78697870 = $f78757876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78757876,
"from":L[728]});
}
} catch($e78677868) {
if(R.isCont($e78677868)) {
var $ss78717872 = {"from":L[728],
"go":function(anf_arg11027877) {
return $Hanf_arg24137878(anf_arg11027877,INDENT7747,PP123,anf_fun10922053,self305741,_plus14);
}};
$e78677868.stack[R.EXN_STACKHEIGHT++] = $ss78717872;
}
if(R.isPyretException($e78677868)) {
$e78677868.pyretStack.push(L[728]);
}
throw $e78677868;
}
var $ret78737874 = $Hanf_arg24137878($z78697870,INDENT7747,PP123,anf_fun10922053,self305741,_plus14);
++R.GAS;
return $ret78737874;
};
var $Hanf_arg24137878 = function(anf_arg11027877,INDENT7747,PP123,anf_fun10922053,self305741,_plus14) {
var anf_fun11037893 = G(PP123,"parens",L[737]);
var anf_fun11047894 = G(PP123,"nest",L[736]);
var anf_fun11057895 = G(PP123,"separate",L[735]);
var anf_arg11067892 = G(PP123,"commabreak",L[734]);
var anf_bracket11077911 = G(self305741,"args",L[733]);
var anf_fun11087889 = G(anf_bracket11077911,"map",L[732]);
var anf_arg11117890 = R.makeFunction(function(f3067897) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[730],1,arguments);
}
var anf_fun11107908 = G(f3067897,"tosource",L[731]);
var $z79007901 = D;
var $f79067907 = function(_) {
return R.isFunction(anf_fun11107908)?anf_fun11107908.app():R.ffi.throwNonFunApp(L[730],anf_fun11107908,[]);
};
try {
if(--R.GAS > 0) {
$z79007901 = $f79067907();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79067907,
"from":L[730]});
}
} catch($e78987899) {
if(R.isCont($e78987899)) {
var $ss79027903 = {"from":L[730],
"go":function(ann_DASH_check_DASH_temp11097909) {
return $Hann_DASH_check_DASH_temp24067910(ann_DASH_check_DASH_temp11097909);
}};
$e78987899.stack[R.EXN_STACKHEIGHT++] = $ss79027903;
}
if(R.isPyretException($e78987899)) {
$e78987899.pyretStack.push(L[730]);
}
throw $e78987899;
}
var $ret79047905 = $Hann_DASH_check_DASH_temp24067910($z79007901);
++R.GAS;
return $ret79047905;
});
var $z78817882 = D;
var $f78877888 = function(_) {
return R.isFunction(anf_fun11087889)?anf_fun11087889.app(anf_arg11117890):R.ffi.throwNonFunApp(L[729],anf_fun11087889,[anf_arg11117890]);
};
try {
if(--R.GAS > 0) {
$z78817882 = $f78877888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78877888,
"from":L[729]});
}
} catch($e78797880) {
if(R.isCont($e78797880)) {
var $ss78837884 = {"from":L[729],
"go":function(anf_arg11127891) {
return $Hanf_arg24127896(anf_arg11127891,INDENT7747,anf_arg11027877,anf_arg11067892,anf_fun10922053,anf_fun11037893,anf_fun11047894,anf_fun11057895,_plus14);
}};
$e78797880.stack[R.EXN_STACKHEIGHT++] = $ss78837884;
}
if(R.isPyretException($e78797880)) {
$e78797880.pyretStack.push(L[729]);
}
throw $e78797880;
}
var $ret78857886 = $Hanf_arg24127896($z78817882,INDENT7747,anf_arg11027877,anf_arg11067892,anf_fun10922053,anf_fun11037893,anf_fun11047894,anf_fun11057895,_plus14);
++R.GAS;
return $ret78857886;
};
var $Hanf_arg24127896 = function(anf_arg11127891,INDENT7747,anf_arg11027877,anf_arg11067892,anf_fun10922053,anf_fun11037893,anf_fun11047894,anf_fun11057895,_plus14) {
var $z79147915 = D;
var $f79207921 = function(_) {
return R.isFunction(anf_fun11057895)?anf_fun11057895.app(anf_arg11067892,anf_arg11127891):R.ffi.throwNonFunApp(L[738],anf_fun11057895,[anf_arg11067892,anf_arg11127891]);
};
try {
if(--R.GAS > 0) {
$z79147915 = $f79207921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79207921,
"from":L[738]});
}
} catch($e79127913) {
if(R.isCont($e79127913)) {
var $ss79167917 = {"from":L[738],
"go":function(anf_arg11137922) {
return $Hanf_arg24117923(anf_arg11137922,INDENT7747,anf_arg11027877,anf_fun10922053,anf_fun11037893,anf_fun11047894,_plus14);
}};
$e79127913.stack[R.EXN_STACKHEIGHT++] = $ss79167917;
}
if(R.isPyretException($e79127913)) {
$e79127913.pyretStack.push(L[738]);
}
throw $e79127913;
}
var $ret79187919 = $Hanf_arg24117923($z79147915,INDENT7747,anf_arg11027877,anf_fun10922053,anf_fun11037893,anf_fun11047894,_plus14);
++R.GAS;
return $ret79187919;
};
var $Hanf_arg24117923 = function(anf_arg11137922,INDENT7747,anf_arg11027877,anf_fun10922053,anf_fun11037893,anf_fun11047894,_plus14) {
var $z79267927 = D;
var $f79327933 = function(_) {
return R.isFunction(anf_fun11047894)?anf_fun11047894.app(INDENT7747,anf_arg11137922):R.ffi.throwNonFunApp(L[739],anf_fun11047894,[INDENT7747,anf_arg11137922]);
};
try {
if(--R.GAS > 0) {
$z79267927 = $f79327933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79327933,
"from":L[739]});
}
} catch($e79247925) {
if(R.isCont($e79247925)) {
var $ss79287929 = {"from":L[739],
"go":function(anf_arg11147934) {
return $Hanf_arg24107935(anf_arg11147934,anf_arg11027877,anf_fun10922053,anf_fun11037893,_plus14);
}};
$e79247925.stack[R.EXN_STACKHEIGHT++] = $ss79287929;
}
if(R.isPyretException($e79247925)) {
$e79247925.pyretStack.push(L[739]);
}
throw $e79247925;
}
var $ret79307931 = $Hanf_arg24107935($z79267927,anf_arg11027877,anf_fun10922053,anf_fun11037893,_plus14);
++R.GAS;
return $ret79307931;
};
var $Hanf_arg24107935 = function(anf_arg11147934,anf_arg11027877,anf_fun10922053,anf_fun11037893,_plus14) {
var $z79387939 = D;
var $f79447945 = function(_) {
return R.isFunction(anf_fun11037893)?anf_fun11037893.app(anf_arg11147934):R.ffi.throwNonFunApp(L[740],anf_fun11037893,[anf_arg11147934]);
};
try {
if(--R.GAS > 0) {
$z79387939 = $f79447945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79447945,
"from":L[740]});
}
} catch($e79367937) {
if(R.isCont($e79367937)) {
var $ss79407941 = {"from":L[740],
"go":function(anf_arg11157946) {
return $Hanf_arg24097947(anf_arg11157946,anf_arg11027877,anf_fun10922053,_plus14);
}};
$e79367937.stack[R.EXN_STACKHEIGHT++] = $ss79407941;
}
if(R.isPyretException($e79367937)) {
$e79367937.pyretStack.push(L[740]);
}
throw $e79367937;
}
var $ret79427943 = $Hanf_arg24097947($z79387939,anf_arg11027877,anf_fun10922053,_plus14);
++R.GAS;
return $ret79427943;
};
var $Hanf_arg24097947 = function(anf_arg11157946,anf_arg11027877,anf_fun10922053,_plus14) {
var $z79507951 = D;
var $f79567957 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11027877,anf_arg11157946):R.ffi.throwNonFunApp(L[741],_plus14,[anf_arg11027877,anf_arg11157946]);
};
try {
if(--R.GAS > 0) {
$z79507951 = $f79567957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79567957,
"from":L[741]});
}
} catch($e79487949) {
if(R.isCont($e79487949)) {
var $ss79527953 = {"from":L[741],
"go":function(anf_arg11167958) {
return $Hanf_arg24087959(anf_arg11167958,anf_fun10922053);
}};
$e79487949.stack[R.EXN_STACKHEIGHT++] = $ss79527953;
}
if(R.isPyretException($e79487949)) {
$e79487949.pyretStack.push(L[741]);
}
throw $e79487949;
}
var $ret79547955 = $Hanf_arg24087959($z79507951,anf_fun10922053);
++R.GAS;
return $ret79547955;
};
var $Hanf_arg24087959 = function(anf_arg11167958,anf_fun10922053) {
var $z79627963 = D;
var $f79687969 = function(_) {
return R.isFunction(anf_fun10922053)?anf_fun10922053.app(anf_arg11167958):R.ffi.throwNonFunApp(L[239],anf_fun10922053,[anf_arg11167958]);
};
try {
if(--R.GAS > 0) {
$z79627963 = $f79687969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79687969,
"from":L[239]});
}
} catch($e79607961) {
if(R.isCont($e79607961)) {
var $ss79647965 = {"from":L[239],
"go":function(ann_DASH_check_DASH_temp10917970) {
return $Hann_DASH_check_DASH_temp24077971(ann_DASH_check_DASH_temp10917970);
}};
$e79607961.stack[R.EXN_STACKHEIGHT++] = $ss79647965;
}
if(R.isPyretException($e79607961)) {
$e79607961.pyretStack.push(L[239]);
}
throw $e79607961;
}
var $ret79667967 = $Hann_DASH_check_DASH_temp24077971($z79627963);
++R.GAS;
return $ret79667967;
};
var $Hann_DASH_check_DASH_temp24077971 = function(ann_DASH_check_DASH_temp10917970) {
return ann_DASH_check_DASH_temp10917970;
};
var $Hann_DASH_check_DASH_temp24067910 = function(ann_DASH_check_DASH_temp11097909) {
return ann_DASH_check_DASH_temp11097909;
};
var $Hanf_begin_app_dropped24052069 = function(anf_begin_app_dropped23872068,each4361,is_DASH_link2563,printer3032067,self302760,nothing16) {
var $z79747975 = D;
var $f79807981 = function(_) {
return R.isFunction(printer3032067)?printer3032067.app((".")):R.ffi.throwNonFunApp(L[742],printer3032067,[(".")]);
};
try {
if(--R.GAS > 0) {
$z79747975 = $f79807981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79807981,
"from":L[742]});
}
} catch($e79727973) {
if(R.isCont($e79727973)) {
var $ss79767977 = {"from":L[742],
"go":function(anf_begin_app_dropped23887982) {
return $Hanf_begin_app_dropped24047983(anf_begin_app_dropped23887982,each4361,is_DASH_link2563,printer3032067,self302760,nothing16);
}};
$e79727973.stack[R.EXN_STACKHEIGHT++] = $ss79767977;
}
if(R.isPyretException($e79727973)) {
$e79727973.pyretStack.push(L[742]);
}
throw $e79727973;
}
var $ret79787979 = $Hanf_begin_app_dropped24047983($z79747975,each4361,is_DASH_link2563,printer3032067,self302760,nothing16);
++R.GAS;
return $ret79787979;
};
var $Hanf_begin_app_dropped24047983 = function(anf_begin_app_dropped23887982,each4361,is_DASH_link2563,printer3032067,self302760,nothing16) {
var anf_arg10737994 = G(self302760,"meth",L[744]);
var $z79867987 = D;
var $f79927993 = function(_) {
return R.isFunction(printer3032067)?printer3032067.app(anf_arg10737994):R.ffi.throwNonFunApp(L[743],printer3032067,[anf_arg10737994]);
};
try {
if(--R.GAS > 0) {
$z79867987 = $f79927993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79927993,
"from":L[743]});
}
} catch($e79847985) {
if(R.isCont($e79847985)) {
var $ss79887989 = {"from":L[743],
"go":function(anf_begin_app_dropped23897995) {
return $Hanf_begin_app_dropped24037996(anf_begin_app_dropped23897995,each4361,is_DASH_link2563,printer3032067,self302760,nothing16);
}};
$e79847985.stack[R.EXN_STACKHEIGHT++] = $ss79887989;
}
if(R.isPyretException($e79847985)) {
$e79847985.pyretStack.push(L[743]);
}
throw $e79847985;
}
var $ret79907991 = $Hanf_begin_app_dropped24037996($z79867987,each4361,is_DASH_link2563,printer3032067,self302760,nothing16);
++R.GAS;
return $ret79907991;
};
var $Hanf_begin_app_dropped24037996 = function(anf_begin_app_dropped23897995,each4361,is_DASH_link2563,printer3032067,self302760,nothing16) {
var $z79998000 = D;
var $f80058006 = function(_) {
return R.isFunction(printer3032067)?printer3032067.app(("(")):R.ffi.throwNonFunApp(L[745],printer3032067,[("(")]);
};
try {
if(--R.GAS > 0) {
$z79998000 = $f80058006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80058006,
"from":L[745]});
}
} catch($e79977998) {
if(R.isCont($e79977998)) {
var $ss80018002 = {"from":L[745],
"go":function(anf_begin_app_dropped23908007) {
return $Hanf_begin_app_dropped24028008(anf_begin_app_dropped23908007,each4361,is_DASH_link2563,printer3032067,self302760,nothing16);
}};
$e79977998.stack[R.EXN_STACKHEIGHT++] = $ss80018002;
}
if(R.isPyretException($e79977998)) {
$e79977998.pyretStack.push(L[745]);
}
throw $e79977998;
}
var $ret80038004 = $Hanf_begin_app_dropped24028008($z79998000,each4361,is_DASH_link2563,printer3032067,self302760,nothing16);
++R.GAS;
return $ret80038004;
};
var $Hanf_begin_app_dropped24028008 = function(anf_begin_app_dropped23908007,each4361,is_DASH_link2563,printer3032067,self302760,nothing16) {
var anf_arg10748019 = G(self302760,"args",L[747]);
var $z80118012 = D;
var $f80178018 = function(_) {
return R.isFunction(is_DASH_link2563)?is_DASH_link2563.app(anf_arg10748019):R.ffi.throwNonFunApp(L[746],is_DASH_link2563,[anf_arg10748019]);
};
try {
if(--R.GAS > 0) {
$z80118012 = $f80178018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80178018,
"from":L[746]});
}
} catch($e80098010) {
if(R.isCont($e80098010)) {
var $ss80138014 = {"from":L[746],
"go":function(when_DASH_2008020) {
return $Hwhen_DASH_24018021(when_DASH_2008020,each4361,printer3032067,self302760,nothing16);
}};
$e80098010.stack[R.EXN_STACKHEIGHT++] = $ss80138014;
}
if(R.isPyretException($e80098010)) {
$e80098010.pyretStack.push(L[746]);
}
throw $e80098010;
}
var $ret80158016 = $Hwhen_DASH_24018021($z80118012,each4361,printer3032067,self302760,nothing16);
++R.GAS;
return $ret80158016;
};
var $Hwhen_DASH_24018021 = function(when_DASH_2008020,each4361,printer3032067,self302760,nothing16) {
var if_helper10758034 = R.makeFunction(function(if_helper_arg10768054) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[746],1,arguments);
}
if_helper_arg10768054;
var $z80578058 = D;
var $f80638064 = function(_) {
return R.isFunction(printer3032067)?printer3032067.app((")")):R.ffi.throwNonFunApp(L[243],printer3032067,[(")")]);
};
try {
if(--R.GAS > 0) {
$z80578058 = $f80638064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80638064,
"from":L[243]});
}
} catch($e80558056) {
if(R.isCont($e80558056)) {
var $ss80598060 = {"from":L[243],
"go":function(ann_DASH_check_DASH_temp10708065) {
return $Hann_DASH_check_DASH_temp23918066(ann_DASH_check_DASH_temp10708065);
}};
$e80558056.stack[R.EXN_STACKHEIGHT++] = $ss80598060;
}
if(R.isPyretException($e80558056)) {
$e80558056.pyretStack.push(L[243]);
}
throw $e80558056;
}
var $ret80618062 = $Hann_DASH_check_DASH_temp23918066($z80578058);
++R.GAS;
return $ret80618062;
});
var anf_if10798053 = R.isBoolean(when_DASH_2008020);
if(R.isPyretTrue(anf_if10798053)) {
if(R.isPyretTrue(when_DASH_2008020)) {
var anf_bracket10818037 = G(self302760,"args",L[751]);
var anf_bracket10828036 = G(anf_bracket10818037,"first",L[750]);
var anf_fun10838032 = G(anf_bracket10828036,"print-ugly-source",L[749]);
var $z80248025 = D;
var $f80308031 = function(_) {
return R.isFunction(anf_fun10838032)?anf_fun10838032.app(printer3032067):R.ffi.throwNonFunApp(L[748],anf_fun10838032,[printer3032067]);
};
try {
if(--R.GAS > 0) {
$z80248025 = $f80308031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80308031,
"from":L[748]});
}
} catch($e80228023) {
if(R.isCont($e80228023)) {
var $ss80268027 = {"from":L[748],
"go":function(anf_begin_app_dropped23928033) {
return $Hanf_begin_app_dropped23998035(anf_begin_app_dropped23928033,each4361,if_helper10758034,printer3032067,self302760,nothing16);
}};
$e80228023.stack[R.EXN_STACKHEIGHT++] = $ss80268027;
}
if(R.isPyretException($e80228023)) {
$e80228023.pyretStack.push(L[748]);
}
throw $e80228023;
}
var $ret80288029 = $Hanf_begin_app_dropped23998035($z80248025,each4361,if_helper10758034,printer3032067,self302760,nothing16);
++R.GAS;
return $ret80288029;
} else {
var $z80408041 = D;
var $f80468047 = function(_) {
return R.isFunction(if_helper10758034)?if_helper10758034.app(nothing16):R.ffi.throwNonFunApp(L[746],if_helper10758034,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z80408041 = $f80468047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80468047,
"from":L[746]});
}
} catch($e80388039) {
if(R.isCont($e80388039)) {
var $ss80428043 = {"from":L[746],
"go":function(cont_tail_app10808048) {
return $Hcont_tail_app24008049(cont_tail_app10808048);
}};
$e80388039.stack[R.EXN_STACKHEIGHT++] = $ss80428043;
}
if(R.isPyretException($e80388039)) {
$e80388039.pyretStack.push(L[746]);
}
throw $e80388039;
}
var $ret80448045 = $Hcont_tail_app24008049($z80408041);
++R.GAS;
return $ret80448045;
}
} else {
var cont_tail_arg10778052 = R.throwNonBooleanCondition(L[752],("when"),when_DASH_2008020);
if(--R.GAS > 0) {
$z80508051 = R.isFunction(if_helper10758034)?if_helper10758034.app(cont_tail_arg10778052):R.ffi.throwNonFunApp(L[752],if_helper10758034,[cont_tail_arg10778052]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper10758034)?if_helper10758034.app(cont_tail_arg10778052):R.ffi.throwNonFunApp(L[752],if_helper10758034,[cont_tail_arg10778052]);
},
"from":L[752]});
}
++R.GAS;
return $z80508051;
}
};
var $Hanf_begin_app_dropped23998035 = function(anf_begin_app_dropped23928033,each4361,if_helper10758034,printer3032067,self302760,nothing16) {
var anf_arg10868077 = R.makeFunction(function(a3048082) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[756],1,arguments);
}
var $z80858086 = D;
var $f80918092 = function(_) {
return R.isFunction(printer3032067)?printer3032067.app((",")):R.ffi.throwNonFunApp(L[757],printer3032067,[(",")]);
};
try {
if(--R.GAS > 0) {
$z80858086 = $f80918092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80918092,
"from":L[757]});
}
} catch($e80838084) {
if(R.isCont($e80838084)) {
var $ss80878088 = {"from":L[757],
"go":function(anf_begin_app_dropped23938093) {
return $Hanf_begin_app_dropped23958094(anf_begin_app_dropped23938093,a3048082,printer3032067);
}};
$e80838084.stack[R.EXN_STACKHEIGHT++] = $ss80878088;
}
if(R.isPyretException($e80838084)) {
$e80838084.pyretStack.push(L[757]);
}
throw $e80838084;
}
var $ret80898090 = $Hanf_begin_app_dropped23958094($z80858086,a3048082,printer3032067);
++R.GAS;
return $ret80898090;
});
var anf_bracket10878081 = G(self302760,"args",L[755]);
var anf_arg10888078 = G(anf_bracket10878081,"rest",L[754]);
var $z80698070 = D;
var $f80758076 = function(_) {
return R.isFunction(each4361)?each4361.app(anf_arg10868077,anf_arg10888078):R.ffi.throwNonFunApp(L[753],each4361,[anf_arg10868077,anf_arg10888078]);
};
try {
if(--R.GAS > 0) {
$z80698070 = $f80758076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80758076,
"from":L[753]});
}
} catch($e80678068) {
if(R.isCont($e80678068)) {
var $ss80718072 = {"from":L[753],
"go":function(anf_begin_app_dropped23968079) {
return $Hanf_begin_app_dropped23988080(anf_begin_app_dropped23968079,if_helper10758034,nothing16);
}};
$e80678068.stack[R.EXN_STACKHEIGHT++] = $ss80718072;
}
if(R.isPyretException($e80678068)) {
$e80678068.pyretStack.push(L[753]);
}
throw $e80678068;
}
var $ret80738074 = $Hanf_begin_app_dropped23988080($z80698070,if_helper10758034,nothing16);
++R.GAS;
return $ret80738074;
};
var $Hanf_begin_app_dropped23988080 = function(anf_begin_app_dropped23968079,if_helper10758034,nothing16) {
var $z80978098 = D;
var $f81038104 = function(_) {
return R.isFunction(if_helper10758034)?if_helper10758034.app(nothing16):R.ffi.throwNonFunApp(L[746],if_helper10758034,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z80978098 = $f81038104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81038104,
"from":L[746]});
}
} catch($e80958096) {
if(R.isCont($e80958096)) {
var $ss80998100 = {"from":L[746],
"go":function(cont_tail_app10898105) {
return $Hcont_tail_app23978106(cont_tail_app10898105);
}};
$e80958096.stack[R.EXN_STACKHEIGHT++] = $ss80998100;
}
if(R.isPyretException($e80958096)) {
$e80958096.pyretStack.push(L[746]);
}
throw $e80958096;
}
var $ret81018102 = $Hcont_tail_app23978106($z80978098);
++R.GAS;
return $ret81018102;
};
var $Hcont_tail_app23978106 = function(cont_tail_app10898105) {
return cont_tail_app10898105;
};
var $Hanf_begin_app_dropped23958094 = function(anf_begin_app_dropped23938093,a3048082,printer3032067) {
var anf_fun10858117 = G(a3048082,"print-ugly-source",L[758]);
var $z81098110 = D;
var $f81158116 = function(_) {
return R.isFunction(anf_fun10858117)?anf_fun10858117.app(printer3032067):R.ffi.throwNonFunApp(L[756],anf_fun10858117,[printer3032067]);
};
try {
if(--R.GAS > 0) {
$z81098110 = $f81158116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81158116,
"from":L[756]});
}
} catch($e81078108) {
if(R.isCont($e81078108)) {
var $ss81118112 = {"from":L[756],
"go":function(ann_DASH_check_DASH_temp10848118) {
return $Hann_DASH_check_DASH_temp23948119(ann_DASH_check_DASH_temp10848118);
}};
$e81078108.stack[R.EXN_STACKHEIGHT++] = $ss81118112;
}
if(R.isPyretException($e81078108)) {
$e81078108.pyretStack.push(L[756]);
}
throw $e81078108;
}
var $ret81138114 = $Hann_DASH_check_DASH_temp23948119($z81098110);
++R.GAS;
return $ret81138114;
};
var $Hann_DASH_check_DASH_temp23948119 = function(ann_DASH_check_DASH_temp10848118) {
return ann_DASH_check_DASH_temp10848118;
};
var $Hcont_tail_app24008049 = function(cont_tail_app10808048) {
return cont_tail_app10808048;
};
var $Hann_DASH_check_DASH_temp23918066 = function(ann_DASH_check_DASH_temp10708065) {
return ann_DASH_check_DASH_temp10708065;
};
var $Hanf_arg23862084 = function(anf_arg10582082,self1982083,_plus14,torepr18) {
var anf_arg10598130 = G(self1982083,"meth",L[37]);
var $z81228123 = D;
var $f81288129 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg10598130):R.ffi.throwNonFunApp(L[37],torepr18,[anf_arg10598130]);
};
try {
if(--R.GAS > 0) {
$z81228123 = $f81288129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81288129,
"from":L[37]});
}
} catch($e81208121) {
if(R.isCont($e81208121)) {
var $ss81248125 = {"from":L[37],
"go":function(anf_arg10608131) {
return $Hanf_arg23858132(anf_arg10608131,anf_arg10582082,self1982083,_plus14,torepr18);
}};
$e81208121.stack[R.EXN_STACKHEIGHT++] = $ss81248125;
}
if(R.isPyretException($e81208121)) {
$e81208121.pyretStack.push(L[37]);
}
throw $e81208121;
}
var $ret81268127 = $Hanf_arg23858132($z81228123,anf_arg10582082,self1982083,_plus14,torepr18);
++R.GAS;
return $ret81268127;
};
var $Hanf_arg23858132 = function(anf_arg10608131,anf_arg10582082,self1982083,_plus14,torepr18) {
var $z81358136 = D;
var $f81418142 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg10608131):R.ffi.throwNonFunApp(L[37],_plus14,[(", "),anf_arg10608131]);
};
try {
if(--R.GAS > 0) {
$z81358136 = $f81418142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81418142,
"from":L[37]});
}
} catch($e81338134) {
if(R.isCont($e81338134)) {
var $ss81378138 = {"from":L[37],
"go":function(anf_arg10618143) {
return $Hanf_arg23848144(anf_arg10618143,anf_arg10582082,self1982083,_plus14,torepr18);
}};
$e81338134.stack[R.EXN_STACKHEIGHT++] = $ss81378138;
}
if(R.isPyretException($e81338134)) {
$e81338134.pyretStack.push(L[37]);
}
throw $e81338134;
}
var $ret81398140 = $Hanf_arg23848144($z81358136,anf_arg10582082,self1982083,_plus14,torepr18);
++R.GAS;
return $ret81398140;
};
var $Hanf_arg23848144 = function(anf_arg10618143,anf_arg10582082,self1982083,_plus14,torepr18) {
var $z81478148 = D;
var $f81538154 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg10582082,anf_arg10618143):R.ffi.throwNonFunApp(L[37],_plus14,[anf_arg10582082,anf_arg10618143]);
};
try {
if(--R.GAS > 0) {
$z81478148 = $f81538154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81538154,
"from":L[37]});
}
} catch($e81458146) {
if(R.isCont($e81458146)) {
var $ss81498150 = {"from":L[37],
"go":function(anf_arg10628155) {
return $Hanf_arg23838156(anf_arg10628155,self1982083,_plus14,torepr18);
}};
$e81458146.stack[R.EXN_STACKHEIGHT++] = $ss81498150;
}
if(R.isPyretException($e81458146)) {
$e81458146.pyretStack.push(L[37]);
}
throw $e81458146;
}
var $ret81518152 = $Hanf_arg23838156($z81478148,self1982083,_plus14,torepr18);
++R.GAS;
return $ret81518152;
};
var $Hanf_arg23838156 = function(anf_arg10628155,self1982083,_plus14,torepr18) {
var anf_arg10638167 = G(self1982083,"args",L[37]);
var $z81598160 = D;
var $f81658166 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg10638167):R.ffi.throwNonFunApp(L[37],torepr18,[anf_arg10638167]);
};
try {
if(--R.GAS > 0) {
$z81598160 = $f81658166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81658166,
"from":L[37]});
}
} catch($e81578158) {
if(R.isCont($e81578158)) {
var $ss81618162 = {"from":L[37],
"go":function(anf_arg10648168) {
return $Hanf_arg23828169(anf_arg10648168,anf_arg10628155,_plus14);
}};
$e81578158.stack[R.EXN_STACKHEIGHT++] = $ss81618162;
}
if(R.isPyretException($e81578158)) {
$e81578158.pyretStack.push(L[37]);
}
throw $e81578158;
}
var $ret81638164 = $Hanf_arg23828169($z81598160,anf_arg10628155,_plus14);
++R.GAS;
return $ret81638164;
};
var $Hanf_arg23828169 = function(anf_arg10648168,anf_arg10628155,_plus14) {
var $z81728173 = D;
var $f81788179 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg10648168):R.ffi.throwNonFunApp(L[37],_plus14,[(", "),anf_arg10648168]);
};
try {
if(--R.GAS > 0) {
$z81728173 = $f81788179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81788179,
"from":L[37]});
}
} catch($e81708171) {
if(R.isCont($e81708171)) {
var $ss81748175 = {"from":L[37],
"go":function(anf_arg10658180) {
return $Hanf_arg23818181(anf_arg10658180,anf_arg10628155,_plus14);
}};
$e81708171.stack[R.EXN_STACKHEIGHT++] = $ss81748175;
}
if(R.isPyretException($e81708171)) {
$e81708171.pyretStack.push(L[37]);
}
throw $e81708171;
}
var $ret81768177 = $Hanf_arg23818181($z81728173,anf_arg10628155,_plus14);
++R.GAS;
return $ret81768177;
};
var $Hanf_arg23818181 = function(anf_arg10658180,anf_arg10628155,_plus14) {
var $z81848185 = D;
var $f81908191 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg10628155,anf_arg10658180):R.ffi.throwNonFunApp(L[37],_plus14,[anf_arg10628155,anf_arg10658180]);
};
try {
if(--R.GAS > 0) {
$z81848185 = $f81908191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81908191,
"from":L[37]});
}
} catch($e81828183) {
if(R.isCont($e81828183)) {
var $ss81868187 = {"from":L[37],
"go":function(anf_arg10668192) {
return $Hanf_arg23808193(anf_arg10668192,_plus14);
}};
$e81828183.stack[R.EXN_STACKHEIGHT++] = $ss81868187;
}
if(R.isPyretException($e81828183)) {
$e81828183.pyretStack.push(L[37]);
}
throw $e81828183;
}
var $ret81888189 = $Hanf_arg23808193($z81848185,_plus14);
++R.GAS;
return $ret81888189;
};
var $Hanf_arg23808193 = function(anf_arg10668192,_plus14) {
var $z81968197 = D;
var $f82028203 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg10668192,(")")):R.ffi.throwNonFunApp(L[37],_plus14,[anf_arg10668192,(")")]);
};
try {
if(--R.GAS > 0) {
$z81968197 = $f82028203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82028203,
"from":L[37]});
}
} catch($e81948195) {
if(R.isCont($e81948195)) {
var $ss81988199 = {"from":L[37],
"go":function(anf_arg10678204) {
return $Hanf_arg23798205(anf_arg10678204,_plus14);
}};
$e81948195.stack[R.EXN_STACKHEIGHT++] = $ss81988199;
}
if(R.isPyretException($e81948195)) {
$e81948195.pyretStack.push(L[37]);
}
throw $e81948195;
}
var $ret82008201 = $Hanf_arg23798205($z81968197,_plus14);
++R.GAS;
return $ret82008201;
};
var $Hanf_arg23798205 = function(anf_arg10678204,_plus14) {
var $z82088209 = D;
var $f82148215 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg10678204):R.ffi.throwNonFunApp(L[37],_plus14,[("("),anf_arg10678204]);
};
try {
if(--R.GAS > 0) {
$z82088209 = $f82148215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82148215,
"from":L[37]});
}
} catch($e82068207) {
if(R.isCont($e82068207)) {
var $ss82108211 = {"from":L[37],
"go":function(anf_arg10688216) {
return $Hanf_arg23788217(anf_arg10688216,_plus14);
}};
$e82068207.stack[R.EXN_STACKHEIGHT++] = $ss82108211;
}
if(R.isPyretException($e82068207)) {
$e82068207.pyretStack.push(L[37]);
}
throw $e82068207;
}
var $ret82128213 = $Hanf_arg23788217($z82088209,_plus14);
++R.GAS;
return $ret82128213;
};
var $Hanf_arg23788217 = function(anf_arg10688216,_plus14) {
var $z82208221 = D;
var $f82268227 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-method"),anf_arg10688216):R.ffi.throwNonFunApp(L[37],_plus14,[("j-method"),anf_arg10688216]);
};
try {
if(--R.GAS > 0) {
$z82208221 = $f82268227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82268227,
"from":L[37]});
}
} catch($e82188219) {
if(R.isCont($e82188219)) {
var $ss82228223 = {"from":L[37],
"go":function(ann_DASH_check_DASH_temp10568228) {
return $Hann_DASH_check_DASH_temp23778229(ann_DASH_check_DASH_temp10568228);
}};
$e82188219.stack[R.EXN_STACKHEIGHT++] = $ss82228223;
}
if(R.isPyretException($e82188219)) {
$e82188219.pyretStack.push(L[37]);
}
throw $e82188219;
}
var $ret82248225 = $Hann_DASH_check_DASH_temp23778229($z82208221);
++R.GAS;
return $ret82248225;
};
var $Hann_DASH_check_DASH_temp23778229 = function(ann_DASH_check_DASH_temp10568228) {
return ann_DASH_check_DASH_temp10568228;
};
var $Hcont_tail_arg23752101 = function(cont_tail_arg10532099,if_helper10432100) {
if(--R.GAS > 0) {
$z82308231 = R.isFunction(if_helper10432100)?if_helper10432100.app(cont_tail_arg10532099):R.ffi.throwNonFunApp(L[37],if_helper10432100,[cont_tail_arg10532099]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper10432100)?if_helper10432100.app(cont_tail_arg10532099):R.ffi.throwNonFunApp(L[37],if_helper10432100,[cont_tail_arg10532099]);
},
"from":L[37]});
}
++R.GAS;
return $z82308231;
};
var $Hcont_tail_arg23762116 = function(cont_tail_arg10482115,if_helper10432100) {
if(--R.GAS > 0) {
$z82328233 = R.isFunction(if_helper10432100)?if_helper10432100.app(cont_tail_arg10482115):R.ffi.throwNonFunApp(L[37],if_helper10432100,[cont_tail_arg10482115]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper10432100)?if_helper10432100.app(cont_tail_arg10482115):R.ffi.throwNonFunApp(L[37],if_helper10432100,[cont_tail_arg10482115]);
},
"from":L[37]});
}
++R.GAS;
return $z82328233;
};
var $Hanf_arg23742138 = function(anf_arg10262135,INDENT7747,PP123,anf_fun10232136,self2972137,_plus14) {
var anf_fun10278248 = G(PP123,"parens",L[767]);
var anf_fun10288249 = G(PP123,"nest",L[766]);
var anf_fun10298250 = G(PP123,"separate",L[765]);
var anf_arg10308247 = G(PP123,"commabreak",L[764]);
var anf_bracket10318266 = G(self2972137,"args",L[763]);
var anf_fun10328244 = G(anf_bracket10318266,"map",L[762]);
var anf_arg10358245 = R.makeFunction(function(f2988252) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[760],1,arguments);
}
var anf_fun10348263 = G(f2988252,"tosource",L[761]);
var $z82558256 = D;
var $f82618262 = function(_) {
return R.isFunction(anf_fun10348263)?anf_fun10348263.app():R.ffi.throwNonFunApp(L[760],anf_fun10348263,[]);
};
try {
if(--R.GAS > 0) {
$z82558256 = $f82618262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82618262,
"from":L[760]});
}
} catch($e82538254) {
if(R.isCont($e82538254)) {
var $ss82578258 = {"from":L[760],
"go":function(ann_DASH_check_DASH_temp10338264) {
return $Hann_DASH_check_DASH_temp23678265(ann_DASH_check_DASH_temp10338264);
}};
$e82538254.stack[R.EXN_STACKHEIGHT++] = $ss82578258;
}
if(R.isPyretException($e82538254)) {
$e82538254.pyretStack.push(L[760]);
}
throw $e82538254;
}
var $ret82598260 = $Hann_DASH_check_DASH_temp23678265($z82558256);
++R.GAS;
return $ret82598260;
});
var $z82368237 = D;
var $f82428243 = function(_) {
return R.isFunction(anf_fun10328244)?anf_fun10328244.app(anf_arg10358245):R.ffi.throwNonFunApp(L[759],anf_fun10328244,[anf_arg10358245]);
};
try {
if(--R.GAS > 0) {
$z82368237 = $f82428243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82428243,
"from":L[759]});
}
} catch($e82348235) {
if(R.isCont($e82348235)) {
var $ss82388239 = {"from":L[759],
"go":function(anf_arg10368246) {
return $Hanf_arg23738251(anf_arg10368246,INDENT7747,anf_arg10262135,anf_arg10308247,anf_fun10232136,anf_fun10278248,anf_fun10288249,anf_fun10298250,_plus14);
}};
$e82348235.stack[R.EXN_STACKHEIGHT++] = $ss82388239;
}
if(R.isPyretException($e82348235)) {
$e82348235.pyretStack.push(L[759]);
}
throw $e82348235;
}
var $ret82408241 = $Hanf_arg23738251($z82368237,INDENT7747,anf_arg10262135,anf_arg10308247,anf_fun10232136,anf_fun10278248,anf_fun10288249,anf_fun10298250,_plus14);
++R.GAS;
return $ret82408241;
};
var $Hanf_arg23738251 = function(anf_arg10368246,INDENT7747,anf_arg10262135,anf_arg10308247,anf_fun10232136,anf_fun10278248,anf_fun10288249,anf_fun10298250,_plus14) {
var $z82698270 = D;
var $f82758276 = function(_) {
return R.isFunction(anf_fun10298250)?anf_fun10298250.app(anf_arg10308247,anf_arg10368246):R.ffi.throwNonFunApp(L[768],anf_fun10298250,[anf_arg10308247,anf_arg10368246]);
};
try {
if(--R.GAS > 0) {
$z82698270 = $f82758276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82758276,
"from":L[768]});
}
} catch($e82678268) {
if(R.isCont($e82678268)) {
var $ss82718272 = {"from":L[768],
"go":function(anf_arg10378277) {
return $Hanf_arg23728278(anf_arg10378277,INDENT7747,anf_arg10262135,anf_fun10232136,anf_fun10278248,anf_fun10288249,_plus14);
}};
$e82678268.stack[R.EXN_STACKHEIGHT++] = $ss82718272;
}
if(R.isPyretException($e82678268)) {
$e82678268.pyretStack.push(L[768]);
}
throw $e82678268;
}
var $ret82738274 = $Hanf_arg23728278($z82698270,INDENT7747,anf_arg10262135,anf_fun10232136,anf_fun10278248,anf_fun10288249,_plus14);
++R.GAS;
return $ret82738274;
};
var $Hanf_arg23728278 = function(anf_arg10378277,INDENT7747,anf_arg10262135,anf_fun10232136,anf_fun10278248,anf_fun10288249,_plus14) {
var $z82818282 = D;
var $f82878288 = function(_) {
return R.isFunction(anf_fun10288249)?anf_fun10288249.app(INDENT7747,anf_arg10378277):R.ffi.throwNonFunApp(L[769],anf_fun10288249,[INDENT7747,anf_arg10378277]);
};
try {
if(--R.GAS > 0) {
$z82818282 = $f82878288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82878288,
"from":L[769]});
}
} catch($e82798280) {
if(R.isCont($e82798280)) {
var $ss82838284 = {"from":L[769],
"go":function(anf_arg10388289) {
return $Hanf_arg23718290(anf_arg10388289,anf_arg10262135,anf_fun10232136,anf_fun10278248,_plus14);
}};
$e82798280.stack[R.EXN_STACKHEIGHT++] = $ss82838284;
}
if(R.isPyretException($e82798280)) {
$e82798280.pyretStack.push(L[769]);
}
throw $e82798280;
}
var $ret82858286 = $Hanf_arg23718290($z82818282,anf_arg10262135,anf_fun10232136,anf_fun10278248,_plus14);
++R.GAS;
return $ret82858286;
};
var $Hanf_arg23718290 = function(anf_arg10388289,anf_arg10262135,anf_fun10232136,anf_fun10278248,_plus14) {
var $z82938294 = D;
var $f82998300 = function(_) {
return R.isFunction(anf_fun10278248)?anf_fun10278248.app(anf_arg10388289):R.ffi.throwNonFunApp(L[770],anf_fun10278248,[anf_arg10388289]);
};
try {
if(--R.GAS > 0) {
$z82938294 = $f82998300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82998300,
"from":L[770]});
}
} catch($e82918292) {
if(R.isCont($e82918292)) {
var $ss82958296 = {"from":L[770],
"go":function(anf_arg10398301) {
return $Hanf_arg23708302(anf_arg10398301,anf_arg10262135,anf_fun10232136,_plus14);
}};
$e82918292.stack[R.EXN_STACKHEIGHT++] = $ss82958296;
}
if(R.isPyretException($e82918292)) {
$e82918292.pyretStack.push(L[770]);
}
throw $e82918292;
}
var $ret82978298 = $Hanf_arg23708302($z82938294,anf_arg10262135,anf_fun10232136,_plus14);
++R.GAS;
return $ret82978298;
};
var $Hanf_arg23708302 = function(anf_arg10398301,anf_arg10262135,anf_fun10232136,_plus14) {
var $z83058306 = D;
var $f83118312 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg10262135,anf_arg10398301):R.ffi.throwNonFunApp(L[771],_plus14,[anf_arg10262135,anf_arg10398301]);
};
try {
if(--R.GAS > 0) {
$z83058306 = $f83118312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83118312,
"from":L[771]});
}
} catch($e83038304) {
if(R.isCont($e83038304)) {
var $ss83078308 = {"from":L[771],
"go":function(anf_arg10408313) {
return $Hanf_arg23698314(anf_arg10408313,anf_fun10232136);
}};
$e83038304.stack[R.EXN_STACKHEIGHT++] = $ss83078308;
}
if(R.isPyretException($e83038304)) {
$e83038304.pyretStack.push(L[771]);
}
throw $e83038304;
}
var $ret83098310 = $Hanf_arg23698314($z83058306,anf_fun10232136);
++R.GAS;
return $ret83098310;
};
var $Hanf_arg23698314 = function(anf_arg10408313,anf_fun10232136) {
var $z83178318 = D;
var $f83238324 = function(_) {
return R.isFunction(anf_fun10232136)?anf_fun10232136.app(anf_arg10408313):R.ffi.throwNonFunApp(L[251],anf_fun10232136,[anf_arg10408313]);
};
try {
if(--R.GAS > 0) {
$z83178318 = $f83238324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83238324,
"from":L[251]});
}
} catch($e83158316) {
if(R.isCont($e83158316)) {
var $ss83198320 = {"from":L[251],
"go":function(ann_DASH_check_DASH_temp10228325) {
return $Hann_DASH_check_DASH_temp23688326(ann_DASH_check_DASH_temp10228325);
}};
$e83158316.stack[R.EXN_STACKHEIGHT++] = $ss83198320;
}
if(R.isPyretException($e83158316)) {
$e83158316.pyretStack.push(L[251]);
}
throw $e83158316;
}
var $ret83218322 = $Hann_DASH_check_DASH_temp23688326($z83178318);
++R.GAS;
return $ret83218322;
};
var $Hann_DASH_check_DASH_temp23688326 = function(ann_DASH_check_DASH_temp10228325) {
return ann_DASH_check_DASH_temp10228325;
};
var $Hann_DASH_check_DASH_temp23678265 = function(ann_DASH_check_DASH_temp10338264) {
return ann_DASH_check_DASH_temp10338264;
};
var $Hanf_begin_app_dropped23662154 = function(anf_begin_app_dropped23522152,each4361,is_DASH_link2563,printer2952151,self2942153,nothing16) {
var $z83298330 = D;
var $f83358336 = function(_) {
return R.isFunction(printer2952151)?printer2952151.app(("(")):R.ffi.throwNonFunApp(L[772],printer2952151,[("(")]);
};
try {
if(--R.GAS > 0) {
$z83298330 = $f83358336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83358336,
"from":L[772]});
}
} catch($e83278328) {
if(R.isCont($e83278328)) {
var $ss83318332 = {"from":L[772],
"go":function(anf_begin_app_dropped23538337) {
return $Hanf_begin_app_dropped23658338(anf_begin_app_dropped23538337,each4361,is_DASH_link2563,printer2952151,self2942153,nothing16);
}};
$e83278328.stack[R.EXN_STACKHEIGHT++] = $ss83318332;
}
if(R.isPyretException($e83278328)) {
$e83278328.pyretStack.push(L[772]);
}
throw $e83278328;
}
var $ret83338334 = $Hanf_begin_app_dropped23658338($z83298330,each4361,is_DASH_link2563,printer2952151,self2942153,nothing16);
++R.GAS;
return $ret83338334;
};
var $Hanf_begin_app_dropped23658338 = function(anf_begin_app_dropped23538337,each4361,is_DASH_link2563,printer2952151,self2942153,nothing16) {
var anf_arg10058349 = G(self2942153,"args",L[774]);
var $z83418342 = D;
var $f83478348 = function(_) {
return R.isFunction(is_DASH_link2563)?is_DASH_link2563.app(anf_arg10058349):R.ffi.throwNonFunApp(L[773],is_DASH_link2563,[anf_arg10058349]);
};
try {
if(--R.GAS > 0) {
$z83418342 = $f83478348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83478348,
"from":L[773]});
}
} catch($e83398340) {
if(R.isCont($e83398340)) {
var $ss83438344 = {"from":L[773],
"go":function(when_DASH_1938350) {
return $Hwhen_DASH_23648351(when_DASH_1938350,each4361,printer2952151,self2942153,nothing16);
}};
$e83398340.stack[R.EXN_STACKHEIGHT++] = $ss83438344;
}
if(R.isPyretException($e83398340)) {
$e83398340.pyretStack.push(L[773]);
}
throw $e83398340;
}
var $ret83458346 = $Hwhen_DASH_23648351($z83418342,each4361,printer2952151,self2942153,nothing16);
++R.GAS;
return $ret83458346;
};
var $Hwhen_DASH_23648351 = function(when_DASH_1938350,each4361,printer2952151,self2942153,nothing16) {
var if_helper10068364 = R.makeFunction(function(if_helper_arg10078384) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[773],1,arguments);
}
if_helper_arg10078384;
var $z83878388 = D;
var $f83938394 = function(_) {
return R.isFunction(printer2952151)?printer2952151.app((")")):R.ffi.throwNonFunApp(L[255],printer2952151,[(")")]);
};
try {
if(--R.GAS > 0) {
$z83878388 = $f83938394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83938394,
"from":L[255]});
}
} catch($e83858386) {
if(R.isCont($e83858386)) {
var $ss83898390 = {"from":L[255],
"go":function(ann_DASH_check_DASH_temp10028395) {
return $Hann_DASH_check_DASH_temp23548396(ann_DASH_check_DASH_temp10028395);
}};
$e83858386.stack[R.EXN_STACKHEIGHT++] = $ss83898390;
}
if(R.isPyretException($e83858386)) {
$e83858386.pyretStack.push(L[255]);
}
throw $e83858386;
}
var $ret83918392 = $Hann_DASH_check_DASH_temp23548396($z83878388);
++R.GAS;
return $ret83918392;
});
var anf_if10108383 = R.isBoolean(when_DASH_1938350);
if(R.isPyretTrue(anf_if10108383)) {
if(R.isPyretTrue(when_DASH_1938350)) {
var anf_bracket10128367 = G(self2942153,"args",L[778]);
var anf_bracket10138366 = G(anf_bracket10128367,"first",L[777]);
var anf_fun10148362 = G(anf_bracket10138366,"print-ugly-source",L[776]);
var $z83548355 = D;
var $f83608361 = function(_) {
return R.isFunction(anf_fun10148362)?anf_fun10148362.app(printer2952151):R.ffi.throwNonFunApp(L[775],anf_fun10148362,[printer2952151]);
};
try {
if(--R.GAS > 0) {
$z83548355 = $f83608361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83608361,
"from":L[775]});
}
} catch($e83528353) {
if(R.isCont($e83528353)) {
var $ss83568357 = {"from":L[775],
"go":function(anf_begin_app_dropped23558363) {
return $Hanf_begin_app_dropped23628365(anf_begin_app_dropped23558363,each4361,if_helper10068364,printer2952151,self2942153,nothing16);
}};
$e83528353.stack[R.EXN_STACKHEIGHT++] = $ss83568357;
}
if(R.isPyretException($e83528353)) {
$e83528353.pyretStack.push(L[775]);
}
throw $e83528353;
}
var $ret83588359 = $Hanf_begin_app_dropped23628365($z83548355,each4361,if_helper10068364,printer2952151,self2942153,nothing16);
++R.GAS;
return $ret83588359;
} else {
var $z83708371 = D;
var $f83768377 = function(_) {
return R.isFunction(if_helper10068364)?if_helper10068364.app(nothing16):R.ffi.throwNonFunApp(L[773],if_helper10068364,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z83708371 = $f83768377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83768377,
"from":L[773]});
}
} catch($e83688369) {
if(R.isCont($e83688369)) {
var $ss83728373 = {"from":L[773],
"go":function(cont_tail_app10118378) {
return $Hcont_tail_app23638379(cont_tail_app10118378);
}};
$e83688369.stack[R.EXN_STACKHEIGHT++] = $ss83728373;
}
if(R.isPyretException($e83688369)) {
$e83688369.pyretStack.push(L[773]);
}
throw $e83688369;
}
var $ret83748375 = $Hcont_tail_app23638379($z83708371);
++R.GAS;
return $ret83748375;
}
} else {
var cont_tail_arg10088382 = R.throwNonBooleanCondition(L[779],("when"),when_DASH_1938350);
if(--R.GAS > 0) {
$z83808381 = R.isFunction(if_helper10068364)?if_helper10068364.app(cont_tail_arg10088382):R.ffi.throwNonFunApp(L[779],if_helper10068364,[cont_tail_arg10088382]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper10068364)?if_helper10068364.app(cont_tail_arg10088382):R.ffi.throwNonFunApp(L[779],if_helper10068364,[cont_tail_arg10088382]);
},
"from":L[779]});
}
++R.GAS;
return $z83808381;
}
};
var $Hanf_begin_app_dropped23628365 = function(anf_begin_app_dropped23558363,each4361,if_helper10068364,printer2952151,self2942153,nothing16) {
var anf_arg10178407 = R.makeFunction(function(a2968412) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[783],1,arguments);
}
var $z84158416 = D;
var $f84218422 = function(_) {
return R.isFunction(printer2952151)?printer2952151.app((",")):R.ffi.throwNonFunApp(L[784],printer2952151,[(",")]);
};
try {
if(--R.GAS > 0) {
$z84158416 = $f84218422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84218422,
"from":L[784]});
}
} catch($e84138414) {
if(R.isCont($e84138414)) {
var $ss84178418 = {"from":L[784],
"go":function(anf_begin_app_dropped23568423) {
return $Hanf_begin_app_dropped23588424(anf_begin_app_dropped23568423,a2968412,printer2952151);
}};
$e84138414.stack[R.EXN_STACKHEIGHT++] = $ss84178418;
}
if(R.isPyretException($e84138414)) {
$e84138414.pyretStack.push(L[784]);
}
throw $e84138414;
}
var $ret84198420 = $Hanf_begin_app_dropped23588424($z84158416,a2968412,printer2952151);
++R.GAS;
return $ret84198420;
});
var anf_bracket10188411 = G(self2942153,"args",L[782]);
var anf_arg10198408 = G(anf_bracket10188411,"rest",L[781]);
var $z83998400 = D;
var $f84058406 = function(_) {
return R.isFunction(each4361)?each4361.app(anf_arg10178407,anf_arg10198408):R.ffi.throwNonFunApp(L[780],each4361,[anf_arg10178407,anf_arg10198408]);
};
try {
if(--R.GAS > 0) {
$z83998400 = $f84058406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84058406,
"from":L[780]});
}
} catch($e83978398) {
if(R.isCont($e83978398)) {
var $ss84018402 = {"from":L[780],
"go":function(anf_begin_app_dropped23598409) {
return $Hanf_begin_app_dropped23618410(anf_begin_app_dropped23598409,if_helper10068364,nothing16);
}};
$e83978398.stack[R.EXN_STACKHEIGHT++] = $ss84018402;
}
if(R.isPyretException($e83978398)) {
$e83978398.pyretStack.push(L[780]);
}
throw $e83978398;
}
var $ret84038404 = $Hanf_begin_app_dropped23618410($z83998400,if_helper10068364,nothing16);
++R.GAS;
return $ret84038404;
};
var $Hanf_begin_app_dropped23618410 = function(anf_begin_app_dropped23598409,if_helper10068364,nothing16) {
var $z84278428 = D;
var $f84338434 = function(_) {
return R.isFunction(if_helper10068364)?if_helper10068364.app(nothing16):R.ffi.throwNonFunApp(L[773],if_helper10068364,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z84278428 = $f84338434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84338434,
"from":L[773]});
}
} catch($e84258426) {
if(R.isCont($e84258426)) {
var $ss84298430 = {"from":L[773],
"go":function(cont_tail_app10208435) {
return $Hcont_tail_app23608436(cont_tail_app10208435);
}};
$e84258426.stack[R.EXN_STACKHEIGHT++] = $ss84298430;
}
if(R.isPyretException($e84258426)) {
$e84258426.pyretStack.push(L[773]);
}
throw $e84258426;
}
var $ret84318432 = $Hcont_tail_app23608436($z84278428);
++R.GAS;
return $ret84318432;
};
var $Hcont_tail_app23608436 = function(cont_tail_app10208435) {
return cont_tail_app10208435;
};
var $Hanf_begin_app_dropped23588424 = function(anf_begin_app_dropped23568423,a2968412,printer2952151) {
var anf_fun10168447 = G(a2968412,"print-ugly-source",L[785]);
var $z84398440 = D;
var $f84458446 = function(_) {
return R.isFunction(anf_fun10168447)?anf_fun10168447.app(printer2952151):R.ffi.throwNonFunApp(L[783],anf_fun10168447,[printer2952151]);
};
try {
if(--R.GAS > 0) {
$z84398440 = $f84458446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84458446,
"from":L[783]});
}
} catch($e84378438) {
if(R.isCont($e84378438)) {
var $ss84418442 = {"from":L[783],
"go":function(ann_DASH_check_DASH_temp10158448) {
return $Hann_DASH_check_DASH_temp23578449(ann_DASH_check_DASH_temp10158448);
}};
$e84378438.stack[R.EXN_STACKHEIGHT++] = $ss84418442;
}
if(R.isPyretException($e84378438)) {
$e84378438.pyretStack.push(L[783]);
}
throw $e84378438;
}
var $ret84438444 = $Hann_DASH_check_DASH_temp23578449($z84398440);
++R.GAS;
return $ret84438444;
};
var $Hann_DASH_check_DASH_temp23578449 = function(ann_DASH_check_DASH_temp10158448) {
return ann_DASH_check_DASH_temp10158448;
};
var $Hcont_tail_app23638379 = function(cont_tail_app10118378) {
return cont_tail_app10118378;
};
var $Hann_DASH_check_DASH_temp23548396 = function(ann_DASH_check_DASH_temp10028395) {
return ann_DASH_check_DASH_temp10028395;
};
var $Hanf_arg23512169 = function(anf_arg9942167,self1912168,_plus14,torepr18) {
var anf_arg9958460 = G(self1912168,"args",L[38]);
var $z84528453 = D;
var $f84588459 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg9958460):R.ffi.throwNonFunApp(L[38],torepr18,[anf_arg9958460]);
};
try {
if(--R.GAS > 0) {
$z84528453 = $f84588459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84588459,
"from":L[38]});
}
} catch($e84508451) {
if(R.isCont($e84508451)) {
var $ss84548455 = {"from":L[38],
"go":function(anf_arg9968461) {
return $Hanf_arg23508462(anf_arg9968461,anf_arg9942167,_plus14);
}};
$e84508451.stack[R.EXN_STACKHEIGHT++] = $ss84548455;
}
if(R.isPyretException($e84508451)) {
$e84508451.pyretStack.push(L[38]);
}
throw $e84508451;
}
var $ret84568457 = $Hanf_arg23508462($z84528453,anf_arg9942167,_plus14);
++R.GAS;
return $ret84568457;
};
var $Hanf_arg23508462 = function(anf_arg9968461,anf_arg9942167,_plus14) {
var $z84658466 = D;
var $f84718472 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg9968461):R.ffi.throwNonFunApp(L[38],_plus14,[(", "),anf_arg9968461]);
};
try {
if(--R.GAS > 0) {
$z84658466 = $f84718472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84718472,
"from":L[38]});
}
} catch($e84638464) {
if(R.isCont($e84638464)) {
var $ss84678468 = {"from":L[38],
"go":function(anf_arg9978473) {
return $Hanf_arg23498474(anf_arg9978473,anf_arg9942167,_plus14);
}};
$e84638464.stack[R.EXN_STACKHEIGHT++] = $ss84678468;
}
if(R.isPyretException($e84638464)) {
$e84638464.pyretStack.push(L[38]);
}
throw $e84638464;
}
var $ret84698470 = $Hanf_arg23498474($z84658466,anf_arg9942167,_plus14);
++R.GAS;
return $ret84698470;
};
var $Hanf_arg23498474 = function(anf_arg9978473,anf_arg9942167,_plus14) {
var $z84778478 = D;
var $f84838484 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg9942167,anf_arg9978473):R.ffi.throwNonFunApp(L[38],_plus14,[anf_arg9942167,anf_arg9978473]);
};
try {
if(--R.GAS > 0) {
$z84778478 = $f84838484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84838484,
"from":L[38]});
}
} catch($e84758476) {
if(R.isCont($e84758476)) {
var $ss84798480 = {"from":L[38],
"go":function(anf_arg9988485) {
return $Hanf_arg23488486(anf_arg9988485,_plus14);
}};
$e84758476.stack[R.EXN_STACKHEIGHT++] = $ss84798480;
}
if(R.isPyretException($e84758476)) {
$e84758476.pyretStack.push(L[38]);
}
throw $e84758476;
}
var $ret84818482 = $Hanf_arg23488486($z84778478,_plus14);
++R.GAS;
return $ret84818482;
};
var $Hanf_arg23488486 = function(anf_arg9988485,_plus14) {
var $z84898490 = D;
var $f84958496 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg9988485,(")")):R.ffi.throwNonFunApp(L[38],_plus14,[anf_arg9988485,(")")]);
};
try {
if(--R.GAS > 0) {
$z84898490 = $f84958496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84958496,
"from":L[38]});
}
} catch($e84878488) {
if(R.isCont($e84878488)) {
var $ss84918492 = {"from":L[38],
"go":function(anf_arg9998497) {
return $Hanf_arg23478498(anf_arg9998497,_plus14);
}};
$e84878488.stack[R.EXN_STACKHEIGHT++] = $ss84918492;
}
if(R.isPyretException($e84878488)) {
$e84878488.pyretStack.push(L[38]);
}
throw $e84878488;
}
var $ret84938494 = $Hanf_arg23478498($z84898490,_plus14);
++R.GAS;
return $ret84938494;
};
var $Hanf_arg23478498 = function(anf_arg9998497,_plus14) {
var $z85018502 = D;
var $f85078508 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg9998497):R.ffi.throwNonFunApp(L[38],_plus14,[("("),anf_arg9998497]);
};
try {
if(--R.GAS > 0) {
$z85018502 = $f85078508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85078508,
"from":L[38]});
}
} catch($e84998500) {
if(R.isCont($e84998500)) {
var $ss85038504 = {"from":L[38],
"go":function(anf_arg10008509) {
return $Hanf_arg23468510(anf_arg10008509,_plus14);
}};
$e84998500.stack[R.EXN_STACKHEIGHT++] = $ss85038504;
}
if(R.isPyretException($e84998500)) {
$e84998500.pyretStack.push(L[38]);
}
throw $e84998500;
}
var $ret85058506 = $Hanf_arg23468510($z85018502,_plus14);
++R.GAS;
return $ret85058506;
};
var $Hanf_arg23468510 = function(anf_arg10008509,_plus14) {
var $z85138514 = D;
var $f85198520 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-app"),anf_arg10008509):R.ffi.throwNonFunApp(L[38],_plus14,[("j-app"),anf_arg10008509]);
};
try {
if(--R.GAS > 0) {
$z85138514 = $f85198520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85198520,
"from":L[38]});
}
} catch($e85118512) {
if(R.isCont($e85118512)) {
var $ss85158516 = {"from":L[38],
"go":function(ann_DASH_check_DASH_temp9928521) {
return $Hann_DASH_check_DASH_temp23458522(ann_DASH_check_DASH_temp9928521);
}};
$e85118512.stack[R.EXN_STACKHEIGHT++] = $ss85158516;
}
if(R.isPyretException($e85118512)) {
$e85118512.pyretStack.push(L[38]);
}
throw $e85118512;
}
var $ret85178518 = $Hann_DASH_check_DASH_temp23458522($z85138514);
++R.GAS;
return $ret85178518;
};
var $Hann_DASH_check_DASH_temp23458522 = function(ann_DASH_check_DASH_temp9928521) {
return ann_DASH_check_DASH_temp9928521;
};
var $Hcont_tail_arg23432185 = function(cont_tail_arg9892183,if_helper9802184) {
if(--R.GAS > 0) {
$z85238524 = R.isFunction(if_helper9802184)?if_helper9802184.app(cont_tail_arg9892183):R.ffi.throwNonFunApp(L[38],if_helper9802184,[cont_tail_arg9892183]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper9802184)?if_helper9802184.app(cont_tail_arg9892183):R.ffi.throwNonFunApp(L[38],if_helper9802184,[cont_tail_arg9892183]);
},
"from":L[38]});
}
++R.GAS;
return $z85238524;
};
var $Hcont_tail_arg23442200 = function(cont_tail_arg9852199,if_helper9802184) {
if(--R.GAS > 0) {
$z85258526 = R.isFunction(if_helper9802184)?if_helper9802184.app(cont_tail_arg9852199):R.ffi.throwNonFunApp(L[38],if_helper9802184,[cont_tail_arg9852199]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper9802184)?if_helper9802184.app(cont_tail_arg9852199):R.ffi.throwNonFunApp(L[38],if_helper9802184,[cont_tail_arg9852199]);
},
"from":L[38]});
}
++R.GAS;
return $z85258526;
};
var $Hanf_arg23422224 = function(anf_arg9562220,INDENT7747,PP123,anf_fun9522221,anf_fun9532222,self2892223,_plus14) {
var anf_arg9578540 = G(PP123,"lparen",L[792]);
var anf_arg9588541 = G(PP123,"commabreak",L[791]);
var anf_arg9598542 = G(PP123,"rparen",L[790]);
var anf_bracket9608544 = G(self2892223,"args",L[789]);
var anf_fun9618537 = G(anf_bracket9608544,"map",L[788]);
var anf_arg9628538 = G(PP123,"str",L[787]);
var $z85298530 = D;
var $f85358536 = function(_) {
return R.isFunction(anf_fun9618537)?anf_fun9618537.app(anf_arg9628538):R.ffi.throwNonFunApp(L[786],anf_fun9618537,[anf_arg9628538]);
};
try {
if(--R.GAS > 0) {
$z85298530 = $f85358536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85358536,
"from":L[786]});
}
} catch($e85278528) {
if(R.isCont($e85278528)) {
var $ss85318532 = {"from":L[786],
"go":function(anf_arg9638539) {
return $Hanf_arg23418543(anf_arg9638539,INDENT7747,PP123,anf_arg9562220,anf_arg9578540,anf_arg9588541,anf_arg9598542,anf_fun9522221,anf_fun9532222,self2892223,_plus14);
}};
$e85278528.stack[R.EXN_STACKHEIGHT++] = $ss85318532;
}
if(R.isPyretException($e85278528)) {
$e85278528.pyretStack.push(L[786]);
}
throw $e85278528;
}
var $ret85338534 = $Hanf_arg23418543($z85298530,INDENT7747,PP123,anf_arg9562220,anf_arg9578540,anf_arg9588541,anf_arg9598542,anf_fun9522221,anf_fun9532222,self2892223,_plus14);
++R.GAS;
return $ret85338534;
};
var $Hanf_arg23418543 = function(anf_arg9638539,INDENT7747,PP123,anf_arg9562220,anf_arg9578540,anf_arg9588541,anf_arg9598542,anf_fun9522221,anf_fun9532222,self2892223,_plus14) {
var $z85478548 = D;
var $f85538554 = function(_) {
return R.isFunction(anf_fun9532222)?anf_fun9532222.app(INDENT7747,(0),anf_arg9562220,anf_arg9578540,anf_arg9588541,anf_arg9598542,anf_arg9638539):R.ffi.throwNonFunApp(L[793],anf_fun9532222,[INDENT7747,(0),anf_arg9562220,anf_arg9578540,anf_arg9588541,anf_arg9598542,anf_arg9638539]);
};
try {
if(--R.GAS > 0) {
$z85478548 = $f85538554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85538554,
"from":L[793]});
}
} catch($e85458546) {
if(R.isCont($e85458546)) {
var $ss85498550 = {"from":L[793],
"go":function(anf_arg9648555) {
return $Hanf_arg23408556(anf_arg9648555,INDENT7747,PP123,anf_fun9522221,self2892223,_plus14);
}};
$e85458546.stack[R.EXN_STACKHEIGHT++] = $ss85498550;
}
if(R.isPyretException($e85458546)) {
$e85458546.pyretStack.push(L[793]);
}
throw $e85458546;
}
var $ret85518552 = $Hanf_arg23408556($z85478548,INDENT7747,PP123,anf_fun9522221,self2892223,_plus14);
++R.GAS;
return $ret85518552;
};
var $Hanf_arg23408556 = function(anf_arg9648555,INDENT7747,PP123,anf_fun9522221,self2892223,_plus14) {
var $z85598560 = D;
var $f85658566 = function(_) {
return R.isFunction(anf_fun9522221)?anf_fun9522221.app(INDENT7747,anf_arg9648555):R.ffi.throwNonFunApp(L[794],anf_fun9522221,[INDENT7747,anf_arg9648555]);
};
try {
if(--R.GAS > 0) {
$z85598560 = $f85658566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85658566,
"from":L[794]});
}
} catch($e85578558) {
if(R.isCont($e85578558)) {
var $ss85618562 = {"from":L[794],
"go":function(arglist2908567) {
return $Harglist23398568(arglist2908567,INDENT7747,PP123,self2892223,_plus14);
}};
$e85578558.stack[R.EXN_STACKHEIGHT++] = $ss85618562;
}
if(R.isPyretException($e85578558)) {
$e85578558.pyretStack.push(L[794]);
}
throw $e85578558;
}
var $ret85638564 = $Harglist23398568($z85598560,INDENT7747,PP123,self2892223,_plus14);
++R.GAS;
return $ret85638564;
};
var $Harglist23398568 = function(arglist2908567,INDENT7747,PP123,self2892223,_plus14) {
var anf_fun9658581 = G(PP123,"group",L[797]);
var anf_fun9668579 = G(PP123,"str",L[796]);
var $z85718572 = D;
var $f85778578 = function(_) {
return R.isFunction(anf_fun9668579)?anf_fun9668579.app(("function")):R.ffi.throwNonFunApp(L[795],anf_fun9668579,[("function")]);
};
try {
if(--R.GAS > 0) {
$z85718572 = $f85778578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85778578,
"from":L[795]});
}
} catch($e85698570) {
if(R.isCont($e85698570)) {
var $ss85738574 = {"from":L[795],
"go":function(anf_arg9678580) {
return $Hanf_arg23388582(anf_arg9678580,INDENT7747,PP123,anf_fun9658581,arglist2908567,self2892223,_plus14);
}};
$e85698570.stack[R.EXN_STACKHEIGHT++] = $ss85738574;
}
if(R.isPyretException($e85698570)) {
$e85698570.pyretStack.push(L[795]);
}
throw $e85698570;
}
var $ret85758576 = $Hanf_arg23388582($z85718572,INDENT7747,PP123,anf_fun9658581,arglist2908567,self2892223,_plus14);
++R.GAS;
return $ret85758576;
};
var $Hanf_arg23388582 = function(anf_arg9678580,INDENT7747,PP123,anf_fun9658581,arglist2908567,self2892223,_plus14) {
var $z85858586 = D;
var $f85918592 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg9678580,arglist2908567):R.ffi.throwNonFunApp(L[798],_plus14,[anf_arg9678580,arglist2908567]);
};
try {
if(--R.GAS > 0) {
$z85858586 = $f85918592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85918592,
"from":L[798]});
}
} catch($e85838584) {
if(R.isCont($e85838584)) {
var $ss85878588 = {"from":L[798],
"go":function(anf_arg9688593) {
return $Hanf_arg23378594(anf_arg9688593,INDENT7747,PP123,anf_fun9658581,self2892223,_plus14);
}};
$e85838584.stack[R.EXN_STACKHEIGHT++] = $ss85878588;
}
if(R.isPyretException($e85838584)) {
$e85838584.pyretStack.push(L[798]);
}
throw $e85838584;
}
var $ret85898590 = $Hanf_arg23378594($z85858586,INDENT7747,PP123,anf_fun9658581,self2892223,_plus14);
++R.GAS;
return $ret85898590;
};
var $Hanf_arg23378594 = function(anf_arg9688593,INDENT7747,PP123,anf_fun9658581,self2892223,_plus14) {
var $z85978598 = D;
var $f86038604 = function(_) {
return R.isFunction(anf_fun9658581)?anf_fun9658581.app(anf_arg9688593):R.ffi.throwNonFunApp(L[799],anf_fun9658581,[anf_arg9688593]);
};
try {
if(--R.GAS > 0) {
$z85978598 = $f86038604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86038604,
"from":L[799]});
}
} catch($e85958596) {
if(R.isCont($e85958596)) {
var $ss85998600 = {"from":L[799],
"go":function(header2918605) {
return $Hheader23368606(header2918605,INDENT7747,PP123,self2892223,_plus14);
}};
$e85958596.stack[R.EXN_STACKHEIGHT++] = $ss85998600;
}
if(R.isPyretException($e85958596)) {
$e85958596.pyretStack.push(L[799]);
}
throw $e85958596;
}
var $ret86018602 = $Hheader23368606($z85978598,INDENT7747,PP123,self2892223,_plus14);
++R.GAS;
return $ret86018602;
};
var $Hheader23368606 = function(header2918605,INDENT7747,PP123,self2892223,_plus14) {
var anf_fun9698619 = G(PP123,"surround",L[802]);
var anf_fun9708617 = G(PP123,"str",L[801]);
var $z86098610 = D;
var $f86158616 = function(_) {
return R.isFunction(anf_fun9708617)?anf_fun9708617.app((" {")):R.ffi.throwNonFunApp(L[800],anf_fun9708617,[(" {")]);
};
try {
if(--R.GAS > 0) {
$z86098610 = $f86158616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86158616,
"from":L[800]});
}
} catch($e86078608) {
if(R.isCont($e86078608)) {
var $ss86118612 = {"from":L[800],
"go":function(anf_arg9718618) {
return $Hanf_arg23358620(anf_arg9718618,INDENT7747,PP123,anf_fun9698619,header2918605,self2892223,_plus14);
}};
$e86078608.stack[R.EXN_STACKHEIGHT++] = $ss86118612;
}
if(R.isPyretException($e86078608)) {
$e86078608.pyretStack.push(L[800]);
}
throw $e86078608;
}
var $ret86138614 = $Hanf_arg23358620($z86098610,INDENT7747,PP123,anf_fun9698619,header2918605,self2892223,_plus14);
++R.GAS;
return $ret86138614;
};
var $Hanf_arg23358620 = function(anf_arg9718618,INDENT7747,PP123,anf_fun9698619,header2918605,self2892223,_plus14) {
var $z86238624 = D;
var $f86298630 = function(_) {
return R.isFunction(_plus14)?_plus14.app(header2918605,anf_arg9718618):R.ffi.throwNonFunApp(L[803],_plus14,[header2918605,anf_arg9718618]);
};
try {
if(--R.GAS > 0) {
$z86238624 = $f86298630();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86298630,
"from":L[803]});
}
} catch($e86218622) {
if(R.isCont($e86218622)) {
var $ss86258626 = {"from":L[803],
"go":function(anf_arg9728631) {
return $Hanf_arg23348632(anf_arg9728631,INDENT7747,PP123,anf_fun9698619,self2892223);
}};
$e86218622.stack[R.EXN_STACKHEIGHT++] = $ss86258626;
}
if(R.isPyretException($e86218622)) {
$e86218622.pyretStack.push(L[803]);
}
throw $e86218622;
}
var $ret86278628 = $Hanf_arg23348632($z86238624,INDENT7747,PP123,anf_fun9698619,self2892223);
++R.GAS;
return $ret86278628;
};
var $Hanf_arg23348632 = function(anf_arg9728631,INDENT7747,PP123,anf_fun9698619,self2892223) {
var anf_bracket9738646 = G(self2892223,"body",L[806]);
var anf_fun9748643 = G(anf_bracket9738646,"tosource",L[805]);
var $z86358636 = D;
var $f86418642 = function(_) {
return R.isFunction(anf_fun9748643)?anf_fun9748643.app():R.ffi.throwNonFunApp(L[804],anf_fun9748643,[]);
};
try {
if(--R.GAS > 0) {
$z86358636 = $f86418642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86418642,
"from":L[804]});
}
} catch($e86338634) {
if(R.isCont($e86338634)) {
var $ss86378638 = {"from":L[804],
"go":function(anf_arg9758644) {
return $Hanf_arg23338645(anf_arg9758644,INDENT7747,PP123,anf_arg9728631,anf_fun9698619);
}};
$e86338634.stack[R.EXN_STACKHEIGHT++] = $ss86378638;
}
if(R.isPyretException($e86338634)) {
$e86338634.pyretStack.push(L[804]);
}
throw $e86338634;
}
var $ret86398640 = $Hanf_arg23338645($z86358636,INDENT7747,PP123,anf_arg9728631,anf_fun9698619);
++R.GAS;
return $ret86398640;
};
var $Hanf_arg23338645 = function(anf_arg9758644,INDENT7747,PP123,anf_arg9728631,anf_fun9698619) {
var anf_fun9768657 = G(PP123,"str",L[808]);
var $z86498650 = D;
var $f86558656 = function(_) {
return R.isFunction(anf_fun9768657)?anf_fun9768657.app(("}")):R.ffi.throwNonFunApp(L[807],anf_fun9768657,[("}")]);
};
try {
if(--R.GAS > 0) {
$z86498650 = $f86558656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86558656,
"from":L[807]});
}
} catch($e86478648) {
if(R.isCont($e86478648)) {
var $ss86518652 = {"from":L[807],
"go":function(anf_arg9778658) {
return $Hanf_arg23328659(anf_arg9778658,INDENT7747,anf_arg9728631,anf_arg9758644,anf_fun9698619);
}};
$e86478648.stack[R.EXN_STACKHEIGHT++] = $ss86518652;
}
if(R.isPyretException($e86478648)) {
$e86478648.pyretStack.push(L[807]);
}
throw $e86478648;
}
var $ret86538654 = $Hanf_arg23328659($z86498650,INDENT7747,anf_arg9728631,anf_arg9758644,anf_fun9698619);
++R.GAS;
return $ret86538654;
};
var $Hanf_arg23328659 = function(anf_arg9778658,INDENT7747,anf_arg9728631,anf_arg9758644,anf_fun9698619) {
var $z86628663 = D;
var $f86688669 = function(_) {
return R.isFunction(anf_fun9698619)?anf_fun9698619.app(INDENT7747,(1),anf_arg9728631,anf_arg9758644,anf_arg9778658):R.ffi.throwNonFunApp(L[263],anf_fun9698619,[INDENT7747,(1),anf_arg9728631,anf_arg9758644,anf_arg9778658]);
};
try {
if(--R.GAS > 0) {
$z86628663 = $f86688669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86688669,
"from":L[263]});
}
} catch($e86608661) {
if(R.isCont($e86608661)) {
var $ss86648665 = {"from":L[263],
"go":function(ann_DASH_check_DASH_temp9518670) {
return $Hann_DASH_check_DASH_temp23318671(ann_DASH_check_DASH_temp9518670);
}};
$e86608661.stack[R.EXN_STACKHEIGHT++] = $ss86648665;
}
if(R.isPyretException($e86608661)) {
$e86608661.pyretStack.push(L[263]);
}
throw $e86608661;
}
var $ret86668667 = $Hann_DASH_check_DASH_temp23318671($z86628663);
++R.GAS;
return $ret86668667;
};
var $Hann_DASH_check_DASH_temp23318671 = function(ann_DASH_check_DASH_temp9518670) {
return ann_DASH_check_DASH_temp9518670;
};
var $Hanf_begin_app_dropped23302237 = function(anf_begin_app_dropped23212236,printer2882235,self287958) {
var anf_bracket9458685 = G(self287958,"args",L[811]);
var anf_fun9468682 = G(anf_bracket9458685,"join-str",L[810]);
var $z86748675 = D;
var $f86808681 = function(_) {
return R.isFunction(anf_fun9468682)?anf_fun9468682.app((",")):R.ffi.throwNonFunApp(L[809],anf_fun9468682,[(",")]);
};
try {
if(--R.GAS > 0) {
$z86748675 = $f86808681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86808681,
"from":L[809]});
}
} catch($e86728673) {
if(R.isCont($e86728673)) {
var $ss86768677 = {"from":L[809],
"go":function(anf_arg9478683) {
return $Hanf_arg23298684(anf_arg9478683,printer2882235,self287958);
}};
$e86728673.stack[R.EXN_STACKHEIGHT++] = $ss86768677;
}
if(R.isPyretException($e86728673)) {
$e86728673.pyretStack.push(L[809]);
}
throw $e86728673;
}
var $ret86788679 = $Hanf_arg23298684($z86748675,printer2882235,self287958);
++R.GAS;
return $ret86788679;
};
var $Hanf_arg23298684 = function(anf_arg9478683,printer2882235,self287958) {
var $z86888689 = D;
var $f86948695 = function(_) {
return R.isFunction(printer2882235)?printer2882235.app(anf_arg9478683):R.ffi.throwNonFunApp(L[812],printer2882235,[anf_arg9478683]);
};
try {
if(--R.GAS > 0) {
$z86888689 = $f86948695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86948695,
"from":L[812]});
}
} catch($e86868687) {
if(R.isCont($e86868687)) {
var $ss86908691 = {"from":L[812],
"go":function(anf_begin_app_dropped23228696) {
return $Hanf_begin_app_dropped23288697(anf_begin_app_dropped23228696,printer2882235,self287958);
}};
$e86868687.stack[R.EXN_STACKHEIGHT++] = $ss86908691;
}
if(R.isPyretException($e86868687)) {
$e86868687.pyretStack.push(L[812]);
}
throw $e86868687;
}
var $ret86928693 = $Hanf_begin_app_dropped23288697($z86888689,printer2882235,self287958);
++R.GAS;
return $ret86928693;
};
var $Hanf_begin_app_dropped23288697 = function(anf_begin_app_dropped23228696,printer2882235,self287958) {
var $z87008701 = D;
var $f87068707 = function(_) {
return R.isFunction(printer2882235)?printer2882235.app((") {\n")):R.ffi.throwNonFunApp(L[813],printer2882235,[(") {\n")]);
};
try {
if(--R.GAS > 0) {
$z87008701 = $f87068707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87068707,
"from":L[813]});
}
} catch($e86988699) {
if(R.isCont($e86988699)) {
var $ss87028703 = {"from":L[813],
"go":function(anf_begin_app_dropped23238708) {
return $Hanf_begin_app_dropped23278709(anf_begin_app_dropped23238708,printer2882235,self287958);
}};
$e86988699.stack[R.EXN_STACKHEIGHT++] = $ss87028703;
}
if(R.isPyretException($e86988699)) {
$e86988699.pyretStack.push(L[813]);
}
throw $e86988699;
}
var $ret87048705 = $Hanf_begin_app_dropped23278709($z87008701,printer2882235,self287958);
++R.GAS;
return $ret87048705;
};
var $Hanf_begin_app_dropped23278709 = function(anf_begin_app_dropped23238708,printer2882235,self287958) {
var anf_bracket9488723 = G(self287958,"body",L[816]);
var anf_fun9498720 = G(anf_bracket9488723,"print-ugly-source",L[815]);
var $z87128713 = D;
var $f87188719 = function(_) {
return R.isFunction(anf_fun9498720)?anf_fun9498720.app(printer2882235):R.ffi.throwNonFunApp(L[814],anf_fun9498720,[printer2882235]);
};
try {
if(--R.GAS > 0) {
$z87128713 = $f87188719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87188719,
"from":L[814]});
}
} catch($e87108711) {
if(R.isCont($e87108711)) {
var $ss87148715 = {"from":L[814],
"go":function(anf_begin_app_dropped23248721) {
return $Hanf_begin_app_dropped23268722(anf_begin_app_dropped23248721,printer2882235);
}};
$e87108711.stack[R.EXN_STACKHEIGHT++] = $ss87148715;
}
if(R.isPyretException($e87108711)) {
$e87108711.pyretStack.push(L[814]);
}
throw $e87108711;
}
var $ret87168717 = $Hanf_begin_app_dropped23268722($z87128713,printer2882235);
++R.GAS;
return $ret87168717;
};
var $Hanf_begin_app_dropped23268722 = function(anf_begin_app_dropped23248721,printer2882235) {
var $z87268727 = D;
var $f87328733 = function(_) {
return R.isFunction(printer2882235)?printer2882235.app(("\n}")):R.ffi.throwNonFunApp(L[265],printer2882235,[("\n}")]);
};
try {
if(--R.GAS > 0) {
$z87268727 = $f87328733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87328733,
"from":L[265]});
}
} catch($e87248725) {
if(R.isCont($e87248725)) {
var $ss87288729 = {"from":L[265],
"go":function(ann_DASH_check_DASH_temp9448734) {
return $Hann_DASH_check_DASH_temp23258735(ann_DASH_check_DASH_temp9448734);
}};
$e87248725.stack[R.EXN_STACKHEIGHT++] = $ss87288729;
}
if(R.isPyretException($e87248725)) {
$e87248725.pyretStack.push(L[265]);
}
throw $e87248725;
}
var $ret87308731 = $Hann_DASH_check_DASH_temp23258735($z87268727);
++R.GAS;
return $ret87308731;
};
var $Hann_DASH_check_DASH_temp23258735 = function(ann_DASH_check_DASH_temp9448734) {
return ann_DASH_check_DASH_temp9448734;
};
var $Hanf_arg23202251 = function(anf_arg9362249,self1852250,_plus14,torepr18) {
var anf_arg9378746 = G(self1852250,"body",L[39]);
var $z87388739 = D;
var $f87448745 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg9378746):R.ffi.throwNonFunApp(L[39],torepr18,[anf_arg9378746]);
};
try {
if(--R.GAS > 0) {
$z87388739 = $f87448745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87448745,
"from":L[39]});
}
} catch($e87368737) {
if(R.isCont($e87368737)) {
var $ss87408741 = {"from":L[39],
"go":function(anf_arg9388747) {
return $Hanf_arg23198748(anf_arg9388747,anf_arg9362249,_plus14);
}};
$e87368737.stack[R.EXN_STACKHEIGHT++] = $ss87408741;
}
if(R.isPyretException($e87368737)) {
$e87368737.pyretStack.push(L[39]);
}
throw $e87368737;
}
var $ret87428743 = $Hanf_arg23198748($z87388739,anf_arg9362249,_plus14);
++R.GAS;
return $ret87428743;
};
var $Hanf_arg23198748 = function(anf_arg9388747,anf_arg9362249,_plus14) {
var $z87518752 = D;
var $f87578758 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg9388747):R.ffi.throwNonFunApp(L[39],_plus14,[(", "),anf_arg9388747]);
};
try {
if(--R.GAS > 0) {
$z87518752 = $f87578758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87578758,
"from":L[39]});
}
} catch($e87498750) {
if(R.isCont($e87498750)) {
var $ss87538754 = {"from":L[39],
"go":function(anf_arg9398759) {
return $Hanf_arg23188760(anf_arg9398759,anf_arg9362249,_plus14);
}};
$e87498750.stack[R.EXN_STACKHEIGHT++] = $ss87538754;
}
if(R.isPyretException($e87498750)) {
$e87498750.pyretStack.push(L[39]);
}
throw $e87498750;
}
var $ret87558756 = $Hanf_arg23188760($z87518752,anf_arg9362249,_plus14);
++R.GAS;
return $ret87558756;
};
var $Hanf_arg23188760 = function(anf_arg9398759,anf_arg9362249,_plus14) {
var $z87638764 = D;
var $f87698770 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg9362249,anf_arg9398759):R.ffi.throwNonFunApp(L[39],_plus14,[anf_arg9362249,anf_arg9398759]);
};
try {
if(--R.GAS > 0) {
$z87638764 = $f87698770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87698770,
"from":L[39]});
}
} catch($e87618762) {
if(R.isCont($e87618762)) {
var $ss87658766 = {"from":L[39],
"go":function(anf_arg9408771) {
return $Hanf_arg23178772(anf_arg9408771,_plus14);
}};
$e87618762.stack[R.EXN_STACKHEIGHT++] = $ss87658766;
}
if(R.isPyretException($e87618762)) {
$e87618762.pyretStack.push(L[39]);
}
throw $e87618762;
}
var $ret87678768 = $Hanf_arg23178772($z87638764,_plus14);
++R.GAS;
return $ret87678768;
};
var $Hanf_arg23178772 = function(anf_arg9408771,_plus14) {
var $z87758776 = D;
var $f87818782 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg9408771,(")")):R.ffi.throwNonFunApp(L[39],_plus14,[anf_arg9408771,(")")]);
};
try {
if(--R.GAS > 0) {
$z87758776 = $f87818782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87818782,
"from":L[39]});
}
} catch($e87738774) {
if(R.isCont($e87738774)) {
var $ss87778778 = {"from":L[39],
"go":function(anf_arg9418783) {
return $Hanf_arg23168784(anf_arg9418783,_plus14);
}};
$e87738774.stack[R.EXN_STACKHEIGHT++] = $ss87778778;
}
if(R.isPyretException($e87738774)) {
$e87738774.pyretStack.push(L[39]);
}
throw $e87738774;
}
var $ret87798780 = $Hanf_arg23168784($z87758776,_plus14);
++R.GAS;
return $ret87798780;
};
var $Hanf_arg23168784 = function(anf_arg9418783,_plus14) {
var $z87878788 = D;
var $f87938794 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg9418783):R.ffi.throwNonFunApp(L[39],_plus14,[("("),anf_arg9418783]);
};
try {
if(--R.GAS > 0) {
$z87878788 = $f87938794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87938794,
"from":L[39]});
}
} catch($e87858786) {
if(R.isCont($e87858786)) {
var $ss87898790 = {"from":L[39],
"go":function(anf_arg9428795) {
return $Hanf_arg23158796(anf_arg9428795,_plus14);
}};
$e87858786.stack[R.EXN_STACKHEIGHT++] = $ss87898790;
}
if(R.isPyretException($e87858786)) {
$e87858786.pyretStack.push(L[39]);
}
throw $e87858786;
}
var $ret87918792 = $Hanf_arg23158796($z87878788,_plus14);
++R.GAS;
return $ret87918792;
};
var $Hanf_arg23158796 = function(anf_arg9428795,_plus14) {
var $z87998800 = D;
var $f88058806 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-fun"),anf_arg9428795):R.ffi.throwNonFunApp(L[39],_plus14,[("j-fun"),anf_arg9428795]);
};
try {
if(--R.GAS > 0) {
$z87998800 = $f88058806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88058806,
"from":L[39]});
}
} catch($e87978798) {
if(R.isCont($e87978798)) {
var $ss88018802 = {"from":L[39],
"go":function(ann_DASH_check_DASH_temp9348807) {
return $Hann_DASH_check_DASH_temp23148808(ann_DASH_check_DASH_temp9348807);
}};
$e87978798.stack[R.EXN_STACKHEIGHT++] = $ss88018802;
}
if(R.isPyretException($e87978798)) {
$e87978798.pyretStack.push(L[39]);
}
throw $e87978798;
}
var $ret88038804 = $Hann_DASH_check_DASH_temp23148808($z87998800);
++R.GAS;
return $ret88038804;
};
var $Hann_DASH_check_DASH_temp23148808 = function(ann_DASH_check_DASH_temp9348807) {
return ann_DASH_check_DASH_temp9348807;
};
var $Hcont_tail_arg23122267 = function(cont_tail_arg9312265,if_helper9222266) {
if(--R.GAS > 0) {
$z88098810 = R.isFunction(if_helper9222266)?if_helper9222266.app(cont_tail_arg9312265):R.ffi.throwNonFunApp(L[39],if_helper9222266,[cont_tail_arg9312265]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper9222266)?if_helper9222266.app(cont_tail_arg9312265):R.ffi.throwNonFunApp(L[39],if_helper9222266,[cont_tail_arg9312265]);
},
"from":L[39]});
}
++R.GAS;
return $z88098810;
};
var $Hcont_tail_arg23132282 = function(cont_tail_arg9272281,if_helper9222266) {
if(--R.GAS > 0) {
$z88118812 = R.isFunction(if_helper9222266)?if_helper9222266.app(cont_tail_arg9272281):R.ffi.throwNonFunApp(L[39],if_helper9222266,[cont_tail_arg9272281]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper9222266)?if_helper9222266.app(cont_tail_arg9272281):R.ffi.throwNonFunApp(L[39],if_helper9222266,[cont_tail_arg9272281]);
},
"from":L[39]});
}
++R.GAS;
return $z88118812;
};
var $Hanf_array_val23112304 = function(anf_array_val9122301,anf_fun9082302,anf_fun9092303,self284994) {
var anf_bracket9138826 = G(self284994,"op",L[819]);
var anf_fun9148823 = G(anf_bracket9138826,"tosource",L[818]);
var $z88158816 = D;
var $f88218822 = function(_) {
return R.isFunction(anf_fun9148823)?anf_fun9148823.app():R.ffi.throwNonFunApp(L[817],anf_fun9148823,[]);
};
try {
if(--R.GAS > 0) {
$z88158816 = $f88218822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88218822,
"from":L[817]});
}
} catch($e88138814) {
if(R.isCont($e88138814)) {
var $ss88178818 = {"from":L[817],
"go":function(anf_array_val9158824) {
return $Hanf_array_val23108825(anf_array_val9158824,anf_array_val9122301,anf_fun9082302,anf_fun9092303,self284994);
}};
$e88138814.stack[R.EXN_STACKHEIGHT++] = $ss88178818;
}
if(R.isPyretException($e88138814)) {
$e88138814.pyretStack.push(L[817]);
}
throw $e88138814;
}
var $ret88198820 = $Hanf_array_val23108825($z88158816,anf_array_val9122301,anf_fun9082302,anf_fun9092303,self284994);
++R.GAS;
return $ret88198820;
};
var $Hanf_array_val23108825 = function(anf_array_val9158824,anf_array_val9122301,anf_fun9082302,anf_fun9092303,self284994) {
var anf_bracket9168840 = G(self284994,"right",L[822]);
var anf_fun9178837 = G(anf_bracket9168840,"tosource",L[821]);
var $z88298830 = D;
var $f88358836 = function(_) {
return R.isFunction(anf_fun9178837)?anf_fun9178837.app():R.ffi.throwNonFunApp(L[820],anf_fun9178837,[]);
};
try {
if(--R.GAS > 0) {
$z88298830 = $f88358836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88358836,
"from":L[820]});
}
} catch($e88278828) {
if(R.isCont($e88278828)) {
var $ss88318832 = {"from":L[820],
"go":function(anf_array_val9188838) {
return $Hanf_array_val23098839(anf_array_val9188838,anf_array_val9122301,anf_array_val9158824,anf_fun9082302,anf_fun9092303);
}};
$e88278828.stack[R.EXN_STACKHEIGHT++] = $ss88318832;
}
if(R.isPyretException($e88278828)) {
$e88278828.pyretStack.push(L[820]);
}
throw $e88278828;
}
var $ret88338834 = $Hanf_array_val23098839($z88298830,anf_array_val9122301,anf_array_val9158824,anf_fun9082302,anf_fun9092303);
++R.GAS;
return $ret88338834;
};
var $Hanf_array_val23098839 = function(anf_array_val9188838,anf_array_val9122301,anf_array_val9158824,anf_fun9082302,anf_fun9092303) {
var $z88438844 = D;
var $f88498850 = function(_) {
return R.isFunction(anf_fun9092303)?anf_fun9092303.app([anf_array_val9122301,anf_array_val9158824,anf_array_val9188838]):R.ffi.throwNonFunApp(L[271],anf_fun9092303,[[anf_array_val9122301,anf_array_val9158824,anf_array_val9188838]]);
};
try {
if(--R.GAS > 0) {
$z88438844 = $f88498850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88498850,
"from":L[271]});
}
} catch($e88418842) {
if(R.isCont($e88418842)) {
var $ss88458846 = {"from":L[271],
"go":function(anf_arg9198851) {
return $Hanf_arg23088852(anf_arg9198851,anf_fun9082302);
}};
$e88418842.stack[R.EXN_STACKHEIGHT++] = $ss88458846;
}
if(R.isPyretException($e88418842)) {
$e88418842.pyretStack.push(L[271]);
}
throw $e88418842;
}
var $ret88478848 = $Hanf_arg23088852($z88438844,anf_fun9082302);
++R.GAS;
return $ret88478848;
};
var $Hanf_arg23088852 = function(anf_arg9198851,anf_fun9082302) {
var $z88558856 = D;
var $f88618862 = function(_) {
return R.isFunction(anf_fun9082302)?anf_fun9082302.app(anf_arg9198851):R.ffi.throwNonFunApp(L[273],anf_fun9082302,[anf_arg9198851]);
};
try {
if(--R.GAS > 0) {
$z88558856 = $f88618862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88618862,
"from":L[273]});
}
} catch($e88538854) {
if(R.isCont($e88538854)) {
var $ss88578858 = {"from":L[273],
"go":function(ann_DASH_check_DASH_temp9078863) {
return $Hann_DASH_check_DASH_temp23078864(ann_DASH_check_DASH_temp9078863);
}};
$e88538854.stack[R.EXN_STACKHEIGHT++] = $ss88578858;
}
if(R.isPyretException($e88538854)) {
$e88538854.pyretStack.push(L[273]);
}
throw $e88538854;
}
var $ret88598860 = $Hann_DASH_check_DASH_temp23078864($z88558856);
++R.GAS;
return $ret88598860;
};
var $Hann_DASH_check_DASH_temp23078864 = function(ann_DASH_check_DASH_temp9078863) {
return ann_DASH_check_DASH_temp9078863;
};
var $Hanf_begin_app_dropped23062320 = function(anf_begin_app_dropped22982318,printer2832317,self2822319) {
var $z88678868 = D;
var $f88738874 = function(_) {
return R.isFunction(printer2832317)?printer2832317.app((" ")):R.ffi.throwNonFunApp(L[823],printer2832317,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z88678868 = $f88738874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88738874,
"from":L[823]});
}
} catch($e88658866) {
if(R.isCont($e88658866)) {
var $ss88698870 = {"from":L[823],
"go":function(anf_begin_app_dropped22998875) {
return $Hanf_begin_app_dropped23058876(anf_begin_app_dropped22998875,printer2832317,self2822319);
}};
$e88658866.stack[R.EXN_STACKHEIGHT++] = $ss88698870;
}
if(R.isPyretException($e88658866)) {
$e88658866.pyretStack.push(L[823]);
}
throw $e88658866;
}
var $ret88718872 = $Hanf_begin_app_dropped23058876($z88678868,printer2832317,self2822319);
++R.GAS;
return $ret88718872;
};
var $Hanf_begin_app_dropped23058876 = function(anf_begin_app_dropped22998875,printer2832317,self2822319) {
var anf_bracket9028890 = G(self2822319,"op",L[826]);
var anf_fun9038887 = G(anf_bracket9028890,"print-ugly-source",L[825]);
var $z88798880 = D;
var $f88858886 = function(_) {
return R.isFunction(anf_fun9038887)?anf_fun9038887.app(printer2832317):R.ffi.throwNonFunApp(L[824],anf_fun9038887,[printer2832317]);
};
try {
if(--R.GAS > 0) {
$z88798880 = $f88858886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88858886,
"from":L[824]});
}
} catch($e88778878) {
if(R.isCont($e88778878)) {
var $ss88818882 = {"from":L[824],
"go":function(anf_begin_app_dropped23008888) {
return $Hanf_begin_app_dropped23048889(anf_begin_app_dropped23008888,printer2832317,self2822319);
}};
$e88778878.stack[R.EXN_STACKHEIGHT++] = $ss88818882;
}
if(R.isPyretException($e88778878)) {
$e88778878.pyretStack.push(L[824]);
}
throw $e88778878;
}
var $ret88838884 = $Hanf_begin_app_dropped23048889($z88798880,printer2832317,self2822319);
++R.GAS;
return $ret88838884;
};
var $Hanf_begin_app_dropped23048889 = function(anf_begin_app_dropped23008888,printer2832317,self2822319) {
var $z88938894 = D;
var $f88998900 = function(_) {
return R.isFunction(printer2832317)?printer2832317.app((" ")):R.ffi.throwNonFunApp(L[827],printer2832317,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z88938894 = $f88998900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88998900,
"from":L[827]});
}
} catch($e88918892) {
if(R.isCont($e88918892)) {
var $ss88958896 = {"from":L[827],
"go":function(anf_begin_app_dropped23018901) {
return $Hanf_begin_app_dropped23038902(anf_begin_app_dropped23018901,printer2832317,self2822319);
}};
$e88918892.stack[R.EXN_STACKHEIGHT++] = $ss88958896;
}
if(R.isPyretException($e88918892)) {
$e88918892.pyretStack.push(L[827]);
}
throw $e88918892;
}
var $ret88978898 = $Hanf_begin_app_dropped23038902($z88938894,printer2832317,self2822319);
++R.GAS;
return $ret88978898;
};
var $Hanf_begin_app_dropped23038902 = function(anf_begin_app_dropped23018901,printer2832317,self2822319) {
var anf_bracket9048916 = G(self2822319,"right",L[829]);
var anf_fun9058913 = G(anf_bracket9048916,"print-ugly-source",L[828]);
var $z89058906 = D;
var $f89118912 = function(_) {
return R.isFunction(anf_fun9058913)?anf_fun9058913.app(printer2832317):R.ffi.throwNonFunApp(L[277],anf_fun9058913,[printer2832317]);
};
try {
if(--R.GAS > 0) {
$z89058906 = $f89118912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89118912,
"from":L[277]});
}
} catch($e89038904) {
if(R.isCont($e89038904)) {
var $ss89078908 = {"from":L[277],
"go":function(ann_DASH_check_DASH_temp8998914) {
return $Hann_DASH_check_DASH_temp23028915(ann_DASH_check_DASH_temp8998914);
}};
$e89038904.stack[R.EXN_STACKHEIGHT++] = $ss89078908;
}
if(R.isPyretException($e89038904)) {
$e89038904.pyretStack.push(L[277]);
}
throw $e89038904;
}
var $ret89098910 = $Hann_DASH_check_DASH_temp23028915($z89058906);
++R.GAS;
return $ret89098910;
};
var $Hann_DASH_check_DASH_temp23028915 = function(ann_DASH_check_DASH_temp8998914) {
return ann_DASH_check_DASH_temp8998914;
};
var $Hanf_arg22972335 = function(anf_arg8872333,self1792334,_plus14,torepr18) {
var anf_arg8888927 = G(self1792334,"op",L[40]);
var $z89198920 = D;
var $f89258926 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg8888927):R.ffi.throwNonFunApp(L[40],torepr18,[anf_arg8888927]);
};
try {
if(--R.GAS > 0) {
$z89198920 = $f89258926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89258926,
"from":L[40]});
}
} catch($e89178918) {
if(R.isCont($e89178918)) {
var $ss89218922 = {"from":L[40],
"go":function(anf_arg8898928) {
return $Hanf_arg22968929(anf_arg8898928,anf_arg8872333,self1792334,_plus14,torepr18);
}};
$e89178918.stack[R.EXN_STACKHEIGHT++] = $ss89218922;
}
if(R.isPyretException($e89178918)) {
$e89178918.pyretStack.push(L[40]);
}
throw $e89178918;
}
var $ret89238924 = $Hanf_arg22968929($z89198920,anf_arg8872333,self1792334,_plus14,torepr18);
++R.GAS;
return $ret89238924;
};
var $Hanf_arg22968929 = function(anf_arg8898928,anf_arg8872333,self1792334,_plus14,torepr18) {
var $z89328933 = D;
var $f89388939 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg8898928):R.ffi.throwNonFunApp(L[40],_plus14,[(", "),anf_arg8898928]);
};
try {
if(--R.GAS > 0) {
$z89328933 = $f89388939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89388939,
"from":L[40]});
}
} catch($e89308931) {
if(R.isCont($e89308931)) {
var $ss89348935 = {"from":L[40],
"go":function(anf_arg8908940) {
return $Hanf_arg22958941(anf_arg8908940,anf_arg8872333,self1792334,_plus14,torepr18);
}};
$e89308931.stack[R.EXN_STACKHEIGHT++] = $ss89348935;
}
if(R.isPyretException($e89308931)) {
$e89308931.pyretStack.push(L[40]);
}
throw $e89308931;
}
var $ret89368937 = $Hanf_arg22958941($z89328933,anf_arg8872333,self1792334,_plus14,torepr18);
++R.GAS;
return $ret89368937;
};
var $Hanf_arg22958941 = function(anf_arg8908940,anf_arg8872333,self1792334,_plus14,torepr18) {
var $z89448945 = D;
var $f89508951 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg8872333,anf_arg8908940):R.ffi.throwNonFunApp(L[40],_plus14,[anf_arg8872333,anf_arg8908940]);
};
try {
if(--R.GAS > 0) {
$z89448945 = $f89508951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89508951,
"from":L[40]});
}
} catch($e89428943) {
if(R.isCont($e89428943)) {
var $ss89468947 = {"from":L[40],
"go":function(anf_arg8918952) {
return $Hanf_arg22948953(anf_arg8918952,self1792334,_plus14,torepr18);
}};
$e89428943.stack[R.EXN_STACKHEIGHT++] = $ss89468947;
}
if(R.isPyretException($e89428943)) {
$e89428943.pyretStack.push(L[40]);
}
throw $e89428943;
}
var $ret89488949 = $Hanf_arg22948953($z89448945,self1792334,_plus14,torepr18);
++R.GAS;
return $ret89488949;
};
var $Hanf_arg22948953 = function(anf_arg8918952,self1792334,_plus14,torepr18) {
var anf_arg8928964 = G(self1792334,"right",L[40]);
var $z89568957 = D;
var $f89628963 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg8928964):R.ffi.throwNonFunApp(L[40],torepr18,[anf_arg8928964]);
};
try {
if(--R.GAS > 0) {
$z89568957 = $f89628963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89628963,
"from":L[40]});
}
} catch($e89548955) {
if(R.isCont($e89548955)) {
var $ss89588959 = {"from":L[40],
"go":function(anf_arg8938965) {
return $Hanf_arg22938966(anf_arg8938965,anf_arg8918952,_plus14);
}};
$e89548955.stack[R.EXN_STACKHEIGHT++] = $ss89588959;
}
if(R.isPyretException($e89548955)) {
$e89548955.pyretStack.push(L[40]);
}
throw $e89548955;
}
var $ret89608961 = $Hanf_arg22938966($z89568957,anf_arg8918952,_plus14);
++R.GAS;
return $ret89608961;
};
var $Hanf_arg22938966 = function(anf_arg8938965,anf_arg8918952,_plus14) {
var $z89698970 = D;
var $f89758976 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg8938965):R.ffi.throwNonFunApp(L[40],_plus14,[(", "),anf_arg8938965]);
};
try {
if(--R.GAS > 0) {
$z89698970 = $f89758976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89758976,
"from":L[40]});
}
} catch($e89678968) {
if(R.isCont($e89678968)) {
var $ss89718972 = {"from":L[40],
"go":function(anf_arg8948977) {
return $Hanf_arg22928978(anf_arg8948977,anf_arg8918952,_plus14);
}};
$e89678968.stack[R.EXN_STACKHEIGHT++] = $ss89718972;
}
if(R.isPyretException($e89678968)) {
$e89678968.pyretStack.push(L[40]);
}
throw $e89678968;
}
var $ret89738974 = $Hanf_arg22928978($z89698970,anf_arg8918952,_plus14);
++R.GAS;
return $ret89738974;
};
var $Hanf_arg22928978 = function(anf_arg8948977,anf_arg8918952,_plus14) {
var $z89818982 = D;
var $f89878988 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg8918952,anf_arg8948977):R.ffi.throwNonFunApp(L[40],_plus14,[anf_arg8918952,anf_arg8948977]);
};
try {
if(--R.GAS > 0) {
$z89818982 = $f89878988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89878988,
"from":L[40]});
}
} catch($e89798980) {
if(R.isCont($e89798980)) {
var $ss89838984 = {"from":L[40],
"go":function(anf_arg8958989) {
return $Hanf_arg22918990(anf_arg8958989,_plus14);
}};
$e89798980.stack[R.EXN_STACKHEIGHT++] = $ss89838984;
}
if(R.isPyretException($e89798980)) {
$e89798980.pyretStack.push(L[40]);
}
throw $e89798980;
}
var $ret89858986 = $Hanf_arg22918990($z89818982,_plus14);
++R.GAS;
return $ret89858986;
};
var $Hanf_arg22918990 = function(anf_arg8958989,_plus14) {
var $z89938994 = D;
var $f89999000 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg8958989,(")")):R.ffi.throwNonFunApp(L[40],_plus14,[anf_arg8958989,(")")]);
};
try {
if(--R.GAS > 0) {
$z89938994 = $f89999000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89999000,
"from":L[40]});
}
} catch($e89918992) {
if(R.isCont($e89918992)) {
var $ss89958996 = {"from":L[40],
"go":function(anf_arg8969001) {
return $Hanf_arg22909002(anf_arg8969001,_plus14);
}};
$e89918992.stack[R.EXN_STACKHEIGHT++] = $ss89958996;
}
if(R.isPyretException($e89918992)) {
$e89918992.pyretStack.push(L[40]);
}
throw $e89918992;
}
var $ret89978998 = $Hanf_arg22909002($z89938994,_plus14);
++R.GAS;
return $ret89978998;
};
var $Hanf_arg22909002 = function(anf_arg8969001,_plus14) {
var $z90059006 = D;
var $f90119012 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg8969001):R.ffi.throwNonFunApp(L[40],_plus14,[("("),anf_arg8969001]);
};
try {
if(--R.GAS > 0) {
$z90059006 = $f90119012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90119012,
"from":L[40]});
}
} catch($e90039004) {
if(R.isCont($e90039004)) {
var $ss90079008 = {"from":L[40],
"go":function(anf_arg8979013) {
return $Hanf_arg22899014(anf_arg8979013,_plus14);
}};
$e90039004.stack[R.EXN_STACKHEIGHT++] = $ss90079008;
}
if(R.isPyretException($e90039004)) {
$e90039004.pyretStack.push(L[40]);
}
throw $e90039004;
}
var $ret90099010 = $Hanf_arg22899014($z90059006,_plus14);
++R.GAS;
return $ret90099010;
};
var $Hanf_arg22899014 = function(anf_arg8979013,_plus14) {
var $z90179018 = D;
var $f90239024 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-binop"),anf_arg8979013):R.ffi.throwNonFunApp(L[40],_plus14,[("j-binop"),anf_arg8979013]);
};
try {
if(--R.GAS > 0) {
$z90179018 = $f90239024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90239024,
"from":L[40]});
}
} catch($e90159016) {
if(R.isCont($e90159016)) {
var $ss90199020 = {"from":L[40],
"go":function(ann_DASH_check_DASH_temp8859025) {
return $Hann_DASH_check_DASH_temp22889026(ann_DASH_check_DASH_temp8859025);
}};
$e90159016.stack[R.EXN_STACKHEIGHT++] = $ss90199020;
}
if(R.isPyretException($e90159016)) {
$e90159016.pyretStack.push(L[40]);
}
throw $e90159016;
}
var $ret90219022 = $Hann_DASH_check_DASH_temp22889026($z90179018);
++R.GAS;
return $ret90219022;
};
var $Hann_DASH_check_DASH_temp22889026 = function(ann_DASH_check_DASH_temp8859025) {
return ann_DASH_check_DASH_temp8859025;
};
var $Hcont_tail_arg22862352 = function(cont_tail_arg8822350,if_helper8722351) {
if(--R.GAS > 0) {
$z90279028 = R.isFunction(if_helper8722351)?if_helper8722351.app(cont_tail_arg8822350):R.ffi.throwNonFunApp(L[40],if_helper8722351,[cont_tail_arg8822350]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper8722351)?if_helper8722351.app(cont_tail_arg8822350):R.ffi.throwNonFunApp(L[40],if_helper8722351,[cont_tail_arg8822350]);
},
"from":L[40]});
}
++R.GAS;
return $z90279028;
};
var $Hcont_tail_arg22872367 = function(cont_tail_arg8772366,if_helper8722351) {
if(--R.GAS > 0) {
$z90299030 = R.isFunction(if_helper8722351)?if_helper8722351.app(cont_tail_arg8772366):R.ffi.throwNonFunApp(L[40],if_helper8722351,[cont_tail_arg8772366]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper8722351)?if_helper8722351.app(cont_tail_arg8772366):R.ffi.throwNonFunApp(L[40],if_helper8722351,[cont_tail_arg8772366]);
},
"from":L[40]});
}
++R.GAS;
return $z90299030;
};
var $Hann_DASH_check_DASH_temp22852389 = function(ann_DASH_check_DASH_temp8432388) {
return ann_DASH_check_DASH_temp8432388;
};
var $Hanf_arg22842402 = function(anf_arg8652401,self2781060,_plus14) {
var anf_bracket8669044 = G(self2781060,"exp",L[832]);
var anf_fun8679041 = G(anf_bracket8669044,"tosource",L[831]);
var $z90339034 = D;
var $f90399040 = function(_) {
return R.isFunction(anf_fun8679041)?anf_fun8679041.app():R.ffi.throwNonFunApp(L[830],anf_fun8679041,[]);
};
try {
if(--R.GAS > 0) {
$z90339034 = $f90399040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90399040,
"from":L[830]});
}
} catch($e90319032) {
if(R.isCont($e90319032)) {
var $ss90359036 = {"from":L[830],
"go":function(anf_arg8689042) {
return $Hanf_arg22839043(anf_arg8689042,anf_arg8652401,_plus14);
}};
$e90319032.stack[R.EXN_STACKHEIGHT++] = $ss90359036;
}
if(R.isPyretException($e90319032)) {
$e90319032.pyretStack.push(L[830]);
}
throw $e90319032;
}
var $ret90379038 = $Hanf_arg22839043($z90339034,anf_arg8652401,_plus14);
++R.GAS;
return $ret90379038;
};
var $Hanf_arg22839043 = function(anf_arg8689042,anf_arg8652401,_plus14) {
var $z90479048 = D;
var $f90539054 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg8652401,anf_arg8689042):R.ffi.throwNonFunApp(L[282],_plus14,[anf_arg8652401,anf_arg8689042]);
};
try {
if(--R.GAS > 0) {
$z90479048 = $f90539054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90539054,
"from":L[282]});
}
} catch($e90459046) {
if(R.isCont($e90459046)) {
var $ss90499050 = {"from":L[282],
"go":function(ann_DASH_check_DASH_temp8629055) {
return $Hann_DASH_check_DASH_temp22829056(ann_DASH_check_DASH_temp8629055);
}};
$e90459046.stack[R.EXN_STACKHEIGHT++] = $ss90499050;
}
if(R.isPyretException($e90459046)) {
$e90459046.pyretStack.push(L[282]);
}
throw $e90459046;
}
var $ret90519052 = $Hann_DASH_check_DASH_temp22829056($z90479048);
++R.GAS;
return $ret90519052;
};
var $Hann_DASH_check_DASH_temp22829056 = function(ann_DASH_check_DASH_temp8629055) {
return ann_DASH_check_DASH_temp8629055;
};
var $Hanf_arg22812418 = function(anf_arg8562417,self2781060,_plus14) {
var anf_bracket8579070 = G(self2781060,"op",L[835]);
var anf_fun8589067 = G(anf_bracket8579070,"tosource",L[834]);
var $z90599060 = D;
var $f90659066 = function(_) {
return R.isFunction(anf_fun8589067)?anf_fun8589067.app():R.ffi.throwNonFunApp(L[833],anf_fun8589067,[]);
};
try {
if(--R.GAS > 0) {
$z90599060 = $f90659066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90659066,
"from":L[833]});
}
} catch($e90579058) {
if(R.isCont($e90579058)) {
var $ss90619062 = {"from":L[833],
"go":function(anf_arg8599068) {
return $Hanf_arg22809069(anf_arg8599068,anf_arg8562417,_plus14);
}};
$e90579058.stack[R.EXN_STACKHEIGHT++] = $ss90619062;
}
if(R.isPyretException($e90579058)) {
$e90579058.pyretStack.push(L[833]);
}
throw $e90579058;
}
var $ret90639064 = $Hanf_arg22809069($z90599060,anf_arg8562417,_plus14);
++R.GAS;
return $ret90639064;
};
var $Hanf_arg22809069 = function(anf_arg8599068,anf_arg8562417,_plus14) {
var $z90739074 = D;
var $f90799080 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg8562417,anf_arg8599068):R.ffi.throwNonFunApp(L[286],_plus14,[anf_arg8562417,anf_arg8599068]);
};
try {
if(--R.GAS > 0) {
$z90739074 = $f90799080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90799080,
"from":L[286]});
}
} catch($e90719072) {
if(R.isCont($e90719072)) {
var $ss90759076 = {"from":L[286],
"go":function(ann_DASH_check_DASH_temp8539081) {
return $Hann_DASH_check_DASH_temp22799082(ann_DASH_check_DASH_temp8539081);
}};
$e90719072.stack[R.EXN_STACKHEIGHT++] = $ss90759076;
}
if(R.isPyretException($e90719072)) {
$e90719072.pyretStack.push(L[286]);
}
throw $e90719072;
}
var $ret90779078 = $Hann_DASH_check_DASH_temp22799082($z90739074);
++R.GAS;
return $ret90779078;
};
var $Hann_DASH_check_DASH_temp22799082 = function(ann_DASH_check_DASH_temp8539081) {
return ann_DASH_check_DASH_temp8539081;
};
var $Hanf_arg22782432 = function(anf_arg8482431,self2781060,_plus14) {
var anf_bracket8499096 = G(self2781060,"op",L[838]);
var anf_fun8509093 = G(anf_bracket8499096,"tosource",L[837]);
var $z90859086 = D;
var $f90919092 = function(_) {
return R.isFunction(anf_fun8509093)?anf_fun8509093.app():R.ffi.throwNonFunApp(L[836],anf_fun8509093,[]);
};
try {
if(--R.GAS > 0) {
$z90859086 = $f90919092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90919092,
"from":L[836]});
}
} catch($e90839084) {
if(R.isCont($e90839084)) {
var $ss90879088 = {"from":L[836],
"go":function(anf_arg8519094) {
return $Hanf_arg22779095(anf_arg8519094,anf_arg8482431,_plus14);
}};
$e90839084.stack[R.EXN_STACKHEIGHT++] = $ss90879088;
}
if(R.isPyretException($e90839084)) {
$e90839084.pyretStack.push(L[836]);
}
throw $e90839084;
}
var $ret90899090 = $Hanf_arg22779095($z90859086,anf_arg8482431,_plus14);
++R.GAS;
return $ret90899090;
};
var $Hanf_arg22779095 = function(anf_arg8519094,anf_arg8482431,_plus14) {
var $z90999100 = D;
var $f91059106 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg8482431,anf_arg8519094):R.ffi.throwNonFunApp(L[290],_plus14,[anf_arg8482431,anf_arg8519094]);
};
try {
if(--R.GAS > 0) {
$z90999100 = $f91059106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91059106,
"from":L[290]});
}
} catch($e90979098) {
if(R.isCont($e90979098)) {
var $ss91019102 = {"from":L[290],
"go":function(ann_DASH_check_DASH_temp8459107) {
return $Hann_DASH_check_DASH_temp22769108(ann_DASH_check_DASH_temp8459107);
}};
$e90979098.stack[R.EXN_STACKHEIGHT++] = $ss91019102;
}
if(R.isPyretException($e90979098)) {
$e90979098.pyretStack.push(L[290]);
}
throw $e90979098;
}
var $ret91039104 = $Hann_DASH_check_DASH_temp22769108($z90999100);
++R.GAS;
return $ret91039104;
};
var $Hann_DASH_check_DASH_temp22769108 = function(ann_DASH_check_DASH_temp8459107) {
return ann_DASH_check_DASH_temp8459107;
};
var $Hann_DASH_check_DASH_temp22752449 = function(ann_DASH_check_DASH_temp8212448) {
return ann_DASH_check_DASH_temp8212448;
};
var $Hanf_begin_app_dropped22742464 = function(anf_begin_app_dropped22722462,printer2772461,self2762463) {
var anf_bracket8399122 = G(self2762463,"exp",L[840]);
var anf_fun8409119 = G(anf_bracket8399122,"print-ugly-source",L[839]);
var $z91119112 = D;
var $f91179118 = function(_) {
return R.isFunction(anf_fun8409119)?anf_fun8409119.app(printer2772461):R.ffi.throwNonFunApp(L[296],anf_fun8409119,[printer2772461]);
};
try {
if(--R.GAS > 0) {
$z91119112 = $f91179118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91179118,
"from":L[296]});
}
} catch($e91099110) {
if(R.isCont($e91099110)) {
var $ss91139114 = {"from":L[296],
"go":function(ann_DASH_check_DASH_temp8369120) {
return $Hann_DASH_check_DASH_temp22739121(ann_DASH_check_DASH_temp8369120);
}};
$e91099110.stack[R.EXN_STACKHEIGHT++] = $ss91139114;
}
if(R.isPyretException($e91099110)) {
$e91099110.pyretStack.push(L[296]);
}
throw $e91099110;
}
var $ret91159116 = $Hann_DASH_check_DASH_temp22739121($z91119112);
++R.GAS;
return $ret91159116;
};
var $Hann_DASH_check_DASH_temp22739121 = function(ann_DASH_check_DASH_temp8369120) {
return ann_DASH_check_DASH_temp8369120;
};
var $Hanf_begin_app_dropped22712480 = function(anf_begin_app_dropped22692479,printer2772461,self2762463) {
var anf_bracket8329136 = G(self2762463,"op",L[842]);
var anf_fun8339133 = G(anf_bracket8329136,"print-ugly-source",L[841]);
var $z91259126 = D;
var $f91319132 = function(_) {
return R.isFunction(anf_fun8339133)?anf_fun8339133.app(printer2772461):R.ffi.throwNonFunApp(L[300],anf_fun8339133,[printer2772461]);
};
try {
if(--R.GAS > 0) {
$z91259126 = $f91319132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91319132,
"from":L[300]});
}
} catch($e91239124) {
if(R.isCont($e91239124)) {
var $ss91279128 = {"from":L[300],
"go":function(ann_DASH_check_DASH_temp8299134) {
return $Hann_DASH_check_DASH_temp22709135(ann_DASH_check_DASH_temp8299134);
}};
$e91239124.stack[R.EXN_STACKHEIGHT++] = $ss91279128;
}
if(R.isPyretException($e91239124)) {
$e91239124.pyretStack.push(L[300]);
}
throw $e91239124;
}
var $ret91299130 = $Hann_DASH_check_DASH_temp22709135($z91259126);
++R.GAS;
return $ret91299130;
};
var $Hann_DASH_check_DASH_temp22709135 = function(ann_DASH_check_DASH_temp8299134) {
return ann_DASH_check_DASH_temp8299134;
};
var $Hanf_begin_app_dropped22682494 = function(anf_begin_app_dropped22662493,printer2772461,self2762463) {
var anf_bracket8269150 = G(self2762463,"op",L[844]);
var anf_fun8279147 = G(anf_bracket8269150,"print-ugly-source",L[843]);
var $z91399140 = D;
var $f91459146 = function(_) {
return R.isFunction(anf_fun8279147)?anf_fun8279147.app(printer2772461):R.ffi.throwNonFunApp(L[304],anf_fun8279147,[printer2772461]);
};
try {
if(--R.GAS > 0) {
$z91399140 = $f91459146();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91459146,
"from":L[304]});
}
} catch($e91379138) {
if(R.isCont($e91379138)) {
var $ss91419142 = {"from":L[304],
"go":function(ann_DASH_check_DASH_temp8239148) {
return $Hann_DASH_check_DASH_temp22679149(ann_DASH_check_DASH_temp8239148);
}};
$e91379138.stack[R.EXN_STACKHEIGHT++] = $ss91419142;
}
if(R.isPyretException($e91379138)) {
$e91379138.pyretStack.push(L[304]);
}
throw $e91379138;
}
var $ret91439144 = $Hann_DASH_check_DASH_temp22679149($z91399140);
++R.GAS;
return $ret91439144;
};
var $Hann_DASH_check_DASH_temp22679149 = function(ann_DASH_check_DASH_temp8239148) {
return ann_DASH_check_DASH_temp8239148;
};
var $Hanf_arg22652510 = function(anf_arg8132508,self1712509,_plus14,torepr18) {
var anf_arg8149161 = G(self1712509,"op",L[41]);
var $z91539154 = D;
var $f91599160 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg8149161):R.ffi.throwNonFunApp(L[41],torepr18,[anf_arg8149161]);
};
try {
if(--R.GAS > 0) {
$z91539154 = $f91599160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91599160,
"from":L[41]});
}
} catch($e91519152) {
if(R.isCont($e91519152)) {
var $ss91559156 = {"from":L[41],
"go":function(anf_arg8159162) {
return $Hanf_arg22649163(anf_arg8159162,anf_arg8132508,_plus14);
}};
$e91519152.stack[R.EXN_STACKHEIGHT++] = $ss91559156;
}
if(R.isPyretException($e91519152)) {
$e91519152.pyretStack.push(L[41]);
}
throw $e91519152;
}
var $ret91579158 = $Hanf_arg22649163($z91539154,anf_arg8132508,_plus14);
++R.GAS;
return $ret91579158;
};
var $Hanf_arg22649163 = function(anf_arg8159162,anf_arg8132508,_plus14) {
var $z91669167 = D;
var $f91729173 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg8159162):R.ffi.throwNonFunApp(L[41],_plus14,[(", "),anf_arg8159162]);
};
try {
if(--R.GAS > 0) {
$z91669167 = $f91729173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91729173,
"from":L[41]});
}
} catch($e91649165) {
if(R.isCont($e91649165)) {
var $ss91689169 = {"from":L[41],
"go":function(anf_arg8169174) {
return $Hanf_arg22639175(anf_arg8169174,anf_arg8132508,_plus14);
}};
$e91649165.stack[R.EXN_STACKHEIGHT++] = $ss91689169;
}
if(R.isPyretException($e91649165)) {
$e91649165.pyretStack.push(L[41]);
}
throw $e91649165;
}
var $ret91709171 = $Hanf_arg22639175($z91669167,anf_arg8132508,_plus14);
++R.GAS;
return $ret91709171;
};
var $Hanf_arg22639175 = function(anf_arg8169174,anf_arg8132508,_plus14) {
var $z91789179 = D;
var $f91849185 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg8132508,anf_arg8169174):R.ffi.throwNonFunApp(L[41],_plus14,[anf_arg8132508,anf_arg8169174]);
};
try {
if(--R.GAS > 0) {
$z91789179 = $f91849185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91849185,
"from":L[41]});
}
} catch($e91769177) {
if(R.isCont($e91769177)) {
var $ss91809181 = {"from":L[41],
"go":function(anf_arg8179186) {
return $Hanf_arg22629187(anf_arg8179186,_plus14);
}};
$e91769177.stack[R.EXN_STACKHEIGHT++] = $ss91809181;
}
if(R.isPyretException($e91769177)) {
$e91769177.pyretStack.push(L[41]);
}
throw $e91769177;
}
var $ret91829183 = $Hanf_arg22629187($z91789179,_plus14);
++R.GAS;
return $ret91829183;
};
var $Hanf_arg22629187 = function(anf_arg8179186,_plus14) {
var $z91909191 = D;
var $f91969197 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg8179186,(")")):R.ffi.throwNonFunApp(L[41],_plus14,[anf_arg8179186,(")")]);
};
try {
if(--R.GAS > 0) {
$z91909191 = $f91969197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91969197,
"from":L[41]});
}
} catch($e91889189) {
if(R.isCont($e91889189)) {
var $ss91929193 = {"from":L[41],
"go":function(anf_arg8189198) {
return $Hanf_arg22619199(anf_arg8189198,_plus14);
}};
$e91889189.stack[R.EXN_STACKHEIGHT++] = $ss91929193;
}
if(R.isPyretException($e91889189)) {
$e91889189.pyretStack.push(L[41]);
}
throw $e91889189;
}
var $ret91949195 = $Hanf_arg22619199($z91909191,_plus14);
++R.GAS;
return $ret91949195;
};
var $Hanf_arg22619199 = function(anf_arg8189198,_plus14) {
var $z92029203 = D;
var $f92089209 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg8189198):R.ffi.throwNonFunApp(L[41],_plus14,[("("),anf_arg8189198]);
};
try {
if(--R.GAS > 0) {
$z92029203 = $f92089209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92089209,
"from":L[41]});
}
} catch($e92009201) {
if(R.isCont($e92009201)) {
var $ss92049205 = {"from":L[41],
"go":function(anf_arg8199210) {
return $Hanf_arg22609211(anf_arg8199210,_plus14);
}};
$e92009201.stack[R.EXN_STACKHEIGHT++] = $ss92049205;
}
if(R.isPyretException($e92009201)) {
$e92009201.pyretStack.push(L[41]);
}
throw $e92009201;
}
var $ret92069207 = $Hanf_arg22609211($z92029203,_plus14);
++R.GAS;
return $ret92069207;
};
var $Hanf_arg22609211 = function(anf_arg8199210,_plus14) {
var $z92149215 = D;
var $f92209221 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-unop"),anf_arg8199210):R.ffi.throwNonFunApp(L[41],_plus14,[("j-unop"),anf_arg8199210]);
};
try {
if(--R.GAS > 0) {
$z92149215 = $f92209221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92209221,
"from":L[41]});
}
} catch($e92129213) {
if(R.isCont($e92129213)) {
var $ss92169217 = {"from":L[41],
"go":function(ann_DASH_check_DASH_temp8119222) {
return $Hann_DASH_check_DASH_temp22599223(ann_DASH_check_DASH_temp8119222);
}};
$e92129213.stack[R.EXN_STACKHEIGHT++] = $ss92169217;
}
if(R.isPyretException($e92129213)) {
$e92129213.pyretStack.push(L[41]);
}
throw $e92129213;
}
var $ret92189219 = $Hann_DASH_check_DASH_temp22599223($z92149215);
++R.GAS;
return $ret92189219;
};
var $Hann_DASH_check_DASH_temp22599223 = function(ann_DASH_check_DASH_temp8119222) {
return ann_DASH_check_DASH_temp8119222;
};
var $Hcont_tail_arg22572526 = function(cont_tail_arg8082524,if_helper7992525) {
if(--R.GAS > 0) {
$z92249225 = R.isFunction(if_helper7992525)?if_helper7992525.app(cont_tail_arg8082524):R.ffi.throwNonFunApp(L[41],if_helper7992525,[cont_tail_arg8082524]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7992525)?if_helper7992525.app(cont_tail_arg8082524):R.ffi.throwNonFunApp(L[41],if_helper7992525,[cont_tail_arg8082524]);
},
"from":L[41]});
}
++R.GAS;
return $z92249225;
};
var $Hcont_tail_arg22582541 = function(cont_tail_arg8042540,if_helper7992525) {
if(--R.GAS > 0) {
$z92269227 = R.isFunction(if_helper7992525)?if_helper7992525.app(cont_tail_arg8042540):R.ffi.throwNonFunApp(L[41],if_helper7992525,[cont_tail_arg8042540]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7992525)?if_helper7992525.app(cont_tail_arg8042540):R.ffi.throwNonFunApp(L[41],if_helper7992525,[cont_tail_arg8042540]);
},
"from":L[41]});
}
++R.GAS;
return $z92269227;
};
var $Hanf_arg22562563 = function(anf_arg7912560,INDENT7747,PP123,anf_fun7892561,self2732562) {
var anf_bracket7929241 = G(self2732562,"exp",L[847]);
var anf_fun7939238 = G(anf_bracket7929241,"tosource",L[846]);
var $z92309231 = D;
var $f92369237 = function(_) {
return R.isFunction(anf_fun7939238)?anf_fun7939238.app():R.ffi.throwNonFunApp(L[845],anf_fun7939238,[]);
};
try {
if(--R.GAS > 0) {
$z92309231 = $f92369237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92369237,
"from":L[845]});
}
} catch($e92289229) {
if(R.isCont($e92289229)) {
var $ss92329233 = {"from":L[845],
"go":function(anf_arg7949239) {
return $Hanf_arg22559240(anf_arg7949239,INDENT7747,PP123,anf_arg7912560,anf_fun7892561);
}};
$e92289229.stack[R.EXN_STACKHEIGHT++] = $ss92329233;
}
if(R.isPyretException($e92289229)) {
$e92289229.pyretStack.push(L[845]);
}
throw $e92289229;
}
var $ret92349235 = $Hanf_arg22559240($z92309231,INDENT7747,PP123,anf_arg7912560,anf_fun7892561);
++R.GAS;
return $ret92349235;
};
var $Hanf_arg22559240 = function(anf_arg7949239,INDENT7747,PP123,anf_arg7912560,anf_fun7892561) {
var anf_fun7959252 = G(PP123,"str",L[849]);
var $z92449245 = D;
var $f92509251 = function(_) {
return R.isFunction(anf_fun7959252)?anf_fun7959252.app((")")):R.ffi.throwNonFunApp(L[848],anf_fun7959252,[(")")]);
};
try {
if(--R.GAS > 0) {
$z92449245 = $f92509251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92509251,
"from":L[848]});
}
} catch($e92429243) {
if(R.isCont($e92429243)) {
var $ss92469247 = {"from":L[848],
"go":function(anf_arg7969253) {
return $Hanf_arg22549254(anf_arg7969253,INDENT7747,anf_arg7912560,anf_arg7949239,anf_fun7892561);
}};
$e92429243.stack[R.EXN_STACKHEIGHT++] = $ss92469247;
}
if(R.isPyretException($e92429243)) {
$e92429243.pyretStack.push(L[848]);
}
throw $e92429243;
}
var $ret92489249 = $Hanf_arg22549254($z92449245,INDENT7747,anf_arg7912560,anf_arg7949239,anf_fun7892561);
++R.GAS;
return $ret92489249;
};
var $Hanf_arg22549254 = function(anf_arg7969253,INDENT7747,anf_arg7912560,anf_arg7949239,anf_fun7892561) {
var $z92579258 = D;
var $f92639264 = function(_) {
return R.isFunction(anf_fun7892561)?anf_fun7892561.app(INDENT7747,(1),anf_arg7912560,anf_arg7949239,anf_arg7969253):R.ffi.throwNonFunApp(L[314],anf_fun7892561,[INDENT7747,(1),anf_arg7912560,anf_arg7949239,anf_arg7969253]);
};
try {
if(--R.GAS > 0) {
$z92579258 = $f92639264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92639264,
"from":L[314]});
}
} catch($e92559256) {
if(R.isCont($e92559256)) {
var $ss92599260 = {"from":L[314],
"go":function(ann_DASH_check_DASH_temp7889265) {
return $Hann_DASH_check_DASH_temp22539266(ann_DASH_check_DASH_temp7889265);
}};
$e92559256.stack[R.EXN_STACKHEIGHT++] = $ss92599260;
}
if(R.isPyretException($e92559256)) {
$e92559256.pyretStack.push(L[314]);
}
throw $e92559256;
}
var $ret92619262 = $Hann_DASH_check_DASH_temp22539266($z92579258);
++R.GAS;
return $ret92619262;
};
var $Hann_DASH_check_DASH_temp22539266 = function(ann_DASH_check_DASH_temp7889265) {
return ann_DASH_check_DASH_temp7889265;
};
var $Hanf_begin_app_dropped22522577 = function(anf_begin_app_dropped22482575,printer2722574,self2712576) {
var anf_bracket7859280 = G(self2712576,"exp",L[852]);
var anf_fun7869277 = G(anf_bracket7859280,"print-ugly-source",L[851]);
var $z92699270 = D;
var $f92759276 = function(_) {
return R.isFunction(anf_fun7869277)?anf_fun7869277.app(printer2722574):R.ffi.throwNonFunApp(L[850],anf_fun7869277,[printer2722574]);
};
try {
if(--R.GAS > 0) {
$z92699270 = $f92759276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92759276,
"from":L[850]});
}
} catch($e92679268) {
if(R.isCont($e92679268)) {
var $ss92719272 = {"from":L[850],
"go":function(anf_begin_app_dropped22499278) {
return $Hanf_begin_app_dropped22519279(anf_begin_app_dropped22499278,printer2722574);
}};
$e92679268.stack[R.EXN_STACKHEIGHT++] = $ss92719272;
}
if(R.isPyretException($e92679268)) {
$e92679268.pyretStack.push(L[850]);
}
throw $e92679268;
}
var $ret92739274 = $Hanf_begin_app_dropped22519279($z92699270,printer2722574);
++R.GAS;
return $ret92739274;
};
var $Hanf_begin_app_dropped22519279 = function(anf_begin_app_dropped22499278,printer2722574) {
var $z92839284 = D;
var $f92899290 = function(_) {
return R.isFunction(printer2722574)?printer2722574.app((")")):R.ffi.throwNonFunApp(L[316],printer2722574,[(")")]);
};
try {
if(--R.GAS > 0) {
$z92839284 = $f92899290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92899290,
"from":L[316]});
}
} catch($e92819282) {
if(R.isCont($e92819282)) {
var $ss92859286 = {"from":L[316],
"go":function(ann_DASH_check_DASH_temp7849291) {
return $Hann_DASH_check_DASH_temp22509292(ann_DASH_check_DASH_temp7849291);
}};
$e92819282.stack[R.EXN_STACKHEIGHT++] = $ss92859286;
}
if(R.isPyretException($e92819282)) {
$e92819282.pyretStack.push(L[316]);
}
throw $e92819282;
}
var $ret92879288 = $Hann_DASH_check_DASH_temp22509292($z92839284);
++R.GAS;
return $ret92879288;
};
var $Hann_DASH_check_DASH_temp22509292 = function(ann_DASH_check_DASH_temp7849291) {
return ann_DASH_check_DASH_temp7849291;
};
var $Hanf_arg22472590 = function(anf_arg7802589,_plus14) {
var $z92959296 = D;
var $f93019302 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg7802589,(")")):R.ffi.throwNonFunApp(L[42],_plus14,[anf_arg7802589,(")")]);
};
try {
if(--R.GAS > 0) {
$z92959296 = $f93019302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93019302,
"from":L[42]});
}
} catch($e92939294) {
if(R.isCont($e92939294)) {
var $ss92979298 = {"from":L[42],
"go":function(anf_arg7819303) {
return $Hanf_arg22469304(anf_arg7819303,_plus14);
}};
$e92939294.stack[R.EXN_STACKHEIGHT++] = $ss92979298;
}
if(R.isPyretException($e92939294)) {
$e92939294.pyretStack.push(L[42]);
}
throw $e92939294;
}
var $ret92999300 = $Hanf_arg22469304($z92959296,_plus14);
++R.GAS;
return $ret92999300;
};
var $Hanf_arg22469304 = function(anf_arg7819303,_plus14) {
var $z93079308 = D;
var $f93139314 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg7819303):R.ffi.throwNonFunApp(L[42],_plus14,[("("),anf_arg7819303]);
};
try {
if(--R.GAS > 0) {
$z93079308 = $f93139314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93139314,
"from":L[42]});
}
} catch($e93059306) {
if(R.isCont($e93059306)) {
var $ss93099310 = {"from":L[42],
"go":function(anf_arg7829315) {
return $Hanf_arg22459316(anf_arg7829315,_plus14);
}};
$e93059306.stack[R.EXN_STACKHEIGHT++] = $ss93099310;
}
if(R.isPyretException($e93059306)) {
$e93059306.pyretStack.push(L[42]);
}
throw $e93059306;
}
var $ret93119312 = $Hanf_arg22459316($z93079308,_plus14);
++R.GAS;
return $ret93119312;
};
var $Hanf_arg22459316 = function(anf_arg7829315,_plus14) {
var $z93199320 = D;
var $f93259326 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-parens"),anf_arg7829315):R.ffi.throwNonFunApp(L[42],_plus14,[("j-parens"),anf_arg7829315]);
};
try {
if(--R.GAS > 0) {
$z93199320 = $f93259326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93259326,
"from":L[42]});
}
} catch($e93179318) {
if(R.isCont($e93179318)) {
var $ss93219322 = {"from":L[42],
"go":function(ann_DASH_check_DASH_temp7789327) {
return $Hann_DASH_check_DASH_temp22449328(ann_DASH_check_DASH_temp7789327);
}};
$e93179318.stack[R.EXN_STACKHEIGHT++] = $ss93219322;
}
if(R.isPyretException($e93179318)) {
$e93179318.pyretStack.push(L[42]);
}
throw $e93179318;
}
var $ret93239324 = $Hann_DASH_check_DASH_temp22449328($z93199320);
++R.GAS;
return $ret93239324;
};
var $Hann_DASH_check_DASH_temp22449328 = function(ann_DASH_check_DASH_temp7789327) {
return ann_DASH_check_DASH_temp7789327;
};
var $Hcont_tail_arg22422606 = function(cont_tail_arg7752604,if_helper7672605) {
if(--R.GAS > 0) {
$z93299330 = R.isFunction(if_helper7672605)?if_helper7672605.app(cont_tail_arg7752604):R.ffi.throwNonFunApp(L[42],if_helper7672605,[cont_tail_arg7752604]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7672605)?if_helper7672605.app(cont_tail_arg7752604):R.ffi.throwNonFunApp(L[42],if_helper7672605,[cont_tail_arg7752604]);
},
"from":L[42]});
}
++R.GAS;
return $z93299330;
};
var $Hcont_tail_arg22432621 = function(cont_tail_arg7722620,if_helper7672605) {
if(--R.GAS > 0) {
$z93319332 = R.isFunction(if_helper7672605)?if_helper7672605.app(cont_tail_arg7722620):R.ffi.throwNonFunApp(L[42],if_helper7672605,[cont_tail_arg7722620]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7672605)?if_helper7672605.app(cont_tail_arg7722620):R.ffi.throwNonFunApp(L[42],if_helper7672605,[cont_tail_arg7722620]);
},
"from":L[42]});
}
++R.GAS;
return $z93319332;
};
var $Hstrprint22412641 = function(strprint3892639,self3882640) {
var anf_fun7629343 = G(self3882640,"print-ugly-source",L[855]);
var anf_arg7639344 = G(strprint3892639,"append",L[854]);
var $z93359336 = D;
var $f93419342 = function(_) {
return R.isFunction(anf_fun7629343)?anf_fun7629343.app(anf_arg7639344):R.ffi.throwNonFunApp(L[853],anf_fun7629343,[anf_arg7639344]);
};
try {
if(--R.GAS > 0) {
$z93359336 = $f93419342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93419342,
"from":L[853]});
}
} catch($e93339334) {
if(R.isCont($e93339334)) {
var $ss93379338 = {"from":L[853],
"go":function(anf_begin_app_dropped22389345) {
return $Hanf_begin_app_dropped22409346(anf_begin_app_dropped22389345,strprint3892639);
}};
$e93339334.stack[R.EXN_STACKHEIGHT++] = $ss93379338;
}
if(R.isPyretException($e93339334)) {
$e93339334.pyretStack.push(L[853]);
}
throw $e93339334;
}
var $ret93399340 = $Hanf_begin_app_dropped22409346($z93359336,strprint3892639);
++R.GAS;
return $ret93399340;
};
var $Hanf_begin_app_dropped22409346 = function(anf_begin_app_dropped22389345,strprint3892639) {
var anf_fun7649357 = G(strprint3892639,"get",L[856]);
var $z93499350 = D;
var $f93559356 = function(_) {
return R.isFunction(anf_fun7649357)?anf_fun7649357.app():R.ffi.throwNonFunApp(L[319],anf_fun7649357,[]);
};
try {
if(--R.GAS > 0) {
$z93499350 = $f93559356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93559356,
"from":L[319]});
}
} catch($e93479348) {
if(R.isCont($e93479348)) {
var $ss93519352 = {"from":L[319],
"go":function(ann_DASH_check_DASH_temp7619358) {
return $Hann_DASH_check_DASH_temp22399359(ann_DASH_check_DASH_temp7619358);
}};
$e93479348.stack[R.EXN_STACKHEIGHT++] = $ss93519352;
}
if(R.isPyretException($e93479348)) {
$e93479348.pyretStack.push(L[319]);
}
throw $e93479348;
}
var $ret93539354 = $Hann_DASH_check_DASH_temp22399359($z93499350);
++R.GAS;
return $ret93539354;
};
var $Hann_DASH_check_DASH_temp22399359 = function(ann_DASH_check_DASH_temp7619358) {
return ann_DASH_check_DASH_temp7619358;
};
var $Hcont_tail_arg22362692 = function(cont_tail_arg7432690,if_helper7362691) {
if(--R.GAS > 0) {
$z93609361 = R.isFunction(if_helper7362691)?if_helper7362691.app(cont_tail_arg7432690):R.ffi.throwNonFunApp(L[320],if_helper7362691,[cont_tail_arg7432690]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7362691)?if_helper7362691.app(cont_tail_arg7432690):R.ffi.throwNonFunApp(L[320],if_helper7362691,[cont_tail_arg7432690]);
},
"from":L[320]});
}
++R.GAS;
return $z93609361;
};
var $Hcont_tail_arg22372706 = function(cont_tail_arg7412705,if_helper7362691) {
if(--R.GAS > 0) {
$z93629363 = R.isFunction(if_helper7362691)?if_helper7362691.app(cont_tail_arg7412705):R.ffi.throwNonFunApp(L[320],if_helper7362691,[cont_tail_arg7412705]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7362691)?if_helper7362691.app(cont_tail_arg7412705):R.ffi.throwNonFunApp(L[320],if_helper7362691,[cont_tail_arg7412705]);
},
"from":L[320]});
}
++R.GAS;
return $z93629363;
};
var $Hcont_tail_arg22342732 = function(cont_tail_arg7282730,if_helper7212731) {
if(--R.GAS > 0) {
$z93649365 = R.isFunction(if_helper7212731)?if_helper7212731.app(cont_tail_arg7282730):R.ffi.throwNonFunApp(L[321],if_helper7212731,[cont_tail_arg7282730]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7212731)?if_helper7212731.app(cont_tail_arg7282730):R.ffi.throwNonFunApp(L[321],if_helper7212731,[cont_tail_arg7282730]);
},
"from":L[321]});
}
++R.GAS;
return $z93649365;
};
var $Hcont_tail_arg22352746 = function(cont_tail_arg7262745,if_helper7212731) {
if(--R.GAS > 0) {
$z93669367 = R.isFunction(if_helper7212731)?if_helper7212731.app(cont_tail_arg7262745):R.ffi.throwNonFunApp(L[321],if_helper7212731,[cont_tail_arg7262745]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7212731)?if_helper7212731.app(cont_tail_arg7262745):R.ffi.throwNonFunApp(L[321],if_helper7212731,[cont_tail_arg7262745]);
},
"from":L[321]});
}
++R.GAS;
return $z93669367;
};
var $Hcont_tail_arg22322772 = function(cont_tail_arg7132770,if_helper7062771) {
if(--R.GAS > 0) {
$z93689369 = R.isFunction(if_helper7062771)?if_helper7062771.app(cont_tail_arg7132770):R.ffi.throwNonFunApp(L[322],if_helper7062771,[cont_tail_arg7132770]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7062771)?if_helper7062771.app(cont_tail_arg7132770):R.ffi.throwNonFunApp(L[322],if_helper7062771,[cont_tail_arg7132770]);
},
"from":L[322]});
}
++R.GAS;
return $z93689369;
};
var $Hcont_tail_arg22332786 = function(cont_tail_arg7112785,if_helper7062771) {
if(--R.GAS > 0) {
$z93709371 = R.isFunction(if_helper7062771)?if_helper7062771.app(cont_tail_arg7112785):R.ffi.throwNonFunApp(L[322],if_helper7062771,[cont_tail_arg7112785]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper7062771)?if_helper7062771.app(cont_tail_arg7112785):R.ffi.throwNonFunApp(L[322],if_helper7062771,[cont_tail_arg7112785]);
},
"from":L[322]});
}
++R.GAS;
return $z93709371;
};
var $Hcont_tail_arg22302811 = function(cont_tail_arg6982809,if_helper6912810) {
if(--R.GAS > 0) {
$z93729373 = R.isFunction(if_helper6912810)?if_helper6912810.app(cont_tail_arg6982809):R.ffi.throwNonFunApp(L[323],if_helper6912810,[cont_tail_arg6982809]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6912810)?if_helper6912810.app(cont_tail_arg6982809):R.ffi.throwNonFunApp(L[323],if_helper6912810,[cont_tail_arg6982809]);
},
"from":L[323]});
}
++R.GAS;
return $z93729373;
};
var $Hcont_tail_arg22312825 = function(cont_tail_arg6962824,if_helper6912810) {
if(--R.GAS > 0) {
$z93749375 = R.isFunction(if_helper6912810)?if_helper6912810.app(cont_tail_arg6962824):R.ffi.throwNonFunApp(L[323],if_helper6912810,[cont_tail_arg6962824]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6912810)?if_helper6912810.app(cont_tail_arg6962824):R.ffi.throwNonFunApp(L[323],if_helper6912810,[cont_tail_arg6962824]);
},
"from":L[323]});
}
++R.GAS;
return $z93749375;
};
var $Hanf_arg22292847 = function(anf_arg6882845,anf_fun6862846) {
var $z93789379 = D;
var $f93849385 = function(_) {
return R.isFunction(anf_fun6862846)?anf_fun6862846.app(anf_arg6882845):R.ffi.throwNonFunApp(L[332],anf_fun6862846,[anf_arg6882845]);
};
try {
if(--R.GAS > 0) {
$z93789379 = $f93849385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93849385,
"from":L[332]});
}
} catch($e93769377) {
if(R.isCont($e93769377)) {
var $ss93809381 = {"from":L[332],
"go":function(ann_DASH_check_DASH_temp6859386) {
return $Hann_DASH_check_DASH_temp22289387(ann_DASH_check_DASH_temp6859386);
}};
$e93769377.stack[R.EXN_STACKHEIGHT++] = $ss93809381;
}
if(R.isPyretException($e93769377)) {
$e93769377.pyretStack.push(L[332]);
}
throw $e93769377;
}
var $ret93829383 = $Hann_DASH_check_DASH_temp22289387($z93789379);
++R.GAS;
return $ret93829383;
};
var $Hann_DASH_check_DASH_temp22289387 = function(ann_DASH_check_DASH_temp6859386) {
return ann_DASH_check_DASH_temp6859386;
};
var $Hanf_arg22272861 = function(anf_arg6832859,printer2682860) {
var $z93909391 = D;
var $f93969397 = function(_) {
return R.isFunction(printer2682860)?printer2682860.app(anf_arg6832859):R.ffi.throwNonFunApp(L[335],printer2682860,[anf_arg6832859]);
};
try {
if(--R.GAS > 0) {
$z93909391 = $f93969397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93969397,
"from":L[335]});
}
} catch($e93889389) {
if(R.isCont($e93889389)) {
var $ss93929393 = {"from":L[335],
"go":function(ann_DASH_check_DASH_temp6819398) {
return $Hann_DASH_check_DASH_temp22269399(ann_DASH_check_DASH_temp6819398);
}};
$e93889389.stack[R.EXN_STACKHEIGHT++] = $ss93929393;
}
if(R.isPyretException($e93889389)) {
$e93889389.pyretStack.push(L[335]);
}
throw $e93889389;
}
var $ret93949395 = $Hann_DASH_check_DASH_temp22269399($z93909391);
++R.GAS;
return $ret93949395;
};
var $Hann_DASH_check_DASH_temp22269399 = function(ann_DASH_check_DASH_temp6819398) {
return ann_DASH_check_DASH_temp6819398;
};
var $Hcont_tail_arg22242994 = function(cont_tail_arg6432992,if_helper6362993) {
if(--R.GAS > 0) {
$z94009401 = R.isFunction(if_helper6362993)?if_helper6362993.app(cont_tail_arg6432992):R.ffi.throwNonFunApp(L[336],if_helper6362993,[cont_tail_arg6432992]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6362993)?if_helper6362993.app(cont_tail_arg6432992):R.ffi.throwNonFunApp(L[336],if_helper6362993,[cont_tail_arg6432992]);
},
"from":L[336]});
}
++R.GAS;
return $z94009401;
};
var $Hcont_tail_arg22253008 = function(cont_tail_arg6413007,if_helper6362993) {
if(--R.GAS > 0) {
$z94029403 = R.isFunction(if_helper6362993)?if_helper6362993.app(cont_tail_arg6413007):R.ffi.throwNonFunApp(L[336],if_helper6362993,[cont_tail_arg6413007]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6362993)?if_helper6362993.app(cont_tail_arg6413007):R.ffi.throwNonFunApp(L[336],if_helper6362993,[cont_tail_arg6413007]);
},
"from":L[336]});
}
++R.GAS;
return $z94029403;
};
var $Hcont_tail_arg22223034 = function(cont_tail_arg6283032,if_helper6213033) {
if(--R.GAS > 0) {
$z94049405 = R.isFunction(if_helper6213033)?if_helper6213033.app(cont_tail_arg6283032):R.ffi.throwNonFunApp(L[337],if_helper6213033,[cont_tail_arg6283032]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6213033)?if_helper6213033.app(cont_tail_arg6283032):R.ffi.throwNonFunApp(L[337],if_helper6213033,[cont_tail_arg6283032]);
},
"from":L[337]});
}
++R.GAS;
return $z94049405;
};
var $Hcont_tail_arg22233048 = function(cont_tail_arg6263047,if_helper6213033) {
if(--R.GAS > 0) {
$z94069407 = R.isFunction(if_helper6213033)?if_helper6213033.app(cont_tail_arg6263047):R.ffi.throwNonFunApp(L[337],if_helper6213033,[cont_tail_arg6263047]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6213033)?if_helper6213033.app(cont_tail_arg6263047):R.ffi.throwNonFunApp(L[337],if_helper6213033,[cont_tail_arg6263047]);
},
"from":L[337]});
}
++R.GAS;
return $z94069407;
};
var $Hcont_tail_arg22203073 = function(cont_tail_arg6133071,if_helper6063072) {
if(--R.GAS > 0) {
$z94089409 = R.isFunction(if_helper6063072)?if_helper6063072.app(cont_tail_arg6133071):R.ffi.throwNonFunApp(L[338],if_helper6063072,[cont_tail_arg6133071]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6063072)?if_helper6063072.app(cont_tail_arg6133071):R.ffi.throwNonFunApp(L[338],if_helper6063072,[cont_tail_arg6133071]);
},
"from":L[338]});
}
++R.GAS;
return $z94089409;
};
var $Hcont_tail_arg22213087 = function(cont_tail_arg6113086,if_helper6063072) {
if(--R.GAS > 0) {
$z94109411 = R.isFunction(if_helper6063072)?if_helper6063072.app(cont_tail_arg6113086):R.ffi.throwNonFunApp(L[338],if_helper6063072,[cont_tail_arg6113086]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper6063072)?if_helper6063072.app(cont_tail_arg6113086):R.ffi.throwNonFunApp(L[338],if_helper6063072,[cont_tail_arg6113086]);
},
"from":L[338]});
}
++R.GAS;
return $z94109411;
};
var $Hcont_tail_arg22183113 = function(cont_tail_arg5983111,if_helper5913112) {
if(--R.GAS > 0) {
$z94129413 = R.isFunction(if_helper5913112)?if_helper5913112.app(cont_tail_arg5983111):R.ffi.throwNonFunApp(L[339],if_helper5913112,[cont_tail_arg5983111]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5913112)?if_helper5913112.app(cont_tail_arg5983111):R.ffi.throwNonFunApp(L[339],if_helper5913112,[cont_tail_arg5983111]);
},
"from":L[339]});
}
++R.GAS;
return $z94129413;
};
var $Hcont_tail_arg22193127 = function(cont_tail_arg5963126,if_helper5913112) {
if(--R.GAS > 0) {
$z94149415 = R.isFunction(if_helper5913112)?if_helper5913112.app(cont_tail_arg5963126):R.ffi.throwNonFunApp(L[339],if_helper5913112,[cont_tail_arg5963126]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5913112)?if_helper5913112.app(cont_tail_arg5963126):R.ffi.throwNonFunApp(L[339],if_helper5913112,[cont_tail_arg5963126]);
},
"from":L[339]});
}
++R.GAS;
return $z94149415;
};
var $Hcont_tail_arg22163153 = function(cont_tail_arg5833151,if_helper5763152) {
if(--R.GAS > 0) {
$z94169417 = R.isFunction(if_helper5763152)?if_helper5763152.app(cont_tail_arg5833151):R.ffi.throwNonFunApp(L[340],if_helper5763152,[cont_tail_arg5833151]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5763152)?if_helper5763152.app(cont_tail_arg5833151):R.ffi.throwNonFunApp(L[340],if_helper5763152,[cont_tail_arg5833151]);
},
"from":L[340]});
}
++R.GAS;
return $z94169417;
};
var $Hcont_tail_arg22173167 = function(cont_tail_arg5813166,if_helper5763152) {
if(--R.GAS > 0) {
$z94189419 = R.isFunction(if_helper5763152)?if_helper5763152.app(cont_tail_arg5813166):R.ffi.throwNonFunApp(L[340],if_helper5763152,[cont_tail_arg5813166]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5763152)?if_helper5763152.app(cont_tail_arg5813166):R.ffi.throwNonFunApp(L[340],if_helper5763152,[cont_tail_arg5813166]);
},
"from":L[340]});
}
++R.GAS;
return $z94189419;
};
var $Hcont_tail_arg22143192 = function(cont_tail_arg5683190,if_helper5613191) {
if(--R.GAS > 0) {
$z94209421 = R.isFunction(if_helper5613191)?if_helper5613191.app(cont_tail_arg5683190):R.ffi.throwNonFunApp(L[341],if_helper5613191,[cont_tail_arg5683190]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5613191)?if_helper5613191.app(cont_tail_arg5683190):R.ffi.throwNonFunApp(L[341],if_helper5613191,[cont_tail_arg5683190]);
},
"from":L[341]});
}
++R.GAS;
return $z94209421;
};
var $Hcont_tail_arg22153206 = function(cont_tail_arg5663205,if_helper5613191) {
if(--R.GAS > 0) {
$z94229423 = R.isFunction(if_helper5613191)?if_helper5613191.app(cont_tail_arg5663205):R.ffi.throwNonFunApp(L[341],if_helper5613191,[cont_tail_arg5663205]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5613191)?if_helper5613191.app(cont_tail_arg5663205):R.ffi.throwNonFunApp(L[341],if_helper5613191,[cont_tail_arg5663205]);
},
"from":L[341]});
}
++R.GAS;
return $z94229423;
};
var $Hcont_tail_arg22123232 = function(cont_tail_arg5533230,if_helper5463231) {
if(--R.GAS > 0) {
$z94249425 = R.isFunction(if_helper5463231)?if_helper5463231.app(cont_tail_arg5533230):R.ffi.throwNonFunApp(L[342],if_helper5463231,[cont_tail_arg5533230]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5463231)?if_helper5463231.app(cont_tail_arg5533230):R.ffi.throwNonFunApp(L[342],if_helper5463231,[cont_tail_arg5533230]);
},
"from":L[342]});
}
++R.GAS;
return $z94249425;
};
var $Hcont_tail_arg22133246 = function(cont_tail_arg5513245,if_helper5463231) {
if(--R.GAS > 0) {
$z94269427 = R.isFunction(if_helper5463231)?if_helper5463231.app(cont_tail_arg5513245):R.ffi.throwNonFunApp(L[342],if_helper5463231,[cont_tail_arg5513245]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5463231)?if_helper5463231.app(cont_tail_arg5513245):R.ffi.throwNonFunApp(L[342],if_helper5463231,[cont_tail_arg5513245]);
},
"from":L[342]});
}
++R.GAS;
return $z94269427;
};
var $Hcont_tail_arg22103272 = function(cont_tail_arg5383270,if_helper5313271) {
if(--R.GAS > 0) {
$z94289429 = R.isFunction(if_helper5313271)?if_helper5313271.app(cont_tail_arg5383270):R.ffi.throwNonFunApp(L[343],if_helper5313271,[cont_tail_arg5383270]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5313271)?if_helper5313271.app(cont_tail_arg5383270):R.ffi.throwNonFunApp(L[343],if_helper5313271,[cont_tail_arg5383270]);
},
"from":L[343]});
}
++R.GAS;
return $z94289429;
};
var $Hcont_tail_arg22113286 = function(cont_tail_arg5363285,if_helper5313271) {
if(--R.GAS > 0) {
$z94309431 = R.isFunction(if_helper5313271)?if_helper5313271.app(cont_tail_arg5363285):R.ffi.throwNonFunApp(L[343],if_helper5313271,[cont_tail_arg5363285]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5313271)?if_helper5313271.app(cont_tail_arg5363285):R.ffi.throwNonFunApp(L[343],if_helper5313271,[cont_tail_arg5363285]);
},
"from":L[343]});
}
++R.GAS;
return $z94309431;
};
var $Hcont_tail_arg22083312 = function(cont_tail_arg5233310,if_helper5163311) {
if(--R.GAS > 0) {
$z94329433 = R.isFunction(if_helper5163311)?if_helper5163311.app(cont_tail_arg5233310):R.ffi.throwNonFunApp(L[344],if_helper5163311,[cont_tail_arg5233310]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5163311)?if_helper5163311.app(cont_tail_arg5233310):R.ffi.throwNonFunApp(L[344],if_helper5163311,[cont_tail_arg5233310]);
},
"from":L[344]});
}
++R.GAS;
return $z94329433;
};
var $Hcont_tail_arg22093326 = function(cont_tail_arg5213325,if_helper5163311) {
if(--R.GAS > 0) {
$z94349435 = R.isFunction(if_helper5163311)?if_helper5163311.app(cont_tail_arg5213325):R.ffi.throwNonFunApp(L[344],if_helper5163311,[cont_tail_arg5213325]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5163311)?if_helper5163311.app(cont_tail_arg5213325):R.ffi.throwNonFunApp(L[344],if_helper5163311,[cont_tail_arg5213325]);
},
"from":L[344]});
}
++R.GAS;
return $z94349435;
};
var $Hcont_tail_arg22063351 = function(cont_tail_arg5083349,if_helper5013350) {
if(--R.GAS > 0) {
$z94369437 = R.isFunction(if_helper5013350)?if_helper5013350.app(cont_tail_arg5083349):R.ffi.throwNonFunApp(L[345],if_helper5013350,[cont_tail_arg5083349]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5013350)?if_helper5013350.app(cont_tail_arg5083349):R.ffi.throwNonFunApp(L[345],if_helper5013350,[cont_tail_arg5083349]);
},
"from":L[345]});
}
++R.GAS;
return $z94369437;
};
var $Hcont_tail_arg22073365 = function(cont_tail_arg5063364,if_helper5013350) {
if(--R.GAS > 0) {
$z94389439 = R.isFunction(if_helper5013350)?if_helper5013350.app(cont_tail_arg5063364):R.ffi.throwNonFunApp(L[345],if_helper5013350,[cont_tail_arg5063364]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper5013350)?if_helper5013350.app(cont_tail_arg5063364):R.ffi.throwNonFunApp(L[345],if_helper5013350,[cont_tail_arg5063364]);
},
"from":L[345]});
}
++R.GAS;
return $z94389439;
};
var $Hcont_tail_arg22043391 = function(cont_tail_arg4933389,if_helper4863390) {
if(--R.GAS > 0) {
$z94409441 = R.isFunction(if_helper4863390)?if_helper4863390.app(cont_tail_arg4933389):R.ffi.throwNonFunApp(L[346],if_helper4863390,[cont_tail_arg4933389]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4863390)?if_helper4863390.app(cont_tail_arg4933389):R.ffi.throwNonFunApp(L[346],if_helper4863390,[cont_tail_arg4933389]);
},
"from":L[346]});
}
++R.GAS;
return $z94409441;
};
var $Hcont_tail_arg22053405 = function(cont_tail_arg4913404,if_helper4863390) {
if(--R.GAS > 0) {
$z94429443 = R.isFunction(if_helper4863390)?if_helper4863390.app(cont_tail_arg4913404):R.ffi.throwNonFunApp(L[346],if_helper4863390,[cont_tail_arg4913404]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4863390)?if_helper4863390.app(cont_tail_arg4913404):R.ffi.throwNonFunApp(L[346],if_helper4863390,[cont_tail_arg4913404]);
},
"from":L[346]});
}
++R.GAS;
return $z94429443;
};
var $Hcont_tail_arg22023431 = function(cont_tail_arg4783429,if_helper4713430) {
if(--R.GAS > 0) {
$z94449445 = R.isFunction(if_helper4713430)?if_helper4713430.app(cont_tail_arg4783429):R.ffi.throwNonFunApp(L[347],if_helper4713430,[cont_tail_arg4783429]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4713430)?if_helper4713430.app(cont_tail_arg4783429):R.ffi.throwNonFunApp(L[347],if_helper4713430,[cont_tail_arg4783429]);
},
"from":L[347]});
}
++R.GAS;
return $z94449445;
};
var $Hcont_tail_arg22033445 = function(cont_tail_arg4763444,if_helper4713430) {
if(--R.GAS > 0) {
$z94469447 = R.isFunction(if_helper4713430)?if_helper4713430.app(cont_tail_arg4763444):R.ffi.throwNonFunApp(L[347],if_helper4713430,[cont_tail_arg4763444]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4713430)?if_helper4713430.app(cont_tail_arg4763444):R.ffi.throwNonFunApp(L[347],if_helper4713430,[cont_tail_arg4763444]);
},
"from":L[347]});
}
++R.GAS;
return $z94469447;
};
var $Hcont_tail_arg22003470 = function(cont_tail_arg4633468,if_helper4563469) {
if(--R.GAS > 0) {
$z94489449 = R.isFunction(if_helper4563469)?if_helper4563469.app(cont_tail_arg4633468):R.ffi.throwNonFunApp(L[348],if_helper4563469,[cont_tail_arg4633468]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4563469)?if_helper4563469.app(cont_tail_arg4633468):R.ffi.throwNonFunApp(L[348],if_helper4563469,[cont_tail_arg4633468]);
},
"from":L[348]});
}
++R.GAS;
return $z94489449;
};
var $Hcont_tail_arg22013484 = function(cont_tail_arg4613483,if_helper4563469) {
if(--R.GAS > 0) {
$z94509451 = R.isFunction(if_helper4563469)?if_helper4563469.app(cont_tail_arg4613483):R.ffi.throwNonFunApp(L[348],if_helper4563469,[cont_tail_arg4613483]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4563469)?if_helper4563469.app(cont_tail_arg4613483):R.ffi.throwNonFunApp(L[348],if_helper4563469,[cont_tail_arg4613483]);
},
"from":L[348]});
}
++R.GAS;
return $z94509451;
};
var $Hcont_tail_arg21983510 = function(cont_tail_arg4483508,if_helper4413509) {
if(--R.GAS > 0) {
$z94529453 = R.isFunction(if_helper4413509)?if_helper4413509.app(cont_tail_arg4483508):R.ffi.throwNonFunApp(L[349],if_helper4413509,[cont_tail_arg4483508]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4413509)?if_helper4413509.app(cont_tail_arg4483508):R.ffi.throwNonFunApp(L[349],if_helper4413509,[cont_tail_arg4483508]);
},
"from":L[349]});
}
++R.GAS;
return $z94529453;
};
var $Hcont_tail_arg21993524 = function(cont_tail_arg4463523,if_helper4413509) {
if(--R.GAS > 0) {
$z94549455 = R.isFunction(if_helper4413509)?if_helper4413509.app(cont_tail_arg4463523):R.ffi.throwNonFunApp(L[349],if_helper4413509,[cont_tail_arg4463523]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper4413509)?if_helper4413509.app(cont_tail_arg4463523):R.ffi.throwNonFunApp(L[349],if_helper4413509,[cont_tail_arg4463523]);
},
"from":L[349]});
}
++R.GAS;
return $z94549455;
};
var $Hanf_arg21973546 = function(anf_arg4383544,anf_fun4363545) {
var $z94589459 = D;
var $f94649465 = function(_) {
return R.isFunction(anf_fun4363545)?anf_fun4363545.app(anf_arg4383544):R.ffi.throwNonFunApp(L[368],anf_fun4363545,[anf_arg4383544]);
};
try {
if(--R.GAS > 0) {
$z94589459 = $f94649465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94649465,
"from":L[368]});
}
} catch($e94569457) {
if(R.isCont($e94569457)) {
var $ss94609461 = {"from":L[368],
"go":function(ann_DASH_check_DASH_temp4359466) {
return $Hann_DASH_check_DASH_temp21969467(ann_DASH_check_DASH_temp4359466);
}};
$e94569457.stack[R.EXN_STACKHEIGHT++] = $ss94609461;
}
if(R.isPyretException($e94569457)) {
$e94569457.pyretStack.push(L[368]);
}
throw $e94569457;
}
var $ret94629463 = $Hann_DASH_check_DASH_temp21969467($z94589459);
++R.GAS;
return $ret94629463;
};
var $Hann_DASH_check_DASH_temp21969467 = function(ann_DASH_check_DASH_temp4359466) {
return ann_DASH_check_DASH_temp4359466;
};
var $Hanf_arg21953561 = function(anf_arg4333559,printer2613560) {
var $z94709471 = D;
var $f94769477 = function(_) {
return R.isFunction(printer2613560)?printer2613560.app(anf_arg4333559):R.ffi.throwNonFunApp(L[371],printer2613560,[anf_arg4333559]);
};
try {
if(--R.GAS > 0) {
$z94709471 = $f94769477();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94769477,
"from":L[371]});
}
} catch($e94689469) {
if(R.isCont($e94689469)) {
var $ss94729473 = {"from":L[371],
"go":function(ann_DASH_check_DASH_temp4319478) {
return $Hann_DASH_check_DASH_temp21949479(ann_DASH_check_DASH_temp4319478);
}};
$e94689469.stack[R.EXN_STACKHEIGHT++] = $ss94729473;
}
if(R.isPyretException($e94689469)) {
$e94689469.pyretStack.push(L[371]);
}
throw $e94689469;
}
var $ret94749475 = $Hann_DASH_check_DASH_temp21949479($z94709471);
++R.GAS;
return $ret94749475;
};
var $Hann_DASH_check_DASH_temp21949479 = function(ann_DASH_check_DASH_temp4319478) {
return ann_DASH_check_DASH_temp4319478;
};
var $Hanf_arg21933651 = function(anf_arg4103650,PP123,_plus14) {
var anf_fun4119490 = G(PP123,"str",L[858]);
var $z94829483 = D;
var $f94889489 = function(_) {
return R.isFunction(anf_fun4119490)?anf_fun4119490.app((";")):R.ffi.throwNonFunApp(L[857],anf_fun4119490,[(";")]);
};
try {
if(--R.GAS > 0) {
$z94829483 = $f94889489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94889489,
"from":L[857]});
}
} catch($e94809481) {
if(R.isCont($e94809481)) {
var $ss94849485 = {"from":L[857],
"go":function(anf_arg4129491) {
return $Hanf_arg21929492(anf_arg4129491,anf_arg4103650,_plus14);
}};
$e94809481.stack[R.EXN_STACKHEIGHT++] = $ss94849485;
}
if(R.isPyretException($e94809481)) {
$e94809481.pyretStack.push(L[857]);
}
throw $e94809481;
}
var $ret94869487 = $Hanf_arg21929492($z94829483,anf_arg4103650,_plus14);
++R.GAS;
return $ret94869487;
};
var $Hanf_arg21929492 = function(anf_arg4129491,anf_arg4103650,_plus14) {
var $z94959496 = D;
var $f95019502 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg4103650,anf_arg4129491):R.ffi.throwNonFunApp(L[403],_plus14,[anf_arg4103650,anf_arg4129491]);
};
try {
if(--R.GAS > 0) {
$z94959496 = $f95019502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95019502,
"from":L[403]});
}
} catch($e94939494) {
if(R.isCont($e94939494)) {
var $ss94979498 = {"from":L[403],
"go":function(ann_DASH_check_DASH_temp4079503) {
return $Hann_DASH_check_DASH_temp21919504(ann_DASH_check_DASH_temp4079503);
}};
$e94939494.stack[R.EXN_STACKHEIGHT++] = $ss94979498;
}
if(R.isPyretException($e94939494)) {
$e94939494.pyretStack.push(L[403]);
}
throw $e94939494;
}
var $ret94999500 = $Hann_DASH_check_DASH_temp21919504($z94959496);
++R.GAS;
return $ret94999500;
};
var $Hann_DASH_check_DASH_temp21919504 = function(ann_DASH_check_DASH_temp4079503) {
return ann_DASH_check_DASH_temp4079503;
};
var $Hanf_begin_app_dropped21903667 = function(anf_begin_app_dropped21883666,printer2423665) {
var $z95079508 = D;
var $f95139514 = function(_) {
return R.isFunction(printer2423665)?printer2423665.app((";")):R.ffi.throwNonFunApp(L[407],printer2423665,[(";")]);
};
try {
if(--R.GAS > 0) {
$z95079508 = $f95139514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95139514,
"from":L[407]});
}
} catch($e95059506) {
if(R.isCont($e95059506)) {
var $ss95099510 = {"from":L[407],
"go":function(ann_DASH_check_DASH_temp4039515) {
return $Hann_DASH_check_DASH_temp21899516(ann_DASH_check_DASH_temp4039515);
}};
$e95059506.stack[R.EXN_STACKHEIGHT++] = $ss95099510;
}
if(R.isPyretException($e95059506)) {
$e95059506.pyretStack.push(L[407]);
}
throw $e95059506;
}
var $ret95119512 = $Hann_DASH_check_DASH_temp21899516($z95079508);
++R.GAS;
return $ret95119512;
};
var $Hann_DASH_check_DASH_temp21899516 = function(ann_DASH_check_DASH_temp4039515) {
return ann_DASH_check_DASH_temp4039515;
};
var $Hanf_arg21873681 = function(anf_arg3993680,_plus14) {
var $z95199520 = D;
var $f95259526 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3993680,(")")):R.ffi.throwNonFunApp(L[372],_plus14,[anf_arg3993680,(")")]);
};
try {
if(--R.GAS > 0) {
$z95199520 = $f95259526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95259526,
"from":L[372]});
}
} catch($e95179518) {
if(R.isCont($e95179518)) {
var $ss95219522 = {"from":L[372],
"go":function(anf_arg4009527) {
return $Hanf_arg21869528(anf_arg4009527,_plus14);
}};
$e95179518.stack[R.EXN_STACKHEIGHT++] = $ss95219522;
}
if(R.isPyretException($e95179518)) {
$e95179518.pyretStack.push(L[372]);
}
throw $e95179518;
}
var $ret95239524 = $Hanf_arg21869528($z95199520,_plus14);
++R.GAS;
return $ret95239524;
};
var $Hanf_arg21869528 = function(anf_arg4009527,_plus14) {
var $z95319532 = D;
var $f95379538 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg4009527):R.ffi.throwNonFunApp(L[372],_plus14,[("("),anf_arg4009527]);
};
try {
if(--R.GAS > 0) {
$z95319532 = $f95379538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95379538,
"from":L[372]});
}
} catch($e95299530) {
if(R.isCont($e95299530)) {
var $ss95339534 = {"from":L[372],
"go":function(anf_arg4019539) {
return $Hanf_arg21859540(anf_arg4019539,_plus14);
}};
$e95299530.stack[R.EXN_STACKHEIGHT++] = $ss95339534;
}
if(R.isPyretException($e95299530)) {
$e95299530.pyretStack.push(L[372]);
}
throw $e95299530;
}
var $ret95359536 = $Hanf_arg21859540($z95319532,_plus14);
++R.GAS;
return $ret95359536;
};
var $Hanf_arg21859540 = function(anf_arg4019539,_plus14) {
var $z95439544 = D;
var $f95499550 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-expr"),anf_arg4019539):R.ffi.throwNonFunApp(L[372],_plus14,[("j-expr"),anf_arg4019539]);
};
try {
if(--R.GAS > 0) {
$z95439544 = $f95499550();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95499550,
"from":L[372]});
}
} catch($e95419542) {
if(R.isCont($e95419542)) {
var $ss95459546 = {"from":L[372],
"go":function(ann_DASH_check_DASH_temp3979551) {
return $Hann_DASH_check_DASH_temp21849552(ann_DASH_check_DASH_temp3979551);
}};
$e95419542.stack[R.EXN_STACKHEIGHT++] = $ss95459546;
}
if(R.isPyretException($e95419542)) {
$e95419542.pyretStack.push(L[372]);
}
throw $e95419542;
}
var $ret95479548 = $Hann_DASH_check_DASH_temp21849552($z95439544);
++R.GAS;
return $ret95479548;
};
var $Hann_DASH_check_DASH_temp21849552 = function(ann_DASH_check_DASH_temp3979551) {
return ann_DASH_check_DASH_temp3979551;
};
var $Hcont_tail_arg21823697 = function(cont_tail_arg3943695,if_helper3863696) {
if(--R.GAS > 0) {
$z95539554 = R.isFunction(if_helper3863696)?if_helper3863696.app(cont_tail_arg3943695):R.ffi.throwNonFunApp(L[372],if_helper3863696,[cont_tail_arg3943695]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper3863696)?if_helper3863696.app(cont_tail_arg3943695):R.ffi.throwNonFunApp(L[372],if_helper3863696,[cont_tail_arg3943695]);
},
"from":L[372]});
}
++R.GAS;
return $z95539554;
};
var $Hcont_tail_arg21833712 = function(cont_tail_arg3913711,if_helper3863696) {
if(--R.GAS > 0) {
$z95559556 = R.isFunction(if_helper3863696)?if_helper3863696.app(cont_tail_arg3913711):R.ffi.throwNonFunApp(L[372],if_helper3863696,[cont_tail_arg3913711]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper3863696)?if_helper3863696.app(cont_tail_arg3913711):R.ffi.throwNonFunApp(L[372],if_helper3863696,[cont_tail_arg3913711]);
},
"from":L[372]});
}
++R.GAS;
return $z95559556;
};
var $Hanf_arg21813735 = function(anf_arg3753731,INDENT7747,PP123,anf_fun3723732,anf_fun3733733,self2393734,_plus14) {
var anf_bracket3769570 = G(self2393734,"exp",L[861]);
var anf_fun3779567 = G(anf_bracket3769570,"tosource",L[860]);
var $z95599560 = D;
var $f95659566 = function(_) {
return R.isFunction(anf_fun3779567)?anf_fun3779567.app():R.ffi.throwNonFunApp(L[859],anf_fun3779567,[]);
};
try {
if(--R.GAS > 0) {
$z95599560 = $f95659566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95659566,
"from":L[859]});
}
} catch($e95579558) {
if(R.isCont($e95579558)) {
var $ss95619562 = {"from":L[859],
"go":function(anf_arg3789568) {
return $Hanf_arg21809569(anf_arg3789568,INDENT7747,PP123,anf_arg3753731,anf_fun3723732,anf_fun3733733,_plus14);
}};
$e95579558.stack[R.EXN_STACKHEIGHT++] = $ss95619562;
}
if(R.isPyretException($e95579558)) {
$e95579558.pyretStack.push(L[859]);
}
throw $e95579558;
}
var $ret95639564 = $Hanf_arg21809569($z95599560,INDENT7747,PP123,anf_arg3753731,anf_fun3723732,anf_fun3733733,_plus14);
++R.GAS;
return $ret95639564;
};
var $Hanf_arg21809569 = function(anf_arg3789568,INDENT7747,PP123,anf_arg3753731,anf_fun3723732,anf_fun3733733,_plus14) {
var $z95739574 = D;
var $f95799580 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3753731,anf_arg3789568):R.ffi.throwNonFunApp(L[862],_plus14,[anf_arg3753731,anf_arg3789568]);
};
try {
if(--R.GAS > 0) {
$z95739574 = $f95799580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95799580,
"from":L[862]});
}
} catch($e95719572) {
if(R.isCont($e95719572)) {
var $ss95759576 = {"from":L[862],
"go":function(anf_arg3799581) {
return $Hanf_arg21799582(anf_arg3799581,INDENT7747,PP123,anf_fun3723732,anf_fun3733733,_plus14);
}};
$e95719572.stack[R.EXN_STACKHEIGHT++] = $ss95759576;
}
if(R.isPyretException($e95719572)) {
$e95719572.pyretStack.push(L[862]);
}
throw $e95719572;
}
var $ret95779578 = $Hanf_arg21799582($z95739574,INDENT7747,PP123,anf_fun3723732,anf_fun3733733,_plus14);
++R.GAS;
return $ret95779578;
};
var $Hanf_arg21799582 = function(anf_arg3799581,INDENT7747,PP123,anf_fun3723732,anf_fun3733733,_plus14) {
var $z95859586 = D;
var $f95919592 = function(_) {
return R.isFunction(anf_fun3733733)?anf_fun3733733.app(INDENT7747,anf_arg3799581):R.ffi.throwNonFunApp(L[863],anf_fun3733733,[INDENT7747,anf_arg3799581]);
};
try {
if(--R.GAS > 0) {
$z95859586 = $f95919592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95919592,
"from":L[863]});
}
} catch($e95839584) {
if(R.isCont($e95839584)) {
var $ss95879588 = {"from":L[863],
"go":function(anf_arg3809593) {
return $Hanf_arg21789594(anf_arg3809593,PP123,anf_fun3723732,_plus14);
}};
$e95839584.stack[R.EXN_STACKHEIGHT++] = $ss95879588;
}
if(R.isPyretException($e95839584)) {
$e95839584.pyretStack.push(L[863]);
}
throw $e95839584;
}
var $ret95899590 = $Hanf_arg21789594($z95859586,PP123,anf_fun3723732,_plus14);
++R.GAS;
return $ret95899590;
};
var $Hanf_arg21789594 = function(anf_arg3809593,PP123,anf_fun3723732,_plus14) {
var $z95979598 = D;
var $f96039604 = function(_) {
return R.isFunction(anf_fun3723732)?anf_fun3723732.app(anf_arg3809593):R.ffi.throwNonFunApp(L[864],anf_fun3723732,[anf_arg3809593]);
};
try {
if(--R.GAS > 0) {
$z95979598 = $f96039604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96039604,
"from":L[864]});
}
} catch($e95959596) {
if(R.isCont($e95959596)) {
var $ss95999600 = {"from":L[864],
"go":function(anf_arg3819605) {
return $Hanf_arg21779606(anf_arg3819605,PP123,_plus14);
}};
$e95959596.stack[R.EXN_STACKHEIGHT++] = $ss95999600;
}
if(R.isPyretException($e95959596)) {
$e95959596.pyretStack.push(L[864]);
}
throw $e95959596;
}
var $ret96019602 = $Hanf_arg21779606($z95979598,PP123,_plus14);
++R.GAS;
return $ret96019602;
};
var $Hanf_arg21779606 = function(anf_arg3819605,PP123,_plus14) {
var anf_fun3829617 = G(PP123,"str",L[866]);
var $z96099610 = D;
var $f96159616 = function(_) {
return R.isFunction(anf_fun3829617)?anf_fun3829617.app((";")):R.ffi.throwNonFunApp(L[865],anf_fun3829617,[(";")]);
};
try {
if(--R.GAS > 0) {
$z96099610 = $f96159616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96159616,
"from":L[865]});
}
} catch($e96079608) {
if(R.isCont($e96079608)) {
var $ss96119612 = {"from":L[865],
"go":function(anf_arg3839618) {
return $Hanf_arg21769619(anf_arg3839618,anf_arg3819605,_plus14);
}};
$e96079608.stack[R.EXN_STACKHEIGHT++] = $ss96119612;
}
if(R.isPyretException($e96079608)) {
$e96079608.pyretStack.push(L[865]);
}
throw $e96079608;
}
var $ret96139614 = $Hanf_arg21769619($z96099610,anf_arg3819605,_plus14);
++R.GAS;
return $ret96139614;
};
var $Hanf_arg21769619 = function(anf_arg3839618,anf_arg3819605,_plus14) {
var $z96229623 = D;
var $f96289629 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3819605,anf_arg3839618):R.ffi.throwNonFunApp(L[413],_plus14,[anf_arg3819605,anf_arg3839618]);
};
try {
if(--R.GAS > 0) {
$z96229623 = $f96289629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96289629,
"from":L[413]});
}
} catch($e96209621) {
if(R.isCont($e96209621)) {
var $ss96249625 = {"from":L[413],
"go":function(ann_DASH_check_DASH_temp3719630) {
return $Hann_DASH_check_DASH_temp21759631(ann_DASH_check_DASH_temp3719630);
}};
$e96209621.stack[R.EXN_STACKHEIGHT++] = $ss96249625;
}
if(R.isPyretException($e96209621)) {
$e96209621.pyretStack.push(L[413]);
}
throw $e96209621;
}
var $ret96269627 = $Hann_DASH_check_DASH_temp21759631($z96229623);
++R.GAS;
return $ret96269627;
};
var $Hann_DASH_check_DASH_temp21759631 = function(ann_DASH_check_DASH_temp3719630) {
return ann_DASH_check_DASH_temp3719630;
};
var $Hanf_begin_app_dropped21743749 = function(anf_begin_app_dropped21703747,printer2383746,self2373748) {
var anf_bracket3689645 = G(self2373748,"exp",L[869]);
var anf_fun3699642 = G(anf_bracket3689645,"print-ugly-source",L[868]);
var $z96349635 = D;
var $f96409641 = function(_) {
return R.isFunction(anf_fun3699642)?anf_fun3699642.app(printer2383746):R.ffi.throwNonFunApp(L[867],anf_fun3699642,[printer2383746]);
};
try {
if(--R.GAS > 0) {
$z96349635 = $f96409641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96409641,
"from":L[867]});
}
} catch($e96329633) {
if(R.isCont($e96329633)) {
var $ss96369637 = {"from":L[867],
"go":function(anf_begin_app_dropped21719643) {
return $Hanf_begin_app_dropped21739644(anf_begin_app_dropped21719643,printer2383746);
}};
$e96329633.stack[R.EXN_STACKHEIGHT++] = $ss96369637;
}
if(R.isPyretException($e96329633)) {
$e96329633.pyretStack.push(L[867]);
}
throw $e96329633;
}
var $ret96389639 = $Hanf_begin_app_dropped21739644($z96349635,printer2383746);
++R.GAS;
return $ret96389639;
};
var $Hanf_begin_app_dropped21739644 = function(anf_begin_app_dropped21719643,printer2383746) {
var $z96489649 = D;
var $f96549655 = function(_) {
return R.isFunction(printer2383746)?printer2383746.app((";")):R.ffi.throwNonFunApp(L[415],printer2383746,[(";")]);
};
try {
if(--R.GAS > 0) {
$z96489649 = $f96549655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96549655,
"from":L[415]});
}
} catch($e96469647) {
if(R.isCont($e96469647)) {
var $ss96509651 = {"from":L[415],
"go":function(ann_DASH_check_DASH_temp3679656) {
return $Hann_DASH_check_DASH_temp21729657(ann_DASH_check_DASH_temp3679656);
}};
$e96469647.stack[R.EXN_STACKHEIGHT++] = $ss96509651;
}
if(R.isPyretException($e96469647)) {
$e96469647.pyretStack.push(L[415]);
}
throw $e96469647;
}
var $ret96529653 = $Hann_DASH_check_DASH_temp21729657($z96489649);
++R.GAS;
return $ret96529653;
};
var $Hann_DASH_check_DASH_temp21729657 = function(ann_DASH_check_DASH_temp3679656) {
return ann_DASH_check_DASH_temp3679656;
};
var $Hanf_arg21693762 = function(anf_arg3633761,_plus14) {
var $z96609661 = D;
var $f96669667 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3633761,(")")):R.ffi.throwNonFunApp(L[373],_plus14,[anf_arg3633761,(")")]);
};
try {
if(--R.GAS > 0) {
$z96609661 = $f96669667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96669667,
"from":L[373]});
}
} catch($e96589659) {
if(R.isCont($e96589659)) {
var $ss96629663 = {"from":L[373],
"go":function(anf_arg3649668) {
return $Hanf_arg21689669(anf_arg3649668,_plus14);
}};
$e96589659.stack[R.EXN_STACKHEIGHT++] = $ss96629663;
}
if(R.isPyretException($e96589659)) {
$e96589659.pyretStack.push(L[373]);
}
throw $e96589659;
}
var $ret96649665 = $Hanf_arg21689669($z96609661,_plus14);
++R.GAS;
return $ret96649665;
};
var $Hanf_arg21689669 = function(anf_arg3649668,_plus14) {
var $z96729673 = D;
var $f96789679 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg3649668):R.ffi.throwNonFunApp(L[373],_plus14,[("("),anf_arg3649668]);
};
try {
if(--R.GAS > 0) {
$z96729673 = $f96789679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96789679,
"from":L[373]});
}
} catch($e96709671) {
if(R.isCont($e96709671)) {
var $ss96749675 = {"from":L[373],
"go":function(anf_arg3659680) {
return $Hanf_arg21679681(anf_arg3659680,_plus14);
}};
$e96709671.stack[R.EXN_STACKHEIGHT++] = $ss96749675;
}
if(R.isPyretException($e96709671)) {
$e96709671.pyretStack.push(L[373]);
}
throw $e96709671;
}
var $ret96769677 = $Hanf_arg21679681($z96729673,_plus14);
++R.GAS;
return $ret96769677;
};
var $Hanf_arg21679681 = function(anf_arg3659680,_plus14) {
var $z96849685 = D;
var $f96909691 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-throw"),anf_arg3659680):R.ffi.throwNonFunApp(L[373],_plus14,[("j-throw"),anf_arg3659680]);
};
try {
if(--R.GAS > 0) {
$z96849685 = $f96909691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96909691,
"from":L[373]});
}
} catch($e96829683) {
if(R.isCont($e96829683)) {
var $ss96869687 = {"from":L[373],
"go":function(ann_DASH_check_DASH_temp3619692) {
return $Hann_DASH_check_DASH_temp21669693(ann_DASH_check_DASH_temp3619692);
}};
$e96829683.stack[R.EXN_STACKHEIGHT++] = $ss96869687;
}
if(R.isPyretException($e96829683)) {
$e96829683.pyretStack.push(L[373]);
}
throw $e96829683;
}
var $ret96889689 = $Hann_DASH_check_DASH_temp21669693($z96849685);
++R.GAS;
return $ret96889689;
};
var $Hann_DASH_check_DASH_temp21669693 = function(ann_DASH_check_DASH_temp3619692) {
return ann_DASH_check_DASH_temp3619692;
};
var $Hcont_tail_arg21643778 = function(cont_tail_arg3583776,if_helper3503777) {
if(--R.GAS > 0) {
$z96949695 = R.isFunction(if_helper3503777)?if_helper3503777.app(cont_tail_arg3583776):R.ffi.throwNonFunApp(L[373],if_helper3503777,[cont_tail_arg3583776]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper3503777)?if_helper3503777.app(cont_tail_arg3583776):R.ffi.throwNonFunApp(L[373],if_helper3503777,[cont_tail_arg3583776]);
},
"from":L[373]});
}
++R.GAS;
return $z96949695;
};
var $Hcont_tail_arg21653793 = function(cont_tail_arg3553792,if_helper3503777) {
if(--R.GAS > 0) {
$z96969697 = R.isFunction(if_helper3503777)?if_helper3503777.app(cont_tail_arg3553792):R.ffi.throwNonFunApp(L[373],if_helper3503777,[cont_tail_arg3553792]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper3503777)?if_helper3503777.app(cont_tail_arg3553792):R.ffi.throwNonFunApp(L[373],if_helper3503777,[cont_tail_arg3553792]);
},
"from":L[373]});
}
++R.GAS;
return $z96969697;
};
var $Hanf_arg21633814 = function(anf_arg3313812,INDENT7747,PP123,anf_fun3293813,self2351577,_plus14) {
var anf_bracket3329711 = G(self2351577,"body",L[872]);
var anf_fun3339708 = G(anf_bracket3329711,"tosource",L[871]);
var $z97009701 = D;
var $f97069707 = function(_) {
return R.isFunction(anf_fun3339708)?anf_fun3339708.app():R.ffi.throwNonFunApp(L[870],anf_fun3339708,[]);
};
try {
if(--R.GAS > 0) {
$z97009701 = $f97069707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97069707,
"from":L[870]});
}
} catch($e96989699) {
if(R.isCont($e96989699)) {
var $ss97029703 = {"from":L[870],
"go":function(anf_arg3349709) {
return $Hanf_arg21629710(anf_arg3349709,INDENT7747,PP123,anf_arg3313812,anf_fun3293813,self2351577,_plus14);
}};
$e96989699.stack[R.EXN_STACKHEIGHT++] = $ss97029703;
}
if(R.isPyretException($e96989699)) {
$e96989699.pyretStack.push(L[870]);
}
throw $e96989699;
}
var $ret97049705 = $Hanf_arg21629710($z97009701,INDENT7747,PP123,anf_arg3313812,anf_fun3293813,self2351577,_plus14);
++R.GAS;
return $ret97049705;
};
var $Hanf_arg21629710 = function(anf_arg3349709,INDENT7747,PP123,anf_arg3313812,anf_fun3293813,self2351577,_plus14) {
var anf_arg3359722 = G(PP123,"rbrace",L[874]);
var $z97149715 = D;
var $f97209721 = function(_) {
return R.isFunction(anf_fun3293813)?anf_fun3293813.app(INDENT7747,(1),anf_arg3313812,anf_arg3349709,anf_arg3359722):R.ffi.throwNonFunApp(L[873],anf_fun3293813,[INDENT7747,(1),anf_arg3313812,anf_arg3349709,anf_arg3359722]);
};
try {
if(--R.GAS > 0) {
$z97149715 = $f97209721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97209721,
"from":L[873]});
}
} catch($e97129713) {
if(R.isCont($e97129713)) {
var $ss97169717 = {"from":L[873],
"go":function(anf_arg3369723) {
return $Hanf_arg21619724(anf_arg3369723,INDENT7747,PP123,self2351577,_plus14);
}};
$e97129713.stack[R.EXN_STACKHEIGHT++] = $ss97169717;
}
if(R.isPyretException($e97129713)) {
$e97129713.pyretStack.push(L[873]);
}
throw $e97129713;
}
var $ret97189719 = $Hanf_arg21619724($z97149715,INDENT7747,PP123,self2351577,_plus14);
++R.GAS;
return $ret97189719;
};
var $Hanf_arg21619724 = function(anf_arg3369723,INDENT7747,PP123,self2351577,_plus14) {
var anf_fun3379737 = G(PP123,"surround",L[878]);
var anf_fun3389738 = G(PP123,"str",L[877]);
var anf_arg3399735 = G(self2351577,"exn",L[876]);
var $z97279728 = D;
var $f97339734 = function(_) {
return R.isFunction(_plus14)?_plus14.app((" catch("),anf_arg3399735):R.ffi.throwNonFunApp(L[875],_plus14,[(" catch("),anf_arg3399735]);
};
try {
if(--R.GAS > 0) {
$z97279728 = $f97339734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97339734,
"from":L[875]});
}
} catch($e97259726) {
if(R.isCont($e97259726)) {
var $ss97299730 = {"from":L[875],
"go":function(anf_arg3409736) {
return $Hanf_arg21609739(anf_arg3409736,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,anf_fun3389738,self2351577,_plus14);
}};
$e97259726.stack[R.EXN_STACKHEIGHT++] = $ss97299730;
}
if(R.isPyretException($e97259726)) {
$e97259726.pyretStack.push(L[875]);
}
throw $e97259726;
}
var $ret97319732 = $Hanf_arg21609739($z97279728,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,anf_fun3389738,self2351577,_plus14);
++R.GAS;
return $ret97319732;
};
var $Hanf_arg21609739 = function(anf_arg3409736,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,anf_fun3389738,self2351577,_plus14) {
var $z97429743 = D;
var $f97489749 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3409736,(") {")):R.ffi.throwNonFunApp(L[875],_plus14,[anf_arg3409736,(") {")]);
};
try {
if(--R.GAS > 0) {
$z97429743 = $f97489749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97489749,
"from":L[875]});
}
} catch($e97409741) {
if(R.isCont($e97409741)) {
var $ss97449745 = {"from":L[875],
"go":function(anf_arg3419750) {
return $Hanf_arg21599751(anf_arg3419750,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,anf_fun3389738,self2351577,_plus14);
}};
$e97409741.stack[R.EXN_STACKHEIGHT++] = $ss97449745;
}
if(R.isPyretException($e97409741)) {
$e97409741.pyretStack.push(L[875]);
}
throw $e97409741;
}
var $ret97469747 = $Hanf_arg21599751($z97429743,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,anf_fun3389738,self2351577,_plus14);
++R.GAS;
return $ret97469747;
};
var $Hanf_arg21599751 = function(anf_arg3419750,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,anf_fun3389738,self2351577,_plus14) {
var $z97549755 = D;
var $f97609761 = function(_) {
return R.isFunction(anf_fun3389738)?anf_fun3389738.app(anf_arg3419750):R.ffi.throwNonFunApp(L[879],anf_fun3389738,[anf_arg3419750]);
};
try {
if(--R.GAS > 0) {
$z97549755 = $f97609761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97609761,
"from":L[879]});
}
} catch($e97529753) {
if(R.isCont($e97529753)) {
var $ss97569757 = {"from":L[879],
"go":function(anf_arg3429762) {
return $Hanf_arg21589763(anf_arg3429762,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,self2351577,_plus14);
}};
$e97529753.stack[R.EXN_STACKHEIGHT++] = $ss97569757;
}
if(R.isPyretException($e97529753)) {
$e97529753.pyretStack.push(L[879]);
}
throw $e97529753;
}
var $ret97589759 = $Hanf_arg21589763($z97549755,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,self2351577,_plus14);
++R.GAS;
return $ret97589759;
};
var $Hanf_arg21589763 = function(anf_arg3429762,INDENT7747,PP123,anf_arg3369723,anf_fun3379737,self2351577,_plus14) {
var anf_bracket3439777 = G(self2351577,"catch",L[882]);
var anf_fun3449774 = G(anf_bracket3439777,"tosource",L[881]);
var $z97669767 = D;
var $f97729773 = function(_) {
return R.isFunction(anf_fun3449774)?anf_fun3449774.app():R.ffi.throwNonFunApp(L[880],anf_fun3449774,[]);
};
try {
if(--R.GAS > 0) {
$z97669767 = $f97729773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97729773,
"from":L[880]});
}
} catch($e97649765) {
if(R.isCont($e97649765)) {
var $ss97689769 = {"from":L[880],
"go":function(anf_arg3459775) {
return $Hanf_arg21579776(anf_arg3459775,INDENT7747,PP123,anf_arg3369723,anf_arg3429762,anf_fun3379737,_plus14);
}};
$e97649765.stack[R.EXN_STACKHEIGHT++] = $ss97689769;
}
if(R.isPyretException($e97649765)) {
$e97649765.pyretStack.push(L[880]);
}
throw $e97649765;
}
var $ret97709771 = $Hanf_arg21579776($z97669767,INDENT7747,PP123,anf_arg3369723,anf_arg3429762,anf_fun3379737,_plus14);
++R.GAS;
return $ret97709771;
};
var $Hanf_arg21579776 = function(anf_arg3459775,INDENT7747,PP123,anf_arg3369723,anf_arg3429762,anf_fun3379737,_plus14) {
var anf_arg3469788 = G(PP123,"rbrace",L[884]);
var $z97809781 = D;
var $f97869787 = function(_) {
return R.isFunction(anf_fun3379737)?anf_fun3379737.app(INDENT7747,(1),anf_arg3429762,anf_arg3459775,anf_arg3469788):R.ffi.throwNonFunApp(L[883],anf_fun3379737,[INDENT7747,(1),anf_arg3429762,anf_arg3459775,anf_arg3469788]);
};
try {
if(--R.GAS > 0) {
$z97809781 = $f97869787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97869787,
"from":L[883]});
}
} catch($e97789779) {
if(R.isCont($e97789779)) {
var $ss97829783 = {"from":L[883],
"go":function(anf_arg3479789) {
return $Hanf_arg21569790(anf_arg3479789,anf_arg3369723,_plus14);
}};
$e97789779.stack[R.EXN_STACKHEIGHT++] = $ss97829783;
}
if(R.isPyretException($e97789779)) {
$e97789779.pyretStack.push(L[883]);
}
throw $e97789779;
}
var $ret97849785 = $Hanf_arg21569790($z97809781,anf_arg3369723,_plus14);
++R.GAS;
return $ret97849785;
};
var $Hanf_arg21569790 = function(anf_arg3479789,anf_arg3369723,_plus14) {
var $z97939794 = D;
var $f97999800 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3369723,anf_arg3479789):R.ffi.throwNonFunApp(L[420],_plus14,[anf_arg3369723,anf_arg3479789]);
};
try {
if(--R.GAS > 0) {
$z97939794 = $f97999800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97999800,
"from":L[420]});
}
} catch($e97919792) {
if(R.isCont($e97919792)) {
var $ss97959796 = {"from":L[420],
"go":function(ann_DASH_check_DASH_temp3289801) {
return $Hann_DASH_check_DASH_temp21559802(ann_DASH_check_DASH_temp3289801);
}};
$e97919792.stack[R.EXN_STACKHEIGHT++] = $ss97959796;
}
if(R.isPyretException($e97919792)) {
$e97919792.pyretStack.push(L[420]);
}
throw $e97919792;
}
var $ret97979798 = $Hann_DASH_check_DASH_temp21559802($z97939794);
++R.GAS;
return $ret97979798;
};
var $Hann_DASH_check_DASH_temp21559802 = function(ann_DASH_check_DASH_temp3289801) {
return ann_DASH_check_DASH_temp3289801;
};
var $Hanf_begin_app_dropped21543828 = function(anf_begin_app_dropped21443826,printer2343825,self2333827,_plus14) {
var anf_bracket3209816 = G(self2333827,"body",L[887]);
var anf_fun3219813 = G(anf_bracket3209816,"print-ugly-source",L[886]);
var $z98059806 = D;
var $f98119812 = function(_) {
return R.isFunction(anf_fun3219813)?anf_fun3219813.app(printer2343825):R.ffi.throwNonFunApp(L[885],anf_fun3219813,[printer2343825]);
};
try {
if(--R.GAS > 0) {
$z98059806 = $f98119812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98119812,
"from":L[885]});
}
} catch($e98039804) {
if(R.isCont($e98039804)) {
var $ss98079808 = {"from":L[885],
"go":function(anf_begin_app_dropped21459814) {
return $Hanf_begin_app_dropped21539815(anf_begin_app_dropped21459814,printer2343825,self2333827,_plus14);
}};
$e98039804.stack[R.EXN_STACKHEIGHT++] = $ss98079808;
}
if(R.isPyretException($e98039804)) {
$e98039804.pyretStack.push(L[885]);
}
throw $e98039804;
}
var $ret98099810 = $Hanf_begin_app_dropped21539815($z98059806,printer2343825,self2333827,_plus14);
++R.GAS;
return $ret98099810;
};
var $Hanf_begin_app_dropped21539815 = function(anf_begin_app_dropped21459814,printer2343825,self2333827,_plus14) {
var anf_arg3229827 = G(self2333827,"exn",L[889]);
var $z98199820 = D;
var $f98259826 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("\n} catch("),anf_arg3229827):R.ffi.throwNonFunApp(L[888],_plus14,[("\n} catch("),anf_arg3229827]);
};
try {
if(--R.GAS > 0) {
$z98199820 = $f98259826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98259826,
"from":L[888]});
}
} catch($e98179818) {
if(R.isCont($e98179818)) {
var $ss98219822 = {"from":L[888],
"go":function(anf_arg3239828) {
return $Hanf_arg21529829(anf_arg3239828,printer2343825,self2333827,_plus14);
}};
$e98179818.stack[R.EXN_STACKHEIGHT++] = $ss98219822;
}
if(R.isPyretException($e98179818)) {
$e98179818.pyretStack.push(L[888]);
}
throw $e98179818;
}
var $ret98239824 = $Hanf_arg21529829($z98199820,printer2343825,self2333827,_plus14);
++R.GAS;
return $ret98239824;
};
var $Hanf_arg21529829 = function(anf_arg3239828,printer2343825,self2333827,_plus14) {
var $z98329833 = D;
var $f98389839 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3239828,(") {\n")):R.ffi.throwNonFunApp(L[888],_plus14,[anf_arg3239828,(") {\n")]);
};
try {
if(--R.GAS > 0) {
$z98329833 = $f98389839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98389839,
"from":L[888]});
}
} catch($e98309831) {
if(R.isCont($e98309831)) {
var $ss98349835 = {"from":L[888],
"go":function(anf_arg3249840) {
return $Hanf_arg21519841(anf_arg3249840,printer2343825,self2333827);
}};
$e98309831.stack[R.EXN_STACKHEIGHT++] = $ss98349835;
}
if(R.isPyretException($e98309831)) {
$e98309831.pyretStack.push(L[888]);
}
throw $e98309831;
}
var $ret98369837 = $Hanf_arg21519841($z98329833,printer2343825,self2333827);
++R.GAS;
return $ret98369837;
};
var $Hanf_arg21519841 = function(anf_arg3249840,printer2343825,self2333827) {
var $z98449845 = D;
var $f98509851 = function(_) {
return R.isFunction(printer2343825)?printer2343825.app(anf_arg3249840):R.ffi.throwNonFunApp(L[890],printer2343825,[anf_arg3249840]);
};
try {
if(--R.GAS > 0) {
$z98449845 = $f98509851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98509851,
"from":L[890]});
}
} catch($e98429843) {
if(R.isCont($e98429843)) {
var $ss98469847 = {"from":L[890],
"go":function(anf_begin_app_dropped21469852) {
return $Hanf_begin_app_dropped21509853(anf_begin_app_dropped21469852,printer2343825,self2333827);
}};
$e98429843.stack[R.EXN_STACKHEIGHT++] = $ss98469847;
}
if(R.isPyretException($e98429843)) {
$e98429843.pyretStack.push(L[890]);
}
throw $e98429843;
}
var $ret98489849 = $Hanf_begin_app_dropped21509853($z98449845,printer2343825,self2333827);
++R.GAS;
return $ret98489849;
};
var $Hanf_begin_app_dropped21509853 = function(anf_begin_app_dropped21469852,printer2343825,self2333827) {
var anf_bracket3259867 = G(self2333827,"catch",L[893]);
var anf_fun3269864 = G(anf_bracket3259867,"print-ugly-source",L[892]);
var $z98569857 = D;
var $f98629863 = function(_) {
return R.isFunction(anf_fun3269864)?anf_fun3269864.app(printer2343825):R.ffi.throwNonFunApp(L[891],anf_fun3269864,[printer2343825]);
};
try {
if(--R.GAS > 0) {
$z98569857 = $f98629863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98629863,
"from":L[891]});
}
} catch($e98549855) {
if(R.isCont($e98549855)) {
var $ss98589859 = {"from":L[891],
"go":function(anf_begin_app_dropped21479865) {
return $Hanf_begin_app_dropped21499866(anf_begin_app_dropped21479865,printer2343825);
}};
$e98549855.stack[R.EXN_STACKHEIGHT++] = $ss98589859;
}
if(R.isPyretException($e98549855)) {
$e98549855.pyretStack.push(L[891]);
}
throw $e98549855;
}
var $ret98609861 = $Hanf_begin_app_dropped21499866($z98569857,printer2343825);
++R.GAS;
return $ret98609861;
};
var $Hanf_begin_app_dropped21499866 = function(anf_begin_app_dropped21479865,printer2343825) {
var $z98709871 = D;
var $f98769877 = function(_) {
return R.isFunction(printer2343825)?printer2343825.app(("\n}")):R.ffi.throwNonFunApp(L[422],printer2343825,[("\n}")]);
};
try {
if(--R.GAS > 0) {
$z98709871 = $f98769877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98769877,
"from":L[422]});
}
} catch($e98689869) {
if(R.isCont($e98689869)) {
var $ss98729873 = {"from":L[422],
"go":function(ann_DASH_check_DASH_temp3199878) {
return $Hann_DASH_check_DASH_temp21489879(ann_DASH_check_DASH_temp3199878);
}};
$e98689869.stack[R.EXN_STACKHEIGHT++] = $ss98729873;
}
if(R.isPyretException($e98689869)) {
$e98689869.pyretStack.push(L[422]);
}
throw $e98689869;
}
var $ret98749875 = $Hann_DASH_check_DASH_temp21489879($z98709871);
++R.GAS;
return $ret98749875;
};
var $Hann_DASH_check_DASH_temp21489879 = function(ann_DASH_check_DASH_temp3199878) {
return ann_DASH_check_DASH_temp3199878;
};
var $Hanf_arg21433842 = function(anf_arg3073840,self393841,_plus14,torepr18) {
var anf_arg3089890 = G(self393841,"exn",L[374]);
var $z98829883 = D;
var $f98889889 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg3089890):R.ffi.throwNonFunApp(L[374],torepr18,[anf_arg3089890]);
};
try {
if(--R.GAS > 0) {
$z98829883 = $f98889889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98889889,
"from":L[374]});
}
} catch($e98809881) {
if(R.isCont($e98809881)) {
var $ss98849885 = {"from":L[374],
"go":function(anf_arg3099891) {
return $Hanf_arg21429892(anf_arg3099891,anf_arg3073840,self393841,_plus14,torepr18);
}};
$e98809881.stack[R.EXN_STACKHEIGHT++] = $ss98849885;
}
if(R.isPyretException($e98809881)) {
$e98809881.pyretStack.push(L[374]);
}
throw $e98809881;
}
var $ret98869887 = $Hanf_arg21429892($z98829883,anf_arg3073840,self393841,_plus14,torepr18);
++R.GAS;
return $ret98869887;
};
var $Hanf_arg21429892 = function(anf_arg3099891,anf_arg3073840,self393841,_plus14,torepr18) {
var $z98959896 = D;
var $f99019902 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg3099891):R.ffi.throwNonFunApp(L[374],_plus14,[(", "),anf_arg3099891]);
};
try {
if(--R.GAS > 0) {
$z98959896 = $f99019902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99019902,
"from":L[374]});
}
} catch($e98939894) {
if(R.isCont($e98939894)) {
var $ss98979898 = {"from":L[374],
"go":function(anf_arg3109903) {
return $Hanf_arg21419904(anf_arg3109903,anf_arg3073840,self393841,_plus14,torepr18);
}};
$e98939894.stack[R.EXN_STACKHEIGHT++] = $ss98979898;
}
if(R.isPyretException($e98939894)) {
$e98939894.pyretStack.push(L[374]);
}
throw $e98939894;
}
var $ret98999900 = $Hanf_arg21419904($z98959896,anf_arg3073840,self393841,_plus14,torepr18);
++R.GAS;
return $ret98999900;
};
var $Hanf_arg21419904 = function(anf_arg3109903,anf_arg3073840,self393841,_plus14,torepr18) {
var $z99079908 = D;
var $f99139914 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3073840,anf_arg3109903):R.ffi.throwNonFunApp(L[374],_plus14,[anf_arg3073840,anf_arg3109903]);
};
try {
if(--R.GAS > 0) {
$z99079908 = $f99139914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99139914,
"from":L[374]});
}
} catch($e99059906) {
if(R.isCont($e99059906)) {
var $ss99099910 = {"from":L[374],
"go":function(anf_arg3119915) {
return $Hanf_arg21409916(anf_arg3119915,self393841,_plus14,torepr18);
}};
$e99059906.stack[R.EXN_STACKHEIGHT++] = $ss99099910;
}
if(R.isPyretException($e99059906)) {
$e99059906.pyretStack.push(L[374]);
}
throw $e99059906;
}
var $ret99119912 = $Hanf_arg21409916($z99079908,self393841,_plus14,torepr18);
++R.GAS;
return $ret99119912;
};
var $Hanf_arg21409916 = function(anf_arg3119915,self393841,_plus14,torepr18) {
var anf_arg3129927 = G(self393841,"catch",L[374]);
var $z99199920 = D;
var $f99259926 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg3129927):R.ffi.throwNonFunApp(L[374],torepr18,[anf_arg3129927]);
};
try {
if(--R.GAS > 0) {
$z99199920 = $f99259926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99259926,
"from":L[374]});
}
} catch($e99179918) {
if(R.isCont($e99179918)) {
var $ss99219922 = {"from":L[374],
"go":function(anf_arg3139928) {
return $Hanf_arg21399929(anf_arg3139928,anf_arg3119915,_plus14);
}};
$e99179918.stack[R.EXN_STACKHEIGHT++] = $ss99219922;
}
if(R.isPyretException($e99179918)) {
$e99179918.pyretStack.push(L[374]);
}
throw $e99179918;
}
var $ret99239924 = $Hanf_arg21399929($z99199920,anf_arg3119915,_plus14);
++R.GAS;
return $ret99239924;
};
var $Hanf_arg21399929 = function(anf_arg3139928,anf_arg3119915,_plus14) {
var $z99329933 = D;
var $f99389939 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg3139928):R.ffi.throwNonFunApp(L[374],_plus14,[(", "),anf_arg3139928]);
};
try {
if(--R.GAS > 0) {
$z99329933 = $f99389939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99389939,
"from":L[374]});
}
} catch($e99309931) {
if(R.isCont($e99309931)) {
var $ss99349935 = {"from":L[374],
"go":function(anf_arg3149940) {
return $Hanf_arg21389941(anf_arg3149940,anf_arg3119915,_plus14);
}};
$e99309931.stack[R.EXN_STACKHEIGHT++] = $ss99349935;
}
if(R.isPyretException($e99309931)) {
$e99309931.pyretStack.push(L[374]);
}
throw $e99309931;
}
var $ret99369937 = $Hanf_arg21389941($z99329933,anf_arg3119915,_plus14);
++R.GAS;
return $ret99369937;
};
var $Hanf_arg21389941 = function(anf_arg3149940,anf_arg3119915,_plus14) {
var $z99449945 = D;
var $f99509951 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3119915,anf_arg3149940):R.ffi.throwNonFunApp(L[374],_plus14,[anf_arg3119915,anf_arg3149940]);
};
try {
if(--R.GAS > 0) {
$z99449945 = $f99509951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99509951,
"from":L[374]});
}
} catch($e99429943) {
if(R.isCont($e99429943)) {
var $ss99469947 = {"from":L[374],
"go":function(anf_arg3159952) {
return $Hanf_arg21379953(anf_arg3159952,_plus14);
}};
$e99429943.stack[R.EXN_STACKHEIGHT++] = $ss99469947;
}
if(R.isPyretException($e99429943)) {
$e99429943.pyretStack.push(L[374]);
}
throw $e99429943;
}
var $ret99489949 = $Hanf_arg21379953($z99449945,_plus14);
++R.GAS;
return $ret99489949;
};
var $Hanf_arg21379953 = function(anf_arg3159952,_plus14) {
var $z99569957 = D;
var $f99629963 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg3159952,(")")):R.ffi.throwNonFunApp(L[374],_plus14,[anf_arg3159952,(")")]);
};
try {
if(--R.GAS > 0) {
$z99569957 = $f99629963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99629963,
"from":L[374]});
}
} catch($e99549955) {
if(R.isCont($e99549955)) {
var $ss99589959 = {"from":L[374],
"go":function(anf_arg3169964) {
return $Hanf_arg21369965(anf_arg3169964,_plus14);
}};
$e99549955.stack[R.EXN_STACKHEIGHT++] = $ss99589959;
}
if(R.isPyretException($e99549955)) {
$e99549955.pyretStack.push(L[374]);
}
throw $e99549955;
}
var $ret99609961 = $Hanf_arg21369965($z99569957,_plus14);
++R.GAS;
return $ret99609961;
};
var $Hanf_arg21369965 = function(anf_arg3169964,_plus14) {
var $z99689969 = D;
var $f99749975 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg3169964):R.ffi.throwNonFunApp(L[374],_plus14,[("("),anf_arg3169964]);
};
try {
if(--R.GAS > 0) {
$z99689969 = $f99749975();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99749975,
"from":L[374]});
}
} catch($e99669967) {
if(R.isCont($e99669967)) {
var $ss99709971 = {"from":L[374],
"go":function(anf_arg3179976) {
return $Hanf_arg21359977(anf_arg3179976,_plus14);
}};
$e99669967.stack[R.EXN_STACKHEIGHT++] = $ss99709971;
}
if(R.isPyretException($e99669967)) {
$e99669967.pyretStack.push(L[374]);
}
throw $e99669967;
}
var $ret99729973 = $Hanf_arg21359977($z99689969,_plus14);
++R.GAS;
return $ret99729973;
};
var $Hanf_arg21359977 = function(anf_arg3179976,_plus14) {
var $z99809981 = D;
var $f99869987 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-try-catch"),anf_arg3179976):R.ffi.throwNonFunApp(L[374],_plus14,[("j-try-catch"),anf_arg3179976]);
};
try {
if(--R.GAS > 0) {
$z99809981 = $f99869987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99869987,
"from":L[374]});
}
} catch($e99789979) {
if(R.isCont($e99789979)) {
var $ss99829983 = {"from":L[374],
"go":function(ann_DASH_check_DASH_temp3059988) {
return $Hann_DASH_check_DASH_temp21349989(ann_DASH_check_DASH_temp3059988);
}};
$e99789979.stack[R.EXN_STACKHEIGHT++] = $ss99829983;
}
if(R.isPyretException($e99789979)) {
$e99789979.pyretStack.push(L[374]);
}
throw $e99789979;
}
var $ret99849985 = $Hann_DASH_check_DASH_temp21349989($z99809981);
++R.GAS;
return $ret99849985;
};
var $Hann_DASH_check_DASH_temp21349989 = function(ann_DASH_check_DASH_temp3059988) {
return ann_DASH_check_DASH_temp3059988;
};
var $Hcont_tail_arg21323859 = function(cont_tail_arg3023857,if_helper2923858) {
if(--R.GAS > 0) {
$z99909991 = R.isFunction(if_helper2923858)?if_helper2923858.app(cont_tail_arg3023857):R.ffi.throwNonFunApp(L[374],if_helper2923858,[cont_tail_arg3023857]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper2923858)?if_helper2923858.app(cont_tail_arg3023857):R.ffi.throwNonFunApp(L[374],if_helper2923858,[cont_tail_arg3023857]);
},
"from":L[374]});
}
++R.GAS;
return $z99909991;
};
var $Hcont_tail_arg21333874 = function(cont_tail_arg2973873,if_helper2923858) {
if(--R.GAS > 0) {
$z99929993 = R.isFunction(if_helper2923858)?if_helper2923858.app(cont_tail_arg2973873):R.ffi.throwNonFunApp(L[374],if_helper2923858,[cont_tail_arg2973873]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper2923858)?if_helper2923858.app(cont_tail_arg2973873):R.ffi.throwNonFunApp(L[374],if_helper2923858,[cont_tail_arg2973873]);
},
"from":L[374]});
}
++R.GAS;
return $z99929993;
};
var $Hanf_arg21313894 = function(anf_arg2833893,PP123,self2291660,_plus14) {
var anf_bracket28410007 = G(self2291660,"expr",L[896]);
var anf_fun28510004 = G(anf_bracket28410007,"tosource",L[895]);
var $z99969997 = D;
var $f1000210003 = function(_) {
return R.isFunction(anf_fun28510004)?anf_fun28510004.app():R.ffi.throwNonFunApp(L[894],anf_fun28510004,[]);
};
try {
if(--R.GAS > 0) {
$z99969997 = $f1000210003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1000210003,
"from":L[894]});
}
} catch($e99949995) {
if(R.isCont($e99949995)) {
var $ss99989999 = {"from":L[894],
"go":function(anf_arg28610005) {
return $Hanf_arg213010006(anf_arg28610005,PP123,anf_arg2833893,_plus14);
}};
$e99949995.stack[R.EXN_STACKHEIGHT++] = $ss99989999;
}
if(R.isPyretException($e99949995)) {
$e99949995.pyretStack.push(L[894]);
}
throw $e99949995;
}
var $ret1000010001 = $Hanf_arg213010006($z99969997,PP123,anf_arg2833893,_plus14);
++R.GAS;
return $ret1000010001;
};
var $Hanf_arg213010006 = function(anf_arg28610005,PP123,anf_arg2833893,_plus14) {
var $z1001010011 = D;
var $f1001610017 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg2833893,anf_arg28610005):R.ffi.throwNonFunApp(L[897],_plus14,[anf_arg2833893,anf_arg28610005]);
};
try {
if(--R.GAS > 0) {
$z1001010011 = $f1001610017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1001610017,
"from":L[897]});
}
} catch($e1000810009) {
if(R.isCont($e1000810009)) {
var $ss1001210013 = {"from":L[897],
"go":function(anf_arg28710018) {
return $Hanf_arg212910019(anf_arg28710018,PP123,_plus14);
}};
$e1000810009.stack[R.EXN_STACKHEIGHT++] = $ss1001210013;
}
if(R.isPyretException($e1000810009)) {
$e1000810009.pyretStack.push(L[897]);
}
throw $e1000810009;
}
var $ret1001410015 = $Hanf_arg212910019($z1001010011,PP123,_plus14);
++R.GAS;
return $ret1001410015;
};
var $Hanf_arg212910019 = function(anf_arg28710018,PP123,_plus14) {
var anf_fun28810030 = G(PP123,"str",L[899]);
var $z1002210023 = D;
var $f1002810029 = function(_) {
return R.isFunction(anf_fun28810030)?anf_fun28810030.app((";")):R.ffi.throwNonFunApp(L[898],anf_fun28810030,[(";")]);
};
try {
if(--R.GAS > 0) {
$z1002210023 = $f1002810029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1002810029,
"from":L[898]});
}
} catch($e1002010021) {
if(R.isCont($e1002010021)) {
var $ss1002410025 = {"from":L[898],
"go":function(anf_arg28910031) {
return $Hanf_arg212810032(anf_arg28910031,anf_arg28710018,_plus14);
}};
$e1002010021.stack[R.EXN_STACKHEIGHT++] = $ss1002410025;
}
if(R.isPyretException($e1002010021)) {
$e1002010021.pyretStack.push(L[898]);
}
throw $e1002010021;
}
var $ret1002610027 = $Hanf_arg212810032($z1002210023,anf_arg28710018,_plus14);
++R.GAS;
return $ret1002610027;
};
var $Hanf_arg212810032 = function(anf_arg28910031,anf_arg28710018,_plus14) {
var $z1003510036 = D;
var $f1004110042 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg28710018,anf_arg28910031):R.ffi.throwNonFunApp(L[428],_plus14,[anf_arg28710018,anf_arg28910031]);
};
try {
if(--R.GAS > 0) {
$z1003510036 = $f1004110042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1004110042,
"from":L[428]});
}
} catch($e1003310034) {
if(R.isCont($e1003310034)) {
var $ss1003710038 = {"from":L[428],
"go":function(ann_DASH_check_DASH_temp28110043) {
return $Hann_DASH_check_DASH_temp212710044(ann_DASH_check_DASH_temp28110043);
}};
$e1003310034.stack[R.EXN_STACKHEIGHT++] = $ss1003710038;
}
if(R.isPyretException($e1003310034)) {
$e1003310034.pyretStack.push(L[428]);
}
throw $e1003310034;
}
var $ret1003910040 = $Hann_DASH_check_DASH_temp212710044($z1003510036);
++R.GAS;
return $ret1003910040;
};
var $Hann_DASH_check_DASH_temp212710044 = function(ann_DASH_check_DASH_temp28110043) {
return ann_DASH_check_DASH_temp28110043;
};
var $Hanf_begin_app_dropped21263908 = function(anf_begin_app_dropped21223906,printer2283905,self2273907) {
var anf_bracket27810058 = G(self2273907,"expr",L[902]);
var anf_fun27910055 = G(anf_bracket27810058,"print-ugly-source",L[901]);
var $z1004710048 = D;
var $f1005310054 = function(_) {
return R.isFunction(anf_fun27910055)?anf_fun27910055.app(printer2283905):R.ffi.throwNonFunApp(L[900],anf_fun27910055,[printer2283905]);
};
try {
if(--R.GAS > 0) {
$z1004710048 = $f1005310054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1005310054,
"from":L[900]});
}
} catch($e1004510046) {
if(R.isCont($e1004510046)) {
var $ss1004910050 = {"from":L[900],
"go":function(anf_begin_app_dropped212310056) {
return $Hanf_begin_app_dropped212510057(anf_begin_app_dropped212310056,printer2283905);
}};
$e1004510046.stack[R.EXN_STACKHEIGHT++] = $ss1004910050;
}
if(R.isPyretException($e1004510046)) {
$e1004510046.pyretStack.push(L[900]);
}
throw $e1004510046;
}
var $ret1005110052 = $Hanf_begin_app_dropped212510057($z1004710048,printer2283905);
++R.GAS;
return $ret1005110052;
};
var $Hanf_begin_app_dropped212510057 = function(anf_begin_app_dropped212310056,printer2283905) {
var $z1006110062 = D;
var $f1006710068 = function(_) {
return R.isFunction(printer2283905)?printer2283905.app((";")):R.ffi.throwNonFunApp(L[430],printer2283905,[(";")]);
};
try {
if(--R.GAS > 0) {
$z1006110062 = $f1006710068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1006710068,
"from":L[430]});
}
} catch($e1005910060) {
if(R.isCont($e1005910060)) {
var $ss1006310064 = {"from":L[430],
"go":function(ann_DASH_check_DASH_temp27710069) {
return $Hann_DASH_check_DASH_temp212410070(ann_DASH_check_DASH_temp27710069);
}};
$e1005910060.stack[R.EXN_STACKHEIGHT++] = $ss1006310064;
}
if(R.isPyretException($e1005910060)) {
$e1005910060.pyretStack.push(L[430]);
}
throw $e1005910060;
}
var $ret1006510066 = $Hann_DASH_check_DASH_temp212410070($z1006110062);
++R.GAS;
return $ret1006510066;
};
var $Hann_DASH_check_DASH_temp212410070 = function(ann_DASH_check_DASH_temp27710069) {
return ann_DASH_check_DASH_temp27710069;
};
var $Hanf_arg21213921 = function(anf_arg2733920,_plus14) {
var $z1007310074 = D;
var $f1007910080 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg2733920,(")")):R.ffi.throwNonFunApp(L[375],_plus14,[anf_arg2733920,(")")]);
};
try {
if(--R.GAS > 0) {
$z1007310074 = $f1007910080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1007910080,
"from":L[375]});
}
} catch($e1007110072) {
if(R.isCont($e1007110072)) {
var $ss1007510076 = {"from":L[375],
"go":function(anf_arg27410081) {
return $Hanf_arg212010082(anf_arg27410081,_plus14);
}};
$e1007110072.stack[R.EXN_STACKHEIGHT++] = $ss1007510076;
}
if(R.isPyretException($e1007110072)) {
$e1007110072.pyretStack.push(L[375]);
}
throw $e1007110072;
}
var $ret1007710078 = $Hanf_arg212010082($z1007310074,_plus14);
++R.GAS;
return $ret1007710078;
};
var $Hanf_arg212010082 = function(anf_arg27410081,_plus14) {
var $z1008510086 = D;
var $f1009110092 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg27410081):R.ffi.throwNonFunApp(L[375],_plus14,[("("),anf_arg27410081]);
};
try {
if(--R.GAS > 0) {
$z1008510086 = $f1009110092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1009110092,
"from":L[375]});
}
} catch($e1008310084) {
if(R.isCont($e1008310084)) {
var $ss1008710088 = {"from":L[375],
"go":function(anf_arg27510093) {
return $Hanf_arg211910094(anf_arg27510093,_plus14);
}};
$e1008310084.stack[R.EXN_STACKHEIGHT++] = $ss1008710088;
}
if(R.isPyretException($e1008310084)) {
$e1008310084.pyretStack.push(L[375]);
}
throw $e1008310084;
}
var $ret1008910090 = $Hanf_arg211910094($z1008510086,_plus14);
++R.GAS;
return $ret1008910090;
};
var $Hanf_arg211910094 = function(anf_arg27510093,_plus14) {
var $z1009710098 = D;
var $f1010310104 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-return"),anf_arg27510093):R.ffi.throwNonFunApp(L[375],_plus14,[("j-return"),anf_arg27510093]);
};
try {
if(--R.GAS > 0) {
$z1009710098 = $f1010310104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1010310104,
"from":L[375]});
}
} catch($e1009510096) {
if(R.isCont($e1009510096)) {
var $ss1009910100 = {"from":L[375],
"go":function(ann_DASH_check_DASH_temp27110105) {
return $Hann_DASH_check_DASH_temp211810106(ann_DASH_check_DASH_temp27110105);
}};
$e1009510096.stack[R.EXN_STACKHEIGHT++] = $ss1009910100;
}
if(R.isPyretException($e1009510096)) {
$e1009510096.pyretStack.push(L[375]);
}
throw $e1009510096;
}
var $ret1010110102 = $Hann_DASH_check_DASH_temp211810106($z1009710098);
++R.GAS;
return $ret1010110102;
};
var $Hann_DASH_check_DASH_temp211810106 = function(ann_DASH_check_DASH_temp27110105) {
return ann_DASH_check_DASH_temp27110105;
};
var $Hcont_tail_arg21163937 = function(cont_tail_arg2683935,if_helper2603936) {
if(--R.GAS > 0) {
$z1010710108 = R.isFunction(if_helper2603936)?if_helper2603936.app(cont_tail_arg2683935):R.ffi.throwNonFunApp(L[375],if_helper2603936,[cont_tail_arg2683935]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper2603936)?if_helper2603936.app(cont_tail_arg2683935):R.ffi.throwNonFunApp(L[375],if_helper2603936,[cont_tail_arg2683935]);
},
"from":L[375]});
}
++R.GAS;
return $z1010710108;
};
var $Hcont_tail_arg21173952 = function(cont_tail_arg2653951,if_helper2603936) {
if(--R.GAS > 0) {
$z1010910110 = R.isFunction(if_helper2603936)?if_helper2603936.app(cont_tail_arg2653951):R.ffi.throwNonFunApp(L[375],if_helper2603936,[cont_tail_arg2653951]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper2603936)?if_helper2603936.app(cont_tail_arg2653951):R.ffi.throwNonFunApp(L[375],if_helper2603936,[cont_tail_arg2653951]);
},
"from":L[375]});
}
++R.GAS;
return $z1010910110;
};
var $Halt_DASH_doc21153972 = function(alt_DASH_doc2243971,INDENT7747,PP123,self2231745,_plus14) {
var anf_arg22110149 = G(PP123,"mt-doc",L[910]);
var if_DASH_2810128 = R.equiv(alt_DASH_doc2243971,anf_arg22110149);
var if_helper22210113 = R.makeFunction(function(if_helper_arg22310133) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[906],1,arguments);
}
var else_DASH_doc22510147 = if_helper_arg22310133;
var anf_fun22410146 = G(PP123,"group",L[909]);
var anf_fun22510144 = G(PP123,"str",L[908]);
var $z1013610137 = D;
var $f1014210143 = function(_) {
return R.isFunction(anf_fun22510144)?anf_fun22510144.app(("if")):R.ffi.throwNonFunApp(L[907],anf_fun22510144,[("if")]);
};
try {
if(--R.GAS > 0) {
$z1013610137 = $f1014210143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1014210143,
"from":L[907]});
}
} catch($e1013410135) {
if(R.isCont($e1013410135)) {
var $ss1013810139 = {"from":L[907],
"go":function(anf_arg22610145) {
return $Hanf_arg211110148(anf_arg22610145,INDENT7747,PP123,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14);
}};
$e1013410135.stack[R.EXN_STACKHEIGHT++] = $ss1013810139;
}
if(R.isPyretException($e1013410135)) {
$e1013410135.pyretStack.push(L[907]);
}
throw $e1013410135;
}
var $ret1014010141 = $Hanf_arg211110148($z1013610137,INDENT7747,PP123,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14);
++R.GAS;
return $ret1014010141;
});
var anf_if24710132 = R.isBoolean(if_DASH_2810128);
if(R.isPyretTrue(anf_if24710132)) {
if(R.isPyretTrue(if_DASH_2810128)) {
var cont_tail_arg25610114 = G(PP123,"mt-doc",L[903]);
if(--R.GAS > 0) {
$z1011110112 = R.isFunction(if_helper22210113)?if_helper22210113.app(cont_tail_arg25610114):R.ffi.throwNonFunApp(L[903],if_helper22210113,[cont_tail_arg25610114]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper22210113)?if_helper22210113.app(cont_tail_arg25610114):R.ffi.throwNonFunApp(L[903],if_helper22210113,[cont_tail_arg25610114]);
},
"from":L[903]});
}
++R.GAS;
return $z1011110112;
} else {
var anf_fun24810125 = G(PP123,"str",L[905]);
var $z1011710118 = D;
var $f1012310124 = function(_) {
return R.isFunction(anf_fun24810125)?anf_fun24810125.app((" else ")):R.ffi.throwNonFunApp(L[904],anf_fun24810125,[(" else ")]);
};
try {
if(--R.GAS > 0) {
$z1011710118 = $f1012310124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1012310124,
"from":L[904]});
}
} catch($e1011510116) {
if(R.isCont($e1011510116)) {
var $ss1011910120 = {"from":L[904],
"go":function(anf_arg24910126) {
return $Hanf_arg211410127(anf_arg24910126,INDENT7747,PP123,alt_DASH_doc2243971,if_helper22210113,_plus14);
}};
$e1011510116.stack[R.EXN_STACKHEIGHT++] = $ss1011910120;
}
if(R.isPyretException($e1011510116)) {
$e1011510116.pyretStack.push(L[904]);
}
throw $e1011510116;
}
var $ret1012110122 = $Hanf_arg211410127($z1011710118,INDENT7747,PP123,alt_DASH_doc2243971,if_helper22210113,_plus14);
++R.GAS;
return $ret1012110122;
}
} else {
var cont_tail_arg24510131 = R.throwNonBooleanCondition(L[906],("if"),if_DASH_2810128);
if(--R.GAS > 0) {
$z1012910130 = R.isFunction(if_helper22210113)?if_helper22210113.app(cont_tail_arg24510131):R.ffi.throwNonFunApp(L[906],if_helper22210113,[cont_tail_arg24510131]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper22210113)?if_helper22210113.app(cont_tail_arg24510131):R.ffi.throwNonFunApp(L[906],if_helper22210113,[cont_tail_arg24510131]);
},
"from":L[906]});
}
++R.GAS;
return $z1012910130;
}
};
var $Hanf_arg211410127 = function(anf_arg24910126,INDENT7747,PP123,alt_DASH_doc2243971,if_helper22210113,_plus14) {
var anf_fun25010160 = G(PP123,"surround",L[914]);
var anf_arg25110161 = G(PP123,"lbrace",L[913]);
var anf_arg25210162 = G(PP123,"rbrace",L[912]);
var $z1015210153 = D;
var $f1015810159 = function(_) {
return R.isFunction(anf_fun25010160)?anf_fun25010160.app(INDENT7747,(1),anf_arg25110161,alt_DASH_doc2243971,anf_arg25210162):R.ffi.throwNonFunApp(L[911],anf_fun25010160,[INDENT7747,(1),anf_arg25110161,alt_DASH_doc2243971,anf_arg25210162]);
};
try {
if(--R.GAS > 0) {
$z1015210153 = $f1015810159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1015810159,
"from":L[911]});
}
} catch($e1015010151) {
if(R.isCont($e1015010151)) {
var $ss1015410155 = {"from":L[911],
"go":function(anf_arg25310163) {
return $Hanf_arg211310164(anf_arg25310163,anf_arg24910126,if_helper22210113,_plus14);
}};
$e1015010151.stack[R.EXN_STACKHEIGHT++] = $ss1015410155;
}
if(R.isPyretException($e1015010151)) {
$e1015010151.pyretStack.push(L[911]);
}
throw $e1015010151;
}
var $ret1015610157 = $Hanf_arg211310164($z1015210153,anf_arg24910126,if_helper22210113,_plus14);
++R.GAS;
return $ret1015610157;
};
var $Hanf_arg211310164 = function(anf_arg25310163,anf_arg24910126,if_helper22210113,_plus14) {
var $z1016710168 = D;
var $f1017310174 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg24910126,anf_arg25310163):R.ffi.throwNonFunApp(L[915],_plus14,[anf_arg24910126,anf_arg25310163]);
};
try {
if(--R.GAS > 0) {
$z1016710168 = $f1017310174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1017310174,
"from":L[915]});
}
} catch($e1016510166) {
if(R.isCont($e1016510166)) {
var $ss1016910170 = {"from":L[915],
"go":function(cont_tail_arg25410175) {
return $Hcont_tail_arg211210176(cont_tail_arg25410175,if_helper22210113);
}};
$e1016510166.stack[R.EXN_STACKHEIGHT++] = $ss1016910170;
}
if(R.isPyretException($e1016510166)) {
$e1016510166.pyretStack.push(L[915]);
}
throw $e1016510166;
}
var $ret1017110172 = $Hcont_tail_arg211210176($z1016710168,if_helper22210113);
++R.GAS;
return $ret1017110172;
};
var $Hcont_tail_arg211210176 = function(cont_tail_arg25410175,if_helper22210113) {
if(--R.GAS > 0) {
$z1017710178 = R.isFunction(if_helper22210113)?if_helper22210113.app(cont_tail_arg25410175):R.ffi.throwNonFunApp(L[915],if_helper22210113,[cont_tail_arg25410175]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper22210113)?if_helper22210113.app(cont_tail_arg25410175):R.ffi.throwNonFunApp(L[915],if_helper22210113,[cont_tail_arg25410175]);
},
"from":L[915]});
}
++R.GAS;
return $z1017710178;
};
var $Hanf_arg211110148 = function(anf_arg22610145,INDENT7747,PP123,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14) {
var anf_fun22710191 = G(PP123,"parens",L[919]);
var anf_bracket22810193 = G(self2231745,"cond",L[918]);
var anf_fun22910189 = G(anf_bracket22810193,"tosource",L[917]);
var $z1018110182 = D;
var $f1018710188 = function(_) {
return R.isFunction(anf_fun22910189)?anf_fun22910189.app():R.ffi.throwNonFunApp(L[916],anf_fun22910189,[]);
};
try {
if(--R.GAS > 0) {
$z1018110182 = $f1018710188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1018710188,
"from":L[916]});
}
} catch($e1017910180) {
if(R.isCont($e1017910180)) {
var $ss1018310184 = {"from":L[916],
"go":function(anf_arg23010190) {
return $Hanf_arg211010192(anf_arg23010190,INDENT7747,PP123,anf_arg22610145,anf_fun22410146,anf_fun22710191,else_DASH_doc22510147,self2231745,_plus14);
}};
$e1017910180.stack[R.EXN_STACKHEIGHT++] = $ss1018310184;
}
if(R.isPyretException($e1017910180)) {
$e1017910180.pyretStack.push(L[916]);
}
throw $e1017910180;
}
var $ret1018510186 = $Hanf_arg211010192($z1018110182,INDENT7747,PP123,anf_arg22610145,anf_fun22410146,anf_fun22710191,else_DASH_doc22510147,self2231745,_plus14);
++R.GAS;
return $ret1018510186;
};
var $Hanf_arg211010192 = function(anf_arg23010190,INDENT7747,PP123,anf_arg22610145,anf_fun22410146,anf_fun22710191,else_DASH_doc22510147,self2231745,_plus14) {
var $z1019610197 = D;
var $f1020210203 = function(_) {
return R.isFunction(anf_fun22710191)?anf_fun22710191.app(anf_arg23010190):R.ffi.throwNonFunApp(L[920],anf_fun22710191,[anf_arg23010190]);
};
try {
if(--R.GAS > 0) {
$z1019610197 = $f1020210203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1020210203,
"from":L[920]});
}
} catch($e1019410195) {
if(R.isCont($e1019410195)) {
var $ss1019810199 = {"from":L[920],
"go":function(anf_arg23110204) {
return $Hanf_arg210910205(anf_arg23110204,INDENT7747,PP123,anf_arg22610145,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14);
}};
$e1019410195.stack[R.EXN_STACKHEIGHT++] = $ss1019810199;
}
if(R.isPyretException($e1019410195)) {
$e1019410195.pyretStack.push(L[920]);
}
throw $e1019410195;
}
var $ret1020010201 = $Hanf_arg210910205($z1019610197,INDENT7747,PP123,anf_arg22610145,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14);
++R.GAS;
return $ret1020010201;
};
var $Hanf_arg210910205 = function(anf_arg23110204,INDENT7747,PP123,anf_arg22610145,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14) {
var $z1020810209 = D;
var $f1021410215 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg22610145,anf_arg23110204):R.ffi.throwNonFunApp(L[921],_plus14,[anf_arg22610145,anf_arg23110204]);
};
try {
if(--R.GAS > 0) {
$z1020810209 = $f1021410215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1021410215,
"from":L[921]});
}
} catch($e1020610207) {
if(R.isCont($e1020610207)) {
var $ss1021010211 = {"from":L[921],
"go":function(anf_arg23210216) {
return $Hanf_arg210810217(anf_arg23210216,INDENT7747,PP123,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14);
}};
$e1020610207.stack[R.EXN_STACKHEIGHT++] = $ss1021010211;
}
if(R.isPyretException($e1020610207)) {
$e1020610207.pyretStack.push(L[921]);
}
throw $e1020610207;
}
var $ret1021210213 = $Hanf_arg210810217($z1020810209,INDENT7747,PP123,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14);
++R.GAS;
return $ret1021210213;
};
var $Hanf_arg210810217 = function(anf_arg23210216,INDENT7747,PP123,anf_fun22410146,else_DASH_doc22510147,self2231745,_plus14) {
var $z1022010221 = D;
var $f1022610227 = function(_) {
return R.isFunction(anf_fun22410146)?anf_fun22410146.app(anf_arg23210216):R.ffi.throwNonFunApp(L[922],anf_fun22410146,[anf_arg23210216]);
};
try {
if(--R.GAS > 0) {
$z1022010221 = $f1022610227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1022610227,
"from":L[922]});
}
} catch($e1021810219) {
if(R.isCont($e1021810219)) {
var $ss1022210223 = {"from":L[922],
"go":function(anf_arg23310228) {
return $Hanf_arg210710229(anf_arg23310228,INDENT7747,PP123,else_DASH_doc22510147,self2231745,_plus14);
}};
$e1021810219.stack[R.EXN_STACKHEIGHT++] = $ss1022210223;
}
if(R.isPyretException($e1021810219)) {
$e1021810219.pyretStack.push(L[922]);
}
throw $e1021810219;
}
var $ret1022410225 = $Hanf_arg210710229($z1022010221,INDENT7747,PP123,else_DASH_doc22510147,self2231745,_plus14);
++R.GAS;
return $ret1022410225;
};
var $Hanf_arg210710229 = function(anf_arg23310228,INDENT7747,PP123,else_DASH_doc22510147,self2231745,_plus14) {
var anf_fun23410240 = G(PP123,"str",L[924]);
var $z1023210233 = D;
var $f1023810239 = function(_) {
return R.isFunction(anf_fun23410240)?anf_fun23410240.app((" ")):R.ffi.throwNonFunApp(L[923],anf_fun23410240,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z1023210233 = $f1023810239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1023810239,
"from":L[923]});
}
} catch($e1023010231) {
if(R.isCont($e1023010231)) {
var $ss1023410235 = {"from":L[923],
"go":function(anf_arg23510241) {
return $Hanf_arg210610242(anf_arg23510241,INDENT7747,PP123,anf_arg23310228,else_DASH_doc22510147,self2231745,_plus14);
}};
$e1023010231.stack[R.EXN_STACKHEIGHT++] = $ss1023410235;
}
if(R.isPyretException($e1023010231)) {
$e1023010231.pyretStack.push(L[923]);
}
throw $e1023010231;
}
var $ret1023610237 = $Hanf_arg210610242($z1023210233,INDENT7747,PP123,anf_arg23310228,else_DASH_doc22510147,self2231745,_plus14);
++R.GAS;
return $ret1023610237;
};
var $Hanf_arg210610242 = function(anf_arg23510241,INDENT7747,PP123,anf_arg23310228,else_DASH_doc22510147,self2231745,_plus14) {
var $z1024510246 = D;
var $f1025110252 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg23310228,anf_arg23510241):R.ffi.throwNonFunApp(L[925],_plus14,[anf_arg23310228,anf_arg23510241]);
};
try {
if(--R.GAS > 0) {
$z1024510246 = $f1025110252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1025110252,
"from":L[925]});
}
} catch($e1024310244) {
if(R.isCont($e1024310244)) {
var $ss1024710248 = {"from":L[925],
"go":function(anf_arg23610253) {
return $Hanf_arg210510254(anf_arg23610253,INDENT7747,PP123,else_DASH_doc22510147,self2231745,_plus14);
}};
$e1024310244.stack[R.EXN_STACKHEIGHT++] = $ss1024710248;
}
if(R.isPyretException($e1024310244)) {
$e1024310244.pyretStack.push(L[925]);
}
throw $e1024310244;
}
var $ret1024910250 = $Hanf_arg210510254($z1024510246,INDENT7747,PP123,else_DASH_doc22510147,self2231745,_plus14);
++R.GAS;
return $ret1024910250;
};
var $Hanf_arg210510254 = function(anf_arg23610253,INDENT7747,PP123,else_DASH_doc22510147,self2231745,_plus14) {
var anf_fun23710268 = G(PP123,"surround",L[930]);
var anf_arg23810267 = G(PP123,"lbrace",L[929]);
var anf_bracket23910270 = G(self2231745,"consq",L[928]);
var anf_fun24010265 = G(anf_bracket23910270,"tosource",L[927]);
var $z1025710258 = D;
var $f1026310264 = function(_) {
return R.isFunction(anf_fun24010265)?anf_fun24010265.app():R.ffi.throwNonFunApp(L[926],anf_fun24010265,[]);
};
try {
if(--R.GAS > 0) {
$z1025710258 = $f1026310264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1026310264,
"from":L[926]});
}
} catch($e1025510256) {
if(R.isCont($e1025510256)) {
var $ss1025910260 = {"from":L[926],
"go":function(anf_arg24110266) {
return $Hanf_arg210410269(anf_arg24110266,INDENT7747,PP123,anf_arg23610253,anf_arg23810267,anf_fun23710268,else_DASH_doc22510147,_plus14);
}};
$e1025510256.stack[R.EXN_STACKHEIGHT++] = $ss1025910260;
}
if(R.isPyretException($e1025510256)) {
$e1025510256.pyretStack.push(L[926]);
}
throw $e1025510256;
}
var $ret1026110262 = $Hanf_arg210410269($z1025710258,INDENT7747,PP123,anf_arg23610253,anf_arg23810267,anf_fun23710268,else_DASH_doc22510147,_plus14);
++R.GAS;
return $ret1026110262;
};
var $Hanf_arg210410269 = function(anf_arg24110266,INDENT7747,PP123,anf_arg23610253,anf_arg23810267,anf_fun23710268,else_DASH_doc22510147,_plus14) {
var anf_arg24210281 = G(PP123,"rbrace",L[932]);
var $z1027310274 = D;
var $f1027910280 = function(_) {
return R.isFunction(anf_fun23710268)?anf_fun23710268.app(INDENT7747,(1),anf_arg23810267,anf_arg24110266,anf_arg24210281):R.ffi.throwNonFunApp(L[931],anf_fun23710268,[INDENT7747,(1),anf_arg23810267,anf_arg24110266,anf_arg24210281]);
};
try {
if(--R.GAS > 0) {
$z1027310274 = $f1027910280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1027910280,
"from":L[931]});
}
} catch($e1027110272) {
if(R.isCont($e1027110272)) {
var $ss1027510276 = {"from":L[931],
"go":function(anf_arg24310282) {
return $Hanf_arg210310283(anf_arg24310282,anf_arg23610253,else_DASH_doc22510147,_plus14);
}};
$e1027110272.stack[R.EXN_STACKHEIGHT++] = $ss1027510276;
}
if(R.isPyretException($e1027110272)) {
$e1027110272.pyretStack.push(L[931]);
}
throw $e1027110272;
}
var $ret1027710278 = $Hanf_arg210310283($z1027310274,anf_arg23610253,else_DASH_doc22510147,_plus14);
++R.GAS;
return $ret1027710278;
};
var $Hanf_arg210310283 = function(anf_arg24310282,anf_arg23610253,else_DASH_doc22510147,_plus14) {
var $z1028610287 = D;
var $f1029210293 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg23610253,anf_arg24310282):R.ffi.throwNonFunApp(L[925],_plus14,[anf_arg23610253,anf_arg24310282]);
};
try {
if(--R.GAS > 0) {
$z1028610287 = $f1029210293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1029210293,
"from":L[925]});
}
} catch($e1028410285) {
if(R.isCont($e1028410285)) {
var $ss1028810289 = {"from":L[925],
"go":function(anf_arg24410294) {
return $Hanf_arg210210295(anf_arg24410294,else_DASH_doc22510147,_plus14);
}};
$e1028410285.stack[R.EXN_STACKHEIGHT++] = $ss1028810289;
}
if(R.isPyretException($e1028410285)) {
$e1028410285.pyretStack.push(L[925]);
}
throw $e1028410285;
}
var $ret1029010291 = $Hanf_arg210210295($z1028610287,else_DASH_doc22510147,_plus14);
++R.GAS;
return $ret1029010291;
};
var $Hanf_arg210210295 = function(anf_arg24410294,else_DASH_doc22510147,_plus14) {
var $z1029810299 = D;
var $f1030410305 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg24410294,else_DASH_doc22510147):R.ffi.throwNonFunApp(L[435],_plus14,[anf_arg24410294,else_DASH_doc22510147]);
};
try {
if(--R.GAS > 0) {
$z1029810299 = $f1030410305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1030410305,
"from":L[435]});
}
} catch($e1029610297) {
if(R.isCont($e1029610297)) {
var $ss1030010301 = {"from":L[435],
"go":function(ann_DASH_check_DASH_temp21810306) {
return $Hann_DASH_check_DASH_temp210110307(ann_DASH_check_DASH_temp21810306);
}};
$e1029610297.stack[R.EXN_STACKHEIGHT++] = $ss1030010301;
}
if(R.isPyretException($e1029610297)) {
$e1029610297.pyretStack.push(L[435]);
}
throw $e1029610297;
}
var $ret1030210303 = $Hann_DASH_check_DASH_temp210110307($z1029810299);
++R.GAS;
return $ret1030210303;
};
var $Hann_DASH_check_DASH_temp210110307 = function(ann_DASH_check_DASH_temp21810306) {
return ann_DASH_check_DASH_temp21810306;
};
var $Hanf_begin_app_dropped21003987 = function(anf_begin_app_dropped20883985,printer2223984,self2213986) {
var anf_bracket21110321 = G(self2213986,"cond",L[935]);
var anf_fun21210318 = G(anf_bracket21110321,"print-ugly-source",L[934]);
var $z1031010311 = D;
var $f1031610317 = function(_) {
return R.isFunction(anf_fun21210318)?anf_fun21210318.app(printer2223984):R.ffi.throwNonFunApp(L[933],anf_fun21210318,[printer2223984]);
};
try {
if(--R.GAS > 0) {
$z1031010311 = $f1031610317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1031610317,
"from":L[933]});
}
} catch($e1030810309) {
if(R.isCont($e1030810309)) {
var $ss1031210313 = {"from":L[933],
"go":function(anf_begin_app_dropped208910319) {
return $Hanf_begin_app_dropped209910320(anf_begin_app_dropped208910319,printer2223984,self2213986);
}};
$e1030810309.stack[R.EXN_STACKHEIGHT++] = $ss1031210313;
}
if(R.isPyretException($e1030810309)) {
$e1030810309.pyretStack.push(L[933]);
}
throw $e1030810309;
}
var $ret1031410315 = $Hanf_begin_app_dropped209910320($z1031010311,printer2223984,self2213986);
++R.GAS;
return $ret1031410315;
};
var $Hanf_begin_app_dropped209910320 = function(anf_begin_app_dropped208910319,printer2223984,self2213986) {
var $z1032410325 = D;
var $f1033010331 = function(_) {
return R.isFunction(printer2223984)?printer2223984.app((") {\n")):R.ffi.throwNonFunApp(L[936],printer2223984,[(") {\n")]);
};
try {
if(--R.GAS > 0) {
$z1032410325 = $f1033010331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1033010331,
"from":L[936]});
}
} catch($e1032210323) {
if(R.isCont($e1032210323)) {
var $ss1032610327 = {"from":L[936],
"go":function(anf_begin_app_dropped209010332) {
return $Hanf_begin_app_dropped209810333(anf_begin_app_dropped209010332,printer2223984,self2213986);
}};
$e1032210323.stack[R.EXN_STACKHEIGHT++] = $ss1032610327;
}
if(R.isPyretException($e1032210323)) {
$e1032210323.pyretStack.push(L[936]);
}
throw $e1032210323;
}
var $ret1032810329 = $Hanf_begin_app_dropped209810333($z1032410325,printer2223984,self2213986);
++R.GAS;
return $ret1032810329;
};
var $Hanf_begin_app_dropped209810333 = function(anf_begin_app_dropped209010332,printer2223984,self2213986) {
var anf_bracket21310347 = G(self2213986,"consq",L[939]);
var anf_fun21410344 = G(anf_bracket21310347,"print-ugly-source",L[938]);
var $z1033610337 = D;
var $f1034210343 = function(_) {
return R.isFunction(anf_fun21410344)?anf_fun21410344.app(printer2223984):R.ffi.throwNonFunApp(L[937],anf_fun21410344,[printer2223984]);
};
try {
if(--R.GAS > 0) {
$z1033610337 = $f1034210343();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1034210343,
"from":L[937]});
}
} catch($e1033410335) {
if(R.isCont($e1033410335)) {
var $ss1033810339 = {"from":L[937],
"go":function(anf_begin_app_dropped209110345) {
return $Hanf_begin_app_dropped209710346(anf_begin_app_dropped209110345,printer2223984,self2213986);
}};
$e1033410335.stack[R.EXN_STACKHEIGHT++] = $ss1033810339;
}
if(R.isPyretException($e1033410335)) {
$e1033410335.pyretStack.push(L[937]);
}
throw $e1033410335;
}
var $ret1034010341 = $Hanf_begin_app_dropped209710346($z1033610337,printer2223984,self2213986);
++R.GAS;
return $ret1034010341;
};
var $Hanf_begin_app_dropped209710346 = function(anf_begin_app_dropped209110345,printer2223984,self2213986) {
var $z1035010351 = D;
var $f1035610357 = function(_) {
return R.isFunction(printer2223984)?printer2223984.app(("\n} else {\n")):R.ffi.throwNonFunApp(L[940],printer2223984,[("\n} else {\n")]);
};
try {
if(--R.GAS > 0) {
$z1035010351 = $f1035610357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1035610357,
"from":L[940]});
}
} catch($e1034810349) {
if(R.isCont($e1034810349)) {
var $ss1035210353 = {"from":L[940],
"go":function(anf_begin_app_dropped209210358) {
return $Hanf_begin_app_dropped209610359(anf_begin_app_dropped209210358,printer2223984,self2213986);
}};
$e1034810349.stack[R.EXN_STACKHEIGHT++] = $ss1035210353;
}
if(R.isPyretException($e1034810349)) {
$e1034810349.pyretStack.push(L[940]);
}
throw $e1034810349;
}
var $ret1035410355 = $Hanf_begin_app_dropped209610359($z1035010351,printer2223984,self2213986);
++R.GAS;
return $ret1035410355;
};
var $Hanf_begin_app_dropped209610359 = function(anf_begin_app_dropped209210358,printer2223984,self2213986) {
var anf_bracket21510373 = G(self2213986,"alt",L[943]);
var anf_fun21610370 = G(anf_bracket21510373,"print-ugly-source",L[942]);
var $z1036210363 = D;
var $f1036810369 = function(_) {
return R.isFunction(anf_fun21610370)?anf_fun21610370.app(printer2223984):R.ffi.throwNonFunApp(L[941],anf_fun21610370,[printer2223984]);
};
try {
if(--R.GAS > 0) {
$z1036210363 = $f1036810369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1036810369,
"from":L[941]});
}
} catch($e1036010361) {
if(R.isCont($e1036010361)) {
var $ss1036410365 = {"from":L[941],
"go":function(anf_begin_app_dropped209310371) {
return $Hanf_begin_app_dropped209510372(anf_begin_app_dropped209310371,printer2223984);
}};
$e1036010361.stack[R.EXN_STACKHEIGHT++] = $ss1036410365;
}
if(R.isPyretException($e1036010361)) {
$e1036010361.pyretStack.push(L[941]);
}
throw $e1036010361;
}
var $ret1036610367 = $Hanf_begin_app_dropped209510372($z1036210363,printer2223984);
++R.GAS;
return $ret1036610367;
};
var $Hanf_begin_app_dropped209510372 = function(anf_begin_app_dropped209310371,printer2223984) {
var $z1037610377 = D;
var $f1038210383 = function(_) {
return R.isFunction(printer2223984)?printer2223984.app(("\n}")):R.ffi.throwNonFunApp(L[437],printer2223984,[("\n}")]);
};
try {
if(--R.GAS > 0) {
$z1037610377 = $f1038210383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1038210383,
"from":L[437]});
}
} catch($e1037410375) {
if(R.isCont($e1037410375)) {
var $ss1037810379 = {"from":L[437],
"go":function(ann_DASH_check_DASH_temp21010384) {
return $Hann_DASH_check_DASH_temp209410385(ann_DASH_check_DASH_temp21010384);
}};
$e1037410375.stack[R.EXN_STACKHEIGHT++] = $ss1037810379;
}
if(R.isPyretException($e1037410375)) {
$e1037410375.pyretStack.push(L[437]);
}
throw $e1037410375;
}
var $ret1038010381 = $Hann_DASH_check_DASH_temp209410385($z1037610377);
++R.GAS;
return $ret1038010381;
};
var $Hann_DASH_check_DASH_temp209410385 = function(ann_DASH_check_DASH_temp21010384) {
return ann_DASH_check_DASH_temp21010384;
};
var $Hanf_arg20874001 = function(anf_arg1983999,self264000,_plus14,torepr18) {
var anf_arg19910396 = G(self264000,"consq",L[376]);
var $z1038810389 = D;
var $f1039410395 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg19910396):R.ffi.throwNonFunApp(L[376],torepr18,[anf_arg19910396]);
};
try {
if(--R.GAS > 0) {
$z1038810389 = $f1039410395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1039410395,
"from":L[376]});
}
} catch($e1038610387) {
if(R.isCont($e1038610387)) {
var $ss1039010391 = {"from":L[376],
"go":function(anf_arg20010397) {
return $Hanf_arg208610398(anf_arg20010397,anf_arg1983999,self264000,_plus14,torepr18);
}};
$e1038610387.stack[R.EXN_STACKHEIGHT++] = $ss1039010391;
}
if(R.isPyretException($e1038610387)) {
$e1038610387.pyretStack.push(L[376]);
}
throw $e1038610387;
}
var $ret1039210393 = $Hanf_arg208610398($z1038810389,anf_arg1983999,self264000,_plus14,torepr18);
++R.GAS;
return $ret1039210393;
};
var $Hanf_arg208610398 = function(anf_arg20010397,anf_arg1983999,self264000,_plus14,torepr18) {
var $z1040110402 = D;
var $f1040710408 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg20010397):R.ffi.throwNonFunApp(L[376],_plus14,[(", "),anf_arg20010397]);
};
try {
if(--R.GAS > 0) {
$z1040110402 = $f1040710408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1040710408,
"from":L[376]});
}
} catch($e1039910400) {
if(R.isCont($e1039910400)) {
var $ss1040310404 = {"from":L[376],
"go":function(anf_arg20110409) {
return $Hanf_arg208510410(anf_arg20110409,anf_arg1983999,self264000,_plus14,torepr18);
}};
$e1039910400.stack[R.EXN_STACKHEIGHT++] = $ss1040310404;
}
if(R.isPyretException($e1039910400)) {
$e1039910400.pyretStack.push(L[376]);
}
throw $e1039910400;
}
var $ret1040510406 = $Hanf_arg208510410($z1040110402,anf_arg1983999,self264000,_plus14,torepr18);
++R.GAS;
return $ret1040510406;
};
var $Hanf_arg208510410 = function(anf_arg20110409,anf_arg1983999,self264000,_plus14,torepr18) {
var $z1041310414 = D;
var $f1041910420 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg1983999,anf_arg20110409):R.ffi.throwNonFunApp(L[376],_plus14,[anf_arg1983999,anf_arg20110409]);
};
try {
if(--R.GAS > 0) {
$z1041310414 = $f1041910420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1041910420,
"from":L[376]});
}
} catch($e1041110412) {
if(R.isCont($e1041110412)) {
var $ss1041510416 = {"from":L[376],
"go":function(anf_arg20210421) {
return $Hanf_arg208410422(anf_arg20210421,self264000,_plus14,torepr18);
}};
$e1041110412.stack[R.EXN_STACKHEIGHT++] = $ss1041510416;
}
if(R.isPyretException($e1041110412)) {
$e1041110412.pyretStack.push(L[376]);
}
throw $e1041110412;
}
var $ret1041710418 = $Hanf_arg208410422($z1041310414,self264000,_plus14,torepr18);
++R.GAS;
return $ret1041710418;
};
var $Hanf_arg208410422 = function(anf_arg20210421,self264000,_plus14,torepr18) {
var anf_arg20310433 = G(self264000,"alt",L[376]);
var $z1042510426 = D;
var $f1043110432 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg20310433):R.ffi.throwNonFunApp(L[376],torepr18,[anf_arg20310433]);
};
try {
if(--R.GAS > 0) {
$z1042510426 = $f1043110432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1043110432,
"from":L[376]});
}
} catch($e1042310424) {
if(R.isCont($e1042310424)) {
var $ss1042710428 = {"from":L[376],
"go":function(anf_arg20410434) {
return $Hanf_arg208310435(anf_arg20410434,anf_arg20210421,_plus14);
}};
$e1042310424.stack[R.EXN_STACKHEIGHT++] = $ss1042710428;
}
if(R.isPyretException($e1042310424)) {
$e1042310424.pyretStack.push(L[376]);
}
throw $e1042310424;
}
var $ret1042910430 = $Hanf_arg208310435($z1042510426,anf_arg20210421,_plus14);
++R.GAS;
return $ret1042910430;
};
var $Hanf_arg208310435 = function(anf_arg20410434,anf_arg20210421,_plus14) {
var $z1043810439 = D;
var $f1044410445 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg20410434):R.ffi.throwNonFunApp(L[376],_plus14,[(", "),anf_arg20410434]);
};
try {
if(--R.GAS > 0) {
$z1043810439 = $f1044410445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1044410445,
"from":L[376]});
}
} catch($e1043610437) {
if(R.isCont($e1043610437)) {
var $ss1044010441 = {"from":L[376],
"go":function(anf_arg20510446) {
return $Hanf_arg208210447(anf_arg20510446,anf_arg20210421,_plus14);
}};
$e1043610437.stack[R.EXN_STACKHEIGHT++] = $ss1044010441;
}
if(R.isPyretException($e1043610437)) {
$e1043610437.pyretStack.push(L[376]);
}
throw $e1043610437;
}
var $ret1044210443 = $Hanf_arg208210447($z1043810439,anf_arg20210421,_plus14);
++R.GAS;
return $ret1044210443;
};
var $Hanf_arg208210447 = function(anf_arg20510446,anf_arg20210421,_plus14) {
var $z1045010451 = D;
var $f1045610457 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg20210421,anf_arg20510446):R.ffi.throwNonFunApp(L[376],_plus14,[anf_arg20210421,anf_arg20510446]);
};
try {
if(--R.GAS > 0) {
$z1045010451 = $f1045610457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1045610457,
"from":L[376]});
}
} catch($e1044810449) {
if(R.isCont($e1044810449)) {
var $ss1045210453 = {"from":L[376],
"go":function(anf_arg20610458) {
return $Hanf_arg208110459(anf_arg20610458,_plus14);
}};
$e1044810449.stack[R.EXN_STACKHEIGHT++] = $ss1045210453;
}
if(R.isPyretException($e1044810449)) {
$e1044810449.pyretStack.push(L[376]);
}
throw $e1044810449;
}
var $ret1045410455 = $Hanf_arg208110459($z1045010451,_plus14);
++R.GAS;
return $ret1045410455;
};
var $Hanf_arg208110459 = function(anf_arg20610458,_plus14) {
var $z1046210463 = D;
var $f1046810469 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg20610458,(")")):R.ffi.throwNonFunApp(L[376],_plus14,[anf_arg20610458,(")")]);
};
try {
if(--R.GAS > 0) {
$z1046210463 = $f1046810469();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1046810469,
"from":L[376]});
}
} catch($e1046010461) {
if(R.isCont($e1046010461)) {
var $ss1046410465 = {"from":L[376],
"go":function(anf_arg20710470) {
return $Hanf_arg208010471(anf_arg20710470,_plus14);
}};
$e1046010461.stack[R.EXN_STACKHEIGHT++] = $ss1046410465;
}
if(R.isPyretException($e1046010461)) {
$e1046010461.pyretStack.push(L[376]);
}
throw $e1046010461;
}
var $ret1046610467 = $Hanf_arg208010471($z1046210463,_plus14);
++R.GAS;
return $ret1046610467;
};
var $Hanf_arg208010471 = function(anf_arg20710470,_plus14) {
var $z1047410475 = D;
var $f1048010481 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg20710470):R.ffi.throwNonFunApp(L[376],_plus14,[("("),anf_arg20710470]);
};
try {
if(--R.GAS > 0) {
$z1047410475 = $f1048010481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1048010481,
"from":L[376]});
}
} catch($e1047210473) {
if(R.isCont($e1047210473)) {
var $ss1047610477 = {"from":L[376],
"go":function(anf_arg20810482) {
return $Hanf_arg207910483(anf_arg20810482,_plus14);
}};
$e1047210473.stack[R.EXN_STACKHEIGHT++] = $ss1047610477;
}
if(R.isPyretException($e1047210473)) {
$e1047210473.pyretStack.push(L[376]);
}
throw $e1047210473;
}
var $ret1047810479 = $Hanf_arg207910483($z1047410475,_plus14);
++R.GAS;
return $ret1047810479;
};
var $Hanf_arg207910483 = function(anf_arg20810482,_plus14) {
var $z1048610487 = D;
var $f1049210493 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-if"),anf_arg20810482):R.ffi.throwNonFunApp(L[376],_plus14,[("j-if"),anf_arg20810482]);
};
try {
if(--R.GAS > 0) {
$z1048610487 = $f1049210493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1049210493,
"from":L[376]});
}
} catch($e1048410485) {
if(R.isCont($e1048410485)) {
var $ss1048810489 = {"from":L[376],
"go":function(ann_DASH_check_DASH_temp19610494) {
return $Hann_DASH_check_DASH_temp207810495(ann_DASH_check_DASH_temp19610494);
}};
$e1048410485.stack[R.EXN_STACKHEIGHT++] = $ss1048810489;
}
if(R.isPyretException($e1048410485)) {
$e1048410485.pyretStack.push(L[376]);
}
throw $e1048410485;
}
var $ret1049010491 = $Hann_DASH_check_DASH_temp207810495($z1048610487);
++R.GAS;
return $ret1049010491;
};
var $Hann_DASH_check_DASH_temp207810495 = function(ann_DASH_check_DASH_temp19610494) {
return ann_DASH_check_DASH_temp19610494;
};
var $Hcont_tail_arg20764018 = function(cont_tail_arg1934016,if_helper1834017) {
if(--R.GAS > 0) {
$z1049610497 = R.isFunction(if_helper1834017)?if_helper1834017.app(cont_tail_arg1934016):R.ffi.throwNonFunApp(L[376],if_helper1834017,[cont_tail_arg1934016]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1834017)?if_helper1834017.app(cont_tail_arg1934016):R.ffi.throwNonFunApp(L[376],if_helper1834017,[cont_tail_arg1934016]);
},
"from":L[376]});
}
++R.GAS;
return $z1049610497;
};
var $Hcont_tail_arg20774033 = function(cont_tail_arg1884032,if_helper1834017) {
if(--R.GAS > 0) {
$z1049810499 = R.isFunction(if_helper1834017)?if_helper1834017.app(cont_tail_arg1884032):R.ffi.throwNonFunApp(L[376],if_helper1834017,[cont_tail_arg1884032]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1834017)?if_helper1834017.app(cont_tail_arg1884032):R.ffi.throwNonFunApp(L[376],if_helper1834017,[cont_tail_arg1884032]);
},
"from":L[376]});
}
++R.GAS;
return $z1049810499;
};
var $Hanf_arg20754054 = function(anf_arg1634052,INDENT7747,PP123,anf_fun1614053,self2171831,_plus14) {
var anf_fun16410512 = G(PP123,"parens",L[947]);
var anf_bracket16510514 = G(self2171831,"cond",L[946]);
var anf_fun16610510 = G(anf_bracket16510514,"tosource",L[945]);
var $z1050210503 = D;
var $f1050810509 = function(_) {
return R.isFunction(anf_fun16610510)?anf_fun16610510.app():R.ffi.throwNonFunApp(L[944],anf_fun16610510,[]);
};
try {
if(--R.GAS > 0) {
$z1050210503 = $f1050810509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1050810509,
"from":L[944]});
}
} catch($e1050010501) {
if(R.isCont($e1050010501)) {
var $ss1050410505 = {"from":L[944],
"go":function(anf_arg16710511) {
return $Hanf_arg207410513(anf_arg16710511,INDENT7747,PP123,anf_arg1634052,anf_fun1614053,anf_fun16410512,self2171831,_plus14);
}};
$e1050010501.stack[R.EXN_STACKHEIGHT++] = $ss1050410505;
}
if(R.isPyretException($e1050010501)) {
$e1050010501.pyretStack.push(L[944]);
}
throw $e1050010501;
}
var $ret1050610507 = $Hanf_arg207410513($z1050210503,INDENT7747,PP123,anf_arg1634052,anf_fun1614053,anf_fun16410512,self2171831,_plus14);
++R.GAS;
return $ret1050610507;
};
var $Hanf_arg207410513 = function(anf_arg16710511,INDENT7747,PP123,anf_arg1634052,anf_fun1614053,anf_fun16410512,self2171831,_plus14) {
var $z1051710518 = D;
var $f1052310524 = function(_) {
return R.isFunction(anf_fun16410512)?anf_fun16410512.app(anf_arg16710511):R.ffi.throwNonFunApp(L[948],anf_fun16410512,[anf_arg16710511]);
};
try {
if(--R.GAS > 0) {
$z1051710518 = $f1052310524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1052310524,
"from":L[948]});
}
} catch($e1051510516) {
if(R.isCont($e1051510516)) {
var $ss1051910520 = {"from":L[948],
"go":function(anf_arg16810525) {
return $Hanf_arg207310526(anf_arg16810525,INDENT7747,PP123,anf_arg1634052,anf_fun1614053,self2171831,_plus14);
}};
$e1051510516.stack[R.EXN_STACKHEIGHT++] = $ss1051910520;
}
if(R.isPyretException($e1051510516)) {
$e1051510516.pyretStack.push(L[948]);
}
throw $e1051510516;
}
var $ret1052110522 = $Hanf_arg207310526($z1051710518,INDENT7747,PP123,anf_arg1634052,anf_fun1614053,self2171831,_plus14);
++R.GAS;
return $ret1052110522;
};
var $Hanf_arg207310526 = function(anf_arg16810525,INDENT7747,PP123,anf_arg1634052,anf_fun1614053,self2171831,_plus14) {
var $z1052910530 = D;
var $f1053510536 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg1634052,anf_arg16810525):R.ffi.throwNonFunApp(L[949],_plus14,[anf_arg1634052,anf_arg16810525]);
};
try {
if(--R.GAS > 0) {
$z1052910530 = $f1053510536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1053510536,
"from":L[949]});
}
} catch($e1052710528) {
if(R.isCont($e1052710528)) {
var $ss1053110532 = {"from":L[949],
"go":function(anf_arg16910537) {
return $Hanf_arg207210538(anf_arg16910537,INDENT7747,PP123,anf_fun1614053,self2171831,_plus14);
}};
$e1052710528.stack[R.EXN_STACKHEIGHT++] = $ss1053110532;
}
if(R.isPyretException($e1052710528)) {
$e1052710528.pyretStack.push(L[949]);
}
throw $e1052710528;
}
var $ret1053310534 = $Hanf_arg207210538($z1052910530,INDENT7747,PP123,anf_fun1614053,self2171831,_plus14);
++R.GAS;
return $ret1053310534;
};
var $Hanf_arg207210538 = function(anf_arg16910537,INDENT7747,PP123,anf_fun1614053,self2171831,_plus14) {
var $z1054110542 = D;
var $f1054710548 = function(_) {
return R.isFunction(anf_fun1614053)?anf_fun1614053.app(anf_arg16910537):R.ffi.throwNonFunApp(L[950],anf_fun1614053,[anf_arg16910537]);
};
try {
if(--R.GAS > 0) {
$z1054110542 = $f1054710548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1054710548,
"from":L[950]});
}
} catch($e1053910540) {
if(R.isCont($e1053910540)) {
var $ss1054310544 = {"from":L[950],
"go":function(anf_arg17010549) {
return $Hanf_arg207110550(anf_arg17010549,INDENT7747,PP123,self2171831,_plus14);
}};
$e1053910540.stack[R.EXN_STACKHEIGHT++] = $ss1054310544;
}
if(R.isPyretException($e1053910540)) {
$e1053910540.pyretStack.push(L[950]);
}
throw $e1053910540;
}
var $ret1054510546 = $Hanf_arg207110550($z1054110542,INDENT7747,PP123,self2171831,_plus14);
++R.GAS;
return $ret1054510546;
};
var $Hanf_arg207110550 = function(anf_arg17010549,INDENT7747,PP123,self2171831,_plus14) {
var anf_fun17110561 = G(PP123,"str",L[952]);
var $z1055310554 = D;
var $f1055910560 = function(_) {
return R.isFunction(anf_fun17110561)?anf_fun17110561.app((" ")):R.ffi.throwNonFunApp(L[951],anf_fun17110561,[(" ")]);
};
try {
if(--R.GAS > 0) {
$z1055310554 = $f1055910560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1055910560,
"from":L[951]});
}
} catch($e1055110552) {
if(R.isCont($e1055110552)) {
var $ss1055510556 = {"from":L[951],
"go":function(anf_arg17210562) {
return $Hanf_arg207010563(anf_arg17210562,INDENT7747,PP123,anf_arg17010549,self2171831,_plus14);
}};
$e1055110552.stack[R.EXN_STACKHEIGHT++] = $ss1055510556;
}
if(R.isPyretException($e1055110552)) {
$e1055110552.pyretStack.push(L[951]);
}
throw $e1055110552;
}
var $ret1055710558 = $Hanf_arg207010563($z1055310554,INDENT7747,PP123,anf_arg17010549,self2171831,_plus14);
++R.GAS;
return $ret1055710558;
};
var $Hanf_arg207010563 = function(anf_arg17210562,INDENT7747,PP123,anf_arg17010549,self2171831,_plus14) {
var $z1056610567 = D;
var $f1057210573 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg17010549,anf_arg17210562):R.ffi.throwNonFunApp(L[953],_plus14,[anf_arg17010549,anf_arg17210562]);
};
try {
if(--R.GAS > 0) {
$z1056610567 = $f1057210573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1057210573,
"from":L[953]});
}
} catch($e1056410565) {
if(R.isCont($e1056410565)) {
var $ss1056810569 = {"from":L[953],
"go":function(anf_arg17310574) {
return $Hanf_arg206910575(anf_arg17310574,INDENT7747,PP123,self2171831,_plus14);
}};
$e1056410565.stack[R.EXN_STACKHEIGHT++] = $ss1056810569;
}
if(R.isPyretException($e1056410565)) {
$e1056410565.pyretStack.push(L[953]);
}
throw $e1056410565;
}
var $ret1057010571 = $Hanf_arg206910575($z1056610567,INDENT7747,PP123,self2171831,_plus14);
++R.GAS;
return $ret1057010571;
};
var $Hanf_arg206910575 = function(anf_arg17310574,INDENT7747,PP123,self2171831,_plus14) {
var anf_fun17410589 = G(PP123,"surround",L[958]);
var anf_arg17510588 = G(PP123,"lbrace",L[957]);
var anf_bracket17610591 = G(self2171831,"consq",L[956]);
var anf_fun17710586 = G(anf_bracket17610591,"tosource",L[955]);
var $z1057810579 = D;
var $f1058410585 = function(_) {
return R.isFunction(anf_fun17710586)?anf_fun17710586.app():R.ffi.throwNonFunApp(L[954],anf_fun17710586,[]);
};
try {
if(--R.GAS > 0) {
$z1057810579 = $f1058410585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1058410585,
"from":L[954]});
}
} catch($e1057610577) {
if(R.isCont($e1057610577)) {
var $ss1058010581 = {"from":L[954],
"go":function(anf_arg17810587) {
return $Hanf_arg206810590(anf_arg17810587,INDENT7747,PP123,anf_arg17310574,anf_arg17510588,anf_fun17410589,_plus14);
}};
$e1057610577.stack[R.EXN_STACKHEIGHT++] = $ss1058010581;
}
if(R.isPyretException($e1057610577)) {
$e1057610577.pyretStack.push(L[954]);
}
throw $e1057610577;
}
var $ret1058210583 = $Hanf_arg206810590($z1057810579,INDENT7747,PP123,anf_arg17310574,anf_arg17510588,anf_fun17410589,_plus14);
++R.GAS;
return $ret1058210583;
};
var $Hanf_arg206810590 = function(anf_arg17810587,INDENT7747,PP123,anf_arg17310574,anf_arg17510588,anf_fun17410589,_plus14) {
var anf_arg17910602 = G(PP123,"rbrace",L[960]);
var $z1059410595 = D;
var $f1060010601 = function(_) {
return R.isFunction(anf_fun17410589)?anf_fun17410589.app(INDENT7747,(1),anf_arg17510588,anf_arg17810587,anf_arg17910602):R.ffi.throwNonFunApp(L[959],anf_fun17410589,[INDENT7747,(1),anf_arg17510588,anf_arg17810587,anf_arg17910602]);
};
try {
if(--R.GAS > 0) {
$z1059410595 = $f1060010601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1060010601,
"from":L[959]});
}
} catch($e1059210593) {
if(R.isCont($e1059210593)) {
var $ss1059610597 = {"from":L[959],
"go":function(anf_arg18010603) {
return $Hanf_arg206710604(anf_arg18010603,anf_arg17310574,_plus14);
}};
$e1059210593.stack[R.EXN_STACKHEIGHT++] = $ss1059610597;
}
if(R.isPyretException($e1059210593)) {
$e1059210593.pyretStack.push(L[959]);
}
throw $e1059210593;
}
var $ret1059810599 = $Hanf_arg206710604($z1059410595,anf_arg17310574,_plus14);
++R.GAS;
return $ret1059810599;
};
var $Hanf_arg206710604 = function(anf_arg18010603,anf_arg17310574,_plus14) {
var $z1060710608 = D;
var $f1061310614 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg17310574,anf_arg18010603):R.ffi.throwNonFunApp(L[444],_plus14,[anf_arg17310574,anf_arg18010603]);
};
try {
if(--R.GAS > 0) {
$z1060710608 = $f1061310614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1061310614,
"from":L[444]});
}
} catch($e1060510606) {
if(R.isCont($e1060510606)) {
var $ss1060910610 = {"from":L[444],
"go":function(ann_DASH_check_DASH_temp16010615) {
return $Hann_DASH_check_DASH_temp206610616(ann_DASH_check_DASH_temp16010615);
}};
$e1060510606.stack[R.EXN_STACKHEIGHT++] = $ss1060910610;
}
if(R.isPyretException($e1060510606)) {
$e1060510606.pyretStack.push(L[444]);
}
throw $e1060510606;
}
var $ret1061110612 = $Hann_DASH_check_DASH_temp206610616($z1060710608);
++R.GAS;
return $ret1061110612;
};
var $Hann_DASH_check_DASH_temp206610616 = function(ann_DASH_check_DASH_temp16010615) {
return ann_DASH_check_DASH_temp16010615;
};
var $Hanf_begin_app_dropped20654068 = function(anf_begin_app_dropped20574066,printer2164065,self2154067) {
var anf_bracket15510630 = G(self2154067,"cond",L[963]);
var anf_fun15610627 = G(anf_bracket15510630,"print-ugly-source",L[962]);
var $z1061910620 = D;
var $f1062510626 = function(_) {
return R.isFunction(anf_fun15610627)?anf_fun15610627.app(printer2164065):R.ffi.throwNonFunApp(L[961],anf_fun15610627,[printer2164065]);
};
try {
if(--R.GAS > 0) {
$z1061910620 = $f1062510626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1062510626,
"from":L[961]});
}
} catch($e1061710618) {
if(R.isCont($e1061710618)) {
var $ss1062110622 = {"from":L[961],
"go":function(anf_begin_app_dropped205810628) {
return $Hanf_begin_app_dropped206410629(anf_begin_app_dropped205810628,printer2164065,self2154067);
}};
$e1061710618.stack[R.EXN_STACKHEIGHT++] = $ss1062110622;
}
if(R.isPyretException($e1061710618)) {
$e1061710618.pyretStack.push(L[961]);
}
throw $e1061710618;
}
var $ret1062310624 = $Hanf_begin_app_dropped206410629($z1061910620,printer2164065,self2154067);
++R.GAS;
return $ret1062310624;
};
var $Hanf_begin_app_dropped206410629 = function(anf_begin_app_dropped205810628,printer2164065,self2154067) {
var $z1063310634 = D;
var $f1063910640 = function(_) {
return R.isFunction(printer2164065)?printer2164065.app((") {\n")):R.ffi.throwNonFunApp(L[964],printer2164065,[(") {\n")]);
};
try {
if(--R.GAS > 0) {
$z1063310634 = $f1063910640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1063910640,
"from":L[964]});
}
} catch($e1063110632) {
if(R.isCont($e1063110632)) {
var $ss1063510636 = {"from":L[964],
"go":function(anf_begin_app_dropped205910641) {
return $Hanf_begin_app_dropped206310642(anf_begin_app_dropped205910641,printer2164065,self2154067);
}};
$e1063110632.stack[R.EXN_STACKHEIGHT++] = $ss1063510636;
}
if(R.isPyretException($e1063110632)) {
$e1063110632.pyretStack.push(L[964]);
}
throw $e1063110632;
}
var $ret1063710638 = $Hanf_begin_app_dropped206310642($z1063310634,printer2164065,self2154067);
++R.GAS;
return $ret1063710638;
};
var $Hanf_begin_app_dropped206310642 = function(anf_begin_app_dropped205910641,printer2164065,self2154067) {
var anf_bracket15710656 = G(self2154067,"consq",L[967]);
var anf_fun15810653 = G(anf_bracket15710656,"print-ugly-source",L[966]);
var $z1064510646 = D;
var $f1065110652 = function(_) {
return R.isFunction(anf_fun15810653)?anf_fun15810653.app(printer2164065):R.ffi.throwNonFunApp(L[965],anf_fun15810653,[printer2164065]);
};
try {
if(--R.GAS > 0) {
$z1064510646 = $f1065110652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1065110652,
"from":L[965]});
}
} catch($e1064310644) {
if(R.isCont($e1064310644)) {
var $ss1064710648 = {"from":L[965],
"go":function(anf_begin_app_dropped206010654) {
return $Hanf_begin_app_dropped206210655(anf_begin_app_dropped206010654,printer2164065);
}};
$e1064310644.stack[R.EXN_STACKHEIGHT++] = $ss1064710648;
}
if(R.isPyretException($e1064310644)) {
$e1064310644.pyretStack.push(L[965]);
}
throw $e1064310644;
}
var $ret1064910650 = $Hanf_begin_app_dropped206210655($z1064510646,printer2164065);
++R.GAS;
return $ret1064910650;
};
var $Hanf_begin_app_dropped206210655 = function(anf_begin_app_dropped206010654,printer2164065) {
var $z1065910660 = D;
var $f1066510666 = function(_) {
return R.isFunction(printer2164065)?printer2164065.app(("\n}")):R.ffi.throwNonFunApp(L[446],printer2164065,[("\n}")]);
};
try {
if(--R.GAS > 0) {
$z1065910660 = $f1066510666();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1066510666,
"from":L[446]});
}
} catch($e1065710658) {
if(R.isCont($e1065710658)) {
var $ss1066110662 = {"from":L[446],
"go":function(ann_DASH_check_DASH_temp15410667) {
return $Hann_DASH_check_DASH_temp206110668(ann_DASH_check_DASH_temp15410667);
}};
$e1065710658.stack[R.EXN_STACKHEIGHT++] = $ss1066110662;
}
if(R.isPyretException($e1065710658)) {
$e1065710658.pyretStack.push(L[446]);
}
throw $e1065710658;
}
var $ret1066310664 = $Hann_DASH_check_DASH_temp206110668($z1065910660);
++R.GAS;
return $ret1066310664;
};
var $Hann_DASH_check_DASH_temp206110668 = function(ann_DASH_check_DASH_temp15410667) {
return ann_DASH_check_DASH_temp15410667;
};
var $Hanf_arg20564082 = function(anf_arg1464080,self204081,_plus14,torepr18) {
var anf_arg14710679 = G(self204081,"consq",L[377]);
var $z1067110672 = D;
var $f1067710678 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg14710679):R.ffi.throwNonFunApp(L[377],torepr18,[anf_arg14710679]);
};
try {
if(--R.GAS > 0) {
$z1067110672 = $f1067710678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1067710678,
"from":L[377]});
}
} catch($e1066910670) {
if(R.isCont($e1066910670)) {
var $ss1067310674 = {"from":L[377],
"go":function(anf_arg14810680) {
return $Hanf_arg205510681(anf_arg14810680,anf_arg1464080,_plus14);
}};
$e1066910670.stack[R.EXN_STACKHEIGHT++] = $ss1067310674;
}
if(R.isPyretException($e1066910670)) {
$e1066910670.pyretStack.push(L[377]);
}
throw $e1066910670;
}
var $ret1067510676 = $Hanf_arg205510681($z1067110672,anf_arg1464080,_plus14);
++R.GAS;
return $ret1067510676;
};
var $Hanf_arg205510681 = function(anf_arg14810680,anf_arg1464080,_plus14) {
var $z1068410685 = D;
var $f1069010691 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg14810680):R.ffi.throwNonFunApp(L[377],_plus14,[(", "),anf_arg14810680]);
};
try {
if(--R.GAS > 0) {
$z1068410685 = $f1069010691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1069010691,
"from":L[377]});
}
} catch($e1068210683) {
if(R.isCont($e1068210683)) {
var $ss1068610687 = {"from":L[377],
"go":function(anf_arg14910692) {
return $Hanf_arg205410693(anf_arg14910692,anf_arg1464080,_plus14);
}};
$e1068210683.stack[R.EXN_STACKHEIGHT++] = $ss1068610687;
}
if(R.isPyretException($e1068210683)) {
$e1068210683.pyretStack.push(L[377]);
}
throw $e1068210683;
}
var $ret1068810689 = $Hanf_arg205410693($z1068410685,anf_arg1464080,_plus14);
++R.GAS;
return $ret1068810689;
};
var $Hanf_arg205410693 = function(anf_arg14910692,anf_arg1464080,_plus14) {
var $z1069610697 = D;
var $f1070210703 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg1464080,anf_arg14910692):R.ffi.throwNonFunApp(L[377],_plus14,[anf_arg1464080,anf_arg14910692]);
};
try {
if(--R.GAS > 0) {
$z1069610697 = $f1070210703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1070210703,
"from":L[377]});
}
} catch($e1069410695) {
if(R.isCont($e1069410695)) {
var $ss1069810699 = {"from":L[377],
"go":function(anf_arg15010704) {
return $Hanf_arg205310705(anf_arg15010704,_plus14);
}};
$e1069410695.stack[R.EXN_STACKHEIGHT++] = $ss1069810699;
}
if(R.isPyretException($e1069410695)) {
$e1069410695.pyretStack.push(L[377]);
}
throw $e1069410695;
}
var $ret1070010701 = $Hanf_arg205310705($z1069610697,_plus14);
++R.GAS;
return $ret1070010701;
};
var $Hanf_arg205310705 = function(anf_arg15010704,_plus14) {
var $z1070810709 = D;
var $f1071410715 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg15010704,(")")):R.ffi.throwNonFunApp(L[377],_plus14,[anf_arg15010704,(")")]);
};
try {
if(--R.GAS > 0) {
$z1070810709 = $f1071410715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1071410715,
"from":L[377]});
}
} catch($e1070610707) {
if(R.isCont($e1070610707)) {
var $ss1071010711 = {"from":L[377],
"go":function(anf_arg15110716) {
return $Hanf_arg205210717(anf_arg15110716,_plus14);
}};
$e1070610707.stack[R.EXN_STACKHEIGHT++] = $ss1071010711;
}
if(R.isPyretException($e1070610707)) {
$e1070610707.pyretStack.push(L[377]);
}
throw $e1070610707;
}
var $ret1071210713 = $Hanf_arg205210717($z1070810709,_plus14);
++R.GAS;
return $ret1071210713;
};
var $Hanf_arg205210717 = function(anf_arg15110716,_plus14) {
var $z1072010721 = D;
var $f1072610727 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg15110716):R.ffi.throwNonFunApp(L[377],_plus14,[("("),anf_arg15110716]);
};
try {
if(--R.GAS > 0) {
$z1072010721 = $f1072610727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1072610727,
"from":L[377]});
}
} catch($e1071810719) {
if(R.isCont($e1071810719)) {
var $ss1072210723 = {"from":L[377],
"go":function(anf_arg15210728) {
return $Hanf_arg205110729(anf_arg15210728,_plus14);
}};
$e1071810719.stack[R.EXN_STACKHEIGHT++] = $ss1072210723;
}
if(R.isPyretException($e1071810719)) {
$e1071810719.pyretStack.push(L[377]);
}
throw $e1071810719;
}
var $ret1072410725 = $Hanf_arg205110729($z1072010721,_plus14);
++R.GAS;
return $ret1072410725;
};
var $Hanf_arg205110729 = function(anf_arg15210728,_plus14) {
var $z1073210733 = D;
var $f1073810739 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-if1"),anf_arg15210728):R.ffi.throwNonFunApp(L[377],_plus14,[("j-if1"),anf_arg15210728]);
};
try {
if(--R.GAS > 0) {
$z1073210733 = $f1073810739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1073810739,
"from":L[377]});
}
} catch($e1073010731) {
if(R.isCont($e1073010731)) {
var $ss1073410735 = {"from":L[377],
"go":function(ann_DASH_check_DASH_temp14410740) {
return $Hann_DASH_check_DASH_temp205010741(ann_DASH_check_DASH_temp14410740);
}};
$e1073010731.stack[R.EXN_STACKHEIGHT++] = $ss1073410735;
}
if(R.isPyretException($e1073010731)) {
$e1073010731.pyretStack.push(L[377]);
}
throw $e1073010731;
}
var $ret1073610737 = $Hann_DASH_check_DASH_temp205010741($z1073210733);
++R.GAS;
return $ret1073610737;
};
var $Hann_DASH_check_DASH_temp205010741 = function(ann_DASH_check_DASH_temp14410740) {
return ann_DASH_check_DASH_temp14410740;
};
var $Hcont_tail_arg20484098 = function(cont_tail_arg1414096,if_helper1324097) {
if(--R.GAS > 0) {
$z1074210743 = R.isFunction(if_helper1324097)?if_helper1324097.app(cont_tail_arg1414096):R.ffi.throwNonFunApp(L[377],if_helper1324097,[cont_tail_arg1414096]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1324097)?if_helper1324097.app(cont_tail_arg1414096):R.ffi.throwNonFunApp(L[377],if_helper1324097,[cont_tail_arg1414096]);
},
"from":L[377]});
}
++R.GAS;
return $z1074210743;
};
var $Hcont_tail_arg20494113 = function(cont_tail_arg1374112,if_helper1324097) {
if(--R.GAS > 0) {
$z1074410745 = R.isFunction(if_helper1324097)?if_helper1324097.app(cont_tail_arg1374112):R.ffi.throwNonFunApp(L[377],if_helper1324097,[cont_tail_arg1374112]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper1324097)?if_helper1324097.app(cont_tail_arg1374112):R.ffi.throwNonFunApp(L[377],if_helper1324097,[cont_tail_arg1374112]);
},
"from":L[377]});
}
++R.GAS;
return $z1074410745;
};
var $Hanf_arg20474135 = function(anf_arg1084132,INDENT7747,PP123,anf_fun1064133,self2124134,_plus14) {
var anf_fun10910759 = G(PP123,"group",L[972]);
var anf_fun11010760 = G(PP123,"nest",L[971]);
var anf_fun11110756 = G(PP123,"str",L[970]);
var anf_arg11210757 = G(self2124134,"name",L[969]);
var $z1074810749 = D;
var $f1075410755 = function(_) {
return R.isFunction(anf_fun11110756)?anf_fun11110756.app(anf_arg11210757):R.ffi.throwNonFunApp(L[968],anf_fun11110756,[anf_arg11210757]);
};
try {
if(--R.GAS > 0) {
$z1074810749 = $f1075410755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1075410755,
"from":L[968]});
}
} catch($e1074610747) {
if(R.isCont($e1074610747)) {
var $ss1075010751 = {"from":L[968],
"go":function(anf_arg11310758) {
return $Hanf_arg204610761(anf_arg11310758,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
}};
$e1074610747.stack[R.EXN_STACKHEIGHT++] = $ss1075010751;
}
if(R.isPyretException($e1074610747)) {
$e1074610747.pyretStack.push(L[968]);
}
throw $e1074610747;
}
var $ret1075210753 = $Hanf_arg204610761($z1074810749,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
++R.GAS;
return $ret1075210753;
};
var $Hanf_arg204610761 = function(anf_arg11310758,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14) {
var anf_fun11410772 = G(PP123,"str",L[974]);
var $z1076410765 = D;
var $f1077010771 = function(_) {
return R.isFunction(anf_fun11410772)?anf_fun11410772.app((" =")):R.ffi.throwNonFunApp(L[973],anf_fun11410772,[(" =")]);
};
try {
if(--R.GAS > 0) {
$z1076410765 = $f1077010771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1077010771,
"from":L[973]});
}
} catch($e1076210763) {
if(R.isCont($e1076210763)) {
var $ss1076610767 = {"from":L[973],
"go":function(anf_arg11510773) {
return $Hanf_arg204510774(anf_arg11510773,INDENT7747,PP123,anf_arg1084132,anf_arg11310758,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
}};
$e1076210763.stack[R.EXN_STACKHEIGHT++] = $ss1076610767;
}
if(R.isPyretException($e1076210763)) {
$e1076210763.pyretStack.push(L[973]);
}
throw $e1076210763;
}
var $ret1076810769 = $Hanf_arg204510774($z1076410765,INDENT7747,PP123,anf_arg1084132,anf_arg11310758,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
++R.GAS;
return $ret1076810769;
};
var $Hanf_arg204510774 = function(anf_arg11510773,INDENT7747,PP123,anf_arg1084132,anf_arg11310758,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14) {
var $z1077710778 = D;
var $f1078310784 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11310758,anf_arg11510773):R.ffi.throwNonFunApp(L[975],_plus14,[anf_arg11310758,anf_arg11510773]);
};
try {
if(--R.GAS > 0) {
$z1077710778 = $f1078310784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1078310784,
"from":L[975]});
}
} catch($e1077510776) {
if(R.isCont($e1077510776)) {
var $ss1077910780 = {"from":L[975],
"go":function(anf_arg11610785) {
return $Hanf_arg204410786(anf_arg11610785,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
}};
$e1077510776.stack[R.EXN_STACKHEIGHT++] = $ss1077910780;
}
if(R.isPyretException($e1077510776)) {
$e1077510776.pyretStack.push(L[975]);
}
throw $e1077510776;
}
var $ret1078110782 = $Hanf_arg204410786($z1077710778,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
++R.GAS;
return $ret1078110782;
};
var $Hanf_arg204410786 = function(anf_arg11610785,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14) {
var anf_fun11710797 = G(PP123,"sbreak",L[977]);
var $z1078910790 = D;
var $f1079510796 = function(_) {
return R.isFunction(anf_fun11710797)?anf_fun11710797.app((1)):R.ffi.throwNonFunApp(L[976],anf_fun11710797,[(1)]);
};
try {
if(--R.GAS > 0) {
$z1078910790 = $f1079510796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1079510796,
"from":L[976]});
}
} catch($e1078710788) {
if(R.isCont($e1078710788)) {
var $ss1079110792 = {"from":L[976],
"go":function(anf_arg11810798) {
return $Hanf_arg204310799(anf_arg11810798,INDENT7747,PP123,anf_arg1084132,anf_arg11610785,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
}};
$e1078710788.stack[R.EXN_STACKHEIGHT++] = $ss1079110792;
}
if(R.isPyretException($e1078710788)) {
$e1078710788.pyretStack.push(L[976]);
}
throw $e1078710788;
}
var $ret1079310794 = $Hanf_arg204310799($z1078910790,INDENT7747,PP123,anf_arg1084132,anf_arg11610785,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
++R.GAS;
return $ret1079310794;
};
var $Hanf_arg204310799 = function(anf_arg11810798,INDENT7747,PP123,anf_arg1084132,anf_arg11610785,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14) {
var $z1080210803 = D;
var $f1080810809 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11610785,anf_arg11810798):R.ffi.throwNonFunApp(L[975],_plus14,[anf_arg11610785,anf_arg11810798]);
};
try {
if(--R.GAS > 0) {
$z1080210803 = $f1080810809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1080810809,
"from":L[975]});
}
} catch($e1080010801) {
if(R.isCont($e1080010801)) {
var $ss1080410805 = {"from":L[975],
"go":function(anf_arg11910810) {
return $Hanf_arg204210811(anf_arg11910810,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
}};
$e1080010801.stack[R.EXN_STACKHEIGHT++] = $ss1080410805;
}
if(R.isPyretException($e1080010801)) {
$e1080010801.pyretStack.push(L[975]);
}
throw $e1080010801;
}
var $ret1080610807 = $Hanf_arg204210811($z1080210803,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14);
++R.GAS;
return $ret1080610807;
};
var $Hanf_arg204210811 = function(anf_arg11910810,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,self2124134,_plus14) {
var anf_bracket12010825 = G(self2124134,"rhs",L[980]);
var anf_fun12110822 = G(anf_bracket12010825,"tosource",L[979]);
var $z1081410815 = D;
var $f1082010821 = function(_) {
return R.isFunction(anf_fun12110822)?anf_fun12110822.app():R.ffi.throwNonFunApp(L[978],anf_fun12110822,[]);
};
try {
if(--R.GAS > 0) {
$z1081410815 = $f1082010821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1082010821,
"from":L[978]});
}
} catch($e1081210813) {
if(R.isCont($e1081210813)) {
var $ss1081610817 = {"from":L[978],
"go":function(anf_arg12210823) {
return $Hanf_arg204110824(anf_arg12210823,INDENT7747,PP123,anf_arg1084132,anf_arg11910810,anf_fun1064133,anf_fun10910759,anf_fun11010760,_plus14);
}};
$e1081210813.stack[R.EXN_STACKHEIGHT++] = $ss1081610817;
}
if(R.isPyretException($e1081210813)) {
$e1081210813.pyretStack.push(L[978]);
}
throw $e1081210813;
}
var $ret1081810819 = $Hanf_arg204110824($z1081410815,INDENT7747,PP123,anf_arg1084132,anf_arg11910810,anf_fun1064133,anf_fun10910759,anf_fun11010760,_plus14);
++R.GAS;
return $ret1081810819;
};
var $Hanf_arg204110824 = function(anf_arg12210823,INDENT7747,PP123,anf_arg1084132,anf_arg11910810,anf_fun1064133,anf_fun10910759,anf_fun11010760,_plus14) {
var $z1082810829 = D;
var $f1083410835 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg11910810,anf_arg12210823):R.ffi.throwNonFunApp(L[975],_plus14,[anf_arg11910810,anf_arg12210823]);
};
try {
if(--R.GAS > 0) {
$z1082810829 = $f1083410835();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1083410835,
"from":L[975]});
}
} catch($e1082610827) {
if(R.isCont($e1082610827)) {
var $ss1083010831 = {"from":L[975],
"go":function(anf_arg12310836) {
return $Hanf_arg204010837(anf_arg12310836,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,_plus14);
}};
$e1082610827.stack[R.EXN_STACKHEIGHT++] = $ss1083010831;
}
if(R.isPyretException($e1082610827)) {
$e1082610827.pyretStack.push(L[975]);
}
throw $e1082610827;
}
var $ret1083210833 = $Hanf_arg204010837($z1082810829,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,_plus14);
++R.GAS;
return $ret1083210833;
};
var $Hanf_arg204010837 = function(anf_arg12310836,INDENT7747,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,anf_fun11010760,_plus14) {
var $z1084010841 = D;
var $f1084610847 = function(_) {
return R.isFunction(anf_fun11010760)?anf_fun11010760.app(INDENT7747,anf_arg12310836):R.ffi.throwNonFunApp(L[981],anf_fun11010760,[INDENT7747,anf_arg12310836]);
};
try {
if(--R.GAS > 0) {
$z1084010841 = $f1084610847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1084610847,
"from":L[981]});
}
} catch($e1083810839) {
if(R.isCont($e1083810839)) {
var $ss1084210843 = {"from":L[981],
"go":function(anf_arg12410848) {
return $Hanf_arg203910849(anf_arg12410848,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,_plus14);
}};
$e1083810839.stack[R.EXN_STACKHEIGHT++] = $ss1084210843;
}
if(R.isPyretException($e1083810839)) {
$e1083810839.pyretStack.push(L[981]);
}
throw $e1083810839;
}
var $ret1084410845 = $Hanf_arg203910849($z1084010841,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,_plus14);
++R.GAS;
return $ret1084410845;
};
var $Hanf_arg203910849 = function(anf_arg12410848,PP123,anf_arg1084132,anf_fun1064133,anf_fun10910759,_plus14) {
var $z1085210853 = D;
var $f1085810859 = function(_) {
return R.isFunction(anf_fun10910759)?anf_fun10910759.app(anf_arg12410848):R.ffi.throwNonFunApp(L[982],anf_fun10910759,[anf_arg12410848]);
};
try {
if(--R.GAS > 0) {
$z1085210853 = $f1085810859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1085810859,
"from":L[982]});
}
} catch($e1085010851) {
if(R.isCont($e1085010851)) {
var $ss1085410855 = {"from":L[982],
"go":function(anf_arg12510860) {
return $Hanf_arg203810861(anf_arg12510860,PP123,anf_arg1084132,anf_fun1064133,_plus14);
}};
$e1085010851.stack[R.EXN_STACKHEIGHT++] = $ss1085410855;
}
if(R.isPyretException($e1085010851)) {
$e1085010851.pyretStack.push(L[982]);
}
throw $e1085010851;
}
var $ret1085610857 = $Hanf_arg203810861($z1085210853,PP123,anf_arg1084132,anf_fun1064133,_plus14);
++R.GAS;
return $ret1085610857;
};
var $Hanf_arg203810861 = function(anf_arg12510860,PP123,anf_arg1084132,anf_fun1064133,_plus14) {
var $z1086410865 = D;
var $f1087010871 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg1084132,anf_arg12510860):R.ffi.throwNonFunApp(L[983],_plus14,[anf_arg1084132,anf_arg12510860]);
};
try {
if(--R.GAS > 0) {
$z1086410865 = $f1087010871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1087010871,
"from":L[983]});
}
} catch($e1086210863) {
if(R.isCont($e1086210863)) {
var $ss1086610867 = {"from":L[983],
"go":function(anf_arg12610872) {
return $Hanf_arg203710873(anf_arg12610872,PP123,anf_fun1064133,_plus14);
}};
$e1086210863.stack[R.EXN_STACKHEIGHT++] = $ss1086610867;
}
if(R.isPyretException($e1086210863)) {
$e1086210863.pyretStack.push(L[983]);
}
throw $e1086210863;
}
var $ret1086810869 = $Hanf_arg203710873($z1086410865,PP123,anf_fun1064133,_plus14);
++R.GAS;
return $ret1086810869;
};
var $Hanf_arg203710873 = function(anf_arg12610872,PP123,anf_fun1064133,_plus14) {
var anf_fun12710884 = G(PP123,"str",L[985]);
var $z1087610877 = D;
var $f1088210883 = function(_) {
return R.isFunction(anf_fun12710884)?anf_fun12710884.app((";")):R.ffi.throwNonFunApp(L[984],anf_fun12710884,[(";")]);
};
try {
if(--R.GAS > 0) {
$z1087610877 = $f1088210883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1088210883,
"from":L[984]});
}
} catch($e1087410875) {
if(R.isCont($e1087410875)) {
var $ss1087810879 = {"from":L[984],
"go":function(anf_arg12810885) {
return $Hanf_arg203610886(anf_arg12810885,anf_arg12610872,anf_fun1064133,_plus14);
}};
$e1087410875.stack[R.EXN_STACKHEIGHT++] = $ss1087810879;
}
if(R.isPyretException($e1087410875)) {
$e1087410875.pyretStack.push(L[984]);
}
throw $e1087410875;
}
var $ret1088010881 = $Hanf_arg203610886($z1087610877,anf_arg12610872,anf_fun1064133,_plus14);
++R.GAS;
return $ret1088010881;
};
var $Hanf_arg203610886 = function(anf_arg12810885,anf_arg12610872,anf_fun1064133,_plus14) {
var $z1088910890 = D;
var $f1089510896 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg12610872,anf_arg12810885):R.ffi.throwNonFunApp(L[983],_plus14,[anf_arg12610872,anf_arg12810885]);
};
try {
if(--R.GAS > 0) {
$z1088910890 = $f1089510896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1089510896,
"from":L[983]});
}
} catch($e1088710888) {
if(R.isCont($e1088710888)) {
var $ss1089110892 = {"from":L[983],
"go":function(anf_arg12910897) {
return $Hanf_arg203510898(anf_arg12910897,anf_fun1064133);
}};
$e1088710888.stack[R.EXN_STACKHEIGHT++] = $ss1089110892;
}
if(R.isPyretException($e1088710888)) {
$e1088710888.pyretStack.push(L[983]);
}
throw $e1088710888;
}
var $ret1089310894 = $Hanf_arg203510898($z1088910890,anf_fun1064133);
++R.GAS;
return $ret1089310894;
};
var $Hanf_arg203510898 = function(anf_arg12910897,anf_fun1064133) {
var $z1090110902 = D;
var $f1090710908 = function(_) {
return R.isFunction(anf_fun1064133)?anf_fun1064133.app(anf_arg12910897):R.ffi.throwNonFunApp(L[452],anf_fun1064133,[anf_arg12910897]);
};
try {
if(--R.GAS > 0) {
$z1090110902 = $f1090710908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1090710908,
"from":L[452]});
}
} catch($e1089910900) {
if(R.isCont($e1089910900)) {
var $ss1090310904 = {"from":L[452],
"go":function(ann_DASH_check_DASH_temp10510909) {
return $Hann_DASH_check_DASH_temp203410910(ann_DASH_check_DASH_temp10510909);
}};
$e1089910900.stack[R.EXN_STACKHEIGHT++] = $ss1090310904;
}
if(R.isPyretException($e1089910900)) {
$e1089910900.pyretStack.push(L[452]);
}
throw $e1089910900;
}
var $ret1090510906 = $Hann_DASH_check_DASH_temp203410910($z1090110902);
++R.GAS;
return $ret1090510906;
};
var $Hann_DASH_check_DASH_temp203410910 = function(ann_DASH_check_DASH_temp10510909) {
return ann_DASH_check_DASH_temp10510909;
};
var $Hanf_arg20334150 = function(anf_arg1004147,printer2114148,self2104149,_plus14) {
var $z1091310914 = D;
var $f1091910920 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg1004147,(" = ")):R.ffi.throwNonFunApp(L[453],_plus14,[anf_arg1004147,(" = ")]);
};
try {
if(--R.GAS > 0) {
$z1091310914 = $f1091910920();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1091910920,
"from":L[453]});
}
} catch($e1091110912) {
if(R.isCont($e1091110912)) {
var $ss1091510916 = {"from":L[453],
"go":function(anf_arg10110921) {
return $Hanf_arg203210922(anf_arg10110921,printer2114148,self2104149);
}};
$e1091110912.stack[R.EXN_STACKHEIGHT++] = $ss1091510916;
}
if(R.isPyretException($e1091110912)) {
$e1091110912.pyretStack.push(L[453]);
}
throw $e1091110912;
}
var $ret1091710918 = $Hanf_arg203210922($z1091310914,printer2114148,self2104149);
++R.GAS;
return $ret1091710918;
};
var $Hanf_arg203210922 = function(anf_arg10110921,printer2114148,self2104149) {
var $z1092510926 = D;
var $f1093110932 = function(_) {
return R.isFunction(printer2114148)?printer2114148.app(anf_arg10110921):R.ffi.throwNonFunApp(L[986],printer2114148,[anf_arg10110921]);
};
try {
if(--R.GAS > 0) {
$z1092510926 = $f1093110932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1093110932,
"from":L[986]});
}
} catch($e1092310924) {
if(R.isCont($e1092310924)) {
var $ss1092710928 = {"from":L[986],
"go":function(anf_begin_app_dropped202710933) {
return $Hanf_begin_app_dropped203110934(anf_begin_app_dropped202710933,printer2114148,self2104149);
}};
$e1092310924.stack[R.EXN_STACKHEIGHT++] = $ss1092710928;
}
if(R.isPyretException($e1092310924)) {
$e1092310924.pyretStack.push(L[986]);
}
throw $e1092310924;
}
var $ret1092910930 = $Hanf_begin_app_dropped203110934($z1092510926,printer2114148,self2104149);
++R.GAS;
return $ret1092910930;
};
var $Hanf_begin_app_dropped203110934 = function(anf_begin_app_dropped202710933,printer2114148,self2104149) {
var anf_bracket10210948 = G(self2104149,"rhs",L[989]);
var anf_fun10310945 = G(anf_bracket10210948,"print-ugly-source",L[988]);
var $z1093710938 = D;
var $f1094310944 = function(_) {
return R.isFunction(anf_fun10310945)?anf_fun10310945.app(printer2114148):R.ffi.throwNonFunApp(L[987],anf_fun10310945,[printer2114148]);
};
try {
if(--R.GAS > 0) {
$z1093710938 = $f1094310944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1094310944,
"from":L[987]});
}
} catch($e1093510936) {
if(R.isCont($e1093510936)) {
var $ss1093910940 = {"from":L[987],
"go":function(anf_begin_app_dropped202810946) {
return $Hanf_begin_app_dropped203010947(anf_begin_app_dropped202810946,printer2114148);
}};
$e1093510936.stack[R.EXN_STACKHEIGHT++] = $ss1093910940;
}
if(R.isPyretException($e1093510936)) {
$e1093510936.pyretStack.push(L[987]);
}
throw $e1093510936;
}
var $ret1094110942 = $Hanf_begin_app_dropped203010947($z1093710938,printer2114148);
++R.GAS;
return $ret1094110942;
};
var $Hanf_begin_app_dropped203010947 = function(anf_begin_app_dropped202810946,printer2114148) {
var $z1095110952 = D;
var $f1095710958 = function(_) {
return R.isFunction(printer2114148)?printer2114148.app((";")):R.ffi.throwNonFunApp(L[455],printer2114148,[(";")]);
};
try {
if(--R.GAS > 0) {
$z1095110952 = $f1095710958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1095710958,
"from":L[455]});
}
} catch($e1094910950) {
if(R.isCont($e1094910950)) {
var $ss1095310954 = {"from":L[455],
"go":function(ann_DASH_check_DASH_temp9810959) {
return $Hann_DASH_check_DASH_temp202910960(ann_DASH_check_DASH_temp9810959);
}};
$e1094910950.stack[R.EXN_STACKHEIGHT++] = $ss1095310954;
}
if(R.isPyretException($e1094910950)) {
$e1094910950.pyretStack.push(L[455]);
}
throw $e1094910950;
}
var $ret1095510956 = $Hann_DASH_check_DASH_temp202910960($z1095110952);
++R.GAS;
return $ret1095510956;
};
var $Hann_DASH_check_DASH_temp202910960 = function(ann_DASH_check_DASH_temp9810959) {
return ann_DASH_check_DASH_temp9810959;
};
var $Hanf_arg20264164 = function(anf_arg904162,self144163,_plus14,torepr18) {
var anf_arg9110971 = G(self144163,"rhs",L[378]);
var $z1096310964 = D;
var $f1096910970 = function(_) {
return R.isFunction(torepr18)?torepr18.app(anf_arg9110971):R.ffi.throwNonFunApp(L[378],torepr18,[anf_arg9110971]);
};
try {
if(--R.GAS > 0) {
$z1096310964 = $f1096910970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1096910970,
"from":L[378]});
}
} catch($e1096110962) {
if(R.isCont($e1096110962)) {
var $ss1096510966 = {"from":L[378],
"go":function(anf_arg9210972) {
return $Hanf_arg202510973(anf_arg9210972,anf_arg904162,_plus14);
}};
$e1096110962.stack[R.EXN_STACKHEIGHT++] = $ss1096510966;
}
if(R.isPyretException($e1096110962)) {
$e1096110962.pyretStack.push(L[378]);
}
throw $e1096110962;
}
var $ret1096710968 = $Hanf_arg202510973($z1096310964,anf_arg904162,_plus14);
++R.GAS;
return $ret1096710968;
};
var $Hanf_arg202510973 = function(anf_arg9210972,anf_arg904162,_plus14) {
var $z1097610977 = D;
var $f1098210983 = function(_) {
return R.isFunction(_plus14)?_plus14.app((", "),anf_arg9210972):R.ffi.throwNonFunApp(L[378],_plus14,[(", "),anf_arg9210972]);
};
try {
if(--R.GAS > 0) {
$z1097610977 = $f1098210983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1098210983,
"from":L[378]});
}
} catch($e1097410975) {
if(R.isCont($e1097410975)) {
var $ss1097810979 = {"from":L[378],
"go":function(anf_arg9310984) {
return $Hanf_arg202410985(anf_arg9310984,anf_arg904162,_plus14);
}};
$e1097410975.stack[R.EXN_STACKHEIGHT++] = $ss1097810979;
}
if(R.isPyretException($e1097410975)) {
$e1097410975.pyretStack.push(L[378]);
}
throw $e1097410975;
}
var $ret1098010981 = $Hanf_arg202410985($z1097610977,anf_arg904162,_plus14);
++R.GAS;
return $ret1098010981;
};
var $Hanf_arg202410985 = function(anf_arg9310984,anf_arg904162,_plus14) {
var $z1098810989 = D;
var $f1099410995 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg904162,anf_arg9310984):R.ffi.throwNonFunApp(L[378],_plus14,[anf_arg904162,anf_arg9310984]);
};
try {
if(--R.GAS > 0) {
$z1098810989 = $f1099410995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1099410995,
"from":L[378]});
}
} catch($e1098610987) {
if(R.isCont($e1098610987)) {
var $ss1099010991 = {"from":L[378],
"go":function(anf_arg9410996) {
return $Hanf_arg202310997(anf_arg9410996,_plus14);
}};
$e1098610987.stack[R.EXN_STACKHEIGHT++] = $ss1099010991;
}
if(R.isPyretException($e1098610987)) {
$e1098610987.pyretStack.push(L[378]);
}
throw $e1098610987;
}
var $ret1099210993 = $Hanf_arg202310997($z1098810989,_plus14);
++R.GAS;
return $ret1099210993;
};
var $Hanf_arg202310997 = function(anf_arg9410996,_plus14) {
var $z1100011001 = D;
var $f1100611007 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg9410996,(")")):R.ffi.throwNonFunApp(L[378],_plus14,[anf_arg9410996,(")")]);
};
try {
if(--R.GAS > 0) {
$z1100011001 = $f1100611007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1100611007,
"from":L[378]});
}
} catch($e1099810999) {
if(R.isCont($e1099810999)) {
var $ss1100211003 = {"from":L[378],
"go":function(anf_arg9511008) {
return $Hanf_arg202211009(anf_arg9511008,_plus14);
}};
$e1099810999.stack[R.EXN_STACKHEIGHT++] = $ss1100211003;
}
if(R.isPyretException($e1099810999)) {
$e1099810999.pyretStack.push(L[378]);
}
throw $e1099810999;
}
var $ret1100411005 = $Hanf_arg202211009($z1100011001,_plus14);
++R.GAS;
return $ret1100411005;
};
var $Hanf_arg202211009 = function(anf_arg9511008,_plus14) {
var $z1101211013 = D;
var $f1101811019 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg9511008):R.ffi.throwNonFunApp(L[378],_plus14,[("("),anf_arg9511008]);
};
try {
if(--R.GAS > 0) {
$z1101211013 = $f1101811019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1101811019,
"from":L[378]});
}
} catch($e1101011011) {
if(R.isCont($e1101011011)) {
var $ss1101411015 = {"from":L[378],
"go":function(anf_arg9611020) {
return $Hanf_arg202111021(anf_arg9611020,_plus14);
}};
$e1101011011.stack[R.EXN_STACKHEIGHT++] = $ss1101411015;
}
if(R.isPyretException($e1101011011)) {
$e1101011011.pyretStack.push(L[378]);
}
throw $e1101011011;
}
var $ret1101611017 = $Hanf_arg202111021($z1101211013,_plus14);
++R.GAS;
return $ret1101611017;
};
var $Hanf_arg202111021 = function(anf_arg9611020,_plus14) {
var $z1102411025 = D;
var $f1103011031 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-var"),anf_arg9611020):R.ffi.throwNonFunApp(L[378],_plus14,[("j-var"),anf_arg9611020]);
};
try {
if(--R.GAS > 0) {
$z1102411025 = $f1103011031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1103011031,
"from":L[378]});
}
} catch($e1102211023) {
if(R.isCont($e1102211023)) {
var $ss1102611027 = {"from":L[378],
"go":function(ann_DASH_check_DASH_temp8811032) {
return $Hann_DASH_check_DASH_temp202011033(ann_DASH_check_DASH_temp8811032);
}};
$e1102211023.stack[R.EXN_STACKHEIGHT++] = $ss1102611027;
}
if(R.isPyretException($e1102211023)) {
$e1102211023.pyretStack.push(L[378]);
}
throw $e1102211023;
}
var $ret1102811029 = $Hann_DASH_check_DASH_temp202011033($z1102411025);
++R.GAS;
return $ret1102811029;
};
var $Hann_DASH_check_DASH_temp202011033 = function(ann_DASH_check_DASH_temp8811032) {
return ann_DASH_check_DASH_temp8811032;
};
var $Hcont_tail_arg20184180 = function(cont_tail_arg854178,if_helper764179) {
if(--R.GAS > 0) {
$z1103411035 = R.isFunction(if_helper764179)?if_helper764179.app(cont_tail_arg854178):R.ffi.throwNonFunApp(L[378],if_helper764179,[cont_tail_arg854178]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper764179)?if_helper764179.app(cont_tail_arg854178):R.ffi.throwNonFunApp(L[378],if_helper764179,[cont_tail_arg854178]);
},
"from":L[378]});
}
++R.GAS;
return $z1103411035;
};
var $Hcont_tail_arg20194195 = function(cont_tail_arg814194,if_helper764179) {
if(--R.GAS > 0) {
$z1103611037 = R.isFunction(if_helper764179)?if_helper764179.app(cont_tail_arg814194):R.ffi.throwNonFunApp(L[378],if_helper764179,[cont_tail_arg814194]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper764179)?if_helper764179.app(cont_tail_arg814194):R.ffi.throwNonFunApp(L[378],if_helper764179,[cont_tail_arg814194]);
},
"from":L[378]});
}
++R.GAS;
return $z1103611037;
};
var $Hstrprint20174215 = function(strprint2454213,self2444214) {
var anf_fun7111048 = G(self2444214,"print-ugly-source",L[992]);
var anf_arg7211049 = G(strprint2454213,"append",L[991]);
var $z1104011041 = D;
var $f1104611047 = function(_) {
return R.isFunction(anf_fun7111048)?anf_fun7111048.app(anf_arg7211049):R.ffi.throwNonFunApp(L[990],anf_fun7111048,[anf_arg7211049]);
};
try {
if(--R.GAS > 0) {
$z1104011041 = $f1104611047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1104611047,
"from":L[990]});
}
} catch($e1103811039) {
if(R.isCont($e1103811039)) {
var $ss1104211043 = {"from":L[990],
"go":function(anf_begin_app_dropped201411050) {
return $Hanf_begin_app_dropped201611051(anf_begin_app_dropped201411050,strprint2454213);
}};
$e1103811039.stack[R.EXN_STACKHEIGHT++] = $ss1104211043;
}
if(R.isPyretException($e1103811039)) {
$e1103811039.pyretStack.push(L[990]);
}
throw $e1103811039;
}
var $ret1104411045 = $Hanf_begin_app_dropped201611051($z1104011041,strprint2454213);
++R.GAS;
return $ret1104411045;
};
var $Hanf_begin_app_dropped201611051 = function(anf_begin_app_dropped201411050,strprint2454213) {
var anf_fun7311062 = G(strprint2454213,"get",L[993]);
var $z1105411055 = D;
var $f1106011061 = function(_) {
return R.isFunction(anf_fun7311062)?anf_fun7311062.app():R.ffi.throwNonFunApp(L[459],anf_fun7311062,[]);
};
try {
if(--R.GAS > 0) {
$z1105411055 = $f1106011061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1106011061,
"from":L[459]});
}
} catch($e1105211053) {
if(R.isCont($e1105211053)) {
var $ss1105611057 = {"from":L[459],
"go":function(ann_DASH_check_DASH_temp7011063) {
return $Hann_DASH_check_DASH_temp201511064(ann_DASH_check_DASH_temp7011063);
}};
$e1105211053.stack[R.EXN_STACKHEIGHT++] = $ss1105611057;
}
if(R.isPyretException($e1105211053)) {
$e1105211053.pyretStack.push(L[459]);
}
throw $e1105211053;
}
var $ret1105811059 = $Hann_DASH_check_DASH_temp201511064($z1105411055);
++R.GAS;
return $ret1105811059;
};
var $Hann_DASH_check_DASH_temp201511064 = function(ann_DASH_check_DASH_temp7011063) {
return ann_DASH_check_DASH_temp7011063;
};
var $Hann_DASH_check_DASH_temp20134241 = function(ann_DASH_check_DASH_temp514240) {
return ann_DASH_check_DASH_temp514240;
};
var $Hann_DASH_check_DASH_temp20124257 = function(ann_DASH_check_DASH_temp564256) {
return ann_DASH_check_DASH_temp564256;
};
var $Hann_DASH_check_DASH_temp20114271 = function(ann_DASH_check_DASH_temp594270) {
return ann_DASH_check_DASH_temp594270;
};
var $Hwhen_DASH_20104288 = function(when_DASH_74286,each4361,printer2034287,self2022019,nothing16) {
var if_helper3511077 = R.makeFunction(function(if_helper_arg3611097) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[473],1,arguments);
}
var ann_DASH_check_DASH_temp3311098 = if_helper_arg3611097;
return ann_DASH_check_DASH_temp3311098;
});
var anf_if3911096 = R.isBoolean(when_DASH_74286);
if(R.isPyretTrue(anf_if3911096)) {
if(R.isPyretTrue(when_DASH_74286)) {
var anf_bracket4111080 = G(self2022019,"stmts",L[997]);
var anf_bracket4211079 = G(anf_bracket4111080,"first",L[996]);
var anf_fun4311075 = G(anf_bracket4211079,"print-ugly-source",L[995]);
var $z1106711068 = D;
var $f1107311074 = function(_) {
return R.isFunction(anf_fun4311075)?anf_fun4311075.app(printer2034287):R.ffi.throwNonFunApp(L[994],anf_fun4311075,[printer2034287]);
};
try {
if(--R.GAS > 0) {
$z1106711068 = $f1107311074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1107311074,
"from":L[994]});
}
} catch($e1106511066) {
if(R.isCont($e1106511066)) {
var $ss1106911070 = {"from":L[994],
"go":function(anf_begin_app_dropped200111076) {
return $Hanf_begin_app_dropped200811078(anf_begin_app_dropped200111076,each4361,if_helper3511077,printer2034287,self2022019,nothing16);
}};
$e1106511066.stack[R.EXN_STACKHEIGHT++] = $ss1106911070;
}
if(R.isPyretException($e1106511066)) {
$e1106511066.pyretStack.push(L[994]);
}
throw $e1106511066;
}
var $ret1107111072 = $Hanf_begin_app_dropped200811078($z1106711068,each4361,if_helper3511077,printer2034287,self2022019,nothing16);
++R.GAS;
return $ret1107111072;
} else {
var $z1108311084 = D;
var $f1108911090 = function(_) {
return R.isFunction(if_helper3511077)?if_helper3511077.app(nothing16):R.ffi.throwNonFunApp(L[473],if_helper3511077,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z1108311084 = $f1108911090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1108911090,
"from":L[473]});
}
} catch($e1108111082) {
if(R.isCont($e1108111082)) {
var $ss1108511086 = {"from":L[473],
"go":function(cont_tail_app4011091) {
return $Hcont_tail_app200911092(cont_tail_app4011091);
}};
$e1108111082.stack[R.EXN_STACKHEIGHT++] = $ss1108511086;
}
if(R.isPyretException($e1108111082)) {
$e1108111082.pyretStack.push(L[473]);
}
throw $e1108111082;
}
var $ret1108711088 = $Hcont_tail_app200911092($z1108311084);
++R.GAS;
return $ret1108711088;
}
} else {
var cont_tail_arg3711095 = R.throwNonBooleanCondition(L[998],("when"),when_DASH_74286);
if(--R.GAS > 0) {
$z1109311094 = R.isFunction(if_helper3511077)?if_helper3511077.app(cont_tail_arg3711095):R.ffi.throwNonFunApp(L[998],if_helper3511077,[cont_tail_arg3711095]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper3511077)?if_helper3511077.app(cont_tail_arg3711095):R.ffi.throwNonFunApp(L[998],if_helper3511077,[cont_tail_arg3711095]);
},
"from":L[998]});
}
++R.GAS;
return $z1109311094;
}
};
var $Hanf_begin_app_dropped200811078 = function(anf_begin_app_dropped200111076,each4361,if_helper3511077,printer2034287,self2022019,nothing16) {
var anf_arg4611109 = R.makeFunction(function(s20411114) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1002],1,arguments);
}
var $z1111711118 = D;
var $f1112311124 = function(_) {
return R.isFunction(printer2034287)?printer2034287.app(("\n")):R.ffi.throwNonFunApp(L[1003],printer2034287,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z1111711118 = $f1112311124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1112311124,
"from":L[1003]});
}
} catch($e1111511116) {
if(R.isCont($e1111511116)) {
var $ss1111911120 = {"from":L[1003],
"go":function(anf_begin_app_dropped200211125) {
return $Hanf_begin_app_dropped200411126(anf_begin_app_dropped200211125,printer2034287,s20411114);
}};
$e1111511116.stack[R.EXN_STACKHEIGHT++] = $ss1111911120;
}
if(R.isPyretException($e1111511116)) {
$e1111511116.pyretStack.push(L[1003]);
}
throw $e1111511116;
}
var $ret1112111122 = $Hanf_begin_app_dropped200411126($z1111711118,printer2034287,s20411114);
++R.GAS;
return $ret1112111122;
});
var anf_bracket4711113 = G(self2022019,"stmts",L[1001]);
var anf_arg4811110 = G(anf_bracket4711113,"rest",L[1000]);
var $z1110111102 = D;
var $f1110711108 = function(_) {
return R.isFunction(each4361)?each4361.app(anf_arg4611109,anf_arg4811110):R.ffi.throwNonFunApp(L[999],each4361,[anf_arg4611109,anf_arg4811110]);
};
try {
if(--R.GAS > 0) {
$z1110111102 = $f1110711108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1110711108,
"from":L[999]});
}
} catch($e1109911100) {
if(R.isCont($e1109911100)) {
var $ss1110311104 = {"from":L[999],
"go":function(anf_begin_app_dropped200511111) {
return $Hanf_begin_app_dropped200711112(anf_begin_app_dropped200511111,if_helper3511077,nothing16);
}};
$e1109911100.stack[R.EXN_STACKHEIGHT++] = $ss1110311104;
}
if(R.isPyretException($e1109911100)) {
$e1109911100.pyretStack.push(L[999]);
}
throw $e1109911100;
}
var $ret1110511106 = $Hanf_begin_app_dropped200711112($z1110111102,if_helper3511077,nothing16);
++R.GAS;
return $ret1110511106;
};
var $Hanf_begin_app_dropped200711112 = function(anf_begin_app_dropped200511111,if_helper3511077,nothing16) {
var $z1112911130 = D;
var $f1113511136 = function(_) {
return R.isFunction(if_helper3511077)?if_helper3511077.app(nothing16):R.ffi.throwNonFunApp(L[473],if_helper3511077,[nothing16]);
};
try {
if(--R.GAS > 0) {
$z1112911130 = $f1113511136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1113511136,
"from":L[473]});
}
} catch($e1112711128) {
if(R.isCont($e1112711128)) {
var $ss1113111132 = {"from":L[473],
"go":function(cont_tail_app4911137) {
return $Hcont_tail_app200611138(cont_tail_app4911137);
}};
$e1112711128.stack[R.EXN_STACKHEIGHT++] = $ss1113111132;
}
if(R.isPyretException($e1112711128)) {
$e1112711128.pyretStack.push(L[473]);
}
throw $e1112711128;
}
var $ret1113311134 = $Hcont_tail_app200611138($z1112911130);
++R.GAS;
return $ret1113311134;
};
var $Hcont_tail_app200611138 = function(cont_tail_app4911137) {
return cont_tail_app4911137;
};
var $Hanf_begin_app_dropped200411126 = function(anf_begin_app_dropped200211125,printer2034287,s20411114) {
var anf_fun4511149 = G(s20411114,"print-ugly-source",L[1004]);
var $z1114111142 = D;
var $f1114711148 = function(_) {
return R.isFunction(anf_fun4511149)?anf_fun4511149.app(printer2034287):R.ffi.throwNonFunApp(L[1002],anf_fun4511149,[printer2034287]);
};
try {
if(--R.GAS > 0) {
$z1114111142 = $f1114711148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1114711148,
"from":L[1002]});
}
} catch($e1113911140) {
if(R.isCont($e1113911140)) {
var $ss1114311144 = {"from":L[1002],
"go":function(ann_DASH_check_DASH_temp4411150) {
return $Hann_DASH_check_DASH_temp200311151(ann_DASH_check_DASH_temp4411150);
}};
$e1113911140.stack[R.EXN_STACKHEIGHT++] = $ss1114311144;
}
if(R.isPyretException($e1113911140)) {
$e1113911140.pyretStack.push(L[1002]);
}
throw $e1113911140;
}
var $ret1114511146 = $Hann_DASH_check_DASH_temp200311151($z1114111142);
++R.GAS;
return $ret1114511146;
};
var $Hann_DASH_check_DASH_temp200311151 = function(ann_DASH_check_DASH_temp4411150) {
return ann_DASH_check_DASH_temp4411150;
};
var $Hcont_tail_app200911092 = function(cont_tail_app4011091) {
return cont_tail_app4011091;
};
var $Hanf_arg20004301 = function(anf_arg294300,_plus14) {
var $z1115411155 = D;
var $f1116011161 = function(_) {
return R.isFunction(_plus14)?_plus14.app(anf_arg294300,(")")):R.ffi.throwNonFunApp(L[460],_plus14,[anf_arg294300,(")")]);
};
try {
if(--R.GAS > 0) {
$z1115411155 = $f1116011161();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1116011161,
"from":L[460]});
}
} catch($e1115211153) {
if(R.isCont($e1115211153)) {
var $ss1115611157 = {"from":L[460],
"go":function(anf_arg3011162) {
return $Hanf_arg199911163(anf_arg3011162,_plus14);
}};
$e1115211153.stack[R.EXN_STACKHEIGHT++] = $ss1115611157;
}
if(R.isPyretException($e1115211153)) {
$e1115211153.pyretStack.push(L[460]);
}
throw $e1115211153;
}
var $ret1115811159 = $Hanf_arg199911163($z1115411155,_plus14);
++R.GAS;
return $ret1115811159;
};
var $Hanf_arg199911163 = function(anf_arg3011162,_plus14) {
var $z1116611167 = D;
var $f1117211173 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("("),anf_arg3011162):R.ffi.throwNonFunApp(L[460],_plus14,[("("),anf_arg3011162]);
};
try {
if(--R.GAS > 0) {
$z1116611167 = $f1117211173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1117211173,
"from":L[460]});
}
} catch($e1116411165) {
if(R.isCont($e1116411165)) {
var $ss1116811169 = {"from":L[460],
"go":function(anf_arg3111174) {
return $Hanf_arg199811175(anf_arg3111174,_plus14);
}};
$e1116411165.stack[R.EXN_STACKHEIGHT++] = $ss1116811169;
}
if(R.isPyretException($e1116411165)) {
$e1116411165.pyretStack.push(L[460]);
}
throw $e1116411165;
}
var $ret1117011171 = $Hanf_arg199811175($z1116611167,_plus14);
++R.GAS;
return $ret1117011171;
};
var $Hanf_arg199811175 = function(anf_arg3111174,_plus14) {
var $z1117811179 = D;
var $f1118411185 = function(_) {
return R.isFunction(_plus14)?_plus14.app(("j-block"),anf_arg3111174):R.ffi.throwNonFunApp(L[460],_plus14,[("j-block"),anf_arg3111174]);
};
try {
if(--R.GAS > 0) {
$z1117811179 = $f1118411185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1118411185,
"from":L[460]});
}
} catch($e1117611177) {
if(R.isCont($e1117611177)) {
var $ss1118011181 = {"from":L[460],
"go":function(ann_DASH_check_DASH_temp2711186) {
return $Hann_DASH_check_DASH_temp199711187(ann_DASH_check_DASH_temp2711186);
}};
$e1117611177.stack[R.EXN_STACKHEIGHT++] = $ss1118011181;
}
if(R.isPyretException($e1117611177)) {
$e1117611177.pyretStack.push(L[460]);
}
throw $e1117611177;
}
var $ret1118211183 = $Hann_DASH_check_DASH_temp199711187($z1117811179);
++R.GAS;
return $ret1118211183;
};
var $Hann_DASH_check_DASH_temp199711187 = function(ann_DASH_check_DASH_temp2711186) {
return ann_DASH_check_DASH_temp2711186;
};
var $Hcont_tail_arg19954317 = function(cont_tail_arg244315,if_helper164316) {
if(--R.GAS > 0) {
$z1118811189 = R.isFunction(if_helper164316)?if_helper164316.app(cont_tail_arg244315):R.ffi.throwNonFunApp(L[460],if_helper164316,[cont_tail_arg244315]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper164316)?if_helper164316.app(cont_tail_arg244315):R.ffi.throwNonFunApp(L[460],if_helper164316,[cont_tail_arg244315]);
},
"from":L[460]});
}
++R.GAS;
return $z1118811189;
};
var $Hcont_tail_arg19964332 = function(cont_tail_arg214331,if_helper164316) {
if(--R.GAS > 0) {
$z1119011191 = R.isFunction(if_helper164316)?if_helper164316.app(cont_tail_arg214331):R.ffi.throwNonFunApp(L[460],if_helper164316,[cont_tail_arg214331]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored422) {
return R.isFunction(if_helper164316)?if_helper164316.app(cont_tail_arg214331):R.ffi.throwNonFunApp(L[460],if_helper164316,[cont_tail_arg214331]);
},
"from":L[460]});
}
++R.GAS;
return $z1119011191;
};
var $Hstrprint19944352 = function(strprint2074350,self2064351) {
var anf_fun1111202 = G(self2064351,"print-ugly-source",L[1007]);
var anf_arg1211203 = G(strprint2074350,"append",L[1006]);
var $z1119411195 = D;
var $f1120011201 = function(_) {
return R.isFunction(anf_fun1111202)?anf_fun1111202.app(anf_arg1211203):R.ffi.throwNonFunApp(L[1005],anf_fun1111202,[anf_arg1211203]);
};
try {
if(--R.GAS > 0) {
$z1119411195 = $f1120011201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1120011201,
"from":L[1005]});
}
} catch($e1119211193) {
if(R.isCont($e1119211193)) {
var $ss1119611197 = {"from":L[1005],
"go":function(anf_begin_app_dropped199111204) {
return $Hanf_begin_app_dropped199311205(anf_begin_app_dropped199111204,strprint2074350);
}};
$e1119211193.stack[R.EXN_STACKHEIGHT++] = $ss1119611197;
}
if(R.isPyretException($e1119211193)) {
$e1119211193.pyretStack.push(L[1005]);
}
throw $e1119211193;
}
var $ret1119811199 = $Hanf_begin_app_dropped199311205($z1119411195,strprint2074350);
++R.GAS;
return $ret1119811199;
};
var $Hanf_begin_app_dropped199311205 = function(anf_begin_app_dropped199111204,strprint2074350) {
var anf_fun1311216 = G(strprint2074350,"get",L[1008]);
var $z1120811209 = D;
var $f1121411215 = function(_) {
return R.isFunction(anf_fun1311216)?anf_fun1311216.app():R.ffi.throwNonFunApp(L[478],anf_fun1311216,[]);
};
try {
if(--R.GAS > 0) {
$z1120811209 = $f1121411215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1121411215,
"from":L[478]});
}
} catch($e1120611207) {
if(R.isCont($e1120611207)) {
var $ss1121011211 = {"from":L[478],
"go":function(ann_DASH_check_DASH_temp1011217) {
return $Hann_DASH_check_DASH_temp199211218(ann_DASH_check_DASH_temp1011217);
}};
$e1120611207.stack[R.EXN_STACKHEIGHT++] = $ss1121011211;
}
if(R.isPyretException($e1120611207)) {
$e1120611207.pyretStack.push(L[478]);
}
throw $e1120611207;
}
var $ret1121211213 = $Hann_DASH_check_DASH_temp199211218($z1120811209);
++R.GAS;
return $ret1121211213;
};
var $Hann_DASH_check_DASH_temp199211218 = function(ann_DASH_check_DASH_temp1011217) {
return ann_DASH_check_DASH_temp1011217;
};
var $Hanf_assign19904370 = function(anf_assign54369,str1994357) {
var ann_DASH_check_DASH_temp411219 = str1994357.$var = anf_assign54369;
return ann_DASH_check_DASH_temp411219;
};
return R.loadModulesNew(NAMESPACE,[$PP12338,$F32439,$arrays52540,$lists72641,$option92742,$error112843,$sets132944],function($PP12338,$F32439,$arrays52540,$lists72641,$option92742,$error112843,$sets132944) {
var PP123 = R.getField($PP12338,"values");
var F324 = R.getField($F32439,"values");
var arrays525 = R.getField($arrays52540,"values");
var lists726 = R.getField($lists72641,"values");
var option927 = R.getField($option92742,"values");
var error1128 = R.getField($error112843,"values");
var sets1329 = R.getField($sets132944,"values");
var PP230 = R.getField($PP12338,"types");
var F431 = R.getField($F32439,"types");
var arrays632 = R.getField($arrays52540,"types");
var lists833 = R.getField($lists72641,"types");
var option1034 = R.getField($option92742,"types");
var error1235 = R.getField($error112843,"types");
var sets1436 = R.getField($sets132944,"types");
return R.safeCall(function() {
var List1560 = R.getDotAnn(L[1009],"lists",lists833,"List");
var Option1611220 = R.getDotAnn(L[1009],"option",option1034,"Option");
var Array1711221 = R.getDotAnn(L[1009],"arrays",arrays632,"Array");
var Set1811222 = R.getDotAnn(L[1009],"sets",sets1436,"Set");
var array1911275 = G(arrays525,"array",L[1009]);
var build_DASH_array2011274 = G(arrays525,"build-array",L[1009]);
var array_DASH_from_DASH_list2111273 = G(arrays525,"array-from-list",L[1009]);
var is_DASH_array2211272 = G(arrays525,"is-array",L[1009]);
var list2364 = G(lists726,"list",L[1009]);
var is_DASH_empty2411271 = G(lists726,"is-empty",L[1009]);
var is_DASH_link2563 = G(lists726,"is-link",L[1009]);
var empty2611270 = G(lists726,"empty",L[1009]);
var link2711269 = G(lists726,"link",L[1009]);
var range2811268 = G(lists726,"range",L[1009]);
var repeat2911267 = G(lists726,"repeat",L[1009]);
var filter3011266 = G(lists726,"filter",L[1009]);
var partition3111265 = G(lists726,"partition",L[1009]);
var split_DASH_at3211264 = G(lists726,"split-at",L[1009]);
var any3311263 = G(lists726,"any",L[1009]);
var find3411262 = G(lists726,"find",L[1009]);
var map3511261 = G(lists726,"map",L[1009]);
var map23611260 = G(lists726,"map2",L[1009]);
var map33711259 = G(lists726,"map3",L[1009]);
var map43811258 = G(lists726,"map4",L[1009]);
var map_n3911257 = G(lists726,"map_n",L[1009]);
var map2_n4011256 = G(lists726,"map2_n",L[1009]);
var map3_n4111255 = G(lists726,"map3_n",L[1009]);
var map4_n4211254 = G(lists726,"map4_n",L[1009]);
var each4361 = G(lists726,"each",L[1009]);
var each24411253 = G(lists726,"each2",L[1009]);
var each34511252 = G(lists726,"each3",L[1009]);
var each44611251 = G(lists726,"each4",L[1009]);
var each_n4711250 = G(lists726,"each_n",L[1009]);
var each2_n4811249 = G(lists726,"each2_n",L[1009]);
var each3_n4911248 = G(lists726,"each3_n",L[1009]);
var each4_n5011247 = G(lists726,"each4_n",L[1009]);
var fold5111246 = G(lists726,"fold",L[1009]);
var fold25211245 = G(lists726,"fold2",L[1009]);
var fold35311244 = G(lists726,"fold3",L[1009]);
var fold45411243 = G(lists726,"fold4",L[1009]);
var index5511242 = G(lists726,"index",L[1009]);
var Option5611241 = G(option927,"Option",L[1009]);
var is_DASH_none5711240 = G(option927,"is-none",L[1009]);
var is_DASH_some5811239 = G(option927,"is-some",L[1009]);
var none5911238 = G(option927,"none",L[1009]);
var some6011237 = G(option927,"some",L[1009]);
var set6111236 = G(sets1329,"set",L[1009]);
var tree_DASH_set6211235 = G(sets1329,"tree-set",L[1009]);
var list_DASH_set6311234 = G(sets1329,"list-set",L[1009]);
var JBlockT26551 = R.namedBrander("JBlock");
var JBlock6450 = R.makeBranderAnn(JBlockT26551,"JBlock");
var JStmtT36757 = R.namedBrander("JStmt");
var JStmt6656 = R.makeBranderAnn(JStmtT36757,"JStmt");
var JBinopT46949 = R.namedBrander("JBinop");
var JBinop6848 = R.makeBranderAnn(JBinopT46949,"JBinop");
var JUnopT57159 = R.namedBrander("JUnop");
var JUnop7058 = R.makeBranderAnn(JUnopT57159,"JUnop");
var JExprT67353 = R.namedBrander("JExpr");
var JExpr7252 = R.makeBranderAnn(JExprT67353,"JExpr");
var JFieldT77555 = R.namedBrander("JField");
var JField7454 = R.makeBranderAnn(JFieldT77555,"JField");
var format7662 = G(F324,"format",L[1012]);
var INDENT7747 = (2);
var anf_fun111233 = G(PP123,"sbreak",L[1011]);
var $z1122511226 = D;
var $f1123111232 = function(_) {
return R.isFunction(anf_fun111233)?anf_fun111233.app((1)):R.ffi.throwNonFunApp(L[1010],anf_fun111233,[(1)]);
};
try {
if(--R.GAS > 0) {
$z1122511226 = $f1123111232();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1123111232,
"from":L[1010]});
}
} catch($e1122311224) {
if(R.isCont($e1122311224)) {
var $ss1122711228 = {"from":L[1010],
"go":function(break_DASH_one7846) {
return $Hbreak_DASH_one281345(break_DASH_one7846,INDENT7747,JBinop6848,JBinopT46949,JBlock6450,JBlockT26551,JExpr7252,JExprT67353,JField7454,JFieldT77555,JStmt6656,JStmtT36757,JUnop7058,JUnopT57159,List1560,PP123,each4361,format7662,is_DASH_link2563,list2364,_plus14,builtins15,nothing16,raise17,torepr18,tostring19,$type$Boolean20,$type$Number21,$type$String22);
}};
$e1122311224.stack[R.EXN_STACKHEIGHT++] = $ss1122711228;
}
if(R.isPyretException($e1122311224)) {
$e1122311224.pyretStack.push(L[1010]);
}
throw $e1122311224;
}
var $ret1122911230 = $Hbreak_DASH_one281345($z1122511226,INDENT7747,JBinop6848,JBinopT46949,JBlock6450,JBlockT26551,JExpr7252,JExprT67353,JField7454,JFieldT77555,JStmt6656,JStmtT36757,JUnop7058,JUnopT57159,List1560,PP123,each4361,format7662,is_DASH_link2563,list2364,_plus14,builtins15,nothing16,raise17,torepr18,tostring19,$type$Boolean20,$type$Number21,$type$String22);
++R.GAS;
return $ret1122911230;
},function(moduleVal) {
R.modules["$src/arr/compiler/js-ast.arr37"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/gensym.arr',["trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($arrays1516,$lists3617,$option5718,$error7819,$sets9920) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/gensym.arr15"]) {
return R.modules["$src/arr/compiler/gensym.arr15"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/gensym.arr";
var D = R.undefined;
var L = [[M,5,0,24,12,3,168],
[M,10,12,133,10,36,157],
[M,8,2,69,11,5,164],
[M,3,0,13,12,3,168],
[M,9,22,102,9,40,120]];
var _plus1 = NAMESPACE.get("_plus");
var builtins2 = NAMESPACE.get("builtins");
var nothing3 = NAMESPACE.get("nothing");
var tostring4 = NAMESPACE.get("tostring");
var $Hanf_bracket1321 = function(anf_bracket622,provides423,nothing3) {
var anf_fun734 = G(anf_bracket622,"results",L[0]);
var $z2627 = D;
var $f3233 = function(_) {
return R.isFunction(anf_fun734)?anf_fun734.app():R.ffi.throwNonFunApp(L[0],anf_fun734,[]);
};
try {
if(--R.GAS > 0) {
$z2627 = $f3233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f3233,
"from":L[0]});
}
} catch($e2425) {
if(R.isCont($e2425)) {
var $ss2829 = {"from":L[0],
"go":function(checks835) {
return $Hchecks1236(checks835,provides423,nothing3);
}};
$e2425.stack[R.EXN_STACKHEIGHT++] = $ss2829;
}
if(R.isPyretException($e2425)) {
$e2425.pyretStack.push(L[0]);
}
throw $e2425;
}
var $ret3031 = $Hchecks1236($z2627,provides423,nothing3);
++R.GAS;
return $ret3031;
};
var $Hchecks1236 = function(checks835,provides423,nothing3) {
return R.makeObject({"answer":nothing3,
"provide-plus-types":R.makeObject({"values":provides423,
"types":{}}),
"checks":checks835});
};
var $Hanf_assign1137 = function(anf_assign238,base6239,gensym_DASH_counter6040,_plus1,tostring4) {
gensym_DASH_counter6040.$var = anf_assign238;
var $z4344 = D;
var $f4950 = function(_) {
return R.isFunction(tostring4)?tostring4.app(gensym_DASH_counter6040.$var):R.ffi.throwNonFunApp(L[1],tostring4,[gensym_DASH_counter6040.$var]);
};
try {
if(--R.GAS > 0) {
$z4344 = $f4950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f4950,
"from":L[1]});
}
} catch($e4142) {
if(R.isCont($e4142)) {
var $ss4546 = {"from":L[1],
"go":function(anf_arg351) {
return $Hanf_arg1052(anf_arg351,base6239,_plus1);
}};
$e4142.stack[R.EXN_STACKHEIGHT++] = $ss4546;
}
if(R.isPyretException($e4142)) {
$e4142.pyretStack.push(L[1]);
}
throw $e4142;
}
var $ret4748 = $Hanf_arg1052($z4344,base6239,_plus1);
++R.GAS;
return $ret4748;
};
var $Hanf_arg1052 = function(anf_arg351,base6239,_plus1) {
var $z5556 = D;
var $f6162 = function(_) {
return R.isFunction(_plus1)?_plus1.app(base6239,anf_arg351):R.ffi.throwNonFunApp(L[2],_plus1,[base6239,anf_arg351]);
};
try {
if(--R.GAS > 0) {
$z5556 = $f6162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6162,
"from":L[2]});
}
} catch($e5354) {
if(R.isCont($e5354)) {
var $ss5758 = {"from":L[2],
"go":function(ann_DASH_check_DASH_temp163) {
return $Hann_DASH_check_DASH_temp964(ann_DASH_check_DASH_temp163);
}};
$e5354.stack[R.EXN_STACKHEIGHT++] = $ss5758;
}
if(R.isPyretException($e5354)) {
$e5354.pyretStack.push(L[2]);
}
throw $e5354;
}
var $ret5960 = $Hann_DASH_check_DASH_temp964($z5556);
++R.GAS;
return $ret5960;
};
var $Hann_DASH_check_DASH_temp964 = function(ann_DASH_check_DASH_temp163) {
return ann_DASH_check_DASH_temp163;
};
return R.loadModulesNew(NAMESPACE,[$arrays1516,$lists3617,$option5718,$error7819,$sets9920],function($arrays1516,$lists3617,$option5718,$error7819,$sets9920) {
var arrays15 = R.getField($arrays1516,"values");
var lists36 = R.getField($lists3617,"values");
var option57 = R.getField($option5718,"values");
var error78 = R.getField($error7819,"values");
var sets99 = R.getField($sets9920,"values");
var arrays210 = R.getField($arrays1516,"types");
var lists411 = R.getField($lists3617,"types");
var option612 = R.getField($option5718,"types");
var error813 = R.getField($error7819,"types");
var sets1014 = R.getField($sets9920,"types");
return R.safeCall(function() {
var List1165 = R.getDotAnn(L[3],"lists",lists411,"List");
var Option1266 = R.getDotAnn(L[3],"option",option612,"Option");
var Array1367 = R.getDotAnn(L[3],"arrays",arrays210,"Array");
var Set1468 = R.getDotAnn(L[3],"sets",sets1014,"Set");
var array15135 = G(arrays15,"array",L[3]);
var build_DASH_array16134 = G(arrays15,"build-array",L[3]);
var array_DASH_from_DASH_list17133 = G(arrays15,"array-from-list",L[3]);
var is_DASH_array18132 = G(arrays15,"is-array",L[3]);
var list19131 = G(lists36,"list",L[3]);
var is_DASH_empty20130 = G(lists36,"is-empty",L[3]);
var is_DASH_link21129 = G(lists36,"is-link",L[3]);
var empty22128 = G(lists36,"empty",L[3]);
var link23127 = G(lists36,"link",L[3]);
var range24126 = G(lists36,"range",L[3]);
var repeat25125 = G(lists36,"repeat",L[3]);
var filter26124 = G(lists36,"filter",L[3]);
var partition27123 = G(lists36,"partition",L[3]);
var split_DASH_at28122 = G(lists36,"split-at",L[3]);
var any29121 = G(lists36,"any",L[3]);
var find30120 = G(lists36,"find",L[3]);
var map31119 = G(lists36,"map",L[3]);
var map232118 = G(lists36,"map2",L[3]);
var map333117 = G(lists36,"map3",L[3]);
var map434116 = G(lists36,"map4",L[3]);
var map_n35115 = G(lists36,"map_n",L[3]);
var map2_n36114 = G(lists36,"map2_n",L[3]);
var map3_n37113 = G(lists36,"map3_n",L[3]);
var map4_n38112 = G(lists36,"map4_n",L[3]);
var each39111 = G(lists36,"each",L[3]);
var each240110 = G(lists36,"each2",L[3]);
var each341109 = G(lists36,"each3",L[3]);
var each442108 = G(lists36,"each4",L[3]);
var each_n43107 = G(lists36,"each_n",L[3]);
var each2_n44106 = G(lists36,"each2_n",L[3]);
var each3_n45105 = G(lists36,"each3_n",L[3]);
var each4_n46104 = G(lists36,"each4_n",L[3]);
var fold47103 = G(lists36,"fold",L[3]);
var fold248102 = G(lists36,"fold2",L[3]);
var fold349101 = G(lists36,"fold3",L[3]);
var fold450100 = G(lists36,"fold4",L[3]);
var index5199 = G(lists36,"index",L[3]);
var Option5298 = G(option57,"Option",L[3]);
var is_DASH_none5397 = G(option57,"is-none",L[3]);
var is_DASH_some5496 = G(option57,"is-some",L[3]);
var none5595 = G(option57,"none",L[3]);
var some5694 = G(option57,"some",L[3]);
var set5793 = G(sets99,"set",L[3]);
var tree_DASH_set5892 = G(sets99,"tree-set",L[3]);
var list_DASH_set5991 = G(sets99,"list-set",L[3]);
var gensym_DASH_counter6040 = {"$var":(0),
"$name":"gensym-counter"};
var make_DASH_name6180 = R.makeFunction(function(base6239) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
var $z8384 = D;
var $f8990 = function(_) {
return R.isFunction(_plus1)?_plus1.app((1),gensym_DASH_counter6040.$var):R.ffi.throwNonFunApp(L[4],_plus1,[(1),gensym_DASH_counter6040.$var]);
};
try {
if(--R.GAS > 0) {
$z8384 = $f8990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8990,
"from":L[4]});
}
} catch($e8182) {
if(R.isCont($e8182)) {
var $ss8586 = {"from":L[4],
"go":function(anf_assign238) {
return $Hanf_assign1137(anf_assign238,base6239,gensym_DASH_counter6040,_plus1,tostring4);
}};
$e8182.stack[R.EXN_STACKHEIGHT++] = $ss8586;
}
if(R.isPyretException($e8182)) {
$e8182.pyretStack.push(L[4]);
}
throw $e8182;
}
var $ret8788 = $Hanf_assign1137($z8384,base6239,gensym_DASH_counter6040,_plus1,tostring4);
++R.GAS;
return $ret8788;
});
var provides423 = R.makeObject({"gensym-counter":gensym_DASH_counter6040.$var,
"make-name":make_DASH_name6180});
var anf_fun579 = G(builtins2,"current-checker",L[0]);
var $z7172 = D;
var $f7778 = function(_) {
return R.isFunction(anf_fun579)?anf_fun579.app():R.ffi.throwNonFunApp(L[0],anf_fun579,[]);
};
try {
if(--R.GAS > 0) {
$z7172 = $f7778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7778,
"from":L[0]});
}
} catch($e6970) {
if(R.isCont($e6970)) {
var $ss7374 = {"from":L[0],
"go":function(anf_bracket622) {
return $Hanf_bracket1321(anf_bracket622,provides423,nothing3);
}};
$e6970.stack[R.EXN_STACKHEIGHT++] = $ss7374;
}
if(R.isPyretException($e6970)) {
$e6970.pyretStack.push(L[0]);
}
throw $e6970;
}
var $ret7576 = $Hanf_bracket1321($z7172,provides423,nothing3);
++R.GAS;
return $ret7576;
},function(moduleVal) {
R.modules["$src/arr/compiler/gensym.arr15"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/anf-visitor-compiler.arr',["trove/ast",
"compiler/ast-anf.arr",
"compiler/ast-split.arr",
"compiler/js-ast.arr",
"compiler/gensym.arr",
"compiler/compile-structs.arr",
"trove/string-dict",
"trove/srcloc",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($A11845,$N31946,$S52047,$J72148,$G92249,$CS112350,$D132451,$SL152552,$arrays172653,$lists192754,$option212855,$error232956,$sets253057) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/anf-visitor-compiler.arr44"]) {
return R.modules["$src/arr/compiler/anf-visitor-compiler.arr44"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/anf-visitor-compiler.arr";
var D = R.undefined;
var L = [[M,57,0,1021,57,31,1052],
[M,58,0,1053,58,23,1076],
[M,59,0,1077,59,21,1098],
[M,87,2,2169,87,30,2197],
[M,87,15,2182,87,28,2195],
[M,76,2,1814,78,65,2012],
[M,73,2,1610,75,66,1811],
[M,68,2,1362,72,72,1607],
[M,65,2,1211,67,55,1359],
[M,62,2,1122,64,26,1208],
[M,61,0,1100,84,3,2147],
[M,65,4,1213,65,29,1238],
[M,68,4,1364,68,64,1424],
[M,68,26,1386,68,39,1399],
[M,68,50,1410,68,63,1423],
[M,73,4,1612,73,50,1658],
[M,73,36,1644,73,49,1657],
[M,76,4,1816,76,49,1861],
[M,76,24,1836,76,37,1849],
[M,78,30,1977,78,46,1993],
[M,78,30,1977,78,43,1990],
[M,78,30,1977,78,39,1986],
[M,78,4,1951,78,65,2012],
[M,77,51,1919,77,72,1940],
[M,77,56,1924,77,65,1933],
[M,77,29,1897,77,50,1918],
[M,77,29,1897,77,38,1906],
[M,77,4,1872,77,77,1945],
[M,76,39,1851,76,48,1860],
[M,76,16,1828,76,37,1849],
[M,75,30,1775,75,43,1788],
[M,75,32,1777,75,42,1787],
[M,75,4,1749,75,66,1811],
[M,74,46,1711,74,73,1738],
[M,74,46,1711,74,67,1732],
[M,74,46,1711,74,55,1720],
[M,74,34,1699,74,44,1709],
[M,74,4,1669,74,78,1743],
[M,73,28,1636,73,49,1657],
[M,73,16,1624,73,26,1634],
[M,72,32,1567,72,48,1583],
[M,72,32,1567,72,45,1580],
[M,72,32,1567,72,41,1576],
[M,72,4,1539,72,72,1607],
[M,70,28,1496,70,56,1524],
[M,70,28,1496,70,50,1518],
[M,70,28,1496,70,38,1506],
[M,70,6,1474,70,27,1495],
[M,70,6,1474,70,15,1483],
[M,69,30,1461,69,34,1465],
[M,69,4,1435,71,7,1533],
[M,68,41,1401,68,63,1423],
[M,68,18,1378,68,39,1399],
[M,67,35,1339,67,50,1354],
[M,67,37,1341,67,49,1353],
[M,67,4,1308,67,55,1359],
[M,66,4,1249,66,57,1302],
[M,66,34,1279,66,46,1291],
[M,65,21,1230,65,28,1237],
[M,64,4,1186,64,26,1208],
[M,63,4,1147,63,37,1180],
[M,83,34,2130,83,42,2138],
[M,83,17,2113,83,33,2129],
[M,83,2,2098,83,47,2143],
[M,81,4,2062,81,17,2075],
[M,80,2,2024,82,5,2094],
[M,80,23,2045,80,33,2055],
[M,15,0,285,735,3,25747],
[M,727,0,25453,735,3,25747],
[M,730,6,25552,730,56,25602],
[M,730,19,25565,730,29,25575],
[M,729,4,25511,733,7,25739],
[M,717,0,25200,725,3,25451],
[M,720,6,25295,720,56,25345],
[M,720,19,25308,720,29,25318],
[M,719,4,25254,723,7,25443],
[M,636,0,21666,715,3,25198],
[M,638,13,21801,638,43,21831],
[M,638,13,21801,638,36,21824],
[M,637,2,21719,637,70,21787],
[M,637,22,21739,637,30,21747],
[M,625,0,21328,634,3,21664],
[M,627,15,21372,627,38,21395],
[M,626,2,21349,633,3,21660],
[M,598,2,20578,604,5,20789],
[M,599,4,20606,603,7,20783],
[M,602,26,20731,602,39,20744],
[M,602,26,20731,602,33,20738],
[M,602,16,20721,602,22,20727],
[M,600,6,20629,601,54,20704],
[M,601,17,20667,601,30,20680],
[M,601,17,20667,601,24,20674],
[M,601,37,20687,601,50,20700],
[M,601,37,20687,601,44,20694],
[M,601,11,20661,601,15,20665],
[M,597,28,20552,597,49,20573],
[M,494,4,16709,494,45,16750],
[M,494,31,16736,494,44,16749],
[M,494,20,16725,494,30,16735],
[M,490,4,16637,492,7,16703],
[M,491,20,16679,491,36,16695],
[M,489,2,16580,594,5,20520],
[M,478,4,16303,478,21,16320],
[M,478,8,16307,478,19,16318],
[M,477,36,16273,477,42,16279],
[M,477,25,16262,477,28,16265],
[M,477,52,16289,477,59,16296],
[M,477,2,16239,487,5,16575],
[M,475,24,16205,475,37,16218],
[M,475,24,16205,475,35,16216],
[M,474,33,16172,474,39,16178],
[M,474,22,16161,474,25,16164],
[M,474,2,16141,476,5,16235],
[M,472,18,16116,472,31,16129],
[M,472,18,16116,472,29,16127],
[M,471,29,16089,471,35,16095],
[M,471,18,16078,471,21,16081],
[M,471,2,16062,473,5,16137],
[M,468,25,16033,468,28,16036],
[M,468,2,16010,470,5,16058],
[M,466,19,15975,466,25,15981],
[M,466,32,15988,466,39,15995],
[M,466,16,15972,466,17,15973],
[M,465,2,15918,467,5,16006],
[M,465,20,15936,465,23,15939],
[M,465,30,15946,465,37,15953],
[M,463,13,15899,463,21,15907],
[M,462,19,15867,462,22,15870],
[M,462,29,15877,462,35,15883],
[M,462,2,15850,464,5,15914],
[M,456,7,15712,456,23,15728],
[M,455,19,15686,455,22,15689],
[M,455,29,15696,455,35,15702],
[M,455,2,15669,461,5,15846],
[M,452,2,15614,454,5,15665],
[M,453,4,15642,453,16,15654],
[M,450,18,15578,450,43,15603],
[M,450,29,15589,450,42,15602],
[M,450,18,15578,450,28,15588],
[M,449,2,15534,451,5,15610],
[M,447,18,15506,447,35,15523],
[M,447,18,15506,447,29,15517],
[M,446,51,15479,446,57,15485],
[M,446,21,15449,446,24,15452],
[M,446,34,15462,446,40,15468],
[M,446,2,15430,448,5,15530],
[M,443,2,15377,445,5,15426],
[M,444,4,15407,444,11,15414],
[M,443,19,15394,443,25,15400],
[M,436,53,14996,436,69,15012],
[M,436,53,14996,436,63,15006],
[M,435,63,14933,435,70,14940],
[M,435,22,14892,435,25,14895],
[M,435,35,14905,435,48,14918],
[M,435,2,14872,442,5,15373],
[M,432,43,14700,432,57,14714],
[M,432,52,14709,432,56,14713],
[M,432,43,14700,432,51,14708],
[M,432,30,14687,433,113,14861],
[M,431,60,14647,431,67,14654],
[M,431,19,14606,431,22,14609],
[M,431,32,14619,431,45,14632],
[M,431,2,14589,434,5,14868],
[M,429,38,14548,429,53,14563],
[M,429,38,14548,429,47,14557],
[M,429,31,14541,429,68,14578],
[M,428,33,14484,428,39,14490],
[M,428,21,14472,428,24,14475],
[M,428,50,14501,428,56,14507],
[M,428,2,14453,430,5,14585],
[M,426,14,14396,426,29,14411],
[M,426,14,14396,426,23,14405],
[M,425,31,14356,425,37,14362],
[M,425,19,14344,425,22,14347],
[M,425,48,14373,425,54,14379],
[M,425,2,14327,427,5,14449],
[M,423,13,14245,423,28,14260],
[M,423,13,14245,423,22,14254],
[M,422,34,14197,422,40,14203],
[M,422,22,14185,422,25,14188],
[M,422,52,14215,422,66,14229],
[M,422,2,14165,424,5,14323],
[M,420,41,14095,420,98,14152],
[M,420,52,14106,420,97,14151],
[M,420,76,14130,420,95,14149],
[M,420,76,14130,420,89,14143],
[M,420,76,14130,420,83,14137],
[M,420,68,14122,420,74,14128],
[M,420,41,14095,420,51,14105],
[M,420,28,14082,420,100,14154],
[M,419,19,14022,419,22,14025],
[M,419,34,14037,419,48,14051],
[M,419,2,14005,421,5,14161],
[M,416,17,13968,416,40,13991],
[M,416,26,13977,416,39,13990],
[M,416,17,13968,416,25,13976],
[M,415,24,13910,415,27,13913],
[M,415,34,13920,415,40,13926],
[M,415,50,13936,415,62,13948],
[M,415,2,13888,417,5,13998],
[M,413,8,13822,413,23,13837],
[M,413,8,13822,413,20,13834],
[M,412,29,13783,412,35,13789],
[M,412,19,13773,412,22,13776],
[M,412,45,13799,412,57,13811],
[M,412,2,13756,414,5,13884],
[M,410,31,13703,410,44,13716],
[M,410,31,13703,410,42,13714],
[M,409,33,13646,409,39,13652],
[M,409,50,13663,409,56,13669],
[M,409,22,13635,409,25,13638],
[M,409,2,13615,411,5,13752],
[M,407,28,13589,407,41,13602],
[M,407,28,13589,407,35,13596],
[M,407,12,13573,407,43,13604],
[M,406,24,13547,406,35,13558],
[M,406,2,13525,408,5,13611],
[M,400,4,13322,400,38,13356],
[M,400,21,13339,400,32,13350],
[M,399,31,13275,399,37,13281],
[M,399,48,13292,399,55,13299],
[M,399,64,13308,399,71,13315],
[M,399,18,13262,399,21,13265],
[M,399,2,13246,405,5,13521],
[M,392,4,13055,392,29,13080],
[M,392,15,13066,392,23,13074],
[M,391,2,13027,398,5,13242],
[M,388,2,12823,390,5,13023],
[M,388,54,12875,388,60,12881],
[M,388,92,12913,388,98,12919],
[M,388,25,12846,388,28,12849],
[M,388,40,12861,388,47,12868],
[M,388,70,12891,388,82,12903],
[M,388,115,12936,388,127,12948],
[M,385,2,12712,387,5,12819],
[M,385,34,12744,385,40,12750],
[M,385,24,12734,385,27,12737],
[M,385,50,12760,385,62,12772],
[M,380,4,12481,380,36,12513],
[M,380,20,12497,380,30,12507],
[M,379,29,12432,379,36,12439],
[M,379,43,12446,379,54,12457],
[M,379,64,12467,379,71,12474],
[M,379,19,12422,379,22,12425],
[M,379,2,12405,384,5,12708],
[M,344,4,11348,344,36,11380],
[M,344,20,11364,344,30,11374],
[M,343,29,11299,343,36,11306],
[M,343,43,11313,343,54,11324],
[M,343,64,11334,343,71,11341],
[M,343,19,11289,343,22,11292],
[M,343,2,11272,378,5,12401],
[M,326,2,10635,342,5,11268],
[M,327,4,10672,341,7,11262],
[M,333,6,10878,340,33,11254],
[M,334,30,10945,334,46,10961],
[M,334,30,10945,334,44,10959],
[M,328,6,10703,332,9,10871],
[M,330,32,10784,330,47,10799],
[M,330,32,10784,330,45,10797],
[M,330,10,10762,330,74,10826],
[M,313,4,10107,315,7,10210],
[M,313,23,10126,315,7,10210],
[M,314,24,10175,314,50,10201],
[M,314,36,10187,314,43,10194],
[M,314,14,10165,314,22,10173],
[M,312,2,10051,325,5,10631],
[M,293,0,9416,309,3,10026],
[M,294,2,9466,294,94,9558],
[M,294,14,9478,294,94,9558],
[M,294,43,9507,294,62,9526],
[M,294,56,9520,294,61,9525],
[M,294,43,9507,294,55,9519],
[M,283,0,9095,291,3,9414],
[M,286,26,9188,286,43,9205],
[M,249,0,7835,281,3,9093],
[M,250,2,7868,280,5,9089],
[M,279,4,9057,279,30,9083],
[M,278,4,9024,278,32,9052],
[M,276,4,8876,277,119,9019],
[M,277,36,8936,277,54,8954],
[M,277,36,8936,277,51,8951],
[M,277,29,8929,277,118,9018],
[M,266,4,8450,275,111,8871],
[M,267,6,8482,270,9,8602],
[M,267,13,8489,270,9,8602],
[M,269,8,8554,269,46,8592],
[M,269,35,8581,269,44,8590],
[M,268,8,8517,268,36,8545],
[M,268,25,8534,268,34,8543],
[M,255,4,8091,265,10,8445],
[M,256,28,8144,256,46,8162],
[M,256,39,8155,256,45,8161],
[M,256,28,8144,256,38,8154],
[M,254,4,8037,254,53,8086],
[M,253,4,7991,253,45,8032],
[M,252,4,7941,252,49,7986],
[M,251,4,7890,251,50,7936],
[M,251,36,7922,251,48,7934],
[M,251,36,7922,251,46,7932],
[M,184,0,4979,246,3,7832],
[M,192,15,5165,192,59,5209],
[M,192,2,5152,192,60,5210],
[M,192,7,5157,192,13,5163],
[M,193,15,5226,193,33,5244],
[M,188,9,5062,188,15,5068],
[M,190,12,5108,190,18,5114],
[M,186,9,5025,186,12,5028],
[M,187,14,5044,187,21,5051],
[M,189,12,5082,189,24,5094],
[M,191,19,5135,191,31,5147],
[M,164,0,4144,182,3,4977],
[M,165,15,4203,165,33,4221],
[M,157,0,3924,162,3,4142],
[M,158,2,3982,161,5,4138],
[M,159,4,4005,160,97,4132],
[M,160,12,4047,160,29,4064],
[M,157,34,3958,157,42,3966],
[M,155,0,3862,155,60,3922],
[M,155,46,3908,155,58,3920],
[M,155,46,3908,155,56,3918],
[M,155,21,3883,155,27,3889],
[M,151,0,3796,153,3,3860],
[M,152,20,3842,152,32,3854],
[M,147,0,3717,149,3,3794],
[M,148,23,3762,148,31,3770],
[M,141,0,3529,145,3,3715],
[M,142,36,3586,142,45,3595],
[M,139,0,3468,139,59,3527],
[M,139,36,3504,139,45,3513],
[M,138,0,3424,138,43,3467],
[M,138,26,3450,138,35,3459],
[M,134,0,3318,136,3,3422],
[M,135,17,3369,135,29,3381],
[M,130,0,3229,132,3,3316],
[M,131,41,3299,131,52,3310],
[M,131,29,3287,131,53,3311],
[M,126,0,3144,128,3,3227],
[M,127,23,3199,127,46,3222],
[M,105,0,2563,124,3,3142],
[M,107,4,2610,107,13,2619],
[M,106,16,2598,114,3,2771],
[M,101,0,2511,103,3,2561],
[M,102,14,2548,102,23,2557],
[M,102,2,2536,102,13,2547],
[M,88,2,2200,98,5,2505],
[M,89,13,2232,89,26,2245],
[M,88,12,2210,88,18,2216],
[M,607,0,20793,623,3,21326],
[M,610,20,20878,610,37,20895],
[M,610,20,20878,610,28,20886],
[M,610,10,20868,610,16,20874],
[M,609,6,20824,609,39,20857],
[M,609,27,20845,609,37,20855],
[M,609,27,20845,609,34,20852],
[M,609,14,20832,609,26,20844],
[M,608,6,20806,608,17,20817],
[M,610,41,20899,610,54,20912],
[M,610,41,20899,610,48,20906],
[M,610,39,20897,610,55,20913],
[M,610,59,20917,610,72,20930],
[M,610,59,20917,610,66,20924],
[M,610,57,20915,610,73,20931],
[M,610,2,20860,610,74,20932],
[M,611,2,20935,611,60,20993],
[M,611,2,20935,611,40,20973],
[M,611,2,20935,611,13,20946],
[M,611,46,20979,611,59,20992],
[M,611,46,20979,611,53,20986],
[M,611,44,20977,611,60,20993],
[M,613,21,21016,613,39,21034],
[M,613,21,21016,613,29,21024],
[M,613,11,21006,613,17,21012],
[M,613,43,21038,613,56,21051],
[M,613,43,21038,613,50,21045],
[M,613,41,21036,613,57,21052],
[M,613,61,21056,613,74,21069],
[M,613,61,21056,613,68,21063],
[M,613,59,21054,613,75,21070],
[M,613,2,20997,613,76,21071],
[M,614,2,21074,614,61,21133],
[M,614,2,21074,614,41,21113],
[M,614,2,21074,614,14,21086],
[M,614,47,21119,614,60,21132],
[M,614,47,21119,614,54,21126],
[M,614,45,21117,614,61,21133],
[M,619,2,21170,619,12,21180],
[M,617,6,21142,617,30,21166],
[M,617,6,21142,617,20,21156],
[M,620,2,21183,621,63,21321],
[M,620,12,21193,620,24,21205],
[M,620,12,21193,620,18,21199],
[M,620,2,21183,620,8,21189],
[M,620,2,21183,620,40,21221],
[M,620,2,21183,620,73,21254],
[M,620,2,21183,620,46,21227],
[M,621,14,21272,621,26,21284],
[M,621,14,21272,621,20,21278],
[M,621,4,21262,621,10,21268],
[M,621,30,21288,621,43,21301],
[M,621,30,21288,621,37,21295],
[M,621,28,21286,621,44,21302],
[M,621,48,21306,621,61,21319],
[M,621,48,21306,621,55,21313],
[M,621,46,21304,621,62,21320],
[M,621,4,21262,621,63,21321],
[M,731,29,25632,731,37,25640],
[M,731,14,25617,731,28,25631],
[M,731,51,25654,731,75,25678],
[M,731,51,25654,731,63,25666],
[M,731,6,25609,731,76,25679],
[M,721,6,25352,721,37,25383],
[M,721,14,25360,721,25,25371],
[M,638,77,21865,638,96,21884],
[M,638,89,21877,638,95,21883],
[M,638,77,21865,638,88,21876],
[M,638,55,21843,638,76,21864],
[M,638,13,21801,638,54,21842],
[M,638,55,21843,638,97,21885],
[M,638,13,21801,638,98,21886],
[M,638,132,21920,638,152,21940],
[M,638,144,21932,638,151,21939],
[M,638,132,21920,638,143,21931],
[M,638,110,21898,638,131,21919],
[M,638,13,21801,638,109,21897],
[M,638,110,21898,638,153,21941],
[M,638,2,21790,638,154,21942],
[M,639,35,21978,639,53,21996],
[M,639,35,21978,639,51,21994],
[M,639,20,21963,646,5,22238],
[M,640,4,22003,644,9,22136],
[M,641,6,22022,644,9,22136],
[M,643,8,22083,643,51,22126],
[M,643,40,22115,643,50,22125],
[M,643,40,22115,643,48,22123],
[M,642,8,22047,642,35,22074],
[M,642,25,22064,642,33,22072],
[M,639,2,21945,646,5,22238],
[M,647,8,22247,647,27,22266],
[M,647,20,22259,647,26,22265],
[M,647,8,22247,647,19,22258],
[M,647,8,22247,647,45,22284],
[M,647,32,22271,647,44,22283],
[M,647,8,22247,647,31,22270],
[M,647,2,22241,647,59,22298],
[M,647,8,22247,647,49,22288],
[M,648,2,22301,648,52,22351],
[M,648,32,22331,648,51,22350],
[M,648,17,22316,648,31,22330],
[M,649,13,22365,649,38,22390],
[M,649,30,22382,649,37,22389],
[M,649,13,22365,649,29,22381],
[M,649,13,22365,649,56,22408],
[M,649,43,22395,649,55,22407],
[M,649,13,22365,649,42,22394],
[M,649,2,22354,649,70,22422],
[M,649,13,22365,649,60,22412],
[M,650,2,22425,655,8,22609],
[M,650,26,22449,655,7,22608],
[M,651,6,22463,654,9,22600],
[M,653,8,22558,653,40,22590],
[M,652,8,22503,652,54,22549],
[M,651,23,22480,651,36,22493],
[M,650,14,22437,650,25,22448],
[M,656,2,22612,656,37,22647],
[M,656,28,22638,656,36,22646],
[M,658,2,22721,658,51,22770],
[M,658,22,22741,658,50,22769],
[M,658,14,22733,658,21,22740],
[M,657,15,22663,657,70,22718],
[M,657,36,22684,657,55,22703],
[M,683,2,23869,685,5,23966],
[M,683,17,23884,685,5,23966],
[M,659,2,22773,682,5,23866],
[M,660,4,22810,660,45,22851],
[M,660,34,22840,660,44,22850],
[M,660,22,22828,660,33,22839],
[M,688,2,24020,688,33,24051],
[M,688,18,24036,688,31,24049],
[M,702,2,24393,702,81,24472],
[M,702,38,24429,702,80,24471],
[M,702,20,24411,702,37,24428],
[M,702,20,24411,702,33,24424],
[M,690,2,24067,701,5,24390],
[M,691,4,24101,691,22,24119],
[M,690,26,24091,690,29,24094],
[M,703,2,24475,703,58,24531],
[M,703,17,24490,703,33,24506],
[M,703,17,24490,703,27,24500],
[M,704,46,24578,704,65,24597],
[M,704,46,24578,704,63,24595],
[M,704,33,24565,704,66,24598],
[M,704,2,24534,704,67,24599],
[M,705,8,24608,705,22,24622],
[M,705,44,24644,705,64,24664],
[M,705,44,24644,705,57,24657],
[M,705,24,24624,714,88,25193],
[M,705,31,24631,705,65,24665],
[M,706,27,24727,706,51,24751],
[M,705,92,24692,714,85,25190],
[M,708,25,24810,708,46,24831],
[M,707,24,24777,714,81,25186],
[M,709,46,24879,709,67,24900],
[M,709,30,24863,709,69,24902],
[M,709,37,24870,709,68,24901],
[M,709,22,24855,709,70,24903],
[M,710,30,24935,710,43,24948],
[M,711,30,24981,711,54,25005],
[M,710,30,24935,714,79,25184],
[M,714,37,25142,714,77,25182],
[M,714,30,25135,714,78,25183],
[M,710,22,24927,714,79,25184],
[M,708,20,24805,714,80,25185],
[M,707,16,24769,714,82,25187],
[M,706,21,24721,714,83,25188],
[M,706,12,24712,714,84,25189],
[M,705,84,24684,714,86,25191],
[M,705,67,24667,714,87,25192],
[M,692,7,24127,692,32,24152],
[M,692,7,24127,692,24,24144],
[M,693,6,24160,693,27,24181],
[M,693,6,24160,693,19,24173],
[M,695,22,24214,695,32,24224],
[M,695,34,24226,695,50,24242],
[M,695,6,24198,695,51,24243],
[M,696,6,24250,696,32,24276],
[M,696,6,24250,696,19,24263],
[M,697,19,24296,697,32,24309],
[M,698,42,24352,698,55,24365],
[M,698,19,24329,698,56,24366],
[M,699,6,24373,699,9,24376],
[M,661,4,22856,661,45,22897],
[M,661,20,22872,661,39,22891],
[M,662,4,22902,662,35,22933],
[M,662,30,22928,662,34,22932],
[M,662,18,22916,662,29,22927],
[M,664,15,22990,664,32,23007],
[M,664,8,22983,681,30,23858],
[M,664,34,23009,664,62,23037],
[M,667,14,23107,669,17,23254],
[M,668,58,23218,668,73,23233],
[M,668,47,23207,668,74,23234],
[M,670,14,23271,672,17,23416],
[M,671,59,23381,671,73,23395],
[M,671,48,23370,671,74,23396],
[M,667,14,23107,681,28,23856],
[M,676,28,23545,676,36,23553],
[M,675,32,23509,681,24,23852],
[M,673,14,23433,681,27,23855],
[M,676,46,23563,676,58,23575],
[M,676,38,23555,676,59,23576],
[M,676,22,23539,676,60,23577],
[M,677,28,23607,677,47,23626],
[M,679,45,23713,679,64,23732],
[M,678,32,23660,681,21,23849],
[M,679,66,23734,679,82,23750],
[M,679,84,23752,679,101,23769],
[M,679,28,23696,679,102,23770],
[M,680,37,23809,680,54,23826],
[M,680,28,23800,680,55,23827],
[M,678,24,23652,681,22,23850],
[M,677,22,23601,681,23,23851],
[M,674,25,23466,681,25,23853],
[M,674,16,23457,681,26,23854],
[M,666,12,23084,681,28,23856],
[M,665,10,23049,681,29,23857],
[M,663,13,22947,681,31,23859],
[M,671,26,23348,671,75,23397],
[M,668,25,23185,668,75,23235],
[M,657,57,22705,657,68,22716],
[M,645,19,22156,645,31,22168],
[M,645,19,22156,645,29,22166],
[M,645,10,22147,645,32,22169],
[M,645,43,22180,645,60,22197],
[M,645,76,22213,645,92,22229],
[M,645,69,22206,645,93,22230],
[M,645,34,22171,645,94,22231],
[M,637,39,21756,637,48,21765],
[M,637,32,21749,637,68,21785],
[M,637,50,21767,637,67,21784],
[M,627,4,21361,627,39,21396],
[M,628,21,21419,628,42,21440],
[M,629,32,21474,629,47,21489],
[M,629,16,21458,630,61,21581],
[M,630,33,21553,630,44,21564],
[M,630,26,21546,630,59,21579],
[M,630,46,21566,630,58,21578],
[M,629,23,21465,630,60,21580],
[M,629,8,21450,630,62,21582],
[M,628,15,21413,630,63,21583],
[M,628,4,21402,630,64,21584],
[M,631,15,21601,631,30,21616],
[M,631,21,21607,631,29,21615],
[M,631,4,21590,631,31,21617],
[M,632,15,21634,632,36,21655],
[M,632,4,21623,632,37,21656],
[M,602,41,20746,602,54,20759],
[M,602,41,20746,602,48,20753],
[M,602,56,20761,602,69,20774],
[M,602,56,20761,602,63,20768],
[M,495,35,16786,495,51,16802],
[M,495,35,16786,495,49,16800],
[M,495,26,16777,495,52,16803],
[M,495,4,16755,495,53,16804],
[M,580,4,19935,580,50,19981],
[M,580,21,19952,580,33,19964],
[M,546,4,18619,578,7,19929],
[M,548,47,18725,548,63,18741],
[M,547,14,18671,547,20,18677],
[M,546,29,18644,546,39,18654],
[M,511,4,17267,544,7,18613],
[M,512,6,17343,512,61,17398],
[M,512,33,17370,512,60,17397],
[M,512,41,17378,512,57,17394],
[M,512,41,17378,512,50,17387],
[M,512,41,17378,512,47,17384],
[M,512,21,17358,512,32,17369],
[M,497,4,16810,509,7,17261],
[M,502,18,17002,502,31,17015],
[M,500,36,16955,507,13,17242],
[M,497,46,16852,497,53,16859],
[M,497,36,16842,497,39,16845],
[M,497,68,16874,497,74,16880],
[M,582,37,20020,582,45,20028],
[M,582,19,20002,584,7,20099],
[M,583,6,20064,583,27,20085],
[M,583,6,20064,583,25,20083],
[M,583,6,20064,583,17,20075],
[M,582,4,19987,584,17,20109],
[M,582,19,20002,584,15,20107],
[M,585,35,20145,585,43,20153],
[M,585,17,20127,587,7,20254],
[M,586,6,20189,586,31,20214],
[M,586,13,20196,586,30,20213],
[M,585,4,20114,587,17,20264],
[M,585,17,20127,587,15,20262],
[M,589,45,20311,589,76,20342],
[M,589,4,20270,589,83,20349],
[M,591,55,20406,591,77,20428],
[M,591,42,20393,591,92,20443],
[M,591,55,20406,591,91,20442],
[M,591,49,20400,591,91,20442],
[M,591,4,20355,591,93,20444],
[M,593,44,20490,593,65,20511],
[M,593,37,20483,593,66,20512],
[M,593,22,20468,593,67,20513],
[M,593,14,20460,593,67,20513],
[M,586,34,20217,586,57,20240],
[M,586,41,20224,586,56,20239],
[M,586,6,20189,586,63,20246],
[M,548,33,18711,548,63,18741],
[M,548,6,18684,548,64,18742],
[M,549,6,18749,549,39,18782],
[M,550,52,18835,550,70,18853],
[M,550,38,18821,550,70,18853],
[M,550,6,18789,550,71,18854],
[M,552,10,18902,552,40,18932],
[M,551,29,18884,553,9,18942],
[M,551,6,18861,553,10,18943],
[M,555,55,19021,555,88,19054],
[M,555,74,19040,555,87,19053],
[M,555,55,19021,555,73,19039],
[M,555,55,19021,555,69,19035],
[M,554,14,18958,561,9,19255],
[M,555,39,19005,555,89,19055],
[M,555,33,18999,555,89,19055],
[M,555,10,18976,555,90,19056],
[M,556,10,19068,556,53,19111],
[M,558,12,19153,558,38,19179],
[M,559,12,19193,559,43,19224],
[M,557,10,19123,560,19,19245],
[M,554,6,18950,561,9,19255],
[M,562,44,19300,562,64,19320],
[M,562,39,19295,562,42,19298],
[M,562,66,19322,562,92,19348],
[M,562,66,19322,562,85,19341],
[M,562,6,19262,562,93,19349],
[M,564,6,19357,577,9,19921],
[M,571,8,19652,576,11,19911],
[M,574,78,19813,574,99,19834],
[M,574,71,19806,574,128,19863],
[M,565,8,19386,570,11,19643],
[M,568,25,19506,568,116,19597],
[M,574,101,19836,574,127,19862],
[M,574,40,19775,574,129,19864],
[M,574,25,19760,574,130,19865],
[M,513,6,17405,513,61,17460],
[M,513,31,17430,513,60,17459],
[M,513,39,17438,513,57,17456],
[M,513,39,17438,513,48,17447],
[M,513,39,17438,513,45,17444],
[M,513,19,17418,513,30,17429],
[M,518,14,17570,518,38,17594],
[M,518,14,17570,518,28,17584],
[M,516,36,17529,542,11,18594],
[M,520,16,17639,520,32,17655],
[M,520,16,17639,520,28,17651],
[M,522,18,17708,522,37,17727],
[M,522,30,17720,522,36,17726],
[M,522,18,17708,522,29,17719],
[M,525,61,17845,525,74,17858],
[M,525,54,17838,525,75,17859],
[M,524,18,17776,526,19,17881],
[M,523,18,17747,523,27,17756],
[M,525,34,17818,525,76,17860],
[M,525,20,17804,525,77,17861],
[M,527,18,17902,533,21,18323],
[M,528,20,17989,532,23,18301],
[M,531,22,18221,531,78,18277],
[M,530,22,18144,530,76,18198],
[M,529,22,18047,529,96,18121],
[M,529,53,18078,529,65,18090],
[M,528,41,18010,528,54,18023],
[M,524,18,17776,536,20,18472],
[M,535,67,18419,535,79,18431],
[M,535,60,18412,535,97,18449],
[M,534,18,18344,536,19,18471],
[M,535,81,18433,535,96,18448],
[M,535,29,18381,535,98,18450],
[M,535,20,18372,535,99,18451],
[M,521,16,17673,538,17,18513],
[M,539,16,18531,539,37,18552],
[M,539,16,18531,539,35,18550],
[M,519,14,17610,540,15,18568],
[M,517,12,17549,541,13,18582],
[M,516,10,17503,542,12,18595],
[M,529,67,18092,529,75,18100],
[M,529,82,18107,529,94,18119],
[M,529,77,18102,529,95,18120],
[M,503,30,17047,503,47,17064],
[M,503,30,17047,503,42,17059],
[M,504,92,17165,504,103,17176],
[M,504,85,17158,504,107,17180],
[M,504,56,17129,504,109,17182],
[M,503,49,17066,505,21,17206],
[M,504,63,17136,504,108,17181],
[M,504,31,17104,504,110,17183],
[M,504,22,17095,504,111,17184],
[M,503,18,17035,505,25,17210],
[M,501,14,16977,506,17,17228],
[M,500,10,16929,507,14,17243],
[M,480,17,16351,480,28,16362],
[M,483,27,16427,483,38,16438],
[M,479,7,16328,479,11,16332],
[M,480,12,16346,480,29,16363],
[M,480,6,16340,480,38,16372],
[M,483,22,16422,483,39,16439],
[M,483,16,16416,483,48,16448],
[M,483,8,16408,483,66,16466],
[M,484,21,16489,484,36,16504],
[M,484,21,16489,484,33,16501],
[M,484,38,16506,484,49,16517],
[M,484,38,16506,484,47,16515],
[M,484,8,16476,484,50,16518],
[M,485,19,16539,485,30,16550],
[M,485,14,16534,485,31,16551],
[M,485,8,16528,485,40,16560],
[M,482,6,16389,485,41,16561],
[M,475,15,16196,475,38,16219],
[M,475,10,16191,475,39,16220],
[M,472,9,16107,472,32,16130],
[M,457,15,15745,457,23,15753],
[M,459,53,15818,459,64,15829],
[M,459,40,15805,459,66,15831],
[M,457,6,15736,457,24,15754],
[M,459,47,15812,459,65,15830],
[M,459,6,15771,459,67,15832],
[M,436,4,14947,436,82,15025],
[M,436,53,14996,436,75,15018],
[M,437,57,15083,437,81,15107],
[M,437,57,15083,437,79,15105],
[M,437,57,15083,437,70,15096],
[M,437,57,15083,437,67,15093],
[M,437,41,15067,437,83,15109],
[M,437,28,15054,441,61,15366],
[M,437,48,15074,437,82,15108],
[M,439,23,15156,439,42,15175],
[M,439,37,15170,439,41,15174],
[M,439,23,15156,439,36,15169],
[M,439,23,15156,439,32,15165],
[M,438,14,15125,440,79,15301],
[M,439,23,15156,439,60,15193],
[M,439,47,15180,439,59,15192],
[M,439,23,15156,439,46,15179],
[M,439,23,15156,439,74,15207],
[M,439,23,15156,439,64,15197],
[M,440,20,15242,440,35,15257],
[M,440,20,15242,440,32,15254],
[M,440,58,15280,440,71,15293],
[M,440,58,15280,440,69,15291],
[M,440,58,15280,440,76,15298],
[M,439,76,15209,440,76,15298],
[M,439,17,15150,440,77,15299],
[M,439,8,15141,440,78,15300],
[M,438,6,15117,440,80,15302],
[M,437,35,15061,440,81,15303],
[M,441,43,15348,441,56,15361],
[M,441,43,15348,441,54,15359],
[M,441,12,15317,441,59,15364],
[M,441,37,15342,441,57,15362],
[M,441,19,15324,441,58,15363],
[M,441,6,15311,441,60,15365],
[M,432,43,14700,432,75,14732],
[M,432,62,14719,432,74,14731],
[M,432,43,14700,432,61,14718],
[M,432,43,14700,432,89,14746],
[M,432,43,14700,432,79,14736],
[M,433,22,14770,433,37,14785],
[M,433,22,14770,433,34,14782],
[M,433,66,14814,433,82,14830],
[M,433,66,14814,433,76,14824],
[M,433,39,14787,433,95,14843],
[M,433,66,14814,433,88,14836],
[M,433,97,14845,433,110,14858],
[M,433,97,14845,433,108,14856],
[M,433,10,14758,433,111,14859],
[M,432,37,14694,433,112,14860],
[M,429,55,14565,429,67,14577],
[M,426,31,14413,426,43,14425],
[M,426,45,14427,426,60,14442],
[M,426,45,14427,426,57,14439],
[M,423,57,14289,423,82,14314],
[M,423,68,14300,423,81,14313],
[M,423,57,14289,423,67,14299],
[M,423,44,14276,423,84,14316],
[M,423,51,14283,423,83,14315],
[M,420,35,14089,420,99,14153],
[M,413,25,13839,413,38,13852],
[M,413,25,13839,413,32,13846],
[M,413,40,13854,413,63,13877],
[M,413,49,13863,413,62,13876],
[M,413,40,13854,413,48,13862],
[M,410,22,13694,410,45,13717],
[M,410,17,13689,410,46,13718],
[M,410,56,13728,410,73,13745],
[M,410,56,13728,410,67,13739],
[M,407,19,13580,407,42,13603],
[M,401,4,13361,401,34,13391],
[M,401,19,13376,401,28,13385],
[M,403,45,13457,403,61,13473],
[M,403,45,13457,403,55,13467],
[M,403,38,13450,403,62,13474],
[M,402,12,13404,404,7,13514],
[M,403,13,13425,403,63,13475],
[M,403,8,13420,403,94,13506],
[M,393,7,13088,393,24,13105],
[M,393,7,13088,393,14,13095],
[M,394,29,13136,394,43,13150],
[M,394,29,13136,394,37,13144],
[M,396,19,13188,396,35,13204],
[M,394,14,13121,394,50,13157],
[M,394,29,13136,394,49,13156],
[M,394,6,13113,394,51,13158],
[M,396,37,13206,396,51,13220],
[M,396,37,13206,396,45,13214],
[M,396,14,13183,396,58,13227],
[M,396,37,13206,396,57,13226],
[M,396,6,13175,396,59,13228],
[M,382,29,12561,382,44,12576],
[M,382,29,12561,382,42,12574],
[M,382,29,12561,382,33,12565],
[M,382,20,12552,382,45,12577],
[M,382,76,12608,382,89,12621],
[M,382,76,12608,382,83,12615],
[M,382,53,12585,382,131,12663],
[M,382,60,12592,382,90,12622],
[M,382,115,12647,382,128,12660],
[M,382,115,12647,382,126,12658],
[M,382,115,12647,382,119,12651],
[M,382,109,12641,382,129,12661],
[M,382,92,12624,382,130,12662],
[M,382,47,12579,382,132,12664],
[M,382,14,12546,382,133,12665],
[M,381,12,12526,383,34,12701],
[M,383,14,12681,383,33,12700],
[M,345,7,11388,345,48,11429],
[M,345,20,11401,345,25,11406],
[M,345,7,11388,345,19,11400],
[M,345,41,11422,345,46,11427],
[M,345,30,11411,345,40,11421],
[M,345,7,11388,345,26,11407],
[M,347,30,11475,347,45,11490],
[M,347,30,11475,347,43,11488],
[M,347,30,11475,347,34,11479],
[M,347,8,11453,347,63,11508],
[M,350,19,11569,350,26,11576],
[M,345,30,11411,345,47,11428],
[M,347,21,11466,347,46,11491],
[M,347,48,11493,347,61,11506],
[M,347,48,11493,347,55,11500],
[M,347,15,11460,347,62,11507],
[M,347,8,11453,348,28,11539],
[M,348,8,11519,348,27,11538],
[M,346,6,11436,348,28,11539],
[M,350,6,11556,350,42,11592],
[M,352,23,11637,352,38,11652],
[M,352,23,11637,352,36,11650],
[M,352,23,11637,352,27,11641],
[M,351,14,11607,359,7,11870],
[M,352,14,11628,352,39,11653],
[M,352,41,11655,352,54,11668],
[M,352,41,11655,352,48,11662],
[M,352,8,11622,352,55,11669],
[M,354,10,11734,354,31,11755],
[M,354,23,11747,354,30,11754],
[M,354,23,11747,354,28,11752],
[M,354,10,11734,354,22,11746],
[M,353,39,11710,358,9,11860],
[M,355,10,11767,355,34,11791],
[M,355,22,11779,355,27,11784],
[M,356,24,11817,356,39,11832],
[M,356,24,11817,356,37,11830],
[M,356,24,11817,356,28,11821],
[M,356,15,11808,356,40,11833],
[M,356,10,11803,356,41,11834],
[M,353,17,11688,358,10,11861],
[M,353,8,11679,358,11,11862],
[M,351,6,11599,359,8,11871],
[M,334,8,10923,334,47,10962],
[M,337,69,11066,337,82,11079],
[M,337,69,11066,337,80,11077],
[M,337,56,11053,337,84,11081],
[M,336,10,10990,339,11,11218],
[M,337,63,11060,337,83,11080],
[M,337,30,11027,337,85,11082],
[M,337,12,11009,337,86,11083],
[M,338,27,11112,338,42,11127],
[M,338,27,11112,338,40,11125],
[M,338,18,11103,338,43,11128],
[M,338,80,11165,338,96,11181],
[M,338,73,11158,338,119,11204],
[M,338,104,11189,338,117,11202],
[M,338,104,11189,338,115,11200],
[M,338,98,11183,338,118,11203],
[M,338,45,11130,338,120,11205],
[M,338,12,11097,338,121,11206],
[M,340,10,11231,340,26,11247],
[M,340,10,11231,340,20,11241],
[M,336,10,10990,340,33,11254],
[M,340,10,11231,340,32,11253],
[M,330,23,10775,330,48,10800],
[M,330,50,10802,330,72,10824],
[M,330,17,10769,330,73,10825],
[M,331,10,10839,331,26,10855],
[M,331,10,10839,331,20,10849],
[M,330,10,10762,331,32,10861],
[M,331,10,10839,331,32,10861],
[M,318,30,10297,318,48,10315],
[M,318,30,10297,318,42,10309],
[M,317,14,10260,324,50,10622],
[M,316,28,10239,324,52,10624],
[M,318,12,10279,318,49,10316],
[M,321,40,10458,321,60,10478],
[M,321,40,10458,321,54,10472],
[M,320,51,10411,323,21,10566],
[M,320,38,10398,323,23,10568],
[M,321,22,10440,321,61,10479],
[M,322,39,10520,322,62,10543],
[M,322,22,10503,322,63,10544],
[M,320,45,10405,323,22,10567],
[M,320,14,10374,323,24,10569],
[M,319,12,10330,323,25,10570],
[M,324,30,10602,324,48,10620],
[M,324,30,10602,324,42,10614],
[M,324,12,10584,324,49,10621],
[M,317,8,10254,324,51,10623],
[M,295,5,9564,295,24,9583],
[M,296,4,9589,296,9,9594],
[M,298,17,9620,298,24,9627],
[M,298,26,9629,298,40,9643],
[M,298,4,9607,298,41,9644],
[M,299,4,9649,299,69,9714],
[M,299,11,9656,299,69,9714],
[M,299,50,9695,299,55,9700],
[M,300,4,9719,300,66,9781],
[M,300,11,9726,300,66,9781],
[M,300,54,9769,300,61,9776],
[M,300,54,9769,300,59,9774],
[M,300,38,9753,300,53,9768],
[M,301,4,9786,301,73,9855],
[M,301,11,9793,301,73,9855],
[M,301,52,9834,301,67,9849],
[M,301,52,9834,301,65,9847],
[M,301,52,9834,301,56,9838],
[M,303,6,9922,303,25,9941],
[M,302,46,9902,307,5,10013],
[M,302,4,9860,307,8,10016],
[M,304,6,9949,304,25,9968],
[M,305,6,9976,305,25,9995],
[M,302,20,9876,307,6,10014],
[M,302,11,9867,307,7,10015],
[M,301,43,9825,301,68,9850],
[M,294,39,9503,294,90,9554],
[M,294,72,9536,294,89,9553],
[M,294,83,9547,294,88,9552],
[M,294,72,9536,294,82,9546],
[M,294,39,9503,294,63,9527],
[M,294,68,9532,294,90,9554],
[M,286,20,9182,286,54,9216],
[M,286,63,9225,286,75,9237],
[M,286,12,9174,286,76,9238],
[M,288,27,9290,288,42,9305],
[M,287,16,9256,289,9,9388],
[M,288,81,9344,288,93,9356],
[M,288,64,9327,288,113,9376],
[M,288,95,9358,288,112,9375],
[M,288,18,9281,288,114,9377],
[M,288,10,9273,288,115,9378],
[M,287,8,9248,289,10,9389],
[M,286,6,9168,289,11,9390],
[M,285,4,9156,290,17,9409],
[M,277,62,8962,277,72,8972],
[M,277,62,8962,277,70,8970],
[M,277,56,8956,277,73,8973],
[M,277,89,8989,277,101,9001],
[M,277,89,8989,277,99,8999],
[M,277,80,8980,277,102,9002],
[M,277,75,8975,277,103,9003],
[M,277,105,9005,277,117,9017],
[M,271,6,8609,274,9,8759],
[M,271,24,8627,274,9,8759],
[M,273,8,8695,273,62,8749],
[M,273,37,8724,273,50,8737],
[M,272,8,8654,272,40,8686],
[M,272,26,8672,272,32,8678],
[M,275,38,8798,275,64,8824],
[M,275,31,8791,275,110,8870],
[M,275,66,8826,275,96,8856],
[M,275,66,8826,275,87,8847],
[M,275,98,8858,275,109,8869],
[M,256,28,8144,256,57,8173],
[M,256,28,8144,256,50,8166],
[M,256,6,8122,256,58,8174],
[M,257,27,8202,257,42,8217],
[M,257,38,8213,257,41,8216],
[M,257,27,8202,257,37,8212],
[M,257,27,8202,257,63,8238],
[M,257,47,8222,257,62,8237],
[M,257,27,8202,257,46,8221],
[M,257,6,8181,257,64,8239],
[M,258,6,8246,260,9,8339],
[M,258,13,8253,260,9,8339],
[M,259,24,8301,259,51,8328],
[M,259,36,8313,259,41,8318],
[M,259,16,8293,259,22,8299],
[M,264,10,8423,264,21,8434],
[M,261,33,8373,265,9,8444],
[M,251,27,7913,251,49,7935],
[M,193,2,5213,193,34,5245],
[M,194,15,5261,194,33,5279],
[M,194,2,5248,194,34,5280],
[M,195,16,5297,195,35,5316],
[M,195,2,5283,195,36,5317],
[M,196,17,5335,196,37,5355],
[M,196,2,5320,196,38,5356],
[M,197,19,5376,197,37,5394],
[M,197,2,5359,197,38,5395],
[M,198,2,5398,198,32,5428],
[M,198,15,5411,198,22,5418],
[M,199,2,5431,199,45,5474],
[M,199,27,5456,199,44,5473],
[M,199,18,5447,199,26,5455],
[M,200,2,5477,200,59,5534],
[M,200,41,5516,200,58,5533],
[M,200,25,5500,200,40,5515],
[M,202,24,5568,202,39,5583],
[M,202,17,5561,202,48,5592],
[M,202,58,5602,202,66,5610],
[M,202,50,5594,202,56,5600],
[M,202,9,5553,202,67,5611],
[M,203,46,5659,203,57,5670],
[M,203,14,5627,203,71,5684],
[M,203,59,5672,203,67,5680],
[M,203,40,5653,203,68,5681],
[M,203,28,5641,203,69,5682],
[M,203,21,5634,203,70,5683],
[M,203,6,5619,203,72,5685],
[M,206,30,5861,206,39,5870],
[M,204,14,5701,209,64,6070],
[M,206,60,5891,206,68,5899],
[M,206,17,5848,206,69,5900],
[M,206,10,5841,206,70,5901],
[M,208,48,5992,208,59,6003],
[M,208,27,5971,209,59,6065],
[M,208,14,5958,209,61,6067],
[M,208,34,5978,208,60,6004],
[M,209,38,6044,209,57,6063],
[M,209,38,6044,209,54,6060],
[M,209,22,6028,209,58,6064],
[M,208,21,5965,209,60,6066],
[M,207,18,5921,209,62,6068],
[M,207,10,5913,209,63,6069],
[M,204,6,5693,209,65,6071],
[M,201,2,5537,209,66,6072],
[M,210,15,6088,210,41,6114],
[M,210,36,6109,210,40,6113],
[M,210,15,6088,210,35,6108],
[M,210,15,6088,210,31,6104],
[M,210,15,6088,210,59,6132],
[M,210,46,6119,210,58,6131],
[M,210,15,6088,210,45,6118],
[M,210,2,6075,210,73,6146],
[M,210,15,6088,210,63,6136],
[M,214,39,6334,214,46,6341],
[M,214,32,6327,214,47,6342],
[M,212,12,6169,237,23,7452],
[M,214,12,6307,214,48,6343],
[M,218,32,6451,218,51,6470],
[M,218,32,6451,218,48,6467],
[M,217,20,6411,226,36,6938],
[M,215,16,6361,232,13,7260],
[M,218,16,6435,218,52,6471],
[M,219,52,6525,219,83,6556],
[M,219,52,6525,219,81,6554],
[M,219,52,6525,219,72,6545],
[M,219,52,6525,219,69,6542],
[M,219,36,6509,219,85,6558],
[M,219,43,6516,219,84,6557],
[M,221,40,6634,221,57,6651],
[M,220,26,6586,226,32,6934],
[M,221,35,6629,221,58,6652],
[M,223,42,6726,223,73,6757],
[M,223,42,6726,223,71,6755],
[M,223,42,6726,223,62,6746],
[M,223,42,6726,223,59,6743],
[M,223,33,6717,223,74,6758],
[M,223,28,6712,223,75,6759],
[M,224,28,6789,224,60,6821],
[M,224,43,6804,224,59,6820],
[M,224,28,6789,224,42,6803],
[M,222,24,6678,226,29,6931],
[M,221,29,6623,226,30,6932],
[M,221,20,6614,226,31,6933],
[M,220,18,6578,226,33,6935],
[M,219,30,6503,226,34,6936],
[M,219,16,6489,226,35,6937],
[M,217,14,6405,228,17,7023],
[M,216,12,6381,228,18,7024],
[M,229,42,7068,229,49,7075],
[M,229,36,7062,229,59,7085],
[M,230,23,7110,230,50,7137],
[M,230,16,7103,230,65,7152],
[M,230,52,7139,230,64,7151],
[M,230,67,7154,230,75,7162],
[M,229,19,7045,230,76,7163],
[M,229,12,7038,230,77,7164],
[M,215,8,6353,232,14,7261],
[M,214,6,6301,232,15,7262],
[M,233,49,7313,233,56,7320],
[M,233,42,7306,233,57,7321],
[M,233,12,7276,233,58,7322],
[M,235,40,7390,235,59,7409],
[M,235,40,7390,235,56,7406],
[M,234,18,7342,236,13,7425],
[M,235,21,7371,235,60,7410],
[M,235,14,7364,235,61,7411],
[M,234,10,7334,236,14,7426],
[M,233,6,7270,236,15,7427],
[M,237,14,7443,237,21,7450],
[M,237,6,7435,237,22,7451],
[M,211,2,6149,237,24,7453],
[M,239,6,7478,239,25,7497],
[M,238,10,7464,245,5,7827],
[M,240,25,7524,240,36,7535],
[M,240,66,7565,240,85,7584],
[M,240,66,7565,240,82,7581],
[M,240,46,7545,240,115,7614],
[M,240,62,7561,240,113,7612],
[M,240,53,7552,240,114,7613],
[M,240,38,7537,240,116,7615],
[M,240,19,7518,240,117,7616],
[M,240,6,7505,240,118,7617],
[M,241,6,7625,241,33,7652],
[M,242,28,7682,242,45,7699],
[M,242,23,7677,242,46,7700],
[M,242,55,7709,242,62,7716],
[M,242,48,7702,242,63,7717],
[M,242,48,7702,242,92,7746],
[M,242,66,7720,242,91,7745],
[M,242,17,7671,242,92,7746],
[M,242,6,7660,242,93,7747],
[M,243,20,7769,243,35,7784],
[M,243,13,7762,243,44,7793],
[M,243,6,7755,243,45,7794],
[M,244,15,7811,244,24,7820],
[M,244,6,7802,244,25,7821],
[M,165,2,4190,165,34,4222],
[M,166,2,4225,166,32,4255],
[M,166,15,4238,166,22,4245],
[M,167,2,4258,167,45,4301],
[M,167,27,4283,167,44,4300],
[M,167,18,4274,167,26,4282],
[M,169,24,4335,169,39,4350],
[M,169,17,4328,169,48,4359],
[M,169,58,4369,169,66,4377],
[M,169,50,4361,169,56,4367],
[M,169,9,4320,169,67,4378],
[M,170,44,4424,170,63,4443],
[M,170,44,4424,170,60,4440],
[M,170,14,4394,170,94,4474],
[M,170,40,4420,170,91,4471],
[M,170,28,4408,170,92,4472],
[M,170,21,4401,170,93,4473],
[M,170,6,4386,170,95,4475],
[M,172,30,4529,172,39,4538],
[M,171,14,4491,176,64,4863],
[M,172,60,4559,172,68,4567],
[M,172,17,4516,172,69,4568],
[M,172,10,4509,172,70,4569],
[M,175,35,4695,175,54,4714],
[M,175,28,4688,175,55,4715],
[M,174,27,4639,176,59,4858],
[M,174,14,4626,176,61,4860],
[M,175,85,4745,175,104,4764],
[M,175,85,4745,175,101,4761],
[M,175,65,4725,175,134,4794],
[M,175,81,4741,175,132,4792],
[M,175,72,4732,175,133,4793],
[M,175,57,4717,175,135,4795],
[M,175,22,4682,175,136,4796],
[M,174,34,4646,175,137,4797],
[M,176,38,4837,176,57,4856],
[M,176,38,4837,176,54,4853],
[M,176,22,4821,176,58,4857],
[M,174,21,4633,176,60,4859],
[M,173,18,4589,176,62,4861],
[M,173,10,4581,176,63,4862],
[M,171,6,4483,176,65,4864],
[M,168,2,4304,176,66,4865],
[M,179,20,4916,179,35,4931],
[M,177,10,4876,181,5,4972],
[M,179,13,4909,179,44,4940],
[M,179,6,4902,179,45,4941],
[M,180,15,4958,180,22,4965],
[M,180,6,4949,180,23,4966],
[M,160,37,4072,160,59,4094],
[M,160,46,4081,160,58,4093],
[M,160,37,4072,160,45,4080],
[M,160,37,4072,160,73,4108],
[M,160,37,4072,160,63,4098],
[M,160,75,4110,160,95,4130],
[M,160,75,4110,160,85,4120],
[M,160,31,4066,160,96,4131],
[M,155,37,3899,155,59,3921],
[M,152,12,3834,152,33,3855],
[M,148,17,3756,148,39,3778],
[M,148,8,3747,148,40,3779],
[M,148,42,3781,148,50,3789],
[M,142,12,3562,142,46,3596],
[M,143,4,3602,143,28,3626],
[M,144,13,3641,144,28,3656],
[M,144,61,3689,144,80,3708],
[M,144,48,3676,144,81,3709],
[M,144,4,3632,144,82,3710],
[M,135,11,3363,135,44,3396],
[M,135,54,3406,135,65,3417],
[M,108,4,2625,108,23,2644],
[M,108,10,2631,108,22,2643],
[M,109,4,2650,109,25,2671],
[M,109,10,2656,109,24,2670],
[M,110,4,2677,110,23,2696],
[M,110,10,2683,110,22,2695],
[M,111,4,2702,111,21,2719],
[M,111,10,2708,111,20,2718],
[M,112,4,2725,112,23,2744],
[M,112,10,2731,112,22,2743],
[M,113,4,2750,113,21,2767],
[M,113,10,2756,113,20,2766],
[M,89,4,2223,89,77,2296],
[M,89,65,2284,89,75,2294],
[M,89,9,2228,89,27,2246],
[M,90,7,2304,90,25,2322],
[M,90,7,2304,90,21,2318],
[M,89,35,2254,89,76,2295],
[M,89,29,2248,89,76,2295],
[M,91,6,2330,91,20,2344],
[M,91,6,2330,91,16,2340],
[M,93,6,2361,93,52,2407],
[M,94,6,2414,94,39,2447],
[M,94,16,2424,94,27,2435],
[M,95,6,2454,95,29,2477],
[M,95,6,2454,95,16,2464],
[M,96,6,2484,96,13,2491],
[M,78,48,1995,78,60,2007],
[M,78,50,1997,78,59,2006],
[M,78,18,1965,78,29,1976],
[M,75,45,1790,75,61,1806],
[M,75,45,1790,75,58,1803],
[M,75,45,1790,75,54,1799],
[M,75,18,1763,75,29,1774],
[M,72,50,1585,72,67,1602],
[M,72,50,1585,72,64,1599],
[M,72,50,1585,72,60,1595],
[M,72,18,1553,72,31,1566],
[M,67,18,1322,67,34,1338],
[M,3,0,13,735,3,25747],
[M,15,11,296,15,20,305],
[M,56,0,995,56,25,1020],
[M,54,11,983,54,21,993],
[M,53,9,963,53,17,971],
[M,52,12,942,52,23,953],
[M,51,9,921,51,17,929],
[M,50,9,903,50,17,911],
[M,49,9,885,49,17,893],
[M,48,8,868,48,15,875],
[M,47,7,853,47,13,859],
[M,46,10,836,46,19,845],
[M,45,9,817,45,17,825],
[M,44,10,798,44,19,807],
[M,43,14,774,43,27,787],
[M,42,19,741,42,37,759],
[M,41,15,707,41,29,721],
[M,40,10,682,40,19,691],
[M,39,12,660,39,23,671],
[M,38,8,640,38,15,647],
[M,37,8,624,37,15,631],
[M,36,9,607,36,17,615],
[M,35,8,590,35,15,597],
[M,34,8,574,34,15,581],
[M,33,7,559,33,13,565],
[M,32,11,541,32,21,551],
[M,31,11,519,31,21,529],
[M,30,8,500,30,15,507],
[M,29,8,484,29,15,491],
[M,28,10,466,28,19,475],
[M,27,9,447,27,17,455],
[M,26,10,428,26,19,437],
[M,25,11,407,25,21,417],
[M,24,7,389,24,13,395],
[M,23,8,374,23,15,381],
[M,22,8,358,22,15,365],
[M,17,0,307,19,3,347]];
var _minus4 = NAMESPACE.get("_minus");
var _plus5 = NAMESPACE.get("_plus");
var builtins6 = NAMESPACE.get("builtins");
var is_DASH_string7 = NAMESPACE.get("is-string");
var not8 = NAMESPACE.get("not");
var nothing9 = NAMESPACE.get("nothing");
var num_DASH_is_DASH_fixnum10 = NAMESPACE.get("num-is-fixnum");
var raise11 = NAMESPACE.get("raise");
var string_DASH_replace12 = NAMESPACE.get("string-replace");
var torepr13 = NAMESPACE.get("torepr");
var tostring14 = NAMESPACE.get("tostring");
var $type$Boolean15 = NAMESPACE.get("$type$Boolean");
var $type$Number16 = NAMESPACE.get("$type$Number");
var $type$String17 = NAMESPACE.get("$type$String");
var $Hget_DASH_field_DASH_loc253958 = function(get_DASH_field_DASH_loc11459,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17) {
var $z108109 = D;
var $f114115 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("U")):R.ffi.throwNonFunApp(L[0],j_DASH_id8381,[("U")]);
};
try {
if(--R.GAS > 0) {
$z108109 = $f114115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f114115,
"from":L[0]});
}
} catch($e106107) {
if(R.isCont($e106107)) {
var $ss110111 = {"from":L[0],
"go":function(throw_DASH_uninitialized115116) {
return $Hthrow_DASH_uninitialized2538117(throw_DASH_uninitialized115116,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
}};
$e106107.stack[R.EXN_STACKHEIGHT++] = $ss110111;
}
if(R.isPyretException($e106107)) {
$e106107.pyretStack.push(L[0]);
}
throw $e106107;
}
var $ret112113 = $Hthrow_DASH_uninitialized2538117($z108109,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
++R.GAS;
return $ret112113;
};
var $Hthrow_DASH_uninitialized2538117 = function(throw_DASH_uninitialized115116,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17) {
var $z120121 = D;
var $f126127 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("M")):R.ffi.throwNonFunApp(L[1],j_DASH_id8381,[("M")]);
};
try {
if(--R.GAS > 0) {
$z120121 = $f126127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f126127,
"from":L[1]});
}
} catch($e118119) {
if(R.isCont($e118119)) {
var $ss122123 = {"from":L[1],
"go":function(source_DASH_name116128) {
return $Hsource_DASH_name2537129(source_DASH_name116128,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,throw_DASH_uninitialized115116,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
}};
$e118119.stack[R.EXN_STACKHEIGHT++] = $ss122123;
}
if(R.isPyretException($e118119)) {
$e118119.pyretStack.push(L[1]);
}
throw $e118119;
}
var $ret124125 = $Hsource_DASH_name2537129($z120121,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,throw_DASH_uninitialized115116,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
++R.GAS;
return $ret124125;
};
var $Hsource_DASH_name2537129 = function(source_DASH_name116128,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,throw_DASH_uninitialized115116,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17) {
var $z132133 = D;
var $f138139 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("D")):R.ffi.throwNonFunApp(L[2],j_DASH_id8381,[("D")]);
};
try {
if(--R.GAS > 0) {
$z132133 = $f138139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f138139,
"from":L[2]});
}
} catch($e130131) {
if(R.isCont($e130131)) {
var $ss134135 = {"from":L[2],
"go":function(undefined117140) {
return $Hundefined2536141(undefined117140,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,source_DASH_name116128,throw_DASH_uninitialized115116,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
}};
$e130131.stack[R.EXN_STACKHEIGHT++] = $ss134135;
}
if(R.isPyretException($e130131)) {
$e130131.pyretStack.push(L[2]);
}
throw $e130131;
}
var $ret136137 = $Hundefined2536141($z132133,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,source_DASH_name116128,throw_DASH_uninitialized115116,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
++R.GAS;
return $ret136137;
};
var $Hundefined2536141 = function(undefined117140,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,source_DASH_name116128,throw_DASH_uninitialized115116,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17) {
var ConcatList3118142 = {"$var":D,
"$name":"ConcatList3"};
var ConcatList119144 = {"$var":D,
"$name":"ConcatList"};
var is_DASH_ConcatList120146 = {"$var":D,
"$name":"is-ConcatList"};
var is_DASH_concat_DASH_empty121148 = {"$var":D,
"$name":"is-concat-empty"};
var concat_DASH_empty122150 = {"$var":D,
"$name":"concat-empty"};
var is_DASH_concat_DASH_singleton123152 = {"$var":D,
"$name":"is-concat-singleton"};
var concat_DASH_singleton124154 = {"$var":D,
"$name":"concat-singleton"};
var is_DASH_concat_DASH_append125156 = {"$var":D,
"$name":"is-concat-append"};
var concat_DASH_append126158 = {"$var":D,
"$name":"concat-append"};
var is_DASH_concat_DASH_cons127160 = {"$var":D,
"$name":"is-concat-cons"};
var concat_DASH_cons128162 = {"$var":D,
"$name":"concat-cons"};
var is_DASH_concat_DASH_snoc129164 = {"$var":D,
"$name":"is-concat-snoc"};
var concat_DASH_snoc130166 = {"$var":D,
"$name":"concat-snoc"};
var anf_shared4181 = R.makeMethod(function(self159641) {
return function(other160642) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[65],1,arguments);
}
return R.checkAnnArgs([ConcatList7660],[other160642],[L[66]],function() {
var $z633634 = D;
var $f639640 = function(_) {
return R.isFunction(concat_DASH_append126158.$var === D?U(L[64],"concat-append"):concat_DASH_append126158.$var)?concat_DASH_append126158.$var === D?U(L[64],"concat-append"):concat_DASH_append126158.$var.app(self159641,other160642):R.ffi.throwNonFunApp(L[65],concat_DASH_append126158.$var === D?U(L[64],"concat-append"):concat_DASH_append126158.$var,[self159641,other160642]);
};
try {
if(--R.GAS > 0) {
$z633634 = $f639640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f639640,
"from":L[65]});
}
} catch($e631632) {
if(R.isCont($e631632)) {
var $ss635636 = {"from":L[65],
"go":function(ann_DASH_check_DASH_temp3643) {
return $Hann_DASH_check_DASH_temp1619644(ann_DASH_check_DASH_temp3643);
}};
$e631632.stack[R.EXN_STACKHEIGHT++] = $ss635636;
}
if(R.isPyretException($e631632)) {
$e631632.pyretStack.push(L[65]);
}
throw $e631632;
}
var $ret637638 = $Hann_DASH_check_DASH_temp1619644($z633634);
++R.GAS;
return $ret637638;
});
};
},{"length":2});
var anf_shared9182 = R.makeMethod(function(self161630) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[63],0,arguments);
}
var anf_fun6628 = G(self161630,"to-list-acc",L[62]);
var anf_fun7626 = G(list35101,"make",L[61]);
var $z618619 = D;
var $f624625 = function(_) {
return R.isFunction(anf_fun7626)?anf_fun7626.app([]):R.ffi.throwNonFunApp(L[61],anf_fun7626,[[]]);
};
try {
if(--R.GAS > 0) {
$z618619 = $f624625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f624625,
"from":L[61]});
}
} catch($e616617) {
if(R.isCont($e616617)) {
var $ss620621 = {"from":L[61],
"go":function(anf_arg8627) {
return $Hanf_arg1621629(anf_arg8627,anf_fun6628);
}};
$e616617.stack[R.EXN_STACKHEIGHT++] = $ss620621;
}
if(R.isPyretException($e616617)) {
$e616617.pyretStack.push(L[61]);
}
throw $e616617;
}
var $ret622623 = $Hanf_arg1621629($z618619,anf_fun6628);
++R.GAS;
return $ret622623;
};
},{"length":1});
var anf_singleton_variant_member20188 = R.makeMethod(function(self2615) {
return function(cases_DASH_funs3594,else_DASH_clause4605) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[9],2,arguments);
}
var if_DASH_6608 = R.hasField(cases_DASH_funs3594,("concat-empty"));
var if_helper11592 = R.makeFunction(function(if_helper_arg12613) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[9],1,arguments);
}
var ann_DASH_check_DASH_temp10614 = if_helper_arg12613;
return ann_DASH_check_DASH_temp10614;
});
var anf_if15612 = R.isBoolean(if_DASH_6608);
if(R.isPyretTrue(anf_if15612)) {
if(R.isPyretTrue(if_DASH_6608)) {
var call_DASH_concat_DASH_empty1590 = G(cases_DASH_funs3594,"concat-empty",L[9]);
var $z582583 = D;
var $f588589 = function(_) {
return R.isFunction(call_DASH_concat_DASH_empty1590)?call_DASH_concat_DASH_empty1590.app():R.ffi.throwNonFunApp(L[9],call_DASH_concat_DASH_empty1590,[]);
};
try {
if(--R.GAS > 0) {
$z582583 = $f588589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f588589,
"from":L[9]});
}
} catch($e580581) {
if(R.isCont($e580581)) {
var $ss584585 = {"from":L[9],
"go":function(cont_tail_arg18591) {
return $Hcont_tail_arg1622593(cont_tail_arg18591,if_helper11592);
}};
$e580581.stack[R.EXN_STACKHEIGHT++] = $ss584585;
}
if(R.isPyretException($e580581)) {
$e580581.pyretStack.push(L[9]);
}
throw $e580581;
}
var $ret586587 = $Hcont_tail_arg1622593($z582583,if_helper11592);
++R.GAS;
return $ret586587;
} else {
var $z597598 = D;
var $f603604 = function(_) {
return R.isFunction(else_DASH_clause4605)?else_DASH_clause4605.app():R.ffi.throwNonFunApp(L[9],else_DASH_clause4605,[]);
};
try {
if(--R.GAS > 0) {
$z597598 = $f603604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f603604,
"from":L[9]});
}
} catch($e595596) {
if(R.isCont($e595596)) {
var $ss599600 = {"from":L[9],
"go":function(cont_tail_arg16606) {
return $Hcont_tail_arg1623607(cont_tail_arg16606,if_helper11592);
}};
$e595596.stack[R.EXN_STACKHEIGHT++] = $ss599600;
}
if(R.isPyretException($e595596)) {
$e595596.pyretStack.push(L[9]);
}
throw $e595596;
}
var $ret601602 = $Hcont_tail_arg1623607($z597598,if_helper11592);
++R.GAS;
return $ret601602;
}
} else {
var cont_tail_arg13611 = R.throwNonBooleanCondition(L[9],("if"),if_DASH_6608);
if(--R.GAS > 0) {
$z609610 = R.isFunction(if_helper11592)?if_helper11592.app(cont_tail_arg13611):R.ffi.throwNonFunApp(L[9],if_helper11592,[cont_tail_arg13611]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper11592)?if_helper11592.app(cont_tail_arg13611):R.ffi.throwNonFunApp(L[9],if_helper11592,[cont_tail_arg13611]);
},
"from":L[9]});
}
++R.GAS;
return $z609610;
}
};
},{"length":3});
var anf_singleton_variant_member22189 = R.makeMethod(function(self5579) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[9],0,arguments);
}
var ann_DASH_check_DASH_temp21578 = ("concat-empty");
return ann_DASH_check_DASH_temp21578;
};
},{"length":1});
var anf_singleton_variant_member24190 = R.makeMethod(function(self132577) {
return function(rest133576) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[60],1,arguments);
}
var ann_DASH_check_DASH_temp23575 = rest133576;
return ann_DASH_check_DASH_temp23575;
};
},{"length":2});
var anf_singleton_variant_member26191 = R.makeMethod(function(self134573) {
return function(f135574) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[59],1,arguments);
}
var ann_DASH_check_DASH_temp25572 = self134573;
return ann_DASH_check_DASH_temp25572;
};
},{"length":2});
var anf_variant_member38197 = R.makeMethod(function(self8550) {
return function(cases_DASH_funs9551,else_DASH_clause10562) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[8],2,arguments);
}
var if_DASH_12565 = R.hasField(cases_DASH_funs9551,("concat-singleton"));
var if_helper28548 = R.makeFunction(function(if_helper_arg29570) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
var ann_DASH_check_DASH_temp27571 = if_helper_arg29570;
return ann_DASH_check_DASH_temp27571;
});
var anf_if32569 = R.isBoolean(if_DASH_12565);
if(R.isPyretTrue(anf_if32569)) {
if(R.isPyretTrue(if_DASH_12565)) {
var call_DASH_concat_DASH_singleton7545 = G(cases_DASH_funs9551,"concat-singleton",L[8]);
var anf_arg35546 = G(self8550,"element",L[58]);
var $z537538 = D;
var $f543544 = function(_) {
return R.isFunction(call_DASH_concat_DASH_singleton7545)?call_DASH_concat_DASH_singleton7545.app(anf_arg35546):R.ffi.throwNonFunApp(L[8],call_DASH_concat_DASH_singleton7545,[anf_arg35546]);
};
try {
if(--R.GAS > 0) {
$z537538 = $f543544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f543544,
"from":L[8]});
}
} catch($e535536) {
if(R.isCont($e535536)) {
var $ss539540 = {"from":L[8],
"go":function(cont_tail_arg36547) {
return $Hcont_tail_arg1624549(cont_tail_arg36547,if_helper28548);
}};
$e535536.stack[R.EXN_STACKHEIGHT++] = $ss539540;
}
if(R.isPyretException($e535536)) {
$e535536.pyretStack.push(L[8]);
}
throw $e535536;
}
var $ret541542 = $Hcont_tail_arg1624549($z537538,if_helper28548);
++R.GAS;
return $ret541542;
} else {
var $z554555 = D;
var $f560561 = function(_) {
return R.isFunction(else_DASH_clause10562)?else_DASH_clause10562.app():R.ffi.throwNonFunApp(L[8],else_DASH_clause10562,[]);
};
try {
if(--R.GAS > 0) {
$z554555 = $f560561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f560561,
"from":L[8]});
}
} catch($e552553) {
if(R.isCont($e552553)) {
var $ss556557 = {"from":L[8],
"go":function(cont_tail_arg33563) {
return $Hcont_tail_arg1625564(cont_tail_arg33563,if_helper28548);
}};
$e552553.stack[R.EXN_STACKHEIGHT++] = $ss556557;
}
if(R.isPyretException($e552553)) {
$e552553.pyretStack.push(L[8]);
}
throw $e552553;
}
var $ret558559 = $Hcont_tail_arg1625564($z554555,if_helper28548);
++R.GAS;
return $ret558559;
}
} else {
var cont_tail_arg30568 = R.throwNonBooleanCondition(L[8],("if"),if_DASH_12565);
if(--R.GAS > 0) {
$z566567 = R.isFunction(if_helper28548)?if_helper28548.app(cont_tail_arg30568):R.ffi.throwNonFunApp(L[8],if_helper28548,[cont_tail_arg30568]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper28548)?if_helper28548.app(cont_tail_arg30568):R.ffi.throwNonFunApp(L[8],if_helper28548,[cont_tail_arg30568]);
},
"from":L[8]});
}
++R.GAS;
return $z566567;
}
};
},{"length":3});
var anf_variant_member44198 = R.makeMethod(function(self11534) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[8],0,arguments);
}
var anf_arg40531 = G(self11534,"element",L[8]);
var $z523524 = D;
var $f529530 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg40531):R.ffi.throwNonFunApp(L[8],torepr13,[anf_arg40531]);
};
try {
if(--R.GAS > 0) {
$z523524 = $f529530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f529530,
"from":L[8]});
}
} catch($e521522) {
if(R.isCont($e521522)) {
var $ss525526 = {"from":L[8],
"go":function(anf_arg41532) {
return $Hanf_arg1629533(anf_arg41532,_plus5);
}};
$e521522.stack[R.EXN_STACKHEIGHT++] = $ss525526;
}
if(R.isPyretException($e521522)) {
$e521522.pyretStack.push(L[8]);
}
throw $e521522;
}
var $ret527528 = $Hanf_arg1629533($z523524,_plus5);
++R.GAS;
return $ret527528;
};
},{"length":1});
var anf_variant_member47199 = R.makeMethod(function(self137520) {
return function(rest138517) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[56],1,arguments);
}
var anf_arg46516 = G(self137520,"element",L[57]);
var $z508509 = D;
var $f514515 = function(_) {
return R.isFunction(link39100)?link39100.app(anf_arg46516,rest138517):R.ffi.throwNonFunApp(L[56],link39100,[anf_arg46516,rest138517]);
};
try {
if(--R.GAS > 0) {
$z508509 = $f514515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f514515,
"from":L[56]});
}
} catch($e506507) {
if(R.isCont($e506507)) {
var $ss510511 = {"from":L[56],
"go":function(ann_DASH_check_DASH_temp45518) {
return $Hann_DASH_check_DASH_temp1630519(ann_DASH_check_DASH_temp45518);
}};
$e506507.stack[R.EXN_STACKHEIGHT++] = $ss510511;
}
if(R.isPyretException($e506507)) {
$e506507.pyretStack.push(L[56]);
}
throw $e506507;
}
var $ret512513 = $Hann_DASH_check_DASH_temp1630519($z508509);
++R.GAS;
return $ret512513;
};
},{"length":2});
var anf_variant_member51200 = R.makeMethod(function(self139505) {
return function(f140501) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[55],1,arguments);
}
var anf_arg49502 = G(self139505,"element",L[54]);
var $z493494 = D;
var $f499500 = function(_) {
return R.isFunction(f140501)?f140501.app(anf_arg49502):R.ffi.throwNonFunApp(L[53],f140501,[anf_arg49502]);
};
try {
if(--R.GAS > 0) {
$z493494 = $f499500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f499500,
"from":L[53]});
}
} catch($e491492) {
if(R.isCont($e491492)) {
var $ss495496 = {"from":L[53],
"go":function(anf_arg50503) {
return $Hanf_arg1632504(anf_arg50503,concat_DASH_singleton124154);
}};
$e491492.stack[R.EXN_STACKHEIGHT++] = $ss495496;
}
if(R.isPyretException($e491492)) {
$e491492.pyretStack.push(L[53]);
}
throw $e491492;
}
var $ret497498 = $Hanf_arg1632504($z493494,concat_DASH_singleton124154);
++R.GAS;
return $ret497498;
};
},{"length":2});
var anf_variant_member64207 = R.makeMethod(function(self14469) {
return function(cases_DASH_funs15470,else_DASH_clause16481) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[7],2,arguments);
}
var if_DASH_18484 = R.hasField(cases_DASH_funs15470,("concat-append"));
var if_helper53467 = R.makeFunction(function(if_helper_arg54489) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
var ann_DASH_check_DASH_temp52490 = if_helper_arg54489;
return ann_DASH_check_DASH_temp52490;
});
var anf_if57488 = R.isBoolean(if_DASH_18484);
if(R.isPyretTrue(anf_if57488)) {
if(R.isPyretTrue(if_DASH_18484)) {
var call_DASH_concat_DASH_append13463 = G(cases_DASH_funs15470,"concat-append",L[7]);
var anf_arg60464 = G(self14469,"left",L[52]);
var anf_arg61465 = G(self14469,"right",L[51]);
var $z455456 = D;
var $f461462 = function(_) {
return R.isFunction(call_DASH_concat_DASH_append13463)?call_DASH_concat_DASH_append13463.app(anf_arg60464,anf_arg61465):R.ffi.throwNonFunApp(L[7],call_DASH_concat_DASH_append13463,[anf_arg60464,anf_arg61465]);
};
try {
if(--R.GAS > 0) {
$z455456 = $f461462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f461462,
"from":L[7]});
}
} catch($e453454) {
if(R.isCont($e453454)) {
var $ss457458 = {"from":L[7],
"go":function(cont_tail_arg62466) {
return $Hcont_tail_arg1633468(cont_tail_arg62466,if_helper53467);
}};
$e453454.stack[R.EXN_STACKHEIGHT++] = $ss457458;
}
if(R.isPyretException($e453454)) {
$e453454.pyretStack.push(L[7]);
}
throw $e453454;
}
var $ret459460 = $Hcont_tail_arg1633468($z455456,if_helper53467);
++R.GAS;
return $ret459460;
} else {
var $z473474 = D;
var $f479480 = function(_) {
return R.isFunction(else_DASH_clause16481)?else_DASH_clause16481.app():R.ffi.throwNonFunApp(L[7],else_DASH_clause16481,[]);
};
try {
if(--R.GAS > 0) {
$z473474 = $f479480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f479480,
"from":L[7]});
}
} catch($e471472) {
if(R.isCont($e471472)) {
var $ss475476 = {"from":L[7],
"go":function(cont_tail_arg58482) {
return $Hcont_tail_arg1634483(cont_tail_arg58482,if_helper53467);
}};
$e471472.stack[R.EXN_STACKHEIGHT++] = $ss475476;
}
if(R.isPyretException($e471472)) {
$e471472.pyretStack.push(L[7]);
}
throw $e471472;
}
var $ret477478 = $Hcont_tail_arg1634483($z473474,if_helper53467);
++R.GAS;
return $ret477478;
}
} else {
var cont_tail_arg55487 = R.throwNonBooleanCondition(L[7],("if"),if_DASH_18484);
if(--R.GAS > 0) {
$z485486 = R.isFunction(if_helper53467)?if_helper53467.app(cont_tail_arg55487):R.ffi.throwNonFunApp(L[7],if_helper53467,[cont_tail_arg55487]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper53467)?if_helper53467.app(cont_tail_arg55487):R.ffi.throwNonFunApp(L[7],if_helper53467,[cont_tail_arg55487]);
},
"from":L[7]});
}
++R.GAS;
return $z485486;
}
};
},{"length":3});
var anf_variant_member74208 = R.makeMethod(function(self17451) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[7],0,arguments);
}
var anf_arg66449 = G(self17451,"left",L[7]);
var $z441442 = D;
var $f447448 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg66449):R.ffi.throwNonFunApp(L[7],torepr13,[anf_arg66449]);
};
try {
if(--R.GAS > 0) {
$z441442 = $f447448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f447448,
"from":L[7]});
}
} catch($e439440) {
if(R.isCont($e439440)) {
var $ss443444 = {"from":L[7],
"go":function(anf_arg67450) {
return $Hanf_arg1641452(anf_arg67450,self17451,_plus5,torepr13);
}};
$e439440.stack[R.EXN_STACKHEIGHT++] = $ss443444;
}
if(R.isPyretException($e439440)) {
$e439440.pyretStack.push(L[7]);
}
throw $e439440;
}
var $ret445446 = $Hanf_arg1641452($z441442,self17451,_plus5,torepr13);
++R.GAS;
return $ret445446;
};
},{"length":1});
var anf_variant_member81209 = R.makeMethod(function(self143437) {
return function(rest144432) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[50],1,arguments);
}
return R.checkAnnArgs([List2762],[rest144432],[L[49]],function() {
var anf_bracket76438 = G(self143437,"left",L[48]);
var anf_fun77434 = G(anf_bracket76438,"to-list-acc",L[47]);
var anf_bracket78436 = G(self143437,"right",L[46]);
var anf_fun79431 = G(anf_bracket78436,"to-list-acc",L[45]);
var $z423424 = D;
var $f429430 = function(_) {
return R.isFunction(anf_fun79431)?anf_fun79431.app(rest144432):R.ffi.throwNonFunApp(L[44],anf_fun79431,[rest144432]);
};
try {
if(--R.GAS > 0) {
$z423424 = $f429430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f429430,
"from":L[44]});
}
} catch($e421422) {
if(R.isCont($e421422)) {
var $ss425426 = {"from":L[44],
"go":function(anf_arg80433) {
return $Hanf_arg1643435(anf_arg80433,anf_fun77434);
}};
$e421422.stack[R.EXN_STACKHEIGHT++] = $ss425426;
}
if(R.isPyretException($e421422)) {
$e421422.pyretStack.push(L[44]);
}
throw $e421422;
}
var $ret427428 = $Hanf_arg1643435($z423424,anf_fun77434);
++R.GAS;
return $ret427428;
});
};
},{"length":2});
var anf_variant_member89210 = R.makeMethod(function(self145418) {
return function(f146416) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[43],1,arguments);
}
var anf_bracket83420 = G(self145418,"left",L[42]);
var anf_fun84415 = G(anf_bracket83420,"map",L[41]);
var $z407408 = D;
var $f413414 = function(_) {
return R.isFunction(anf_fun84415)?anf_fun84415.app(f146416):R.ffi.throwNonFunApp(L[40],anf_fun84415,[f146416]);
};
try {
if(--R.GAS > 0) {
$z407408 = $f413414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f413414,
"from":L[40]});
}
} catch($e405406) {
if(R.isCont($e405406)) {
var $ss409410 = {"from":L[40],
"go":function(anf_arg85417) {
return $Hanf_arg1646419(anf_arg85417,concat_DASH_append126158,f146416,self145418);
}};
$e405406.stack[R.EXN_STACKHEIGHT++] = $ss409410;
}
if(R.isPyretException($e405406)) {
$e405406.pyretStack.push(L[40]);
}
throw $e405406;
}
var $ret411412 = $Hanf_arg1646419($z407408,concat_DASH_append126158,f146416,self145418);
++R.GAS;
return $ret411412;
};
},{"length":2});
var anf_variant_member102218 = R.makeMethod(function(self20383) {
return function(cases_DASH_funs21384,else_DASH_clause22395) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[6],2,arguments);
}
var if_DASH_24398 = R.hasField(cases_DASH_funs21384,("concat-cons"));
var if_helper91381 = R.makeFunction(function(if_helper_arg92403) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
var ann_DASH_check_DASH_temp90404 = if_helper_arg92403;
return ann_DASH_check_DASH_temp90404;
});
var anf_if95402 = R.isBoolean(if_DASH_24398);
if(R.isPyretTrue(anf_if95402)) {
if(R.isPyretTrue(if_DASH_24398)) {
var call_DASH_concat_DASH_cons19377 = G(cases_DASH_funs21384,"concat-cons",L[6]);
var anf_arg98378 = G(self20383,"first",L[39]);
var anf_arg99379 = G(self20383,"rest",L[38]);
var $z369370 = D;
var $f375376 = function(_) {
return R.isFunction(call_DASH_concat_DASH_cons19377)?call_DASH_concat_DASH_cons19377.app(anf_arg98378,anf_arg99379):R.ffi.throwNonFunApp(L[6],call_DASH_concat_DASH_cons19377,[anf_arg98378,anf_arg99379]);
};
try {
if(--R.GAS > 0) {
$z369370 = $f375376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f375376,
"from":L[6]});
}
} catch($e367368) {
if(R.isCont($e367368)) {
var $ss371372 = {"from":L[6],
"go":function(cont_tail_arg100380) {
return $Hcont_tail_arg1647382(cont_tail_arg100380,if_helper91381);
}};
$e367368.stack[R.EXN_STACKHEIGHT++] = $ss371372;
}
if(R.isPyretException($e367368)) {
$e367368.pyretStack.push(L[6]);
}
throw $e367368;
}
var $ret373374 = $Hcont_tail_arg1647382($z369370,if_helper91381);
++R.GAS;
return $ret373374;
} else {
var $z387388 = D;
var $f393394 = function(_) {
return R.isFunction(else_DASH_clause22395)?else_DASH_clause22395.app():R.ffi.throwNonFunApp(L[6],else_DASH_clause22395,[]);
};
try {
if(--R.GAS > 0) {
$z387388 = $f393394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f393394,
"from":L[6]});
}
} catch($e385386) {
if(R.isCont($e385386)) {
var $ss389390 = {"from":L[6],
"go":function(cont_tail_arg96396) {
return $Hcont_tail_arg1648397(cont_tail_arg96396,if_helper91381);
}};
$e385386.stack[R.EXN_STACKHEIGHT++] = $ss389390;
}
if(R.isPyretException($e385386)) {
$e385386.pyretStack.push(L[6]);
}
throw $e385386;
}
var $ret391392 = $Hcont_tail_arg1648397($z387388,if_helper91381);
++R.GAS;
return $ret391392;
}
} else {
var cont_tail_arg93401 = R.throwNonBooleanCondition(L[6],("if"),if_DASH_24398);
if(--R.GAS > 0) {
$z399400 = R.isFunction(if_helper91381)?if_helper91381.app(cont_tail_arg93401):R.ffi.throwNonFunApp(L[6],if_helper91381,[cont_tail_arg93401]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper91381)?if_helper91381.app(cont_tail_arg93401):R.ffi.throwNonFunApp(L[6],if_helper91381,[cont_tail_arg93401]);
},
"from":L[6]});
}
++R.GAS;
return $z399400;
}
};
},{"length":3});
var anf_variant_member112219 = R.makeMethod(function(self23365) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[6],0,arguments);
}
var anf_arg104363 = G(self23365,"first",L[6]);
var $z355356 = D;
var $f361362 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg104363):R.ffi.throwNonFunApp(L[6],torepr13,[anf_arg104363]);
};
try {
if(--R.GAS > 0) {
$z355356 = $f361362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f361362,
"from":L[6]});
}
} catch($e353354) {
if(R.isCont($e353354)) {
var $ss357358 = {"from":L[6],
"go":function(anf_arg105364) {
return $Hanf_arg1655366(anf_arg105364,self23365,_plus5,torepr13);
}};
$e353354.stack[R.EXN_STACKHEIGHT++] = $ss357358;
}
if(R.isPyretException($e353354)) {
$e353354.pyretStack.push(L[6]);
}
throw $e353354;
}
var $ret359360 = $Hanf_arg1655366($z355356,self23365,_plus5,torepr13);
++R.GAS;
return $ret359360;
};
},{"length":1});
var anf_variant_member118220 = R.makeMethod(function(self149352) {
return function(rest150347) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[37],1,arguments);
}
var anf_arg114349 = G(self149352,"first",L[36]);
var anf_bracket115351 = G(self149352,"rest",L[35]);
var anf_fun116346 = G(anf_bracket115351,"to-list-acc",L[34]);
var $z338339 = D;
var $f344345 = function(_) {
return R.isFunction(anf_fun116346)?anf_fun116346.app(rest150347):R.ffi.throwNonFunApp(L[33],anf_fun116346,[rest150347]);
};
try {
if(--R.GAS > 0) {
$z338339 = $f344345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f344345,
"from":L[33]});
}
} catch($e336337) {
if(R.isCont($e336337)) {
var $ss340341 = {"from":L[33],
"go":function(anf_arg117348) {
return $Hanf_arg1657350(anf_arg117348,anf_arg114349,link39100);
}};
$e336337.stack[R.EXN_STACKHEIGHT++] = $ss340341;
}
if(R.isPyretException($e336337)) {
$e336337.pyretStack.push(L[33]);
}
throw $e336337;
}
var $ret342343 = $Hanf_arg1657350($z338339,anf_arg114349,link39100);
++R.GAS;
return $ret342343;
};
},{"length":2});
var anf_variant_member125221 = R.makeMethod(function(self151334) {
return function(f152331) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[32],1,arguments);
}
var anf_arg120332 = G(self151334,"first",L[31]);
var $z323324 = D;
var $f329330 = function(_) {
return R.isFunction(f152331)?f152331.app(anf_arg120332):R.ffi.throwNonFunApp(L[30],f152331,[anf_arg120332]);
};
try {
if(--R.GAS > 0) {
$z323324 = $f329330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f329330,
"from":L[30]});
}
} catch($e321322) {
if(R.isCont($e321322)) {
var $ss325326 = {"from":L[30],
"go":function(anf_arg121333) {
return $Hanf_arg1660335(anf_arg121333,concat_DASH_cons128162,f152331,self151334);
}};
$e321322.stack[R.EXN_STACKHEIGHT++] = $ss325326;
}
if(R.isPyretException($e321322)) {
$e321322.pyretStack.push(L[30]);
}
throw $e321322;
}
var $ret327328 = $Hanf_arg1660335($z323324,concat_DASH_cons128162,f152331,self151334);
++R.GAS;
return $ret327328;
};
},{"length":2});
var anf_variant_member138229 = R.makeMethod(function(self26298) {
return function(cases_DASH_funs27299,else_DASH_clause28310) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[5],2,arguments);
}
var if_DASH_30313 = R.hasField(cases_DASH_funs27299,("concat-snoc"));
var if_helper127296 = R.makeFunction(function(if_helper_arg128319) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[5],1,arguments);
}
var ann_DASH_check_DASH_temp126320 = if_helper_arg128319;
return ann_DASH_check_DASH_temp126320;
});
var anf_if131318 = R.isBoolean(if_DASH_30313);
if(R.isPyretTrue(anf_if131318)) {
if(R.isPyretTrue(if_DASH_30313)) {
var call_DASH_concat_DASH_snoc25292 = G(cases_DASH_funs27299,"concat-snoc",L[5]);
var anf_arg134293 = G(self26298,"head",L[29]);
var anf_arg135294 = G(self26298,"last",L[28]);
var $z284285 = D;
var $f290291 = function(_) {
return R.isFunction(call_DASH_concat_DASH_snoc25292)?call_DASH_concat_DASH_snoc25292.app(anf_arg134293,anf_arg135294):R.ffi.throwNonFunApp(L[5],call_DASH_concat_DASH_snoc25292,[anf_arg134293,anf_arg135294]);
};
try {
if(--R.GAS > 0) {
$z284285 = $f290291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f290291,
"from":L[5]});
}
} catch($e282283) {
if(R.isCont($e282283)) {
var $ss286287 = {"from":L[5],
"go":function(cont_tail_arg136295) {
return $Hcont_tail_arg1661297(cont_tail_arg136295,if_helper127296);
}};
$e282283.stack[R.EXN_STACKHEIGHT++] = $ss286287;
}
if(R.isPyretException($e282283)) {
$e282283.pyretStack.push(L[5]);
}
throw $e282283;
}
var $ret288289 = $Hcont_tail_arg1661297($z284285,if_helper127296);
++R.GAS;
return $ret288289;
} else {
var $z302303 = D;
var $f308309 = function(_) {
return R.isFunction(else_DASH_clause28310)?else_DASH_clause28310.app():R.ffi.throwNonFunApp(L[5],else_DASH_clause28310,[]);
};
try {
if(--R.GAS > 0) {
$z302303 = $f308309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f308309,
"from":L[5]});
}
} catch($e300301) {
if(R.isCont($e300301)) {
var $ss304305 = {"from":L[5],
"go":function(cont_tail_arg132311) {
return $Hcont_tail_arg1662312(cont_tail_arg132311,if_helper127296);
}};
$e300301.stack[R.EXN_STACKHEIGHT++] = $ss304305;
}
if(R.isPyretException($e300301)) {
$e300301.pyretStack.push(L[5]);
}
throw $e300301;
}
var $ret306307 = $Hcont_tail_arg1662312($z302303,if_helper127296);
++R.GAS;
return $ret306307;
}
} else {
var cont_tail_arg129316 = R.throwNonBooleanCondition(L[5],("if"),if_DASH_30313);
if(--R.GAS > 0) {
$z314315 = R.isFunction(if_helper127296)?if_helper127296.app(cont_tail_arg129316):R.ffi.throwNonFunApp(L[5],if_helper127296,[cont_tail_arg129316]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper127296)?if_helper127296.app(cont_tail_arg129316):R.ffi.throwNonFunApp(L[5],if_helper127296,[cont_tail_arg129316]);
},
"from":L[5]});
}
++R.GAS;
return $z314315;
}
};
},{"length":3});
var anf_variant_member148230 = R.makeMethod(function(self29280) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[5],0,arguments);
}
var anf_arg140278 = G(self29280,"head",L[5]);
var $z270271 = D;
var $f276277 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg140278):R.ffi.throwNonFunApp(L[5],torepr13,[anf_arg140278]);
};
try {
if(--R.GAS > 0) {
$z270271 = $f276277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f276277,
"from":L[5]});
}
} catch($e268269) {
if(R.isCont($e268269)) {
var $ss272273 = {"from":L[5],
"go":function(anf_arg141279) {
return $Hanf_arg1669281(anf_arg141279,self29280,_plus5,torepr13);
}};
$e268269.stack[R.EXN_STACKHEIGHT++] = $ss272273;
}
if(R.isPyretException($e268269)) {
$e268269.pyretStack.push(L[5]);
}
throw $e268269;
}
var $ret274275 = $Hanf_arg1669281($z270271,self29280,_plus5,torepr13);
++R.GAS;
return $ret274275;
};
},{"length":1});
var anf_variant_member154231 = R.makeMethod(function(self155266) {
return function(rest156262) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[27],1,arguments);
}
var anf_bracket150267 = G(self155266,"head",L[26]);
var anf_fun151264 = G(anf_bracket150267,"to-list-acc",L[25]);
var anf_arg152261 = G(self155266,"last",L[24]);
var $z253254 = D;
var $f259260 = function(_) {
return R.isFunction(link39100)?link39100.app(anf_arg152261,rest156262):R.ffi.throwNonFunApp(L[23],link39100,[anf_arg152261,rest156262]);
};
try {
if(--R.GAS > 0) {
$z253254 = $f259260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f259260,
"from":L[23]});
}
} catch($e251252) {
if(R.isCont($e251252)) {
var $ss255256 = {"from":L[23],
"go":function(anf_arg153263) {
return $Hanf_arg1671265(anf_arg153263,anf_fun151264);
}};
$e251252.stack[R.EXN_STACKHEIGHT++] = $ss255256;
}
if(R.isPyretException($e251252)) {
$e251252.pyretStack.push(L[23]);
}
throw $e251252;
}
var $ret257258 = $Hanf_arg1671265($z253254,anf_fun151264);
++R.GAS;
return $ret257258;
};
},{"length":2});
var anf_variant_member161232 = R.makeMethod(function(self157248) {
return function(f158246) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
var anf_bracket156250 = G(self157248,"head",L[21]);
var anf_fun157245 = G(anf_bracket156250,"map",L[20]);
var $z237238 = D;
var $f243244 = function(_) {
return R.isFunction(anf_fun157245)?anf_fun157245.app(f158246):R.ffi.throwNonFunApp(L[19],anf_fun157245,[f158246]);
};
try {
if(--R.GAS > 0) {
$z237238 = $f243244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f243244,
"from":L[19]});
}
} catch($e235236) {
if(R.isCont($e235236)) {
var $ss239240 = {"from":L[19],
"go":function(anf_arg158247) {
return $Hanf_arg1674249(anf_arg158247,concat_DASH_snoc130166,f158246,self157248);
}};
$e235236.stack[R.EXN_STACKHEIGHT++] = $ss239240;
}
if(R.isPyretException($e235236)) {
$e235236.pyretStack.push(L[19]);
}
throw $e235236;
}
var $ret241242 = $Hanf_arg1674249($z237238,concat_DASH_snoc130166,f158246,self157248);
++R.GAS;
return $ret241242;
};
},{"length":2});
var anf_assign162143 = (function() {
var $concat_DASH_empty_DASH_base183184 = {"_plus":anf_shared4181,
"to-list":anf_shared9182,
"_match":anf_singleton_variant_member20188,
"_torepr":anf_singleton_variant_member22189,
"to-list-acc":anf_singleton_variant_member24190,
"map":anf_singleton_variant_member26191};
var $concat_DASH_empty_DASH_brands186187 = {"$brand-concat-empty185":true};
$concat_DASH_empty_DASH_brands186187[ConcatListT27761._brand] = true
var $concat_DASH_singleton_DASH_base192193 = {"_plus":anf_shared4181,
"to-list":anf_shared9182,
"_match":anf_variant_member38197,
"_torepr":anf_variant_member44198,
"to-list-acc":anf_variant_member47199,
"map":anf_variant_member51200};
var $concat_DASH_singleton_DASH_brands195196 = {"$brand-concat-singleton194":true};
$concat_DASH_singleton_DASH_brands195196[ConcatListT27761._brand] = true
var $concat_DASH_append_DASH_base202203 = {"_plus":anf_shared4181,
"to-list":anf_shared9182,
"_match":anf_variant_member64207,
"_torepr":anf_variant_member74208,
"to-list-acc":anf_variant_member81209,
"map":anf_variant_member89210};
var $concat_DASH_append_DASH_brands205206 = {"$brand-concat-append204":true};
$concat_DASH_append_DASH_brands205206[ConcatListT27761._brand] = true
var $concat_DASH_cons_DASH_base213214 = {"_plus":anf_shared4181,
"to-list":anf_shared9182,
"_match":anf_variant_member102218,
"_torepr":anf_variant_member112219,
"to-list-acc":anf_variant_member118220,
"map":anf_variant_member125221};
var $concat_DASH_cons_DASH_brands216217 = {"$brand-concat-cons215":true};
$concat_DASH_cons_DASH_brands216217[ConcatListT27761._brand] = true
var $concat_DASH_snoc_DASH_base224225 = {"_plus":anf_shared4181,
"to-list":anf_shared9182,
"_match":anf_variant_member138229,
"_torepr":anf_variant_member148230,
"to-list-acc":anf_variant_member154231,
"map":anf_variant_member161232};
var $concat_DASH_snoc_DASH_brands227228 = {"$brand-concat-snoc226":true};
$concat_DASH_snoc_DASH_brands227228[ConcatListT27761._brand] = true
return R.makeObject({"ConcatList":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[10],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ConcatListT27761._brand));
}),
"is-concat-empty":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[9],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat-empty185"));
}),
"concat-empty":R.makeBrandedObject($concat_DASH_empty_DASH_base183184,$concat_DASH_empty_DASH_brands186187),
"is-concat-singleton":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[8],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat-singleton194"));
}),
"concat-singleton":R.makeFunction(function(element136201) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[11],1,arguments);
}
var dict = R.create($concat_DASH_singleton_DASH_base192193);
dict["element"] = element136201
return R.makeBrandedObject(dict,$concat_DASH_singleton_DASH_brands195196);
}),
"is-concat-append":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat-append204"));
}),
"concat-append":R.makeFunction(function(left141211,right142212) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[12],2,arguments);
}
return R.checkAnnArgs([ConcatList7660,ConcatList7660],[left141211,right142212],[L[13],L[14]],function() {
var dict = R.create($concat_DASH_append_DASH_base202203);
dict["left"] = left141211
dict["right"] = right142212
return R.makeBrandedObject(dict,$concat_DASH_append_DASH_brands205206);
});
}),
"is-concat-cons":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat-cons215"));
}),
"concat-cons":R.makeFunction(function(first147222,rest148223) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[15],2,arguments);
}
return R.checkAnnArgs([ConcatList7660],[rest148223],[L[16]],function() {
var dict = R.create($concat_DASH_cons_DASH_base213214);
dict["first"] = first147222
dict["rest"] = rest148223
return R.makeBrandedObject(dict,$concat_DASH_cons_DASH_brands216217);
});
}),
"is-concat-snoc":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[5],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-concat-snoc226"));
}),
"concat-snoc":R.makeFunction(function(head153233,last154234) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[17],2,arguments);
}
return R.checkAnnArgs([ConcatList7660],[head153233],[L[18]],function() {
var dict = R.create($concat_DASH_snoc_DASH_base224225);
dict["head"] = head153233
dict["last"] = last154234
return R.makeBrandedObject(dict,$concat_DASH_snoc_DASH_brands227228);
});
})});
})();
ConcatList3118142.$var = anf_assign162143;
var anf_assign163145 = G(ConcatList3118142.$var,"ConcatList",L[10]);
ConcatList119144.$var = anf_assign163145;
var anf_assign164147 = G(ConcatList3118142.$var,"ConcatList",L[10]);
is_DASH_ConcatList120146.$var = anf_assign164147;
var anf_assign165149 = G(ConcatList3118142.$var,"is-concat-empty",L[9]);
is_DASH_concat_DASH_empty121148.$var = anf_assign165149;
var anf_assign166151 = G(ConcatList3118142.$var,"concat-empty",L[9]);
concat_DASH_empty122150.$var = anf_assign166151;
var anf_assign167153 = G(ConcatList3118142.$var,"is-concat-singleton",L[8]);
is_DASH_concat_DASH_singleton123152.$var = anf_assign167153;
var anf_assign168155 = G(ConcatList3118142.$var,"concat-singleton",L[8]);
concat_DASH_singleton124154.$var = anf_assign168155;
var anf_assign169157 = G(ConcatList3118142.$var,"is-concat-append",L[7]);
is_DASH_concat_DASH_append125156.$var = anf_assign169157;
var anf_assign170159 = G(ConcatList3118142.$var,"concat-append",L[7]);
concat_DASH_append126158.$var = anf_assign170159;
var anf_assign171161 = G(ConcatList3118142.$var,"is-concat-cons",L[6]);
is_DASH_concat_DASH_cons127160.$var = anf_assign171161;
var anf_assign172163 = G(ConcatList3118142.$var,"concat-cons",L[6]);
concat_DASH_cons128162.$var = anf_assign172163;
var anf_assign173165 = G(ConcatList3118142.$var,"is-concat-snoc",L[5]);
is_DASH_concat_DASH_snoc129164.$var = anf_assign173165;
var anf_assign174167 = G(ConcatList3118142.$var,"concat-snoc",L[5]);
concat_DASH_snoc130166.$var = anf_assign174167;
var anf_fun175178 = G(D1324,"string-dict",L[4]);
var $z170171 = D;
var $f176177 = function(_) {
return R.isFunction(anf_fun175178)?anf_fun175178.app():R.ffi.throwNonFunApp(L[3],anf_fun175178,[]);
};
try {
if(--R.GAS > 0) {
$z170171 = $f176177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f176177,
"from":L[3]});
}
} catch($e168169) {
if(R.isCont($e168169)) {
var $ss172173 = {"from":L[3],
"go":function(var_DASH_bind1675179) {
return $Hvar_DASH_bind2535180(var_DASH_bind1675179,A118,A231,ConcatList119144,ConcatList7660,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,source_DASH_name116128,throw_DASH_uninitialized115116,type_DASH_name79105,undefined117140,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
}};
$e168169.stack[R.EXN_STACKHEIGHT++] = $ss172173;
}
if(R.isPyretException($e168169)) {
$e168169.pyretStack.push(L[3]);
}
throw $e168169;
}
var $ret174175 = $Hvar_DASH_bind2535180($z170171,A118,A231,ConcatList119144,ConcatList7660,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,source_DASH_name116128,throw_DASH_uninitialized115116,type_DASH_name79105,undefined117140,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
++R.GAS;
return $ret174175;
};
var $Hvar_DASH_bind2535180 = function(var_DASH_bind1675179,A118,A231,ConcatList119144,ConcatList7660,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,filter4264,fold6365,get_DASH_field_DASH_loc11459,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,source_DASH_name116128,throw_DASH_uninitialized115116,type_DASH_name79105,undefined117140,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17) {
var js_DASH_ids1632074 = {"$var":var_DASH_bind1675179,
"$name":"js-ids"};
var js_DASH_id_DASH_of162700 = R.makeFunction(function(id1642062) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[345],1,arguments);
}
return R.checkAnnArgs([$type$String17],[id1642062],[L[347]],function() {
var $z20652066 = D;
var $f20712072 = function(_) {
return R.isFunction(is_DASH_string7)?is_DASH_string7.app(id1642062):R.ffi.throwNonFunApp(L[346],is_DASH_string7,[id1642062]);
};
try {
if(--R.GAS > 0) {
$z20652066 = $f20712072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20712072,
"from":L[346]});
}
} catch($e20632064) {
if(R.isCont($e20632064)) {
var $ss20672068 = {"from":L[346],
"go":function(anf_arg1772073) {
return $Hanf_arg16902075(anf_arg1772073,G922,id1642062,js_DASH_ids1632074,_plus5,not8,nothing9,raise11,string_DASH_replace12,torepr13);
}};
$e20632064.stack[R.EXN_STACKHEIGHT++] = $ss20672068;
}
if(R.isPyretException($e20632064)) {
$e20632064.pyretStack.push(L[346]);
}
throw $e20632064;
}
var $ret20692070 = $Hanf_arg16902075($z20652066,G922,id1642062,js_DASH_ids1632074,_plus5,not8,nothing9,raise11,string_DASH_replace12,torepr13);
++R.GAS;
return $ret20692070;
});
});
var compiler_DASH_name167645 = {"$var":D,
"$name":"compiler-name"};
var obj_DASH_of_DASH_loc168647 = {"$var":D,
"$name":"obj-of-loc"};
var get_DASH_field169649 = {"$var":D,
"$name":"get-field"};
var raise_DASH_id_DASH_exn170651 = {"$var":D,
"$name":"raise-id-exn"};
var add_DASH_stack_DASH_frame171653 = {"$var":D,
"$name":"add-stack-frame"};
var rt_DASH_field172655 = {"$var":D,
"$name":"rt-field"};
var rt_DASH_method173657 = {"$var":D,
"$name":"rt-method"};
var app174659 = {"$var":D,
"$name":"app"};
var thunk_DASH_app175661 = {"$var":D,
"$name":"thunk-app"};
var thunk_DASH_app_DASH_stmt176663 = {"$var":D,
"$name":"thunk-app-stmt"};
var helper_DASH_name177665 = {"$var":D,
"$name":"helper-name"};
var compile_DASH_helper178667 = {"$var":D,
"$name":"compile-helper"};
var compile_DASH_tail_DASH_app179669 = {"$var":D,
"$name":"compile-tail-app"};
var compile_DASH_split_DASH_app180671 = {"$var":D,
"$name":"compile-split-app"};
var compile_DASH_ann181673 = {"$var":D,
"$name":"compile-ann"};
var arity_DASH_check182675 = {"$var":D,
"$name":"arity-check"};
var contract_DASH_checks183677 = {"$var":D,
"$name":"contract-checks"};
var anf_assign202646 = R.makeFunction(function(id1842048) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[342],1,arguments);
}
var anf_fun2002060 = G(G922,"make-name",L[344]);
var $z20512052 = D;
var $f20572058 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("$"),id1842048):R.ffi.throwNonFunApp(L[343],_plus5,[("$"),id1842048]);
};
try {
if(--R.GAS > 0) {
$z20512052 = $f20572058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20572058,
"from":L[343]});
}
} catch($e20492050) {
if(R.isCont($e20492050)) {
var $ss20532054 = {"from":L[343],
"go":function(anf_arg2012059) {
return $Hanf_arg16922061(anf_arg2012059,anf_fun2002060);
}};
$e20492050.stack[R.EXN_STACKHEIGHT++] = $ss20532054;
}
if(R.isPyretException($e20492050)) {
$e20492050.pyretStack.push(L[343]);
}
throw $e20492050;
}
var $ret20552056 = $Hanf_arg16922061($z20512052,anf_fun2002060);
++R.GAS;
return $ret20552056;
});
compiler_DASH_name167645.$var = anf_assign202646;
var anf_assign219648 = R.makeFunction(function(l1852034) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[339],1,arguments);
}
var anf_fun2042046 = G(list35101,"make",L[341]);
var $z20372038 = D;
var $f20432044 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("M")):R.ffi.throwNonFunApp(L[340],j_DASH_id8381,[("M")]);
};
try {
if(--R.GAS > 0) {
$z20372038 = $f20432044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20432044,
"from":L[340]});
}
} catch($e20352036) {
if(R.isCont($e20352036)) {
var $ss20392040 = {"from":L[340],
"go":function(anf_array_val2052045) {
return $Hanf_array_val17012047(anf_array_val2052045,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
}};
$e20352036.stack[R.EXN_STACKHEIGHT++] = $ss20392040;
}
if(R.isPyretException($e20352036)) {
$e20352036.pyretStack.push(L[340]);
}
throw $e20352036;
}
var $ret20412042 = $Hanf_array_val17012047($z20372038,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
++R.GAS;
return $ret20412042;
});
obj_DASH_of_DASH_loc168647.$var = anf_assign219648;
var anf_assign223650 = R.makeFunction(function(obj1862018,field1872019,loc1882020) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[337],3,arguments);
}
var anf_fun2212031 = G(list35101,"make",L[338]);
var $z20232024 = D;
var $f20292030 = function(_) {
return R.isFunction(anf_fun2212031)?anf_fun2212031.app([obj1862018,field1872019,loc1882020]):R.ffi.throwNonFunApp(L[338],anf_fun2212031,[[obj1862018,field1872019,loc1882020]]);
};
try {
if(--R.GAS > 0) {
$z20232024 = $f20292030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20292030,
"from":L[338]});
}
} catch($e20212022) {
if(R.isCont($e20212022)) {
var $ss20252026 = {"from":L[338],
"go":function(anf_arg2222032) {
return $Hanf_arg17032033(anf_arg2222032,get_DASH_field_DASH_loc11459,j_DASH_app9467);
}};
$e20212022.stack[R.EXN_STACKHEIGHT++] = $ss20252026;
}
if(R.isPyretException($e20212022)) {
$e20212022.pyretStack.push(L[338]);
}
throw $e20212022;
}
var $ret20272028 = $Hanf_arg17032033($z20232024,get_DASH_field_DASH_loc11459,j_DASH_app9467);
++R.GAS;
return $ret20272028;
});
get_DASH_field169649.$var = anf_assign223650;
var anf_assign228652 = R.makeFunction(function(loc1892003,name1902004) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[334],2,arguments);
}
var anf_fun2252016 = G(list35101,"make",L[336]);
var $z20072008 = D;
var $f20132014 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(name1902004):R.ffi.throwNonFunApp(L[335],j_DASH_str8993,[name1902004]);
};
try {
if(--R.GAS > 0) {
$z20072008 = $f20132014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20132014,
"from":L[335]});
}
} catch($e20052006) {
if(R.isCont($e20052006)) {
var $ss20092010 = {"from":L[335],
"go":function(anf_array_val2262015) {
return $Hanf_array_val17062017(anf_array_val2262015,anf_fun2252016,j_DASH_app9467,loc1892003,throw_DASH_uninitialized115116);
}};
$e20052006.stack[R.EXN_STACKHEIGHT++] = $ss20092010;
}
if(R.isPyretException($e20052006)) {
$e20052006.pyretStack.push(L[335]);
}
throw $e20052006;
}
var $ret20112012 = $Hanf_array_val17062017($z20072008,anf_fun2252016,j_DASH_app9467,loc1892003,throw_DASH_uninitialized115116);
++R.GAS;
return $ret20112012;
});
raise_DASH_id_DASH_exn170651.$var = anf_assign228652;
var anf_assign234654 = R.makeFunction(function(exn_DASH_id1911989,loc1921990) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[332],2,arguments);
}
var $z19931994 = D;
var $f19992000 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(exn_DASH_id1911989):R.ffi.throwNonFunApp(L[333],j_DASH_id8381,[exn_DASH_id1911989]);
};
try {
if(--R.GAS > 0) {
$z19931994 = $f19992000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19992000,
"from":L[333]});
}
} catch($e19911992) {
if(R.isCont($e19911992)) {
var $ss19951996 = {"from":L[333],
"go":function(anf_arg2302001) {
return $Hanf_arg17102002(anf_arg2302001,j_DASH_dot9775,j_DASH_method8486,list35101,loc1921990);
}};
$e19911992.stack[R.EXN_STACKHEIGHT++] = $ss19951996;
}
if(R.isPyretException($e19911992)) {
$e19911992.pyretStack.push(L[333]);
}
throw $e19911992;
}
var $ret19971998 = $Hanf_arg17102002($z19931994,j_DASH_dot9775,j_DASH_method8486,list35101,loc1921990);
++R.GAS;
return $ret19971998;
});
add_DASH_stack_DASH_frame171653.$var = anf_assign234654;
var anf_assign237656 = R.makeFunction(function(name1931976) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[330],1,arguments);
}
var $z19791980 = D;
var $f19851986 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("R")):R.ffi.throwNonFunApp(L[331],j_DASH_id8381,[("R")]);
};
try {
if(--R.GAS > 0) {
$z19791980 = $f19851986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19851986,
"from":L[331]});
}
} catch($e19771978) {
if(R.isCont($e19771978)) {
var $ss19811982 = {"from":L[331],
"go":function(anf_arg2361987) {
return $Hanf_arg17121988(anf_arg2361987,j_DASH_dot9775,name1931976);
}};
$e19771978.stack[R.EXN_STACKHEIGHT++] = $ss19811982;
}
if(R.isPyretException($e19771978)) {
$e19771978.pyretStack.push(L[331]);
}
throw $e19771978;
}
var $ret19831984 = $Hanf_arg17121988($z19791980,j_DASH_dot9775,name1931976);
++R.GAS;
return $ret19831984;
});
rt_DASH_field172655.$var = anf_assign237656;
var anf_assign240658 = R.makeFunction(function(name1941962,args1951963) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[328],2,arguments);
}
var $z19661967 = D;
var $f19721973 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("R")):R.ffi.throwNonFunApp(L[329],j_DASH_id8381,[("R")]);
};
try {
if(--R.GAS > 0) {
$z19661967 = $f19721973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19721973,
"from":L[329]});
}
} catch($e19641965) {
if(R.isCont($e19641965)) {
var $ss19681969 = {"from":L[329],
"go":function(anf_arg2391974) {
return $Hanf_arg17141975(anf_arg2391974,args1951963,j_DASH_method8486,name1941962);
}};
$e19641965.stack[R.EXN_STACKHEIGHT++] = $ss19681969;
}
if(R.isPyretException($e19641965)) {
$e19641965.pyretStack.push(L[329]);
}
throw $e19641965;
}
var $ret19701971 = $Hanf_arg17141975($z19661967,args1951963,j_DASH_method8486,name1941962);
++R.GAS;
return $ret19701971;
});
rt_DASH_method173657.$var = anf_assign240658;
var anf_assign251660 = R.makeFunction(function(l1961946,f1971947,args1981948) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[326],3,arguments);
}
var anf_fun2421959 = G(list35101,"make",L[327]);
var $z19511952 = D;
var $f19571958 = function(_) {
return R.isFunction(anf_fun2421959)?anf_fun2421959.app([f1971947]):R.ffi.throwNonFunApp(L[327],anf_fun2421959,[[f1971947]]);
};
try {
if(--R.GAS > 0) {
$z19511952 = $f19571958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19571958,
"from":L[327]});
}
} catch($e19491950) {
if(R.isCont($e19491950)) {
var $ss19531954 = {"from":L[327],
"go":function(anf_arg2431960) {
return $Hanf_arg17221961(anf_arg2431960,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655,rt_DASH_method173657);
}};
$e19491950.stack[R.EXN_STACKHEIGHT++] = $ss19531954;
}
if(R.isPyretException($e19491950)) {
$e19491950.pyretStack.push(L[327]);
}
throw $e19491950;
}
var $ret19551956 = $Hanf_arg17221961($z19511952,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655,rt_DASH_method173657);
++R.GAS;
return $ret19551956;
});
app174659.$var = anf_assign251660;
var anf_assign259662 = R.makeFunction(function(block1991932) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[324],1,arguments);
}
var anf_fun2531943 = G(list35101,"make",L[325]);
var $z19351936 = D;
var $f19411942 = function(_) {
return R.isFunction(anf_fun2531943)?anf_fun2531943.app([]):R.ffi.throwNonFunApp(L[325],anf_fun2531943,[[]]);
};
try {
if(--R.GAS > 0) {
$z19351936 = $f19411942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19411942,
"from":L[325]});
}
} catch($e19331934) {
if(R.isCont($e19331934)) {
var $ss19371938 = {"from":L[325],
"go":function(anf_arg2541944) {
return $Hanf_arg17271945(anf_arg2541944,block1991932,j_DASH_app9467,j_DASH_fun8180,j_DASH_parens11391,list35101);
}};
$e19331934.stack[R.EXN_STACKHEIGHT++] = $ss19371938;
}
if(R.isPyretException($e19331934)) {
$e19331934.pyretStack.push(L[325]);
}
throw $e19331934;
}
var $ret19391940 = $Hanf_arg17271945($z19351936,block1991932,j_DASH_app9467,j_DASH_fun8180,j_DASH_parens11391,list35101);
++R.GAS;
return $ret19391940;
});
thunk_DASH_app175661.$var = anf_assign259662;
var anf_assign264664 = R.makeFunction(function(stmt2001918) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[322],1,arguments);
}
var anf_fun2611929 = G(list35101,"make",L[323]);
var $z19211922 = D;
var $f19271928 = function(_) {
return R.isFunction(anf_fun2611929)?anf_fun2611929.app([stmt2001918]):R.ffi.throwNonFunApp(L[323],anf_fun2611929,[[stmt2001918]]);
};
try {
if(--R.GAS > 0) {
$z19211922 = $f19271928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19271928,
"from":L[323]});
}
} catch($e19191920) {
if(R.isCont($e19191920)) {
var $ss19231924 = {"from":L[323],
"go":function(anf_arg2621930) {
return $Hanf_arg17301931(anf_arg2621930,j_DASH_block8570,thunk_DASH_app175661);
}};
$e19191920.stack[R.EXN_STACKHEIGHT++] = $ss19231924;
}
if(R.isPyretException($e19191920)) {
$e19191920.pyretStack.push(L[323]);
}
throw $e19191920;
}
var $ret19251926 = $Hanf_arg17301931($z19211922,j_DASH_block8570,thunk_DASH_app175661);
++R.GAS;
return $ret19251926;
});
thunk_DASH_app_DASH_stmt176663.$var = anf_assign264664;
var anf_assign269666 = R.makeFunction(function(s2011904) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[318],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[321],"A",A231,"Name")],[s2011904],[L[321]],function() {
var anf_fun2661915 = G(s2011904,"tostring",L[320]);
var $z19071908 = D;
var $f19131914 = function(_) {
return R.isFunction(anf_fun2661915)?anf_fun2661915.app():R.ffi.throwNonFunApp(L[319],anf_fun2661915,[]);
};
try {
if(--R.GAS > 0) {
$z19071908 = $f19131914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19131914,
"from":L[319]});
}
} catch($e19051906) {
if(R.isCont($e19051906)) {
var $ss19091910 = {"from":L[319],
"go":function(anf_arg2671916) {
return $Hanf_arg17331917(anf_arg2671916,js_DASH_id_DASH_of162700,_plus5);
}};
$e19051906.stack[R.EXN_STACKHEIGHT++] = $ss19091910;
}
if(R.isPyretException($e19051906)) {
$e19051906.pyretStack.push(L[319]);
}
throw $e19051906;
}
var $ret19111912 = $Hanf_arg17331917($z19071908,js_DASH_id_DASH_of162700,_plus5);
++R.GAS;
return $ret19111912;
});
});
helper_DASH_name177665.$var = anf_assign269666;
var anf_assign288668 = R.makeFunction(function(compiler2021869,h2031870) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[313],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[317],"S",S633,"Helper")],[h2031870],[L[317]],function() {
var cases_DASH_val341903 = h2031870;
var anf_fun2711881 = G(cases_DASH_val341903,"_match",L[314]);
var anf_obj2841887 = R.makeFunction(function(name2041888,args2051889,body2061890) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[315],3,arguments);
}
var $z18931894 = D;
var $f18991900 = function(_) {
return R.isFunction(helper_DASH_name177665.$var)?helper_DASH_name177665.$var.app(name2041888):R.ffi.throwNonFunApp(L[316],helper_DASH_name177665.$var,[name2041888]);
};
try {
if(--R.GAS > 0) {
$z18931894 = $f18991900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18991900,
"from":L[316]});
}
} catch($e18911892) {
if(R.isCont($e18911892)) {
var $ss18951896 = {"from":L[316],
"go":function(anf_arg2731901) {
return $Hanf_arg17401902(anf_arg2731901,args2051889,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299,js_DASH_id_DASH_of162700);
}};
$e18911892.stack[R.EXN_STACKHEIGHT++] = $ss18951896;
}
if(R.isPyretException($e18911892)) {
$e18911892.pyretStack.push(L[316]);
}
throw $e18911892;
}
var $ret18971898 = $Hanf_arg17401902($z18931894,args2051889,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299,js_DASH_id_DASH_of162700);
++R.GAS;
return $ret18971898;
});
var anf_arg2851882 = R.makeObject({"helper":anf_obj2841887});
var anf_arg2871883 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[314],0,arguments);
}
var ann_DASH_check_DASH_temp2861886 = R.throwNoBranchesMatched(L[314],("cases"));
return ann_DASH_check_DASH_temp2861886;
});
var $z18731874 = D;
var $f18791880 = function(_) {
return R.isFunction(anf_fun2711881)?anf_fun2711881.app(anf_arg2851882,anf_arg2871883):R.ffi.throwNonFunApp(L[313],anf_fun2711881,[anf_arg2851882,anf_arg2871883]);
};
try {
if(--R.GAS > 0) {
$z18731874 = $f18791880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18791880,
"from":L[313]});
}
} catch($e18711872) {
if(R.isCont($e18711872)) {
var $ss18751876 = {"from":L[313],
"go":function(ann_DASH_check_DASH_temp2701884) {
return $Hann_DASH_check_DASH_temp17411885(ann_DASH_check_DASH_temp2701884,J834);
}};
$e18711872.stack[R.EXN_STACKHEIGHT++] = $ss18751876;
}
if(R.isPyretException($e18711872)) {
$e18711872.pyretStack.push(L[313]);
}
throw $e18711872;
}
var $ret18771878 = $Hann_DASH_check_DASH_temp17411885($z18731874,J834);
++R.GAS;
return $ret18771878;
});
});
compile_DASH_helper178667.$var = anf_assign288668;
var anf_assign345670 = R.makeFunction(function(compiler2071853,l2081854,f2091855,args2101856) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[311],4,arguments);
}
var $z18591860 = D;
var $f18651866 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(("z")):R.ffi.throwNonFunApp(L[312],compiler_DASH_name167645.$var,[("z")]);
};
try {
if(--R.GAS > 0) {
$z18591860 = $f18651866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18651866,
"from":L[312]});
}
} catch($e18571858) {
if(R.isCont($e18571858)) {
var $ss18611862 = {"from":L[312],
"go":function(anf_arg2901867) {
return $Hanf_arg17861868(anf_arg2901867,J721,app174659,args2101856,compiler2071853,f2091855,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657);
}};
$e18571858.stack[R.EXN_STACKHEIGHT++] = $ss18611862;
}
if(R.isPyretException($e18571858)) {
$e18571858.pyretStack.push(L[312]);
}
throw $e18571858;
}
var $ret18631864 = $Hanf_arg17861868($z18591860,J721,app174659,args2101856,compiler2071853,f2091855,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657);
++R.GAS;
return $ret18631864;
});
compile_DASH_tail_DASH_app179669.$var = anf_assign345670;
var anf_assign507672 = R.makeFunction(function(compiler2151803,l2161804,is_DASH_var2171805,f2181806,args2191807,name2201808,helper_DASH_args2211809) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[300],7,arguments);
}
return R.checkAnnArgs([Loc7863,$type$Boolean15,R.getDotAnn(L[305],"N",N432,"AVal"),List2762,R.getDotAnn(L[306],"A",A231,"Name"),List2762],[l2161804,is_DASH_var2171805,f2181806,args2191807,name2201808,helper_DASH_args2211809],[L[307],L[308],L[305],L[309],L[306],L[310]],function() {
var when_DASH_361835 = is_DASH_var2171805;
var if_helper3471821 = R.makeFunction(function(if_helper_arg3481840) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[302],1,arguments);
}
if_helper_arg3481840;
var $z18431844 = D;
var $f18491850 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(("e")):R.ffi.throwNonFunApp(L[304],compiler_DASH_name167645.$var,[("e")]);
};
try {
if(--R.GAS > 0) {
$z18431844 = $f18491850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18491850,
"from":L[304]});
}
} catch($e18411842) {
if(R.isCont($e18411842)) {
var $ss18451846 = {"from":L[304],
"go":function(anf_arg3491851) {
return $Hanf_arg19041852(anf_arg3491851,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5);
}};
$e18411842.stack[R.EXN_STACKHEIGHT++] = $ss18451846;
}
if(R.isPyretException($e18411842)) {
$e18411842.pyretStack.push(L[304]);
}
throw $e18411842;
}
var $ret18471848 = $Hanf_arg19041852($z18431844,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5);
++R.GAS;
return $ret18471848;
});
var anf_if5041839 = R.isBoolean(when_DASH_361835);
if(R.isPyretTrue(anf_if5041839)) {
if(R.isPyretTrue(when_DASH_361835)) {
var $z18121813 = D;
var $f18181819 = function(_) {
return R.isFunction(raise11)?raise11.app(("Can't handle splitting on a var yet")):R.ffi.throwNonFunApp(L[301],raise11,[("Can't handle splitting on a var yet")]);
};
try {
if(--R.GAS > 0) {
$z18121813 = $f18181819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18181819,
"from":L[301]});
}
} catch($e18101811) {
if(R.isCont($e18101811)) {
var $ss18141815 = {"from":L[301],
"go":function(anf_begin_app_dropped19051820) {
return $Hanf_begin_app_dropped19071822(anf_begin_app_dropped19051820,if_helper3471821,nothing9);
}};
$e18101811.stack[R.EXN_STACKHEIGHT++] = $ss18141815;
}
if(R.isPyretException($e18101811)) {
$e18101811.pyretStack.push(L[301]);
}
throw $e18101811;
}
var $ret18161817 = $Hanf_begin_app_dropped19071822($z18121813,if_helper3471821,nothing9);
++R.GAS;
return $ret18161817;
} else {
var $z18251826 = D;
var $f18311832 = function(_) {
return R.isFunction(if_helper3471821)?if_helper3471821.app(nothing9):R.ffi.throwNonFunApp(L[302],if_helper3471821,[nothing9]);
};
try {
if(--R.GAS > 0) {
$z18251826 = $f18311832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18311832,
"from":L[302]});
}
} catch($e18231824) {
if(R.isCont($e18231824)) {
var $ss18271828 = {"from":L[302],
"go":function(cont_tail_app5051833) {
return $Hcont_tail_app19081834(cont_tail_app5051833);
}};
$e18231824.stack[R.EXN_STACKHEIGHT++] = $ss18271828;
}
if(R.isPyretException($e18231824)) {
$e18231824.pyretStack.push(L[302]);
}
throw $e18231824;
}
var $ret18291830 = $Hcont_tail_app19081834($z18251826);
++R.GAS;
return $ret18291830;
}
} else {
var cont_tail_arg5021838 = R.throwNonBooleanCondition(L[303],("when"),when_DASH_361835);
if(--R.GAS > 0) {
$z18361837 = R.isFunction(if_helper3471821)?if_helper3471821.app(cont_tail_arg5021838):R.ffi.throwNonFunApp(L[303],if_helper3471821,[cont_tail_arg5021838]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper3471821)?if_helper3471821.app(cont_tail_arg5021838):R.ffi.throwNonFunApp(L[303],if_helper3471821,[cont_tail_arg5021838]);
},
"from":L[303]});
}
++R.GAS;
return $z18361837;
}
});
});
compile_DASH_split_DASH_app180671.$var = anf_assign507672;
var anf_assign593674 = R.makeFunction(function(ann2341602,visitor2351603) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[275],2,arguments);
}
var cases_DASH_val451802 = ann2341602;
var anf_fun5091614 = G(cases_DASH_val451802,"_match",L[276]);
var anf_obj5141620 = R.makeFunction(function($underscore2361787,n2371788) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[297],2,arguments);
}
var anf_fun5111799 = G(n2371788,"tostring",L[299]);
var $z17911792 = D;
var $f17971798 = function(_) {
return R.isFunction(anf_fun5111799)?anf_fun5111799.app():R.ffi.throwNonFunApp(L[298],anf_fun5111799,[]);
};
try {
if(--R.GAS > 0) {
$z17911792 = $f17971798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17971798,
"from":L[298]});
}
} catch($e17891790) {
if(R.isCont($e17891790)) {
var $ss17931794 = {"from":L[298],
"go":function(anf_arg5121800) {
return $Hanf_arg19111801(anf_arg5121800,j_DASH_id8381,js_DASH_id_DASH_of162700);
}};
$e17891790.stack[R.EXN_STACKHEIGHT++] = $ss17931794;
}
if(R.isPyretException($e17891790)) {
$e17891790.pyretStack.push(L[298]);
}
throw $e17891790;
}
var $ret17951796 = $Hanf_arg19111801($z17911792,j_DASH_id8381,js_DASH_id_DASH_of162700);
++R.GAS;
return $ret17951796;
});
var anf_obj5161621 = R.makeFunction(function($underscore2381771,$underscore2391772,$underscore2401773,$underscore2411774) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[296],4,arguments);
}
var $z17771778 = D;
var $f17831784 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("Function")):R.ffi.throwNonFunApp(L[296],rt_DASH_field172655.$var,[("Function")]);
};
try {
if(--R.GAS > 0) {
$z17771778 = $f17831784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17831784,
"from":L[296]});
}
} catch($e17751776) {
if(R.isCont($e17751776)) {
var $ss17791780 = {"from":L[296],
"go":function(ann_DASH_check_DASH_temp5151785) {
return $Hann_DASH_check_DASH_temp19121786(ann_DASH_check_DASH_temp5151785);
}};
$e17751776.stack[R.EXN_STACKHEIGHT++] = $ss17791780;
}
if(R.isPyretException($e17751776)) {
$e17751776.pyretStack.push(L[296]);
}
throw $e17751776;
}
var $ret17811782 = $Hann_DASH_check_DASH_temp19121786($z17771778);
++R.GAS;
return $ret17811782;
});
var anf_obj5181622 = R.makeFunction(function($underscore2421756,$underscore2431757,$underscore2441758) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[295],3,arguments);
}
var $z17611762 = D;
var $f17671768 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("Method")):R.ffi.throwNonFunApp(L[295],rt_DASH_field172655.$var,[("Method")]);
};
try {
if(--R.GAS > 0) {
$z17611762 = $f17671768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17671768,
"from":L[295]});
}
} catch($e17591760) {
if(R.isCont($e17591760)) {
var $ss17631764 = {"from":L[295],
"go":function(ann_DASH_check_DASH_temp5171769) {
return $Hann_DASH_check_DASH_temp19131770(ann_DASH_check_DASH_temp5171769);
}};
$e17591760.stack[R.EXN_STACKHEIGHT++] = $ss17631764;
}
if(R.isPyretException($e17591760)) {
$e17591760.pyretStack.push(L[295]);
}
throw $e17591760;
}
var $ret17651766 = $Hann_DASH_check_DASH_temp19131770($z17611762);
++R.GAS;
return $ret17651766;
});
var anf_obj5201623 = R.makeFunction(function(l2451741,base2461742,$underscore2471743) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[294],3,arguments);
}
var $z17461747 = D;
var $f17521753 = function(_) {
return R.isFunction(compile_DASH_ann181673.$var)?compile_DASH_ann181673.$var.app(base2461742,visitor2351603):R.ffi.throwNonFunApp(L[294],compile_DASH_ann181673.$var,[base2461742,visitor2351603]);
};
try {
if(--R.GAS > 0) {
$z17461747 = $f17521753();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17521753,
"from":L[294]});
}
} catch($e17441745) {
if(R.isCont($e17441745)) {
var $ss17481749 = {"from":L[294],
"go":function(ann_DASH_check_DASH_temp5191754) {
return $Hann_DASH_check_DASH_temp19141755(ann_DASH_check_DASH_temp5191754);
}};
$e17441745.stack[R.EXN_STACKHEIGHT++] = $ss17481749;
}
if(R.isPyretException($e17441745)) {
$e17441745.pyretStack.push(L[294]);
}
throw $e17441745;
}
var $ret17501751 = $Hann_DASH_check_DASH_temp19141755($z17461747);
++R.GAS;
return $ret17501751;
});
var anf_obj5431624 = R.makeFunction(function(l2481723,fields2491724) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[290],2,arguments);
}
var anf_fun5221735 = G(fields2491724,"map",L[293]);
var anf_arg5241736 = R.makeFunction(function(recv_DASH_411739) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[292],1,arguments);
}
var ann_DASH_check_DASH_temp5231740 = G(recv_DASH_411739,"name",L[292]);
return ann_DASH_check_DASH_temp5231740;
});
var $z17271728 = D;
var $f17331734 = function(_) {
return R.isFunction(anf_fun5221735)?anf_fun5221735.app(anf_arg5241736):R.ffi.throwNonFunApp(L[291],anf_fun5221735,[anf_arg5241736]);
};
try {
if(--R.GAS > 0) {
$z17271728 = $f17331734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17331734,
"from":L[291]});
}
} catch($e17251726) {
if(R.isCont($e17251726)) {
var $ss17291730 = {"from":L[291],
"go":function(anf_bracket5251737) {
return $Hanf_bracket19261738(anf_bracket5251737,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,j_DASH_str8993,list35101,map47104,rt_DASH_method173657,visitor2351603);
}};
$e17251726.stack[R.EXN_STACKHEIGHT++] = $ss17291730;
}
if(R.isPyretException($e17251726)) {
$e17251726.pyretStack.push(L[291]);
}
throw $e17251726;
}
var $ret17311732 = $Hanf_bracket19261738($z17271728,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,j_DASH_str8993,list35101,map47104,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret17311732;
});
var anf_obj5711625 = R.makeFunction(function(l2541670,base2551671,exp2561672) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[283],3,arguments);
}
var cases_DASH_val431722 = exp2561672;
var anf_fun5451683 = G(cases_DASH_val431722,"_match",L[285]);
var anf_obj5481689 = R.makeFunction(function($underscore2581707,id2591708) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[288],2,arguments);
}
var anf_fun5471719 = G(id2591708,"toname",L[289]);
var $z17111712 = D;
var $f17171718 = function(_) {
return R.isFunction(anf_fun5471719)?anf_fun5471719.app():R.ffi.throwNonFunApp(L[288],anf_fun5471719,[]);
};
try {
if(--R.GAS > 0) {
$z17111712 = $f17171718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17171718,
"from":L[288]});
}
} catch($e17091710) {
if(R.isCont($e17091710)) {
var $ss17131714 = {"from":L[288],
"go":function(ann_DASH_check_DASH_temp5461720) {
return $Hann_DASH_check_DASH_temp19271721(ann_DASH_check_DASH_temp5461720);
}};
$e17091710.stack[R.EXN_STACKHEIGHT++] = $ss17131714;
}
if(R.isPyretException($e17091710)) {
$e17091710.pyretStack.push(L[288]);
}
throw $e17091710;
}
var $ret17151716 = $Hann_DASH_check_DASH_temp19271721($z17111712);
++R.GAS;
return $ret17151716;
});
var anf_obj5511690 = R.makeFunction(function($underscore2601691,id2611692,$underscore2621693) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[286],3,arguments);
}
var anf_fun5501704 = G(id2611692,"toname",L[287]);
var $z16961697 = D;
var $f17021703 = function(_) {
return R.isFunction(anf_fun5501704)?anf_fun5501704.app():R.ffi.throwNonFunApp(L[286],anf_fun5501704,[]);
};
try {
if(--R.GAS > 0) {
$z16961697 = $f17021703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17021703,
"from":L[286]});
}
} catch($e16941695) {
if(R.isCont($e16941695)) {
var $ss16981699 = {"from":L[286],
"go":function(ann_DASH_check_DASH_temp5491705) {
return $Hann_DASH_check_DASH_temp19281706(ann_DASH_check_DASH_temp5491705);
}};
$e16941695.stack[R.EXN_STACKHEIGHT++] = $ss16981699;
}
if(R.isPyretException($e16941695)) {
$e16941695.pyretStack.push(L[286]);
}
throw $e16941695;
}
var $ret17001701 = $Hann_DASH_check_DASH_temp19281706($z16961697);
++R.GAS;
return $ret17001701;
});
var anf_arg5521684 = R.makeObject({"s-id":anf_obj5481689,
"s-id-letrec":anf_obj5511690});
var anf_arg5541685 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[285],0,arguments);
}
var ann_DASH_check_DASH_temp5531688 = R.throwNoBranchesMatched(L[285],("cases"));
return ann_DASH_check_DASH_temp5531688;
});
var $z16751676 = D;
var $f16811682 = function(_) {
return R.isFunction(anf_fun5451683)?anf_fun5451683.app(anf_arg5521684,anf_arg5541685):R.ffi.throwNonFunApp(L[284],anf_fun5451683,[anf_arg5521684,anf_arg5541685]);
};
try {
if(--R.GAS > 0) {
$z16751676 = $f16811682();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16811682,
"from":L[284]});
}
} catch($e16731674) {
if(R.isCont($e16731674)) {
var $ss16771678 = {"from":L[284],
"go":function(name2571686) {
return $Hname19371687(name2571686,N319,base2551671,compile_DASH_ann181673,exp2561672,j_DASH_str8993,list35101,rt_DASH_method173657,visitor2351603);
}};
$e16731674.stack[R.EXN_STACKHEIGHT++] = $ss16771678;
}
if(R.isPyretException($e16731674)) {
$e16731674.pyretStack.push(L[284]);
}
throw $e16731674;
}
var $ret16791680 = $Hname19371687($z16751676,N319,base2551671,compile_DASH_ann181673,exp2561672,j_DASH_str8993,list35101,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret16791680;
});
var anf_obj5851626 = R.makeFunction(function(l2691653,m2701654,field2711655) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[279],3,arguments);
}
var anf_fun5731668 = G(list35101,"make",L[282]);
var anf_fun5741666 = G(visitor2351603,"get-loc",L[281]);
var $z16581659 = D;
var $f16641665 = function(_) {
return R.isFunction(anf_fun5741666)?anf_fun5741666.app(l2691653):R.ffi.throwNonFunApp(L[280],anf_fun5741666,[l2691653]);
};
try {
if(--R.GAS > 0) {
$z16581659 = $f16641665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16641665,
"from":L[280]});
}
} catch($e16561657) {
if(R.isCont($e16561657)) {
var $ss16601661 = {"from":L[280],
"go":function(anf_array_val5751667) {
return $Hanf_array_val19461669(anf_array_val5751667,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657);
}};
$e16561657.stack[R.EXN_STACKHEIGHT++] = $ss16601661;
}
if(R.isPyretException($e16561657)) {
$e16561657.pyretStack.push(L[280]);
}
throw $e16561657;
}
var $ret16621663 = $Hanf_array_val19461669($z16581659,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657);
++R.GAS;
return $ret16621663;
});
var anf_obj5871627 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[278],0,arguments);
}
var $z16431644 = D;
var $f16491650 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("Any")):R.ffi.throwNonFunApp(L[278],rt_DASH_field172655.$var,[("Any")]);
};
try {
if(--R.GAS > 0) {
$z16431644 = $f16491650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16491650,
"from":L[278]});
}
} catch($e16411642) {
if(R.isCont($e16411642)) {
var $ss16451646 = {"from":L[278],
"go":function(ann_DASH_check_DASH_temp5861651) {
return $Hann_DASH_check_DASH_temp19471652(ann_DASH_check_DASH_temp5861651);
}};
$e16411642.stack[R.EXN_STACKHEIGHT++] = $ss16451646;
}
if(R.isPyretException($e16411642)) {
$e16411642.pyretStack.push(L[278]);
}
throw $e16411642;
}
var $ret16471648 = $Hann_DASH_check_DASH_temp19471652($z16431644);
++R.GAS;
return $ret16471648;
});
var anf_obj5891628 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[277],0,arguments);
}
var $z16311632 = D;
var $f16371638 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("Any")):R.ffi.throwNonFunApp(L[277],rt_DASH_field172655.$var,[("Any")]);
};
try {
if(--R.GAS > 0) {
$z16311632 = $f16371638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16371638,
"from":L[277]});
}
} catch($e16291630) {
if(R.isCont($e16291630)) {
var $ss16331634 = {"from":L[277],
"go":function(ann_DASH_check_DASH_temp5881639) {
return $Hann_DASH_check_DASH_temp19481640(ann_DASH_check_DASH_temp5881639);
}};
$e16291630.stack[R.EXN_STACKHEIGHT++] = $ss16331634;
}
if(R.isPyretException($e16291630)) {
$e16291630.pyretStack.push(L[277]);
}
throw $e16291630;
}
var $ret16351636 = $Hann_DASH_check_DASH_temp19481640($z16311632);
++R.GAS;
return $ret16351636;
});
var anf_arg5901615 = R.makeObject({"a-name":anf_obj5141620,
"a-arrow":anf_obj5161621,
"a-method":anf_obj5181622,
"a-app":anf_obj5201623,
"a-record":anf_obj5431624,
"a-pred":anf_obj5711625,
"a-dot":anf_obj5851626,
"a-blank":anf_obj5871627,
"a-any":anf_obj5891628});
var anf_arg5921616 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[276],0,arguments);
}
var ann_DASH_check_DASH_temp5911619 = R.throwNoBranchesMatched(L[276],("cases"));
return ann_DASH_check_DASH_temp5911619;
});
var $z16061607 = D;
var $f16121613 = function(_) {
return R.isFunction(anf_fun5091614)?anf_fun5091614.app(anf_arg5901615,anf_arg5921616):R.ffi.throwNonFunApp(L[275],anf_fun5091614,[anf_arg5901615,anf_arg5921616]);
};
try {
if(--R.GAS > 0) {
$z16061607 = $f16121613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16121613,
"from":L[275]});
}
} catch($e16041605) {
if(R.isCont($e16041605)) {
var $ss16081609 = {"from":L[275],
"go":function(ann_DASH_check_DASH_temp5081617) {
return $Hann_DASH_check_DASH_temp19491618(ann_DASH_check_DASH_temp5081617);
}};
$e16041605.stack[R.EXN_STACKHEIGHT++] = $ss16081609;
}
if(R.isPyretException($e16041605)) {
$e16041605.pyretStack.push(L[275]);
}
throw $e16041605;
}
var $ret16101611 = $Hann_DASH_check_DASH_temp19491618($z16061607);
++R.GAS;
return $ret16101611;
});
compile_DASH_ann181673.$var = anf_assign593674;
var anf_assign611676 = R.makeFunction(function(loc_DASH_expr2721587,body_DASH_stmts2731588,arity2741589) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[273],3,arguments);
}
var $z15921593 = D;
var $f15981599 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("arguments")):R.ffi.throwNonFunApp(L[274],j_DASH_id8381,[("arguments")]);
};
try {
if(--R.GAS > 0) {
$z15921593 = $f15981599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15981599,
"from":L[274]});
}
} catch($e15901591) {
if(R.isCont($e15901591)) {
var $ss15941595 = {"from":L[274],
"go":function(anf_arg5951600) {
return $Hanf_arg19641601(anf_arg5951600,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot9775,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655);
}};
$e15901591.stack[R.EXN_STACKHEIGHT++] = $ss15941595;
}
if(R.isPyretException($e15901591)) {
$e15901591.pyretStack.push(L[274]);
}
throw $e15901591;
}
var $ret15961597 = $Hanf_arg19641601($z15921593,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot9775,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655);
++R.GAS;
return $ret15961597;
});
arity_DASH_check182675.$var = anf_assign611676;
var anf_assign664678 = R.makeFunction(function(args2751555,ret2761556,stmts2771557,visitor2781558) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[267],4,arguments);
}
var anf_arg6301569 = R.makeFunction(function(a2801572) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[269],1,arguments);
}
var anf_fun6141583 = G(A118,"is-a-blank",L[272]);
var anf_arg6151584 = G(a2801572,"ann",L[271]);
var $z15751576 = D;
var $f15811582 = function(_) {
return R.isFunction(anf_fun6141583)?anf_fun6141583.app(anf_arg6151584):R.ffi.throwNonFunApp(L[270],anf_fun6141583,[anf_arg6151584]);
};
try {
if(--R.GAS > 0) {
$z15751576 = $f15811582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15811582,
"from":L[270]});
}
} catch($e15731574) {
if(R.isCont($e15731574)) {
var $ss15771578 = {"from":L[270],
"go":function(anf_arg6161585) {
return $Hanf_arg19701586(anf_arg6161585,A118,a2801572,not8);
}};
$e15731574.stack[R.EXN_STACKHEIGHT++] = $ss15771578;
}
if(R.isPyretException($e15731574)) {
$e15731574.pyretStack.push(L[270]);
}
throw $e15731574;
}
var $ret15791580 = $Hanf_arg19701586($z15751576,A118,a2801572,not8);
++R.GAS;
return $ret15791580;
});
var $z15611562 = D;
var $f15671568 = function(_) {
return R.isFunction(filter4264)?filter4264.app(anf_arg6301569,args2751555):R.ffi.throwNonFunApp(L[268],filter4264,[anf_arg6301569,args2751555]);
};
try {
if(--R.GAS > 0) {
$z15611562 = $f15671568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15671568,
"from":L[268]});
}
} catch($e15591560) {
if(R.isCont($e15591560)) {
var $ss15631564 = {"from":L[268],
"go":function(nonblanks2791570) {
return $Hnonblanks19911571(nonblanks2791570,compile_DASH_ann181673,is_DASH_empty3666,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,rt_DASH_method173657,stmts2771557,visitor2781558);
}};
$e15591560.stack[R.EXN_STACKHEIGHT++] = $ss15631564;
}
if(R.isPyretException($e15591560)) {
$e15591560.pyretStack.push(L[268]);
}
throw $e15591560;
}
var $ret15651566 = $Hnonblanks19911571($z15611562,compile_DASH_ann181673,is_DASH_empty3666,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,rt_DASH_method173657,stmts2771557,visitor2781558);
++R.GAS;
return $ret15651566;
});
contract_DASH_checks183677.$var = anf_assign664678;
var anf_obj694865 = R.makeMethod(function(self2891537) {
return function(l2901554,answer2911534,provides2921536,types2931532,checks2941535) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[266],5,arguments);
}
var anf_arg6701531 = R.makeFunction(function(ann2961539) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[262],1,arguments);
}
var anf_arg6671552 = G(ann2961539,"name",L[265]);
var anf_arg6681550 = G(ann2961539,"ann",L[264]);
var $z15421543 = D;
var $f15481549 = function(_) {
return R.isFunction(compile_DASH_ann181673.$var)?compile_DASH_ann181673.$var.app(anf_arg6681550,self2891537):R.ffi.throwNonFunApp(L[263],compile_DASH_ann181673.$var,[anf_arg6681550,self2891537]);
};
try {
if(--R.GAS > 0) {
$z15421543 = $f15481549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15481549,
"from":L[263]});
}
} catch($e15401541) {
if(R.isCont($e15401541)) {
var $ss15441545 = {"from":L[263],
"go":function(anf_arg6691551) {
return $Hanf_arg19931553(anf_arg6691551,anf_arg6671552,j_DASH_field9979);
}};
$e15401541.stack[R.EXN_STACKHEIGHT++] = $ss15441545;
}
if(R.isPyretException($e15401541)) {
$e15401541.pyretStack.push(L[263]);
}
throw $e15401541;
}
var $ret15461547 = $Hanf_arg19931553($z15421543,anf_arg6671552,j_DASH_field9979);
++R.GAS;
return $ret15461547;
});
var $z15231524 = D;
var $f15291530 = function(_) {
return R.isFunction(map47104)?map47104.app(anf_arg6701531,types2931532):R.ffi.throwNonFunApp(L[261],map47104,[anf_arg6701531,types2931532]);
};
try {
if(--R.GAS > 0) {
$z15231524 = $f15291530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15291530,
"from":L[261]});
}
} catch($e15211522) {
if(R.isCont($e15211522)) {
var $ss15251526 = {"from":L[261],
"go":function(types_DASH_obj_DASH_fields2951533) {
return $Htypes_DASH_obj_DASH_fields20111538(types_DASH_obj_DASH_fields2951533,answer2911534,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537);
}};
$e15211522.stack[R.EXN_STACKHEIGHT++] = $ss15251526;
}
if(R.isPyretException($e15211522)) {
$e15211522.pyretStack.push(L[261]);
}
throw $e15211522;
}
var $ret15271528 = $Htypes_DASH_obj_DASH_fields20111538($z15231524,answer2911534,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537);
++R.GAS;
return $ret15271528;
};
},{"length":6});
var anf_obj741866 = R.makeMethod(function(self2971499) {
return function(l2981520,bind2991519,body3001498) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[252],3,arguments);
}
var cases_DASH_val491518 = bind2991519;
var anf_fun6961475 = G(cases_DASH_val491518,"_match",L[253]);
var anf_obj7091481 = R.makeFunction(function(l23011501,name3021502,ann3031503) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[257],3,arguments);
}
var anf_fun6981516 = G(list35101,"make",L[260]);
var anf_fun6991514 = G(name3021502,"tostring",L[259]);
var $z15061507 = D;
var $f15121513 = function(_) {
return R.isFunction(anf_fun6991514)?anf_fun6991514.app():R.ffi.throwNonFunApp(L[258],anf_fun6991514,[]);
};
try {
if(--R.GAS > 0) {
$z15061507 = $f15121513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15121513,
"from":L[258]});
}
} catch($e15041505) {
if(R.isCont($e15041505)) {
var $ss15081509 = {"from":L[258],
"go":function(anf_arg7001515) {
return $Hanf_arg20191517(anf_arg7001515,anf_fun6981516,ann3031503,body3001498,compile_DASH_ann181673,j_DASH_block8570,j_DASH_var8299,js_DASH_id_DASH_of162700,self2971499,_plus5);
}};
$e15041505.stack[R.EXN_STACKHEIGHT++] = $ss15081509;
}
if(R.isPyretException($e15041505)) {
$e15041505.pyretStack.push(L[258]);
}
throw $e15041505;
}
var $ret15101511 = $Hanf_arg20191517($z15061507,anf_fun6981516,ann3031503,body3001498,compile_DASH_ann181673,j_DASH_block8570,j_DASH_var8299,js_DASH_id_DASH_of162700,self2971499,_plus5);
++R.GAS;
return $ret15101511;
});
var anf_obj7371482 = R.makeFunction(function(l23041483,name3051484,nameb3061485) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[254],3,arguments);
}
var anf_fun7111496 = G(nameb3061485,"tostring",L[256]);
var $z14881489 = D;
var $f14941495 = function(_) {
return R.isFunction(anf_fun7111496)?anf_fun7111496.app():R.ffi.throwNonFunApp(L[255],anf_fun7111496,[]);
};
try {
if(--R.GAS > 0) {
$z14881489 = $f14941495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14941495,
"from":L[255]});
}
} catch($e14861487) {
if(R.isCont($e14861487)) {
var $ss14901491 = {"from":L[255],
"go":function(anf_arg7121497) {
return $Hanf_arg20381500(anf_arg7121497,body3001498,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e14861487.stack[R.EXN_STACKHEIGHT++] = $ss14901491;
}
if(R.isPyretException($e14861487)) {
$e14861487.pyretStack.push(L[255]);
}
throw $e14861487;
}
var $ret14921493 = $Hanf_arg20381500($z14881489,body3001498,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret14921493;
});
var anf_arg7381476 = R.makeObject({"a-type-bind":anf_obj7091481,
"a-newtype-bind":anf_obj7371482});
var anf_arg7401477 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[253],0,arguments);
}
var ann_DASH_check_DASH_temp7391480 = R.throwNoBranchesMatched(L[253],("cases"));
return ann_DASH_check_DASH_temp7391480;
});
var $z14671468 = D;
var $f14731474 = function(_) {
return R.isFunction(anf_fun6961475)?anf_fun6961475.app(anf_arg7381476,anf_arg7401477):R.ffi.throwNonFunApp(L[252],anf_fun6961475,[anf_arg7381476,anf_arg7401477]);
};
try {
if(--R.GAS > 0) {
$z14671468 = $f14731474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14731474,
"from":L[252]});
}
} catch($e14651466) {
if(R.isCont($e14651466)) {
var $ss14691470 = {"from":L[252],
"go":function(ann_DASH_check_DASH_temp6951478) {
return $Hann_DASH_check_DASH_temp20391479(ann_DASH_check_DASH_temp6951478);
}};
$e14651466.stack[R.EXN_STACKHEIGHT++] = $ss14691470;
}
if(R.isPyretException($e14651466)) {
$e14651466.pyretStack.push(L[252]);
}
throw $e14651466;
}
var $ret14711472 = $Hann_DASH_check_DASH_temp20391479($z14671468);
++R.GAS;
return $ret14711472;
};
},{"length":4});
var anf_obj804867 = R.makeMethod(function(self3081458) {
return function(l3091464,b3101460,e3111461,body3121463) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[251],4,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[247],"N",N432,"ABind"),R.getDotAnn(L[248],"N",N432,"ALettable"),R.getDotAnn(L[249],"N",N432,"AExpr")],[l3091464,b3101460,e3111461,body3121463],[L[250],L[247],L[248],L[249]],function() {
var anf_fun7431457 = G(body3121463,"visit",L[246]);
var $z14491450 = D;
var $f14551456 = function(_) {
return R.isFunction(anf_fun7431457)?anf_fun7431457.app(self3081458):R.ffi.throwNonFunApp(L[245],anf_fun7431457,[self3081458]);
};
try {
if(--R.GAS > 0) {
$z14491450 = $f14551456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14551456,
"from":L[245]});
}
} catch($e14471448) {
if(R.isCont($e14471448)) {
var $ss14511452 = {"from":L[245],
"go":function(compiled_DASH_body3131459) {
return $Hcompiled_DASH_body20671462(compiled_DASH_body3131459,A118,b3101460,compile_DASH_ann181673,e3111461,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458,_plus5);
}};
$e14471448.stack[R.EXN_STACKHEIGHT++] = $ss14511452;
}
if(R.isPyretException($e14471448)) {
$e14471448.pyretStack.push(L[245]);
}
throw $e14471448;
}
var $ret14531454 = $Hcompiled_DASH_body20671462($z14491450,A118,b3101460,compile_DASH_ann181673,e3111461,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458,_plus5);
++R.GAS;
return $ret14531454;
});
};
},{"length":5});
var anf_obj825868 = R.makeMethod(function(self3151440) {
return function(l3161446,b3171442,e3181443,body3191445) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[244],4,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[240],"N",N432,"ABind"),R.getDotAnn(L[241],"N",N432,"ALettable"),R.getDotAnn(L[242],"N",N432,"AExpr")],[l3161446,b3171442,e3181443,body3191445],[L[243],L[240],L[241],L[242]],function() {
var anf_fun8061439 = G(body3191445,"visit",L[239]);
var $z14311432 = D;
var $f14371438 = function(_) {
return R.isFunction(anf_fun8061439)?anf_fun8061439.app(self3151440):R.ffi.throwNonFunApp(L[238],anf_fun8061439,[self3151440]);
};
try {
if(--R.GAS > 0) {
$z14311432 = $f14371438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14371438,
"from":L[238]});
}
} catch($e14291430) {
if(R.isCont($e14291430)) {
var $ss14331434 = {"from":L[238],
"go":function(compiled_DASH_body3201441) {
return $Hcompiled_DASH_body20801444(compiled_DASH_body3201441,b3171442,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,link39100,list35101,self3151440);
}};
$e14291430.stack[R.EXN_STACKHEIGHT++] = $ss14331434;
}
if(R.isPyretException($e14291430)) {
$e14291430.pyretStack.push(L[238]);
}
throw $e14291430;
}
var $ret14351436 = $Hcompiled_DASH_body20801444($z14311432,b3171442,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,link39100,list35101,self3151440);
++R.GAS;
return $ret14351436;
});
};
},{"length":5});
var anf_obj827869 = R.makeMethod(function(self3211423) {
return function(l3221424,f3231425,args3241426) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[234],3,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[235],"N",N432,"AVal"),List2762],[l3221424,f3231425,args3241426],[L[236],L[235],L[237]],function() {
var $z14151416 = D;
var $f14211422 = function(_) {
return R.isFunction(compile_DASH_tail_DASH_app179669.$var)?compile_DASH_tail_DASH_app179669.$var.app(self3211423,l3221424,f3231425,args3241426):R.ffi.throwNonFunApp(L[234],compile_DASH_tail_DASH_app179669.$var,[self3211423,l3221424,f3231425,args3241426]);
};
try {
if(--R.GAS > 0) {
$z14151416 = $f14211422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14211422,
"from":L[234]});
}
} catch($e14131414) {
if(R.isCont($e14131414)) {
var $ss14171418 = {"from":L[234],
"go":function(ann_DASH_check_DASH_temp8261427) {
return $Hann_DASH_check_DASH_temp20811428(ann_DASH_check_DASH_temp8261427);
}};
$e14131414.stack[R.EXN_STACKHEIGHT++] = $ss14171418;
}
if(R.isPyretException($e14131414)) {
$e14131414.pyretStack.push(L[234]);
}
throw $e14131414;
}
var $ret14191420 = $Hann_DASH_check_DASH_temp20811428($z14151416);
++R.GAS;
return $ret14191420;
});
};
},{"length":4});
var anf_obj829870 = R.makeMethod(function(self3251404) {
return function(l3261405,is_DASH_var3271406,f3281407,args3291408,name3301409,helper_DASH_args3311410) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[227],6,arguments);
}
return R.checkAnnArgs([Loc7863,$type$Boolean15,R.getDotAnn(L[228],"N",N432,"AVal"),List2762,R.getDotAnn(L[229],"A",A231,"Name"),List2762],[l3261405,is_DASH_var3271406,f3281407,args3291408,name3301409,helper_DASH_args3311410],[L[230],L[231],L[228],L[232],L[229],L[233]],function() {
var $z13961397 = D;
var $f14021403 = function(_) {
return R.isFunction(compile_DASH_split_DASH_app180671.$var)?compile_DASH_split_DASH_app180671.$var.app(self3251404,l3261405,is_DASH_var3271406,f3281407,args3291408,name3301409,helper_DASH_args3311410):R.ffi.throwNonFunApp(L[227],compile_DASH_split_DASH_app180671.$var,[self3251404,l3261405,is_DASH_var3271406,f3281407,args3291408,name3301409,helper_DASH_args3311410]);
};
try {
if(--R.GAS > 0) {
$z13961397 = $f14021403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14021403,
"from":L[227]});
}
} catch($e13941395) {
if(R.isCont($e13941395)) {
var $ss13981399 = {"from":L[227],
"go":function(ann_DASH_check_DASH_temp8281411) {
return $Hann_DASH_check_DASH_temp20821412(ann_DASH_check_DASH_temp8281411);
}};
$e13941395.stack[R.EXN_STACKHEIGHT++] = $ss13981399;
}
if(R.isPyretException($e13941395)) {
$e13941395.pyretStack.push(L[227]);
}
throw $e13941395;
}
var $ret14001401 = $Hann_DASH_check_DASH_temp20821412($z13961397);
++R.GAS;
return $ret14001401;
});
};
},{"length":7});
var anf_obj851871 = R.makeMethod(function(self3321388) {
return function(l3331393,e13341392,e23351390) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[226],3,arguments);
}
var anf_fun8311387 = G(e13341392,"visit",L[225]);
var $z13791380 = D;
var $f13851386 = function(_) {
return R.isFunction(anf_fun8311387)?anf_fun8311387.app(self3321388):R.ffi.throwNonFunApp(L[224],anf_fun8311387,[self3321388]);
};
try {
if(--R.GAS > 0) {
$z13791380 = $f13851386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13851386,
"from":L[224]});
}
} catch($e13771378) {
if(R.isCont($e13771378)) {
var $ss13811382 = {"from":L[224],
"go":function(e1_DASH_visit3361389) {
return $He1_DASH_visit20911391(e1_DASH_visit3361389,J721,e23351390,j_DASH_block8570,j_DASH_expr10477,link39100,self3321388);
}};
$e13771378.stack[R.EXN_STACKHEIGHT++] = $ss13811382;
}
if(R.isPyretException($e13771378)) {
$e13771378.pyretStack.push(L[224]);
}
throw $e13771378;
}
var $ret13831384 = $He1_DASH_visit20911391($z13791380,J721,e23351390,j_DASH_block8570,j_DASH_expr10477,link39100,self3321388);
++R.GAS;
return $ret13831384;
};
},{"length":4});
var anf_obj863872 = R.makeMethod(function(self3371370) {
return function(l3381376,cond3391373,consq3401375,alt3411372) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[223],4,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[219],"N",N432,"AVal"),R.getDotAnn(L[220],"N",N432,"AExpr"),R.getDotAnn(L[221],"N",N432,"AExpr")],[l3381376,cond3391373,consq3401375,alt3411372],[L[222],L[219],L[220],L[221]],function() {
var anf_fun8531369 = G(consq3401375,"visit",L[218]);
var $z13611362 = D;
var $f13671368 = function(_) {
return R.isFunction(anf_fun8531369)?anf_fun8531369.app(self3371370):R.ffi.throwNonFunApp(L[217],anf_fun8531369,[self3371370]);
};
try {
if(--R.GAS > 0) {
$z13611362 = $f13671368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13671368,
"from":L[217]});
}
} catch($e13591360) {
if(R.isCont($e13591360)) {
var $ss13631364 = {"from":L[217],
"go":function(compiled_DASH_consq3421371) {
return $Hcompiled_DASH_consq20991374(compiled_DASH_consq3421371,alt3411372,cond3391373,j_DASH_block8570,j_DASH_if9283,list35101,rt_DASH_method173657,self3371370);
}};
$e13591360.stack[R.EXN_STACKHEIGHT++] = $ss13631364;
}
if(R.isPyretException($e13591360)) {
$e13591360.pyretStack.push(L[217]);
}
throw $e13591360;
}
var $ret13651366 = $Hcompiled_DASH_consq20991374($z13611362,alt3411372,cond3391373,j_DASH_block8570,j_DASH_if9283,list35101,rt_DASH_method173657,self3371370);
++R.GAS;
return $ret13651366;
});
};
},{"length":5});
var anf_obj870873 = R.makeMethod(function(self3441354) {
return function(e3451358) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[216],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[215],"N",N432,"ALettable")],[e3451358],[L[215]],function() {
var anf_fun8651356 = G(list35101,"make",L[214]);
var anf_fun8661353 = G(e3451358,"visit",L[213]);
var $z13451346 = D;
var $f13511352 = function(_) {
return R.isFunction(anf_fun8661353)?anf_fun8661353.app(self3441354):R.ffi.throwNonFunApp(L[212],anf_fun8661353,[self3441354]);
};
try {
if(--R.GAS > 0) {
$z13451346 = $f13511352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13511352,
"from":L[212]});
}
} catch($e13431344) {
if(R.isCont($e13431344)) {
var $ss13471348 = {"from":L[212],
"go":function(anf_arg8671355) {
return $Hanf_arg21031357(anf_arg8671355,anf_fun8651356,j_DASH_block8570,j_DASH_return9092);
}};
$e13431344.stack[R.EXN_STACKHEIGHT++] = $ss13471348;
}
if(R.isPyretException($e13431344)) {
$e13431344.pyretStack.push(L[212]);
}
throw $e13431344;
}
var $ret13491350 = $Hanf_arg21031357($z13451346,anf_fun8651356,j_DASH_block8570,j_DASH_return9092);
++R.GAS;
return $ret13491350;
});
};
},{"length":2});
var anf_obj878874 = R.makeMethod(function(self3461338) {
return function(l3471342,id3481341,value3491339) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[211],3,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[208],"A",A231,"Name"),R.getDotAnn(L[209],"N",N432,"AVal")],[l3471342,id3481341,value3491339],[L[210],L[208],L[209]],function() {
var anf_fun8721336 = G(id3481341,"tostring",L[207]);
var $z13281329 = D;
var $f13341335 = function(_) {
return R.isFunction(anf_fun8721336)?anf_fun8721336.app():R.ffi.throwNonFunApp(L[206],anf_fun8721336,[]);
};
try {
if(--R.GAS > 0) {
$z13281329 = $f13341335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13341335,
"from":L[206]});
}
} catch($e13261327) {
if(R.isCont($e13261327)) {
var $ss13301331 = {"from":L[206],
"go":function(anf_arg8731337) {
return $Hanf_arg21081340(anf_arg8731337,j_DASH_dot_DASH_assign10074,j_DASH_id8381,js_DASH_id_DASH_of162700,self3461338,value3491339);
}};
$e13261327.stack[R.EXN_STACKHEIGHT++] = $ss13301331;
}
if(R.isPyretException($e13261327)) {
$e13261327.pyretStack.push(L[206]);
}
throw $e13261327;
}
var $ret13321333 = $Hanf_arg21081340($z13281329,j_DASH_dot_DASH_assign10074,j_DASH_id8381,js_DASH_id_DASH_of162700,self3461338,value3491339);
++R.GAS;
return $ret13321333;
});
};
},{"length":4});
var anf_obj889875 = R.makeMethod(function(self3501324) {
return function(l3511320,f3521323,args3531322) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[205],3,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[202],"N",N432,"AVal"),List2762],[l3511320,f3521323,args3531322],[L[203],L[202],L[204]],function() {
var anf_fun8801319 = G(self3501324,"get-loc",L[201]);
var $z13111312 = D;
var $f13171318 = function(_) {
return R.isFunction(anf_fun8801319)?anf_fun8801319.app(l3511320):R.ffi.throwNonFunApp(L[200],anf_fun8801319,[l3511320]);
};
try {
if(--R.GAS > 0) {
$z13111312 = $f13171318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13171318,
"from":L[200]});
}
} catch($e13091310) {
if(R.isCont($e13091310)) {
var $ss13131314 = {"from":L[200],
"go":function(anf_arg8811321) {
return $Hanf_arg21131325(anf_arg8811321,app174659,args3531322,f3521323,self3501324);
}};
$e13091310.stack[R.EXN_STACKHEIGHT++] = $ss13131314;
}
if(R.isPyretException($e13091310)) {
$e13091310.pyretStack.push(L[200]);
}
throw $e13091310;
}
var $ret13151316 = $Hanf_arg21131325($z13111312,app174659,args3531322,f3521323,self3501324);
++R.GAS;
return $ret13151316;
});
};
},{"length":4});
var anf_obj896876 = R.makeMethod(function(self3541304) {
return function(l3551308,f3561290,args3571307) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[199],3,arguments);
}
return R.checkAnnArgs([Loc7863,$type$String17,List2762],[l3551308,f3561290,args3571307],[L[196],L[197],L[198]],function() {
var anf_fun8911287 = G(args3571307,"map",L[195]);
var anf_arg8941288 = R.makeFunction(function(recv_DASH_551292) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[194],1,arguments);
}
var anf_fun8931303 = G(recv_DASH_551292,"visit",L[194]);
var $z12951296 = D;
var $f13011302 = function(_) {
return R.isFunction(anf_fun8931303)?anf_fun8931303.app(self3541304):R.ffi.throwNonFunApp(L[194],anf_fun8931303,[self3541304]);
};
try {
if(--R.GAS > 0) {
$z12951296 = $f13011302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13011302,
"from":L[194]});
}
} catch($e12931294) {
if(R.isCont($e12931294)) {
var $ss12971298 = {"from":L[194],
"go":function(ann_DASH_check_DASH_temp8921305) {
return $Hann_DASH_check_DASH_temp21141306(ann_DASH_check_DASH_temp8921305);
}};
$e12931294.stack[R.EXN_STACKHEIGHT++] = $ss12971298;
}
if(R.isPyretException($e12931294)) {
$e12931294.pyretStack.push(L[194]);
}
throw $e12931294;
}
var $ret12991300 = $Hann_DASH_check_DASH_temp21141306($z12951296);
++R.GAS;
return $ret12991300;
});
var $z12791280 = D;
var $f12851286 = function(_) {
return R.isFunction(anf_fun8911287)?anf_fun8911287.app(anf_arg8941288):R.ffi.throwNonFunApp(L[193],anf_fun8911287,[anf_arg8941288]);
};
try {
if(--R.GAS > 0) {
$z12791280 = $f12851286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12851286,
"from":L[193]});
}
} catch($e12771278) {
if(R.isCont($e12771278)) {
var $ss12811282 = {"from":L[193],
"go":function(anf_arg8951289) {
return $Hanf_arg21161291(anf_arg8951289,f3561290,rt_DASH_method173657);
}};
$e12771278.stack[R.EXN_STACKHEIGHT++] = $ss12811282;
}
if(R.isPyretException($e12771278)) {
$e12771278.pyretStack.push(L[193]);
}
throw $e12771278;
}
var $ret12831284 = $Hanf_arg21161291($z12791280,f3561290,rt_DASH_method173657);
++R.GAS;
return $ret12831284;
});
};
},{"length":4});
var anf_obj909877 = R.makeMethod(function(self3581270) {
return function(l3591276,fields3601275) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[192],2,arguments);
}
return R.checkAnnArgs([Loc7863,List2762],[l3591276,fields3601275],[L[190],L[191]],function() {
var anf_fun8981256 = G(list35101,"make",L[189]);
var anf_fun8991253 = G(fields3601275,"map",L[188]);
var anf_arg9051254 = R.makeFunction(function(f3611258) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[183],1,arguments);
}
var anf_arg9011272 = G(f3611258,"name",L[187]);
var anf_bracket9021274 = G(f3611258,"value",L[186]);
var anf_fun9031269 = G(anf_bracket9021274,"visit",L[185]);
var $z12611262 = D;
var $f12671268 = function(_) {
return R.isFunction(anf_fun9031269)?anf_fun9031269.app(self3581270):R.ffi.throwNonFunApp(L[184],anf_fun9031269,[self3581270]);
};
try {
if(--R.GAS > 0) {
$z12611262 = $f12671268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12671268,
"from":L[184]});
}
} catch($e12591260) {
if(R.isCont($e12591260)) {
var $ss12631264 = {"from":L[184],
"go":function(anf_arg9041271) {
return $Hanf_arg21181273(anf_arg9041271,anf_arg9011272,j_DASH_field9979);
}};
$e12591260.stack[R.EXN_STACKHEIGHT++] = $ss12631264;
}
if(R.isPyretException($e12591260)) {
$e12591260.pyretStack.push(L[184]);
}
throw $e12591260;
}
var $ret12651266 = $Hanf_arg21181273($z12611262,anf_arg9011272,j_DASH_field9979);
++R.GAS;
return $ret12651266;
});
var $z12451246 = D;
var $f12511252 = function(_) {
return R.isFunction(anf_fun8991253)?anf_fun8991253.app(anf_arg9051254):R.ffi.throwNonFunApp(L[182],anf_fun8991253,[anf_arg9051254]);
};
try {
if(--R.GAS > 0) {
$z12451246 = $f12511252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12511252,
"from":L[182]});
}
} catch($e12431244) {
if(R.isCont($e12431244)) {
var $ss12471248 = {"from":L[182],
"go":function(anf_arg9061255) {
return $Hanf_arg21221257(anf_arg9061255,anf_fun8981256,j_DASH_obj9690,rt_DASH_method173657);
}};
$e12431244.stack[R.EXN_STACKHEIGHT++] = $ss12471248;
}
if(R.isPyretException($e12431244)) {
$e12431244.pyretStack.push(L[182]);
}
throw $e12431244;
}
var $ret12491250 = $Hanf_arg21221257($z12451246,anf_fun8981256,j_DASH_obj9690,rt_DASH_method173657);
++R.GAS;
return $ret12491250;
});
};
},{"length":3});
var anf_obj921878 = R.makeMethod(function(self3621237) {
return function(l3631242,obj3641241,fields3651239) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[181],3,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[178],"N",N432,"AVal"),List2762],[l3631242,obj3641241,fields3651239],[L[179],L[178],L[180]],function() {
var anf_fun9111236 = G(obj3641241,"visit",L[177]);
var $z12281229 = D;
var $f12341235 = function(_) {
return R.isFunction(anf_fun9111236)?anf_fun9111236.app(self3621237):R.ffi.throwNonFunApp(L[176],anf_fun9111236,[self3621237]);
};
try {
if(--R.GAS > 0) {
$z12281229 = $f12341235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12341235,
"from":L[176]});
}
} catch($e12261227) {
if(R.isCont($e12261227)) {
var $ss12301231 = {"from":L[176],
"go":function(anf_arg9121238) {
return $Hanf_arg21281240(anf_arg9121238,fields3651239,j_DASH_method8486,j_DASH_obj9690,list35101,self3621237);
}};
$e12261227.stack[R.EXN_STACKHEIGHT++] = $ss12301231;
}
if(R.isPyretException($e12261227)) {
$e12261227.pyretStack.push(L[176]);
}
throw $e12261227;
}
var $ret12321233 = $Hanf_arg21281240($z12281229,fields3651239,j_DASH_method8486,j_DASH_obj9690,list35101,self3621237);
++R.GAS;
return $ret12321233;
});
};
},{"length":4});
var anf_obj928879 = R.makeMethod(function(self3661220) {
return function(l3671223,obj3681225,field3691222) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[175],3,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[172],"N",N432,"AVal"),$type$String17],[l3671223,obj3681225,field3691222],[L[173],L[172],L[174]],function() {
var anf_fun9231219 = G(obj3681225,"visit",L[171]);
var $z12111212 = D;
var $f12171218 = function(_) {
return R.isFunction(anf_fun9231219)?anf_fun9231219.app(self3661220):R.ffi.throwNonFunApp(L[170],anf_fun9231219,[self3661220]);
};
try {
if(--R.GAS > 0) {
$z12111212 = $f12171218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12171218,
"from":L[170]});
}
} catch($e12091210) {
if(R.isCont($e12091210)) {
var $ss12131214 = {"from":L[170],
"go":function(anf_arg9241221) {
return $Hanf_arg21321224(anf_arg9241221,field3691222,get_DASH_field169649,j_DASH_str8993,l3671223,self3661220);
}};
$e12091210.stack[R.EXN_STACKHEIGHT++] = $ss12131214;
}
if(R.isPyretException($e12091210)) {
$e12091210.pyretStack.push(L[170]);
}
throw $e12091210;
}
var $ret12151216 = $Hanf_arg21321224($z12111212,field3691222,get_DASH_field169649,j_DASH_str8993,l3671223,self3661220);
++R.GAS;
return $ret12151216;
});
};
},{"length":4});
var anf_obj935880 = R.makeMethod(function(self3701202) {
return function(l3711208,obj3721207,field3731205) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[169],3,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[166],"N",N432,"AVal"),$type$String17],[l3711208,obj3721207,field3731205],[L[167],L[166],L[168]],function() {
var anf_fun9301204 = G(list35101,"make",L[165]);
var anf_fun9311201 = G(obj3721207,"visit",L[164]);
var $z11931194 = D;
var $f11991200 = function(_) {
return R.isFunction(anf_fun9311201)?anf_fun9311201.app(self3701202):R.ffi.throwNonFunApp(L[163],anf_fun9311201,[self3701202]);
};
try {
if(--R.GAS > 0) {
$z11931194 = $f11991200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11991200,
"from":L[163]});
}
} catch($e11911192) {
if(R.isCont($e11911192)) {
var $ss11951196 = {"from":L[163],
"go":function(anf_array_val9321203) {
return $Hanf_array_val21361206(anf_array_val9321203,anf_fun9301204,field3731205,j_DASH_str8993,rt_DASH_method173657);
}};
$e11911192.stack[R.EXN_STACKHEIGHT++] = $ss11951196;
}
if(R.isPyretException($e11911192)) {
$e11911192.pyretStack.push(L[163]);
}
throw $e11911192;
}
var $ret11971198 = $Hanf_array_val21361206($z11931194,anf_fun9301204,field3731205,j_DASH_str8993,rt_DASH_method173657);
++R.GAS;
return $ret11971198;
});
};
},{"length":4});
var anf_obj960881 = R.makeMethod(function(self3741187) {
return function(l3751185,args3761183,ret3771186,body3781184) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[162],4,arguments);
}
return R.checkAnnArgs([Loc7863,List2762,R.getDotAnn(L[159],"N",N432,"AExpr")],[l3751185,args3761183,body3781184],[L[160],L[161],L[159]],function() {
var anf_fun9371182 = G(list35101,"make",L[158]);
var anf_fun9381179 = G(args3761183,"map",L[157]);
var anf_arg9401180 = R.makeFunction(function(recv_DASH_581189) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[156],1,arguments);
}
var ann_DASH_check_DASH_temp9391190 = G(recv_DASH_581189,"id",L[156]);
return ann_DASH_check_DASH_temp9391190;
});
var $z11711172 = D;
var $f11771178 = function(_) {
return R.isFunction(anf_fun9381179)?anf_fun9381179.app(anf_arg9401180):R.ffi.throwNonFunApp(L[155],anf_fun9381179,[anf_arg9401180]);
};
try {
if(--R.GAS > 0) {
$z11711172 = $f11771178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11771178,
"from":L[155]});
}
} catch($e11691170) {
if(R.isCont($e11691170)) {
var $ss11731174 = {"from":L[155],
"go":function(anf_bracket9411181) {
return $Hanf_bracket21481188(anf_bracket9411181,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,js_DASH_id_DASH_of162700,l3751185,ret3771186,rt_DASH_method173657,self3741187);
}};
$e11691170.stack[R.EXN_STACKHEIGHT++] = $ss11731174;
}
if(R.isPyretException($e11691170)) {
$e11691170.pyretStack.push(L[155]);
}
throw $e11691170;
}
var $ret11751176 = $Hanf_bracket21481188($z11711172,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,js_DASH_id_DASH_of162700,l3751185,ret3771186,rt_DASH_method173657,self3741187);
++R.GAS;
return $ret11751176;
});
};
},{"length":5});
var anf_obj1005882 = R.makeMethod(function(self3791162) {
return function(l3801165,args3811164,ret3821166,body3831168) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[154],4,arguments);
}
return R.checkAnnArgs([Loc7863,List2762,R.getDotAnn(L[151],"N",N432,"AExpr")],[l3801165,args3811164,body3831168],[L[152],L[153],L[151]],function() {
var anf_fun9621161 = G(body3831168,"visit",L[150]);
var $z11531154 = D;
var $f11591160 = function(_) {
return R.isFunction(anf_fun9621161)?anf_fun9621161.app(self3791162):R.ffi.throwNonFunApp(L[149],anf_fun9621161,[self3791162]);
};
try {
if(--R.GAS > 0) {
$z11531154 = $f11591160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11591160,
"from":L[149]});
}
} catch($e11511152) {
if(R.isCont($e11511152)) {
var $ss11551156 = {"from":L[149],
"go":function(anf_bracket9631163) {
return $Hanf_bracket21731167(anf_bracket9631163,args3811164,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,ret3821166,rt_DASH_method173657,self3791162,_minus4);
}};
$e11511152.stack[R.EXN_STACKHEIGHT++] = $ss11551156;
}
if(R.isPyretException($e11511152)) {
$e11511152.pyretStack.push(L[149]);
}
throw $e11511152;
}
var $ret11571158 = $Hanf_bracket21731167($z11531154,args3811164,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,ret3821166,rt_DASH_method173657,self3791162,_minus4);
++R.GAS;
return $ret11571158;
});
};
},{"length":5});
var anf_obj1008883 = R.makeMethod(function(self3851147) {
return function(v3861150) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[146],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[148],"N",N432,"AVal")],[v3861150],[L[148]],function() {
var anf_fun10071146 = G(v3861150,"visit",L[147]);
var $z11381139 = D;
var $f11441145 = function(_) {
return R.isFunction(anf_fun10071146)?anf_fun10071146.app(self3851147):R.ffi.throwNonFunApp(L[146],anf_fun10071146,[self3851147]);
};
try {
if(--R.GAS > 0) {
$z11381139 = $f11441145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11441145,
"from":L[146]});
}
} catch($e11361137) {
if(R.isCont($e11361137)) {
var $ss11401141 = {"from":L[146],
"go":function(ann_DASH_check_DASH_temp10061148) {
return $Hann_DASH_check_DASH_temp21741149(ann_DASH_check_DASH_temp10061148);
}};
$e11361137.stack[R.EXN_STACKHEIGHT++] = $ss11401141;
}
if(R.isPyretException($e11361137)) {
$e11361137.pyretStack.push(L[146]);
}
throw $e11361137;
}
var $ret11421143 = $Hann_DASH_check_DASH_temp21741149($z11381139);
++R.GAS;
return $ret11421143;
});
};
},{"length":2});
var anf_obj1012884 = R.makeMethod(function(self3871130) {
return function(l3881135,name3891132,value3901134) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[145],3,arguments);
}
return R.checkAnnArgs([Loc7863,$type$String17,R.getDotAnn(L[142],"N",N432,"AVal")],[l3881135,name3891132,value3901134],[L[143],L[144],L[142]],function() {
var anf_fun10101129 = G(value3901134,"visit",L[141]);
var $z11211122 = D;
var $f11271128 = function(_) {
return R.isFunction(anf_fun10101129)?anf_fun10101129.app(self3871130):R.ffi.throwNonFunApp(L[140],anf_fun10101129,[self3871130]);
};
try {
if(--R.GAS > 0) {
$z11211122 = $f11271128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11271128,
"from":L[140]});
}
} catch($e11191120) {
if(R.isCont($e11191120)) {
var $ss11231124 = {"from":L[140],
"go":function(anf_arg10111131) {
return $Hanf_arg21761133(anf_arg10111131,j_DASH_field9979,name3891132);
}};
$e11191120.stack[R.EXN_STACKHEIGHT++] = $ss11231124;
}
if(R.isPyretException($e11191120)) {
$e11191120.pyretStack.push(L[140]);
}
throw $e11191120;
}
var $ret11251126 = $Hanf_arg21761133($z11211122,j_DASH_field9979,name3891132);
++R.GAS;
return $ret11251126;
});
};
},{"length":4});
var anf_obj1019885 = R.makeMethod(function(self3911114) {
return function(l3921118,values3931117) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[139],2,arguments);
}
var anf_fun10141098 = G(values3931117,"map",L[138]);
var anf_arg10171099 = R.makeFunction(function(recv_DASH_611102) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[137],1,arguments);
}
var anf_fun10161113 = G(recv_DASH_611102,"visit",L[137]);
var $z11051106 = D;
var $f11111112 = function(_) {
return R.isFunction(anf_fun10161113)?anf_fun10161113.app(self3911114):R.ffi.throwNonFunApp(L[137],anf_fun10161113,[self3911114]);
};
try {
if(--R.GAS > 0) {
$z11051106 = $f11111112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11111112,
"from":L[137]});
}
} catch($e11031104) {
if(R.isCont($e11031104)) {
var $ss11071108 = {"from":L[137],
"go":function(ann_DASH_check_DASH_temp10151115) {
return $Hann_DASH_check_DASH_temp21771116(ann_DASH_check_DASH_temp10151115);
}};
$e11031104.stack[R.EXN_STACKHEIGHT++] = $ss11071108;
}
if(R.isPyretException($e11031104)) {
$e11031104.pyretStack.push(L[137]);
}
throw $e11031104;
}
var $ret11091110 = $Hann_DASH_check_DASH_temp21771116($z11051106);
++R.GAS;
return $ret11091110;
});
var $z10901091 = D;
var $f10961097 = function(_) {
return R.isFunction(anf_fun10141098)?anf_fun10141098.app(anf_arg10171099):R.ffi.throwNonFunApp(L[136],anf_fun10141098,[anf_arg10171099]);
};
try {
if(--R.GAS > 0) {
$z10901091 = $f10961097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10961097,
"from":L[136]});
}
} catch($e10881089) {
if(R.isCont($e10881089)) {
var $ss10921093 = {"from":L[136],
"go":function(anf_arg10181100) {
return $Hanf_arg21791101(anf_arg10181100,j_DASH_list9585);
}};
$e10881089.stack[R.EXN_STACKHEIGHT++] = $ss10921093;
}
if(R.isPyretException($e10881089)) {
$e10881089.pyretStack.push(L[136]);
}
throw $e10881089;
}
var $ret10941095 = $Hanf_arg21791101($z10901091,j_DASH_list9585);
++R.GAS;
return $ret10941095;
};
},{"length":3});
var anf_obj1022886 = R.makeMethod(function(self3941086) {
return function(l3951087,loc3961083) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[134],2,arguments);
}
var anf_fun10211082 = G(self3941086,"get-loc",L[135]);
var $z10741075 = D;
var $f10801081 = function(_) {
return R.isFunction(anf_fun10211082)?anf_fun10211082.app(loc3961083):R.ffi.throwNonFunApp(L[134],anf_fun10211082,[loc3961083]);
};
try {
if(--R.GAS > 0) {
$z10741075 = $f10801081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10801081,
"from":L[134]});
}
} catch($e10721073) {
if(R.isCont($e10721073)) {
var $ss10761077 = {"from":L[134],
"go":function(ann_DASH_check_DASH_temp10201084) {
return $Hann_DASH_check_DASH_temp21801085(ann_DASH_check_DASH_temp10201084);
}};
$e10721073.stack[R.EXN_STACKHEIGHT++] = $ss10761077;
}
if(R.isPyretException($e10721073)) {
$e10721073.pyretStack.push(L[134]);
}
throw $e10721073;
}
var $ret10781079 = $Hann_DASH_check_DASH_temp21801085($z10741075);
++R.GAS;
return $ret10781079;
};
},{"length":3});
var anf_obj1038887 = R.makeMethod(function(self3971071) {
return function(l3981070,n3991067) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[133],2,arguments);
}
return R.checkAnnArgs([Loc7863,$type$Number16],[l3981070,n3991067],[L[131],L[132]],function() {
var $z10591060 = D;
var $f10651066 = function(_) {
return R.isFunction(num_DASH_is_DASH_fixnum10)?num_DASH_is_DASH_fixnum10.app(n3991067):R.ffi.throwNonFunApp(L[130],num_DASH_is_DASH_fixnum10,[n3991067]);
};
try {
if(--R.GAS > 0) {
$z10591060 = $f10651066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10651066,
"from":L[130]});
}
} catch($e10571058) {
if(R.isCont($e10571058)) {
var $ss10611062 = {"from":L[130],
"go":function(if_DASH_621068) {
return $Hif_DASH_21871069(if_DASH_621068,j_DASH_num8889,j_DASH_parens11391,j_DASH_str8993,list35101,n3991067,rt_DASH_method173657,tostring14);
}};
$e10571058.stack[R.EXN_STACKHEIGHT++] = $ss10611062;
}
if(R.isPyretException($e10571058)) {
$e10571058.pyretStack.push(L[130]);
}
throw $e10571058;
}
var $ret10631064 = $Hif_DASH_21871069($z10591060,j_DASH_num8889,j_DASH_parens11391,j_DASH_str8993,list35101,n3991067,rt_DASH_method173657,tostring14);
++R.GAS;
return $ret10631064;
});
};
},{"length":3});
var anf_obj1041888 = R.makeMethod(function(self4001056) {
return function(l4011055,s4021052) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[129],2,arguments);
}
return R.checkAnnArgs([Loc7863,$type$String17],[l4011055,s4021052],[L[127],L[128]],function() {
var $z10441045 = D;
var $f10501051 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(s4021052):R.ffi.throwNonFunApp(L[126],j_DASH_str8993,[s4021052]);
};
try {
if(--R.GAS > 0) {
$z10441045 = $f10501051();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10501051,
"from":L[126]});
}
} catch($e10421043) {
if(R.isCont($e10421043)) {
var $ss10461047 = {"from":L[126],
"go":function(anf_arg10401053) {
return $Hanf_arg21891054(anf_arg10401053,j_DASH_parens11391);
}};
$e10421043.stack[R.EXN_STACKHEIGHT++] = $ss10461047;
}
if(R.isPyretException($e10421043)) {
$e10421043.pyretStack.push(L[126]);
}
throw $e10421043;
}
var $ret10481049 = $Hanf_arg21891054($z10441045,j_DASH_parens11391);
++R.GAS;
return $ret10481049;
});
};
},{"length":3});
var anf_obj1050889 = R.makeMethod(function(self4031041) {
return function(l4041040,b4051039) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[123],2,arguments);
}
return R.checkAnnArgs([Loc7863,$type$Boolean15],[l4041040,b4051039],[L[124],L[125]],function() {
var if_DASH_631021 = b4051039;
var if_helper10431006 = R.makeFunction(function(if_helper_arg10441026) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[122],1,arguments);
}
var $z10291030 = D;
var $f10351036 = function(_) {
return R.isFunction(j_DASH_parens11391)?j_DASH_parens11391.app(if_helper_arg10441026):R.ffi.throwNonFunApp(L[123],j_DASH_parens11391,[if_helper_arg10441026]);
};
try {
if(--R.GAS > 0) {
$z10291030 = $f10351036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10351036,
"from":L[123]});
}
} catch($e10271028) {
if(R.isCont($e10271028)) {
var $ss10311032 = {"from":L[123],
"go":function(ann_DASH_check_DASH_temp10421037) {
return $Hann_DASH_check_DASH_temp21901038(ann_DASH_check_DASH_temp10421037);
}};
$e10271028.stack[R.EXN_STACKHEIGHT++] = $ss10311032;
}
if(R.isPyretException($e10271028)) {
$e10271028.pyretStack.push(L[123]);
}
throw $e10271028;
}
var $ret10331034 = $Hann_DASH_check_DASH_temp21901038($z10291030);
++R.GAS;
return $ret10331034;
});
var anf_if10471025 = R.isBoolean(if_DASH_631021);
if(R.isPyretTrue(anf_if10471025)) {
if(R.isPyretTrue(if_DASH_631021)) {
var $z998999 = D;
var $f10041005 = function(_) {
return R.isFunction(if_helper10431006)?if_helper10431006.app(j_DASH_true8696):R.ffi.throwNonFunApp(L[120],if_helper10431006,[j_DASH_true8696]);
};
try {
if(--R.GAS > 0) {
$z998999 = $f10041005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10041005,
"from":L[120]});
}
} catch($e996997) {
if(R.isCont($e996997)) {
var $ss10001001 = {"from":L[120],
"go":function(cont_tail_app10491007) {
return $Hcont_tail_app21911008(cont_tail_app10491007);
}};
$e996997.stack[R.EXN_STACKHEIGHT++] = $ss10001001;
}
if(R.isPyretException($e996997)) {
$e996997.pyretStack.push(L[120]);
}
throw $e996997;
}
var $ret10021003 = $Hcont_tail_app21911008($z998999);
++R.GAS;
return $ret10021003;
} else {
var $z10111012 = D;
var $f10171018 = function(_) {
return R.isFunction(if_helper10431006)?if_helper10431006.app(j_DASH_false8778):R.ffi.throwNonFunApp(L[121],if_helper10431006,[j_DASH_false8778]);
};
try {
if(--R.GAS > 0) {
$z10111012 = $f10171018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10171018,
"from":L[121]});
}
} catch($e10091010) {
if(R.isCont($e10091010)) {
var $ss10131014 = {"from":L[121],
"go":function(cont_tail_app10481019) {
return $Hcont_tail_app21921020(cont_tail_app10481019);
}};
$e10091010.stack[R.EXN_STACKHEIGHT++] = $ss10131014;
}
if(R.isPyretException($e10091010)) {
$e10091010.pyretStack.push(L[121]);
}
throw $e10091010;
}
var $ret10151016 = $Hcont_tail_app21921020($z10111012);
++R.GAS;
return $ret10151016;
}
} else {
var cont_tail_arg10451024 = R.throwNonBooleanCondition(L[122],("if"),if_DASH_631021);
if(--R.GAS > 0) {
$z10221023 = R.isFunction(if_helper10431006)?if_helper10431006.app(cont_tail_arg10451024):R.ffi.throwNonFunApp(L[122],if_helper10431006,[cont_tail_arg10451024]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper10431006)?if_helper10431006.app(cont_tail_arg10451024):R.ffi.throwNonFunApp(L[122],if_helper10431006,[cont_tail_arg10451024]);
},
"from":L[122]});
}
++R.GAS;
return $z10221023;
}
});
};
},{"length":3});
var anf_obj1052890 = R.makeMethod(function(self406995) {
return function(l407994) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[119],1,arguments);
}
return R.checkAnnArgs([Loc7863],[l407994],[L[118]],function() {
var ann_DASH_check_DASH_temp1051993 = undefined117140;
return ann_DASH_check_DASH_temp1051993;
});
};
},{"length":2});
var anf_obj1057891 = R.makeMethod(function(self408992) {
return function(l409991,id410990) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[117],2,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[115],"A",A231,"Name")],[l409991,id410990],[L[116],L[115]],function() {
var anf_fun1054987 = G(id410990,"tostring",L[114]);
var $z979980 = D;
var $f985986 = function(_) {
return R.isFunction(anf_fun1054987)?anf_fun1054987.app():R.ffi.throwNonFunApp(L[113],anf_fun1054987,[]);
};
try {
if(--R.GAS > 0) {
$z979980 = $f985986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f985986,
"from":L[113]});
}
} catch($e977978) {
if(R.isCont($e977978)) {
var $ss981982 = {"from":L[113],
"go":function(anf_arg1055988) {
return $Hanf_arg2195989(anf_arg1055988,j_DASH_id8381,js_DASH_id_DASH_of162700);
}};
$e977978.stack[R.EXN_STACKHEIGHT++] = $ss981982;
}
if(R.isPyretException($e977978)) {
$e977978.pyretStack.push(L[113]);
}
throw $e977978;
}
var $ret983984 = $Hanf_arg2195989($z979980,j_DASH_id8381,js_DASH_id_DASH_of162700);
++R.GAS;
return $ret983984;
});
};
},{"length":3});
var anf_obj1063892 = R.makeMethod(function(self411976) {
return function(l412975,id413974) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[112],2,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[110],"A",A231,"Name")],[l412975,id413974],[L[111],L[110]],function() {
var anf_fun1059971 = G(id413974,"tostring",L[109]);
var $z963964 = D;
var $f969970 = function(_) {
return R.isFunction(anf_fun1059971)?anf_fun1059971.app():R.ffi.throwNonFunApp(L[108],anf_fun1059971,[]);
};
try {
if(--R.GAS > 0) {
$z963964 = $f969970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f969970,
"from":L[108]});
}
} catch($e961962) {
if(R.isCont($e961962)) {
var $ss965966 = {"from":L[108],
"go":function(anf_arg1060972) {
return $Hanf_arg2199973(anf_arg1060972,j_DASH_dot9775,j_DASH_id8381,js_DASH_id_DASH_of162700);
}};
$e961962.stack[R.EXN_STACKHEIGHT++] = $ss965966;
}
if(R.isPyretException($e961962)) {
$e961962.pyretStack.push(L[108]);
}
throw $e961962;
}
var $ret967968 = $Hanf_arg2199973($z963964,j_DASH_dot9775,j_DASH_id8381,js_DASH_id_DASH_of162700);
++R.GAS;
return $ret967968;
});
};
},{"length":3});
var anf_obj1089893 = R.makeMethod(function(self414959) {
return function(l415957,id416956,safe417958) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[107],3,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[104],"A",A231,"Name"),$type$Boolean15],[l415957,id416956,safe417958],[L[105],L[104],L[106]],function() {
var anf_fun1065954 = G(id416956,"tostring",L[103]);
var $z946947 = D;
var $f952953 = function(_) {
return R.isFunction(anf_fun1065954)?anf_fun1065954.app():R.ffi.throwNonFunApp(L[102],anf_fun1065954,[]);
};
try {
if(--R.GAS > 0) {
$z946947 = $f952953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f952953,
"from":L[102]});
}
} catch($e944945) {
if(R.isCont($e944945)) {
var $ss948949 = {"from":L[102],
"go":function(s418955) {
return $Hs2214960(s418955,id416956,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,safe417958,self414959,undefined117140);
}};
$e944945.stack[R.EXN_STACKHEIGHT++] = $ss948949;
}
if(R.isPyretException($e944945)) {
$e944945.pyretStack.push(L[102]);
}
throw $e944945;
}
var $ret950951 = $Hs2214960($z946947,id416956,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,safe417958,self414959,undefined117140);
++R.GAS;
return $ret950951;
});
};
},{"length":4});
var anf_obj1264894 = R.makeMethod(function(self419913) {
return function(l420910,name421911,namet422912,variants423914,shared424930) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[101],5,arguments);
}
var brand_DASH_name425895 = {"$var":D,
"$name":"brand-name"};
var anf_assign1093896 = R.makeFunction(function(base426931) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[99],1,arguments);
}
var $z934935 = D;
var $f940941 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("brand-"),base426931):R.ffi.throwNonFunApp(L[100],_plus5,[("brand-"),base426931]);
};
try {
if(--R.GAS > 0) {
$z934935 = $f940941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f940941,
"from":L[100]});
}
} catch($e932933) {
if(R.isCont($e932933)) {
var $ss936937 = {"from":L[100],
"go":function(anf_arg1092942) {
return $Hanf_arg2216943(anf_arg1092942,compiler_DASH_name167645);
}};
$e932933.stack[R.EXN_STACKHEIGHT++] = $ss936937;
}
if(R.isPyretException($e932933)) {
$e932933.pyretStack.push(L[100]);
}
throw $e932933;
}
var $ret938939 = $Hanf_arg2216943($z934935,compiler_DASH_name167645);
++R.GAS;
return $ret938939;
});
brand_DASH_name425895.$var = anf_assign1093896;
var anf_fun1094907 = G(shared424930,"map",L[98]);
var anf_arg1097908 = R.makeFunction(function(recv_DASH_65916) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[97],1,arguments);
}
var anf_fun1096927 = G(recv_DASH_65916,"visit",L[97]);
var $z919920 = D;
var $f925926 = function(_) {
return R.isFunction(anf_fun1096927)?anf_fun1096927.app(self419913):R.ffi.throwNonFunApp(L[97],anf_fun1096927,[self419913]);
};
try {
if(--R.GAS > 0) {
$z919920 = $f925926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f925926,
"from":L[97]});
}
} catch($e917918) {
if(R.isCont($e917918)) {
var $ss921922 = {"from":L[97],
"go":function(ann_DASH_check_DASH_temp1095928) {
return $Hann_DASH_check_DASH_temp2217929(ann_DASH_check_DASH_temp1095928);
}};
$e917918.stack[R.EXN_STACKHEIGHT++] = $ss921922;
}
if(R.isPyretException($e917918)) {
$e917918.pyretStack.push(L[97]);
}
throw $e917918;
}
var $ret923924 = $Hann_DASH_check_DASH_temp2217929($z919920);
++R.GAS;
return $ret923924;
});
var $z899900 = D;
var $f905906 = function(_) {
return R.isFunction(anf_fun1094907)?anf_fun1094907.app(anf_arg1097908):R.ffi.throwNonFunApp(L[96],anf_fun1094907,[anf_arg1097908]);
};
try {
if(--R.GAS > 0) {
$z899900 = $f905906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f905906,
"from":L[96]});
}
} catch($e897898) {
if(R.isCont($e897898)) {
var $ss901902 = {"from":L[96],
"go":function(shared_DASH_fields427909) {
return $Hshared_DASH_fields2326915(shared_DASH_fields427909,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,namet422912,rt_DASH_method173657,self419913,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17);
}};
$e897898.stack[R.EXN_STACKHEIGHT++] = $ss901902;
}
if(R.isPyretException($e897898)) {
$e897898.pyretStack.push(L[96]);
}
throw $e897898;
}
var $ret903904 = $Hshared_DASH_fields2326915($z899900,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,namet422912,rt_DASH_method173657,self419913,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17);
++R.GAS;
return $ret903904;
};
},{"length":6});
var compiler_DASH_visitor288699 = R.makeObject({"a-module":anf_obj694865,
"a-type-let":anf_obj741866,
"a-let":anf_obj804867,
"a-var":anf_obj825868,
"a-tail-app":anf_obj827869,
"a-split-app":anf_obj829870,
"a-seq":anf_obj851871,
"a-if":anf_obj863872,
"a-lettable":anf_obj870873,
"a-assign":anf_obj878874,
"a-app":anf_obj889875,
"a-prim-app":anf_obj896876,
"a-obj":anf_obj909877,
"a-extend":anf_obj921878,
"a-dot":anf_obj928879,
"a-colon":anf_obj935880,
"a-lam":anf_obj960881,
"a-method":anf_obj1005882,
"a-val":anf_obj1008883,
"a-field":anf_obj1012884,
"a-array":anf_obj1019885,
"a-srcloc":anf_obj1022886,
"a-num":anf_obj1038887,
"a-str":anf_obj1041888,
"a-bool":anf_obj1050889,
"a-undefined":anf_obj1052890,
"a-id":anf_obj1057891,
"a-id-var":anf_obj1063892,
"a-id-letrec":anf_obj1089893,
"a-data-expr":anf_obj1264894});
var anf_extend1265791 = G(N319,"default-map-visitor",L[95]);
var anf_extend1291792 = R.makeMethod(function(self473819) {
return function(l474823,c475826,t476824,e477822) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[84],4,arguments);
}
var cases_DASH_val71864 = c475826;
var anf_fun1267803 = G(cases_DASH_val71864,"_match",L[85]);
var anf_obj1280827 = R.makeFunction(function($underscore478828,test479829) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[89],2,arguments);
}
var if_DASH_70857 = test479829;
var if_helper1269842 = R.makeFunction(function(if_helper_arg1270862) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[94],1,arguments);
}
var ann_DASH_check_DASH_temp1268863 = if_helper_arg1270862;
return ann_DASH_check_DASH_temp1268863;
});
var anf_if1273861 = R.isBoolean(if_DASH_70857);
if(R.isPyretTrue(anf_if1273861)) {
if(R.isPyretTrue(if_DASH_70857)) {
var anf_fun1277840 = G(t476824,"visit",L[91]);
var $z832833 = D;
var $f838839 = function(_) {
return R.isFunction(anf_fun1277840)?anf_fun1277840.app(self473819):R.ffi.throwNonFunApp(L[90],anf_fun1277840,[self473819]);
};
try {
if(--R.GAS > 0) {
$z832833 = $f838839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f838839,
"from":L[90]});
}
} catch($e830831) {
if(R.isCont($e830831)) {
var $ss834835 = {"from":L[90],
"go":function(cont_tail_arg1278841) {
return $Hcont_tail_arg2327843(cont_tail_arg1278841,if_helper1269842);
}};
$e830831.stack[R.EXN_STACKHEIGHT++] = $ss834835;
}
if(R.isPyretException($e830831)) {
$e830831.pyretStack.push(L[90]);
}
throw $e830831;
}
var $ret836837 = $Hcont_tail_arg2327843($z832833,if_helper1269842);
++R.GAS;
return $ret836837;
} else {
var anf_fun1274854 = G(e477822,"visit",L[93]);
var $z846847 = D;
var $f852853 = function(_) {
return R.isFunction(anf_fun1274854)?anf_fun1274854.app(self473819):R.ffi.throwNonFunApp(L[92],anf_fun1274854,[self473819]);
};
try {
if(--R.GAS > 0) {
$z846847 = $f852853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f852853,
"from":L[92]});
}
} catch($e844845) {
if(R.isCont($e844845)) {
var $ss848849 = {"from":L[92],
"go":function(cont_tail_arg1275855) {
return $Hcont_tail_arg2328856(cont_tail_arg1275855,if_helper1269842);
}};
$e844845.stack[R.EXN_STACKHEIGHT++] = $ss848849;
}
if(R.isPyretException($e844845)) {
$e844845.pyretStack.push(L[92]);
}
throw $e844845;
}
var $ret850851 = $Hcont_tail_arg2328856($z846847,if_helper1269842);
++R.GAS;
return $ret850851;
}
} else {
var cont_tail_arg1271860 = R.throwNonBooleanCondition(L[94],("if"),if_DASH_70857);
if(--R.GAS > 0) {
$z858859 = R.isFunction(if_helper1269842)?if_helper1269842.app(cont_tail_arg1271860):R.ffi.throwNonFunApp(L[94],if_helper1269842,[cont_tail_arg1271860]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper1269842)?if_helper1269842.app(cont_tail_arg1271860):R.ffi.throwNonFunApp(L[94],if_helper1269842,[cont_tail_arg1271860]);
},
"from":L[94]});
}
++R.GAS;
return $z858859;
}
});
var anf_arg1281804 = R.makeObject({"a-bool":anf_obj1280827});
var anf_arg1290805 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[85],0,arguments);
}
var anf_fun1283821 = G(N319,"a-if",L[88]);
var anf_fun1284818 = G(c475826,"visit",L[87]);
var $z810811 = D;
var $f816817 = function(_) {
return R.isFunction(anf_fun1284818)?anf_fun1284818.app(self473819):R.ffi.throwNonFunApp(L[86],anf_fun1284818,[self473819]);
};
try {
if(--R.GAS > 0) {
$z810811 = $f816817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f816817,
"from":L[86]});
}
} catch($e808809) {
if(R.isCont($e808809)) {
var $ss812813 = {"from":L[86],
"go":function(anf_arg1285820) {
return $Hanf_arg2332825(anf_arg1285820,anf_fun1283821,e477822,l474823,self473819,t476824);
}};
$e808809.stack[R.EXN_STACKHEIGHT++] = $ss812813;
}
if(R.isPyretException($e808809)) {
$e808809.pyretStack.push(L[86]);
}
throw $e808809;
}
var $ret814815 = $Hanf_arg2332825($z810811,anf_fun1283821,e477822,l474823,self473819,t476824);
++R.GAS;
return $ret814815;
});
var $z795796 = D;
var $f801802 = function(_) {
return R.isFunction(anf_fun1267803)?anf_fun1267803.app(anf_arg1281804,anf_arg1290805):R.ffi.throwNonFunApp(L[84],anf_fun1267803,[anf_arg1281804,anf_arg1290805]);
};
try {
if(--R.GAS > 0) {
$z795796 = $f801802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f801802,
"from":L[84]});
}
} catch($e793794) {
if(R.isCont($e793794)) {
var $ss797798 = {"from":L[84],
"go":function(ann_DASH_check_DASH_temp1266806) {
return $Hann_DASH_check_DASH_temp2333807(ann_DASH_check_DASH_temp1266806);
}};
$e793794.stack[R.EXN_STACKHEIGHT++] = $ss797798;
}
if(R.isPyretException($e793794)) {
$e793794.pyretStack.push(L[84]);
}
throw $e793794;
}
var $ret799800 = $Hann_DASH_check_DASH_temp2333807($z795796);
++R.GAS;
return $ret799800;
};
},{"length":5});
var remove_DASH_useless_DASH_if_DASH_visitor472701 = anf_extend1265791.extendWith({"a-if":anf_extend1291792});
nothing9;
var mk_DASH_abbrevs480679 = {"$var":D,
"$name":"mk-abbrevs"};
var compile_DASH_program481681 = {"$var":D,
"$name":"compile-program"};
var splitting_DASH_compiler482683 = {"$var":D,
"$name":"splitting-compiler"};
var non_DASH_splitting_DASH_compiler483685 = {"$var":D,
"$name":"non-splitting-compiler"};
var anf_assign1314680 = R.makeFunction(function(l484777) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[81],1,arguments);
}
var anf_fun1293789 = G(list35101,"make",L[83]);
var $z780781 = D;
var $f786787 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("getFieldLoc")):R.ffi.throwNonFunApp(L[82],rt_DASH_field172655.$var,[("getFieldLoc")]);
};
try {
if(--R.GAS > 0) {
$z780781 = $f786787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f786787,
"from":L[82]});
}
} catch($e778779) {
if(R.isCont($e778779)) {
var $ss782783 = {"from":L[82],
"go":function(anf_arg1294788) {
return $Hanf_arg2350790(anf_arg1294788,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655);
}};
$e778779.stack[R.EXN_STACKHEIGHT++] = $ss782783;
}
if(R.isPyretException($e778779)) {
$e778779.pyretStack.push(L[82]);
}
throw $e778779;
}
var $ret784785 = $Hanf_arg2350790($z780781,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655);
++R.GAS;
return $ret784785;
});
mk_DASH_abbrevs480679.$var = anf_assign1314680;
var anf_assign1526682 = R.makeFunction(function(self485744,l486745,headers487746,split488747,env489748) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[76],5,arguments);
}
var inst490749 = {"$var":D,
"$name":"inst"};
var anf_assign1322750 = R.makeFunction(function(id491764) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[79],1,arguments);
}
var $z767768 = D;
var $f773774 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(id491764):R.ffi.throwNonFunApp(L[80],j_DASH_id8381,[id491764]);
};
try {
if(--R.GAS > 0) {
$z767768 = $f773774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f773774,
"from":L[80]});
}
} catch($e765766) {
if(R.isCont($e765766)) {
var $ss769770 = {"from":L[80],
"go":function(anf_arg1317775) {
return $Hanf_arg2355776(anf_arg1317775,j_DASH_app9467,j_DASH_id8381,list35101);
}};
$e765766.stack[R.EXN_STACKHEIGHT++] = $ss769770;
}
if(R.isPyretException($e765766)) {
$e765766.pyretStack.push(L[80]);
}
throw $e765766;
}
var $ret771772 = $Hanf_arg2355776($z767768,j_DASH_app9467,j_DASH_id8381,list35101);
++R.GAS;
return $ret771772;
});
inst490749.$var = anf_assign1322750;
var anf_fun1323761 = G(S520,"freevars-split-result",L[78]);
var $z753754 = D;
var $f759760 = function(_) {
return R.isFunction(anf_fun1323761)?anf_fun1323761.app(split488747):R.ffi.throwNonFunApp(L[77],anf_fun1323761,[split488747]);
};
try {
if(--R.GAS > 0) {
$z753754 = $f759760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f759760,
"from":L[77]});
}
} catch($e751752) {
if(R.isCont($e751752)) {
var $ss755756 = {"from":L[77],
"go":function(anf_bracket1324762) {
return $Hanf_bracket2482763(anf_bracket1324762,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13);
}};
$e751752.stack[R.EXN_STACKHEIGHT++] = $ss755756;
}
if(R.isPyretException($e751752)) {
$e751752.pyretStack.push(L[77]);
}
throw $e751752;
}
var $ret757758 = $Hanf_bracket2482763($z753754,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13);
++R.GAS;
return $ret757758;
});
compile_DASH_program481681.$var = anf_assign1526682;
var anf_assign1532684 = R.makeFunction(function(env536724) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[72],1,arguments);
}
var anf_extend1531726 = R.makeMethod(function(self537741) {
return function(l538740,headers539739,body540743) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[75],3,arguments);
}
var anf_fun1529737 = G(body540743,"visit",L[74]);
var $z729730 = D;
var $f735736 = function(_) {
return R.isFunction(anf_fun1529737)?anf_fun1529737.app(remove_DASH_useless_DASH_if_DASH_visitor472701):R.ffi.throwNonFunApp(L[73],anf_fun1529737,[remove_DASH_useless_DASH_if_DASH_visitor472701]);
};
try {
if(--R.GAS > 0) {
$z729730 = $f735736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f735736,
"from":L[73]});
}
} catch($e727728) {
if(R.isCont($e727728)) {
var $ss731732 = {"from":L[73],
"go":function(simplified541738) {
return $Hsimplified2485742(simplified541738,S520,compile_DASH_program481681,env536724,headers539739,l538740,self537741);
}};
$e727728.stack[R.EXN_STACKHEIGHT++] = $ss731732;
}
if(R.isPyretException($e727728)) {
$e727728.pyretStack.push(L[73]);
}
throw $e727728;
}
var $ret733734 = $Hsimplified2485742($z729730,S520,compile_DASH_program481681,env536724,headers539739,l538740,self537741);
++R.GAS;
return $ret733734;
};
},{"length":4});
var ann_DASH_check_DASH_temp1527725 = compiler_DASH_visitor288699.extendWith({"a-program":anf_extend1531726});
return ann_DASH_check_DASH_temp1527725;
});
splitting_DASH_compiler482683.$var = anf_assign1532684;
var anf_assign1542686 = R.makeFunction(function(env543704) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[68],1,arguments);
}
var anf_extend1541706 = R.makeMethod(function(self544721) {
return function(l545720,headers546719,body547723) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[71],3,arguments);
}
var anf_fun1535717 = G(body547723,"visit",L[70]);
var $z709710 = D;
var $f715716 = function(_) {
return R.isFunction(anf_fun1535717)?anf_fun1535717.app(remove_DASH_useless_DASH_if_DASH_visitor472701):R.ffi.throwNonFunApp(L[69],anf_fun1535717,[remove_DASH_useless_DASH_if_DASH_visitor472701]);
};
try {
if(--R.GAS > 0) {
$z709710 = $f715716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f715716,
"from":L[69]});
}
} catch($e707708) {
if(R.isCont($e707708)) {
var $ss711712 = {"from":L[69],
"go":function(simplified548718) {
return $Hsimplified2490722(simplified548718,N319,S520,compile_DASH_program481681,env543704,headers546719,l545720,list35101,self544721);
}};
$e707708.stack[R.EXN_STACKHEIGHT++] = $ss711712;
}
if(R.isPyretException($e707708)) {
$e707708.pyretStack.push(L[69]);
}
throw $e707708;
}
var $ret713714 = $Hsimplified2490722($z709710,N319,S520,compile_DASH_program481681,env543704,headers546719,l545720,list35101,self544721);
++R.GAS;
return $ret713714;
};
},{"length":4});
var ann_DASH_check_DASH_temp1533705 = compiler_DASH_visitor288699.extendWith({"a-program":anf_extend1541706});
return ann_DASH_check_DASH_temp1533705;
});
non_DASH_splitting_DASH_compiler483685.$var = anf_assign1542686;
var result_DASH_after_DASH_checks1550702 = nothing9;
var anf_fun1543697 = G(builtins6,"current-checker",L[67]);
var $z689690 = D;
var $f695696 = function(_) {
return R.isFunction(anf_fun1543697)?anf_fun1543697.app():R.ffi.throwNonFunApp(L[67],anf_fun1543697,[]);
};
try {
if(--R.GAS > 0) {
$z689690 = $f695696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f695696,
"from":L[67]});
}
} catch($e687688) {
if(R.isCont($e687688)) {
var $ss691692 = {"from":L[67],
"go":function(anf_bracket1544698) {
return $Hanf_bracket2534703(anf_bracket1544698,A118,ConcatList119144,ConcatList7660,Loc7863,N319,add_DASH_stack_DASH_frame171653,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6);
}};
$e687688.stack[R.EXN_STACKHEIGHT++] = $ss691692;
}
if(R.isPyretException($e687688)) {
$e687688.pyretStack.push(L[67]);
}
throw $e687688;
}
var $ret693694 = $Hanf_bracket2534703($z689690,A118,ConcatList119144,ConcatList7660,Loc7863,N319,add_DASH_stack_DASH_frame171653,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6);
++R.GAS;
return $ret693694;
};
var $Hanf_bracket2534703 = function(anf_bracket1544698,A118,ConcatList119144,ConcatList7660,Loc7863,N319,add_DASH_stack_DASH_frame171653,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6) {
var anf_fun15452089 = G(anf_bracket1544698,"run-checks",L[67]);
var anf_fun15462086 = G(list35101,"make",L[67]);
var anf_obj16092091 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[348],0,arguments);
}
var d5512104 = G(N319,"dummy-loc",L[356]);
var e5522107 = R.makeFunction(function(v5532109) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[352],1,arguments);
}
var anf_fun15492122 = G(N319,"a-lettable",L[355]);
var anf_fun15502120 = G(N319,"a-val",L[354]);
var $z21122113 = D;
var $f21182119 = function(_) {
return R.isFunction(anf_fun15502120)?anf_fun15502120.app(v5532109):R.ffi.throwNonFunApp(L[353],anf_fun15502120,[v5532109]);
};
try {
if(--R.GAS > 0) {
$z21122113 = $f21182119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21182119,
"from":L[353]});
}
} catch($e21102111) {
if(R.isCont($e21102111)) {
var $ss21142115 = {"from":L[353],
"go":function(anf_arg15512121) {
return $Hanf_arg24922123(anf_arg15512121,anf_fun15492122);
}};
$e21102111.stack[R.EXN_STACKHEIGHT++] = $ss21142115;
}
if(R.isPyretException($e21102111)) {
$e21102111.pyretStack.push(L[353]);
}
throw $e21102111;
}
var $ret21162117 = $Hanf_arg24922123($z21122113,anf_fun15492122);
++R.GAS;
return $ret21162117;
});
var anf_fun15522106 = G(N319,"a-if",L[351]);
var anf_fun15532103 = G(N319,"a-bool",L[350]);
var $z20952096 = D;
var $f21012102 = function(_) {
return R.isFunction(anf_fun15532103)?anf_fun15532103.app(d5512104,(true)):R.ffi.throwNonFunApp(L[349],anf_fun15532103,[d5512104,(true)]);
};
try {
if(--R.GAS > 0) {
$z20952096 = $f21012102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21012102,
"from":L[349]});
}
} catch($e20932094) {
if(R.isCont($e20932094)) {
var $ss20972098 = {"from":L[349],
"go":function(anf_arg15542105) {
return $Hanf_arg25282108(anf_arg15542105,A118,N319,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
}};
$e20932094.stack[R.EXN_STACKHEIGHT++] = $ss20972098;
}
if(R.isPyretException($e20932094)) {
$e20932094.pyretStack.push(L[349]);
}
throw $e20932094;
}
var $ret20992100 = $Hanf_arg25282108($z20952096,A118,N319,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
++R.GAS;
return $ret20992100;
});
var anf_obj16102092 = R.makeSrcloc(L[348]);
var anf_array_val16112087 = R.makeObject({"name":("check-block-1"),
"run":anf_obj16092091,
"location":anf_obj16102092});
var $z20782079 = D;
var $f20842085 = function(_) {
return R.isFunction(anf_fun15462086)?anf_fun15462086.app([anf_array_val16112087]):R.ffi.throwNonFunApp(L[67],anf_fun15462086,[[anf_array_val16112087]]);
};
try {
if(--R.GAS > 0) {
$z20782079 = $f20842085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20842085,
"from":L[67]});
}
} catch($e20762077) {
if(R.isCont($e20762077)) {
var $ss20802081 = {"from":L[67],
"go":function(anf_arg16122088) {
return $Hanf_arg25332090(anf_arg16122088,ConcatList119144,ConcatList7660,Loc7863,add_DASH_stack_DASH_frame171653,anf_fun15452089,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6);
}};
$e20762077.stack[R.EXN_STACKHEIGHT++] = $ss20802081;
}
if(R.isPyretException($e20762077)) {
$e20762077.pyretStack.push(L[67]);
}
throw $e20762077;
}
var $ret20822083 = $Hanf_arg25332090($z20782079,ConcatList119144,ConcatList7660,Loc7863,add_DASH_stack_DASH_frame171653,anf_fun15452089,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6);
++R.GAS;
return $ret20822083;
};
var $Hanf_arg25332090 = function(anf_arg16122088,ConcatList119144,ConcatList7660,Loc7863,add_DASH_stack_DASH_frame171653,anf_fun15452089,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6) {
var $z21262127 = D;
var $f21322133 = function(_) {
return R.isFunction(anf_fun15452089)?anf_fun15452089.app(("src/arr/compiler/anf-visitor-compiler.arr"),anf_arg16122088):R.ffi.throwNonFunApp(L[67],anf_fun15452089,[("src/arr/compiler/anf-visitor-compiler.arr"),anf_arg16122088]);
};
try {
if(--R.GAS > 0) {
$z21262127 = $f21322133();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21322133,
"from":L[67]});
}
} catch($e21242125) {
if(R.isCont($e21242125)) {
var $ss21282129 = {"from":L[67],
"go":function(anf_begin_app_dropped25292134) {
return $Hanf_begin_app_dropped25322135(anf_begin_app_dropped25292134,ConcatList119144,ConcatList7660,Loc7863,add_DASH_stack_DASH_frame171653,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6);
}};
$e21242125.stack[R.EXN_STACKHEIGHT++] = $ss21282129;
}
if(R.isPyretException($e21242125)) {
$e21242125.pyretStack.push(L[67]);
}
throw $e21242125;
}
var $ret21302131 = $Hanf_begin_app_dropped25322135($z21262127,ConcatList119144,ConcatList7660,Loc7863,add_DASH_stack_DASH_frame171653,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6);
++R.GAS;
return $ret21302131;
};
var $Hanf_begin_app_dropped25322135 = function(anf_begin_app_dropped25292134,ConcatList119144,ConcatList7660,Loc7863,add_DASH_stack_DASH_frame171653,app174659,arity_DASH_check182675,compile_DASH_ann181673,compile_DASH_helper178667,compile_DASH_program481681,compile_DASH_split_DASH_app180671,compile_DASH_tail_DASH_app179669,compiler_DASH_name167645,compiler_DASH_visitor288699,concat_DASH_append126158,concat_DASH_cons128162,concat_DASH_empty122150,concat_DASH_singleton124154,concat_DASH_snoc130166,contract_DASH_checks183677,get_DASH_field_DASH_loc11459,get_DASH_field169649,helper_DASH_name177665,is_DASH_ConcatList120146,is_DASH_concat_DASH_append125156,is_DASH_concat_DASH_cons127160,is_DASH_concat_DASH_empty121148,is_DASH_concat_DASH_singleton123152,is_DASH_concat_DASH_snoc129164,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,mk_DASH_abbrevs480679,non_DASH_splitting_DASH_compiler483685,obj_DASH_of_DASH_loc168647,raise_DASH_id_DASH_exn170651,remove_DASH_useless_DASH_if_DASH_visitor472701,result_DASH_after_DASH_checks1550702,rt_DASH_field172655,rt_DASH_method173657,source_DASH_name116128,splitting_DASH_compiler482683,throw_DASH_uninitialized115116,thunk_DASH_app_DASH_stmt176663,thunk_DASH_app175661,type_DASH_name79105,undefined117140,builtins6) {
var provides16132148 = R.makeObject({"type-name":type_DASH_name79105.$var,
"j-fun":j_DASH_fun8180,
"j-var":j_DASH_var8299,
"j-id":j_DASH_id8381,
"j-method":j_DASH_method8486,
"j-block":j_DASH_block8570,
"j-true":j_DASH_true8696,
"j-false":j_DASH_false8778,
"j-num":j_DASH_num8889,
"j-str":j_DASH_str8993,
"j-return":j_DASH_return9092,
"j-assign":j_DASH_assign9168,
"j-if":j_DASH_if9283,
"j-if1":j_DASH_if19382,
"j-app":j_DASH_app9467,
"j-list":j_DASH_list9585,
"j-obj":j_DASH_obj9690,
"j-dot":j_DASH_dot9775,
"j-bracket":j_DASH_bracket9872,
"j-field":j_DASH_field9979,
"j-dot-assign":j_DASH_dot_DASH_assign10074,
"j-bracket-assign":j_DASH_bracket_DASH_assign10171,
"j-try-catch":j_DASH_try_DASH_catch10297,
"j-throw":j_DASH_throw10395,
"j-expr":j_DASH_expr10477,
"j-binop":j_DASH_binop10569,
"j-eq":j_DASH_eq10676,
"j-neq":j_DASH_neq10787,
"j-unop":j_DASH_unop10898,
"j-decr":j_DASH_decr10973,
"j-incr":j_DASH_incr11084,
"j-ternary":j_DASH_ternary11194,
"j-null":j_DASH_null11288,
"j-parens":j_DASH_parens11391,
"get-field-loc":get_DASH_field_DASH_loc11459,
"throw-uninitialized":throw_DASH_uninitialized115116,
"source-name":source_DASH_name116128,
"undefined":undefined117140,
"ConcatList":ConcatList119144.$var,
"is-ConcatList":is_DASH_ConcatList120146.$var,
"concat-empty":concat_DASH_empty122150.$var,
"is-concat-empty":is_DASH_concat_DASH_empty121148.$var,
"concat-singleton":concat_DASH_singleton124154.$var,
"is-concat-singleton":is_DASH_concat_DASH_singleton123152.$var,
"concat-append":concat_DASH_append126158.$var,
"is-concat-append":is_DASH_concat_DASH_append125156.$var,
"concat-cons":concat_DASH_cons128162.$var,
"is-concat-cons":is_DASH_concat_DASH_cons127160.$var,
"concat-snoc":concat_DASH_snoc130166.$var,
"is-concat-snoc":is_DASH_concat_DASH_snoc129164.$var,
"js-id-of":js_DASH_id_DASH_of162700,
"compiler-name":compiler_DASH_name167645.$var,
"obj-of-loc":obj_DASH_of_DASH_loc168647.$var,
"get-field":get_DASH_field169649.$var,
"raise-id-exn":raise_DASH_id_DASH_exn170651.$var,
"add-stack-frame":add_DASH_stack_DASH_frame171653.$var,
"rt-field":rt_DASH_field172655.$var,
"rt-method":rt_DASH_method173657.$var,
"app":app174659.$var,
"thunk-app":thunk_DASH_app175661.$var,
"thunk-app-stmt":thunk_DASH_app_DASH_stmt176663.$var,
"helper-name":helper_DASH_name177665.$var,
"compile-helper":compile_DASH_helper178667.$var,
"compile-tail-app":compile_DASH_tail_DASH_app179669.$var,
"compile-split-app":compile_DASH_split_DASH_app180671.$var,
"compile-ann":compile_DASH_ann181673.$var,
"arity-check":arity_DASH_check182675.$var,
"contract-checks":contract_DASH_checks183677.$var,
"compiler-visitor":compiler_DASH_visitor288699,
"remove-useless-if-visitor":remove_DASH_useless_DASH_if_DASH_visitor472701,
"mk-abbrevs":mk_DASH_abbrevs480679.$var,
"compile-program":compile_DASH_program481681.$var,
"splitting-compiler":splitting_DASH_compiler482683.$var,
"non-splitting-compiler":non_DASH_splitting_DASH_compiler483685.$var,
"result-after-checks1":result_DASH_after_DASH_checks1550702});
var anf_fun16142146 = G(builtins6,"current-checker",L[10]);
var $z21382139 = D;
var $f21442145 = function(_) {
return R.isFunction(anf_fun16142146)?anf_fun16142146.app():R.ffi.throwNonFunApp(L[10],anf_fun16142146,[]);
};
try {
if(--R.GAS > 0) {
$z21382139 = $f21442145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21442145,
"from":L[10]});
}
} catch($e21362137) {
if(R.isCont($e21362137)) {
var $ss21402141 = {"from":L[10],
"go":function(anf_bracket16152147) {
return $Hanf_bracket25312149(anf_bracket16152147,ConcatList7660,Loc7863,provides16132148,result_DASH_after_DASH_checks1550702);
}};
$e21362137.stack[R.EXN_STACKHEIGHT++] = $ss21402141;
}
if(R.isPyretException($e21362137)) {
$e21362137.pyretStack.push(L[10]);
}
throw $e21362137;
}
var $ret21422143 = $Hanf_bracket25312149($z21382139,ConcatList7660,Loc7863,provides16132148,result_DASH_after_DASH_checks1550702);
++R.GAS;
return $ret21422143;
};
var $Hanf_bracket25312149 = function(anf_bracket16152147,ConcatList7660,Loc7863,provides16132148,result_DASH_after_DASH_checks1550702) {
var anf_fun16162160 = G(anf_bracket16152147,"results",L[10]);
var $z21522153 = D;
var $f21582159 = function(_) {
return R.isFunction(anf_fun16162160)?anf_fun16162160.app():R.ffi.throwNonFunApp(L[10],anf_fun16162160,[]);
};
try {
if(--R.GAS > 0) {
$z21522153 = $f21582159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21582159,
"from":L[10]});
}
} catch($e21502151) {
if(R.isCont($e21502151)) {
var $ss21542155 = {"from":L[10],
"go":function(checks16172161) {
return $Hchecks25302162(checks16172161,ConcatList7660,Loc7863,provides16132148,result_DASH_after_DASH_checks1550702);
}};
$e21502151.stack[R.EXN_STACKHEIGHT++] = $ss21542155;
}
if(R.isPyretException($e21502151)) {
$e21502151.pyretStack.push(L[10]);
}
throw $e21502151;
}
var $ret21562157 = $Hchecks25302162($z21522153,ConcatList7660,Loc7863,provides16132148,result_DASH_after_DASH_checks1550702);
++R.GAS;
return $ret21562157;
};
var $Hchecks25302162 = function(checks16172161,ConcatList7660,Loc7863,provides16132148,result_DASH_after_DASH_checks1550702) {
return R.makeObject({"answer":result_DASH_after_DASH_checks1550702,
"provide-plus-types":R.makeObject({"values":provides16132148,
"types":{"Loc":Loc7863,
"ConcatList":ConcatList7660}}),
"checks":checks16172161});
};
var $Hanf_arg25282108 = function(anf_arg15542105,A118,N319,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6) {
var anf_fun15552173 = G(N319,"a-num",L[358]);
var $z21652166 = D;
var $f21712172 = function(_) {
return R.isFunction(anf_fun15552173)?anf_fun15552173.app(d5512104,(1)):R.ffi.throwNonFunApp(L[357],anf_fun15552173,[d5512104,(1)]);
};
try {
if(--R.GAS > 0) {
$z21652166 = $f21712172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21712172,
"from":L[357]});
}
} catch($e21632164) {
if(R.isCont($e21632164)) {
var $ss21672168 = {"from":L[357],
"go":function(anf_arg15562174) {
return $Hanf_arg25272175(anf_arg15562174,A118,N319,anf_arg15542105,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
}};
$e21632164.stack[R.EXN_STACKHEIGHT++] = $ss21672168;
}
if(R.isPyretException($e21632164)) {
$e21632164.pyretStack.push(L[357]);
}
throw $e21632164;
}
var $ret21692170 = $Hanf_arg25272175($z21652166,A118,N319,anf_arg15542105,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
++R.GAS;
return $ret21692170;
};
var $Hanf_arg25272175 = function(anf_arg15562174,A118,N319,anf_arg15542105,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6) {
var $z21782179 = D;
var $f21842185 = function(_) {
return R.isFunction(e5522107)?e5522107.app(anf_arg15562174):R.ffi.throwNonFunApp(L[359],e5522107,[anf_arg15562174]);
};
try {
if(--R.GAS > 0) {
$z21782179 = $f21842185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21842185,
"from":L[359]});
}
} catch($e21762177) {
if(R.isCont($e21762177)) {
var $ss21802181 = {"from":L[359],
"go":function(anf_arg15572186) {
return $Hanf_arg25262187(anf_arg15572186,A118,N319,anf_arg15542105,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
}};
$e21762177.stack[R.EXN_STACKHEIGHT++] = $ss21802181;
}
if(R.isPyretException($e21762177)) {
$e21762177.pyretStack.push(L[359]);
}
throw $e21762177;
}
var $ret21822183 = $Hanf_arg25262187($z21782179,A118,N319,anf_arg15542105,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
++R.GAS;
return $ret21822183;
};
var $Hanf_arg25262187 = function(anf_arg15572186,A118,N319,anf_arg15542105,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6) {
var anf_fun15582198 = G(N319,"a-num",L[361]);
var $z21902191 = D;
var $f21962197 = function(_) {
return R.isFunction(anf_fun15582198)?anf_fun15582198.app(d5512104,(2)):R.ffi.throwNonFunApp(L[360],anf_fun15582198,[d5512104,(2)]);
};
try {
if(--R.GAS > 0) {
$z21902191 = $f21962197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21962197,
"from":L[360]});
}
} catch($e21882189) {
if(R.isCont($e21882189)) {
var $ss21922193 = {"from":L[360],
"go":function(anf_arg15592199) {
return $Hanf_arg25252200(anf_arg15592199,A118,N319,anf_arg15542105,anf_arg15572186,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
}};
$e21882189.stack[R.EXN_STACKHEIGHT++] = $ss21922193;
}
if(R.isPyretException($e21882189)) {
$e21882189.pyretStack.push(L[360]);
}
throw $e21882189;
}
var $ret21942195 = $Hanf_arg25252200($z21902191,A118,N319,anf_arg15542105,anf_arg15572186,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
++R.GAS;
return $ret21942195;
};
var $Hanf_arg25252200 = function(anf_arg15592199,A118,N319,anf_arg15542105,anf_arg15572186,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6) {
var $z22032204 = D;
var $f22092210 = function(_) {
return R.isFunction(e5522107)?e5522107.app(anf_arg15592199):R.ffi.throwNonFunApp(L[362],e5522107,[anf_arg15592199]);
};
try {
if(--R.GAS > 0) {
$z22032204 = $f22092210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22092210,
"from":L[362]});
}
} catch($e22012202) {
if(R.isCont($e22012202)) {
var $ss22052206 = {"from":L[362],
"go":function(anf_arg15602211) {
return $Hanf_arg25242212(anf_arg15602211,A118,N319,anf_arg15542105,anf_arg15572186,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
}};
$e22012202.stack[R.EXN_STACKHEIGHT++] = $ss22052206;
}
if(R.isPyretException($e22012202)) {
$e22012202.pyretStack.push(L[362]);
}
throw $e22012202;
}
var $ret22072208 = $Hanf_arg25242212($z22032204,A118,N319,anf_arg15542105,anf_arg15572186,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
++R.GAS;
return $ret22072208;
};
var $Hanf_arg25242212 = function(anf_arg15602211,A118,N319,anf_arg15542105,anf_arg15572186,anf_fun15522106,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6) {
var $z22152216 = D;
var $f22212222 = function(_) {
return R.isFunction(anf_fun15522106)?anf_fun15522106.app(d5512104,anf_arg15542105,anf_arg15572186,anf_arg15602211):R.ffi.throwNonFunApp(L[363],anf_fun15522106,[d5512104,anf_arg15542105,anf_arg15572186,anf_arg15602211]);
};
try {
if(--R.GAS > 0) {
$z22152216 = $f22212222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22212222,
"from":L[363]});
}
} catch($e22132214) {
if(R.isCont($e22132214)) {
var $ss22172218 = {"from":L[363],
"go":function(true15542223) {
return $Htrue125232224(true15542223,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
}};
$e22132214.stack[R.EXN_STACKHEIGHT++] = $ss22172218;
}
if(R.isPyretException($e22132214)) {
$e22132214.pyretStack.push(L[363]);
}
throw $e22132214;
}
var $ret22192220 = $Htrue125232224($z22152216,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6);
++R.GAS;
return $ret22192220;
};
var $Htrue125232224 = function(true15542223,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,builtins6) {
var anf_fun15612235 = G(builtins6,"current-checker",L[364]);
var $z22272228 = D;
var $f22332234 = function(_) {
return R.isFunction(anf_fun15612235)?anf_fun15612235.app():R.ffi.throwNonFunApp(L[364],anf_fun15612235,[]);
};
try {
if(--R.GAS > 0) {
$z22272228 = $f22332234();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22332234,
"from":L[364]});
}
} catch($e22252226) {
if(R.isCont($e22252226)) {
var $ss22292230 = {"from":L[364],
"go":function(anf_bracket15622236) {
return $Hanf_bracket25222237(anf_bracket15622236,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e22252226.stack[R.EXN_STACKHEIGHT++] = $ss22292230;
}
if(R.isPyretException($e22252226)) {
$e22252226.pyretStack.push(L[364]);
}
throw $e22252226;
}
var $ret22312232 = $Hanf_bracket25222237($z22272228,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret22312232;
};
var $Hanf_bracket25222237 = function(anf_bracket15622236,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15632250 = G(anf_bracket15622236,"check-is",L[364]);
var anf_fun15642248 = G(true15542223,"visit",L[366]);
var $z22402241 = D;
var $f22462247 = function(_) {
return R.isFunction(anf_fun15642248)?anf_fun15642248.app(remove_DASH_useless_DASH_if_DASH_visitor472701):R.ffi.throwNonFunApp(L[365],anf_fun15642248,[remove_DASH_useless_DASH_if_DASH_visitor472701]);
};
try {
if(--R.GAS > 0) {
$z22402241 = $f22462247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22462247,
"from":L[365]});
}
} catch($e22382239) {
if(R.isCont($e22382239)) {
var $ss22422243 = {"from":L[365],
"go":function(anf_arg15652249) {
return $Hanf_arg25212251(anf_arg15652249,A118,N319,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e22382239.stack[R.EXN_STACKHEIGHT++] = $ss22422243;
}
if(R.isPyretException($e22382239)) {
$e22382239.pyretStack.push(L[365]);
}
throw $e22382239;
}
var $ret22442245 = $Hanf_arg25212251($z22402241,A118,N319,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret22442245;
};
var $Hanf_arg25212251 = function(anf_arg15652249,A118,N319,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15662262 = G(N319,"a-num",L[368]);
var $z22542255 = D;
var $f22602261 = function(_) {
return R.isFunction(anf_fun15662262)?anf_fun15662262.app(d5512104,(1)):R.ffi.throwNonFunApp(L[367],anf_fun15662262,[d5512104,(1)]);
};
try {
if(--R.GAS > 0) {
$z22542255 = $f22602261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22602261,
"from":L[367]});
}
} catch($e22522253) {
if(R.isCont($e22522253)) {
var $ss22562257 = {"from":L[367],
"go":function(anf_arg15672263) {
return $Hanf_arg25202264(anf_arg15672263,A118,N319,anf_arg15652249,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e22522253.stack[R.EXN_STACKHEIGHT++] = $ss22562257;
}
if(R.isPyretException($e22522253)) {
$e22522253.pyretStack.push(L[367]);
}
throw $e22522253;
}
var $ret22582259 = $Hanf_arg25202264($z22542255,A118,N319,anf_arg15652249,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret22582259;
};
var $Hanf_arg25202264 = function(anf_arg15672263,A118,N319,anf_arg15652249,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var $z22672268 = D;
var $f22732274 = function(_) {
return R.isFunction(e5522107)?e5522107.app(anf_arg15672263):R.ffi.throwNonFunApp(L[369],e5522107,[anf_arg15672263]);
};
try {
if(--R.GAS > 0) {
$z22672268 = $f22732274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22732274,
"from":L[369]});
}
} catch($e22652266) {
if(R.isCont($e22652266)) {
var $ss22692270 = {"from":L[369],
"go":function(anf_arg15682275) {
return $Hanf_arg25192276(anf_arg15682275,A118,N319,anf_arg15652249,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e22652266.stack[R.EXN_STACKHEIGHT++] = $ss22692270;
}
if(R.isPyretException($e22652266)) {
$e22652266.pyretStack.push(L[369]);
}
throw $e22652266;
}
var $ret22712272 = $Hanf_arg25192276($z22672268,A118,N319,anf_arg15652249,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret22712272;
};
var $Hanf_arg25192276 = function(anf_arg15682275,A118,N319,anf_arg15652249,anf_fun15632250,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_arg15692287 = R.makeSrcloc(L[364]);
var $z22792280 = D;
var $f22852286 = function(_) {
return R.isFunction(anf_fun15632250)?anf_fun15632250.app(("true1.visit(remove-useless-if-visitor) is e(N.a-num(d, 1))"),anf_arg15652249,anf_arg15682275,anf_arg15692287):R.ffi.throwNonFunApp(L[364],anf_fun15632250,[("true1.visit(remove-useless-if-visitor) is e(N.a-num(d, 1))"),anf_arg15652249,anf_arg15682275,anf_arg15692287]);
};
try {
if(--R.GAS > 0) {
$z22792280 = $f22852286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22852286,
"from":L[364]});
}
} catch($e22772278) {
if(R.isCont($e22772278)) {
var $ss22812282 = {"from":L[364],
"go":function(anf_begin_app_dropped24932288) {
return $Hanf_begin_app_dropped25182289(anf_begin_app_dropped24932288,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e22772278.stack[R.EXN_STACKHEIGHT++] = $ss22812282;
}
if(R.isPyretException($e22772278)) {
$e22772278.pyretStack.push(L[364]);
}
throw $e22772278;
}
var $ret22832284 = $Hanf_begin_app_dropped25182289($z22792280,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret22832284;
};
var $Hanf_begin_app_dropped25182289 = function(anf_begin_app_dropped24932288,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15702302 = G(N319,"a-if",L[372]);
var anf_fun15712300 = G(N319,"a-bool",L[371]);
var $z22922293 = D;
var $f22982299 = function(_) {
return R.isFunction(anf_fun15712300)?anf_fun15712300.app(d5512104,(false)):R.ffi.throwNonFunApp(L[370],anf_fun15712300,[d5512104,(false)]);
};
try {
if(--R.GAS > 0) {
$z22922293 = $f22982299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22982299,
"from":L[370]});
}
} catch($e22902291) {
if(R.isCont($e22902291)) {
var $ss22942295 = {"from":L[370],
"go":function(anf_arg15722301) {
return $Hanf_arg25172303(anf_arg15722301,A118,N319,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e22902291.stack[R.EXN_STACKHEIGHT++] = $ss22942295;
}
if(R.isPyretException($e22902291)) {
$e22902291.pyretStack.push(L[370]);
}
throw $e22902291;
}
var $ret22962297 = $Hanf_arg25172303($z22922293,A118,N319,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret22962297;
};
var $Hanf_arg25172303 = function(anf_arg15722301,A118,N319,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15732314 = G(N319,"a-num",L[374]);
var $z23062307 = D;
var $f23122313 = function(_) {
return R.isFunction(anf_fun15732314)?anf_fun15732314.app(d5512104,(3)):R.ffi.throwNonFunApp(L[373],anf_fun15732314,[d5512104,(3)]);
};
try {
if(--R.GAS > 0) {
$z23062307 = $f23122313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23122313,
"from":L[373]});
}
} catch($e23042305) {
if(R.isCont($e23042305)) {
var $ss23082309 = {"from":L[373],
"go":function(anf_arg15742315) {
return $Hanf_arg25162316(anf_arg15742315,A118,N319,anf_arg15722301,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e23042305.stack[R.EXN_STACKHEIGHT++] = $ss23082309;
}
if(R.isPyretException($e23042305)) {
$e23042305.pyretStack.push(L[373]);
}
throw $e23042305;
}
var $ret23102311 = $Hanf_arg25162316($z23062307,A118,N319,anf_arg15722301,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret23102311;
};
var $Hanf_arg25162316 = function(anf_arg15742315,A118,N319,anf_arg15722301,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var $z23192320 = D;
var $f23252326 = function(_) {
return R.isFunction(e5522107)?e5522107.app(anf_arg15742315):R.ffi.throwNonFunApp(L[375],e5522107,[anf_arg15742315]);
};
try {
if(--R.GAS > 0) {
$z23192320 = $f23252326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23252326,
"from":L[375]});
}
} catch($e23172318) {
if(R.isCont($e23172318)) {
var $ss23212322 = {"from":L[375],
"go":function(anf_arg15752327) {
return $Hanf_arg25152328(anf_arg15752327,A118,N319,anf_arg15722301,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e23172318.stack[R.EXN_STACKHEIGHT++] = $ss23212322;
}
if(R.isPyretException($e23172318)) {
$e23172318.pyretStack.push(L[375]);
}
throw $e23172318;
}
var $ret23232324 = $Hanf_arg25152328($z23192320,A118,N319,anf_arg15722301,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret23232324;
};
var $Hanf_arg25152328 = function(anf_arg15752327,A118,N319,anf_arg15722301,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15762339 = G(N319,"a-num",L[377]);
var $z23312332 = D;
var $f23372338 = function(_) {
return R.isFunction(anf_fun15762339)?anf_fun15762339.app(d5512104,(4)):R.ffi.throwNonFunApp(L[376],anf_fun15762339,[d5512104,(4)]);
};
try {
if(--R.GAS > 0) {
$z23312332 = $f23372338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23372338,
"from":L[376]});
}
} catch($e23292330) {
if(R.isCont($e23292330)) {
var $ss23332334 = {"from":L[376],
"go":function(anf_arg15772340) {
return $Hanf_arg25142341(anf_arg15772340,A118,N319,anf_arg15722301,anf_arg15752327,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e23292330.stack[R.EXN_STACKHEIGHT++] = $ss23332334;
}
if(R.isPyretException($e23292330)) {
$e23292330.pyretStack.push(L[376]);
}
throw $e23292330;
}
var $ret23352336 = $Hanf_arg25142341($z23312332,A118,N319,anf_arg15722301,anf_arg15752327,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret23352336;
};
var $Hanf_arg25142341 = function(anf_arg15772340,A118,N319,anf_arg15722301,anf_arg15752327,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var $z23442345 = D;
var $f23502351 = function(_) {
return R.isFunction(e5522107)?e5522107.app(anf_arg15772340):R.ffi.throwNonFunApp(L[378],e5522107,[anf_arg15772340]);
};
try {
if(--R.GAS > 0) {
$z23442345 = $f23502351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23502351,
"from":L[378]});
}
} catch($e23422343) {
if(R.isCont($e23422343)) {
var $ss23462347 = {"from":L[378],
"go":function(anf_arg15782352) {
return $Hanf_arg25132353(anf_arg15782352,A118,N319,anf_arg15722301,anf_arg15752327,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e23422343.stack[R.EXN_STACKHEIGHT++] = $ss23462347;
}
if(R.isPyretException($e23422343)) {
$e23422343.pyretStack.push(L[378]);
}
throw $e23422343;
}
var $ret23482349 = $Hanf_arg25132353($z23442345,A118,N319,anf_arg15722301,anf_arg15752327,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret23482349;
};
var $Hanf_arg25132353 = function(anf_arg15782352,A118,N319,anf_arg15722301,anf_arg15752327,anf_fun15702302,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var $z23562357 = D;
var $f23622363 = function(_) {
return R.isFunction(anf_fun15702302)?anf_fun15702302.app(d5512104,anf_arg15722301,anf_arg15752327,anf_arg15782352):R.ffi.throwNonFunApp(L[379],anf_fun15702302,[d5512104,anf_arg15722301,anf_arg15752327,anf_arg15782352]);
};
try {
if(--R.GAS > 0) {
$z23562357 = $f23622363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23622363,
"from":L[379]});
}
} catch($e23542355) {
if(R.isCont($e23542355)) {
var $ss23582359 = {"from":L[379],
"go":function(false45552364) {
return $Hfalse425122365(false45552364,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e23542355.stack[R.EXN_STACKHEIGHT++] = $ss23582359;
}
if(R.isPyretException($e23542355)) {
$e23542355.pyretStack.push(L[379]);
}
throw $e23542355;
}
var $ret23602361 = $Hfalse425122365($z23562357,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret23602361;
};
var $Hfalse425122365 = function(false45552364,A118,N319,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15792376 = G(builtins6,"current-checker",L[380]);
var $z23682369 = D;
var $f23742375 = function(_) {
return R.isFunction(anf_fun15792376)?anf_fun15792376.app():R.ffi.throwNonFunApp(L[380],anf_fun15792376,[]);
};
try {
if(--R.GAS > 0) {
$z23682369 = $f23742375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23742375,
"from":L[380]});
}
} catch($e23662367) {
if(R.isCont($e23662367)) {
var $ss23702371 = {"from":L[380],
"go":function(anf_bracket15802377) {
return $Hanf_bracket25112378(anf_bracket15802377,A118,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e23662367.stack[R.EXN_STACKHEIGHT++] = $ss23702371;
}
if(R.isPyretException($e23662367)) {
$e23662367.pyretStack.push(L[380]);
}
throw $e23662367;
}
var $ret23722373 = $Hanf_bracket25112378($z23682369,A118,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret23722373;
};
var $Hanf_bracket25112378 = function(anf_bracket15802377,A118,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15812391 = G(anf_bracket15802377,"check-is",L[380]);
var anf_fun15822389 = G(false45552364,"visit",L[382]);
var $z23812382 = D;
var $f23872388 = function(_) {
return R.isFunction(anf_fun15822389)?anf_fun15822389.app(remove_DASH_useless_DASH_if_DASH_visitor472701):R.ffi.throwNonFunApp(L[381],anf_fun15822389,[remove_DASH_useless_DASH_if_DASH_visitor472701]);
};
try {
if(--R.GAS > 0) {
$z23812382 = $f23872388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23872388,
"from":L[381]});
}
} catch($e23792380) {
if(R.isCont($e23792380)) {
var $ss23832384 = {"from":L[381],
"go":function(anf_arg15832390) {
return $Hanf_arg25102392(anf_arg15832390,A118,N319,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e23792380.stack[R.EXN_STACKHEIGHT++] = $ss23832384;
}
if(R.isPyretException($e23792380)) {
$e23792380.pyretStack.push(L[381]);
}
throw $e23792380;
}
var $ret23852386 = $Hanf_arg25102392($z23812382,A118,N319,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret23852386;
};
var $Hanf_arg25102392 = function(anf_arg15832390,A118,N319,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15842403 = G(N319,"a-num",L[384]);
var $z23952396 = D;
var $f24012402 = function(_) {
return R.isFunction(anf_fun15842403)?anf_fun15842403.app(d5512104,(4)):R.ffi.throwNonFunApp(L[383],anf_fun15842403,[d5512104,(4)]);
};
try {
if(--R.GAS > 0) {
$z23952396 = $f24012402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24012402,
"from":L[383]});
}
} catch($e23932394) {
if(R.isCont($e23932394)) {
var $ss23972398 = {"from":L[383],
"go":function(anf_arg15852404) {
return $Hanf_arg25092405(anf_arg15852404,A118,N319,anf_arg15832390,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e23932394.stack[R.EXN_STACKHEIGHT++] = $ss23972398;
}
if(R.isPyretException($e23932394)) {
$e23932394.pyretStack.push(L[383]);
}
throw $e23932394;
}
var $ret23992400 = $Hanf_arg25092405($z23952396,A118,N319,anf_arg15832390,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret23992400;
};
var $Hanf_arg25092405 = function(anf_arg15852404,A118,N319,anf_arg15832390,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var $z24082409 = D;
var $f24142415 = function(_) {
return R.isFunction(e5522107)?e5522107.app(anf_arg15852404):R.ffi.throwNonFunApp(L[385],e5522107,[anf_arg15852404]);
};
try {
if(--R.GAS > 0) {
$z24082409 = $f24142415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24142415,
"from":L[385]});
}
} catch($e24062407) {
if(R.isCont($e24062407)) {
var $ss24102411 = {"from":L[385],
"go":function(anf_arg15862416) {
return $Hanf_arg25082417(anf_arg15862416,A118,N319,anf_arg15832390,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e24062407.stack[R.EXN_STACKHEIGHT++] = $ss24102411;
}
if(R.isPyretException($e24062407)) {
$e24062407.pyretStack.push(L[385]);
}
throw $e24062407;
}
var $ret24122413 = $Hanf_arg25082417($z24082409,A118,N319,anf_arg15832390,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret24122413;
};
var $Hanf_arg25082417 = function(anf_arg15862416,A118,N319,anf_arg15832390,anf_fun15812391,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_arg15872428 = R.makeSrcloc(L[380]);
var $z24202421 = D;
var $f24262427 = function(_) {
return R.isFunction(anf_fun15812391)?anf_fun15812391.app(("false4.visit(remove-useless-if-visitor) is e(N.a-num(d, 4))"),anf_arg15832390,anf_arg15862416,anf_arg15872428):R.ffi.throwNonFunApp(L[380],anf_fun15812391,[("false4.visit(remove-useless-if-visitor) is e(N.a-num(d, 4))"),anf_arg15832390,anf_arg15862416,anf_arg15872428]);
};
try {
if(--R.GAS > 0) {
$z24202421 = $f24262427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24262427,
"from":L[380]});
}
} catch($e24182419) {
if(R.isCont($e24182419)) {
var $ss24222423 = {"from":L[380],
"go":function(anf_begin_app_dropped24942429) {
return $Hanf_begin_app_dropped25072430(anf_begin_app_dropped24942429,A118,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e24182419.stack[R.EXN_STACKHEIGHT++] = $ss24222423;
}
if(R.isPyretException($e24182419)) {
$e24182419.pyretStack.push(L[380]);
}
throw $e24182419;
}
var $ret24242425 = $Hanf_begin_app_dropped25072430($z24202421,A118,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret24242425;
};
var $Hanf_begin_app_dropped25072430 = function(anf_begin_app_dropped24942429,A118,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_bracket15882444 = G(A118,"global-names",L[388]);
var n5562441 = G(anf_bracket15882444,"make-atom",L[387]);
var $z24332434 = D;
var $f24392440 = function(_) {
return R.isFunction(n5562441)?n5562441.app(("x")):R.ffi.throwNonFunApp(L[386],n5562441,[("x")]);
};
try {
if(--R.GAS > 0) {
$z24332434 = $f24392440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24392440,
"from":L[386]});
}
} catch($e24312432) {
if(R.isCont($e24312432)) {
var $ss24352436 = {"from":L[386],
"go":function(x5572442) {
return $Hx25062443(x5572442,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
}};
$e24312432.stack[R.EXN_STACKHEIGHT++] = $ss24352436;
}
if(R.isPyretException($e24312432)) {
$e24312432.pyretStack.push(L[386]);
}
throw $e24312432;
}
var $ret24372438 = $Hx25062443($z24332434,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6);
++R.GAS;
return $ret24372438;
};
var $Hx25062443 = function(x5572442,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,builtins6) {
var anf_fun15892455 = G(builtins6,"current-checker",L[389]);
var $z24472448 = D;
var $f24532454 = function(_) {
return R.isFunction(anf_fun15892455)?anf_fun15892455.app():R.ffi.throwNonFunApp(L[389],anf_fun15892455,[]);
};
try {
if(--R.GAS > 0) {
$z24472448 = $f24532454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24532454,
"from":L[389]});
}
} catch($e24452446) {
if(R.isCont($e24452446)) {
var $ss24492450 = {"from":L[389],
"go":function(anf_bracket15902456) {
return $Hanf_bracket25052457(anf_bracket15902456,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,x5572442);
}};
$e24452446.stack[R.EXN_STACKHEIGHT++] = $ss24492450;
}
if(R.isPyretException($e24452446)) {
$e24452446.pyretStack.push(L[389]);
}
throw $e24452446;
}
var $ret24512452 = $Hanf_bracket25052457($z24472448,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,x5572442);
++R.GAS;
return $ret24512452;
};
var $Hanf_bracket25052457 = function(anf_bracket15902456,N319,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,x5572442) {
var anf_fun15912470 = G(anf_bracket15902456,"check-is",L[389]);
var anf_fun15922471 = G(N319,"a-if",L[392]);
var anf_fun15932468 = G(N319,"a-id",L[391]);
var $z24602461 = D;
var $f24662467 = function(_) {
return R.isFunction(anf_fun15932468)?anf_fun15932468.app(d5512104,x5572442):R.ffi.throwNonFunApp(L[390],anf_fun15932468,[d5512104,x5572442]);
};
try {
if(--R.GAS > 0) {
$z24602461 = $f24662467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24662467,
"from":L[390]});
}
} catch($e24582459) {
if(R.isCont($e24582459)) {
var $ss24622463 = {"from":L[390],
"go":function(anf_arg15942469) {
return $Hanf_arg25042472(anf_arg15942469,N319,anf_fun15912470,anf_fun15922471,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,x5572442);
}};
$e24582459.stack[R.EXN_STACKHEIGHT++] = $ss24622463;
}
if(R.isPyretException($e24582459)) {
$e24582459.pyretStack.push(L[390]);
}
throw $e24582459;
}
var $ret24642465 = $Hanf_arg25042472($z24602461,N319,anf_fun15912470,anf_fun15922471,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,x5572442);
++R.GAS;
return $ret24642465;
};
var $Hanf_arg25042472 = function(anf_arg15942469,N319,anf_fun15912470,anf_fun15922471,d5512104,e5522107,false45552364,remove_DASH_useless_DASH_if_DASH_visitor472701,true15542223,x5572442) {
var $z24752476 = D;
var $f24812482 = function(_) {
return R.isFunction(anf_fun15922471)?anf_fun15922471.app(d5512104,anf_arg15942469,true15542223,false45552364):R.ffi.throwNonFunApp(L[393],anf_fun15922471,[d5512104,anf_arg15942469,true15542223,false45552364]);
};
try {
if(--R.GAS > 0) {
$z24752476 = $f24812482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24812482,
"from":L[393]});
}
} catch($e24732474) {
if(R.isCont($e24732474)) {
var $ss24772478 = {"from":L[393],
"go":function(anf_bracket15952483) {
return $Hanf_bracket25032484(anf_bracket15952483,N319,anf_fun15912470,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,x5572442);
}};
$e24732474.stack[R.EXN_STACKHEIGHT++] = $ss24772478;
}
if(R.isPyretException($e24732474)) {
$e24732474.pyretStack.push(L[393]);
}
throw $e24732474;
}
var $ret24792480 = $Hanf_bracket25032484($z24752476,N319,anf_fun15912470,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,x5572442);
++R.GAS;
return $ret24792480;
};
var $Hanf_bracket25032484 = function(anf_bracket15952483,N319,anf_fun15912470,d5512104,e5522107,remove_DASH_useless_DASH_if_DASH_visitor472701,x5572442) {
var anf_fun15962495 = G(anf_bracket15952483,"visit",L[395]);
var $z24872488 = D;
var $f24932494 = function(_) {
return R.isFunction(anf_fun15962495)?anf_fun15962495.app(remove_DASH_useless_DASH_if_DASH_visitor472701):R.ffi.throwNonFunApp(L[394],anf_fun15962495,[remove_DASH_useless_DASH_if_DASH_visitor472701]);
};
try {
if(--R.GAS > 0) {
$z24872488 = $f24932494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24932494,
"from":L[394]});
}
} catch($e24852486) {
if(R.isCont($e24852486)) {
var $ss24892490 = {"from":L[394],
"go":function(anf_arg15972496) {
return $Hanf_arg25022497(anf_arg15972496,N319,anf_fun15912470,d5512104,e5522107,x5572442);
}};
$e24852486.stack[R.EXN_STACKHEIGHT++] = $ss24892490;
}
if(R.isPyretException($e24852486)) {
$e24852486.pyretStack.push(L[394]);
}
throw $e24852486;
}
var $ret24912492 = $Hanf_arg25022497($z24872488,N319,anf_fun15912470,d5512104,e5522107,x5572442);
++R.GAS;
return $ret24912492;
};
var $Hanf_arg25022497 = function(anf_arg15972496,N319,anf_fun15912470,d5512104,e5522107,x5572442) {
var anf_fun15982510 = G(N319,"a-if",L[398]);
var anf_fun15992508 = G(N319,"a-id",L[397]);
var $z25002501 = D;
var $f25062507 = function(_) {
return R.isFunction(anf_fun15992508)?anf_fun15992508.app(d5512104,x5572442):R.ffi.throwNonFunApp(L[396],anf_fun15992508,[d5512104,x5572442]);
};
try {
if(--R.GAS > 0) {
$z25002501 = $f25062507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25062507,
"from":L[396]});
}
} catch($e24982499) {
if(R.isCont($e24982499)) {
var $ss25022503 = {"from":L[396],
"go":function(anf_arg16002509) {
return $Hanf_arg25012511(anf_arg16002509,N319,anf_arg15972496,anf_fun15912470,anf_fun15982510,d5512104,e5522107);
}};
$e24982499.stack[R.EXN_STACKHEIGHT++] = $ss25022503;
}
if(R.isPyretException($e24982499)) {
$e24982499.pyretStack.push(L[396]);
}
throw $e24982499;
}
var $ret25042505 = $Hanf_arg25012511($z25002501,N319,anf_arg15972496,anf_fun15912470,anf_fun15982510,d5512104,e5522107);
++R.GAS;
return $ret25042505;
};
var $Hanf_arg25012511 = function(anf_arg16002509,N319,anf_arg15972496,anf_fun15912470,anf_fun15982510,d5512104,e5522107) {
var anf_fun16012522 = G(N319,"a-num",L[400]);
var $z25142515 = D;
var $f25202521 = function(_) {
return R.isFunction(anf_fun16012522)?anf_fun16012522.app(d5512104,(1)):R.ffi.throwNonFunApp(L[399],anf_fun16012522,[d5512104,(1)]);
};
try {
if(--R.GAS > 0) {
$z25142515 = $f25202521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25202521,
"from":L[399]});
}
} catch($e25122513) {
if(R.isCont($e25122513)) {
var $ss25162517 = {"from":L[399],
"go":function(anf_arg16022523) {
return $Hanf_arg25002524(anf_arg16022523,N319,anf_arg15972496,anf_arg16002509,anf_fun15912470,anf_fun15982510,d5512104,e5522107);
}};
$e25122513.stack[R.EXN_STACKHEIGHT++] = $ss25162517;
}
if(R.isPyretException($e25122513)) {
$e25122513.pyretStack.push(L[399]);
}
throw $e25122513;
}
var $ret25182519 = $Hanf_arg25002524($z25142515,N319,anf_arg15972496,anf_arg16002509,anf_fun15912470,anf_fun15982510,d5512104,e5522107);
++R.GAS;
return $ret25182519;
};
var $Hanf_arg25002524 = function(anf_arg16022523,N319,anf_arg15972496,anf_arg16002509,anf_fun15912470,anf_fun15982510,d5512104,e5522107) {
var $z25272528 = D;
var $f25332534 = function(_) {
return R.isFunction(e5522107)?e5522107.app(anf_arg16022523):R.ffi.throwNonFunApp(L[401],e5522107,[anf_arg16022523]);
};
try {
if(--R.GAS > 0) {
$z25272528 = $f25332534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25332534,
"from":L[401]});
}
} catch($e25252526) {
if(R.isCont($e25252526)) {
var $ss25292530 = {"from":L[401],
"go":function(anf_arg16032535) {
return $Hanf_arg24992536(anf_arg16032535,N319,anf_arg15972496,anf_arg16002509,anf_fun15912470,anf_fun15982510,d5512104,e5522107);
}};
$e25252526.stack[R.EXN_STACKHEIGHT++] = $ss25292530;
}
if(R.isPyretException($e25252526)) {
$e25252526.pyretStack.push(L[401]);
}
throw $e25252526;
}
var $ret25312532 = $Hanf_arg24992536($z25272528,N319,anf_arg15972496,anf_arg16002509,anf_fun15912470,anf_fun15982510,d5512104,e5522107);
++R.GAS;
return $ret25312532;
};
var $Hanf_arg24992536 = function(anf_arg16032535,N319,anf_arg15972496,anf_arg16002509,anf_fun15912470,anf_fun15982510,d5512104,e5522107) {
var anf_fun16042547 = G(N319,"a-num",L[403]);
var $z25392540 = D;
var $f25452546 = function(_) {
return R.isFunction(anf_fun16042547)?anf_fun16042547.app(d5512104,(4)):R.ffi.throwNonFunApp(L[402],anf_fun16042547,[d5512104,(4)]);
};
try {
if(--R.GAS > 0) {
$z25392540 = $f25452546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25452546,
"from":L[402]});
}
} catch($e25372538) {
if(R.isCont($e25372538)) {
var $ss25412542 = {"from":L[402],
"go":function(anf_arg16052548) {
return $Hanf_arg24982549(anf_arg16052548,anf_arg15972496,anf_arg16002509,anf_arg16032535,anf_fun15912470,anf_fun15982510,d5512104,e5522107);
}};
$e25372538.stack[R.EXN_STACKHEIGHT++] = $ss25412542;
}
if(R.isPyretException($e25372538)) {
$e25372538.pyretStack.push(L[402]);
}
throw $e25372538;
}
var $ret25432544 = $Hanf_arg24982549($z25392540,anf_arg15972496,anf_arg16002509,anf_arg16032535,anf_fun15912470,anf_fun15982510,d5512104,e5522107);
++R.GAS;
return $ret25432544;
};
var $Hanf_arg24982549 = function(anf_arg16052548,anf_arg15972496,anf_arg16002509,anf_arg16032535,anf_fun15912470,anf_fun15982510,d5512104,e5522107) {
var $z25522553 = D;
var $f25582559 = function(_) {
return R.isFunction(e5522107)?e5522107.app(anf_arg16052548):R.ffi.throwNonFunApp(L[404],e5522107,[anf_arg16052548]);
};
try {
if(--R.GAS > 0) {
$z25522553 = $f25582559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25582559,
"from":L[404]});
}
} catch($e25502551) {
if(R.isCont($e25502551)) {
var $ss25542555 = {"from":L[404],
"go":function(anf_arg16062560) {
return $Hanf_arg24972561(anf_arg16062560,anf_arg15972496,anf_arg16002509,anf_arg16032535,anf_fun15912470,anf_fun15982510,d5512104);
}};
$e25502551.stack[R.EXN_STACKHEIGHT++] = $ss25542555;
}
if(R.isPyretException($e25502551)) {
$e25502551.pyretStack.push(L[404]);
}
throw $e25502551;
}
var $ret25562557 = $Hanf_arg24972561($z25522553,anf_arg15972496,anf_arg16002509,anf_arg16032535,anf_fun15912470,anf_fun15982510,d5512104);
++R.GAS;
return $ret25562557;
};
var $Hanf_arg24972561 = function(anf_arg16062560,anf_arg15972496,anf_arg16002509,anf_arg16032535,anf_fun15912470,anf_fun15982510,d5512104) {
var $z25642565 = D;
var $f25702571 = function(_) {
return R.isFunction(anf_fun15982510)?anf_fun15982510.app(d5512104,anf_arg16002509,anf_arg16032535,anf_arg16062560):R.ffi.throwNonFunApp(L[405],anf_fun15982510,[d5512104,anf_arg16002509,anf_arg16032535,anf_arg16062560]);
};
try {
if(--R.GAS > 0) {
$z25642565 = $f25702571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25702571,
"from":L[405]});
}
} catch($e25622563) {
if(R.isCont($e25622563)) {
var $ss25662567 = {"from":L[405],
"go":function(anf_arg16072572) {
return $Hanf_arg24962573(anf_arg16072572,anf_arg15972496,anf_fun15912470);
}};
$e25622563.stack[R.EXN_STACKHEIGHT++] = $ss25662567;
}
if(R.isPyretException($e25622563)) {
$e25622563.pyretStack.push(L[405]);
}
throw $e25622563;
}
var $ret25682569 = $Hanf_arg24962573($z25642565,anf_arg15972496,anf_fun15912470);
++R.GAS;
return $ret25682569;
};
var $Hanf_arg24962573 = function(anf_arg16072572,anf_arg15972496,anf_fun15912470) {
var anf_arg16082584 = R.makeSrcloc(L[389]);
var $z25762577 = D;
var $f25822583 = function(_) {
return R.isFunction(anf_fun15912470)?anf_fun15912470.app(("N.a-if(d, N.a-id(d, x), true1, false4).visit(remove-useless-if-visitor) is\n  N.a-if(d, N.a-id(d, x), e(N.a-num(d, 1)), e(N.a-num(d, 4)))"),anf_arg15972496,anf_arg16072572,anf_arg16082584):R.ffi.throwNonFunApp(L[348],anf_fun15912470,[("N.a-if(d, N.a-id(d, x), true1, false4).visit(remove-useless-if-visitor) is\n  N.a-if(d, N.a-id(d, x), e(N.a-num(d, 1)), e(N.a-num(d, 4)))"),anf_arg15972496,anf_arg16072572,anf_arg16082584]);
};
try {
if(--R.GAS > 0) {
$z25762577 = $f25822583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25822583,
"from":L[348]});
}
} catch($e25742575) {
if(R.isCont($e25742575)) {
var $ss25782579 = {"from":L[348],
"go":function(ann_DASH_check_DASH_temp15472585) {
return $Hann_DASH_check_DASH_temp24952586(ann_DASH_check_DASH_temp15472585);
}};
$e25742575.stack[R.EXN_STACKHEIGHT++] = $ss25782579;
}
if(R.isPyretException($e25742575)) {
$e25742575.pyretStack.push(L[348]);
}
throw $e25742575;
}
var $ret25802581 = $Hann_DASH_check_DASH_temp24952586($z25762577);
++R.GAS;
return $ret25802581;
};
var $Hann_DASH_check_DASH_temp24952586 = function(ann_DASH_check_DASH_temp15472585) {
return ann_DASH_check_DASH_temp15472585;
};
var $Hanf_arg24922123 = function(anf_arg15512121,anf_fun15492122) {
var $z25892590 = D;
var $f25952596 = function(_) {
return R.isFunction(anf_fun15492122)?anf_fun15492122.app(anf_arg15512121):R.ffi.throwNonFunApp(L[352],anf_fun15492122,[anf_arg15512121]);
};
try {
if(--R.GAS > 0) {
$z25892590 = $f25952596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25952596,
"from":L[352]});
}
} catch($e25872588) {
if(R.isCont($e25872588)) {
var $ss25912592 = {"from":L[352],
"go":function(ann_DASH_check_DASH_temp15482597) {
return $Hann_DASH_check_DASH_temp24912598(ann_DASH_check_DASH_temp15482597);
}};
$e25872588.stack[R.EXN_STACKHEIGHT++] = $ss25912592;
}
if(R.isPyretException($e25872588)) {
$e25872588.pyretStack.push(L[352]);
}
throw $e25872588;
}
var $ret25932594 = $Hann_DASH_check_DASH_temp24912598($z25892590);
++R.GAS;
return $ret25932594;
};
var $Hann_DASH_check_DASH_temp24912598 = function(ann_DASH_check_DASH_temp15482597) {
return ann_DASH_check_DASH_temp15482597;
};
var $Hsimplified2490722 = function(simplified548718,N319,S520,compile_DASH_program481681,env543704,headers546719,l545720,list35101,self544721) {
var anf_fun15362611 = G(S520,"split-result",L[407]);
var anf_fun15372609 = G(list35101,"make",L[406]);
var $z26012602 = D;
var $f26072608 = function(_) {
return R.isFunction(anf_fun15372609)?anf_fun15372609.app([]):R.ffi.throwNonFunApp(L[406],anf_fun15372609,[[]]);
};
try {
if(--R.GAS > 0) {
$z26012602 = $f26072608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26072608,
"from":L[406]});
}
} catch($e25992600) {
if(R.isCont($e25992600)) {
var $ss26032604 = {"from":L[406],
"go":function(anf_arg15382610) {
return $Hanf_arg24892612(anf_arg15382610,N319,anf_fun15362611,compile_DASH_program481681,env543704,headers546719,l545720,self544721,simplified548718);
}};
$e25992600.stack[R.EXN_STACKHEIGHT++] = $ss26032604;
}
if(R.isPyretException($e25992600)) {
$e25992600.pyretStack.push(L[406]);
}
throw $e25992600;
}
var $ret26052606 = $Hanf_arg24892612($z26012602,N319,anf_fun15362611,compile_DASH_program481681,env543704,headers546719,l545720,self544721,simplified548718);
++R.GAS;
return $ret26052606;
};
var $Hanf_arg24892612 = function(anf_arg15382610,N319,anf_fun15362611,compile_DASH_program481681,env543704,headers546719,l545720,self544721,simplified548718) {
var anf_fun15392623 = G(N319,"freevars-e",L[409]);
var $z26152616 = D;
var $f26212622 = function(_) {
return R.isFunction(anf_fun15392623)?anf_fun15392623.app(simplified548718):R.ffi.throwNonFunApp(L[408],anf_fun15392623,[simplified548718]);
};
try {
if(--R.GAS > 0) {
$z26152616 = $f26212622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26212622,
"from":L[408]});
}
} catch($e26132614) {
if(R.isCont($e26132614)) {
var $ss26172618 = {"from":L[408],
"go":function(anf_arg15402624) {
return $Hanf_arg24882625(anf_arg15402624,anf_arg15382610,anf_fun15362611,compile_DASH_program481681,env543704,headers546719,l545720,self544721,simplified548718);
}};
$e26132614.stack[R.EXN_STACKHEIGHT++] = $ss26172618;
}
if(R.isPyretException($e26132614)) {
$e26132614.pyretStack.push(L[408]);
}
throw $e26132614;
}
var $ret26192620 = $Hanf_arg24882625($z26152616,anf_arg15382610,anf_fun15362611,compile_DASH_program481681,env543704,headers546719,l545720,self544721,simplified548718);
++R.GAS;
return $ret26192620;
};
var $Hanf_arg24882625 = function(anf_arg15402624,anf_arg15382610,anf_fun15362611,compile_DASH_program481681,env543704,headers546719,l545720,self544721,simplified548718) {
var $z26282629 = D;
var $f26342635 = function(_) {
return R.isFunction(anf_fun15362611)?anf_fun15362611.app(anf_arg15382610,simplified548718,anf_arg15402624):R.ffi.throwNonFunApp(L[410],anf_fun15362611,[anf_arg15382610,simplified548718,anf_arg15402624]);
};
try {
if(--R.GAS > 0) {
$z26282629 = $f26342635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26342635,
"from":L[410]});
}
} catch($e26262627) {
if(R.isCont($e26262627)) {
var $ss26302631 = {"from":L[410],
"go":function(split5492636) {
return $Hsplit24872637(split5492636,compile_DASH_program481681,env543704,headers546719,l545720,self544721);
}};
$e26262627.stack[R.EXN_STACKHEIGHT++] = $ss26302631;
}
if(R.isPyretException($e26262627)) {
$e26262627.pyretStack.push(L[410]);
}
throw $e26262627;
}
var $ret26322633 = $Hsplit24872637($z26282629,compile_DASH_program481681,env543704,headers546719,l545720,self544721);
++R.GAS;
return $ret26322633;
};
var $Hsplit24872637 = function(split5492636,compile_DASH_program481681,env543704,headers546719,l545720,self544721) {
var $z26402641 = D;
var $f26462647 = function(_) {
return R.isFunction(compile_DASH_program481681.$var)?compile_DASH_program481681.$var.app(self544721,l545720,headers546719,split5492636,env543704):R.ffi.throwNonFunApp(L[71],compile_DASH_program481681.$var,[self544721,l545720,headers546719,split5492636,env543704]);
};
try {
if(--R.GAS > 0) {
$z26402641 = $f26462647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26462647,
"from":L[71]});
}
} catch($e26382639) {
if(R.isCont($e26382639)) {
var $ss26422643 = {"from":L[71],
"go":function(ann_DASH_check_DASH_temp15342648) {
return $Hann_DASH_check_DASH_temp24862649(ann_DASH_check_DASH_temp15342648);
}};
$e26382639.stack[R.EXN_STACKHEIGHT++] = $ss26422643;
}
if(R.isPyretException($e26382639)) {
$e26382639.pyretStack.push(L[71]);
}
throw $e26382639;
}
var $ret26442645 = $Hann_DASH_check_DASH_temp24862649($z26402641);
++R.GAS;
return $ret26442645;
};
var $Hann_DASH_check_DASH_temp24862649 = function(ann_DASH_check_DASH_temp15342648) {
return ann_DASH_check_DASH_temp15342648;
};
var $Hsimplified2485742 = function(simplified541738,S520,compile_DASH_program481681,env536724,headers539739,l538740,self537741) {
var anf_fun15302660 = G(S520,"ast-split",L[412]);
var $z26522653 = D;
var $f26582659 = function(_) {
return R.isFunction(anf_fun15302660)?anf_fun15302660.app(simplified541738):R.ffi.throwNonFunApp(L[411],anf_fun15302660,[simplified541738]);
};
try {
if(--R.GAS > 0) {
$z26522653 = $f26582659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26582659,
"from":L[411]});
}
} catch($e26502651) {
if(R.isCont($e26502651)) {
var $ss26542655 = {"from":L[411],
"go":function(split5422661) {
return $Hsplit24842662(split5422661,compile_DASH_program481681,env536724,headers539739,l538740,self537741);
}};
$e26502651.stack[R.EXN_STACKHEIGHT++] = $ss26542655;
}
if(R.isPyretException($e26502651)) {
$e26502651.pyretStack.push(L[411]);
}
throw $e26502651;
}
var $ret26562657 = $Hsplit24842662($z26522653,compile_DASH_program481681,env536724,headers539739,l538740,self537741);
++R.GAS;
return $ret26562657;
};
var $Hsplit24842662 = function(split5422661,compile_DASH_program481681,env536724,headers539739,l538740,self537741) {
var $z26652666 = D;
var $f26712672 = function(_) {
return R.isFunction(compile_DASH_program481681.$var)?compile_DASH_program481681.$var.app(self537741,l538740,headers539739,split5422661,env536724):R.ffi.throwNonFunApp(L[75],compile_DASH_program481681.$var,[self537741,l538740,headers539739,split5422661,env536724]);
};
try {
if(--R.GAS > 0) {
$z26652666 = $f26712672();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26712672,
"from":L[75]});
}
} catch($e26632664) {
if(R.isCont($e26632664)) {
var $ss26672668 = {"from":L[75],
"go":function(ann_DASH_check_DASH_temp15282673) {
return $Hann_DASH_check_DASH_temp24832674(ann_DASH_check_DASH_temp15282673);
}};
$e26632664.stack[R.EXN_STACKHEIGHT++] = $ss26672668;
}
if(R.isPyretException($e26632664)) {
$e26632664.pyretStack.push(L[75]);
}
throw $e26632664;
}
var $ret26692670 = $Hann_DASH_check_DASH_temp24832674($z26652666);
++R.GAS;
return $ret26692670;
};
var $Hann_DASH_check_DASH_temp24832674 = function(ann_DASH_check_DASH_temp15282673) {
return ann_DASH_check_DASH_temp15282673;
};
var $Hanf_bracket2482763 = function(anf_bracket1324762,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13) {
var anf_fun13252688 = G(anf_bracket1324762,"difference",L[417]);
var anf_fun13262689 = G(sets2530,"list-to-tree-set",L[416]);
var anf_fun13272685 = G(headers487746,"map",L[415]);
var anf_arg13292686 = R.makeFunction(function(recv_DASH_732691) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[414],1,arguments);
}
var ann_DASH_check_DASH_temp13282692 = G(recv_DASH_732691,"name",L[414]);
return ann_DASH_check_DASH_temp13282692;
});
var $z26772678 = D;
var $f26832684 = function(_) {
return R.isFunction(anf_fun13272685)?anf_fun13272685.app(anf_arg13292686):R.ffi.throwNonFunApp(L[413],anf_fun13272685,[anf_arg13292686]);
};
try {
if(--R.GAS > 0) {
$z26772678 = $f26832684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26832684,
"from":L[413]});
}
} catch($e26752676) {
if(R.isCont($e26752676)) {
var $ss26792680 = {"from":L[413],
"go":function(anf_arg13302687) {
return $Hanf_arg24812690(anf_arg13302687,D1324,Loc7863,N319,anf_fun13252688,anf_fun13262689,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13);
}};
$e26752676.stack[R.EXN_STACKHEIGHT++] = $ss26792680;
}
if(R.isPyretException($e26752676)) {
$e26752676.pyretStack.push(L[413]);
}
throw $e26752676;
}
var $ret26812682 = $Hanf_arg24812690($z26772678,D1324,Loc7863,N319,anf_fun13252688,anf_fun13262689,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13);
++R.GAS;
return $ret26812682;
};
var $Hanf_arg24812690 = function(anf_arg13302687,D1324,Loc7863,N319,anf_fun13252688,anf_fun13262689,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13) {
var $z26952696 = D;
var $f27012702 = function(_) {
return R.isFunction(anf_fun13262689)?anf_fun13262689.app(anf_arg13302687):R.ffi.throwNonFunApp(L[418],anf_fun13262689,[anf_arg13302687]);
};
try {
if(--R.GAS > 0) {
$z26952696 = $f27012702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27012702,
"from":L[418]});
}
} catch($e26932694) {
if(R.isCont($e26932694)) {
var $ss26972698 = {"from":L[418],
"go":function(anf_arg13312703) {
return $Hanf_arg24802704(anf_arg13312703,D1324,Loc7863,N319,anf_fun13252688,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13);
}};
$e26932694.stack[R.EXN_STACKHEIGHT++] = $ss26972698;
}
if(R.isPyretException($e26932694)) {
$e26932694.pyretStack.push(L[418]);
}
throw $e26932694;
}
var $ret26992700 = $Hanf_arg24802704($z26952696,D1324,Loc7863,N319,anf_fun13252688,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13);
++R.GAS;
return $ret26992700;
};
var $Hanf_arg24802704 = function(anf_arg13312703,D1324,Loc7863,N319,anf_fun13252688,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13) {
var $z27072708 = D;
var $f27132714 = function(_) {
return R.isFunction(anf_fun13252688)?anf_fun13252688.app(anf_arg13312703):R.ffi.throwNonFunApp(L[419],anf_fun13252688,[anf_arg13312703]);
};
try {
if(--R.GAS > 0) {
$z27072708 = $f27132714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27132714,
"from":L[419]});
}
} catch($e27052706) {
if(R.isCont($e27052706)) {
var $ss27092710 = {"from":L[419],
"go":function(anf_bracket13322715) {
return $Hanf_bracket24792716(anf_bracket13322715,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13);
}};
$e27052706.stack[R.EXN_STACKHEIGHT++] = $ss27092710;
}
if(R.isPyretException($e27052706)) {
$e27052706.pyretStack.push(L[419]);
}
throw $e27052706;
}
var $ret27112712 = $Hanf_bracket24792716($z27072708,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13);
++R.GAS;
return $ret27112712;
};
var $Hanf_bracket24792716 = function(anf_bracket13322715,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,sets2530,split488747,type_DASH_name79105,_plus5,torepr13) {
var anf_fun13332730 = G(anf_bracket13322715,"difference",L[424]);
var anf_fun13342731 = G(sets2530,"list-to-tree-set",L[423]);
var anf_fun13352727 = G(headers487746,"map",L[422]);
var anf_arg13372728 = R.makeFunction(function(recv_DASH_722733) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[421],1,arguments);
}
var ann_DASH_check_DASH_temp13362734 = G(recv_DASH_722733,"types",L[421]);
return ann_DASH_check_DASH_temp13362734;
});
var $z27192720 = D;
var $f27252726 = function(_) {
return R.isFunction(anf_fun13352727)?anf_fun13352727.app(anf_arg13372728):R.ffi.throwNonFunApp(L[420],anf_fun13352727,[anf_arg13372728]);
};
try {
if(--R.GAS > 0) {
$z27192720 = $f27252726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27252726,
"from":L[420]});
}
} catch($e27172718) {
if(R.isCont($e27172718)) {
var $ss27212722 = {"from":L[420],
"go":function(anf_arg13382729) {
return $Hanf_arg24782732(anf_arg13382729,D1324,Loc7863,N319,anf_fun13332730,anf_fun13342731,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13);
}};
$e27172718.stack[R.EXN_STACKHEIGHT++] = $ss27212722;
}
if(R.isPyretException($e27172718)) {
$e27172718.pyretStack.push(L[420]);
}
throw $e27172718;
}
var $ret27232724 = $Hanf_arg24782732($z27192720,D1324,Loc7863,N319,anf_fun13332730,anf_fun13342731,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13);
++R.GAS;
return $ret27232724;
};
var $Hanf_arg24782732 = function(anf_arg13382729,D1324,Loc7863,N319,anf_fun13332730,anf_fun13342731,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13) {
var $z27372738 = D;
var $f27432744 = function(_) {
return R.isFunction(anf_fun13342731)?anf_fun13342731.app(anf_arg13382729):R.ffi.throwNonFunApp(L[425],anf_fun13342731,[anf_arg13382729]);
};
try {
if(--R.GAS > 0) {
$z27372738 = $f27432744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27432744,
"from":L[425]});
}
} catch($e27352736) {
if(R.isCont($e27352736)) {
var $ss27392740 = {"from":L[425],
"go":function(anf_arg13392745) {
return $Hanf_arg24772746(anf_arg13392745,D1324,Loc7863,N319,anf_fun13332730,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13);
}};
$e27352736.stack[R.EXN_STACKHEIGHT++] = $ss27392740;
}
if(R.isPyretException($e27352736)) {
$e27352736.pyretStack.push(L[425]);
}
throw $e27352736;
}
var $ret27412742 = $Hanf_arg24772746($z27372738,D1324,Loc7863,N319,anf_fun13332730,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13);
++R.GAS;
return $ret27412742;
};
var $Hanf_arg24772746 = function(anf_arg13392745,D1324,Loc7863,N319,anf_fun13332730,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13) {
var $z27492750 = D;
var $f27552756 = function(_) {
return R.isFunction(anf_fun13332730)?anf_fun13332730.app(anf_arg13392745):R.ffi.throwNonFunApp(L[426],anf_fun13332730,[anf_arg13392745]);
};
try {
if(--R.GAS > 0) {
$z27492750 = $f27552756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27552756,
"from":L[426]});
}
} catch($e27472748) {
if(R.isCont($e27472748)) {
var $ss27512752 = {"from":L[426],
"go":function(free_DASH_ids4922757) {
return $Hfree_DASH_ids24762758(free_DASH_ids4922757,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13);
}};
$e27472748.stack[R.EXN_STACKHEIGHT++] = $ss27512752;
}
if(R.isPyretException($e27472748)) {
$e27472748.pyretStack.push(L[426]);
}
throw $e27472748;
}
var $ret27532754 = $Hfree_DASH_ids24762758($z27492750,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13);
++R.GAS;
return $ret27532754;
};
var $Hfree_DASH_ids24762758 = function(free_DASH_ids4922757,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_method8486,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_name79105,_plus5,torepr13) {
var anf_arg13602771 = R.makeFunction(function(n4942773) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[429],1,arguments);
}
var cases_DASH_val742820 = n4942773;
var anf_fun13412784 = G(cases_DASH_val742820,"_match",L[431]);
var anf_obj13442790 = R.makeFunction(function(s4962806) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[435],1,arguments);
}
var anf_fun13432817 = G(n4942773,"toname",L[436]);
var $z28092810 = D;
var $f28152816 = function(_) {
return R.isFunction(anf_fun13432817)?anf_fun13432817.app():R.ffi.throwNonFunApp(L[435],anf_fun13432817,[]);
};
try {
if(--R.GAS > 0) {
$z28092810 = $f28152816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28152816,
"from":L[435]});
}
} catch($e28072808) {
if(R.isCont($e28072808)) {
var $ss28112812 = {"from":L[435],
"go":function(ann_DASH_check_DASH_temp13422818) {
return $Hann_DASH_check_DASH_temp23562819(ann_DASH_check_DASH_temp13422818);
}};
$e28072808.stack[R.EXN_STACKHEIGHT++] = $ss28112812;
}
if(R.isPyretException($e28072808)) {
$e28072808.pyretStack.push(L[435]);
}
throw $e28072808;
}
var $ret28132814 = $Hann_DASH_check_DASH_temp23562819($z28092810);
++R.GAS;
return $ret28132814;
});
var anf_obj13482791 = R.makeFunction(function(s4972792) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[432],1,arguments);
}
var anf_fun13462803 = G(n4942773,"toname",L[434]);
var $z27952796 = D;
var $f28012802 = function(_) {
return R.isFunction(anf_fun13462803)?anf_fun13462803.app():R.ffi.throwNonFunApp(L[433],anf_fun13462803,[]);
};
try {
if(--R.GAS > 0) {
$z27952796 = $f28012802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28012802,
"from":L[433]});
}
} catch($e27932794) {
if(R.isCont($e27932794)) {
var $ss27972798 = {"from":L[433],
"go":function(anf_arg13472804) {
return $Hanf_arg23582805(anf_arg13472804,type_DASH_name79105);
}};
$e27932794.stack[R.EXN_STACKHEIGHT++] = $ss27972798;
}
if(R.isPyretException($e27932794)) {
$e27932794.pyretStack.push(L[433]);
}
throw $e27932794;
}
var $ret27992800 = $Hanf_arg23582805($z27952796,type_DASH_name79105);
++R.GAS;
return $ret27992800;
});
var anf_arg13492785 = R.makeObject({"s-global":anf_obj13442790,
"s-type-global":anf_obj13482791});
var anf_arg13512786 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[431],0,arguments);
}
var ann_DASH_check_DASH_temp13502789 = R.throwNoBranchesMatched(L[431],("cases"));
return ann_DASH_check_DASH_temp13502789;
});
var $z27762777 = D;
var $f27822783 = function(_) {
return R.isFunction(anf_fun13412784)?anf_fun13412784.app(anf_arg13492785,anf_arg13512786):R.ffi.throwNonFunApp(L[430],anf_fun13412784,[anf_arg13492785,anf_arg13512786]);
};
try {
if(--R.GAS > 0) {
$z27762777 = $f27822783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27822783,
"from":L[430]});
}
} catch($e27742775) {
if(R.isCont($e27742775)) {
var $ss27782779 = {"from":L[430],
"go":function(bind_DASH_name4952787) {
return $Hbind_DASH_name23662788(bind_DASH_name4952787,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,n4942773);
}};
$e27742775.stack[R.EXN_STACKHEIGHT++] = $ss27782779;
}
if(R.isPyretException($e27742775)) {
$e27742775.pyretStack.push(L[430]);
}
throw $e27742775;
}
var $ret27802781 = $Hbind_DASH_name23662788($z27762777,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,n4942773);
++R.GAS;
return $ret27802781;
});
var anf_fun13612769 = G(free_DASH_ids4922757,"to-list",L[428]);
var $z27612762 = D;
var $f27672768 = function(_) {
return R.isFunction(anf_fun13612769)?anf_fun13612769.app():R.ffi.throwNonFunApp(L[427],anf_fun13612769,[]);
};
try {
if(--R.GAS > 0) {
$z27612762 = $f27672768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27672768,
"from":L[427]});
}
} catch($e27592760) {
if(R.isCont($e27592760)) {
var $ss27632764 = {"from":L[427],
"go":function(anf_arg13622770) {
return $Hanf_arg24752772(anf_arg13622770,D1324,Loc7863,N319,anf_arg13602771,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e27592760.stack[R.EXN_STACKHEIGHT++] = $ss27632764;
}
if(R.isPyretException($e27592760)) {
$e27592760.pyretStack.push(L[427]);
}
throw $e27592760;
}
var $ret27652766 = $Hanf_arg24752772($z27612762,D1324,Loc7863,N319,anf_arg13602771,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret27652766;
};
var $Hanf_arg24752772 = function(anf_arg13622770,D1324,Loc7863,N319,anf_arg13602771,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,map47104,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var $z28232824 = D;
var $f28292830 = function(_) {
return R.isFunction(map47104)?map47104.app(anf_arg13602771,anf_arg13622770):R.ffi.throwNonFunApp(L[437],map47104,[anf_arg13602771,anf_arg13622770]);
};
try {
if(--R.GAS > 0) {
$z28232824 = $f28292830();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28292830,
"from":L[437]});
}
} catch($e28212822) {
if(R.isCont($e28212822)) {
var $ss28252826 = {"from":L[437],
"go":function(namespace_DASH_binds4932831) {
return $Hnamespace_DASH_binds24742832(namespace_DASH_binds4932831,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e28212822.stack[R.EXN_STACKHEIGHT++] = $ss28252826;
}
if(R.isPyretException($e28212822)) {
$e28212822.pyretStack.push(L[437]);
}
throw $e28212822;
}
var $ret28272828 = $Hnamespace_DASH_binds24742832($z28232824,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret28272828;
};
var $Hnamespace_DASH_binds24742832 = function(namespace_DASH_binds4932831,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var anf_fun13632843 = G(headers487746,"map",L[440]);
var anf_arg13652844 = R.makeFunction(function(recv_DASH_762847) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[439],1,arguments);
}
var ann_DASH_check_DASH_temp13642848 = G(recv_DASH_762847,"name",L[439]);
return ann_DASH_check_DASH_temp13642848;
});
var $z28352836 = D;
var $f28412842 = function(_) {
return R.isFunction(anf_fun13632843)?anf_fun13632843.app(anf_arg13652844):R.ffi.throwNonFunApp(L[438],anf_fun13632843,[anf_arg13652844]);
};
try {
if(--R.GAS > 0) {
$z28352836 = $f28412842();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28412842,
"from":L[438]});
}
} catch($e28332834) {
if(R.isCont($e28332834)) {
var $ss28372838 = {"from":L[438],
"go":function(anf_bracket13662845) {
return $Hanf_bracket24732846(anf_bracket13662845,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e28332834.stack[R.EXN_STACKHEIGHT++] = $ss28372838;
}
if(R.isPyretException($e28332834)) {
$e28332834.pyretStack.push(L[438]);
}
throw $e28332834;
}
var $ret28392840 = $Hanf_bracket24732846($z28352836,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret28392840;
};
var $Hanf_bracket24732846 = function(anf_bracket13662845,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var anf_fun13672859 = G(anf_bracket13662845,"map",L[443]);
var anf_arg13702860 = R.makeFunction(function(recv_DASH_752863) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[442],1,arguments);
}
var anf_fun13692874 = G(recv_DASH_752863,"tostring",L[442]);
var $z28662867 = D;
var $f28722873 = function(_) {
return R.isFunction(anf_fun13692874)?anf_fun13692874.app():R.ffi.throwNonFunApp(L[442],anf_fun13692874,[]);
};
try {
if(--R.GAS > 0) {
$z28662867 = $f28722873();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28722873,
"from":L[442]});
}
} catch($e28642865) {
if(R.isCont($e28642865)) {
var $ss28682869 = {"from":L[442],
"go":function(ann_DASH_check_DASH_temp13682875) {
return $Hann_DASH_check_DASH_temp23672876(ann_DASH_check_DASH_temp13682875);
}};
$e28642865.stack[R.EXN_STACKHEIGHT++] = $ss28682869;
}
if(R.isPyretException($e28642865)) {
$e28642865.pyretStack.push(L[442]);
}
throw $e28642865;
}
var $ret28702871 = $Hann_DASH_check_DASH_temp23672876($z28662867);
++R.GAS;
return $ret28702871;
});
var $z28512852 = D;
var $f28572858 = function(_) {
return R.isFunction(anf_fun13672859)?anf_fun13672859.app(anf_arg13702860):R.ffi.throwNonFunApp(L[441],anf_fun13672859,[anf_arg13702860]);
};
try {
if(--R.GAS > 0) {
$z28512852 = $f28572858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28572858,
"from":L[441]});
}
} catch($e28492850) {
if(R.isCont($e28492850)) {
var $ss28532854 = {"from":L[441],
"go":function(anf_bracket13712861) {
return $Hanf_bracket24722862(anf_bracket13712861,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e28492850.stack[R.EXN_STACKHEIGHT++] = $ss28532854;
}
if(R.isPyretException($e28492850)) {
$e28492850.pyretStack.push(L[441]);
}
throw $e28492850;
}
var $ret28552856 = $Hanf_bracket24722862($z28512852,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret28552856;
};
var $Hanf_bracket24722862 = function(anf_bracket13712861,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var anf_fun13722887 = G(anf_bracket13712861,"map",L[445]);
var $z28792880 = D;
var $f28852886 = function(_) {
return R.isFunction(anf_fun13722887)?anf_fun13722887.app(js_DASH_id_DASH_of162700):R.ffi.throwNonFunApp(L[444],anf_fun13722887,[js_DASH_id_DASH_of162700]);
};
try {
if(--R.GAS > 0) {
$z28792880 = $f28852886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28852886,
"from":L[444]});
}
} catch($e28772878) {
if(R.isCont($e28772878)) {
var $ss28812882 = {"from":L[444],
"go":function(ids4982888) {
return $Hids24712889(ids4982888,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e28772878.stack[R.EXN_STACKHEIGHT++] = $ss28812882;
}
if(R.isPyretException($e28772878)) {
$e28772878.pyretStack.push(L[444]);
}
throw $e28772878;
}
var $ret28832884 = $Hids24712889($z28792880,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret28832884;
};
var $Hids24712889 = function(ids4982888,D1324,Loc7863,N319,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var anf_fun13732900 = G(headers487746,"filter",L[448]);
var anf_arg13742901 = G(N319,"is-a-import-types",L[447]);
var $z28922893 = D;
var $f28982899 = function(_) {
return R.isFunction(anf_fun13732900)?anf_fun13732900.app(anf_arg13742901):R.ffi.throwNonFunApp(L[446],anf_fun13732900,[anf_arg13742901]);
};
try {
if(--R.GAS > 0) {
$z28922893 = $f28982899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28982899,
"from":L[446]});
}
} catch($e28902891) {
if(R.isCont($e28902891)) {
var $ss28942895 = {"from":L[446],
"go":function(type_DASH_imports4992902) {
return $Htype_DASH_imports24702903(type_DASH_imports4992902,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e28902891.stack[R.EXN_STACKHEIGHT++] = $ss28942895;
}
if(R.isPyretException($e28902891)) {
$e28902891.pyretStack.push(L[446]);
}
throw $e28902891;
}
var $ret28962897 = $Htype_DASH_imports24702903($z28922893,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret28962897;
};
var $Htype_DASH_imports24702903 = function(type_DASH_imports4992902,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var anf_fun13752914 = G(type_DASH_imports4992902,"map",L[451]);
var anf_arg13772915 = R.makeFunction(function(recv_DASH_782918) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[450],1,arguments);
}
var ann_DASH_check_DASH_temp13762919 = G(recv_DASH_782918,"types",L[450]);
return ann_DASH_check_DASH_temp13762919;
});
var $z29062907 = D;
var $f29122913 = function(_) {
return R.isFunction(anf_fun13752914)?anf_fun13752914.app(anf_arg13772915):R.ffi.throwNonFunApp(L[449],anf_fun13752914,[anf_arg13772915]);
};
try {
if(--R.GAS > 0) {
$z29062907 = $f29122913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29122913,
"from":L[449]});
}
} catch($e29042905) {
if(R.isCont($e29042905)) {
var $ss29082909 = {"from":L[449],
"go":function(anf_bracket13782916) {
return $Hanf_bracket24692917(anf_bracket13782916,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e29042905.stack[R.EXN_STACKHEIGHT++] = $ss29082909;
}
if(R.isPyretException($e29042905)) {
$e29042905.pyretStack.push(L[449]);
}
throw $e29042905;
}
var $ret29102911 = $Hanf_bracket24692917($z29062907,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret29102911;
};
var $Hanf_bracket24692917 = function(anf_bracket13782916,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var anf_fun13792930 = G(anf_bracket13782916,"map",L[454]);
var anf_arg13822931 = R.makeFunction(function(recv_DASH_772934) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[453],1,arguments);
}
var anf_fun13812945 = G(recv_DASH_772934,"tostring",L[453]);
var $z29372938 = D;
var $f29432944 = function(_) {
return R.isFunction(anf_fun13812945)?anf_fun13812945.app():R.ffi.throwNonFunApp(L[453],anf_fun13812945,[]);
};
try {
if(--R.GAS > 0) {
$z29372938 = $f29432944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29432944,
"from":L[453]});
}
} catch($e29352936) {
if(R.isCont($e29352936)) {
var $ss29392940 = {"from":L[453],
"go":function(ann_DASH_check_DASH_temp13802946) {
return $Hann_DASH_check_DASH_temp23682947(ann_DASH_check_DASH_temp13802946);
}};
$e29352936.stack[R.EXN_STACKHEIGHT++] = $ss29392940;
}
if(R.isPyretException($e29352936)) {
$e29352936.pyretStack.push(L[453]);
}
throw $e29352936;
}
var $ret29412942 = $Hann_DASH_check_DASH_temp23682947($z29372938);
++R.GAS;
return $ret29412942;
});
var $z29222923 = D;
var $f29282929 = function(_) {
return R.isFunction(anf_fun13792930)?anf_fun13792930.app(anf_arg13822931):R.ffi.throwNonFunApp(L[452],anf_fun13792930,[anf_arg13822931]);
};
try {
if(--R.GAS > 0) {
$z29222923 = $f29282929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29282929,
"from":L[452]});
}
} catch($e29202921) {
if(R.isCont($e29202921)) {
var $ss29242925 = {"from":L[452],
"go":function(anf_bracket13832932) {
return $Hanf_bracket24682933(anf_bracket13832932,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e29202921.stack[R.EXN_STACKHEIGHT++] = $ss29242925;
}
if(R.isPyretException($e29202921)) {
$e29202921.pyretStack.push(L[452]);
}
throw $e29202921;
}
var $ret29262927 = $Hanf_bracket24682933($z29222923,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret29262927;
};
var $Hanf_bracket24682933 = function(anf_bracket13832932,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var anf_fun13842958 = G(anf_bracket13832932,"map",L[456]);
var $z29502951 = D;
var $f29562957 = function(_) {
return R.isFunction(anf_fun13842958)?anf_fun13842958.app(js_DASH_id_DASH_of162700):R.ffi.throwNonFunApp(L[455],anf_fun13842958,[js_DASH_id_DASH_of162700]);
};
try {
if(--R.GAS > 0) {
$z29502951 = $f29562957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29562957,
"from":L[455]});
}
} catch($e29482949) {
if(R.isCont($e29482949)) {
var $ss29522953 = {"from":L[455],
"go":function(type_DASH_ids5002959) {
return $Htype_DASH_ids24672960(type_DASH_ids5002959,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
}};
$e29482949.stack[R.EXN_STACKHEIGHT++] = $ss29522953;
}
if(R.isPyretException($e29482949)) {
$e29482949.pyretStack.push(L[455]);
}
throw $e29482949;
}
var $ret29542955 = $Htype_DASH_ids24672960($z29502951,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13);
++R.GAS;
return $ret29542955;
};
var $Htype_DASH_ids24672960 = function(type_DASH_ids5002959,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,headers487746,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,_plus5,torepr13) {
var anf_fun13852971 = G(headers487746,"map",L[463]);
var anf_arg13952972 = R.makeFunction(function(h5022975) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[458],1,arguments);
}
var cases_DASH_val793011 = G(h5022975,"import-type",L[462]);
var anf_fun13872986 = G(cases_DASH_val793011,"_match",L[459]);
var anf_obj13892992 = R.makeFunction(function($underscore5032997,name5042998) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[461],2,arguments);
}
var $z30013002 = D;
var $f30073008 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("trove/"),name5042998):R.ffi.throwNonFunApp(L[461],_plus5,[("trove/"),name5042998]);
};
try {
if(--R.GAS > 0) {
$z30013002 = $f30073008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30073008,
"from":L[461]});
}
} catch($e29993000) {
if(R.isCont($e29993000)) {
var $ss30033004 = {"from":L[461],
"go":function(ann_DASH_check_DASH_temp13883009) {
return $Hann_DASH_check_DASH_temp23693010(ann_DASH_check_DASH_temp13883009);
}};
$e29993000.stack[R.EXN_STACKHEIGHT++] = $ss30033004;
}
if(R.isPyretException($e29993000)) {
$e29993000.pyretStack.push(L[461]);
}
throw $e29993000;
}
var $ret30053006 = $Hann_DASH_check_DASH_temp23693010($z30013002);
++R.GAS;
return $ret30053006;
});
var anf_obj13912993 = R.makeFunction(function($underscore5052994,file5062995) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[460],2,arguments);
}
var ann_DASH_check_DASH_temp13902996 = file5062995;
return ann_DASH_check_DASH_temp13902996;
});
var anf_arg13922987 = R.makeObject({"a-import-builtin":anf_obj13892992,
"a-import-file":anf_obj13912993});
var anf_arg13942988 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[459],0,arguments);
}
var ann_DASH_check_DASH_temp13932991 = R.throwNoBranchesMatched(L[459],("cases"));
return ann_DASH_check_DASH_temp13932991;
});
var $z29782979 = D;
var $f29842985 = function(_) {
return R.isFunction(anf_fun13872986)?anf_fun13872986.app(anf_arg13922987,anf_arg13942988):R.ffi.throwNonFunApp(L[458],anf_fun13872986,[anf_arg13922987,anf_arg13942988]);
};
try {
if(--R.GAS > 0) {
$z29782979 = $f29842985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29842985,
"from":L[458]});
}
} catch($e29762977) {
if(R.isCont($e29762977)) {
var $ss29802981 = {"from":L[458],
"go":function(ann_DASH_check_DASH_temp13862989) {
return $Hann_DASH_check_DASH_temp23702990(ann_DASH_check_DASH_temp13862989);
}};
$e29762977.stack[R.EXN_STACKHEIGHT++] = $ss29802981;
}
if(R.isPyretException($e29762977)) {
$e29762977.pyretStack.push(L[458]);
}
throw $e29762977;
}
var $ret29822983 = $Hann_DASH_check_DASH_temp23702990($z29782979);
++R.GAS;
return $ret29822983;
});
var $z29632964 = D;
var $f29692970 = function(_) {
return R.isFunction(anf_fun13852971)?anf_fun13852971.app(anf_arg13952972):R.ffi.throwNonFunApp(L[457],anf_fun13852971,[anf_arg13952972]);
};
try {
if(--R.GAS > 0) {
$z29632964 = $f29692970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29692970,
"from":L[457]});
}
} catch($e29612962) {
if(R.isCont($e29612962)) {
var $ss29652966 = {"from":L[457],
"go":function(filenames5012973) {
return $Hfilenames24662974(filenames5012973,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13);
}};
$e29612962.stack[R.EXN_STACKHEIGHT++] = $ss29652966;
}
if(R.isPyretException($e29612962)) {
$e29612962.pyretStack.push(L[457]);
}
throw $e29612962;
}
var $ret29672968 = $Hfilenames24662974($z29632964,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13);
++R.GAS;
return $ret29672968;
};
var $Hfilenames24662974 = function(filenames5012973,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13) {
var anf_arg13963022 = G(l486745,"source",L[465]);
var $z30143015 = D;
var $f30203021 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(anf_arg13963022):R.ffi.throwNonFunApp(L[464],compiler_DASH_name167645.$var,[anf_arg13963022]);
};
try {
if(--R.GAS > 0) {
$z30143015 = $f30203021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30203021,
"from":L[464]});
}
} catch($e30123013) {
if(R.isCont($e30123013)) {
var $ss30163017 = {"from":L[464],
"go":function(module_DASH_id5073023) {
return $Hmodule_DASH_id24653024(module_DASH_id5073023,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13);
}};
$e30123013.stack[R.EXN_STACKHEIGHT++] = $ss30163017;
}
if(R.isPyretException($e30123013)) {
$e30123013.pyretStack.push(L[464]);
}
throw $e30123013;
}
var $ret30183019 = $Hmodule_DASH_id24653024($z30143015,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13);
++R.GAS;
return $ret30183019;
};
var $Hmodule_DASH_id24653024 = function(module_DASH_id5073023,D1324,Loc7863,compile_DASH_helper178667,compiler_DASH_name167645,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13) {
var module_DASH_ref5083038 = R.makeFunction(function(name5093053) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[469],1,arguments);
}
var $z30563057 = D;
var $f30623063 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("modules")):R.ffi.throwNonFunApp(L[470],rt_DASH_field172655.$var,[("modules")]);
};
try {
if(--R.GAS > 0) {
$z30563057 = $f30623063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30623063,
"from":L[470]});
}
} catch($e30543055) {
if(R.isCont($e30543055)) {
var $ss30583059 = {"from":L[470],
"go":function(anf_arg13983064) {
return $Hanf_arg23733065(anf_arg13983064,j_DASH_bracket9872,j_DASH_str8993,name5093053);
}};
$e30543055.stack[R.EXN_STACKHEIGHT++] = $ss30583059;
}
if(R.isPyretException($e30543055)) {
$e30543055.pyretStack.push(L[470]);
}
throw $e30543055;
}
var $ret30603061 = $Hanf_arg23733065($z30563057,j_DASH_bracket9872,j_DASH_str8993,name5093053);
++R.GAS;
return $ret30603061;
});
var anf_fun14003035 = G(ids4982888,"map",L[468]);
var anf_arg14023036 = R.makeFunction(function(f5113040) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[467],1,arguments);
}
var $z30433044 = D;
var $f30493050 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(f5113040):R.ffi.throwNonFunApp(L[467],compiler_DASH_name167645.$var,[f5113040]);
};
try {
if(--R.GAS > 0) {
$z30433044 = $f30493050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30493050,
"from":L[467]});
}
} catch($e30413042) {
if(R.isCont($e30413042)) {
var $ss30453046 = {"from":L[467],
"go":function(ann_DASH_check_DASH_temp14013051) {
return $Hann_DASH_check_DASH_temp23743052(ann_DASH_check_DASH_temp14013051);
}};
$e30413042.stack[R.EXN_STACKHEIGHT++] = $ss30453046;
}
if(R.isPyretException($e30413042)) {
$e30413042.pyretStack.push(L[467]);
}
throw $e30413042;
}
var $ret30473048 = $Hann_DASH_check_DASH_temp23743052($z30433044);
++R.GAS;
return $ret30473048;
});
var $z30273028 = D;
var $f30333034 = function(_) {
return R.isFunction(anf_fun14003035)?anf_fun14003035.app(anf_arg14023036):R.ffi.throwNonFunApp(L[466],anf_fun14003035,[anf_arg14023036]);
};
try {
if(--R.GAS > 0) {
$z30273028 = $f30333034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30333034,
"from":L[466]});
}
} catch($e30253026) {
if(R.isCont($e30253026)) {
var $ss30293030 = {"from":L[466],
"go":function(input_DASH_ids5103037) {
return $Hinput_DASH_ids24643039(input_DASH_ids5103037,D1324,Loc7863,compile_DASH_helper178667,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13);
}};
$e30253026.stack[R.EXN_STACKHEIGHT++] = $ss30293030;
}
if(R.isPyretException($e30253026)) {
$e30253026.pyretStack.push(L[466]);
}
throw $e30253026;
}
var $ret30313032 = $Hinput_DASH_ids24643039($z30273028,D1324,Loc7863,compile_DASH_helper178667,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13);
++R.GAS;
return $ret30313032;
};
var $Hinput_DASH_ids24643039 = function(input_DASH_ids5103037,D1324,Loc7863,compile_DASH_helper178667,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,ids4982888,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,map248102,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,rt_DASH_field172655,rt_DASH_method173657,self485744,split488747,type_DASH_ids5002959,_plus5,torepr13) {
var wrap_DASH_modules5123066 = {"$var":D,
"$name":"wrap-modules"};
var anf_assign14583067 = R.makeFunction(function(modules5133084,body5143085) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[473],2,arguments);
}
var anf_fun14043096 = G(modules5133084,"map",L[476]);
var anf_arg14063097 = R.makeFunction(function(recv_DASH_803100) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[475],1,arguments);
}
var ann_DASH_check_DASH_temp14053101 = G(recv_DASH_803100,"input-id",L[475]);
return ann_DASH_check_DASH_temp14053101;
});
var $z30883089 = D;
var $f30943095 = function(_) {
return R.isFunction(anf_fun14043096)?anf_fun14043096.app(anf_arg14063097):R.ffi.throwNonFunApp(L[474],anf_fun14043096,[anf_arg14063097]);
};
try {
if(--R.GAS > 0) {
$z30883089 = $f30943095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30943095,
"from":L[474]});
}
} catch($e30863087) {
if(R.isCont($e30863087)) {
var $ss30903091 = {"from":L[474],
"go":function(mod_DASH_input_DASH_names5153098) {
return $Hmod_DASH_input_DASH_names24143099(mod_DASH_input_DASH_names5153098,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,module_DASH_id5073023,modules5133084,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
}};
$e30863087.stack[R.EXN_STACKHEIGHT++] = $ss30903091;
}
if(R.isPyretException($e30863087)) {
$e30863087.pyretStack.push(L[474]);
}
throw $e30863087;
}
var $ret30923093 = $Hmod_DASH_input_DASH_names24143099($z30883089,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,module_DASH_id5073023,modules5133084,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
++R.GAS;
return $ret30923093;
});
wrap_DASH_modules5123066.$var = anf_assign14583067;
var anf_arg14603078 = R.makeFunction(function(id5233081,in_DASH_id5243082) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[472],2,arguments);
}
var ann_DASH_check_DASH_temp14593083 = R.makeObject({"id":id5233081,
"input-id":in_DASH_id5243082});
return ann_DASH_check_DASH_temp14593083;
});
var $z30703071 = D;
var $f30763077 = function(_) {
return R.isFunction(map248102)?map248102.app(anf_arg14603078,ids4982888,input_DASH_ids5103037):R.ffi.throwNonFunApp(L[471],map248102,[anf_arg14603078,ids4982888,input_DASH_ids5103037]);
};
try {
if(--R.GAS > 0) {
$z30703071 = $f30763077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30763077,
"from":L[471]});
}
} catch($e30683069) {
if(R.isCont($e30683069)) {
var $ss30723073 = {"from":L[471],
"go":function(module_DASH_specs5223079) {
return $Hmodule_DASH_specs24633080(module_DASH_specs5223079,D1324,Loc7863,compile_DASH_helper178667,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,self485744,split488747,wrap_DASH_modules5123066,_plus5,torepr13);
}};
$e30683069.stack[R.EXN_STACKHEIGHT++] = $ss30723073;
}
if(R.isPyretException($e30683069)) {
$e30683069.pyretStack.push(L[471]);
}
throw $e30683069;
}
var $ret30743075 = $Hmodule_DASH_specs24633080($z30703071,D1324,Loc7863,compile_DASH_helper178667,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,self485744,split488747,wrap_DASH_modules5123066,_plus5,torepr13);
++R.GAS;
return $ret30743075;
};
var $Hmodule_DASH_specs24633080 = function(module_DASH_specs5223079,D1324,Loc7863,compile_DASH_helper178667,concat_DASH_empty122150,concat_DASH_snoc130166,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,self485744,split488747,wrap_DASH_modules5123066,_plus5,torepr13) {
var locations5253115 = {"$var":concat_DASH_empty122150.$var,
"$name":"locations"};
var loc_DASH_count5263114 = {"$var":(0),
"$name":"loc-count"};
var anf_fun14613112 = G(D1324,"string-dict",L[478]);
var $z31043105 = D;
var $f31103111 = function(_) {
return R.isFunction(anf_fun14613112)?anf_fun14613112.app():R.ffi.throwNonFunApp(L[477],anf_fun14613112,[]);
};
try {
if(--R.GAS > 0) {
$z31043105 = $f31103111();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31103111,
"from":L[477]});
}
} catch($e31023103) {
if(R.isCont($e31023103)) {
var $ss31063107 = {"from":L[477],
"go":function(var_DASH_bind24153113) {
return $Hvar_DASH_bind24623116(var_DASH_bind24153113,Loc7863,compile_DASH_helper178667,concat_DASH_snoc130166,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,loc_DASH_count5263114,locations5253115,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,self485744,split488747,wrap_DASH_modules5123066,_plus5,torepr13);
}};
$e31023103.stack[R.EXN_STACKHEIGHT++] = $ss31063107;
}
if(R.isPyretException($e31023103)) {
$e31023103.pyretStack.push(L[477]);
}
throw $e31023103;
}
var $ret31083109 = $Hvar_DASH_bind24623116($z31043105,Loc7863,compile_DASH_helper178667,concat_DASH_snoc130166,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,loc_DASH_count5263114,locations5253115,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,self485744,split488747,wrap_DASH_modules5123066,_plus5,torepr13);
++R.GAS;
return $ret31083109;
};
var $Hvar_DASH_bind24623116 = function(var_DASH_bind24153113,Loc7863,compile_DASH_helper178667,concat_DASH_snoc130166,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket9872,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_num8889,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,loc_DASH_count5263114,locations5253115,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,obj_DASH_of_DASH_loc168647,self485744,split488747,wrap_DASH_modules5123066,_plus5,torepr13) {
var loc_DASH_cache5273161 = {"$var":var_DASH_bind24153113,
"$name":"loc-cache"};
var locs5283132 = ("L");
var get_DASH_loc5293117 = {"$var":D,
"$name":"get-loc"};
var anf_assign14793118 = R.makeFunction(function(l5303149) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[483],1,arguments);
}
return R.checkAnnArgs([Loc7863],[l5303149],[L[485]],function() {
var $z31523153 = D;
var $f31583159 = function(_) {
return R.isFunction(torepr13)?torepr13.app(l5303149):R.ffi.throwNonFunApp(L[484],torepr13,[l5303149]);
};
try {
if(--R.GAS > 0) {
$z31523153 = $f31583159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31583159,
"from":L[484]});
}
} catch($e31503151) {
if(R.isCont($e31503151)) {
var $ss31543155 = {"from":L[484],
"go":function(as_DASH_str5313160) {
return $Has_DASH_str24273162(as_DASH_str5313160,concat_DASH_snoc130166,j_DASH_bracket9872,j_DASH_id8381,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,locs5283132,obj_DASH_of_DASH_loc168647,_plus5);
}};
$e31503151.stack[R.EXN_STACKHEIGHT++] = $ss31543155;
}
if(R.isPyretException($e31503151)) {
$e31503151.pyretStack.push(L[484]);
}
throw $e31503151;
}
var $ret31563157 = $Has_DASH_str24273162($z31523153,concat_DASH_snoc130166,j_DASH_bracket9872,j_DASH_id8381,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,locs5283132,obj_DASH_of_DASH_loc168647,_plus5);
++R.GAS;
return $ret31563157;
});
});
get_DASH_loc5293117.$var = anf_assign14793118;
var anf_bracket14803148 = G(split488747,"helpers",L[482]);
var anf_fun14813129 = G(anf_bracket14803148,"map",L[481]);
var anf_arg14843130 = R.makeFunction(function(arg_DASH_833134) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[480],1,arguments);
}
var anf_arg14833145 = self485744.extendWith({"get-loc":get_DASH_loc5293117.$var});
var $z31373138 = D;
var $f31433144 = function(_) {
return R.isFunction(compile_DASH_helper178667.$var)?compile_DASH_helper178667.$var.app(anf_arg14833145,arg_DASH_833134):R.ffi.throwNonFunApp(L[480],compile_DASH_helper178667.$var,[anf_arg14833145,arg_DASH_833134]);
};
try {
if(--R.GAS > 0) {
$z31373138 = $f31433144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31433144,
"from":L[480]});
}
} catch($e31353136) {
if(R.isCont($e31353136)) {
var $ss31393140 = {"from":L[480],
"go":function(ann_DASH_check_DASH_temp14823146) {
return $Hann_DASH_check_DASH_temp24283147(ann_DASH_check_DASH_temp14823146);
}};
$e31353136.stack[R.EXN_STACKHEIGHT++] = $ss31393140;
}
if(R.isPyretException($e31353136)) {
$e31353136.pyretStack.push(L[480]);
}
throw $e31353136;
}
var $ret31413142 = $Hann_DASH_check_DASH_temp24283147($z31373138);
++R.GAS;
return $ret31413142;
});
var $z31213122 = D;
var $f31273128 = function(_) {
return R.isFunction(anf_fun14813129)?anf_fun14813129.app(anf_arg14843130):R.ffi.throwNonFunApp(L[479],anf_fun14813129,[anf_arg14843130]);
};
try {
if(--R.GAS > 0) {
$z31213122 = $f31273128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31273128,
"from":L[479]});
}
} catch($e31193120) {
if(R.isCont($e31193120)) {
var $ss31233124 = {"from":L[479],
"go":function(visited_DASH_helpers5333131) {
return $Hvisited_DASH_helpers24613133(visited_DASH_helpers5333131,filenames5012973,get_DASH_loc5293117,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locations5253115,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,self485744,split488747,wrap_DASH_modules5123066,_plus5);
}};
$e31193120.stack[R.EXN_STACKHEIGHT++] = $ss31233124;
}
if(R.isPyretException($e31193120)) {
$e31193120.pyretStack.push(L[479]);
}
throw $e31193120;
}
var $ret31253126 = $Hvisited_DASH_helpers24613133($z31213122,filenames5012973,get_DASH_loc5293117,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locations5253115,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,self485744,split488747,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret31253126;
};
var $Hvisited_DASH_helpers24613133 = function(visited_DASH_helpers5333131,filenames5012973,get_DASH_loc5293117,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locations5253115,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,self485744,split488747,wrap_DASH_modules5123066,_plus5) {
var anf_bracket14853177 = G(split488747,"body",L[488]);
var anf_fun14863173 = G(anf_bracket14853177,"visit",L[487]);
var anf_arg14873174 = self485744.extendWith({"get-loc":get_DASH_loc5293117.$var});
var $z31653166 = D;
var $f31713172 = function(_) {
return R.isFunction(anf_fun14863173)?anf_fun14863173.app(anf_arg14873174):R.ffi.throwNonFunApp(L[486],anf_fun14863173,[anf_arg14873174]);
};
try {
if(--R.GAS > 0) {
$z31653166 = $f31713172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31713172,
"from":L[486]});
}
} catch($e31633164) {
if(R.isCont($e31633164)) {
var $ss31673168 = {"from":L[486],
"go":function(visited_DASH_body5343175) {
return $Hvisited_DASH_body24603176(visited_DASH_body5343175,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locations5253115,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e31633164.stack[R.EXN_STACKHEIGHT++] = $ss31673168;
}
if(R.isPyretException($e31633164)) {
$e31633164.pyretStack.push(L[486]);
}
throw $e31633164;
}
var $ret31693170 = $Hvisited_DASH_body24603176($z31653166,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locations5253115,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret31693170;
};
var $Hvisited_DASH_body24603176 = function(visited_DASH_body5343175,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locations5253115,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var anf_fun14883188 = G(locations5253115.$var,"to-list",L[490]);
var $z31803181 = D;
var $f31863187 = function(_) {
return R.isFunction(anf_fun14883188)?anf_fun14883188.app():R.ffi.throwNonFunApp(L[489],anf_fun14883188,[]);
};
try {
if(--R.GAS > 0) {
$z31803181 = $f31863187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31863187,
"from":L[489]});
}
} catch($e31783179) {
if(R.isCont($e31783179)) {
var $ss31823183 = {"from":L[489],
"go":function(anf_arg14893189) {
return $Hanf_arg24593190(anf_arg14893189,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e31783179.stack[R.EXN_STACKHEIGHT++] = $ss31823183;
}
if(R.isPyretException($e31783179)) {
$e31783179.pyretStack.push(L[489]);
}
throw $e31783179;
}
var $ret31843185 = $Hanf_arg24593190($z31803181,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret31843185;
};
var $Hanf_arg24593190 = function(anf_arg14893189,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z31933194 = D;
var $f31993200 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((true),anf_arg14893189):R.ffi.throwNonFunApp(L[491],j_DASH_list9585,[(true),anf_arg14893189]);
};
try {
if(--R.GAS > 0) {
$z31933194 = $f31993200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31993200,
"from":L[491]});
}
} catch($e31913192) {
if(R.isCont($e31913192)) {
var $ss31953196 = {"from":L[491],
"go":function(anf_arg14903201) {
return $Hanf_arg24583202(anf_arg14903201,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e31913192.stack[R.EXN_STACKHEIGHT++] = $ss31953196;
}
if(R.isPyretException($e31913192)) {
$e31913192.pyretStack.push(L[491]);
}
throw $e31913192;
}
var $ret31973198 = $Hanf_arg24583202($z31933194,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret31973198;
};
var $Hanf_arg24583202 = function(anf_arg14903201,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,l486745,list35101,locs5283132,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z32053206 = D;
var $f32113212 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(locs5283132,anf_arg14903201):R.ffi.throwNonFunApp(L[492],j_DASH_var8299,[locs5283132,anf_arg14903201]);
};
try {
if(--R.GAS > 0) {
$z32053206 = $f32113212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32113212,
"from":L[492]});
}
} catch($e32033204) {
if(R.isCont($e32033204)) {
var $ss32073208 = {"from":L[492],
"go":function(define_DASH_locations5353213) {
return $Hdefine_DASH_locations24573214(define_DASH_locations5353213,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e32033204.stack[R.EXN_STACKHEIGHT++] = $ss32073208;
}
if(R.isPyretException($e32033204)) {
$e32033204.pyretStack.push(L[492]);
}
throw $e32033204;
}
var $ret32093210 = $Hdefine_DASH_locations24573214($z32053206,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret32093210;
};
var $Hdefine_DASH_locations24573214 = function(define_DASH_locations5353213,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z32173218 = D;
var $f32233224 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("define")):R.ffi.throwNonFunApp(L[493],j_DASH_id8381,[("define")]);
};
try {
if(--R.GAS > 0) {
$z32173218 = $f32233224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32233224,
"from":L[493]});
}
} catch($e32153216) {
if(R.isCont($e32153216)) {
var $ss32193220 = {"from":L[493],
"go":function(anf_arg14913225) {
return $Hanf_arg24563226(anf_arg14913225,define_DASH_locations5353213,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e32153216.stack[R.EXN_STACKHEIGHT++] = $ss32193220;
}
if(R.isPyretException($e32153216)) {
$e32153216.pyretStack.push(L[493]);
}
throw $e32153216;
}
var $ret32213222 = $Hanf_arg24563226($z32173218,define_DASH_locations5353213,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret32213222;
};
var $Hanf_arg24563226 = function(anf_arg14913225,define_DASH_locations5353213,filenames5012973,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var anf_fun14923239 = G(list35101,"make",L[496]);
var anf_fun14933237 = G(filenames5012973,"map",L[495]);
var $z32293230 = D;
var $f32353236 = function(_) {
return R.isFunction(anf_fun14933237)?anf_fun14933237.app(j_DASH_str8993):R.ffi.throwNonFunApp(L[494],anf_fun14933237,[j_DASH_str8993]);
};
try {
if(--R.GAS > 0) {
$z32293230 = $f32353236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32353236,
"from":L[494]});
}
} catch($e32273228) {
if(R.isCont($e32273228)) {
var $ss32313232 = {"from":L[494],
"go":function(anf_arg14943238) {
return $Hanf_arg24553240(anf_arg14943238,anf_arg14913225,anf_fun14923239,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e32273228.stack[R.EXN_STACKHEIGHT++] = $ss32313232;
}
if(R.isPyretException($e32273228)) {
$e32273228.pyretStack.push(L[494]);
}
throw $e32273228;
}
var $ret32333234 = $Hanf_arg24553240($z32293230,anf_arg14913225,anf_fun14923239,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret32333234;
};
var $Hanf_arg24553240 = function(anf_arg14943238,anf_arg14913225,anf_fun14923239,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_list9585,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z32433244 = D;
var $f32493250 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((true),anf_arg14943238):R.ffi.throwNonFunApp(L[497],j_DASH_list9585,[(true),anf_arg14943238]);
};
try {
if(--R.GAS > 0) {
$z32433244 = $f32493250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32493250,
"from":L[497]});
}
} catch($e32413242) {
if(R.isCont($e32413242)) {
var $ss32453246 = {"from":L[497],
"go":function(anf_array_val14953251) {
return $Hanf_array_val24543252(anf_array_val14953251,anf_arg14913225,anf_fun14923239,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e32413242.stack[R.EXN_STACKHEIGHT++] = $ss32453246;
}
if(R.isPyretException($e32413242)) {
$e32413242.pyretStack.push(L[497]);
}
throw $e32413242;
}
var $ret32473248 = $Hanf_array_val24543252($z32433244,anf_arg14913225,anf_fun14923239,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret32473248;
};
var $Hanf_array_val24543252 = function(anf_array_val14953251,anf_arg14913225,anf_fun14923239,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var anf_fun14963265 = G(list35101,"make",L[499]);
var anf_fun14973263 = G(list35101,"make",L[498]);
var $z32553256 = D;
var $f32613262 = function(_) {
return R.isFunction(anf_fun14973263)?anf_fun14973263.app([("R"),("NAMESPACE")]):R.ffi.throwNonFunApp(L[498],anf_fun14973263,[[("R"),("NAMESPACE")]]);
};
try {
if(--R.GAS > 0) {
$z32553256 = $f32613262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32613262,
"from":L[498]});
}
} catch($e32533254) {
if(R.isCont($e32533254)) {
var $ss32573258 = {"from":L[498],
"go":function(anf_arg14983264) {
return $Hanf_arg24533266(anf_arg14983264,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e32533254.stack[R.EXN_STACKHEIGHT++] = $ss32573258;
}
if(R.isPyretException($e32533254)) {
$e32533254.pyretStack.push(L[498]);
}
throw $e32533254;
}
var $ret32593260 = $Hanf_arg24533266($z32553256,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret32593260;
};
var $Hanf_arg24533266 = function(anf_arg14983264,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var anf_fun14993278 = G(list35101,"make",L[501]);
var $z32693270 = D;
var $f32753276 = function(_) {
return R.isFunction(module_DASH_ref5083038)?module_DASH_ref5083038.app(module_DASH_id5073023):R.ffi.throwNonFunApp(L[500],module_DASH_ref5083038,[module_DASH_id5073023]);
};
try {
if(--R.GAS > 0) {
$z32693270 = $f32753276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32753276,
"from":L[500]});
}
} catch($e32673268) {
if(R.isCont($e32673268)) {
var $ss32713272 = {"from":L[500],
"go":function(anf_arg15003277) {
return $Hanf_arg24523279(anf_arg15003277,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e32673268.stack[R.EXN_STACKHEIGHT++] = $ss32713272;
}
if(R.isPyretException($e32673268)) {
$e32673268.pyretStack.push(L[500]);
}
throw $e32673268;
}
var $ret32733274 = $Hanf_arg24523279($z32693270,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret32733274;
};
var $Hanf_arg24523279 = function(anf_arg15003277,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_id5073023,module_DASH_ref5083038,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var anf_fun15013291 = G(list35101,"make",L[503]);
var $z32823283 = D;
var $f32883289 = function(_) {
return R.isFunction(module_DASH_ref5083038)?module_DASH_ref5083038.app(module_DASH_id5073023):R.ffi.throwNonFunApp(L[502],module_DASH_ref5083038,[module_DASH_id5073023]);
};
try {
if(--R.GAS > 0) {
$z32823283 = $f32883289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32883289,
"from":L[502]});
}
} catch($e32803281) {
if(R.isCont($e32803281)) {
var $ss32843285 = {"from":L[502],
"go":function(anf_arg15023290) {
return $Hanf_arg24513292(anf_arg15023290,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15013291,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e32803281.stack[R.EXN_STACKHEIGHT++] = $ss32843285;
}
if(R.isPyretException($e32803281)) {
$e32803281.pyretStack.push(L[502]);
}
throw $e32803281;
}
var $ret32863287 = $Hanf_arg24513292($z32823283,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15013291,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret32863287;
};
var $Hanf_arg24513292 = function(anf_arg15023290,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15013291,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z32953296 = D;
var $f33013302 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg15023290):R.ffi.throwNonFunApp(L[504],j_DASH_return9092,[anf_arg15023290]);
};
try {
if(--R.GAS > 0) {
$z32953296 = $f33013302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33013302,
"from":L[504]});
}
} catch($e32933294) {
if(R.isCont($e32933294)) {
var $ss32973298 = {"from":L[504],
"go":function(anf_array_val15033303) {
return $Hanf_array_val24503304(anf_array_val15033303,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15013291,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e32933294.stack[R.EXN_STACKHEIGHT++] = $ss32973298;
}
if(R.isPyretException($e32933294)) {
$e32933294.pyretStack.push(L[504]);
}
throw $e32933294;
}
var $ret32993300 = $Hanf_array_val24503304($z32953296,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15013291,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret32993300;
};
var $Hanf_array_val24503304 = function(anf_array_val15033303,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15013291,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z33073308 = D;
var $f33133314 = function(_) {
return R.isFunction(anf_fun15013291)?anf_fun15013291.app([anf_array_val15033303]):R.ffi.throwNonFunApp(L[503],anf_fun15013291,[[anf_array_val15033303]]);
};
try {
if(--R.GAS > 0) {
$z33073308 = $f33133314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33133314,
"from":L[503]});
}
} catch($e33053306) {
if(R.isCont($e33053306)) {
var $ss33093310 = {"from":L[503],
"go":function(anf_arg15043315) {
return $Hanf_arg24493316(anf_arg15043315,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e33053306.stack[R.EXN_STACKHEIGHT++] = $ss33093310;
}
if(R.isPyretException($e33053306)) {
$e33053306.pyretStack.push(L[503]);
}
throw $e33053306;
}
var $ret33113312 = $Hanf_arg24493316($z33073308,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret33113312;
};
var $Hanf_arg24493316 = function(anf_arg15043315,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z33193320 = D;
var $f33253326 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg15043315):R.ffi.throwNonFunApp(L[505],j_DASH_block8570,[anf_arg15043315]);
};
try {
if(--R.GAS > 0) {
$z33193320 = $f33253326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33253326,
"from":L[505]});
}
} catch($e33173318) {
if(R.isCont($e33173318)) {
var $ss33213322 = {"from":L[505],
"go":function(anf_arg15053327) {
return $Hanf_arg24483328(anf_arg15053327,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e33173318.stack[R.EXN_STACKHEIGHT++] = $ss33213322;
}
if(R.isPyretException($e33173318)) {
$e33173318.pyretStack.push(L[505]);
}
throw $e33173318;
}
var $ret33233324 = $Hanf_arg24483328($z33193320,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret33233324;
};
var $Hanf_arg24483328 = function(anf_arg15053327,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,l486745,list35101,mk_DASH_abbrevs480679,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z33313332 = D;
var $f33373338 = function(_) {
return R.isFunction(mk_DASH_abbrevs480679.$var)?mk_DASH_abbrevs480679.$var.app(l486745):R.ffi.throwNonFunApp(L[506],mk_DASH_abbrevs480679.$var,[l486745]);
};
try {
if(--R.GAS > 0) {
$z33313332 = $f33373338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33373338,
"from":L[506]});
}
} catch($e33293330) {
if(R.isCont($e33293330)) {
var $ss33333334 = {"from":L[506],
"go":function(anf_arg15063339) {
return $Hanf_arg24473340(anf_arg15063339,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e33293330.stack[R.EXN_STACKHEIGHT++] = $ss33333334;
}
if(R.isPyretException($e33293330)) {
$e33293330.pyretStack.push(L[506]);
}
throw $e33293330;
}
var $ret33353336 = $Hanf_arg24473340($z33313332,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret33353336;
};
var $Hanf_arg24473340 = function(anf_arg15063339,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,define_DASH_locations5353213,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var anf_fun15073351 = G(list35101,"make",L[507]);
var $z33433344 = D;
var $f33493350 = function(_) {
return R.isFunction(anf_fun15073351)?anf_fun15073351.app([define_DASH_locations5353213]):R.ffi.throwNonFunApp(L[507],anf_fun15073351,[[define_DASH_locations5353213]]);
};
try {
if(--R.GAS > 0) {
$z33433344 = $f33493350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33493350,
"from":L[507]});
}
} catch($e33413342) {
if(R.isCont($e33413342)) {
var $ss33453346 = {"from":L[507],
"go":function(anf_arg15083352) {
return $Hanf_arg24463353(anf_arg15083352,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15063339,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e33413342.stack[R.EXN_STACKHEIGHT++] = $ss33453346;
}
if(R.isPyretException($e33413342)) {
$e33413342.pyretStack.push(L[507]);
}
throw $e33413342;
}
var $ret33473348 = $Hanf_arg24463353($z33433344,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15063339,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret33473348;
};
var $Hanf_arg24463353 = function(anf_arg15083352,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15063339,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z33563357 = D;
var $f33623363 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg15063339,anf_arg15083352):R.ffi.throwNonFunApp(L[508],_plus5,[anf_arg15063339,anf_arg15083352]);
};
try {
if(--R.GAS > 0) {
$z33563357 = $f33623363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33623363,
"from":L[508]});
}
} catch($e33543355) {
if(R.isCont($e33543355)) {
var $ss33583359 = {"from":L[508],
"go":function(anf_arg15093364) {
return $Hanf_arg24453365(anf_arg15093364,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e33543355.stack[R.EXN_STACKHEIGHT++] = $ss33583359;
}
if(R.isPyretException($e33543355)) {
$e33543355.pyretStack.push(L[508]);
}
throw $e33543355;
}
var $ret33603361 = $Hanf_arg24453365($z33563357,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret33603361;
};
var $Hanf_arg24453365 = function(anf_arg15093364,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,namespace_DASH_binds4932831,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z33683369 = D;
var $f33743375 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg15093364,namespace_DASH_binds4932831):R.ffi.throwNonFunApp(L[508],_plus5,[anf_arg15093364,namespace_DASH_binds4932831]);
};
try {
if(--R.GAS > 0) {
$z33683369 = $f33743375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33743375,
"from":L[508]});
}
} catch($e33663367) {
if(R.isCont($e33663367)) {
var $ss33703371 = {"from":L[508],
"go":function(anf_arg15103376) {
return $Hanf_arg24443377(anf_arg15103376,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
}};
$e33663367.stack[R.EXN_STACKHEIGHT++] = $ss33703371;
}
if(R.isPyretException($e33663367)) {
$e33663367.pyretStack.push(L[508]);
}
throw $e33663367;
}
var $ret33723373 = $Hanf_arg24443377($z33683369,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret33723373;
};
var $Hanf_arg24443377 = function(anf_arg15103376,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,visited_DASH_body5343175,visited_DASH_helpers5333131,wrap_DASH_modules5123066,_plus5) {
var $z33803381 = D;
var $f33863387 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg15103376,visited_DASH_helpers5333131):R.ffi.throwNonFunApp(L[508],_plus5,[anf_arg15103376,visited_DASH_helpers5333131]);
};
try {
if(--R.GAS > 0) {
$z33803381 = $f33863387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33863387,
"from":L[508]});
}
} catch($e33783379) {
if(R.isCont($e33783379)) {
var $ss33823383 = {"from":L[508],
"go":function(anf_arg15113388) {
return $Hanf_arg24433389(anf_arg15113388,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,visited_DASH_body5343175,wrap_DASH_modules5123066,_plus5);
}};
$e33783379.stack[R.EXN_STACKHEIGHT++] = $ss33823383;
}
if(R.isPyretException($e33783379)) {
$e33783379.pyretStack.push(L[508]);
}
throw $e33783379;
}
var $ret33843385 = $Hanf_arg24433389($z33803381,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,visited_DASH_body5343175,wrap_DASH_modules5123066,_plus5);
++R.GAS;
return $ret33843385;
};
var $Hanf_arg24433389 = function(anf_arg15113388,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,list35101,module_DASH_specs5223079,visited_DASH_body5343175,wrap_DASH_modules5123066,_plus5) {
var anf_fun15123401 = G(list35101,"make",L[510]);
var $z33923393 = D;
var $f33983399 = function(_) {
return R.isFunction(wrap_DASH_modules5123066.$var)?wrap_DASH_modules5123066.$var.app(module_DASH_specs5223079,visited_DASH_body5343175):R.ffi.throwNonFunApp(L[509],wrap_DASH_modules5123066.$var,[module_DASH_specs5223079,visited_DASH_body5343175]);
};
try {
if(--R.GAS > 0) {
$z33923393 = $f33983399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33983399,
"from":L[509]});
}
} catch($e33903391) {
if(R.isCont($e33903391)) {
var $ss33943395 = {"from":L[509],
"go":function(anf_array_val15133400) {
return $Hanf_array_val24423402(anf_array_val15133400,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15113388,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15123401,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,_plus5);
}};
$e33903391.stack[R.EXN_STACKHEIGHT++] = $ss33943395;
}
if(R.isPyretException($e33903391)) {
$e33903391.pyretStack.push(L[509]);
}
throw $e33903391;
}
var $ret33963397 = $Hanf_array_val24423402($z33923393,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15113388,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15123401,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,_plus5);
++R.GAS;
return $ret33963397;
};
var $Hanf_array_val24423402 = function(anf_array_val15133400,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15113388,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,anf_fun15123401,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,_plus5) {
var $z34053406 = D;
var $f34113412 = function(_) {
return R.isFunction(anf_fun15123401)?anf_fun15123401.app([anf_array_val15133400]):R.ffi.throwNonFunApp(L[510],anf_fun15123401,[[anf_array_val15133400]]);
};
try {
if(--R.GAS > 0) {
$z34053406 = $f34113412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34113412,
"from":L[510]});
}
} catch($e34033404) {
if(R.isCont($e34033404)) {
var $ss34073408 = {"from":L[510],
"go":function(anf_arg15143413) {
return $Hanf_arg24413414(anf_arg15143413,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15113388,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,_plus5);
}};
$e34033404.stack[R.EXN_STACKHEIGHT++] = $ss34073408;
}
if(R.isPyretException($e34033404)) {
$e34033404.pyretStack.push(L[510]);
}
throw $e34033404;
}
var $ret34093410 = $Hanf_arg24413414($z34053406,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15113388,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,_plus5);
++R.GAS;
return $ret34093410;
};
var $Hanf_arg24413414 = function(anf_arg15143413,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_arg15113388,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092,_plus5) {
var $z34173418 = D;
var $f34233424 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg15113388,anf_arg15143413):R.ffi.throwNonFunApp(L[508],_plus5,[anf_arg15113388,anf_arg15143413]);
};
try {
if(--R.GAS > 0) {
$z34173418 = $f34233424();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34233424,
"from":L[508]});
}
} catch($e34153416) {
if(R.isCont($e34153416)) {
var $ss34193420 = {"from":L[508],
"go":function(anf_arg15153425) {
return $Hanf_arg24403426(anf_arg15153425,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092);
}};
$e34153416.stack[R.EXN_STACKHEIGHT++] = $ss34193420;
}
if(R.isPyretException($e34153416)) {
$e34153416.pyretStack.push(L[508]);
}
throw $e34153416;
}
var $ret34213422 = $Hanf_arg24403426($z34173418,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092);
++R.GAS;
return $ret34213422;
};
var $Hanf_arg24403426 = function(anf_arg15153425,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092) {
var $z34293430 = D;
var $f34353436 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg15153425):R.ffi.throwNonFunApp(L[511],j_DASH_block8570,[anf_arg15153425]);
};
try {
if(--R.GAS > 0) {
$z34293430 = $f34353436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34353436,
"from":L[511]});
}
} catch($e34273428) {
if(R.isCont($e34273428)) {
var $ss34313432 = {"from":L[511],
"go":function(anf_arg15163437) {
return $Hanf_arg24393438(anf_arg15163437,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092);
}};
$e34273428.stack[R.EXN_STACKHEIGHT++] = $ss34313432;
}
if(R.isPyretException($e34273428)) {
$e34273428.pyretStack.push(L[511]);
}
throw $e34273428;
}
var $ret34333434 = $Hanf_arg24393438($z34293430,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092);
++R.GAS;
return $ret34333434;
};
var $Hanf_arg24393438 = function(anf_arg15163437,anf_arg14913225,anf_arg14983264,anf_arg15003277,anf_arg15053327,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_if9283,j_DASH_return9092) {
var $z34413442 = D;
var $f34473448 = function(_) {
return R.isFunction(j_DASH_if9283)?j_DASH_if9283.app(anf_arg15003277,anf_arg15053327,anf_arg15163437):R.ffi.throwNonFunApp(L[512],j_DASH_if9283,[anf_arg15003277,anf_arg15053327,anf_arg15163437]);
};
try {
if(--R.GAS > 0) {
$z34413442 = $f34473448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34473448,
"from":L[512]});
}
} catch($e34393440) {
if(R.isCont($e34393440)) {
var $ss34433444 = {"from":L[512],
"go":function(anf_array_val15173449) {
return $Hanf_array_val24383450(anf_array_val15173449,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092);
}};
$e34393440.stack[R.EXN_STACKHEIGHT++] = $ss34433444;
}
if(R.isPyretException($e34393440)) {
$e34393440.pyretStack.push(L[512]);
}
throw $e34393440;
}
var $ret34453446 = $Hanf_array_val24383450($z34413442,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092);
++R.GAS;
return $ret34453446;
};
var $Hanf_array_val24383450 = function(anf_array_val15173449,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,anf_fun14993278,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092) {
var $z34533454 = D;
var $f34593460 = function(_) {
return R.isFunction(anf_fun14993278)?anf_fun14993278.app([anf_array_val15173449]):R.ffi.throwNonFunApp(L[501],anf_fun14993278,[[anf_array_val15173449]]);
};
try {
if(--R.GAS > 0) {
$z34533454 = $f34593460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34593460,
"from":L[501]});
}
} catch($e34513452) {
if(R.isCont($e34513452)) {
var $ss34553456 = {"from":L[501],
"go":function(anf_arg15183461) {
return $Hanf_arg24373462(anf_arg15183461,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092);
}};
$e34513452.stack[R.EXN_STACKHEIGHT++] = $ss34553456;
}
if(R.isPyretException($e34513452)) {
$e34513452.pyretStack.push(L[501]);
}
throw $e34513452;
}
var $ret34573458 = $Hanf_arg24373462($z34533454,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092);
++R.GAS;
return $ret34573458;
};
var $Hanf_arg24373462 = function(anf_arg15183461,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092) {
var $z34653466 = D;
var $f34713472 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg15183461):R.ffi.throwNonFunApp(L[513],j_DASH_block8570,[anf_arg15183461]);
};
try {
if(--R.GAS > 0) {
$z34653466 = $f34713472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34713472,
"from":L[513]});
}
} catch($e34633464) {
if(R.isCont($e34633464)) {
var $ss34673468 = {"from":L[513],
"go":function(anf_arg15193473) {
return $Hanf_arg24363474(anf_arg15193473,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092);
}};
$e34633464.stack[R.EXN_STACKHEIGHT++] = $ss34673468;
}
if(R.isPyretException($e34633464)) {
$e34633464.pyretStack.push(L[513]);
}
throw $e34633464;
}
var $ret34693470 = $Hanf_arg24363474($z34653466,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092);
++R.GAS;
return $ret34693470;
};
var $Hanf_arg24363474 = function(anf_arg15193473,anf_arg14913225,anf_arg14983264,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092) {
var $z34773478 = D;
var $f34833484 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg14983264,anf_arg15193473):R.ffi.throwNonFunApp(L[514],j_DASH_fun8180,[anf_arg14983264,anf_arg15193473]);
};
try {
if(--R.GAS > 0) {
$z34773478 = $f34833484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34833484,
"from":L[514]});
}
} catch($e34753476) {
if(R.isCont($e34753476)) {
var $ss34793480 = {"from":L[514],
"go":function(anf_arg15203485) {
return $Hanf_arg24353486(anf_arg15203485,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092);
}};
$e34753476.stack[R.EXN_STACKHEIGHT++] = $ss34793480;
}
if(R.isPyretException($e34753476)) {
$e34753476.pyretStack.push(L[514]);
}
throw $e34753476;
}
var $ret34813482 = $Hanf_arg24353486($z34773478,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092);
++R.GAS;
return $ret34813482;
};
var $Hanf_arg24353486 = function(anf_arg15203485,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092) {
var $z34893490 = D;
var $f34953496 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg15203485):R.ffi.throwNonFunApp(L[515],j_DASH_return9092,[anf_arg15203485]);
};
try {
if(--R.GAS > 0) {
$z34893490 = $f34953496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34953496,
"from":L[515]});
}
} catch($e34873488) {
if(R.isCont($e34873488)) {
var $ss34913492 = {"from":L[515],
"go":function(anf_array_val15213497) {
return $Hanf_array_val24343498(anf_array_val15213497,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180);
}};
$e34873488.stack[R.EXN_STACKHEIGHT++] = $ss34913492;
}
if(R.isPyretException($e34873488)) {
$e34873488.pyretStack.push(L[515]);
}
throw $e34873488;
}
var $ret34933494 = $Hanf_array_val24343498($z34893490,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180);
++R.GAS;
return $ret34933494;
};
var $Hanf_array_val24343498 = function(anf_array_val15213497,anf_arg14913225,anf_array_val14953251,anf_fun14923239,anf_fun14963265,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180) {
var $z35013502 = D;
var $f35073508 = function(_) {
return R.isFunction(anf_fun14963265)?anf_fun14963265.app([anf_array_val15213497]):R.ffi.throwNonFunApp(L[499],anf_fun14963265,[[anf_array_val15213497]]);
};
try {
if(--R.GAS > 0) {
$z35013502 = $f35073508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35073508,
"from":L[499]});
}
} catch($e34993500) {
if(R.isCont($e34993500)) {
var $ss35033504 = {"from":L[499],
"go":function(anf_arg15223509) {
return $Hanf_arg24333510(anf_arg15223509,anf_arg14913225,anf_array_val14953251,anf_fun14923239,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180);
}};
$e34993500.stack[R.EXN_STACKHEIGHT++] = $ss35033504;
}
if(R.isPyretException($e34993500)) {
$e34993500.pyretStack.push(L[499]);
}
throw $e34993500;
}
var $ret35053506 = $Hanf_arg24333510($z35013502,anf_arg14913225,anf_array_val14953251,anf_fun14923239,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180);
++R.GAS;
return $ret35053506;
};
var $Hanf_arg24333510 = function(anf_arg15223509,anf_arg14913225,anf_array_val14953251,anf_fun14923239,input_DASH_ids5103037,j_DASH_app9467,j_DASH_block8570,j_DASH_fun8180) {
var $z35133514 = D;
var $f35193520 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg15223509):R.ffi.throwNonFunApp(L[516],j_DASH_block8570,[anf_arg15223509]);
};
try {
if(--R.GAS > 0) {
$z35133514 = $f35193520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35193520,
"from":L[516]});
}
} catch($e35113512) {
if(R.isCont($e35113512)) {
var $ss35153516 = {"from":L[516],
"go":function(anf_arg15233521) {
return $Hanf_arg24323522(anf_arg15233521,anf_arg14913225,anf_array_val14953251,anf_fun14923239,input_DASH_ids5103037,j_DASH_app9467,j_DASH_fun8180);
}};
$e35113512.stack[R.EXN_STACKHEIGHT++] = $ss35153516;
}
if(R.isPyretException($e35113512)) {
$e35113512.pyretStack.push(L[516]);
}
throw $e35113512;
}
var $ret35173518 = $Hanf_arg24323522($z35133514,anf_arg14913225,anf_array_val14953251,anf_fun14923239,input_DASH_ids5103037,j_DASH_app9467,j_DASH_fun8180);
++R.GAS;
return $ret35173518;
};
var $Hanf_arg24323522 = function(anf_arg15233521,anf_arg14913225,anf_array_val14953251,anf_fun14923239,input_DASH_ids5103037,j_DASH_app9467,j_DASH_fun8180) {
var $z35253526 = D;
var $f35313532 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(input_DASH_ids5103037,anf_arg15233521):R.ffi.throwNonFunApp(L[517],j_DASH_fun8180,[input_DASH_ids5103037,anf_arg15233521]);
};
try {
if(--R.GAS > 0) {
$z35253526 = $f35313532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35313532,
"from":L[517]});
}
} catch($e35233524) {
if(R.isCont($e35233524)) {
var $ss35273528 = {"from":L[517],
"go":function(anf_array_val15243533) {
return $Hanf_array_val24313534(anf_array_val15243533,anf_arg14913225,anf_array_val14953251,anf_fun14923239,j_DASH_app9467);
}};
$e35233524.stack[R.EXN_STACKHEIGHT++] = $ss35273528;
}
if(R.isPyretException($e35233524)) {
$e35233524.pyretStack.push(L[517]);
}
throw $e35233524;
}
var $ret35293530 = $Hanf_array_val24313534($z35253526,anf_arg14913225,anf_array_val14953251,anf_fun14923239,j_DASH_app9467);
++R.GAS;
return $ret35293530;
};
var $Hanf_array_val24313534 = function(anf_array_val15243533,anf_arg14913225,anf_array_val14953251,anf_fun14923239,j_DASH_app9467) {
var $z35373538 = D;
var $f35433544 = function(_) {
return R.isFunction(anf_fun14923239)?anf_fun14923239.app([anf_array_val14953251,anf_array_val15243533]):R.ffi.throwNonFunApp(L[496],anf_fun14923239,[[anf_array_val14953251,anf_array_val15243533]]);
};
try {
if(--R.GAS > 0) {
$z35373538 = $f35433544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35433544,
"from":L[496]});
}
} catch($e35353536) {
if(R.isCont($e35353536)) {
var $ss35393540 = {"from":L[496],
"go":function(anf_arg15253545) {
return $Hanf_arg24303546(anf_arg15253545,anf_arg14913225,j_DASH_app9467);
}};
$e35353536.stack[R.EXN_STACKHEIGHT++] = $ss35393540;
}
if(R.isPyretException($e35353536)) {
$e35353536.pyretStack.push(L[496]);
}
throw $e35353536;
}
var $ret35413542 = $Hanf_arg24303546($z35373538,anf_arg14913225,j_DASH_app9467);
++R.GAS;
return $ret35413542;
};
var $Hanf_arg24303546 = function(anf_arg15253545,anf_arg14913225,j_DASH_app9467) {
var $z35493550 = D;
var $f35553556 = function(_) {
return R.isFunction(j_DASH_app9467)?j_DASH_app9467.app(anf_arg14913225,anf_arg15253545):R.ffi.throwNonFunApp(L[76],j_DASH_app9467,[anf_arg14913225,anf_arg15253545]);
};
try {
if(--R.GAS > 0) {
$z35493550 = $f35553556();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35553556,
"from":L[76]});
}
} catch($e35473548) {
if(R.isCont($e35473548)) {
var $ss35513552 = {"from":L[76],
"go":function(ann_DASH_check_DASH_temp13153557) {
return $Hann_DASH_check_DASH_temp24293558(ann_DASH_check_DASH_temp13153557);
}};
$e35473548.stack[R.EXN_STACKHEIGHT++] = $ss35513552;
}
if(R.isPyretException($e35473548)) {
$e35473548.pyretStack.push(L[76]);
}
throw $e35473548;
}
var $ret35533554 = $Hann_DASH_check_DASH_temp24293558($z35493550);
++R.GAS;
return $ret35533554;
};
var $Hann_DASH_check_DASH_temp24293558 = function(ann_DASH_check_DASH_temp13153557) {
return ann_DASH_check_DASH_temp13153557;
};
var $Hann_DASH_check_DASH_temp24283147 = function(ann_DASH_check_DASH_temp14823146) {
return ann_DASH_check_DASH_temp14823146;
};
var $Has_DASH_str24273162 = function(as_DASH_str5313160,concat_DASH_snoc130166,j_DASH_bracket9872,j_DASH_id8381,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,locs5283132,obj_DASH_of_DASH_loc168647,_plus5) {
var anf_fun14633569 = G(loc_DASH_cache5273161.$var,"has-key",L[519]);
var $z35613562 = D;
var $f35673568 = function(_) {
return R.isFunction(anf_fun14633569)?anf_fun14633569.app(as_DASH_str5313160):R.ffi.throwNonFunApp(L[518],anf_fun14633569,[as_DASH_str5313160]);
};
try {
if(--R.GAS > 0) {
$z35613562 = $f35673568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35673568,
"from":L[518]});
}
} catch($e35593560) {
if(R.isCont($e35593560)) {
var $ss35633564 = {"from":L[518],
"go":function(if_DASH_823570) {
return $Hif_DASH_24263571(if_DASH_823570,as_DASH_str5313160,concat_DASH_snoc130166,j_DASH_bracket9872,j_DASH_id8381,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,locs5283132,obj_DASH_of_DASH_loc168647,_plus5);
}};
$e35593560.stack[R.EXN_STACKHEIGHT++] = $ss35633564;
}
if(R.isPyretException($e35593560)) {
$e35593560.pyretStack.push(L[518]);
}
throw $e35593560;
}
var $ret35653566 = $Hif_DASH_24263571($z35613562,as_DASH_str5313160,concat_DASH_snoc130166,j_DASH_bracket9872,j_DASH_id8381,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,locs5283132,obj_DASH_of_DASH_loc168647,_plus5);
++R.GAS;
return $ret35653566;
};
var $Hif_DASH_24263571 = function(if_DASH_823570,as_DASH_str5313160,concat_DASH_snoc130166,j_DASH_bracket9872,j_DASH_id8381,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,locs5283132,obj_DASH_of_DASH_loc168647,_plus5) {
var if_helper14643584 = R.makeFunction(function(if_helper_arg14653602) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[518],1,arguments);
}
var ann_DASH_check_DASH_temp14623603 = if_helper_arg14653602;
return ann_DASH_check_DASH_temp14623603;
});
var anf_if14683601 = R.isBoolean(if_DASH_823570);
if(R.isPyretTrue(anf_if14683601)) {
if(R.isPyretTrue(if_DASH_823570)) {
var anf_fun14763582 = G(loc_DASH_cache5273161.$var,"get",L[521]);
var $z35743575 = D;
var $f35803581 = function(_) {
return R.isFunction(anf_fun14763582)?anf_fun14763582.app(as_DASH_str5313160):R.ffi.throwNonFunApp(L[520],anf_fun14763582,[as_DASH_str5313160]);
};
try {
if(--R.GAS > 0) {
$z35743575 = $f35803581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35803581,
"from":L[520]});
}
} catch($e35723573) {
if(R.isCont($e35723573)) {
var $ss35763577 = {"from":L[520],
"go":function(cont_tail_arg14773583) {
return $Hcont_tail_arg24163585(cont_tail_arg14773583,if_helper14643584);
}};
$e35723573.stack[R.EXN_STACKHEIGHT++] = $ss35763577;
}
if(R.isPyretException($e35723573)) {
$e35723573.pyretStack.push(L[520]);
}
throw $e35723573;
}
var $ret35783579 = $Hcont_tail_arg24163585($z35743575,if_helper14643584);
++R.GAS;
return $ret35783579;
} else {
var $z35883589 = D;
var $f35943595 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(locs5283132):R.ffi.throwNonFunApp(L[522],j_DASH_id8381,[locs5283132]);
};
try {
if(--R.GAS > 0) {
$z35883589 = $f35943595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35943595,
"from":L[522]});
}
} catch($e35863587) {
if(R.isCont($e35863587)) {
var $ss35903591 = {"from":L[522],
"go":function(anf_arg14693596) {
return $Hanf_arg24253597(anf_arg14693596,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,j_DASH_bracket9872,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5);
}};
$e35863587.stack[R.EXN_STACKHEIGHT++] = $ss35903591;
}
if(R.isPyretException($e35863587)) {
$e35863587.pyretStack.push(L[522]);
}
throw $e35863587;
}
var $ret35923593 = $Hanf_arg24253597($z35883589,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,j_DASH_bracket9872,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5);
++R.GAS;
return $ret35923593;
}
} else {
var cont_tail_arg14663600 = R.throwNonBooleanCondition(L[518],("if"),if_DASH_823570);
if(--R.GAS > 0) {
$z35983599 = R.isFunction(if_helper14643584)?if_helper14643584.app(cont_tail_arg14663600):R.ffi.throwNonFunApp(L[518],if_helper14643584,[cont_tail_arg14663600]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper14643584)?if_helper14643584.app(cont_tail_arg14663600):R.ffi.throwNonFunApp(L[518],if_helper14643584,[cont_tail_arg14663600]);
},
"from":L[518]});
}
++R.GAS;
return $z35983599;
}
};
var $Hcont_tail_arg24163585 = function(cont_tail_arg14773583,if_helper14643584) {
if(--R.GAS > 0) {
$z36043605 = R.isFunction(if_helper14643584)?if_helper14643584.app(cont_tail_arg14773583):R.ffi.throwNonFunApp(L[520],if_helper14643584,[cont_tail_arg14773583]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper14643584)?if_helper14643584.app(cont_tail_arg14773583):R.ffi.throwNonFunApp(L[520],if_helper14643584,[cont_tail_arg14773583]);
},
"from":L[520]});
}
++R.GAS;
return $z36043605;
};
var $Hanf_arg24253597 = function(anf_arg14693596,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,j_DASH_bracket9872,j_DASH_num8889,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5) {
var $z36083609 = D;
var $f36143615 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(loc_DASH_count5263114.$var):R.ffi.throwNonFunApp(L[523],j_DASH_num8889,[loc_DASH_count5263114.$var]);
};
try {
if(--R.GAS > 0) {
$z36083609 = $f36143615();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36143615,
"from":L[523]});
}
} catch($e36063607) {
if(R.isCont($e36063607)) {
var $ss36103611 = {"from":L[523],
"go":function(anf_arg14703616) {
return $Hanf_arg24243617(anf_arg14703616,anf_arg14693596,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,j_DASH_bracket9872,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5);
}};
$e36063607.stack[R.EXN_STACKHEIGHT++] = $ss36103611;
}
if(R.isPyretException($e36063607)) {
$e36063607.pyretStack.push(L[523]);
}
throw $e36063607;
}
var $ret36123613 = $Hanf_arg24243617($z36083609,anf_arg14693596,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,j_DASH_bracket9872,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5);
++R.GAS;
return $ret36123613;
};
var $Hanf_arg24243617 = function(anf_arg14703616,anf_arg14693596,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,j_DASH_bracket9872,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5) {
var $z36203621 = D;
var $f36263627 = function(_) {
return R.isFunction(j_DASH_bracket9872)?j_DASH_bracket9872.app(anf_arg14693596,anf_arg14703616):R.ffi.throwNonFunApp(L[524],j_DASH_bracket9872,[anf_arg14693596,anf_arg14703616]);
};
try {
if(--R.GAS > 0) {
$z36203621 = $f36263627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36263627,
"from":L[524]});
}
} catch($e36183619) {
if(R.isCont($e36183619)) {
var $ss36223623 = {"from":L[524],
"go":function(ans5323628) {
return $Hans24233629(ans5323628,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5);
}};
$e36183619.stack[R.EXN_STACKHEIGHT++] = $ss36223623;
}
if(R.isPyretException($e36183619)) {
$e36183619.pyretStack.push(L[524]);
}
throw $e36183619;
}
var $ret36243625 = $Hans24233629($z36203621,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5);
++R.GAS;
return $ret36243625;
};
var $Hans24233629 = function(ans5323628,as_DASH_str5313160,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_cache5273161,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5) {
var anf_fun14713640 = G(loc_DASH_cache5273161.$var,"set",L[526]);
var $z36323633 = D;
var $f36383639 = function(_) {
return R.isFunction(anf_fun14713640)?anf_fun14713640.app(as_DASH_str5313160,ans5323628):R.ffi.throwNonFunApp(L[525],anf_fun14713640,[as_DASH_str5313160,ans5323628]);
};
try {
if(--R.GAS > 0) {
$z36323633 = $f36383639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36383639,
"from":L[525]});
}
} catch($e36303631) {
if(R.isCont($e36303631)) {
var $ss36343635 = {"from":L[525],
"go":function(anf_begin_app_dropped24173641) {
return $Hanf_begin_app_dropped24223642(anf_begin_app_dropped24173641,ans5323628,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5);
}};
$e36303631.stack[R.EXN_STACKHEIGHT++] = $ss36343635;
}
if(R.isPyretException($e36303631)) {
$e36303631.pyretStack.push(L[525]);
}
throw $e36303631;
}
var $ret36363637 = $Hanf_begin_app_dropped24223642($z36323633,ans5323628,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5);
++R.GAS;
return $ret36363637;
};
var $Hanf_begin_app_dropped24223642 = function(anf_begin_app_dropped24173641,ans5323628,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647,_plus5) {
var $z36453646 = D;
var $f36513652 = function(_) {
return R.isFunction(_plus5)?_plus5.app(loc_DASH_count5263114.$var,(1)):R.ffi.throwNonFunApp(L[527],_plus5,[loc_DASH_count5263114.$var,(1)]);
};
try {
if(--R.GAS > 0) {
$z36453646 = $f36513652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36513652,
"from":L[527]});
}
} catch($e36433644) {
if(R.isCont($e36433644)) {
var $ss36473648 = {"from":L[527],
"go":function(anf_assign14723653) {
return $Hanf_assign24213654(anf_assign14723653,ans5323628,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647);
}};
$e36433644.stack[R.EXN_STACKHEIGHT++] = $ss36473648;
}
if(R.isPyretException($e36433644)) {
$e36433644.pyretStack.push(L[527]);
}
throw $e36433644;
}
var $ret36493650 = $Hanf_assign24213654($z36453646,ans5323628,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647);
++R.GAS;
return $ret36493650;
};
var $Hanf_assign24213654 = function(anf_assign14723653,ans5323628,concat_DASH_snoc130166,if_helper14643584,l5303149,loc_DASH_count5263114,locations5253115,obj_DASH_of_DASH_loc168647) {
loc_DASH_count5263114.$var = anf_assign14723653;
var $z36573658 = D;
var $f36633664 = function(_) {
return R.isFunction(obj_DASH_of_DASH_loc168647.$var)?obj_DASH_of_DASH_loc168647.$var.app(l5303149):R.ffi.throwNonFunApp(L[528],obj_DASH_of_DASH_loc168647.$var,[l5303149]);
};
try {
if(--R.GAS > 0) {
$z36573658 = $f36633664();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36633664,
"from":L[528]});
}
} catch($e36553656) {
if(R.isCont($e36553656)) {
var $ss36593660 = {"from":L[528],
"go":function(anf_arg14733665) {
return $Hanf_arg24203666(anf_arg14733665,ans5323628,concat_DASH_snoc130166,if_helper14643584,locations5253115);
}};
$e36553656.stack[R.EXN_STACKHEIGHT++] = $ss36593660;
}
if(R.isPyretException($e36553656)) {
$e36553656.pyretStack.push(L[528]);
}
throw $e36553656;
}
var $ret36613662 = $Hanf_arg24203666($z36573658,ans5323628,concat_DASH_snoc130166,if_helper14643584,locations5253115);
++R.GAS;
return $ret36613662;
};
var $Hanf_arg24203666 = function(anf_arg14733665,ans5323628,concat_DASH_snoc130166,if_helper14643584,locations5253115) {
var $z36693670 = D;
var $f36753676 = function(_) {
return R.isFunction(concat_DASH_snoc130166.$var)?concat_DASH_snoc130166.$var.app(locations5253115.$var,anf_arg14733665):R.ffi.throwNonFunApp(L[529],concat_DASH_snoc130166.$var,[locations5253115.$var,anf_arg14733665]);
};
try {
if(--R.GAS > 0) {
$z36693670 = $f36753676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36753676,
"from":L[529]});
}
} catch($e36673668) {
if(R.isCont($e36673668)) {
var $ss36713672 = {"from":L[529],
"go":function(anf_assign14743677) {
return $Hanf_assign24193678(anf_assign14743677,ans5323628,if_helper14643584,locations5253115);
}};
$e36673668.stack[R.EXN_STACKHEIGHT++] = $ss36713672;
}
if(R.isPyretException($e36673668)) {
$e36673668.pyretStack.push(L[529]);
}
throw $e36673668;
}
var $ret36733674 = $Hanf_assign24193678($z36693670,ans5323628,if_helper14643584,locations5253115);
++R.GAS;
return $ret36733674;
};
var $Hanf_assign24193678 = function(anf_assign14743677,ans5323628,if_helper14643584,locations5253115) {
locations5253115.$var = anf_assign14743677;
var $z36813682 = D;
var $f36873688 = function(_) {
return R.isFunction(if_helper14643584)?if_helper14643584.app(ans5323628):R.ffi.throwNonFunApp(L[530],if_helper14643584,[ans5323628]);
};
try {
if(--R.GAS > 0) {
$z36813682 = $f36873688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36873688,
"from":L[530]});
}
} catch($e36793680) {
if(R.isCont($e36793680)) {
var $ss36833684 = {"from":L[530],
"go":function(cont_tail_app14753689) {
return $Hcont_tail_app24183690(cont_tail_app14753689);
}};
$e36793680.stack[R.EXN_STACKHEIGHT++] = $ss36833684;
}
if(R.isPyretException($e36793680)) {
$e36793680.pyretStack.push(L[530]);
}
throw $e36793680;
}
var $ret36853686 = $Hcont_tail_app24183690($z36813682);
++R.GAS;
return $ret36853686;
};
var $Hcont_tail_app24183690 = function(cont_tail_app14753689) {
return cont_tail_app14753689;
};
var $Hmod_DASH_input_DASH_names24143099 = function(mod_DASH_input_DASH_names5153098,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,module_DASH_id5073023,modules5133084,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5) {
var anf_fun14073701 = G(mod_DASH_input_DASH_names5153098,"map",L[532]);
var $z36933694 = D;
var $f36993700 = function(_) {
return R.isFunction(anf_fun14073701)?anf_fun14073701.app(j_DASH_id8381):R.ffi.throwNonFunApp(L[531],anf_fun14073701,[j_DASH_id8381]);
};
try {
if(--R.GAS > 0) {
$z36933694 = $f36993700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36993700,
"from":L[531]});
}
} catch($e36913692) {
if(R.isCont($e36913692)) {
var $ss36953696 = {"from":L[531],
"go":function(mod_DASH_input_DASH_ids5163702) {
return $Hmod_DASH_input_DASH_ids24133703(mod_DASH_input_DASH_ids5163702,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,modules5133084,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
}};
$e36913692.stack[R.EXN_STACKHEIGHT++] = $ss36953696;
}
if(R.isPyretException($e36913692)) {
$e36913692.pyretStack.push(L[531]);
}
throw $e36913692;
}
var $ret36973698 = $Hmod_DASH_input_DASH_ids24133703($z36933694,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,modules5133084,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
++R.GAS;
return $ret36973698;
};
var $Hmod_DASH_input_DASH_ids24133703 = function(mod_DASH_input_DASH_ids5163702,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,modules5133084,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5) {
var anf_fun14083714 = G(modules5133084,"map",L[535]);
var anf_arg14103715 = R.makeFunction(function(recv_DASH_813718) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[534],1,arguments);
}
var ann_DASH_check_DASH_temp14093719 = G(recv_DASH_813718,"id",L[534]);
return ann_DASH_check_DASH_temp14093719;
});
var $z37063707 = D;
var $f37123713 = function(_) {
return R.isFunction(anf_fun14083714)?anf_fun14083714.app(anf_arg14103715):R.ffi.throwNonFunApp(L[533],anf_fun14083714,[anf_arg14103715]);
};
try {
if(--R.GAS > 0) {
$z37063707 = $f37123713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37123713,
"from":L[533]});
}
} catch($e37043705) {
if(R.isCont($e37043705)) {
var $ss37083709 = {"from":L[533],
"go":function(mod_DASH_val_DASH_ids5173716) {
return $Hmod_DASH_val_DASH_ids24123717(mod_DASH_val_DASH_ids5173716,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
}};
$e37043705.stack[R.EXN_STACKHEIGHT++] = $ss37083709;
}
if(R.isPyretException($e37043705)) {
$e37043705.pyretStack.push(L[533]);
}
throw $e37043705;
}
var $ret37103711 = $Hmod_DASH_val_DASH_ids24123717($z37063707,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
++R.GAS;
return $ret37103711;
};
var $Hmod_DASH_val_DASH_ids24123717 = function(mod_DASH_val_DASH_ids5173716,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5) {
var anf_fun14113731 = G(list35101,"make",L[537]);
var $z37223723 = D;
var $f37283729 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("NAMESPACE")):R.ffi.throwNonFunApp(L[536],j_DASH_id8381,[("NAMESPACE")]);
};
try {
if(--R.GAS > 0) {
$z37223723 = $f37283729();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37283729,
"from":L[536]});
}
} catch($e37203721) {
if(R.isCont($e37203721)) {
var $ss37243725 = {"from":L[536],
"go":function(anf_array_val14123730) {
return $Hanf_array_val24113732(anf_array_val14123730,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,mod_DASH_val_DASH_ids5173716,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
}};
$e37203721.stack[R.EXN_STACKHEIGHT++] = $ss37243725;
}
if(R.isPyretException($e37203721)) {
$e37203721.pyretStack.push(L[536]);
}
throw $e37203721;
}
var $ret37263727 = $Hanf_array_val24113732($z37223723,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,mod_DASH_val_DASH_ids5173716,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
++R.GAS;
return $ret37263727;
};
var $Hanf_array_val24113732 = function(anf_array_val14123730,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,mod_DASH_val_DASH_ids5173716,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5) {
var $z37353736 = D;
var $f37413742 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),mod_DASH_input_DASH_ids5163702):R.ffi.throwNonFunApp(L[538],j_DASH_list9585,[(false),mod_DASH_input_DASH_ids5163702]);
};
try {
if(--R.GAS > 0) {
$z37353736 = $f37413742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37413742,
"from":L[538]});
}
} catch($e37333734) {
if(R.isCont($e37333734)) {
var $ss37373738 = {"from":L[538],
"go":function(anf_array_val14133743) {
return $Hanf_array_val24103744(anf_array_val14133743,anf_array_val14123730,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,mod_DASH_val_DASH_ids5173716,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
}};
$e37333734.stack[R.EXN_STACKHEIGHT++] = $ss37373738;
}
if(R.isPyretException($e37333734)) {
$e37333734.pyretStack.push(L[538]);
}
throw $e37333734;
}
var $ret37393740 = $Hanf_array_val24103744($z37353736,anf_array_val14123730,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,mod_DASH_val_DASH_ids5173716,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
++R.GAS;
return $ret37393740;
};
var $Hanf_array_val24103744 = function(anf_array_val14133743,anf_array_val14123730,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,mod_DASH_val_DASH_ids5173716,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5) {
var anf_arg14193755 = R.makeFunction(function(m5183758,in5193759) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[539],2,arguments);
}
var anf_fun14153771 = G(list35101,"make",L[541]);
var $z37623763 = D;
var $f37683769 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(("values")):R.ffi.throwNonFunApp(L[540],j_DASH_str8993,[("values")]);
};
try {
if(--R.GAS > 0) {
$z37623763 = $f37683769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37683769,
"from":L[540]});
}
} catch($e37603761) {
if(R.isCont($e37603761)) {
var $ss37643765 = {"from":L[540],
"go":function(anf_array_val14163770) {
return $Hanf_array_val23783772(anf_array_val14163770,anf_fun14153771,in5193759,j_DASH_var8299,m5183758,rt_DASH_method173657);
}};
$e37603761.stack[R.EXN_STACKHEIGHT++] = $ss37643765;
}
if(R.isPyretException($e37603761)) {
$e37603761.pyretStack.push(L[540]);
}
throw $e37603761;
}
var $ret37663767 = $Hanf_array_val23783772($z37623763,anf_fun14153771,in5193759,j_DASH_var8299,m5183758,rt_DASH_method173657);
++R.GAS;
return $ret37663767;
});
var $z37473748 = D;
var $f37533754 = function(_) {
return R.isFunction(map248102)?map248102.app(anf_arg14193755,mod_DASH_val_DASH_ids5173716,mod_DASH_input_DASH_ids5163702):R.ffi.throwNonFunApp(L[539],map248102,[anf_arg14193755,mod_DASH_val_DASH_ids5173716,mod_DASH_input_DASH_ids5163702]);
};
try {
if(--R.GAS > 0) {
$z37473748 = $f37533754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37533754,
"from":L[539]});
}
} catch($e37453746) {
if(R.isCont($e37453746)) {
var $ss37493750 = {"from":L[539],
"go":function(anf_arg14203756) {
return $Hanf_arg24093757(anf_arg14203756,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
}};
$e37453746.stack[R.EXN_STACKHEIGHT++] = $ss37493750;
}
if(R.isPyretException($e37453746)) {
$e37453746.pyretStack.push(L[539]);
}
throw $e37453746;
}
var $ret37513752 = $Hanf_arg24093757($z37473748,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5);
++R.GAS;
return $ret37513752;
};
var $Hanf_arg24093757 = function(anf_arg14203756,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,list35101,map248102,mod_DASH_input_DASH_ids5163702,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,type_DASH_ids5002959,_plus5) {
var anf_arg14263783 = R.makeFunction(function(mt5203786,in5213787) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[542],2,arguments);
}
var anf_fun14223799 = G(list35101,"make",L[544]);
var $z37903791 = D;
var $f37963797 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(("types")):R.ffi.throwNonFunApp(L[543],j_DASH_str8993,[("types")]);
};
try {
if(--R.GAS > 0) {
$z37903791 = $f37963797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37963797,
"from":L[543]});
}
} catch($e37883789) {
if(R.isCont($e37883789)) {
var $ss37923793 = {"from":L[543],
"go":function(anf_array_val14233798) {
return $Hanf_array_val23823800(anf_array_val14233798,anf_fun14223799,in5213787,j_DASH_var8299,mt5203786,rt_DASH_method173657);
}};
$e37883789.stack[R.EXN_STACKHEIGHT++] = $ss37923793;
}
if(R.isPyretException($e37883789)) {
$e37883789.pyretStack.push(L[543]);
}
throw $e37883789;
}
var $ret37943795 = $Hanf_array_val23823800($z37903791,anf_fun14223799,in5213787,j_DASH_var8299,mt5203786,rt_DASH_method173657);
++R.GAS;
return $ret37943795;
});
var $z37753776 = D;
var $f37813782 = function(_) {
return R.isFunction(map248102)?map248102.app(anf_arg14263783,type_DASH_ids5002959,mod_DASH_input_DASH_ids5163702):R.ffi.throwNonFunApp(L[542],map248102,[anf_arg14263783,type_DASH_ids5002959,mod_DASH_input_DASH_ids5163702]);
};
try {
if(--R.GAS > 0) {
$z37753776 = $f37813782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37813782,
"from":L[542]});
}
} catch($e37733774) {
if(R.isCont($e37733774)) {
var $ss37773778 = {"from":L[542],
"go":function(anf_arg14273784) {
return $Hanf_arg24083785(anf_arg14273784,anf_arg14203756,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
}};
$e37733774.stack[R.EXN_STACKHEIGHT++] = $ss37773778;
}
if(R.isPyretException($e37733774)) {
$e37733774.pyretStack.push(L[542]);
}
throw $e37733774;
}
var $ret37793780 = $Hanf_arg24083785($z37753776,anf_arg14203756,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret37793780;
};
var $Hanf_arg24083785 = function(anf_arg14273784,anf_arg14203756,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5) {
var $z38033804 = D;
var $f38093810 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg14203756,anf_arg14273784):R.ffi.throwNonFunApp(L[545],_plus5,[anf_arg14203756,anf_arg14273784]);
};
try {
if(--R.GAS > 0) {
$z38033804 = $f38093810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38093810,
"from":L[545]});
}
} catch($e38013802) {
if(R.isCont($e38013802)) {
var $ss38053806 = {"from":L[545],
"go":function(anf_arg14283811) {
return $Hanf_arg24073812(anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
}};
$e38013802.stack[R.EXN_STACKHEIGHT++] = $ss38053806;
}
if(R.isPyretException($e38013802)) {
$e38013802.pyretStack.push(L[545]);
}
throw $e38013802;
}
var $ret38073808 = $Hanf_arg24073812($z38033804,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret38073808;
};
var $Hanf_arg24073812 = function(anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5) {
var anf_fun14293825 = G(list35101,"make",L[548]);
var anf_fun14303826 = G(list35101,"make",L[547]);
var anf_fun14313823 = G(list35101,"make",L[546]);
var $z38153816 = D;
var $f38213822 = function(_) {
return R.isFunction(anf_fun14313823)?anf_fun14313823.app([]):R.ffi.throwNonFunApp(L[546],anf_fun14313823,[[]]);
};
try {
if(--R.GAS > 0) {
$z38153816 = $f38213822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38213822,
"from":L[546]});
}
} catch($e38133814) {
if(R.isCont($e38133814)) {
var $ss38173818 = {"from":L[546],
"go":function(anf_arg14323824) {
return $Hanf_arg24063827(anf_arg14323824,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
}};
$e38133814.stack[R.EXN_STACKHEIGHT++] = $ss38173818;
}
if(R.isPyretException($e38133814)) {
$e38133814.pyretStack.push(L[546]);
}
throw $e38133814;
}
var $ret38193820 = $Hanf_arg24063827($z38153816,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret38193820;
};
var $Hanf_arg24063827 = function(anf_arg14323824,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,body5143085,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5) {
var anf_fun14333838 = G(list35101,"make",L[549]);
var $z38303831 = D;
var $f38363837 = function(_) {
return R.isFunction(anf_fun14333838)?anf_fun14333838.app([body5143085]):R.ffi.throwNonFunApp(L[549],anf_fun14333838,[[body5143085]]);
};
try {
if(--R.GAS > 0) {
$z38303831 = $f38363837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38363837,
"from":L[549]});
}
} catch($e38283829) {
if(R.isCont($e38283829)) {
var $ss38323833 = {"from":L[549],
"go":function(anf_arg14343839) {
return $Hanf_arg24053840(anf_arg14343839,anf_arg14283811,anf_arg14323824,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
}};
$e38283829.stack[R.EXN_STACKHEIGHT++] = $ss38323833;
}
if(R.isPyretException($e38283829)) {
$e38283829.pyretStack.push(L[549]);
}
throw $e38283829;
}
var $ret38343835 = $Hanf_arg24053840($z38303831,anf_arg14283811,anf_arg14323824,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret38343835;
};
var $Hanf_arg24053840 = function(anf_arg14343839,anf_arg14283811,anf_arg14323824,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5) {
var $z38433844 = D;
var $f38493850 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg14343839):R.ffi.throwNonFunApp(L[550],j_DASH_block8570,[anf_arg14343839]);
};
try {
if(--R.GAS > 0) {
$z38433844 = $f38493850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38493850,
"from":L[550]});
}
} catch($e38413842) {
if(R.isCont($e38413842)) {
var $ss38453846 = {"from":L[550],
"go":function(anf_arg14353851) {
return $Hanf_arg24043852(anf_arg14353851,anf_arg14283811,anf_arg14323824,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
}};
$e38413842.stack[R.EXN_STACKHEIGHT++] = $ss38453846;
}
if(R.isPyretException($e38413842)) {
$e38413842.pyretStack.push(L[550]);
}
throw $e38413842;
}
var $ret38473848 = $Hanf_arg24043852($z38433844,anf_arg14283811,anf_arg14323824,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret38473848;
};
var $Hanf_arg24043852 = function(anf_arg14353851,anf_arg14283811,anf_arg14323824,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5) {
var $z38553856 = D;
var $f38613862 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg14323824,anf_arg14353851):R.ffi.throwNonFunApp(L[551],j_DASH_fun8180,[anf_arg14323824,anf_arg14353851]);
};
try {
if(--R.GAS > 0) {
$z38553856 = $f38613862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38613862,
"from":L[551]});
}
} catch($e38533854) {
if(R.isCont($e38533854)) {
var $ss38573858 = {"from":L[551],
"go":function(anf_array_val14363863) {
return $Hanf_array_val24033864(anf_array_val14363863,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
}};
$e38533854.stack[R.EXN_STACKHEIGHT++] = $ss38573858;
}
if(R.isPyretException($e38533854)) {
$e38533854.pyretStack.push(L[551]);
}
throw $e38533854;
}
var $ret38593860 = $Hanf_array_val24033864($z38553856,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret38593860;
};
var $Hanf_array_val24033864 = function(anf_array_val14363863,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5) {
var anf_fun14373875 = G(list35101,"make",L[552]);
var $z38673868 = D;
var $f38733874 = function(_) {
return R.isFunction(anf_fun14373875)?anf_fun14373875.app([("moduleVal")]):R.ffi.throwNonFunApp(L[552],anf_fun14373875,[[("moduleVal")]]);
};
try {
if(--R.GAS > 0) {
$z38673868 = $f38733874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38733874,
"from":L[552]});
}
} catch($e38653866) {
if(R.isCont($e38653866)) {
var $ss38693870 = {"from":L[552],
"go":function(anf_arg14383876) {
return $Hanf_arg24023877(anf_arg14383876,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
}};
$e38653866.stack[R.EXN_STACKHEIGHT++] = $ss38693870;
}
if(R.isPyretException($e38653866)) {
$e38653866.pyretStack.push(L[552]);
}
throw $e38653866;
}
var $ret38713872 = $Hanf_arg24023877($z38673868,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret38713872;
};
var $Hanf_arg24023877 = function(anf_arg14383876,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,list35101,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_field172655,rt_DASH_method173657,_plus5) {
var anf_fun14393889 = G(list35101,"make",L[554]);
var $z38803881 = D;
var $f38863887 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("modules")):R.ffi.throwNonFunApp(L[553],rt_DASH_field172655.$var,[("modules")]);
};
try {
if(--R.GAS > 0) {
$z38803881 = $f38863887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38863887,
"from":L[553]});
}
} catch($e38783879) {
if(R.isCont($e38783879)) {
var $ss38823883 = {"from":L[553],
"go":function(anf_arg14403888) {
return $Hanf_arg24013890(anf_arg14403888,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_method173657,_plus5);
}};
$e38783879.stack[R.EXN_STACKHEIGHT++] = $ss38823883;
}
if(R.isPyretException($e38783879)) {
$e38783879.pyretStack.push(L[553]);
}
throw $e38783879;
}
var $ret38843885 = $Hanf_arg24013890($z38803881,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret38843885;
};
var $Hanf_arg24013890 = function(anf_arg14403888,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,mod_DASH_input_DASH_names5153098,module_DASH_id5073023,rt_DASH_method173657,_plus5) {
var $z38933894 = D;
var $f38993900 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(module_DASH_id5073023):R.ffi.throwNonFunApp(L[555],j_DASH_str8993,[module_DASH_id5073023]);
};
try {
if(--R.GAS > 0) {
$z38933894 = $f38993900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38993900,
"from":L[555]});
}
} catch($e38913892) {
if(R.isCont($e38913892)) {
var $ss38953896 = {"from":L[555],
"go":function(anf_arg14413901) {
return $Hanf_arg24003902(anf_arg14413901,anf_arg14283811,anf_arg14383876,anf_arg14403888,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e38913892.stack[R.EXN_STACKHEIGHT++] = $ss38953896;
}
if(R.isPyretException($e38913892)) {
$e38913892.pyretStack.push(L[555]);
}
throw $e38913892;
}
var $ret38973898 = $Hanf_arg24003902($z38933894,anf_arg14283811,anf_arg14383876,anf_arg14403888,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret38973898;
};
var $Hanf_arg24003902 = function(anf_arg14413901,anf_arg14283811,anf_arg14383876,anf_arg14403888,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z39053906 = D;
var $f39113912 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("moduleVal")):R.ffi.throwNonFunApp(L[556],j_DASH_id8381,[("moduleVal")]);
};
try {
if(--R.GAS > 0) {
$z39053906 = $f39113912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39113912,
"from":L[556]});
}
} catch($e39033904) {
if(R.isCont($e39033904)) {
var $ss39073908 = {"from":L[556],
"go":function(anf_arg14423913) {
return $Hanf_arg23993914(anf_arg14423913,anf_arg14283811,anf_arg14383876,anf_arg14403888,anf_arg14413901,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39033904.stack[R.EXN_STACKHEIGHT++] = $ss39073908;
}
if(R.isPyretException($e39033904)) {
$e39033904.pyretStack.push(L[556]);
}
throw $e39033904;
}
var $ret39093910 = $Hanf_arg23993914($z39053906,anf_arg14283811,anf_arg14383876,anf_arg14403888,anf_arg14413901,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret39093910;
};
var $Hanf_arg23993914 = function(anf_arg14423913,anf_arg14283811,anf_arg14383876,anf_arg14403888,anf_arg14413901,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z39173918 = D;
var $f39233924 = function(_) {
return R.isFunction(j_DASH_bracket_DASH_assign10171)?j_DASH_bracket_DASH_assign10171.app(anf_arg14403888,anf_arg14413901,anf_arg14423913):R.ffi.throwNonFunApp(L[557],j_DASH_bracket_DASH_assign10171,[anf_arg14403888,anf_arg14413901,anf_arg14423913]);
};
try {
if(--R.GAS > 0) {
$z39173918 = $f39233924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39233924,
"from":L[557]});
}
} catch($e39153916) {
if(R.isCont($e39153916)) {
var $ss39193920 = {"from":L[557],
"go":function(anf_array_val14433925) {
return $Hanf_array_val23983926(anf_array_val14433925,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39153916.stack[R.EXN_STACKHEIGHT++] = $ss39193920;
}
if(R.isPyretException($e39153916)) {
$e39153916.pyretStack.push(L[557]);
}
throw $e39153916;
}
var $ret39213922 = $Hanf_array_val23983926($z39173918,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret39213922;
};
var $Hanf_array_val23983926 = function(anf_array_val14433925,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z39293930 = D;
var $f39353936 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("moduleVal")):R.ffi.throwNonFunApp(L[558],j_DASH_id8381,[("moduleVal")]);
};
try {
if(--R.GAS > 0) {
$z39293930 = $f39353936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39353936,
"from":L[558]});
}
} catch($e39273928) {
if(R.isCont($e39273928)) {
var $ss39313932 = {"from":L[558],
"go":function(anf_arg14443937) {
return $Hanf_arg23973938(anf_arg14443937,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_array_val14433925,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39273928.stack[R.EXN_STACKHEIGHT++] = $ss39313932;
}
if(R.isPyretException($e39273928)) {
$e39273928.pyretStack.push(L[558]);
}
throw $e39273928;
}
var $ret39333934 = $Hanf_arg23973938($z39293930,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_array_val14433925,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret39333934;
};
var $Hanf_arg23973938 = function(anf_arg14443937,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_array_val14433925,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z39413942 = D;
var $f39473948 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg14443937):R.ffi.throwNonFunApp(L[559],j_DASH_return9092,[anf_arg14443937]);
};
try {
if(--R.GAS > 0) {
$z39413942 = $f39473948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39473948,
"from":L[559]});
}
} catch($e39393940) {
if(R.isCont($e39393940)) {
var $ss39433944 = {"from":L[559],
"go":function(anf_array_val14453949) {
return $Hanf_array_val23963950(anf_array_val14453949,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_array_val14433925,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39393940.stack[R.EXN_STACKHEIGHT++] = $ss39433944;
}
if(R.isPyretException($e39393940)) {
$e39393940.pyretStack.push(L[559]);
}
throw $e39393940;
}
var $ret39453946 = $Hanf_array_val23963950($z39413942,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_array_val14433925,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret39453946;
};
var $Hanf_array_val23963950 = function(anf_array_val14453949,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_array_val14433925,anf_fun14113731,anf_fun14293825,anf_fun14303826,anf_fun14393889,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z39533954 = D;
var $f39593960 = function(_) {
return R.isFunction(anf_fun14393889)?anf_fun14393889.app([anf_array_val14433925,anf_array_val14453949]):R.ffi.throwNonFunApp(L[554],anf_fun14393889,[[anf_array_val14433925,anf_array_val14453949]]);
};
try {
if(--R.GAS > 0) {
$z39533954 = $f39593960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39593960,
"from":L[554]});
}
} catch($e39513952) {
if(R.isCont($e39513952)) {
var $ss39553956 = {"from":L[554],
"go":function(anf_arg14463961) {
return $Hanf_arg23953962(anf_arg14463961,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39513952.stack[R.EXN_STACKHEIGHT++] = $ss39553956;
}
if(R.isPyretException($e39513952)) {
$e39513952.pyretStack.push(L[554]);
}
throw $e39513952;
}
var $ret39573958 = $Hanf_arg23953962($z39533954,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret39573958;
};
var $Hanf_arg23953962 = function(anf_arg14463961,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z39653966 = D;
var $f39713972 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg14463961):R.ffi.throwNonFunApp(L[560],j_DASH_block8570,[anf_arg14463961]);
};
try {
if(--R.GAS > 0) {
$z39653966 = $f39713972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39713972,
"from":L[560]});
}
} catch($e39633964) {
if(R.isCont($e39633964)) {
var $ss39673968 = {"from":L[560],
"go":function(anf_arg14473973) {
return $Hanf_arg23943974(anf_arg14473973,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39633964.stack[R.EXN_STACKHEIGHT++] = $ss39673968;
}
if(R.isPyretException($e39633964)) {
$e39633964.pyretStack.push(L[560]);
}
throw $e39633964;
}
var $ret39693970 = $Hanf_arg23943974($z39653966,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret39693970;
};
var $Hanf_arg23943974 = function(anf_arg14473973,anf_arg14283811,anf_arg14383876,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z39773978 = D;
var $f39833984 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg14383876,anf_arg14473973):R.ffi.throwNonFunApp(L[561],j_DASH_fun8180,[anf_arg14383876,anf_arg14473973]);
};
try {
if(--R.GAS > 0) {
$z39773978 = $f39833984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39833984,
"from":L[561]});
}
} catch($e39753976) {
if(R.isCont($e39753976)) {
var $ss39793980 = {"from":L[561],
"go":function(anf_array_val14483985) {
return $Hanf_array_val23933986(anf_array_val14483985,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39753976.stack[R.EXN_STACKHEIGHT++] = $ss39793980;
}
if(R.isPyretException($e39753976)) {
$e39753976.pyretStack.push(L[561]);
}
throw $e39753976;
}
var $ret39813982 = $Hanf_array_val23933986($z39773978,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret39813982;
};
var $Hanf_array_val23933986 = function(anf_array_val14483985,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_array_val14363863,anf_fun14113731,anf_fun14293825,anf_fun14303826,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z39893990 = D;
var $f39953996 = function(_) {
return R.isFunction(anf_fun14303826)?anf_fun14303826.app([anf_array_val14363863,anf_array_val14483985]):R.ffi.throwNonFunApp(L[547],anf_fun14303826,[[anf_array_val14363863,anf_array_val14483985]]);
};
try {
if(--R.GAS > 0) {
$z39893990 = $f39953996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39953996,
"from":L[547]});
}
} catch($e39873988) {
if(R.isCont($e39873988)) {
var $ss39913992 = {"from":L[547],
"go":function(anf_arg14493997) {
return $Hanf_arg23923998(anf_arg14493997,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39873988.stack[R.EXN_STACKHEIGHT++] = $ss39913992;
}
if(R.isPyretException($e39873988)) {
$e39873988.pyretStack.push(L[547]);
}
throw $e39873988;
}
var $ret39933994 = $Hanf_arg23923998($z39893990,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret39933994;
};
var $Hanf_arg23923998 = function(anf_arg14493997,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z40014002 = D;
var $f40074008 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("safeCall"),anf_arg14493997):R.ffi.throwNonFunApp(L[562],rt_DASH_method173657.$var,[("safeCall"),anf_arg14493997]);
};
try {
if(--R.GAS > 0) {
$z40014002 = $f40074008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40074008,
"from":L[562]});
}
} catch($e39994000) {
if(R.isCont($e39994000)) {
var $ss40034004 = {"from":L[562],
"go":function(anf_arg14504009) {
return $Hanf_arg23914010(anf_arg14504009,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e39994000.stack[R.EXN_STACKHEIGHT++] = $ss40034004;
}
if(R.isPyretException($e39994000)) {
$e39994000.pyretStack.push(L[562]);
}
throw $e39994000;
}
var $ret40054006 = $Hanf_arg23914010($z40014002,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret40054006;
};
var $Hanf_arg23914010 = function(anf_arg14504009,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z40134014 = D;
var $f40194020 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg14504009):R.ffi.throwNonFunApp(L[563],j_DASH_return9092,[anf_arg14504009]);
};
try {
if(--R.GAS > 0) {
$z40134014 = $f40194020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40194020,
"from":L[563]});
}
} catch($e40114012) {
if(R.isCont($e40114012)) {
var $ss40154016 = {"from":L[563],
"go":function(anf_array_val14514021) {
return $Hanf_array_val23904022(anf_array_val14514021,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e40114012.stack[R.EXN_STACKHEIGHT++] = $ss40154016;
}
if(R.isPyretException($e40114012)) {
$e40114012.pyretStack.push(L[563]);
}
throw $e40114012;
}
var $ret40174018 = $Hanf_array_val23904022($z40134014,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret40174018;
};
var $Hanf_array_val23904022 = function(anf_array_val14514021,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,anf_fun14293825,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z40254026 = D;
var $f40314032 = function(_) {
return R.isFunction(anf_fun14293825)?anf_fun14293825.app([anf_array_val14514021]):R.ffi.throwNonFunApp(L[548],anf_fun14293825,[[anf_array_val14514021]]);
};
try {
if(--R.GAS > 0) {
$z40254026 = $f40314032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40314032,
"from":L[548]});
}
} catch($e40234024) {
if(R.isCont($e40234024)) {
var $ss40274028 = {"from":L[548],
"go":function(anf_arg14524033) {
return $Hanf_arg23894034(anf_arg14524033,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
}};
$e40234024.stack[R.EXN_STACKHEIGHT++] = $ss40274028;
}
if(R.isPyretException($e40234024)) {
$e40234024.pyretStack.push(L[548]);
}
throw $e40234024;
}
var $ret40294030 = $Hanf_arg23894034($z40254026,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5);
++R.GAS;
return $ret40294030;
};
var $Hanf_arg23894034 = function(anf_arg14524033,anf_arg14283811,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657,_plus5) {
var $z40374038 = D;
var $f40434044 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg14283811,anf_arg14524033):R.ffi.throwNonFunApp(L[545],_plus5,[anf_arg14283811,anf_arg14524033]);
};
try {
if(--R.GAS > 0) {
$z40374038 = $f40434044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40434044,
"from":L[545]});
}
} catch($e40354036) {
if(R.isCont($e40354036)) {
var $ss40394040 = {"from":L[545],
"go":function(anf_arg14534045) {
return $Hanf_arg23884046(anf_arg14534045,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657);
}};
$e40354036.stack[R.EXN_STACKHEIGHT++] = $ss40394040;
}
if(R.isPyretException($e40354036)) {
$e40354036.pyretStack.push(L[545]);
}
throw $e40354036;
}
var $ret40414042 = $Hanf_arg23884046($z40374038,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657);
++R.GAS;
return $ret40414042;
};
var $Hanf_arg23884046 = function(anf_arg14534045,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_block8570,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657) {
var $z40494050 = D;
var $f40554056 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg14534045):R.ffi.throwNonFunApp(L[564],j_DASH_block8570,[anf_arg14534045]);
};
try {
if(--R.GAS > 0) {
$z40494050 = $f40554056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40554056,
"from":L[564]});
}
} catch($e40474048) {
if(R.isCont($e40474048)) {
var $ss40514052 = {"from":L[564],
"go":function(anf_arg14544057) {
return $Hanf_arg23874058(anf_arg14544057,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657);
}};
$e40474048.stack[R.EXN_STACKHEIGHT++] = $ss40514052;
}
if(R.isPyretException($e40474048)) {
$e40474048.pyretStack.push(L[564]);
}
throw $e40474048;
}
var $ret40534054 = $Hanf_arg23874058($z40494050,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657);
++R.GAS;
return $ret40534054;
};
var $Hanf_arg23874058 = function(anf_arg14544057,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_fun8180,j_DASH_return9092,mod_DASH_input_DASH_names5153098,rt_DASH_method173657) {
var $z40614062 = D;
var $f40674068 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(mod_DASH_input_DASH_names5153098,anf_arg14544057):R.ffi.throwNonFunApp(L[565],j_DASH_fun8180,[mod_DASH_input_DASH_names5153098,anf_arg14544057]);
};
try {
if(--R.GAS > 0) {
$z40614062 = $f40674068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40674068,
"from":L[565]});
}
} catch($e40594060) {
if(R.isCont($e40594060)) {
var $ss40634064 = {"from":L[565],
"go":function(anf_array_val14554069) {
return $Hanf_array_val23864070(anf_array_val14554069,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_return9092,rt_DASH_method173657);
}};
$e40594060.stack[R.EXN_STACKHEIGHT++] = $ss40634064;
}
if(R.isPyretException($e40594060)) {
$e40594060.pyretStack.push(L[565]);
}
throw $e40594060;
}
var $ret40654066 = $Hanf_array_val23864070($z40614062,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_return9092,rt_DASH_method173657);
++R.GAS;
return $ret40654066;
};
var $Hanf_array_val23864070 = function(anf_array_val14554069,anf_array_val14123730,anf_array_val14133743,anf_fun14113731,j_DASH_return9092,rt_DASH_method173657) {
var $z40734074 = D;
var $f40794080 = function(_) {
return R.isFunction(anf_fun14113731)?anf_fun14113731.app([anf_array_val14123730,anf_array_val14133743,anf_array_val14554069]):R.ffi.throwNonFunApp(L[537],anf_fun14113731,[[anf_array_val14123730,anf_array_val14133743,anf_array_val14554069]]);
};
try {
if(--R.GAS > 0) {
$z40734074 = $f40794080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40794080,
"from":L[537]});
}
} catch($e40714072) {
if(R.isCont($e40714072)) {
var $ss40754076 = {"from":L[537],
"go":function(anf_arg14564081) {
return $Hanf_arg23854082(anf_arg14564081,j_DASH_return9092,rt_DASH_method173657);
}};
$e40714072.stack[R.EXN_STACKHEIGHT++] = $ss40754076;
}
if(R.isPyretException($e40714072)) {
$e40714072.pyretStack.push(L[537]);
}
throw $e40714072;
}
var $ret40774078 = $Hanf_arg23854082($z40734074,j_DASH_return9092,rt_DASH_method173657);
++R.GAS;
return $ret40774078;
};
var $Hanf_arg23854082 = function(anf_arg14564081,j_DASH_return9092,rt_DASH_method173657) {
var $z40854086 = D;
var $f40914092 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("loadModulesNew"),anf_arg14564081):R.ffi.throwNonFunApp(L[566],rt_DASH_method173657.$var,[("loadModulesNew"),anf_arg14564081]);
};
try {
if(--R.GAS > 0) {
$z40854086 = $f40914092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40914092,
"from":L[566]});
}
} catch($e40834084) {
if(R.isCont($e40834084)) {
var $ss40874088 = {"from":L[566],
"go":function(anf_arg14574093) {
return $Hanf_arg23844094(anf_arg14574093,j_DASH_return9092);
}};
$e40834084.stack[R.EXN_STACKHEIGHT++] = $ss40874088;
}
if(R.isPyretException($e40834084)) {
$e40834084.pyretStack.push(L[566]);
}
throw $e40834084;
}
var $ret40894090 = $Hanf_arg23844094($z40854086,j_DASH_return9092);
++R.GAS;
return $ret40894090;
};
var $Hanf_arg23844094 = function(anf_arg14574093,j_DASH_return9092) {
var $z40974098 = D;
var $f41034104 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg14574093):R.ffi.throwNonFunApp(L[473],j_DASH_return9092,[anf_arg14574093]);
};
try {
if(--R.GAS > 0) {
$z40974098 = $f41034104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41034104,
"from":L[473]});
}
} catch($e40954096) {
if(R.isCont($e40954096)) {
var $ss40994100 = {"from":L[473],
"go":function(ann_DASH_check_DASH_temp14034105) {
return $Hann_DASH_check_DASH_temp23834106(ann_DASH_check_DASH_temp14034105);
}};
$e40954096.stack[R.EXN_STACKHEIGHT++] = $ss40994100;
}
if(R.isPyretException($e40954096)) {
$e40954096.pyretStack.push(L[473]);
}
throw $e40954096;
}
var $ret41014102 = $Hann_DASH_check_DASH_temp23834106($z40974098);
++R.GAS;
return $ret41014102;
};
var $Hann_DASH_check_DASH_temp23834106 = function(ann_DASH_check_DASH_temp14034105) {
return ann_DASH_check_DASH_temp14034105;
};
var $Hanf_array_val23823800 = function(anf_array_val14233798,anf_fun14223799,in5213787,j_DASH_var8299,mt5203786,rt_DASH_method173657) {
var $z41094110 = D;
var $f41154116 = function(_) {
return R.isFunction(anf_fun14223799)?anf_fun14223799.app([in5213787,anf_array_val14233798]):R.ffi.throwNonFunApp(L[544],anf_fun14223799,[[in5213787,anf_array_val14233798]]);
};
try {
if(--R.GAS > 0) {
$z41094110 = $f41154116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41154116,
"from":L[544]});
}
} catch($e41074108) {
if(R.isCont($e41074108)) {
var $ss41114112 = {"from":L[544],
"go":function(anf_arg14244117) {
return $Hanf_arg23814118(anf_arg14244117,j_DASH_var8299,mt5203786,rt_DASH_method173657);
}};
$e41074108.stack[R.EXN_STACKHEIGHT++] = $ss41114112;
}
if(R.isPyretException($e41074108)) {
$e41074108.pyretStack.push(L[544]);
}
throw $e41074108;
}
var $ret41134114 = $Hanf_arg23814118($z41094110,j_DASH_var8299,mt5203786,rt_DASH_method173657);
++R.GAS;
return $ret41134114;
};
var $Hanf_arg23814118 = function(anf_arg14244117,j_DASH_var8299,mt5203786,rt_DASH_method173657) {
var $z41214122 = D;
var $f41274128 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("getField"),anf_arg14244117):R.ffi.throwNonFunApp(L[567],rt_DASH_method173657.$var,[("getField"),anf_arg14244117]);
};
try {
if(--R.GAS > 0) {
$z41214122 = $f41274128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41274128,
"from":L[567]});
}
} catch($e41194120) {
if(R.isCont($e41194120)) {
var $ss41234124 = {"from":L[567],
"go":function(anf_arg14254129) {
return $Hanf_arg23804130(anf_arg14254129,j_DASH_var8299,mt5203786);
}};
$e41194120.stack[R.EXN_STACKHEIGHT++] = $ss41234124;
}
if(R.isPyretException($e41194120)) {
$e41194120.pyretStack.push(L[567]);
}
throw $e41194120;
}
var $ret41254126 = $Hanf_arg23804130($z41214122,j_DASH_var8299,mt5203786);
++R.GAS;
return $ret41254126;
};
var $Hanf_arg23804130 = function(anf_arg14254129,j_DASH_var8299,mt5203786) {
var $z41334134 = D;
var $f41394140 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(mt5203786,anf_arg14254129):R.ffi.throwNonFunApp(L[542],j_DASH_var8299,[mt5203786,anf_arg14254129]);
};
try {
if(--R.GAS > 0) {
$z41334134 = $f41394140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41394140,
"from":L[542]});
}
} catch($e41314132) {
if(R.isCont($e41314132)) {
var $ss41354136 = {"from":L[542],
"go":function(ann_DASH_check_DASH_temp14214141) {
return $Hann_DASH_check_DASH_temp23794142(ann_DASH_check_DASH_temp14214141);
}};
$e41314132.stack[R.EXN_STACKHEIGHT++] = $ss41354136;
}
if(R.isPyretException($e41314132)) {
$e41314132.pyretStack.push(L[542]);
}
throw $e41314132;
}
var $ret41374138 = $Hann_DASH_check_DASH_temp23794142($z41334134);
++R.GAS;
return $ret41374138;
};
var $Hann_DASH_check_DASH_temp23794142 = function(ann_DASH_check_DASH_temp14214141) {
return ann_DASH_check_DASH_temp14214141;
};
var $Hanf_array_val23783772 = function(anf_array_val14163770,anf_fun14153771,in5193759,j_DASH_var8299,m5183758,rt_DASH_method173657) {
var $z41454146 = D;
var $f41514152 = function(_) {
return R.isFunction(anf_fun14153771)?anf_fun14153771.app([in5193759,anf_array_val14163770]):R.ffi.throwNonFunApp(L[541],anf_fun14153771,[[in5193759,anf_array_val14163770]]);
};
try {
if(--R.GAS > 0) {
$z41454146 = $f41514152();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41514152,
"from":L[541]});
}
} catch($e41434144) {
if(R.isCont($e41434144)) {
var $ss41474148 = {"from":L[541],
"go":function(anf_arg14174153) {
return $Hanf_arg23774154(anf_arg14174153,j_DASH_var8299,m5183758,rt_DASH_method173657);
}};
$e41434144.stack[R.EXN_STACKHEIGHT++] = $ss41474148;
}
if(R.isPyretException($e41434144)) {
$e41434144.pyretStack.push(L[541]);
}
throw $e41434144;
}
var $ret41494150 = $Hanf_arg23774154($z41454146,j_DASH_var8299,m5183758,rt_DASH_method173657);
++R.GAS;
return $ret41494150;
};
var $Hanf_arg23774154 = function(anf_arg14174153,j_DASH_var8299,m5183758,rt_DASH_method173657) {
var $z41574158 = D;
var $f41634164 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("getField"),anf_arg14174153):R.ffi.throwNonFunApp(L[568],rt_DASH_method173657.$var,[("getField"),anf_arg14174153]);
};
try {
if(--R.GAS > 0) {
$z41574158 = $f41634164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41634164,
"from":L[568]});
}
} catch($e41554156) {
if(R.isCont($e41554156)) {
var $ss41594160 = {"from":L[568],
"go":function(anf_arg14184165) {
return $Hanf_arg23764166(anf_arg14184165,j_DASH_var8299,m5183758);
}};
$e41554156.stack[R.EXN_STACKHEIGHT++] = $ss41594160;
}
if(R.isPyretException($e41554156)) {
$e41554156.pyretStack.push(L[568]);
}
throw $e41554156;
}
var $ret41614162 = $Hanf_arg23764166($z41574158,j_DASH_var8299,m5183758);
++R.GAS;
return $ret41614162;
};
var $Hanf_arg23764166 = function(anf_arg14184165,j_DASH_var8299,m5183758) {
var $z41694170 = D;
var $f41754176 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(m5183758,anf_arg14184165):R.ffi.throwNonFunApp(L[539],j_DASH_var8299,[m5183758,anf_arg14184165]);
};
try {
if(--R.GAS > 0) {
$z41694170 = $f41754176();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41754176,
"from":L[539]});
}
} catch($e41674168) {
if(R.isCont($e41674168)) {
var $ss41714172 = {"from":L[539],
"go":function(ann_DASH_check_DASH_temp14144177) {
return $Hann_DASH_check_DASH_temp23754178(ann_DASH_check_DASH_temp14144177);
}};
$e41674168.stack[R.EXN_STACKHEIGHT++] = $ss41714172;
}
if(R.isPyretException($e41674168)) {
$e41674168.pyretStack.push(L[539]);
}
throw $e41674168;
}
var $ret41734174 = $Hann_DASH_check_DASH_temp23754178($z41694170);
++R.GAS;
return $ret41734174;
};
var $Hann_DASH_check_DASH_temp23754178 = function(ann_DASH_check_DASH_temp14144177) {
return ann_DASH_check_DASH_temp14144177;
};
var $Hann_DASH_check_DASH_temp23743052 = function(ann_DASH_check_DASH_temp14013051) {
return ann_DASH_check_DASH_temp14013051;
};
var $Hanf_arg23733065 = function(anf_arg13983064,j_DASH_bracket9872,j_DASH_str8993,name5093053) {
var $z41814182 = D;
var $f41874188 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(name5093053):R.ffi.throwNonFunApp(L[569],j_DASH_str8993,[name5093053]);
};
try {
if(--R.GAS > 0) {
$z41814182 = $f41874188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41874188,
"from":L[569]});
}
} catch($e41794180) {
if(R.isCont($e41794180)) {
var $ss41834184 = {"from":L[569],
"go":function(anf_arg13994189) {
return $Hanf_arg23724190(anf_arg13994189,anf_arg13983064,j_DASH_bracket9872);
}};
$e41794180.stack[R.EXN_STACKHEIGHT++] = $ss41834184;
}
if(R.isPyretException($e41794180)) {
$e41794180.pyretStack.push(L[569]);
}
throw $e41794180;
}
var $ret41854186 = $Hanf_arg23724190($z41814182,anf_arg13983064,j_DASH_bracket9872);
++R.GAS;
return $ret41854186;
};
var $Hanf_arg23724190 = function(anf_arg13994189,anf_arg13983064,j_DASH_bracket9872) {
var $z41934194 = D;
var $f41994200 = function(_) {
return R.isFunction(j_DASH_bracket9872)?j_DASH_bracket9872.app(anf_arg13983064,anf_arg13994189):R.ffi.throwNonFunApp(L[469],j_DASH_bracket9872,[anf_arg13983064,anf_arg13994189]);
};
try {
if(--R.GAS > 0) {
$z41934194 = $f41994200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41994200,
"from":L[469]});
}
} catch($e41914192) {
if(R.isCont($e41914192)) {
var $ss41954196 = {"from":L[469],
"go":function(ann_DASH_check_DASH_temp13974201) {
return $Hann_DASH_check_DASH_temp23714202(ann_DASH_check_DASH_temp13974201);
}};
$e41914192.stack[R.EXN_STACKHEIGHT++] = $ss41954196;
}
if(R.isPyretException($e41914192)) {
$e41914192.pyretStack.push(L[469]);
}
throw $e41914192;
}
var $ret41974198 = $Hann_DASH_check_DASH_temp23714202($z41934194);
++R.GAS;
return $ret41974198;
};
var $Hann_DASH_check_DASH_temp23714202 = function(ann_DASH_check_DASH_temp13974201) {
return ann_DASH_check_DASH_temp13974201;
};
var $Hann_DASH_check_DASH_temp23702990 = function(ann_DASH_check_DASH_temp13862989) {
return ann_DASH_check_DASH_temp13862989;
};
var $Hann_DASH_check_DASH_temp23693010 = function(ann_DASH_check_DASH_temp13883009) {
return ann_DASH_check_DASH_temp13883009;
};
var $Hann_DASH_check_DASH_temp23682947 = function(ann_DASH_check_DASH_temp13802946) {
return ann_DASH_check_DASH_temp13802946;
};
var $Hann_DASH_check_DASH_temp23672876 = function(ann_DASH_check_DASH_temp13682875) {
return ann_DASH_check_DASH_temp13682875;
};
var $Hbind_DASH_name23662788 = function(bind_DASH_name4952787,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,n4942773) {
var anf_fun13524213 = G(n4942773,"tostring",L[571]);
var $z42054206 = D;
var $f42114212 = function(_) {
return R.isFunction(anf_fun13524213)?anf_fun13524213.app():R.ffi.throwNonFunApp(L[570],anf_fun13524213,[]);
};
try {
if(--R.GAS > 0) {
$z42054206 = $f42114212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42114212,
"from":L[570]});
}
} catch($e42034204) {
if(R.isCont($e42034204)) {
var $ss42074208 = {"from":L[570],
"go":function(anf_arg13534214) {
return $Hanf_arg23654215(anf_arg13534214,bind_DASH_name4952787,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101);
}};
$e42034204.stack[R.EXN_STACKHEIGHT++] = $ss42074208;
}
if(R.isPyretException($e42034204)) {
$e42034204.pyretStack.push(L[570]);
}
throw $e42034204;
}
var $ret42094210 = $Hanf_arg23654215($z42054206,bind_DASH_name4952787,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101);
++R.GAS;
return $ret42094210;
};
var $Hanf_arg23654215 = function(anf_arg13534214,bind_DASH_name4952787,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101) {
var $z42184219 = D;
var $f42244225 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg13534214):R.ffi.throwNonFunApp(L[572],js_DASH_id_DASH_of162700,[anf_arg13534214]);
};
try {
if(--R.GAS > 0) {
$z42184219 = $f42244225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42244225,
"from":L[572]});
}
} catch($e42164217) {
if(R.isCont($e42164217)) {
var $ss42204221 = {"from":L[572],
"go":function(anf_arg13544226) {
return $Hanf_arg23644227(anf_arg13544226,bind_DASH_name4952787,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,list35101);
}};
$e42164217.stack[R.EXN_STACKHEIGHT++] = $ss42204221;
}
if(R.isPyretException($e42164217)) {
$e42164217.pyretStack.push(L[572]);
}
throw $e42164217;
}
var $ret42224223 = $Hanf_arg23644227($z42184219,bind_DASH_name4952787,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,list35101);
++R.GAS;
return $ret42224223;
};
var $Hanf_arg23644227 = function(anf_arg13544226,bind_DASH_name4952787,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,list35101) {
var $z42304231 = D;
var $f42364237 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("NAMESPACE")):R.ffi.throwNonFunApp(L[573],j_DASH_id8381,[("NAMESPACE")]);
};
try {
if(--R.GAS > 0) {
$z42304231 = $f42364237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42364237,
"from":L[573]});
}
} catch($e42284229) {
if(R.isCont($e42284229)) {
var $ss42324233 = {"from":L[573],
"go":function(anf_arg13554238) {
return $Hanf_arg23634239(anf_arg13554238,anf_arg13544226,bind_DASH_name4952787,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,list35101);
}};
$e42284229.stack[R.EXN_STACKHEIGHT++] = $ss42324233;
}
if(R.isPyretException($e42284229)) {
$e42284229.pyretStack.push(L[573]);
}
throw $e42284229;
}
var $ret42344235 = $Hanf_arg23634239($z42304231,anf_arg13544226,bind_DASH_name4952787,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,list35101);
++R.GAS;
return $ret42344235;
};
var $Hanf_arg23634239 = function(anf_arg13554238,anf_arg13544226,bind_DASH_name4952787,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,list35101) {
var anf_fun13564251 = G(list35101,"make",L[575]);
var $z42424243 = D;
var $f42484249 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(bind_DASH_name4952787):R.ffi.throwNonFunApp(L[574],j_DASH_str8993,[bind_DASH_name4952787]);
};
try {
if(--R.GAS > 0) {
$z42424243 = $f42484249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42484249,
"from":L[574]});
}
} catch($e42404241) {
if(R.isCont($e42404241)) {
var $ss42444245 = {"from":L[574],
"go":function(anf_array_val13574250) {
return $Hanf_array_val23624252(anf_array_val13574250,anf_arg13544226,anf_arg13554238,anf_fun13564251,j_DASH_method8486,j_DASH_var8299);
}};
$e42404241.stack[R.EXN_STACKHEIGHT++] = $ss42444245;
}
if(R.isPyretException($e42404241)) {
$e42404241.pyretStack.push(L[574]);
}
throw $e42404241;
}
var $ret42464247 = $Hanf_array_val23624252($z42424243,anf_arg13544226,anf_arg13554238,anf_fun13564251,j_DASH_method8486,j_DASH_var8299);
++R.GAS;
return $ret42464247;
};
var $Hanf_array_val23624252 = function(anf_array_val13574250,anf_arg13544226,anf_arg13554238,anf_fun13564251,j_DASH_method8486,j_DASH_var8299) {
var $z42554256 = D;
var $f42614262 = function(_) {
return R.isFunction(anf_fun13564251)?anf_fun13564251.app([anf_array_val13574250]):R.ffi.throwNonFunApp(L[575],anf_fun13564251,[[anf_array_val13574250]]);
};
try {
if(--R.GAS > 0) {
$z42554256 = $f42614262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42614262,
"from":L[575]});
}
} catch($e42534254) {
if(R.isCont($e42534254)) {
var $ss42574258 = {"from":L[575],
"go":function(anf_arg13584263) {
return $Hanf_arg23614264(anf_arg13584263,anf_arg13544226,anf_arg13554238,j_DASH_method8486,j_DASH_var8299);
}};
$e42534254.stack[R.EXN_STACKHEIGHT++] = $ss42574258;
}
if(R.isPyretException($e42534254)) {
$e42534254.pyretStack.push(L[575]);
}
throw $e42534254;
}
var $ret42594260 = $Hanf_arg23614264($z42554256,anf_arg13544226,anf_arg13554238,j_DASH_method8486,j_DASH_var8299);
++R.GAS;
return $ret42594260;
};
var $Hanf_arg23614264 = function(anf_arg13584263,anf_arg13544226,anf_arg13554238,j_DASH_method8486,j_DASH_var8299) {
var $z42674268 = D;
var $f42734274 = function(_) {
return R.isFunction(j_DASH_method8486)?j_DASH_method8486.app(anf_arg13554238,("get"),anf_arg13584263):R.ffi.throwNonFunApp(L[576],j_DASH_method8486,[anf_arg13554238,("get"),anf_arg13584263]);
};
try {
if(--R.GAS > 0) {
$z42674268 = $f42734274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42734274,
"from":L[576]});
}
} catch($e42654266) {
if(R.isCont($e42654266)) {
var $ss42694270 = {"from":L[576],
"go":function(anf_arg13594275) {
return $Hanf_arg23604276(anf_arg13594275,anf_arg13544226,j_DASH_var8299);
}};
$e42654266.stack[R.EXN_STACKHEIGHT++] = $ss42694270;
}
if(R.isPyretException($e42654266)) {
$e42654266.pyretStack.push(L[576]);
}
throw $e42654266;
}
var $ret42714272 = $Hanf_arg23604276($z42674268,anf_arg13544226,j_DASH_var8299);
++R.GAS;
return $ret42714272;
};
var $Hanf_arg23604276 = function(anf_arg13594275,anf_arg13544226,j_DASH_var8299) {
var $z42794280 = D;
var $f42854286 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(anf_arg13544226,anf_arg13594275):R.ffi.throwNonFunApp(L[429],j_DASH_var8299,[anf_arg13544226,anf_arg13594275]);
};
try {
if(--R.GAS > 0) {
$z42794280 = $f42854286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42854286,
"from":L[429]});
}
} catch($e42774278) {
if(R.isCont($e42774278)) {
var $ss42814282 = {"from":L[429],
"go":function(ann_DASH_check_DASH_temp13404287) {
return $Hann_DASH_check_DASH_temp23594288(ann_DASH_check_DASH_temp13404287);
}};
$e42774278.stack[R.EXN_STACKHEIGHT++] = $ss42814282;
}
if(R.isPyretException($e42774278)) {
$e42774278.pyretStack.push(L[429]);
}
throw $e42774278;
}
var $ret42834284 = $Hann_DASH_check_DASH_temp23594288($z42794280);
++R.GAS;
return $ret42834284;
};
var $Hann_DASH_check_DASH_temp23594288 = function(ann_DASH_check_DASH_temp13404287) {
return ann_DASH_check_DASH_temp13404287;
};
var $Hanf_arg23582805 = function(anf_arg13472804,type_DASH_name79105) {
var $z42914292 = D;
var $f42974298 = function(_) {
return R.isFunction(type_DASH_name79105.$var)?type_DASH_name79105.$var.app(anf_arg13472804):R.ffi.throwNonFunApp(L[432],type_DASH_name79105.$var,[anf_arg13472804]);
};
try {
if(--R.GAS > 0) {
$z42914292 = $f42974298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42974298,
"from":L[432]});
}
} catch($e42894290) {
if(R.isCont($e42894290)) {
var $ss42934294 = {"from":L[432],
"go":function(ann_DASH_check_DASH_temp13454299) {
return $Hann_DASH_check_DASH_temp23574300(ann_DASH_check_DASH_temp13454299);
}};
$e42894290.stack[R.EXN_STACKHEIGHT++] = $ss42934294;
}
if(R.isPyretException($e42894290)) {
$e42894290.pyretStack.push(L[432]);
}
throw $e42894290;
}
var $ret42954296 = $Hann_DASH_check_DASH_temp23574300($z42914292);
++R.GAS;
return $ret42954296;
};
var $Hann_DASH_check_DASH_temp23574300 = function(ann_DASH_check_DASH_temp13454299) {
return ann_DASH_check_DASH_temp13454299;
};
var $Hann_DASH_check_DASH_temp23562819 = function(ann_DASH_check_DASH_temp13422818) {
return ann_DASH_check_DASH_temp13422818;
};
var $Hanf_arg2355776 = function(anf_arg1317775,j_DASH_app9467,j_DASH_id8381,list35101) {
var anf_fun13184312 = G(list35101,"make",L[578]);
var $z43034304 = D;
var $f43094310 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("R")):R.ffi.throwNonFunApp(L[577],j_DASH_id8381,[("R")]);
};
try {
if(--R.GAS > 0) {
$z43034304 = $f43094310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43094310,
"from":L[577]});
}
} catch($e43014302) {
if(R.isCont($e43014302)) {
var $ss43054306 = {"from":L[577],
"go":function(anf_array_val13194311) {
return $Hanf_array_val23544313(anf_array_val13194311,anf_arg1317775,anf_fun13184312,j_DASH_app9467,j_DASH_id8381);
}};
$e43014302.stack[R.EXN_STACKHEIGHT++] = $ss43054306;
}
if(R.isPyretException($e43014302)) {
$e43014302.pyretStack.push(L[577]);
}
throw $e43014302;
}
var $ret43074308 = $Hanf_array_val23544313($z43034304,anf_arg1317775,anf_fun13184312,j_DASH_app9467,j_DASH_id8381);
++R.GAS;
return $ret43074308;
};
var $Hanf_array_val23544313 = function(anf_array_val13194311,anf_arg1317775,anf_fun13184312,j_DASH_app9467,j_DASH_id8381) {
var $z43164317 = D;
var $f43224323 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("NAMESPACE")):R.ffi.throwNonFunApp(L[579],j_DASH_id8381,[("NAMESPACE")]);
};
try {
if(--R.GAS > 0) {
$z43164317 = $f43224323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43224323,
"from":L[579]});
}
} catch($e43144315) {
if(R.isCont($e43144315)) {
var $ss43184319 = {"from":L[579],
"go":function(anf_array_val13204324) {
return $Hanf_array_val23534325(anf_array_val13204324,anf_arg1317775,anf_array_val13194311,anf_fun13184312,j_DASH_app9467);
}};
$e43144315.stack[R.EXN_STACKHEIGHT++] = $ss43184319;
}
if(R.isPyretException($e43144315)) {
$e43144315.pyretStack.push(L[579]);
}
throw $e43144315;
}
var $ret43204321 = $Hanf_array_val23534325($z43164317,anf_arg1317775,anf_array_val13194311,anf_fun13184312,j_DASH_app9467);
++R.GAS;
return $ret43204321;
};
var $Hanf_array_val23534325 = function(anf_array_val13204324,anf_arg1317775,anf_array_val13194311,anf_fun13184312,j_DASH_app9467) {
var $z43284329 = D;
var $f43344335 = function(_) {
return R.isFunction(anf_fun13184312)?anf_fun13184312.app([anf_array_val13194311,anf_array_val13204324]):R.ffi.throwNonFunApp(L[578],anf_fun13184312,[[anf_array_val13194311,anf_array_val13204324]]);
};
try {
if(--R.GAS > 0) {
$z43284329 = $f43344335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43344335,
"from":L[578]});
}
} catch($e43264327) {
if(R.isCont($e43264327)) {
var $ss43304331 = {"from":L[578],
"go":function(anf_arg13214336) {
return $Hanf_arg23524337(anf_arg13214336,anf_arg1317775,j_DASH_app9467);
}};
$e43264327.stack[R.EXN_STACKHEIGHT++] = $ss43304331;
}
if(R.isPyretException($e43264327)) {
$e43264327.pyretStack.push(L[578]);
}
throw $e43264327;
}
var $ret43324333 = $Hanf_arg23524337($z43284329,anf_arg1317775,j_DASH_app9467);
++R.GAS;
return $ret43324333;
};
var $Hanf_arg23524337 = function(anf_arg13214336,anf_arg1317775,j_DASH_app9467) {
var $z43404341 = D;
var $f43464347 = function(_) {
return R.isFunction(j_DASH_app9467)?j_DASH_app9467.app(anf_arg1317775,anf_arg13214336):R.ffi.throwNonFunApp(L[79],j_DASH_app9467,[anf_arg1317775,anf_arg13214336]);
};
try {
if(--R.GAS > 0) {
$z43404341 = $f43464347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43464347,
"from":L[79]});
}
} catch($e43384339) {
if(R.isCont($e43384339)) {
var $ss43424343 = {"from":L[79],
"go":function(ann_DASH_check_DASH_temp13164348) {
return $Hann_DASH_check_DASH_temp23514349(ann_DASH_check_DASH_temp13164348);
}};
$e43384339.stack[R.EXN_STACKHEIGHT++] = $ss43424343;
}
if(R.isPyretException($e43384339)) {
$e43384339.pyretStack.push(L[79]);
}
throw $e43384339;
}
var $ret43444345 = $Hann_DASH_check_DASH_temp23514349($z43404341);
++R.GAS;
return $ret43444345;
};
var $Hann_DASH_check_DASH_temp23514349 = function(ann_DASH_check_DASH_temp13164348) {
return ann_DASH_check_DASH_temp13164348;
};
var $Hanf_arg2350790 = function(anf_arg1294788,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655) {
var $z43524353 = D;
var $f43584359 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(("G"),anf_arg1294788):R.ffi.throwNonFunApp(L[580],j_DASH_var8299,[("G"),anf_arg1294788]);
};
try {
if(--R.GAS > 0) {
$z43524353 = $f43584359();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43584359,
"from":L[580]});
}
} catch($e43504351) {
if(R.isCont($e43504351)) {
var $ss43544355 = {"from":L[580],
"go":function(anf_array_val12954360) {
return $Hanf_array_val23494361(anf_array_val12954360,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655);
}};
$e43504351.stack[R.EXN_STACKHEIGHT++] = $ss43544355;
}
if(R.isPyretException($e43504351)) {
$e43504351.pyretStack.push(L[580]);
}
throw $e43504351;
}
var $ret43564357 = $Hanf_array_val23494361($z43524353,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655);
++R.GAS;
return $ret43564357;
};
var $Hanf_array_val23494361 = function(anf_array_val12954360,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655) {
var anf_fun12964372 = G(list35101,"make",L[581]);
var $z43644365 = D;
var $f43704371 = function(_) {
return R.isFunction(anf_fun12964372)?anf_fun12964372.app([("loc"),("name")]):R.ffi.throwNonFunApp(L[581],anf_fun12964372,[[("loc"),("name")]]);
};
try {
if(--R.GAS > 0) {
$z43644365 = $f43704371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43704371,
"from":L[581]});
}
} catch($e43624363) {
if(R.isCont($e43624363)) {
var $ss43664367 = {"from":L[581],
"go":function(anf_arg12974373) {
return $Hanf_arg23484374(anf_arg12974373,anf_array_val12954360,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655);
}};
$e43624363.stack[R.EXN_STACKHEIGHT++] = $ss43664367;
}
if(R.isPyretException($e43624363)) {
$e43624363.pyretStack.push(L[581]);
}
throw $e43624363;
}
var $ret43684369 = $Hanf_arg23484374($z43644365,anf_array_val12954360,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655);
++R.GAS;
return $ret43684369;
};
var $Hanf_arg23484374 = function(anf_arg12974373,anf_array_val12954360,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655) {
var anf_fun12984386 = G(list35101,"make",L[583]);
var $z43774378 = D;
var $f43834384 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("ffi")):R.ffi.throwNonFunApp(L[582],rt_DASH_field172655.$var,[("ffi")]);
};
try {
if(--R.GAS > 0) {
$z43774378 = $f43834384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43834384,
"from":L[582]});
}
} catch($e43754376) {
if(R.isCont($e43754376)) {
var $ss43794380 = {"from":L[582],
"go":function(anf_arg12994385) {
return $Hanf_arg23474387(anf_arg12994385,anf_arg12974373,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655);
}};
$e43754376.stack[R.EXN_STACKHEIGHT++] = $ss43794380;
}
if(R.isPyretException($e43754376)) {
$e43754376.pyretStack.push(L[582]);
}
throw $e43754376;
}
var $ret43814382 = $Hanf_arg23474387($z43774378,anf_arg12974373,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655);
++R.GAS;
return $ret43814382;
};
var $Hanf_arg23474387 = function(anf_arg12994385,anf_arg12974373,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,list35101,rt_DASH_field172655) {
var anf_fun13004399 = G(list35101,"make",L[585]);
var $z43904391 = D;
var $f43964397 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("loc")):R.ffi.throwNonFunApp(L[584],j_DASH_id8381,[("loc")]);
};
try {
if(--R.GAS > 0) {
$z43904391 = $f43964397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43964397,
"from":L[584]});
}
} catch($e43884389) {
if(R.isCont($e43884389)) {
var $ss43924393 = {"from":L[584],
"go":function(anf_array_val13014398) {
return $Hanf_array_val23464400(anf_array_val13014398,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_fun1293789,anf_fun12984386,anf_fun13004399,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
}};
$e43884389.stack[R.EXN_STACKHEIGHT++] = $ss43924393;
}
if(R.isPyretException($e43884389)) {
$e43884389.pyretStack.push(L[584]);
}
throw $e43884389;
}
var $ret43944395 = $Hanf_array_val23464400($z43904391,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_fun1293789,anf_fun12984386,anf_fun13004399,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
++R.GAS;
return $ret43944395;
};
var $Hanf_array_val23464400 = function(anf_array_val13014398,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_fun1293789,anf_fun12984386,anf_fun13004399,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655) {
var $z44034404 = D;
var $f44094410 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("name")):R.ffi.throwNonFunApp(L[586],j_DASH_id8381,[("name")]);
};
try {
if(--R.GAS > 0) {
$z44034404 = $f44094410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44094410,
"from":L[586]});
}
} catch($e44014402) {
if(R.isCont($e44014402)) {
var $ss44054406 = {"from":L[586],
"go":function(anf_array_val13024411) {
return $Hanf_array_val23454412(anf_array_val13024411,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_array_val13014398,anf_fun1293789,anf_fun12984386,anf_fun13004399,j_DASH_block8570,j_DASH_fun8180,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
}};
$e44014402.stack[R.EXN_STACKHEIGHT++] = $ss44054406;
}
if(R.isPyretException($e44014402)) {
$e44014402.pyretStack.push(L[586]);
}
throw $e44014402;
}
var $ret44074408 = $Hanf_array_val23454412($z44034404,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_array_val13014398,anf_fun1293789,anf_fun12984386,anf_fun13004399,j_DASH_block8570,j_DASH_fun8180,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
++R.GAS;
return $ret44074408;
};
var $Hanf_array_val23454412 = function(anf_array_val13024411,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_array_val13014398,anf_fun1293789,anf_fun12984386,anf_fun13004399,j_DASH_block8570,j_DASH_fun8180,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655) {
var $z44154416 = D;
var $f44214422 = function(_) {
return R.isFunction(anf_fun13004399)?anf_fun13004399.app([anf_array_val13014398,anf_array_val13024411]):R.ffi.throwNonFunApp(L[585],anf_fun13004399,[[anf_array_val13014398,anf_array_val13024411]]);
};
try {
if(--R.GAS > 0) {
$z44154416 = $f44214422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44214422,
"from":L[585]});
}
} catch($e44134414) {
if(R.isCont($e44134414)) {
var $ss44174418 = {"from":L[585],
"go":function(anf_arg13034423) {
return $Hanf_arg23444424(anf_arg13034423,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
}};
$e44134414.stack[R.EXN_STACKHEIGHT++] = $ss44174418;
}
if(R.isPyretException($e44134414)) {
$e44134414.pyretStack.push(L[585]);
}
throw $e44134414;
}
var $ret44194420 = $Hanf_arg23444424($z44154416,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
++R.GAS;
return $ret44194420;
};
var $Hanf_arg23444424 = function(anf_arg13034423,anf_arg12974373,anf_arg12994385,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_method8486,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655) {
var $z44274428 = D;
var $f44334434 = function(_) {
return R.isFunction(j_DASH_method8486)?j_DASH_method8486.app(anf_arg12994385,("throwUninitializedIdMkLoc"),anf_arg13034423):R.ffi.throwNonFunApp(L[587],j_DASH_method8486,[anf_arg12994385,("throwUninitializedIdMkLoc"),anf_arg13034423]);
};
try {
if(--R.GAS > 0) {
$z44274428 = $f44334434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44334434,
"from":L[587]});
}
} catch($e44254426) {
if(R.isCont($e44254426)) {
var $ss44294430 = {"from":L[587],
"go":function(anf_array_val13044435) {
return $Hanf_array_val23434436(anf_array_val13044435,anf_arg12974373,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
}};
$e44254426.stack[R.EXN_STACKHEIGHT++] = $ss44294430;
}
if(R.isPyretException($e44254426)) {
$e44254426.pyretStack.push(L[587]);
}
throw $e44254426;
}
var $ret44314432 = $Hanf_array_val23434436($z44274428,anf_arg12974373,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
++R.GAS;
return $ret44314432;
};
var $Hanf_array_val23434436 = function(anf_array_val13044435,anf_arg12974373,anf_array_val12954360,anf_fun1293789,anf_fun12984386,j_DASH_block8570,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655) {
var $z44394440 = D;
var $f44454446 = function(_) {
return R.isFunction(anf_fun12984386)?anf_fun12984386.app([anf_array_val13044435]):R.ffi.throwNonFunApp(L[583],anf_fun12984386,[[anf_array_val13044435]]);
};
try {
if(--R.GAS > 0) {
$z44394440 = $f44454446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44454446,
"from":L[583]});
}
} catch($e44374438) {
if(R.isCont($e44374438)) {
var $ss44414442 = {"from":L[583],
"go":function(anf_arg13054447) {
return $Hanf_arg23424448(anf_arg13054447,anf_arg12974373,anf_array_val12954360,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
}};
$e44374438.stack[R.EXN_STACKHEIGHT++] = $ss44414442;
}
if(R.isPyretException($e44374438)) {
$e44374438.pyretStack.push(L[583]);
}
throw $e44374438;
}
var $ret44434444 = $Hanf_arg23424448($z44394440,anf_arg12974373,anf_array_val12954360,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
++R.GAS;
return $ret44434444;
};
var $Hanf_arg23424448 = function(anf_arg13054447,anf_arg12974373,anf_array_val12954360,anf_fun1293789,j_DASH_block8570,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655) {
var $z44514452 = D;
var $f44574458 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg13054447):R.ffi.throwNonFunApp(L[588],j_DASH_block8570,[anf_arg13054447]);
};
try {
if(--R.GAS > 0) {
$z44514452 = $f44574458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44574458,
"from":L[588]});
}
} catch($e44494450) {
if(R.isCont($e44494450)) {
var $ss44534454 = {"from":L[588],
"go":function(anf_arg13064459) {
return $Hanf_arg23414460(anf_arg13064459,anf_arg12974373,anf_array_val12954360,anf_fun1293789,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
}};
$e44494450.stack[R.EXN_STACKHEIGHT++] = $ss44534454;
}
if(R.isPyretException($e44494450)) {
$e44494450.pyretStack.push(L[588]);
}
throw $e44494450;
}
var $ret44554456 = $Hanf_arg23414460($z44514452,anf_arg12974373,anf_array_val12954360,anf_fun1293789,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
++R.GAS;
return $ret44554456;
};
var $Hanf_arg23414460 = function(anf_arg13064459,anf_arg12974373,anf_array_val12954360,anf_fun1293789,j_DASH_fun8180,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655) {
var $z44634464 = D;
var $f44694470 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg12974373,anf_arg13064459):R.ffi.throwNonFunApp(L[589],j_DASH_fun8180,[anf_arg12974373,anf_arg13064459]);
};
try {
if(--R.GAS > 0) {
$z44634464 = $f44694470();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44694470,
"from":L[589]});
}
} catch($e44614462) {
if(R.isCont($e44614462)) {
var $ss44654466 = {"from":L[589],
"go":function(anf_arg13074471) {
return $Hanf_arg23404472(anf_arg13074471,anf_array_val12954360,anf_fun1293789,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
}};
$e44614462.stack[R.EXN_STACKHEIGHT++] = $ss44654466;
}
if(R.isPyretException($e44614462)) {
$e44614462.pyretStack.push(L[589]);
}
throw $e44614462;
}
var $ret44674468 = $Hanf_arg23404472($z44634464,anf_array_val12954360,anf_fun1293789,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
++R.GAS;
return $ret44674468;
};
var $Hanf_arg23404472 = function(anf_arg13074471,anf_array_val12954360,anf_fun1293789,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655) {
var $z44754476 = D;
var $f44814482 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(("U"),anf_arg13074471):R.ffi.throwNonFunApp(L[590],j_DASH_var8299,[("U"),anf_arg13074471]);
};
try {
if(--R.GAS > 0) {
$z44754476 = $f44814482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44814482,
"from":L[590]});
}
} catch($e44734474) {
if(R.isCont($e44734474)) {
var $ss44774478 = {"from":L[590],
"go":function(anf_array_val13084483) {
return $Hanf_array_val23394484(anf_array_val13084483,anf_array_val12954360,anf_fun1293789,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
}};
$e44734474.stack[R.EXN_STACKHEIGHT++] = $ss44774478;
}
if(R.isPyretException($e44734474)) {
$e44734474.pyretStack.push(L[590]);
}
throw $e44734474;
}
var $ret44794480 = $Hanf_array_val23394484($z44754476,anf_array_val12954360,anf_fun1293789,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655);
++R.GAS;
return $ret44794480;
};
var $Hanf_array_val23394484 = function(anf_array_val13084483,anf_array_val12954360,anf_fun1293789,j_DASH_str8993,j_DASH_var8299,l484777,rt_DASH_field172655) {
var anf_arg13094495 = G(l484777,"source",L[592]);
var $z44874488 = D;
var $f44934494 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(anf_arg13094495):R.ffi.throwNonFunApp(L[591],j_DASH_str8993,[anf_arg13094495]);
};
try {
if(--R.GAS > 0) {
$z44874488 = $f44934494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44934494,
"from":L[591]});
}
} catch($e44854486) {
if(R.isCont($e44854486)) {
var $ss44894490 = {"from":L[591],
"go":function(anf_arg13104496) {
return $Hanf_arg23384497(anf_arg13104496,anf_array_val12954360,anf_array_val13084483,anf_fun1293789,j_DASH_var8299,rt_DASH_field172655);
}};
$e44854486.stack[R.EXN_STACKHEIGHT++] = $ss44894490;
}
if(R.isPyretException($e44854486)) {
$e44854486.pyretStack.push(L[591]);
}
throw $e44854486;
}
var $ret44914492 = $Hanf_arg23384497($z44874488,anf_array_val12954360,anf_array_val13084483,anf_fun1293789,j_DASH_var8299,rt_DASH_field172655);
++R.GAS;
return $ret44914492;
};
var $Hanf_arg23384497 = function(anf_arg13104496,anf_array_val12954360,anf_array_val13084483,anf_fun1293789,j_DASH_var8299,rt_DASH_field172655) {
var $z45004501 = D;
var $f45064507 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(("M"),anf_arg13104496):R.ffi.throwNonFunApp(L[593],j_DASH_var8299,[("M"),anf_arg13104496]);
};
try {
if(--R.GAS > 0) {
$z45004501 = $f45064507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45064507,
"from":L[593]});
}
} catch($e44984499) {
if(R.isCont($e44984499)) {
var $ss45024503 = {"from":L[593],
"go":function(anf_array_val13114508) {
return $Hanf_array_val23374509(anf_array_val13114508,anf_array_val12954360,anf_array_val13084483,anf_fun1293789,j_DASH_var8299,rt_DASH_field172655);
}};
$e44984499.stack[R.EXN_STACKHEIGHT++] = $ss45024503;
}
if(R.isPyretException($e44984499)) {
$e44984499.pyretStack.push(L[593]);
}
throw $e44984499;
}
var $ret45044505 = $Hanf_array_val23374509($z45004501,anf_array_val12954360,anf_array_val13084483,anf_fun1293789,j_DASH_var8299,rt_DASH_field172655);
++R.GAS;
return $ret45044505;
};
var $Hanf_array_val23374509 = function(anf_array_val13114508,anf_array_val12954360,anf_array_val13084483,anf_fun1293789,j_DASH_var8299,rt_DASH_field172655) {
var $z45124513 = D;
var $f45184519 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("undefined")):R.ffi.throwNonFunApp(L[594],rt_DASH_field172655.$var,[("undefined")]);
};
try {
if(--R.GAS > 0) {
$z45124513 = $f45184519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45184519,
"from":L[594]});
}
} catch($e45104511) {
if(R.isCont($e45104511)) {
var $ss45144515 = {"from":L[594],
"go":function(anf_arg13124520) {
return $Hanf_arg23364521(anf_arg13124520,anf_array_val12954360,anf_array_val13084483,anf_array_val13114508,anf_fun1293789,j_DASH_var8299);
}};
$e45104511.stack[R.EXN_STACKHEIGHT++] = $ss45144515;
}
if(R.isPyretException($e45104511)) {
$e45104511.pyretStack.push(L[594]);
}
throw $e45104511;
}
var $ret45164517 = $Hanf_arg23364521($z45124513,anf_array_val12954360,anf_array_val13084483,anf_array_val13114508,anf_fun1293789,j_DASH_var8299);
++R.GAS;
return $ret45164517;
};
var $Hanf_arg23364521 = function(anf_arg13124520,anf_array_val12954360,anf_array_val13084483,anf_array_val13114508,anf_fun1293789,j_DASH_var8299) {
var $z45244525 = D;
var $f45304531 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(("D"),anf_arg13124520):R.ffi.throwNonFunApp(L[595],j_DASH_var8299,[("D"),anf_arg13124520]);
};
try {
if(--R.GAS > 0) {
$z45244525 = $f45304531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45304531,
"from":L[595]});
}
} catch($e45224523) {
if(R.isCont($e45224523)) {
var $ss45264527 = {"from":L[595],
"go":function(anf_array_val13134532) {
return $Hanf_array_val23354533(anf_array_val13134532,anf_array_val12954360,anf_array_val13084483,anf_array_val13114508,anf_fun1293789);
}};
$e45224523.stack[R.EXN_STACKHEIGHT++] = $ss45264527;
}
if(R.isPyretException($e45224523)) {
$e45224523.pyretStack.push(L[595]);
}
throw $e45224523;
}
var $ret45284529 = $Hanf_array_val23354533($z45244525,anf_array_val12954360,anf_array_val13084483,anf_array_val13114508,anf_fun1293789);
++R.GAS;
return $ret45284529;
};
var $Hanf_array_val23354533 = function(anf_array_val13134532,anf_array_val12954360,anf_array_val13084483,anf_array_val13114508,anf_fun1293789) {
var $z45364537 = D;
var $f45424543 = function(_) {
return R.isFunction(anf_fun1293789)?anf_fun1293789.app([anf_array_val12954360,anf_array_val13084483,anf_array_val13114508,anf_array_val13134532]):R.ffi.throwNonFunApp(L[81],anf_fun1293789,[[anf_array_val12954360,anf_array_val13084483,anf_array_val13114508,anf_array_val13134532]]);
};
try {
if(--R.GAS > 0) {
$z45364537 = $f45424543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45424543,
"from":L[81]});
}
} catch($e45344535) {
if(R.isCont($e45344535)) {
var $ss45384539 = {"from":L[81],
"go":function(ann_DASH_check_DASH_temp12924544) {
return $Hann_DASH_check_DASH_temp23344545(ann_DASH_check_DASH_temp12924544);
}};
$e45344535.stack[R.EXN_STACKHEIGHT++] = $ss45384539;
}
if(R.isPyretException($e45344535)) {
$e45344535.pyretStack.push(L[81]);
}
throw $e45344535;
}
var $ret45404541 = $Hann_DASH_check_DASH_temp23344545($z45364537);
++R.GAS;
return $ret45404541;
};
var $Hann_DASH_check_DASH_temp23344545 = function(ann_DASH_check_DASH_temp12924544) {
return ann_DASH_check_DASH_temp12924544;
};
var $Hann_DASH_check_DASH_temp2333807 = function(ann_DASH_check_DASH_temp1266806) {
return ann_DASH_check_DASH_temp1266806;
};
var $Hanf_arg2332825 = function(anf_arg1285820,anf_fun1283821,e477822,l474823,self473819,t476824) {
var anf_fun12864556 = G(t476824,"visit",L[597]);
var $z45484549 = D;
var $f45544555 = function(_) {
return R.isFunction(anf_fun12864556)?anf_fun12864556.app(self473819):R.ffi.throwNonFunApp(L[596],anf_fun12864556,[self473819]);
};
try {
if(--R.GAS > 0) {
$z45484549 = $f45544555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45544555,
"from":L[596]});
}
} catch($e45464547) {
if(R.isCont($e45464547)) {
var $ss45504551 = {"from":L[596],
"go":function(anf_arg12874557) {
return $Hanf_arg23314558(anf_arg12874557,anf_arg1285820,anf_fun1283821,e477822,l474823,self473819);
}};
$e45464547.stack[R.EXN_STACKHEIGHT++] = $ss45504551;
}
if(R.isPyretException($e45464547)) {
$e45464547.pyretStack.push(L[596]);
}
throw $e45464547;
}
var $ret45524553 = $Hanf_arg23314558($z45484549,anf_arg1285820,anf_fun1283821,e477822,l474823,self473819);
++R.GAS;
return $ret45524553;
};
var $Hanf_arg23314558 = function(anf_arg12874557,anf_arg1285820,anf_fun1283821,e477822,l474823,self473819) {
var anf_fun12884569 = G(e477822,"visit",L[599]);
var $z45614562 = D;
var $f45674568 = function(_) {
return R.isFunction(anf_fun12884569)?anf_fun12884569.app(self473819):R.ffi.throwNonFunApp(L[598],anf_fun12884569,[self473819]);
};
try {
if(--R.GAS > 0) {
$z45614562 = $f45674568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45674568,
"from":L[598]});
}
} catch($e45594560) {
if(R.isCont($e45594560)) {
var $ss45634564 = {"from":L[598],
"go":function(anf_arg12894570) {
return $Hanf_arg23304571(anf_arg12894570,anf_arg1285820,anf_arg12874557,anf_fun1283821,l474823);
}};
$e45594560.stack[R.EXN_STACKHEIGHT++] = $ss45634564;
}
if(R.isPyretException($e45594560)) {
$e45594560.pyretStack.push(L[598]);
}
throw $e45594560;
}
var $ret45654566 = $Hanf_arg23304571($z45614562,anf_arg1285820,anf_arg12874557,anf_fun1283821,l474823);
++R.GAS;
return $ret45654566;
};
var $Hanf_arg23304571 = function(anf_arg12894570,anf_arg1285820,anf_arg12874557,anf_fun1283821,l474823) {
var $z45744575 = D;
var $f45804581 = function(_) {
return R.isFunction(anf_fun1283821)?anf_fun1283821.app(l474823,anf_arg1285820,anf_arg12874557,anf_arg12894570):R.ffi.throwNonFunApp(L[85],anf_fun1283821,[l474823,anf_arg1285820,anf_arg12874557,anf_arg12894570]);
};
try {
if(--R.GAS > 0) {
$z45744575 = $f45804581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45804581,
"from":L[85]});
}
} catch($e45724573) {
if(R.isCont($e45724573)) {
var $ss45764577 = {"from":L[85],
"go":function(ann_DASH_check_DASH_temp12824582) {
return $Hann_DASH_check_DASH_temp23294583(ann_DASH_check_DASH_temp12824582);
}};
$e45724573.stack[R.EXN_STACKHEIGHT++] = $ss45764577;
}
if(R.isPyretException($e45724573)) {
$e45724573.pyretStack.push(L[85]);
}
throw $e45724573;
}
var $ret45784579 = $Hann_DASH_check_DASH_temp23294583($z45744575);
++R.GAS;
return $ret45784579;
};
var $Hann_DASH_check_DASH_temp23294583 = function(ann_DASH_check_DASH_temp12824582) {
return ann_DASH_check_DASH_temp12824582;
};
var $Hcont_tail_arg2327843 = function(cont_tail_arg1278841,if_helper1269842) {
if(--R.GAS > 0) {
$z45844585 = R.isFunction(if_helper1269842)?if_helper1269842.app(cont_tail_arg1278841):R.ffi.throwNonFunApp(L[90],if_helper1269842,[cont_tail_arg1278841]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper1269842)?if_helper1269842.app(cont_tail_arg1278841):R.ffi.throwNonFunApp(L[90],if_helper1269842,[cont_tail_arg1278841]);
},
"from":L[90]});
}
++R.GAS;
return $z45844585;
};
var $Hcont_tail_arg2328856 = function(cont_tail_arg1275855,if_helper1269842) {
if(--R.GAS > 0) {
$z45864587 = R.isFunction(if_helper1269842)?if_helper1269842.app(cont_tail_arg1275855):R.ffi.throwNonFunApp(L[92],if_helper1269842,[cont_tail_arg1275855]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper1269842)?if_helper1269842.app(cont_tail_arg1275855):R.ffi.throwNonFunApp(L[92],if_helper1269842,[cont_tail_arg1275855]);
},
"from":L[92]});
}
++R.GAS;
return $z45864587;
};
var $Hshared_DASH_fields2326915 = function(shared_DASH_fields427909,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,namet422912,rt_DASH_method173657,self419913,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17) {
var anf_fun10984598 = G(namet422912,"tostring",L[601]);
var $z45904591 = D;
var $f45964597 = function(_) {
return R.isFunction(anf_fun10984598)?anf_fun10984598.app():R.ffi.throwNonFunApp(L[600],anf_fun10984598,[]);
};
try {
if(--R.GAS > 0) {
$z45904591 = $f45964597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45964597,
"from":L[600]});
}
} catch($e45884589) {
if(R.isCont($e45884589)) {
var $ss45924593 = {"from":L[600],
"go":function(anf_arg10994599) {
return $Hanf_arg23254600(anf_arg10994599,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17);
}};
$e45884589.stack[R.EXN_STACKHEIGHT++] = $ss45924593;
}
if(R.isPyretException($e45884589)) {
$e45884589.pyretStack.push(L[600]);
}
throw $e45884589;
}
var $ret45944595 = $Hanf_arg23254600($z45904591,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17);
++R.GAS;
return $ret45944595;
};
var $Hanf_arg23254600 = function(anf_arg10994599,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17) {
var $z46034604 = D;
var $f46094610 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg10994599):R.ffi.throwNonFunApp(L[602],js_DASH_id_DASH_of162700,[anf_arg10994599]);
};
try {
if(--R.GAS > 0) {
$z46034604 = $f46094610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46094610,
"from":L[602]});
}
} catch($e46014602) {
if(R.isCont($e46014602)) {
var $ss46054606 = {"from":L[602],
"go":function(anf_arg11004611) {
return $Hanf_arg23244612(anf_arg11004611,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17);
}};
$e46014602.stack[R.EXN_STACKHEIGHT++] = $ss46054606;
}
if(R.isPyretException($e46014602)) {
$e46014602.pyretStack.push(L[602]);
}
throw $e46014602;
}
var $ret46074608 = $Hanf_arg23244612($z46034604,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17);
++R.GAS;
return $ret46074608;
};
var $Hanf_arg23244612 = function(anf_arg11004611,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17) {
var $z46154616 = D;
var $f46214622 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg11004611):R.ffi.throwNonFunApp(L[603],j_DASH_id8381,[anf_arg11004611]);
};
try {
if(--R.GAS > 0) {
$z46154616 = $f46214622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46214622,
"from":L[603]});
}
} catch($e46134614) {
if(R.isCont($e46134614)) {
var $ss46174618 = {"from":L[603],
"go":function(external_DASH_brand4284623) {
return $Hexternal_DASH_brand23234624(external_DASH_brand4284623,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17);
}};
$e46134614.stack[R.EXN_STACKHEIGHT++] = $ss46174618;
}
if(R.isPyretException($e46134614)) {
$e46134614.pyretStack.push(L[603]);
}
throw $e46134614;
}
var $ret46194620 = $Hexternal_DASH_brand23234624($z46154616,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17);
++R.GAS;
return $ret46194620;
};
var $Hexternal_DASH_brand23234624 = function(external_DASH_brand4284623,A118,J834,Loc7863,N432,arity_DASH_check182675,brand_DASH_name425895,compiler_DASH_name167645,contract_DASH_checks183677,fold6365,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_obj9690,j_DASH_return9092,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,l420910,list35101,map349103,name421911,rt_DASH_method173657,self419913,shared_DASH_fields427909,thunk_DASH_app175661,variants423914,_plus5,raise11,$type$String17) {
var make_DASH_brand_DASH_predicate4294625 = {"$var":D,
"$name":"make-brand-predicate"};
var make_DASH_variant_DASH_constructor4304627 = {"$var":D,
"$name":"make-variant-constructor"};
var compile_DASH_variant4314629 = {"$var":D,
"$name":"compile-variant"};
var anf_assign11214626 = R.makeFunction(function(loc4324693,b4334694,pred_DASH_name4344695) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[617],3,arguments);
}
return R.checkAnnArgs([Loc7863,R.getDotAnn(L[620],"J",J834,"JExpr"),$type$String17],[loc4324693,b4334694,pred_DASH_name4344695],[L[621],L[620],L[622]],function() {
var anf_fun11024708 = G(list35101,"make",L[619]);
var anf_fun11034706 = G(list35101,"make",L[618]);
var $z46984699 = D;
var $f47044705 = function(_) {
return R.isFunction(anf_fun11034706)?anf_fun11034706.app([("val")]):R.ffi.throwNonFunApp(L[618],anf_fun11034706,[[("val")]]);
};
try {
if(--R.GAS > 0) {
$z46984699 = $f47044705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47044705,
"from":L[618]});
}
} catch($e46964697) {
if(R.isCont($e46964697)) {
var $ss47004701 = {"from":L[618],
"go":function(anf_arg11044707) {
return $Hanf_arg22314709(anf_arg11044707,anf_fun11024708,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,loc4324693,pred_DASH_name4344695,rt_DASH_method173657,self419913);
}};
$e46964697.stack[R.EXN_STACKHEIGHT++] = $ss47004701;
}
if(R.isPyretException($e46964697)) {
$e46964697.pyretStack.push(L[618]);
}
throw $e46964697;
}
var $ret47024703 = $Hanf_arg22314709($z46984699,anf_fun11024708,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,loc4324693,pred_DASH_name4344695,rt_DASH_method173657,self419913);
++R.GAS;
return $ret47024703;
});
});
make_DASH_brand_DASH_predicate4294625.$var = anf_assign11214626;
var anf_assign11864628 = R.makeFunction(function(l24354658,base_DASH_id4364659,brands_DASH_id4374660,vname4384661,members4394662) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[610],5,arguments);
}
var anf_fun11234673 = G(members4394662,"map",L[616]);
var anf_arg11284674 = R.makeFunction(function(m4414677) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[612],1,arguments);
}
var anf_bracket11254692 = G(m4414677,"bind",L[615]);
var anf_bracket11264691 = G(anf_bracket11254692,"id",L[614]);
var anf_fun11274688 = G(anf_bracket11264691,"toname",L[613]);
var $z46804681 = D;
var $f46864687 = function(_) {
return R.isFunction(anf_fun11274688)?anf_fun11274688.app():R.ffi.throwNonFunApp(L[612],anf_fun11274688,[]);
};
try {
if(--R.GAS > 0) {
$z46804681 = $f46864687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46864687,
"from":L[612]});
}
} catch($e46784679) {
if(R.isCont($e46784679)) {
var $ss46824683 = {"from":L[612],
"go":function(ann_DASH_check_DASH_temp11244689) {
return $Hann_DASH_check_DASH_temp22324690(ann_DASH_check_DASH_temp11244689);
}};
$e46784679.stack[R.EXN_STACKHEIGHT++] = $ss46824683;
}
if(R.isPyretException($e46784679)) {
$e46784679.pyretStack.push(L[612]);
}
throw $e46784679;
}
var $ret46844685 = $Hann_DASH_check_DASH_temp22324690($z46804681);
++R.GAS;
return $ret46844685;
});
var $z46654666 = D;
var $f46714672 = function(_) {
return R.isFunction(anf_fun11234673)?anf_fun11234673.app(anf_arg11284674):R.ffi.throwNonFunApp(L[611],anf_fun11234673,[anf_arg11284674]);
};
try {
if(--R.GAS > 0) {
$z46654666 = $f46714672();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46714672,
"from":L[611]});
}
} catch($e46634664) {
if(R.isCont($e46634664)) {
var $ss46674668 = {"from":L[611],
"go":function(member_DASH_names4404675) {
return $Hmember_DASH_names22674676(member_DASH_names4404675,A118,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e46634664.stack[R.EXN_STACKHEIGHT++] = $ss46674668;
}
if(R.isPyretException($e46634664)) {
$e46634664.pyretStack.push(L[611]);
}
throw $e46634664;
}
var $ret46694670 = $Hmember_DASH_names22674676($z46654666,A118,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret46694670;
});
make_DASH_variant_DASH_constructor4304627.$var = anf_assign11864628;
var anf_assign12284630 = R.makeFunction(function(v4474644) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[606],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[609],"N",N432,"AVariant")],[v4474644],[L[609]],function() {
var vname4484655 = G(v4474644,"name",L[608]);
var $z46474648 = D;
var $f46534654 = function(_) {
return R.isFunction(_plus5)?_plus5.app(vname4484655,("-base")):R.ffi.throwNonFunApp(L[607],_plus5,[vname4484655,("-base")]);
};
try {
if(--R.GAS > 0) {
$z46474648 = $f46534654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46534654,
"from":L[607]});
}
} catch($e46454646) {
if(R.isCont($e46454646)) {
var $ss46494650 = {"from":L[607],
"go":function(anf_arg11884656) {
return $Hanf_arg22974657(anf_arg11884656,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5);
}};
$e46454646.stack[R.EXN_STACKHEIGHT++] = $ss46494650;
}
if(R.isPyretException($e46454646)) {
$e46454646.pyretStack.push(L[607]);
}
throw $e46454646;
}
var $ret46514652 = $Hanf_arg22974657($z46474648,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5);
++R.GAS;
return $ret46514652;
});
});
compile_DASH_variant4314629.$var = anf_assign12284630;
var anf_fun12294641 = G(variants423914,"map",L[605]);
var $z46334634 = D;
var $f46394640 = function(_) {
return R.isFunction(anf_fun12294641)?anf_fun12294641.app(compile_DASH_variant4314629.$var):R.ffi.throwNonFunApp(L[604],anf_fun12294641,[compile_DASH_variant4314629.$var]);
};
try {
if(--R.GAS > 0) {
$z46334634 = $f46394640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46394640,
"from":L[604]});
}
} catch($e46314632) {
if(R.isCont($e46314632)) {
var $ss46354636 = {"from":L[604],
"go":function(variant_DASH_pieces4634642) {
return $Hvariant_DASH_pieces23224643(variant_DASH_pieces4634642,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e46314632.stack[R.EXN_STACKHEIGHT++] = $ss46354636;
}
if(R.isPyretException($e46314632)) {
$e46314632.pyretStack.push(L[604]);
}
throw $e46314632;
}
var $ret46374638 = $Hvariant_DASH_pieces23224643($z46334634,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret46374638;
};
var $Hvariant_DASH_pieces23224643 = function(variant_DASH_pieces4634642,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var anf_arg12344722 = R.makeFunction(function(acc4654724,piece4664725) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[624],2,arguments);
}
var anf_bracket12314739 = G(piece4664725,"stmts",L[627]);
var anf_fun12324736 = G(anf_bracket12314739,"reverse",L[626]);
var $z47284729 = D;
var $f47344735 = function(_) {
return R.isFunction(anf_fun12324736)?anf_fun12324736.app():R.ffi.throwNonFunApp(L[625],anf_fun12324736,[]);
};
try {
if(--R.GAS > 0) {
$z47284729 = $f47344735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47344735,
"from":L[625]});
}
} catch($e47264727) {
if(R.isCont($e47264727)) {
var $ss47304731 = {"from":L[625],
"go":function(anf_arg12334737) {
return $Hanf_arg22994738(anf_arg12334737,acc4654724,_plus5);
}};
$e47264727.stack[R.EXN_STACKHEIGHT++] = $ss47304731;
}
if(R.isPyretException($e47264727)) {
$e47264727.pyretStack.push(L[625]);
}
throw $e47264727;
}
var $ret47324733 = $Hanf_arg22994738($z47284729,acc4654724,_plus5);
++R.GAS;
return $ret47324733;
});
var anf_fun12354720 = G(list35101,"make",L[623]);
var $z47124713 = D;
var $f47184719 = function(_) {
return R.isFunction(anf_fun12354720)?anf_fun12354720.app([]):R.ffi.throwNonFunApp(L[623],anf_fun12354720,[[]]);
};
try {
if(--R.GAS > 0) {
$z47124713 = $f47184719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47184719,
"from":L[623]});
}
} catch($e47104711) {
if(R.isCont($e47104711)) {
var $ss47144715 = {"from":L[623],
"go":function(anf_arg12364721) {
return $Hanf_arg23214723(anf_arg12364721,anf_arg12344722,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5);
}};
$e47104711.stack[R.EXN_STACKHEIGHT++] = $ss47144715;
}
if(R.isPyretException($e47104711)) {
$e47104711.pyretStack.push(L[623]);
}
throw $e47104711;
}
var $ret47164717 = $Hanf_arg23214723($z47124713,anf_arg12344722,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5);
++R.GAS;
return $ret47164717;
};
var $Hanf_arg23214723 = function(anf_arg12364721,anf_arg12344722,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5) {
var $z47424743 = D;
var $f47484749 = function(_) {
return R.isFunction(fold6365)?fold6365.app(anf_arg12344722,anf_arg12364721,variant_DASH_pieces4634642):R.ffi.throwNonFunApp(L[624],fold6365,[anf_arg12344722,anf_arg12364721,variant_DASH_pieces4634642]);
};
try {
if(--R.GAS > 0) {
$z47424743 = $f47484749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47484749,
"from":L[624]});
}
} catch($e47404741) {
if(R.isCont($e47404741)) {
var $ss47444745 = {"from":L[624],
"go":function(anf_bracket12374750) {
return $Hanf_bracket23204751(anf_bracket12374750,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5);
}};
$e47404741.stack[R.EXN_STACKHEIGHT++] = $ss47444745;
}
if(R.isPyretException($e47404741)) {
$e47404741.pyretStack.push(L[624]);
}
throw $e47404741;
}
var $ret47464747 = $Hanf_bracket23204751($z47424743,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5);
++R.GAS;
return $ret47464747;
};
var $Hanf_bracket23204751 = function(anf_bracket12374750,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5) {
var anf_fun12384762 = G(anf_bracket12374750,"reverse",L[629]);
var $z47544755 = D;
var $f47604761 = function(_) {
return R.isFunction(anf_fun12384762)?anf_fun12384762.app():R.ffi.throwNonFunApp(L[628],anf_fun12384762,[]);
};
try {
if(--R.GAS > 0) {
$z47544755 = $f47604761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47604761,
"from":L[628]});
}
} catch($e47524753) {
if(R.isCont($e47524753)) {
var $ss47564757 = {"from":L[628],
"go":function(header_DASH_stmts4644763) {
return $Hheader_DASH_stmts23194764(header_DASH_stmts4644763,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5);
}};
$e47524753.stack[R.EXN_STACKHEIGHT++] = $ss47564757;
}
if(R.isPyretException($e47524753)) {
$e47524753.pyretStack.push(L[628]);
}
throw $e47524753;
}
var $ret47584759 = $Hheader_DASH_stmts23194764($z47544755,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5);
++R.GAS;
return $ret47584759;
};
var $Hheader_DASH_stmts23194764 = function(header_DASH_stmts4644763,external_DASH_brand4284623,fold6365,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5) {
var anf_arg12474777 = R.makeFunction(function(acc4684779,piece4694780) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[631],2,arguments);
}
var anf_fun12404791 = G(list35101,"make",L[632]);
var anf_array_val12414792 = G(piece4694780,"constructor",L[633]);
var $z47834784 = D;
var $f47894790 = function(_) {
return R.isFunction(anf_fun12404791)?anf_fun12404791.app([anf_array_val12414792]):R.ffi.throwNonFunApp(L[632],anf_fun12404791,[[anf_array_val12414792]]);
};
try {
if(--R.GAS > 0) {
$z47834784 = $f47894790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47894790,
"from":L[632]});
}
} catch($e47814782) {
if(R.isCont($e47814782)) {
var $ss47854786 = {"from":L[632],
"go":function(anf_arg12424793) {
return $Hanf_arg23034794(anf_arg12424793,acc4684779,list35101,piece4694780,_plus5);
}};
$e47814782.stack[R.EXN_STACKHEIGHT++] = $ss47854786;
}
if(R.isPyretException($e47814782)) {
$e47814782.pyretStack.push(L[632]);
}
throw $e47814782;
}
var $ret47874788 = $Hanf_arg23034794($z47834784,acc4684779,list35101,piece4694780,_plus5);
++R.GAS;
return $ret47874788;
});
var anf_fun12484775 = G(list35101,"make",L[630]);
var $z47674768 = D;
var $f47734774 = function(_) {
return R.isFunction(anf_fun12484775)?anf_fun12484775.app([]):R.ffi.throwNonFunApp(L[630],anf_fun12484775,[[]]);
};
try {
if(--R.GAS > 0) {
$z47674768 = $f47734774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47734774,
"from":L[630]});
}
} catch($e47654766) {
if(R.isCont($e47654766)) {
var $ss47694770 = {"from":L[630],
"go":function(anf_arg12494776) {
return $Hanf_arg23184778(anf_arg12494776,anf_arg12474777,external_DASH_brand4284623,fold6365,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5);
}};
$e47654766.stack[R.EXN_STACKHEIGHT++] = $ss47694770;
}
if(R.isPyretException($e47654766)) {
$e47654766.pyretStack.push(L[630]);
}
throw $e47654766;
}
var $ret47714772 = $Hanf_arg23184778($z47674768,anf_arg12474777,external_DASH_brand4284623,fold6365,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5);
++R.GAS;
return $ret47714772;
};
var $Hanf_arg23184778 = function(anf_arg12494776,anf_arg12474777,external_DASH_brand4284623,fold6365,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,variant_DASH_pieces4634642,_plus5) {
var $z47974798 = D;
var $f48034804 = function(_) {
return R.isFunction(fold6365)?fold6365.app(anf_arg12474777,anf_arg12494776,variant_DASH_pieces4634642):R.ffi.throwNonFunApp(L[631],fold6365,[anf_arg12474777,anf_arg12494776,variant_DASH_pieces4634642]);
};
try {
if(--R.GAS > 0) {
$z47974798 = $f48034804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48034804,
"from":L[631]});
}
} catch($e47954796) {
if(R.isCont($e47954796)) {
var $ss47994800 = {"from":L[631],
"go":function(anf_bracket12504805) {
return $Hanf_bracket23174806(anf_bracket12504805,external_DASH_brand4284623,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e47954796.stack[R.EXN_STACKHEIGHT++] = $ss47994800;
}
if(R.isPyretException($e47954796)) {
$e47954796.pyretStack.push(L[631]);
}
throw $e47954796;
}
var $ret48014802 = $Hanf_bracket23174806($z47974798,external_DASH_brand4284623,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret48014802;
};
var $Hanf_bracket23174806 = function(anf_bracket12504805,external_DASH_brand4284623,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var anf_fun12514817 = G(anf_bracket12504805,"reverse",L[635]);
var $z48094810 = D;
var $f48154816 = function(_) {
return R.isFunction(anf_fun12514817)?anf_fun12514817.app():R.ffi.throwNonFunApp(L[634],anf_fun12514817,[]);
};
try {
if(--R.GAS > 0) {
$z48094810 = $f48154816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48154816,
"from":L[634]});
}
} catch($e48074808) {
if(R.isCont($e48074808)) {
var $ss48114812 = {"from":L[634],
"go":function(obj_DASH_fields4674818) {
return $Hobj_DASH_fields23164819(obj_DASH_fields4674818,external_DASH_brand4284623,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e48074808.stack[R.EXN_STACKHEIGHT++] = $ss48114812;
}
if(R.isPyretException($e48074808)) {
$e48074808.pyretStack.push(L[634]);
}
throw $e48074808;
}
var $ret48134814 = $Hobj_DASH_fields23164819($z48094810,external_DASH_brand4284623,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret48134814;
};
var $Hobj_DASH_fields23164819 = function(obj_DASH_fields4674818,external_DASH_brand4284623,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_dot9775,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var $z48224823 = D;
var $f48284829 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(external_DASH_brand4284623,("_brand")):R.ffi.throwNonFunApp(L[636],j_DASH_dot9775,[external_DASH_brand4284623,("_brand")]);
};
try {
if(--R.GAS > 0) {
$z48224823 = $f48284829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48284829,
"from":L[636]});
}
} catch($e48204821) {
if(R.isCont($e48204821)) {
var $ss48244825 = {"from":L[636],
"go":function(anf_arg12524830) {
return $Hanf_arg23154831(anf_arg12524830,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e48204821.stack[R.EXN_STACKHEIGHT++] = $ss48244825;
}
if(R.isPyretException($e48204821)) {
$e48204821.pyretStack.push(L[636]);
}
throw $e48204821;
}
var $ret48264827 = $Hanf_arg23154831($z48224823,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret48264827;
};
var $Hanf_arg23154831 = function(anf_arg12524830,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,l420910,list35101,make_DASH_brand_DASH_predicate4294625,name421911,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var $z48344835 = D;
var $f48404841 = function(_) {
return R.isFunction(make_DASH_brand_DASH_predicate4294625.$var)?make_DASH_brand_DASH_predicate4294625.$var.app(l420910,anf_arg12524830,name421911):R.ffi.throwNonFunApp(L[637],make_DASH_brand_DASH_predicate4294625.$var,[l420910,anf_arg12524830,name421911]);
};
try {
if(--R.GAS > 0) {
$z48344835 = $f48404841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48404841,
"from":L[637]});
}
} catch($e48324833) {
if(R.isCont($e48324833)) {
var $ss48364837 = {"from":L[637],
"go":function(data_DASH_predicate4704842) {
return $Hdata_DASH_predicate23144843(data_DASH_predicate4704842,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e48324833.stack[R.EXN_STACKHEIGHT++] = $ss48364837;
}
if(R.isPyretException($e48324833)) {
$e48324833.pyretStack.push(L[637]);
}
throw $e48324833;
}
var $ret48384839 = $Hdata_DASH_predicate23144843($z48344835,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret48384839;
};
var $Hdata_DASH_predicate23144843 = function(data_DASH_predicate4704842,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var anf_fun12534856 = G(list35101,"make",L[639]);
var anf_fun12544854 = G(list35101,"make",L[638]);
var $z48464847 = D;
var $f48524853 = function(_) {
return R.isFunction(anf_fun12544854)?anf_fun12544854.app([data_DASH_predicate4704842]):R.ffi.throwNonFunApp(L[638],anf_fun12544854,[[data_DASH_predicate4704842]]);
};
try {
if(--R.GAS > 0) {
$z48464847 = $f48524853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48524853,
"from":L[638]});
}
} catch($e48444845) {
if(R.isCont($e48444845)) {
var $ss48484849 = {"from":L[638],
"go":function(anf_arg12554855) {
return $Hanf_arg23134857(anf_arg12554855,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e48444845.stack[R.EXN_STACKHEIGHT++] = $ss48484849;
}
if(R.isPyretException($e48444845)) {
$e48444845.pyretStack.push(L[638]);
}
throw $e48444845;
}
var $ret48504851 = $Hanf_arg23134857($z48464847,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret48504851;
};
var $Hanf_arg23134857 = function(anf_arg12554855,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,obj_DASH_fields4674818,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var $z48604861 = D;
var $f48664867 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg12554855,obj_DASH_fields4674818):R.ffi.throwNonFunApp(L[640],_plus5,[anf_arg12554855,obj_DASH_fields4674818]);
};
try {
if(--R.GAS > 0) {
$z48604861 = $f48664867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48664867,
"from":L[640]});
}
} catch($e48584859) {
if(R.isCont($e48584859)) {
var $ss48624863 = {"from":L[640],
"go":function(anf_arg12564868) {
return $Hanf_arg23124869(anf_arg12564868,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e48584859.stack[R.EXN_STACKHEIGHT++] = $ss48624863;
}
if(R.isPyretException($e48584859)) {
$e48584859.pyretStack.push(L[640]);
}
throw $e48584859;
}
var $ret48644865 = $Hanf_arg23124869($z48604861,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret48644865;
};
var $Hanf_arg23124869 = function(anf_arg12564868,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var $z48724873 = D;
var $f48784879 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg12564868):R.ffi.throwNonFunApp(L[641],j_DASH_obj9690,[anf_arg12564868]);
};
try {
if(--R.GAS > 0) {
$z48724873 = $f48784879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48784879,
"from":L[641]});
}
} catch($e48704871) {
if(R.isCont($e48704871)) {
var $ss48744875 = {"from":L[641],
"go":function(anf_array_val12574880) {
return $Hanf_array_val23114881(anf_array_val12574880,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e48704871.stack[R.EXN_STACKHEIGHT++] = $ss48744875;
}
if(R.isPyretException($e48704871)) {
$e48704871.pyretStack.push(L[641]);
}
throw $e48704871;
}
var $ret48764877 = $Hanf_array_val23114881($z48724873,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret48764877;
};
var $Hanf_array_val23114881 = function(anf_array_val12574880,anf_fun12534856,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var $z48844885 = D;
var $f48904891 = function(_) {
return R.isFunction(anf_fun12534856)?anf_fun12534856.app([anf_array_val12574880]):R.ffi.throwNonFunApp(L[639],anf_fun12534856,[[anf_array_val12574880]]);
};
try {
if(--R.GAS > 0) {
$z48844885 = $f48904891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48904891,
"from":L[639]});
}
} catch($e48824883) {
if(R.isCont($e48824883)) {
var $ss48864887 = {"from":L[639],
"go":function(anf_arg12584892) {
return $Hanf_arg23104893(anf_arg12584892,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
}};
$e48824883.stack[R.EXN_STACKHEIGHT++] = $ss48864887;
}
if(R.isPyretException($e48824883)) {
$e48824883.pyretStack.push(L[639]);
}
throw $e48824883;
}
var $ret48884889 = $Hanf_arg23104893($z48844885,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret48884889;
};
var $Hanf_arg23104893 = function(anf_arg12584892,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,rt_DASH_method173657,thunk_DASH_app175661,_plus5) {
var $z48964897 = D;
var $f49024903 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeObject"),anf_arg12584892):R.ffi.throwNonFunApp(L[642],rt_DASH_method173657.$var,[("makeObject"),anf_arg12584892]);
};
try {
if(--R.GAS > 0) {
$z48964897 = $f49024903();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49024903,
"from":L[642]});
}
} catch($e48944895) {
if(R.isCont($e48944895)) {
var $ss48984899 = {"from":L[642],
"go":function(data_DASH_object4714904) {
return $Hdata_DASH_object23094905(data_DASH_object4714904,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,thunk_DASH_app175661,_plus5);
}};
$e48944895.stack[R.EXN_STACKHEIGHT++] = $ss48984899;
}
if(R.isPyretException($e48944895)) {
$e48944895.pyretStack.push(L[642]);
}
throw $e48944895;
}
var $ret49004901 = $Hdata_DASH_object23094905($z48964897,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret49004901;
};
var $Hdata_DASH_object23094905 = function(data_DASH_object4714904,header_DASH_stmts4644763,j_DASH_block8570,j_DASH_return9092,list35101,thunk_DASH_app175661,_plus5) {
var anf_fun12594917 = G(list35101,"make",L[644]);
var $z49084909 = D;
var $f49144915 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(data_DASH_object4714904):R.ffi.throwNonFunApp(L[643],j_DASH_return9092,[data_DASH_object4714904]);
};
try {
if(--R.GAS > 0) {
$z49084909 = $f49144915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49144915,
"from":L[643]});
}
} catch($e49064907) {
if(R.isCont($e49064907)) {
var $ss49104911 = {"from":L[643],
"go":function(anf_array_val12604916) {
return $Hanf_array_val23084918(anf_array_val12604916,anf_fun12594917,header_DASH_stmts4644763,j_DASH_block8570,thunk_DASH_app175661,_plus5);
}};
$e49064907.stack[R.EXN_STACKHEIGHT++] = $ss49104911;
}
if(R.isPyretException($e49064907)) {
$e49064907.pyretStack.push(L[643]);
}
throw $e49064907;
}
var $ret49124913 = $Hanf_array_val23084918($z49084909,anf_fun12594917,header_DASH_stmts4644763,j_DASH_block8570,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret49124913;
};
var $Hanf_array_val23084918 = function(anf_array_val12604916,anf_fun12594917,header_DASH_stmts4644763,j_DASH_block8570,thunk_DASH_app175661,_plus5) {
var $z49214922 = D;
var $f49274928 = function(_) {
return R.isFunction(anf_fun12594917)?anf_fun12594917.app([anf_array_val12604916]):R.ffi.throwNonFunApp(L[644],anf_fun12594917,[[anf_array_val12604916]]);
};
try {
if(--R.GAS > 0) {
$z49214922 = $f49274928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49274928,
"from":L[644]});
}
} catch($e49194920) {
if(R.isCont($e49194920)) {
var $ss49234924 = {"from":L[644],
"go":function(anf_arg12614929) {
return $Hanf_arg23074930(anf_arg12614929,header_DASH_stmts4644763,j_DASH_block8570,thunk_DASH_app175661,_plus5);
}};
$e49194920.stack[R.EXN_STACKHEIGHT++] = $ss49234924;
}
if(R.isPyretException($e49194920)) {
$e49194920.pyretStack.push(L[644]);
}
throw $e49194920;
}
var $ret49254926 = $Hanf_arg23074930($z49214922,header_DASH_stmts4644763,j_DASH_block8570,thunk_DASH_app175661,_plus5);
++R.GAS;
return $ret49254926;
};
var $Hanf_arg23074930 = function(anf_arg12614929,header_DASH_stmts4644763,j_DASH_block8570,thunk_DASH_app175661,_plus5) {
var $z49334934 = D;
var $f49394940 = function(_) {
return R.isFunction(_plus5)?_plus5.app(header_DASH_stmts4644763,anf_arg12614929):R.ffi.throwNonFunApp(L[645],_plus5,[header_DASH_stmts4644763,anf_arg12614929]);
};
try {
if(--R.GAS > 0) {
$z49334934 = $f49394940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49394940,
"from":L[645]});
}
} catch($e49314932) {
if(R.isCont($e49314932)) {
var $ss49354936 = {"from":L[645],
"go":function(anf_arg12624941) {
return $Hanf_arg23064942(anf_arg12624941,j_DASH_block8570,thunk_DASH_app175661);
}};
$e49314932.stack[R.EXN_STACKHEIGHT++] = $ss49354936;
}
if(R.isPyretException($e49314932)) {
$e49314932.pyretStack.push(L[645]);
}
throw $e49314932;
}
var $ret49374938 = $Hanf_arg23064942($z49334934,j_DASH_block8570,thunk_DASH_app175661);
++R.GAS;
return $ret49374938;
};
var $Hanf_arg23064942 = function(anf_arg12624941,j_DASH_block8570,thunk_DASH_app175661) {
var $z49454946 = D;
var $f49514952 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg12624941):R.ffi.throwNonFunApp(L[646],j_DASH_block8570,[anf_arg12624941]);
};
try {
if(--R.GAS > 0) {
$z49454946 = $f49514952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49514952,
"from":L[646]});
}
} catch($e49434944) {
if(R.isCont($e49434944)) {
var $ss49474948 = {"from":L[646],
"go":function(anf_arg12634953) {
return $Hanf_arg23054954(anf_arg12634953,thunk_DASH_app175661);
}};
$e49434944.stack[R.EXN_STACKHEIGHT++] = $ss49474948;
}
if(R.isPyretException($e49434944)) {
$e49434944.pyretStack.push(L[646]);
}
throw $e49434944;
}
var $ret49494950 = $Hanf_arg23054954($z49454946,thunk_DASH_app175661);
++R.GAS;
return $ret49494950;
};
var $Hanf_arg23054954 = function(anf_arg12634953,thunk_DASH_app175661) {
var $z49574958 = D;
var $f49634964 = function(_) {
return R.isFunction(thunk_DASH_app175661.$var)?thunk_DASH_app175661.$var.app(anf_arg12634953):R.ffi.throwNonFunApp(L[101],thunk_DASH_app175661.$var,[anf_arg12634953]);
};
try {
if(--R.GAS > 0) {
$z49574958 = $f49634964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49634964,
"from":L[101]});
}
} catch($e49554956) {
if(R.isCont($e49554956)) {
var $ss49594960 = {"from":L[101],
"go":function(ann_DASH_check_DASH_temp10904965) {
return $Hann_DASH_check_DASH_temp23044966(ann_DASH_check_DASH_temp10904965);
}};
$e49554956.stack[R.EXN_STACKHEIGHT++] = $ss49594960;
}
if(R.isPyretException($e49554956)) {
$e49554956.pyretStack.push(L[101]);
}
throw $e49554956;
}
var $ret49614962 = $Hann_DASH_check_DASH_temp23044966($z49574958);
++R.GAS;
return $ret49614962;
};
var $Hann_DASH_check_DASH_temp23044966 = function(ann_DASH_check_DASH_temp10904965) {
return ann_DASH_check_DASH_temp10904965;
};
var $Hanf_arg23034794 = function(anf_arg12424793,acc4684779,list35101,piece4694780,_plus5) {
var anf_fun12434977 = G(list35101,"make",L[647]);
var anf_array_val12444978 = G(piece4694780,"predicate",L[648]);
var $z49694970 = D;
var $f49754976 = function(_) {
return R.isFunction(anf_fun12434977)?anf_fun12434977.app([anf_array_val12444978]):R.ffi.throwNonFunApp(L[647],anf_fun12434977,[[anf_array_val12444978]]);
};
try {
if(--R.GAS > 0) {
$z49694970 = $f49754976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49754976,
"from":L[647]});
}
} catch($e49674968) {
if(R.isCont($e49674968)) {
var $ss49714972 = {"from":L[647],
"go":function(anf_arg12454979) {
return $Hanf_arg23024980(anf_arg12454979,acc4684779,anf_arg12424793,_plus5);
}};
$e49674968.stack[R.EXN_STACKHEIGHT++] = $ss49714972;
}
if(R.isPyretException($e49674968)) {
$e49674968.pyretStack.push(L[647]);
}
throw $e49674968;
}
var $ret49734974 = $Hanf_arg23024980($z49694970,acc4684779,anf_arg12424793,_plus5);
++R.GAS;
return $ret49734974;
};
var $Hanf_arg23024980 = function(anf_arg12454979,acc4684779,anf_arg12424793,_plus5) {
var $z49834984 = D;
var $f49894990 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg12424793,anf_arg12454979):R.ffi.throwNonFunApp(L[649],_plus5,[anf_arg12424793,anf_arg12454979]);
};
try {
if(--R.GAS > 0) {
$z49834984 = $f49894990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49894990,
"from":L[649]});
}
} catch($e49814982) {
if(R.isCont($e49814982)) {
var $ss49854986 = {"from":L[649],
"go":function(anf_arg12464991) {
return $Hanf_arg23014992(anf_arg12464991,acc4684779,_plus5);
}};
$e49814982.stack[R.EXN_STACKHEIGHT++] = $ss49854986;
}
if(R.isPyretException($e49814982)) {
$e49814982.pyretStack.push(L[649]);
}
throw $e49814982;
}
var $ret49874988 = $Hanf_arg23014992($z49834984,acc4684779,_plus5);
++R.GAS;
return $ret49874988;
};
var $Hanf_arg23014992 = function(anf_arg12464991,acc4684779,_plus5) {
var $z49954996 = D;
var $f50015002 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg12464991,acc4684779):R.ffi.throwNonFunApp(L[631],_plus5,[anf_arg12464991,acc4684779]);
};
try {
if(--R.GAS > 0) {
$z49954996 = $f50015002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50015002,
"from":L[631]});
}
} catch($e49934994) {
if(R.isCont($e49934994)) {
var $ss49974998 = {"from":L[631],
"go":function(ann_DASH_check_DASH_temp12395003) {
return $Hann_DASH_check_DASH_temp23005004(ann_DASH_check_DASH_temp12395003);
}};
$e49934994.stack[R.EXN_STACKHEIGHT++] = $ss49974998;
}
if(R.isPyretException($e49934994)) {
$e49934994.pyretStack.push(L[631]);
}
throw $e49934994;
}
var $ret49995000 = $Hann_DASH_check_DASH_temp23005004($z49954996);
++R.GAS;
return $ret49995000;
};
var $Hann_DASH_check_DASH_temp23005004 = function(ann_DASH_check_DASH_temp12395003) {
return ann_DASH_check_DASH_temp12395003;
};
var $Hanf_arg22994738 = function(anf_arg12334737,acc4654724,_plus5) {
var $z50075008 = D;
var $f50135014 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg12334737,acc4654724):R.ffi.throwNonFunApp(L[624],_plus5,[anf_arg12334737,acc4654724]);
};
try {
if(--R.GAS > 0) {
$z50075008 = $f50135014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50135014,
"from":L[624]});
}
} catch($e50055006) {
if(R.isCont($e50055006)) {
var $ss50095010 = {"from":L[624],
"go":function(ann_DASH_check_DASH_temp12305015) {
return $Hann_DASH_check_DASH_temp22985016(ann_DASH_check_DASH_temp12305015);
}};
$e50055006.stack[R.EXN_STACKHEIGHT++] = $ss50095010;
}
if(R.isPyretException($e50055006)) {
$e50055006.pyretStack.push(L[624]);
}
throw $e50055006;
}
var $ret50115012 = $Hann_DASH_check_DASH_temp22985016($z50075008);
++R.GAS;
return $ret50115012;
};
var $Hann_DASH_check_DASH_temp22985016 = function(ann_DASH_check_DASH_temp12305015) {
return ann_DASH_check_DASH_temp12305015;
};
var $Hanf_arg22974657 = function(anf_arg11884656,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5) {
var $z50195020 = D;
var $f50255026 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(anf_arg11884656):R.ffi.throwNonFunApp(L[650],compiler_DASH_name167645.$var,[anf_arg11884656]);
};
try {
if(--R.GAS > 0) {
$z50195020 = $f50255026();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50255026,
"from":L[650]});
}
} catch($e50175018) {
if(R.isCont($e50175018)) {
var $ss50215022 = {"from":L[650],
"go":function(anf_arg11895027) {
return $Hanf_arg22965028(anf_arg11895027,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5);
}};
$e50175018.stack[R.EXN_STACKHEIGHT++] = $ss50215022;
}
if(R.isPyretException($e50175018)) {
$e50175018.pyretStack.push(L[650]);
}
throw $e50175018;
}
var $ret50235024 = $Hanf_arg22965028($z50195020,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5);
++R.GAS;
return $ret50235024;
};
var $Hanf_arg22965028 = function(anf_arg11895027,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5) {
var $z50315032 = D;
var $f50375038 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg11895027):R.ffi.throwNonFunApp(L[651],js_DASH_id_DASH_of162700,[anf_arg11895027]);
};
try {
if(--R.GAS > 0) {
$z50315032 = $f50375038();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50375038,
"from":L[651]});
}
} catch($e50295030) {
if(R.isCont($e50295030)) {
var $ss50335034 = {"from":L[651],
"go":function(variant_DASH_base_DASH_id4495039) {
return $Hvariant_DASH_base_DASH_id22955040(variant_DASH_base_DASH_id4495039,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5);
}};
$e50295030.stack[R.EXN_STACKHEIGHT++] = $ss50335034;
}
if(R.isPyretException($e50295030)) {
$e50295030.pyretStack.push(L[651]);
}
throw $e50295030;
}
var $ret50355036 = $Hvariant_DASH_base_DASH_id22955040($z50315032,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5);
++R.GAS;
return $ret50355036;
};
var $Hvariant_DASH_base_DASH_id22955040 = function(variant_DASH_base_DASH_id4495039,A118,brand_DASH_name425895,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,vname4484655,_plus5) {
var $z50435044 = D;
var $f50495050 = function(_) {
return R.isFunction(brand_DASH_name425895.$var)?brand_DASH_name425895.$var.app(vname4484655):R.ffi.throwNonFunApp(L[652],brand_DASH_name425895.$var,[vname4484655]);
};
try {
if(--R.GAS > 0) {
$z50435044 = $f50495050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50495050,
"from":L[652]});
}
} catch($e50415042) {
if(R.isCont($e50415042)) {
var $ss50455046 = {"from":L[652],
"go":function(variant_DASH_brand4505051) {
return $Hvariant_DASH_brand22945052(variant_DASH_brand4505051,A118,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,vname4484655,_plus5);
}};
$e50415042.stack[R.EXN_STACKHEIGHT++] = $ss50455046;
}
if(R.isPyretException($e50415042)) {
$e50415042.pyretStack.push(L[652]);
}
throw $e50415042;
}
var $ret50475048 = $Hvariant_DASH_brand22945052($z50435044,A118,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,vname4484655,_plus5);
++R.GAS;
return $ret50475048;
};
var $Hvariant_DASH_brand22945052 = function(variant_DASH_brand4505051,A118,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,vname4484655,_plus5) {
var $z50555056 = D;
var $f50615062 = function(_) {
return R.isFunction(_plus5)?_plus5.app(vname4484655,("-brands")):R.ffi.throwNonFunApp(L[653],_plus5,[vname4484655,("-brands")]);
};
try {
if(--R.GAS > 0) {
$z50555056 = $f50615062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50615062,
"from":L[653]});
}
} catch($e50535054) {
if(R.isCont($e50535054)) {
var $ss50575058 = {"from":L[653],
"go":function(anf_arg11905063) {
return $Hanf_arg22935064(anf_arg11905063,A118,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5);
}};
$e50535054.stack[R.EXN_STACKHEIGHT++] = $ss50575058;
}
if(R.isPyretException($e50535054)) {
$e50535054.pyretStack.push(L[653]);
}
throw $e50535054;
}
var $ret50595060 = $Hanf_arg22935064($z50555056,A118,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5);
++R.GAS;
return $ret50595060;
};
var $Hanf_arg22935064 = function(anf_arg11905063,A118,compiler_DASH_name167645,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5) {
var $z50675068 = D;
var $f50735074 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(anf_arg11905063):R.ffi.throwNonFunApp(L[654],compiler_DASH_name167645.$var,[anf_arg11905063]);
};
try {
if(--R.GAS > 0) {
$z50675068 = $f50735074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50735074,
"from":L[654]});
}
} catch($e50655066) {
if(R.isCont($e50655066)) {
var $ss50695070 = {"from":L[654],
"go":function(anf_arg11915075) {
return $Hanf_arg22925076(anf_arg11915075,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5);
}};
$e50655066.stack[R.EXN_STACKHEIGHT++] = $ss50695070;
}
if(R.isPyretException($e50655066)) {
$e50655066.pyretStack.push(L[654]);
}
throw $e50655066;
}
var $ret50715072 = $Hanf_arg22925076($z50675068,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5);
++R.GAS;
return $ret50715072;
};
var $Hanf_arg22925076 = function(anf_arg11915075,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5) {
var $z50795080 = D;
var $f50855086 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg11915075):R.ffi.throwNonFunApp(L[655],js_DASH_id_DASH_of162700,[anf_arg11915075]);
};
try {
if(--R.GAS > 0) {
$z50795080 = $f50855086();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50855086,
"from":L[655]});
}
} catch($e50775078) {
if(R.isCont($e50775078)) {
var $ss50815082 = {"from":L[655],
"go":function(variant_DASH_brand_DASH_obj_DASH_id4515087) {
return $Hvariant_DASH_brand_DASH_obj_DASH_id22915088(variant_DASH_brand_DASH_obj_DASH_id4515087,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5);
}};
$e50775078.stack[R.EXN_STACKHEIGHT++] = $ss50815082;
}
if(R.isPyretException($e50775078)) {
$e50775078.pyretStack.push(L[655]);
}
throw $e50775078;
}
var $ret50835084 = $Hvariant_DASH_brand_DASH_obj_DASH_id22915088($z50795080,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5);
++R.GAS;
return $ret50835084;
};
var $Hvariant_DASH_brand_DASH_obj_DASH_id22915088 = function(variant_DASH_brand_DASH_obj_DASH_id4515087,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand4505051,vname4484655,_plus5) {
var anf_fun11925100 = G(list35101,"make",L[657]);
var $z50915092 = D;
var $f50975098 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(variant_DASH_brand4505051,j_DASH_true8696):R.ffi.throwNonFunApp(L[656],j_DASH_field9979,[variant_DASH_brand4505051,j_DASH_true8696]);
};
try {
if(--R.GAS > 0) {
$z50915092 = $f50975098();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50975098,
"from":L[656]});
}
} catch($e50895090) {
if(R.isCont($e50895090)) {
var $ss50935094 = {"from":L[656],
"go":function(anf_array_val11935099) {
return $Hanf_array_val22905101(anf_array_val11935099,A118,anf_fun11925100,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5);
}};
$e50895090.stack[R.EXN_STACKHEIGHT++] = $ss50935094;
}
if(R.isPyretException($e50895090)) {
$e50895090.pyretStack.push(L[656]);
}
throw $e50895090;
}
var $ret50955096 = $Hanf_array_val22905101($z50915092,A118,anf_fun11925100,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5);
++R.GAS;
return $ret50955096;
};
var $Hanf_array_val22905101 = function(anf_array_val11935099,A118,anf_fun11925100,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5) {
var $z51045105 = D;
var $f51105111 = function(_) {
return R.isFunction(anf_fun11925100)?anf_fun11925100.app([anf_array_val11935099]):R.ffi.throwNonFunApp(L[657],anf_fun11925100,[[anf_array_val11935099]]);
};
try {
if(--R.GAS > 0) {
$z51045105 = $f51105111();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51105111,
"from":L[657]});
}
} catch($e51025103) {
if(R.isCont($e51025103)) {
var $ss51065107 = {"from":L[657],
"go":function(anf_arg11945112) {
return $Hanf_arg22895113(anf_arg11945112,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5);
}};
$e51025103.stack[R.EXN_STACKHEIGHT++] = $ss51065107;
}
if(R.isPyretException($e51025103)) {
$e51025103.pyretStack.push(L[657]);
}
throw $e51025103;
}
var $ret51085109 = $Hanf_arg22895113($z51045105,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5);
++R.GAS;
return $ret51085109;
};
var $Hanf_arg22895113 = function(anf_arg11945112,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5) {
var $z51165117 = D;
var $f51225123 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg11945112):R.ffi.throwNonFunApp(L[658],j_DASH_obj9690,[anf_arg11945112]);
};
try {
if(--R.GAS > 0) {
$z51165117 = $f51225123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51225123,
"from":L[658]});
}
} catch($e51145115) {
if(R.isCont($e51145115)) {
var $ss51185119 = {"from":L[658],
"go":function(variant_DASH_brands4525124) {
return $Hvariant_DASH_brands22885125(variant_DASH_brands4525124,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5);
}};
$e51145115.stack[R.EXN_STACKHEIGHT++] = $ss51185119;
}
if(R.isPyretException($e51145115)) {
$e51145115.pyretStack.push(L[658]);
}
throw $e51145115;
}
var $ret51205121 = $Hvariant_DASH_brands22885125($z51165117,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5);
++R.GAS;
return $ret51205121;
};
var $Hvariant_DASH_brands22885125 = function(variant_DASH_brands4525124,A118,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,self419913,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655,_plus5) {
var anf_fun11955139 = G(list35101,"make",L[663]);
var anf_bracket11965155 = G(v4474644,"with-members",L[662]);
var anf_fun11975136 = G(anf_bracket11965155,"map",L[661]);
var anf_arg12005137 = R.makeFunction(function(recv_DASH_685141) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[660],1,arguments);
}
var anf_fun11995152 = G(recv_DASH_685141,"visit",L[660]);
var $z51445145 = D;
var $f51505151 = function(_) {
return R.isFunction(anf_fun11995152)?anf_fun11995152.app(self419913):R.ffi.throwNonFunApp(L[660],anf_fun11995152,[self419913]);
};
try {
if(--R.GAS > 0) {
$z51445145 = $f51505151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51505151,
"from":L[660]});
}
} catch($e51425143) {
if(R.isCont($e51425143)) {
var $ss51465147 = {"from":L[660],
"go":function(ann_DASH_check_DASH_temp11985153) {
return $Hann_DASH_check_DASH_temp22685154(ann_DASH_check_DASH_temp11985153);
}};
$e51425143.stack[R.EXN_STACKHEIGHT++] = $ss51465147;
}
if(R.isPyretException($e51425143)) {
$e51425143.pyretStack.push(L[660]);
}
throw $e51425143;
}
var $ret51485149 = $Hann_DASH_check_DASH_temp22685154($z51445145);
++R.GAS;
return $ret51485149;
});
var $z51285129 = D;
var $f51345135 = function(_) {
return R.isFunction(anf_fun11975136)?anf_fun11975136.app(anf_arg12005137):R.ffi.throwNonFunApp(L[659],anf_fun11975136,[anf_arg12005137]);
};
try {
if(--R.GAS > 0) {
$z51285129 = $f51345135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51345135,
"from":L[659]});
}
} catch($e51265127) {
if(R.isCont($e51265127)) {
var $ss51305131 = {"from":L[659],
"go":function(anf_arg12015138) {
return $Hanf_arg22875140(anf_arg12015138,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655,_plus5);
}};
$e51265127.stack[R.EXN_STACKHEIGHT++] = $ss51305131;
}
if(R.isPyretException($e51265127)) {
$e51265127.pyretStack.push(L[659]);
}
throw $e51265127;
}
var $ret51325133 = $Hanf_arg22875140($z51285129,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655,_plus5);
++R.GAS;
return $ret51325133;
};
var $Hanf_arg22875140 = function(anf_arg12015138,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,shared_DASH_fields427909,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655,_plus5) {
var $z51585159 = D;
var $f51645165 = function(_) {
return R.isFunction(_plus5)?_plus5.app(shared_DASH_fields427909,anf_arg12015138):R.ffi.throwNonFunApp(L[664],_plus5,[shared_DASH_fields427909,anf_arg12015138]);
};
try {
if(--R.GAS > 0) {
$z51585159 = $f51645165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51645165,
"from":L[664]});
}
} catch($e51565157) {
if(R.isCont($e51565157)) {
var $ss51605161 = {"from":L[664],
"go":function(anf_arg12025166) {
return $Hanf_arg22865167(anf_arg12025166,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655);
}};
$e51565157.stack[R.EXN_STACKHEIGHT++] = $ss51605161;
}
if(R.isPyretException($e51565157)) {
$e51565157.pyretStack.push(L[664]);
}
throw $e51565157;
}
var $ret51625163 = $Hanf_arg22865167($z51585159,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655);
++R.GAS;
return $ret51625163;
};
var $Hanf_arg22865167 = function(anf_arg12025166,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_obj9690,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655) {
var $z51705171 = D;
var $f51765177 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg12025166):R.ffi.throwNonFunApp(L[665],j_DASH_obj9690,[anf_arg12025166]);
};
try {
if(--R.GAS > 0) {
$z51705171 = $f51765177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51765177,
"from":L[665]});
}
} catch($e51685169) {
if(R.isCont($e51685169)) {
var $ss51725173 = {"from":L[665],
"go":function(anf_arg12035178) {
return $Hanf_arg22855179(anf_arg12035178,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655);
}};
$e51685169.stack[R.EXN_STACKHEIGHT++] = $ss51725173;
}
if(R.isPyretException($e51685169)) {
$e51685169.pyretStack.push(L[665]);
}
throw $e51685169;
}
var $ret51745175 = $Hanf_arg22855179($z51705171,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655);
++R.GAS;
return $ret51745175;
};
var $Hanf_arg22855179 = function(anf_arg12035178,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655) {
var $z51825183 = D;
var $f51885189 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(variant_DASH_base_DASH_id4495039,anf_arg12035178):R.ffi.throwNonFunApp(L[666],j_DASH_var8299,[variant_DASH_base_DASH_id4495039,anf_arg12035178]);
};
try {
if(--R.GAS > 0) {
$z51825183 = $f51885189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51885189,
"from":L[666]});
}
} catch($e51805181) {
if(R.isCont($e51805181)) {
var $ss51845185 = {"from":L[666],
"go":function(anf_array_val12045190) {
return $Hanf_array_val22845191(anf_array_val12045190,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655);
}};
$e51805181.stack[R.EXN_STACKHEIGHT++] = $ss51845185;
}
if(R.isPyretException($e51805181)) {
$e51805181.pyretStack.push(L[666]);
}
throw $e51805181;
}
var $ret51865187 = $Hanf_array_val22845191($z51825183,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655);
++R.GAS;
return $ret51865187;
};
var $Hanf_array_val22845191 = function(anf_array_val12045190,A118,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,j_DASH_var8299,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,variant_DASH_brands4525124,vname4484655) {
var $z51945195 = D;
var $f52005201 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brands4525124):R.ffi.throwNonFunApp(L[667],j_DASH_var8299,[variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brands4525124]);
};
try {
if(--R.GAS > 0) {
$z51945195 = $f52005201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52005201,
"from":L[667]});
}
} catch($e51925193) {
if(R.isCont($e51925193)) {
var $ss51965197 = {"from":L[667],
"go":function(anf_array_val12055202) {
return $Hanf_array_val22835203(anf_array_val12055202,A118,anf_array_val12045190,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
}};
$e51925193.stack[R.EXN_STACKHEIGHT++] = $ss51965197;
}
if(R.isPyretException($e51925193)) {
$e51925193.pyretStack.push(L[667]);
}
throw $e51925193;
}
var $ret51985199 = $Hanf_array_val22835203($z51945195,A118,anf_array_val12045190,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
++R.GAS;
return $ret51985199;
};
var $Hanf_array_val22835203 = function(anf_array_val12055202,A118,anf_array_val12045190,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655) {
var $z52065207 = D;
var $f52125213 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(variant_DASH_brand_DASH_obj_DASH_id4515087):R.ffi.throwNonFunApp(L[668],j_DASH_id8381,[variant_DASH_brand_DASH_obj_DASH_id4515087]);
};
try {
if(--R.GAS > 0) {
$z52065207 = $f52125213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52125213,
"from":L[668]});
}
} catch($e52045205) {
if(R.isCont($e52045205)) {
var $ss52085209 = {"from":L[668],
"go":function(anf_arg12065214) {
return $Hanf_arg22825215(anf_arg12065214,A118,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
}};
$e52045205.stack[R.EXN_STACKHEIGHT++] = $ss52085209;
}
if(R.isPyretException($e52045205)) {
$e52045205.pyretStack.push(L[668]);
}
throw $e52045205;
}
var $ret52105211 = $Hanf_arg22825215($z52065207,A118,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
++R.GAS;
return $ret52105211;
};
var $Hanf_arg22825215 = function(anf_arg12065214,A118,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,external_DASH_brand4284623,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655) {
var $z52185219 = D;
var $f52245225 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(external_DASH_brand4284623,("_brand")):R.ffi.throwNonFunApp(L[669],j_DASH_dot9775,[external_DASH_brand4284623,("_brand")]);
};
try {
if(--R.GAS > 0) {
$z52185219 = $f52245225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52245225,
"from":L[669]});
}
} catch($e52165217) {
if(R.isCont($e52165217)) {
var $ss52205221 = {"from":L[669],
"go":function(anf_arg12075226) {
return $Hanf_arg22815227(anf_arg12075226,A118,anf_arg12065214,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
}};
$e52165217.stack[R.EXN_STACKHEIGHT++] = $ss52205221;
}
if(R.isPyretException($e52165217)) {
$e52165217.pyretStack.push(L[669]);
}
throw $e52165217;
}
var $ret52225223 = $Hanf_arg22815227($z52185219,A118,anf_arg12065214,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
++R.GAS;
return $ret52225223;
};
var $Hanf_arg22815227 = function(anf_arg12075226,A118,anf_arg12065214,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,j_DASH_true8696,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655) {
var $z52305231 = D;
var $f52365237 = function(_) {
return R.isFunction(j_DASH_bracket_DASH_assign10171)?j_DASH_bracket_DASH_assign10171.app(anf_arg12065214,anf_arg12075226,j_DASH_true8696):R.ffi.throwNonFunApp(L[670],j_DASH_bracket_DASH_assign10171,[anf_arg12065214,anf_arg12075226,j_DASH_true8696]);
};
try {
if(--R.GAS > 0) {
$z52305231 = $f52365237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52365237,
"from":L[670]});
}
} catch($e52285229) {
if(R.isCont($e52285229)) {
var $ss52325233 = {"from":L[670],
"go":function(anf_array_val12085238) {
return $Hanf_array_val22805239(anf_array_val12085238,A118,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
}};
$e52285229.stack[R.EXN_STACKHEIGHT++] = $ss52325233;
}
if(R.isPyretException($e52285229)) {
$e52285229.pyretStack.push(L[670]);
}
throw $e52285229;
}
var $ret52345235 = $Hanf_array_val22805239($z52305231,A118,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
++R.GAS;
return $ret52345235;
};
var $Hanf_array_val22805239 = function(anf_array_val12085238,A118,anf_array_val12045190,anf_array_val12055202,anf_fun11955139,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655) {
var $z52425243 = D;
var $f52485249 = function(_) {
return R.isFunction(anf_fun11955139)?anf_fun11955139.app([anf_array_val12045190,anf_array_val12055202,anf_array_val12085238]):R.ffi.throwNonFunApp(L[671],anf_fun11955139,[[anf_array_val12045190,anf_array_val12055202,anf_array_val12085238]]);
};
try {
if(--R.GAS > 0) {
$z52425243 = $f52485249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52485249,
"from":L[671]});
}
} catch($e52405241) {
if(R.isCont($e52405241)) {
var $ss52445245 = {"from":L[671],
"go":function(stmts4535250) {
return $Hstmts22795251(stmts4535250,A118,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
}};
$e52405241.stack[R.EXN_STACKHEIGHT++] = $ss52445245;
}
if(R.isPyretException($e52405241)) {
$e52405241.pyretStack.push(L[671]);
}
throw $e52405241;
}
var $ret52465247 = $Hstmts22795251($z52425243,A118,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655);
++R.GAS;
return $ret52465247;
};
var $Hstmts22795251 = function(stmts4535250,A118,j_DASH_field9979,j_DASH_id8381,j_DASH_str8993,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,variant_DASH_brand4505051,vname4484655) {
var anf_arg12095263 = G(v4474644,"l",L[673]);
var $z52545255 = D;
var $f52605261 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(variant_DASH_brand4505051):R.ffi.throwNonFunApp(L[672],j_DASH_str8993,[variant_DASH_brand4505051]);
};
try {
if(--R.GAS > 0) {
$z52545255 = $f52605261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52605261,
"from":L[672]});
}
} catch($e52525253) {
if(R.isCont($e52525253)) {
var $ss52565257 = {"from":L[672],
"go":function(anf_arg12105262) {
return $Hanf_arg22785264(anf_arg12105262,A118,anf_arg12095263,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655);
}};
$e52525253.stack[R.EXN_STACKHEIGHT++] = $ss52565257;
}
if(R.isPyretException($e52525253)) {
$e52525253.pyretStack.push(L[672]);
}
throw $e52525253;
}
var $ret52585259 = $Hanf_arg22785264($z52545255,A118,anf_arg12095263,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655);
++R.GAS;
return $ret52585259;
};
var $Hanf_arg22785264 = function(anf_arg12105262,A118,anf_arg12095263,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655) {
var anf_fun12115275 = G(A118,"make-checker-name",L[675]);
var $z52675268 = D;
var $f52735274 = function(_) {
return R.isFunction(anf_fun12115275)?anf_fun12115275.app(vname4484655):R.ffi.throwNonFunApp(L[674],anf_fun12115275,[vname4484655]);
};
try {
if(--R.GAS > 0) {
$z52675268 = $f52735274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52735274,
"from":L[674]});
}
} catch($e52655266) {
if(R.isCont($e52655266)) {
var $ss52695270 = {"from":L[674],
"go":function(anf_arg12125276) {
return $Hanf_arg22775277(anf_arg12125276,anf_arg12095263,anf_arg12105262,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655);
}};
$e52655266.stack[R.EXN_STACKHEIGHT++] = $ss52695270;
}
if(R.isPyretException($e52655266)) {
$e52655266.pyretStack.push(L[674]);
}
throw $e52655266;
}
var $ret52715272 = $Hanf_arg22775277($z52675268,anf_arg12095263,anf_arg12105262,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655);
++R.GAS;
return $ret52715272;
};
var $Hanf_arg22775277 = function(anf_arg12125276,anf_arg12095263,anf_arg12105262,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_brand_DASH_predicate4294625,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655) {
var $z52805281 = D;
var $f52865287 = function(_) {
return R.isFunction(make_DASH_brand_DASH_predicate4294625.$var)?make_DASH_brand_DASH_predicate4294625.$var.app(anf_arg12095263,anf_arg12105262,anf_arg12125276):R.ffi.throwNonFunApp(L[676],make_DASH_brand_DASH_predicate4294625.$var,[anf_arg12095263,anf_arg12105262,anf_arg12125276]);
};
try {
if(--R.GAS > 0) {
$z52805281 = $f52865287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52865287,
"from":L[676]});
}
} catch($e52785279) {
if(R.isCont($e52785279)) {
var $ss52825283 = {"from":L[676],
"go":function(predicate4545288) {
return $Hpredicate22765289(predicate4545288,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655);
}};
$e52785279.stack[R.EXN_STACKHEIGHT++] = $ss52825283;
}
if(R.isPyretException($e52785279)) {
$e52785279.pyretStack.push(L[676]);
}
throw $e52785279;
}
var $ret52845285 = $Hpredicate22765289($z52805281,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655);
++R.GAS;
return $ret52845285;
};
var $Hpredicate22765289 = function(predicate4545288,j_DASH_field9979,j_DASH_id8381,list35101,make_DASH_variant_DASH_constructor4304627,rt_DASH_method173657,stmts4535250,v4474644,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655) {
var cases_DASH_val695341 = v4474644;
var anf_fun12135300 = G(cases_DASH_val695341,"_match",L[677]);
var anf_obj12165306 = R.makeFunction(function(l24555324,constr_DASH_loc4565325,$underscore4575326,members4585327,with_DASH_members4595328) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[681],5,arguments);
}
var $z53315332 = D;
var $f53375338 = function(_) {
return R.isFunction(make_DASH_variant_DASH_constructor4304627.$var)?make_DASH_variant_DASH_constructor4304627.$var.app(constr_DASH_loc4565325,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655,members4585327):R.ffi.throwNonFunApp(L[682],make_DASH_variant_DASH_constructor4304627.$var,[constr_DASH_loc4565325,variant_DASH_base_DASH_id4495039,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655,members4585327]);
};
try {
if(--R.GAS > 0) {
$z53315332 = $f53375338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53375338,
"from":L[682]});
}
} catch($e53295330) {
if(R.isCont($e53295330)) {
var $ss53335334 = {"from":L[682],
"go":function(anf_obj12155339) {
return $Hanf_obj22695340(anf_obj12155339,predicate4545288,stmts4535250);
}};
$e53295330.stack[R.EXN_STACKHEIGHT++] = $ss53335334;
}
if(R.isPyretException($e53295330)) {
$e53295330.pyretStack.push(L[682]);
}
throw $e53295330;
}
var $ret53355336 = $Hanf_obj22695340($z53315332,predicate4545288,stmts4535250);
++R.GAS;
return $ret53355336;
});
var anf_obj12245307 = R.makeFunction(function($underscore4605308,$underscore4615309,with_DASH_members4625310) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[678],3,arguments);
}
var anf_fun12185322 = G(list35101,"make",L[680]);
var $z53135314 = D;
var $f53195320 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(variant_DASH_base_DASH_id4495039):R.ffi.throwNonFunApp(L[679],j_DASH_id8381,[variant_DASH_base_DASH_id4495039]);
};
try {
if(--R.GAS > 0) {
$z53135314 = $f53195320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53195320,
"from":L[679]});
}
} catch($e53115312) {
if(R.isCont($e53115312)) {
var $ss53155316 = {"from":L[679],
"go":function(anf_array_val12195321) {
return $Hanf_array_val22745323(anf_array_val12195321,anf_fun12185322,j_DASH_field9979,j_DASH_id8381,predicate4545288,rt_DASH_method173657,stmts4535250,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655);
}};
$e53115312.stack[R.EXN_STACKHEIGHT++] = $ss53155316;
}
if(R.isPyretException($e53115312)) {
$e53115312.pyretStack.push(L[679]);
}
throw $e53115312;
}
var $ret53175318 = $Hanf_array_val22745323($z53135314,anf_fun12185322,j_DASH_field9979,j_DASH_id8381,predicate4545288,rt_DASH_method173657,stmts4535250,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655);
++R.GAS;
return $ret53175318;
});
var anf_arg12255301 = R.makeObject({"a-variant":anf_obj12165306,
"a-singleton-variant":anf_obj12245307});
var anf_arg12275302 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[677],0,arguments);
}
var ann_DASH_check_DASH_temp12265305 = R.throwNoBranchesMatched(L[677],("cases"));
return ann_DASH_check_DASH_temp12265305;
});
var $z52925293 = D;
var $f52985299 = function(_) {
return R.isFunction(anf_fun12135300)?anf_fun12135300.app(anf_arg12255301,anf_arg12275302):R.ffi.throwNonFunApp(L[606],anf_fun12135300,[anf_arg12255301,anf_arg12275302]);
};
try {
if(--R.GAS > 0) {
$z52925293 = $f52985299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52985299,
"from":L[606]});
}
} catch($e52905291) {
if(R.isCont($e52905291)) {
var $ss52945295 = {"from":L[606],
"go":function(ann_DASH_check_DASH_temp11875303) {
return $Hann_DASH_check_DASH_temp22755304(ann_DASH_check_DASH_temp11875303);
}};
$e52905291.stack[R.EXN_STACKHEIGHT++] = $ss52945295;
}
if(R.isPyretException($e52905291)) {
$e52905291.pyretStack.push(L[606]);
}
throw $e52905291;
}
var $ret52965297 = $Hann_DASH_check_DASH_temp22755304($z52925293);
++R.GAS;
return $ret52965297;
};
var $Hann_DASH_check_DASH_temp22755304 = function(ann_DASH_check_DASH_temp11875303) {
return ann_DASH_check_DASH_temp11875303;
};
var $Hanf_array_val22745323 = function(anf_array_val12195321,anf_fun12185322,j_DASH_field9979,j_DASH_id8381,predicate4545288,rt_DASH_method173657,stmts4535250,variant_DASH_brand_DASH_obj_DASH_id4515087,vname4484655) {
var $z53445345 = D;
var $f53505351 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(variant_DASH_brand_DASH_obj_DASH_id4515087):R.ffi.throwNonFunApp(L[683],j_DASH_id8381,[variant_DASH_brand_DASH_obj_DASH_id4515087]);
};
try {
if(--R.GAS > 0) {
$z53445345 = $f53505351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53505351,
"from":L[683]});
}
} catch($e53425343) {
if(R.isCont($e53425343)) {
var $ss53465347 = {"from":L[683],
"go":function(anf_array_val12205352) {
return $Hanf_array_val22735353(anf_array_val12205352,anf_array_val12195321,anf_fun12185322,j_DASH_field9979,predicate4545288,rt_DASH_method173657,stmts4535250,vname4484655);
}};
$e53425343.stack[R.EXN_STACKHEIGHT++] = $ss53465347;
}
if(R.isPyretException($e53425343)) {
$e53425343.pyretStack.push(L[683]);
}
throw $e53425343;
}
var $ret53485349 = $Hanf_array_val22735353($z53445345,anf_array_val12195321,anf_fun12185322,j_DASH_field9979,predicate4545288,rt_DASH_method173657,stmts4535250,vname4484655);
++R.GAS;
return $ret53485349;
};
var $Hanf_array_val22735353 = function(anf_array_val12205352,anf_array_val12195321,anf_fun12185322,j_DASH_field9979,predicate4545288,rt_DASH_method173657,stmts4535250,vname4484655) {
var $z53565357 = D;
var $f53625363 = function(_) {
return R.isFunction(anf_fun12185322)?anf_fun12185322.app([anf_array_val12195321,anf_array_val12205352]):R.ffi.throwNonFunApp(L[680],anf_fun12185322,[[anf_array_val12195321,anf_array_val12205352]]);
};
try {
if(--R.GAS > 0) {
$z53565357 = $f53625363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53625363,
"from":L[680]});
}
} catch($e53545355) {
if(R.isCont($e53545355)) {
var $ss53585359 = {"from":L[680],
"go":function(anf_arg12215364) {
return $Hanf_arg22725365(anf_arg12215364,j_DASH_field9979,predicate4545288,rt_DASH_method173657,stmts4535250,vname4484655);
}};
$e53545355.stack[R.EXN_STACKHEIGHT++] = $ss53585359;
}
if(R.isPyretException($e53545355)) {
$e53545355.pyretStack.push(L[680]);
}
throw $e53545355;
}
var $ret53605361 = $Hanf_arg22725365($z53565357,j_DASH_field9979,predicate4545288,rt_DASH_method173657,stmts4535250,vname4484655);
++R.GAS;
return $ret53605361;
};
var $Hanf_arg22725365 = function(anf_arg12215364,j_DASH_field9979,predicate4545288,rt_DASH_method173657,stmts4535250,vname4484655) {
var $z53685369 = D;
var $f53745375 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeBrandedObject"),anf_arg12215364):R.ffi.throwNonFunApp(L[684],rt_DASH_method173657.$var,[("makeBrandedObject"),anf_arg12215364]);
};
try {
if(--R.GAS > 0) {
$z53685369 = $f53745375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53745375,
"from":L[684]});
}
} catch($e53665367) {
if(R.isCont($e53665367)) {
var $ss53705371 = {"from":L[684],
"go":function(anf_arg12225376) {
return $Hanf_arg22715377(anf_arg12225376,j_DASH_field9979,predicate4545288,stmts4535250,vname4484655);
}};
$e53665367.stack[R.EXN_STACKHEIGHT++] = $ss53705371;
}
if(R.isPyretException($e53665367)) {
$e53665367.pyretStack.push(L[684]);
}
throw $e53665367;
}
var $ret53725373 = $Hanf_arg22715377($z53685369,j_DASH_field9979,predicate4545288,stmts4535250,vname4484655);
++R.GAS;
return $ret53725373;
};
var $Hanf_arg22715377 = function(anf_arg12225376,j_DASH_field9979,predicate4545288,stmts4535250,vname4484655) {
var $z53805381 = D;
var $f53865387 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(vname4484655,anf_arg12225376):R.ffi.throwNonFunApp(L[685],j_DASH_field9979,[vname4484655,anf_arg12225376]);
};
try {
if(--R.GAS > 0) {
$z53805381 = $f53865387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53865387,
"from":L[685]});
}
} catch($e53785379) {
if(R.isCont($e53785379)) {
var $ss53825383 = {"from":L[685],
"go":function(anf_obj12235388) {
return $Hanf_obj22705389(anf_obj12235388,predicate4545288,stmts4535250);
}};
$e53785379.stack[R.EXN_STACKHEIGHT++] = $ss53825383;
}
if(R.isPyretException($e53785379)) {
$e53785379.pyretStack.push(L[685]);
}
throw $e53785379;
}
var $ret53845385 = $Hanf_obj22705389($z53805381,predicate4545288,stmts4535250);
++R.GAS;
return $ret53845385;
};
var $Hanf_obj22705389 = function(anf_obj12235388,predicate4545288,stmts4535250) {
var ann_DASH_check_DASH_temp12175390 = R.makeObject({"stmts":stmts4535250,
"constructor":anf_obj12235388,
"predicate":predicate4545288});
return ann_DASH_check_DASH_temp12175390;
};
var $Hanf_obj22695340 = function(anf_obj12155339,predicate4545288,stmts4535250) {
var ann_DASH_check_DASH_temp12145391 = R.makeObject({"stmts":stmts4535250,
"constructor":anf_obj12155339,
"predicate":predicate4545288});
return ann_DASH_check_DASH_temp12145391;
};
var $Hann_DASH_check_DASH_temp22685154 = function(ann_DASH_check_DASH_temp11985153) {
return ann_DASH_check_DASH_temp11985153;
};
var $Hmember_DASH_names22674676 = function(member_DASH_names4404675,A118,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var anf_fun11295402 = G(members4394662,"map",L[691]);
var anf_arg11345403 = R.makeFunction(function(m4435406) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[687],1,arguments);
}
var anf_bracket11315421 = G(m4435406,"bind",L[690]);
var anf_bracket11325420 = G(anf_bracket11315421,"id",L[689]);
var anf_fun11335417 = G(anf_bracket11325420,"tostring",L[688]);
var $z54095410 = D;
var $f54155416 = function(_) {
return R.isFunction(anf_fun11335417)?anf_fun11335417.app():R.ffi.throwNonFunApp(L[687],anf_fun11335417,[]);
};
try {
if(--R.GAS > 0) {
$z54095410 = $f54155416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54155416,
"from":L[687]});
}
} catch($e54075408) {
if(R.isCont($e54075408)) {
var $ss54115412 = {"from":L[687],
"go":function(ann_DASH_check_DASH_temp11305418) {
return $Hann_DASH_check_DASH_temp22335419(ann_DASH_check_DASH_temp11305418);
}};
$e54075408.stack[R.EXN_STACKHEIGHT++] = $ss54115412;
}
if(R.isPyretException($e54075408)) {
$e54075408.pyretStack.push(L[687]);
}
throw $e54075408;
}
var $ret54135414 = $Hann_DASH_check_DASH_temp22335419($z54095410);
++R.GAS;
return $ret54135414;
});
var $z53945395 = D;
var $f54005401 = function(_) {
return R.isFunction(anf_fun11295402)?anf_fun11295402.app(anf_arg11345403):R.ffi.throwNonFunApp(L[686],anf_fun11295402,[anf_arg11345403]);
};
try {
if(--R.GAS > 0) {
$z53945395 = $f54005401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54005401,
"from":L[686]});
}
} catch($e53925393) {
if(R.isCont($e53925393)) {
var $ss53965397 = {"from":L[686],
"go":function(member_DASH_ids4425404) {
return $Hmember_DASH_ids22665405(member_DASH_ids4425404,A118,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e53925393.stack[R.EXN_STACKHEIGHT++] = $ss53965397;
}
if(R.isPyretException($e53925393)) {
$e53925393.pyretStack.push(L[686]);
}
throw $e53925393;
}
var $ret53985399 = $Hmember_DASH_ids22665405($z53945395,A118,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret53985399;
};
var $Hmember_DASH_ids22665405 = function(member_DASH_ids4425404,A118,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var anf_fun11355434 = G(list35101,"make",L[694]);
var anf_fun11365432 = G(member_DASH_ids4425404,"map",L[693]);
var $z54245425 = D;
var $f54305431 = function(_) {
return R.isFunction(anf_fun11365432)?anf_fun11365432.app(js_DASH_id_DASH_of162700):R.ffi.throwNonFunApp(L[692],anf_fun11365432,[js_DASH_id_DASH_of162700]);
};
try {
if(--R.GAS > 0) {
$z54245425 = $f54305431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54305431,
"from":L[692]});
}
} catch($e54225423) {
if(R.isCont($e54225423)) {
var $ss54265427 = {"from":L[692],
"go":function(anf_arg11375433) {
return $Hanf_arg22655435(anf_arg11375433,A118,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e54225423.stack[R.EXN_STACKHEIGHT++] = $ss54265427;
}
if(R.isPyretException($e54225423)) {
$e54225423.pyretStack.push(L[692]);
}
throw $e54225423;
}
var $ret54285429 = $Hanf_arg22655435($z54245425,A118,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret54285429;
};
var $Hanf_arg22655435 = function(anf_arg11375433,A118,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,l24354658,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var anf_fun11385446 = G(self419913,"get-loc",L[696]);
var $z54385439 = D;
var $f54445445 = function(_) {
return R.isFunction(anf_fun11385446)?anf_fun11385446.app(l24354658):R.ffi.throwNonFunApp(L[695],anf_fun11385446,[l24354658]);
};
try {
if(--R.GAS > 0) {
$z54385439 = $f54445445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54445445,
"from":L[695]});
}
} catch($e54365437) {
if(R.isCont($e54365437)) {
var $ss54405441 = {"from":L[695],
"go":function(anf_arg11395447) {
return $Hanf_arg22645448(anf_arg11395447,A118,anf_arg11375433,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e54365437.stack[R.EXN_STACKHEIGHT++] = $ss54405441;
}
if(R.isPyretException($e54365437)) {
$e54365437.pyretStack.push(L[695]);
}
throw $e54365437;
}
var $ret54425443 = $Hanf_arg22645448($z54385439,A118,anf_arg11375433,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret54425443;
};
var $Hanf_arg22645448 = function(anf_arg11395447,A118,anf_arg11375433,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var anf_fun11405459 = G(members4394662,"map",L[699]);
var anf_arg11425460 = R.makeFunction(function(recv_DASH_665463) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[698],1,arguments);
}
var ann_DASH_check_DASH_temp11415464 = G(recv_DASH_665463,"bind",L[698]);
return ann_DASH_check_DASH_temp11415464;
});
var $z54515452 = D;
var $f54575458 = function(_) {
return R.isFunction(anf_fun11405459)?anf_fun11405459.app(anf_arg11425460):R.ffi.throwNonFunApp(L[697],anf_fun11405459,[anf_arg11425460]);
};
try {
if(--R.GAS > 0) {
$z54515452 = $f54575458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54575458,
"from":L[697]});
}
} catch($e54495450) {
if(R.isCont($e54495450)) {
var $ss54535454 = {"from":L[697],
"go":function(anf_arg11435461) {
return $Hanf_arg22635462(anf_arg11435461,A118,anf_arg11375433,anf_arg11395447,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e54495450.stack[R.EXN_STACKHEIGHT++] = $ss54535454;
}
if(R.isPyretException($e54495450)) {
$e54495450.pyretStack.push(L[697]);
}
throw $e54495450;
}
var $ret54555456 = $Hanf_arg22635462($z54515452,A118,anf_arg11375433,anf_arg11395447,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret54555456;
};
var $Hanf_arg22635462 = function(anf_arg11435461,A118,anf_arg11375433,anf_arg11395447,anf_fun11355434,arity_DASH_check182675,base_DASH_id4364659,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var anf_arg11445476 = G(A118,"a-blank",L[703]);
var anf_fun11455477 = G(list35101,"make",L[702]);
var anf_fun11465478 = G(list35101,"make",L[701]);
var $z54675468 = D;
var $f54735474 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(base_DASH_id4364659):R.ffi.throwNonFunApp(L[700],j_DASH_id8381,[base_DASH_id4364659]);
};
try {
if(--R.GAS > 0) {
$z54675468 = $f54735474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54735474,
"from":L[700]});
}
} catch($e54655466) {
if(R.isCont($e54655466)) {
var $ss54695470 = {"from":L[700],
"go":function(anf_array_val11475475) {
return $Hanf_array_val22625479(anf_array_val11475475,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,anf_fun11465478,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e54655466.stack[R.EXN_STACKHEIGHT++] = $ss54695470;
}
if(R.isPyretException($e54655466)) {
$e54655466.pyretStack.push(L[700]);
}
throw $e54655466;
}
var $ret54715472 = $Hanf_array_val22625479($z54675468,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,anf_fun11465478,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret54715472;
};
var $Hanf_array_val22625479 = function(anf_array_val11475475,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,anf_fun11465478,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var $z54825483 = D;
var $f54885489 = function(_) {
return R.isFunction(anf_fun11465478)?anf_fun11465478.app([anf_array_val11475475]):R.ffi.throwNonFunApp(L[701],anf_fun11465478,[[anf_array_val11475475]]);
};
try {
if(--R.GAS > 0) {
$z54825483 = $f54885489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54885489,
"from":L[701]});
}
} catch($e54805481) {
if(R.isCont($e54805481)) {
var $ss54845485 = {"from":L[701],
"go":function(anf_arg11485490) {
return $Hanf_arg22615491(anf_arg11485490,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e54805481.stack[R.EXN_STACKHEIGHT++] = $ss54845485;
}
if(R.isPyretException($e54805481)) {
$e54805481.pyretStack.push(L[701]);
}
throw $e54805481;
}
var $ret54865487 = $Hanf_arg22615491($z54825483,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret54865487;
};
var $Hanf_arg22615491 = function(anf_arg11485490,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var $z54945495 = D;
var $f55005501 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("create"),anf_arg11485490):R.ffi.throwNonFunApp(L[704],rt_DASH_method173657.$var,[("create"),anf_arg11485490]);
};
try {
if(--R.GAS > 0) {
$z54945495 = $f55005501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55005501,
"from":L[704]});
}
} catch($e54925493) {
if(R.isCont($e54925493)) {
var $ss54965497 = {"from":L[704],
"go":function(anf_arg11495502) {
return $Hanf_arg22605503(anf_arg11495502,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e54925493.stack[R.EXN_STACKHEIGHT++] = $ss54965497;
}
if(R.isPyretException($e54925493)) {
$e54925493.pyretStack.push(L[704]);
}
throw $e54925493;
}
var $ret54985499 = $Hanf_arg22605503($z54945495,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret54985499;
};
var $Hanf_arg22605503 = function(anf_arg11495502,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var $z55065507 = D;
var $f55125513 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(("dict"),anf_arg11495502):R.ffi.throwNonFunApp(L[705],j_DASH_var8299,[("dict"),anf_arg11495502]);
};
try {
if(--R.GAS > 0) {
$z55065507 = $f55125513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55125513,
"from":L[705]});
}
} catch($e55045505) {
if(R.isCont($e55045505)) {
var $ss55085509 = {"from":L[705],
"go":function(anf_array_val11505514) {
return $Hanf_array_val22595515(anf_array_val11505514,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e55045505.stack[R.EXN_STACKHEIGHT++] = $ss55085509;
}
if(R.isPyretException($e55045505)) {
$e55045505.pyretStack.push(L[705]);
}
throw $e55045505;
}
var $ret55105511 = $Hanf_array_val22595515($z55065507,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret55105511;
};
var $Hanf_array_val22595515 = function(anf_array_val11505514,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,anf_fun11455477,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var $z55185519 = D;
var $f55245525 = function(_) {
return R.isFunction(anf_fun11455477)?anf_fun11455477.app([anf_array_val11505514]):R.ffi.throwNonFunApp(L[702],anf_fun11455477,[[anf_array_val11505514]]);
};
try {
if(--R.GAS > 0) {
$z55185519 = $f55245525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55245525,
"from":L[702]});
}
} catch($e55165517) {
if(R.isCont($e55165517)) {
var $ss55205521 = {"from":L[702],
"go":function(anf_arg11515526) {
return $Hanf_arg22585527(anf_arg11515526,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
}};
$e55165517.stack[R.EXN_STACKHEIGHT++] = $ss55205521;
}
if(R.isPyretException($e55165517)) {
$e55165517.pyretStack.push(L[702]);
}
throw $e55165517;
}
var $ret55225523 = $Hanf_arg22585527($z55185519,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11);
++R.GAS;
return $ret55225523;
};
var $Hanf_arg22585527 = function(anf_arg11515526,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_bracket_DASH_assign10171,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_str8993,js_DASH_id_DASH_of162700,list35101,map349103,member_DASH_ids4425404,member_DASH_names4404675,members4394662,rt_DASH_method173657,self419913,vname4384661,_plus5,raise11) {
var anf_arg11675538 = R.makeFunction(function(n4445541,m4455542,id4465543) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[706],3,arguments);
}
var cases_DASH_val675599 = G(m4455542,"member-type",L[712]);
var anf_fun11535554 = G(cases_DASH_val675599,"_match",L[707]);
var anf_obj11595560 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[710],0,arguments);
}
var $z55895590 = D;
var $f55955596 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("dict")):R.ffi.throwNonFunApp(L[711],j_DASH_id8381,[("dict")]);
};
try {
if(--R.GAS > 0) {
$z55895590 = $f55955596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55955596,
"from":L[711]});
}
} catch($e55875588) {
if(R.isCont($e55875588)) {
var $ss55915592 = {"from":L[711],
"go":function(anf_arg11555597) {
return $Hanf_arg22385598(anf_arg11555597,id4465543,j_DASH_bracket_DASH_assign10171,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,n4445541);
}};
$e55875588.stack[R.EXN_STACKHEIGHT++] = $ss55915592;
}
if(R.isPyretException($e55875588)) {
$e55875588.pyretStack.push(L[711]);
}
throw $e55875588;
}
var $ret55935594 = $Hanf_arg22385598($z55895590,id4465543,j_DASH_bracket_DASH_assign10171,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,n4445541);
++R.GAS;
return $ret55935594;
});
var anf_obj11615561 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[709],0,arguments);
}
var $z55775578 = D;
var $f55835584 = function(_) {
return R.isFunction(raise11)?raise11.app(("Cannot handle cyclic fields yet")):R.ffi.throwNonFunApp(L[709],raise11,[("Cannot handle cyclic fields yet")]);
};
try {
if(--R.GAS > 0) {
$z55775578 = $f55835584();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55835584,
"from":L[709]});
}
} catch($e55755576) {
if(R.isCont($e55755576)) {
var $ss55795580 = {"from":L[709],
"go":function(ann_DASH_check_DASH_temp11605585) {
return $Hann_DASH_check_DASH_temp22395586(ann_DASH_check_DASH_temp11605585);
}};
$e55755576.stack[R.EXN_STACKHEIGHT++] = $ss55795580;
}
if(R.isPyretException($e55755576)) {
$e55755576.pyretStack.push(L[709]);
}
throw $e55755576;
}
var $ret55815582 = $Hann_DASH_check_DASH_temp22395586($z55775578);
++R.GAS;
return $ret55815582;
});
var anf_obj11635562 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[708],0,arguments);
}
var $z55655566 = D;
var $f55715572 = function(_) {
return R.isFunction(raise11)?raise11.app(("Cannot handle mutable fields yet")):R.ffi.throwNonFunApp(L[708],raise11,[("Cannot handle mutable fields yet")]);
};
try {
if(--R.GAS > 0) {
$z55655566 = $f55715572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55715572,
"from":L[708]});
}
} catch($e55635564) {
if(R.isCont($e55635564)) {
var $ss55675568 = {"from":L[708],
"go":function(ann_DASH_check_DASH_temp11625573) {
return $Hann_DASH_check_DASH_temp22405574(ann_DASH_check_DASH_temp11625573);
}};
$e55635564.stack[R.EXN_STACKHEIGHT++] = $ss55675568;
}
if(R.isPyretException($e55635564)) {
$e55635564.pyretStack.push(L[708]);
}
throw $e55635564;
}
var $ret55695570 = $Hann_DASH_check_DASH_temp22405574($z55655566);
++R.GAS;
return $ret55695570;
});
var anf_arg11645555 = R.makeObject({"a-normal":anf_obj11595560,
"a-cyclic":anf_obj11615561,
"a-mutable":anf_obj11635562});
var anf_arg11665556 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[707],0,arguments);
}
var ann_DASH_check_DASH_temp11655559 = R.throwNoBranchesMatched(L[707],("cases"));
return ann_DASH_check_DASH_temp11655559;
});
var $z55465547 = D;
var $f55525553 = function(_) {
return R.isFunction(anf_fun11535554)?anf_fun11535554.app(anf_arg11645555,anf_arg11665556):R.ffi.throwNonFunApp(L[706],anf_fun11535554,[anf_arg11645555,anf_arg11665556]);
};
try {
if(--R.GAS > 0) {
$z55465547 = $f55525553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55525553,
"from":L[706]});
}
} catch($e55445545) {
if(R.isCont($e55445545)) {
var $ss55485549 = {"from":L[706],
"go":function(ann_DASH_check_DASH_temp11525557) {
return $Hann_DASH_check_DASH_temp22415558(ann_DASH_check_DASH_temp11525557);
}};
$e55445545.stack[R.EXN_STACKHEIGHT++] = $ss55485549;
}
if(R.isPyretException($e55445545)) {
$e55445545.pyretStack.push(L[706]);
}
throw $e55445545;
}
var $ret55505551 = $Hann_DASH_check_DASH_temp22415558($z55465547);
++R.GAS;
return $ret55505551;
});
var $z55305531 = D;
var $f55365537 = function(_) {
return R.isFunction(map349103)?map349103.app(anf_arg11675538,member_DASH_names4404675,members4394662,member_DASH_ids4425404):R.ffi.throwNonFunApp(L[706],map349103,[anf_arg11675538,member_DASH_names4404675,members4394662,member_DASH_ids4425404]);
};
try {
if(--R.GAS > 0) {
$z55305531 = $f55365537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55365537,
"from":L[706]});
}
} catch($e55285529) {
if(R.isCont($e55285529)) {
var $ss55325533 = {"from":L[706],
"go":function(anf_arg11685539) {
return $Hanf_arg22575540(anf_arg11685539,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11515526,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
}};
$e55285529.stack[R.EXN_STACKHEIGHT++] = $ss55325533;
}
if(R.isPyretException($e55285529)) {
$e55285529.pyretStack.push(L[706]);
}
throw $e55285529;
}
var $ret55345535 = $Hanf_arg22575540($z55305531,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11515526,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
++R.GAS;
return $ret55345535;
};
var $Hanf_arg22575540 = function(anf_arg11685539,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11515526,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5) {
var $z56025603 = D;
var $f56085609 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg11515526,anf_arg11685539):R.ffi.throwNonFunApp(L[713],_plus5,[anf_arg11515526,anf_arg11685539]);
};
try {
if(--R.GAS > 0) {
$z56025603 = $f56085609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56085609,
"from":L[713]});
}
} catch($e56005601) {
if(R.isCont($e56005601)) {
var $ss56045605 = {"from":L[713],
"go":function(anf_arg11695610) {
return $Hanf_arg22565611(anf_arg11695610,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
}};
$e56005601.stack[R.EXN_STACKHEIGHT++] = $ss56045605;
}
if(R.isPyretException($e56005601)) {
$e56005601.pyretStack.push(L[713]);
}
throw $e56005601;
}
var $ret56065607 = $Hanf_arg22565611($z56025603,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
++R.GAS;
return $ret56065607;
};
var $Hanf_arg22565611 = function(anf_arg11695610,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5) {
var anf_fun11705623 = G(list35101,"make",L[716]);
var anf_fun11715624 = G(list35101,"make",L[715]);
var $z56145615 = D;
var $f56205621 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("dict")):R.ffi.throwNonFunApp(L[714],j_DASH_id8381,[("dict")]);
};
try {
if(--R.GAS > 0) {
$z56145615 = $f56205621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56205621,
"from":L[714]});
}
} catch($e56125613) {
if(R.isCont($e56125613)) {
var $ss56165617 = {"from":L[714],
"go":function(anf_array_val11725622) {
return $Hanf_array_val22555625(anf_array_val11725622,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,anf_fun11715624,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
}};
$e56125613.stack[R.EXN_STACKHEIGHT++] = $ss56165617;
}
if(R.isPyretException($e56125613)) {
$e56125613.pyretStack.push(L[714]);
}
throw $e56125613;
}
var $ret56185619 = $Hanf_array_val22555625($z56145615,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,anf_fun11715624,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
++R.GAS;
return $ret56185619;
};
var $Hanf_array_val22555625 = function(anf_array_val11725622,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,anf_fun11715624,arity_DASH_check182675,brands_DASH_id4374660,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5) {
var $z56285629 = D;
var $f56345635 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(brands_DASH_id4374660):R.ffi.throwNonFunApp(L[717],j_DASH_id8381,[brands_DASH_id4374660]);
};
try {
if(--R.GAS > 0) {
$z56285629 = $f56345635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56345635,
"from":L[717]});
}
} catch($e56265627) {
if(R.isCont($e56265627)) {
var $ss56305631 = {"from":L[717],
"go":function(anf_array_val11735636) {
return $Hanf_array_val22545637(anf_array_val11735636,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_array_val11725622,anf_fun11355434,anf_fun11705623,anf_fun11715624,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
}};
$e56265627.stack[R.EXN_STACKHEIGHT++] = $ss56305631;
}
if(R.isPyretException($e56265627)) {
$e56265627.pyretStack.push(L[717]);
}
throw $e56265627;
}
var $ret56325633 = $Hanf_array_val22545637($z56285629,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_array_val11725622,anf_fun11355434,anf_fun11705623,anf_fun11715624,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
++R.GAS;
return $ret56325633;
};
var $Hanf_array_val22545637 = function(anf_array_val11735636,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_array_val11725622,anf_fun11355434,anf_fun11705623,anf_fun11715624,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5) {
var $z56405641 = D;
var $f56465647 = function(_) {
return R.isFunction(anf_fun11715624)?anf_fun11715624.app([anf_array_val11725622,anf_array_val11735636]):R.ffi.throwNonFunApp(L[715],anf_fun11715624,[[anf_array_val11725622,anf_array_val11735636]]);
};
try {
if(--R.GAS > 0) {
$z56405641 = $f56465647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56465647,
"from":L[715]});
}
} catch($e56385639) {
if(R.isCont($e56385639)) {
var $ss56425643 = {"from":L[715],
"go":function(anf_arg11745648) {
return $Hanf_arg22535649(anf_arg11745648,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
}};
$e56385639.stack[R.EXN_STACKHEIGHT++] = $ss56425643;
}
if(R.isPyretException($e56385639)) {
$e56385639.pyretStack.push(L[715]);
}
throw $e56385639;
}
var $ret56445645 = $Hanf_arg22535649($z56405641,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
++R.GAS;
return $ret56445645;
};
var $Hanf_arg22535649 = function(anf_arg11745648,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5) {
var $z56525653 = D;
var $f56585659 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeBrandedObject"),anf_arg11745648):R.ffi.throwNonFunApp(L[718],rt_DASH_method173657.$var,[("makeBrandedObject"),anf_arg11745648]);
};
try {
if(--R.GAS > 0) {
$z56525653 = $f56585659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56585659,
"from":L[718]});
}
} catch($e56505651) {
if(R.isCont($e56505651)) {
var $ss56545655 = {"from":L[718],
"go":function(anf_arg11755660) {
return $Hanf_arg22525661(anf_arg11755660,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
}};
$e56505651.stack[R.EXN_STACKHEIGHT++] = $ss56545655;
}
if(R.isPyretException($e56505651)) {
$e56505651.pyretStack.push(L[718]);
}
throw $e56505651;
}
var $ret56565657 = $Hanf_arg22525661($z56525653,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
++R.GAS;
return $ret56565657;
};
var $Hanf_arg22525661 = function(anf_arg11755660,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5) {
var $z56645665 = D;
var $f56705671 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg11755660):R.ffi.throwNonFunApp(L[719],j_DASH_return9092,[anf_arg11755660]);
};
try {
if(--R.GAS > 0) {
$z56645665 = $f56705671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56705671,
"from":L[719]});
}
} catch($e56625663) {
if(R.isCont($e56625663)) {
var $ss56665667 = {"from":L[719],
"go":function(anf_array_val11765672) {
return $Hanf_array_val22515673(anf_array_val11765672,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
}};
$e56625663.stack[R.EXN_STACKHEIGHT++] = $ss56665667;
}
if(R.isPyretException($e56625663)) {
$e56625663.pyretStack.push(L[719]);
}
throw $e56625663;
}
var $ret56685669 = $Hanf_array_val22515673($z56645665,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
++R.GAS;
return $ret56685669;
};
var $Hanf_array_val22515673 = function(anf_array_val11765672,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,anf_fun11705623,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5) {
var $z56765677 = D;
var $f56825683 = function(_) {
return R.isFunction(anf_fun11705623)?anf_fun11705623.app([anf_array_val11765672]):R.ffi.throwNonFunApp(L[716],anf_fun11705623,[[anf_array_val11765672]]);
};
try {
if(--R.GAS > 0) {
$z56765677 = $f56825683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56825683,
"from":L[716]});
}
} catch($e56745675) {
if(R.isCont($e56745675)) {
var $ss56785679 = {"from":L[716],
"go":function(anf_arg11775684) {
return $Hanf_arg22505685(anf_arg11775684,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
}};
$e56745675.stack[R.EXN_STACKHEIGHT++] = $ss56785679;
}
if(R.isPyretException($e56745675)) {
$e56745675.pyretStack.push(L[716]);
}
throw $e56745675;
}
var $ret56805681 = $Hanf_arg22505685($z56765677,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5);
++R.GAS;
return $ret56805681;
};
var $Hanf_arg22505685 = function(anf_arg11775684,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_arg11695610,anf_fun11355434,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661,_plus5) {
var $z56885689 = D;
var $f56945695 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg11695610,anf_arg11775684):R.ffi.throwNonFunApp(L[713],_plus5,[anf_arg11695610,anf_arg11775684]);
};
try {
if(--R.GAS > 0) {
$z56885689 = $f56945695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56945695,
"from":L[713]});
}
} catch($e56865687) {
if(R.isCont($e56865687)) {
var $ss56905691 = {"from":L[713],
"go":function(anf_arg11785696) {
return $Hanf_arg22495697(anf_arg11785696,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661);
}};
$e56865687.stack[R.EXN_STACKHEIGHT++] = $ss56905691;
}
if(R.isPyretException($e56865687)) {
$e56865687.pyretStack.push(L[713]);
}
throw $e56865687;
}
var $ret56925693 = $Hanf_arg22495697($z56885689,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661);
++R.GAS;
return $ret56925693;
};
var $Hanf_arg22495697 = function(anf_arg11785696,anf_arg11375433,anf_arg11395447,anf_arg11435461,anf_arg11445476,anf_fun11355434,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,self419913,vname4384661) {
var $z57005701 = D;
var $f57065707 = function(_) {
return R.isFunction(contract_DASH_checks183677.$var)?contract_DASH_checks183677.$var.app(anf_arg11435461,anf_arg11445476,anf_arg11785696,self419913):R.ffi.throwNonFunApp(L[720],contract_DASH_checks183677.$var,[anf_arg11435461,anf_arg11445476,anf_arg11785696,self419913]);
};
try {
if(--R.GAS > 0) {
$z57005701 = $f57065707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57065707,
"from":L[720]});
}
} catch($e56985699) {
if(R.isCont($e56985699)) {
var $ss57025703 = {"from":L[720],
"go":function(anf_arg11795708) {
return $Hanf_arg22485709(anf_arg11795708,anf_arg11375433,anf_arg11395447,anf_fun11355434,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,vname4384661);
}};
$e56985699.stack[R.EXN_STACKHEIGHT++] = $ss57025703;
}
if(R.isPyretException($e56985699)) {
$e56985699.pyretStack.push(L[720]);
}
throw $e56985699;
}
var $ret57045705 = $Hanf_arg22485709($z57005701,anf_arg11375433,anf_arg11395447,anf_fun11355434,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,vname4384661);
++R.GAS;
return $ret57045705;
};
var $Hanf_arg22485709 = function(anf_arg11795708,anf_arg11375433,anf_arg11395447,anf_fun11355434,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,member_DASH_names4404675,rt_DASH_method173657,vname4384661) {
var anf_fun11805720 = G(member_DASH_names4404675,"length",L[722]);
var $z57125713 = D;
var $f57185719 = function(_) {
return R.isFunction(anf_fun11805720)?anf_fun11805720.app():R.ffi.throwNonFunApp(L[721],anf_fun11805720,[]);
};
try {
if(--R.GAS > 0) {
$z57125713 = $f57185719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57185719,
"from":L[721]});
}
} catch($e57105711) {
if(R.isCont($e57105711)) {
var $ss57145715 = {"from":L[721],
"go":function(anf_arg11815721) {
return $Hanf_arg22475722(anf_arg11815721,anf_arg11375433,anf_arg11395447,anf_arg11795708,anf_fun11355434,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,rt_DASH_method173657,vname4384661);
}};
$e57105711.stack[R.EXN_STACKHEIGHT++] = $ss57145715;
}
if(R.isPyretException($e57105711)) {
$e57105711.pyretStack.push(L[721]);
}
throw $e57105711;
}
var $ret57165717 = $Hanf_arg22475722($z57125713,anf_arg11375433,anf_arg11395447,anf_arg11795708,anf_fun11355434,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,rt_DASH_method173657,vname4384661);
++R.GAS;
return $ret57165717;
};
var $Hanf_arg22475722 = function(anf_arg11815721,anf_arg11375433,anf_arg11395447,anf_arg11795708,anf_fun11355434,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,rt_DASH_method173657,vname4384661) {
var $z57255726 = D;
var $f57315732 = function(_) {
return R.isFunction(arity_DASH_check182675.$var)?arity_DASH_check182675.$var.app(anf_arg11395447,anf_arg11795708,anf_arg11815721):R.ffi.throwNonFunApp(L[723],arity_DASH_check182675.$var,[anf_arg11395447,anf_arg11795708,anf_arg11815721]);
};
try {
if(--R.GAS > 0) {
$z57255726 = $f57315732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57315732,
"from":L[723]});
}
} catch($e57235724) {
if(R.isCont($e57235724)) {
var $ss57275728 = {"from":L[723],
"go":function(anf_arg11825733) {
return $Hanf_arg22465734(anf_arg11825733,anf_arg11375433,anf_fun11355434,j_DASH_field9979,j_DASH_fun8180,rt_DASH_method173657,vname4384661);
}};
$e57235724.stack[R.EXN_STACKHEIGHT++] = $ss57275728;
}
if(R.isPyretException($e57235724)) {
$e57235724.pyretStack.push(L[723]);
}
throw $e57235724;
}
var $ret57295730 = $Hanf_arg22465734($z57255726,anf_arg11375433,anf_fun11355434,j_DASH_field9979,j_DASH_fun8180,rt_DASH_method173657,vname4384661);
++R.GAS;
return $ret57295730;
};
var $Hanf_arg22465734 = function(anf_arg11825733,anf_arg11375433,anf_fun11355434,j_DASH_field9979,j_DASH_fun8180,rt_DASH_method173657,vname4384661) {
var $z57375738 = D;
var $f57435744 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg11375433,anf_arg11825733):R.ffi.throwNonFunApp(L[724],j_DASH_fun8180,[anf_arg11375433,anf_arg11825733]);
};
try {
if(--R.GAS > 0) {
$z57375738 = $f57435744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57435744,
"from":L[724]});
}
} catch($e57355736) {
if(R.isCont($e57355736)) {
var $ss57395740 = {"from":L[724],
"go":function(anf_array_val11835745) {
return $Hanf_array_val22455746(anf_array_val11835745,anf_fun11355434,j_DASH_field9979,rt_DASH_method173657,vname4384661);
}};
$e57355736.stack[R.EXN_STACKHEIGHT++] = $ss57395740;
}
if(R.isPyretException($e57355736)) {
$e57355736.pyretStack.push(L[724]);
}
throw $e57355736;
}
var $ret57415742 = $Hanf_array_val22455746($z57375738,anf_fun11355434,j_DASH_field9979,rt_DASH_method173657,vname4384661);
++R.GAS;
return $ret57415742;
};
var $Hanf_array_val22455746 = function(anf_array_val11835745,anf_fun11355434,j_DASH_field9979,rt_DASH_method173657,vname4384661) {
var $z57495750 = D;
var $f57555756 = function(_) {
return R.isFunction(anf_fun11355434)?anf_fun11355434.app([anf_array_val11835745]):R.ffi.throwNonFunApp(L[694],anf_fun11355434,[[anf_array_val11835745]]);
};
try {
if(--R.GAS > 0) {
$z57495750 = $f57555756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57555756,
"from":L[694]});
}
} catch($e57475748) {
if(R.isCont($e57475748)) {
var $ss57515752 = {"from":L[694],
"go":function(anf_arg11845757) {
return $Hanf_arg22445758(anf_arg11845757,j_DASH_field9979,rt_DASH_method173657,vname4384661);
}};
$e57475748.stack[R.EXN_STACKHEIGHT++] = $ss57515752;
}
if(R.isPyretException($e57475748)) {
$e57475748.pyretStack.push(L[694]);
}
throw $e57475748;
}
var $ret57535754 = $Hanf_arg22445758($z57495750,j_DASH_field9979,rt_DASH_method173657,vname4384661);
++R.GAS;
return $ret57535754;
};
var $Hanf_arg22445758 = function(anf_arg11845757,j_DASH_field9979,rt_DASH_method173657,vname4384661) {
var $z57615762 = D;
var $f57675768 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeFunction"),anf_arg11845757):R.ffi.throwNonFunApp(L[725],rt_DASH_method173657.$var,[("makeFunction"),anf_arg11845757]);
};
try {
if(--R.GAS > 0) {
$z57615762 = $f57675768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57675768,
"from":L[725]});
}
} catch($e57595760) {
if(R.isCont($e57595760)) {
var $ss57635764 = {"from":L[725],
"go":function(anf_arg11855769) {
return $Hanf_arg22435770(anf_arg11855769,j_DASH_field9979,vname4384661);
}};
$e57595760.stack[R.EXN_STACKHEIGHT++] = $ss57635764;
}
if(R.isPyretException($e57595760)) {
$e57595760.pyretStack.push(L[725]);
}
throw $e57595760;
}
var $ret57655766 = $Hanf_arg22435770($z57615762,j_DASH_field9979,vname4384661);
++R.GAS;
return $ret57655766;
};
var $Hanf_arg22435770 = function(anf_arg11855769,j_DASH_field9979,vname4384661) {
var $z57735774 = D;
var $f57795780 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(vname4384661,anf_arg11855769):R.ffi.throwNonFunApp(L[610],j_DASH_field9979,[vname4384661,anf_arg11855769]);
};
try {
if(--R.GAS > 0) {
$z57735774 = $f57795780();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57795780,
"from":L[610]});
}
} catch($e57715772) {
if(R.isCont($e57715772)) {
var $ss57755776 = {"from":L[610],
"go":function(ann_DASH_check_DASH_temp11225781) {
return $Hann_DASH_check_DASH_temp22425782(ann_DASH_check_DASH_temp11225781);
}};
$e57715772.stack[R.EXN_STACKHEIGHT++] = $ss57755776;
}
if(R.isPyretException($e57715772)) {
$e57715772.pyretStack.push(L[610]);
}
throw $e57715772;
}
var $ret57775778 = $Hann_DASH_check_DASH_temp22425782($z57735774);
++R.GAS;
return $ret57775778;
};
var $Hann_DASH_check_DASH_temp22425782 = function(ann_DASH_check_DASH_temp11225781) {
return ann_DASH_check_DASH_temp11225781;
};
var $Hann_DASH_check_DASH_temp22415558 = function(ann_DASH_check_DASH_temp11525557) {
return ann_DASH_check_DASH_temp11525557;
};
var $Hann_DASH_check_DASH_temp22405574 = function(ann_DASH_check_DASH_temp11625573) {
return ann_DASH_check_DASH_temp11625573;
};
var $Hann_DASH_check_DASH_temp22395586 = function(ann_DASH_check_DASH_temp11605585) {
return ann_DASH_check_DASH_temp11605585;
};
var $Hanf_arg22385598 = function(anf_arg11555597,id4465543,j_DASH_bracket_DASH_assign10171,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,n4445541) {
var $z57855786 = D;
var $f57915792 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(n4445541):R.ffi.throwNonFunApp(L[726],j_DASH_str8993,[n4445541]);
};
try {
if(--R.GAS > 0) {
$z57855786 = $f57915792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57915792,
"from":L[726]});
}
} catch($e57835784) {
if(R.isCont($e57835784)) {
var $ss57875788 = {"from":L[726],
"go":function(anf_arg11565793) {
return $Hanf_arg22375794(anf_arg11565793,anf_arg11555597,id4465543,j_DASH_bracket_DASH_assign10171,j_DASH_id8381,js_DASH_id_DASH_of162700);
}};
$e57835784.stack[R.EXN_STACKHEIGHT++] = $ss57875788;
}
if(R.isPyretException($e57835784)) {
$e57835784.pyretStack.push(L[726]);
}
throw $e57835784;
}
var $ret57895790 = $Hanf_arg22375794($z57855786,anf_arg11555597,id4465543,j_DASH_bracket_DASH_assign10171,j_DASH_id8381,js_DASH_id_DASH_of162700);
++R.GAS;
return $ret57895790;
};
var $Hanf_arg22375794 = function(anf_arg11565793,anf_arg11555597,id4465543,j_DASH_bracket_DASH_assign10171,j_DASH_id8381,js_DASH_id_DASH_of162700) {
var $z57975798 = D;
var $f58035804 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(id4465543):R.ffi.throwNonFunApp(L[727],js_DASH_id_DASH_of162700,[id4465543]);
};
try {
if(--R.GAS > 0) {
$z57975798 = $f58035804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58035804,
"from":L[727]});
}
} catch($e57955796) {
if(R.isCont($e57955796)) {
var $ss57995800 = {"from":L[727],
"go":function(anf_arg11575805) {
return $Hanf_arg22365806(anf_arg11575805,anf_arg11555597,anf_arg11565793,j_DASH_bracket_DASH_assign10171,j_DASH_id8381);
}};
$e57955796.stack[R.EXN_STACKHEIGHT++] = $ss57995800;
}
if(R.isPyretException($e57955796)) {
$e57955796.pyretStack.push(L[727]);
}
throw $e57955796;
}
var $ret58015802 = $Hanf_arg22365806($z57975798,anf_arg11555597,anf_arg11565793,j_DASH_bracket_DASH_assign10171,j_DASH_id8381);
++R.GAS;
return $ret58015802;
};
var $Hanf_arg22365806 = function(anf_arg11575805,anf_arg11555597,anf_arg11565793,j_DASH_bracket_DASH_assign10171,j_DASH_id8381) {
var $z58095810 = D;
var $f58155816 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg11575805):R.ffi.throwNonFunApp(L[728],j_DASH_id8381,[anf_arg11575805]);
};
try {
if(--R.GAS > 0) {
$z58095810 = $f58155816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58155816,
"from":L[728]});
}
} catch($e58075808) {
if(R.isCont($e58075808)) {
var $ss58115812 = {"from":L[728],
"go":function(anf_arg11585817) {
return $Hanf_arg22355818(anf_arg11585817,anf_arg11555597,anf_arg11565793,j_DASH_bracket_DASH_assign10171);
}};
$e58075808.stack[R.EXN_STACKHEIGHT++] = $ss58115812;
}
if(R.isPyretException($e58075808)) {
$e58075808.pyretStack.push(L[728]);
}
throw $e58075808;
}
var $ret58135814 = $Hanf_arg22355818($z58095810,anf_arg11555597,anf_arg11565793,j_DASH_bracket_DASH_assign10171);
++R.GAS;
return $ret58135814;
};
var $Hanf_arg22355818 = function(anf_arg11585817,anf_arg11555597,anf_arg11565793,j_DASH_bracket_DASH_assign10171) {
var $z58215822 = D;
var $f58275828 = function(_) {
return R.isFunction(j_DASH_bracket_DASH_assign10171)?j_DASH_bracket_DASH_assign10171.app(anf_arg11555597,anf_arg11565793,anf_arg11585817):R.ffi.throwNonFunApp(L[710],j_DASH_bracket_DASH_assign10171,[anf_arg11555597,anf_arg11565793,anf_arg11585817]);
};
try {
if(--R.GAS > 0) {
$z58215822 = $f58275828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58275828,
"from":L[710]});
}
} catch($e58195820) {
if(R.isCont($e58195820)) {
var $ss58235824 = {"from":L[710],
"go":function(ann_DASH_check_DASH_temp11545829) {
return $Hann_DASH_check_DASH_temp22345830(ann_DASH_check_DASH_temp11545829);
}};
$e58195820.stack[R.EXN_STACKHEIGHT++] = $ss58235824;
}
if(R.isPyretException($e58195820)) {
$e58195820.pyretStack.push(L[710]);
}
throw $e58195820;
}
var $ret58255826 = $Hann_DASH_check_DASH_temp22345830($z58215822);
++R.GAS;
return $ret58255826;
};
var $Hann_DASH_check_DASH_temp22345830 = function(ann_DASH_check_DASH_temp11545829) {
return ann_DASH_check_DASH_temp11545829;
};
var $Hann_DASH_check_DASH_temp22335419 = function(ann_DASH_check_DASH_temp11305418) {
return ann_DASH_check_DASH_temp11305418;
};
var $Hann_DASH_check_DASH_temp22324690 = function(ann_DASH_check_DASH_temp11244689) {
return ann_DASH_check_DASH_temp11244689;
};
var $Hanf_arg22314709 = function(anf_arg11044707,anf_fun11024708,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,loc4324693,pred_DASH_name4344695,rt_DASH_method173657,self419913) {
var anf_fun11055841 = G(self419913,"get-loc",L[730]);
var $z58335834 = D;
var $f58395840 = function(_) {
return R.isFunction(anf_fun11055841)?anf_fun11055841.app(loc4324693):R.ffi.throwNonFunApp(L[729],anf_fun11055841,[loc4324693]);
};
try {
if(--R.GAS > 0) {
$z58335834 = $f58395840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58395840,
"from":L[729]});
}
} catch($e58315832) {
if(R.isCont($e58315832)) {
var $ss58355836 = {"from":L[729],
"go":function(anf_arg11065842) {
return $Hanf_arg22305843(anf_arg11065842,anf_arg11044707,anf_fun11024708,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e58315832.stack[R.EXN_STACKHEIGHT++] = $ss58355836;
}
if(R.isPyretException($e58315832)) {
$e58315832.pyretStack.push(L[729]);
}
throw $e58315832;
}
var $ret58375838 = $Hanf_arg22305843($z58335834,anf_arg11044707,anf_fun11024708,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret58375838;
};
var $Hanf_arg22305843 = function(anf_arg11065842,anf_arg11044707,anf_fun11024708,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,list35101,pred_DASH_name4344695,rt_DASH_method173657) {
var anf_fun11075855 = G(list35101,"make",L[734]);
var anf_fun11085856 = G(list35101,"make",L[733]);
var anf_fun11095857 = G(list35101,"make",L[732]);
var $z58465847 = D;
var $f58525853 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("val")):R.ffi.throwNonFunApp(L[731],j_DASH_id8381,[("val")]);
};
try {
if(--R.GAS > 0) {
$z58465847 = $f58525853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58525853,
"from":L[731]});
}
} catch($e58445845) {
if(R.isCont($e58445845)) {
var $ss58485849 = {"from":L[731],
"go":function(anf_array_val11105854) {
return $Hanf_array_val22295858(anf_array_val11105854,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,anf_fun11095857,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e58445845.stack[R.EXN_STACKHEIGHT++] = $ss58485849;
}
if(R.isPyretException($e58445845)) {
$e58445845.pyretStack.push(L[731]);
}
throw $e58445845;
}
var $ret58505851 = $Hanf_array_val22295858($z58465847,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,anf_fun11095857,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret58505851;
};
var $Hanf_array_val22295858 = function(anf_array_val11105854,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,anf_fun11095857,arity_DASH_check182675,b4334694,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657) {
var $z58615862 = D;
var $f58675868 = function(_) {
return R.isFunction(anf_fun11095857)?anf_fun11095857.app([anf_array_val11105854,b4334694]):R.ffi.throwNonFunApp(L[732],anf_fun11095857,[[anf_array_val11105854,b4334694]]);
};
try {
if(--R.GAS > 0) {
$z58615862 = $f58675868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58675868,
"from":L[732]});
}
} catch($e58595860) {
if(R.isCont($e58595860)) {
var $ss58635864 = {"from":L[732],
"go":function(anf_arg11115869) {
return $Hanf_arg22285870(anf_arg11115869,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e58595860.stack[R.EXN_STACKHEIGHT++] = $ss58635864;
}
if(R.isPyretException($e58595860)) {
$e58595860.pyretStack.push(L[732]);
}
throw $e58595860;
}
var $ret58655866 = $Hanf_arg22285870($z58615862,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret58655866;
};
var $Hanf_arg22285870 = function(anf_arg11115869,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657) {
var $z58735874 = D;
var $f58795880 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("hasBrand"),anf_arg11115869):R.ffi.throwNonFunApp(L[735],rt_DASH_method173657.$var,[("hasBrand"),anf_arg11115869]);
};
try {
if(--R.GAS > 0) {
$z58735874 = $f58795880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58795880,
"from":L[735]});
}
} catch($e58715872) {
if(R.isCont($e58715872)) {
var $ss58755876 = {"from":L[735],
"go":function(anf_array_val11125881) {
return $Hanf_array_val22275882(anf_array_val11125881,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e58715872.stack[R.EXN_STACKHEIGHT++] = $ss58755876;
}
if(R.isPyretException($e58715872)) {
$e58715872.pyretStack.push(L[735]);
}
throw $e58715872;
}
var $ret58775878 = $Hanf_array_val22275882($z58735874,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret58775878;
};
var $Hanf_array_val22275882 = function(anf_array_val11125881,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,anf_fun11085856,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657) {
var $z58855886 = D;
var $f58915892 = function(_) {
return R.isFunction(anf_fun11085856)?anf_fun11085856.app([anf_array_val11125881]):R.ffi.throwNonFunApp(L[733],anf_fun11085856,[[anf_array_val11125881]]);
};
try {
if(--R.GAS > 0) {
$z58855886 = $f58915892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58915892,
"from":L[733]});
}
} catch($e58835884) {
if(R.isCont($e58835884)) {
var $ss58875888 = {"from":L[733],
"go":function(anf_arg11135893) {
return $Hanf_arg22265894(anf_arg11135893,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e58835884.stack[R.EXN_STACKHEIGHT++] = $ss58875888;
}
if(R.isPyretException($e58835884)) {
$e58835884.pyretStack.push(L[733]);
}
throw $e58835884;
}
var $ret58895890 = $Hanf_arg22265894($z58855886,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret58895890;
};
var $Hanf_arg22265894 = function(anf_arg11135893,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657) {
var $z58975898 = D;
var $f59035904 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeBoolean"),anf_arg11135893):R.ffi.throwNonFunApp(L[736],rt_DASH_method173657.$var,[("makeBoolean"),anf_arg11135893]);
};
try {
if(--R.GAS > 0) {
$z58975898 = $f59035904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59035904,
"from":L[736]});
}
} catch($e58955896) {
if(R.isCont($e58955896)) {
var $ss58995900 = {"from":L[736],
"go":function(anf_arg11145905) {
return $Hanf_arg22255906(anf_arg11145905,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e58955896.stack[R.EXN_STACKHEIGHT++] = $ss58995900;
}
if(R.isPyretException($e58955896)) {
$e58955896.pyretStack.push(L[736]);
}
throw $e58955896;
}
var $ret59015902 = $Hanf_arg22255906($z58975898,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret59015902;
};
var $Hanf_arg22255906 = function(anf_arg11145905,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,j_DASH_return9092,pred_DASH_name4344695,rt_DASH_method173657) {
var $z59095910 = D;
var $f59155916 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg11145905):R.ffi.throwNonFunApp(L[737],j_DASH_return9092,[anf_arg11145905]);
};
try {
if(--R.GAS > 0) {
$z59095910 = $f59155916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59155916,
"from":L[737]});
}
} catch($e59075908) {
if(R.isCont($e59075908)) {
var $ss59115912 = {"from":L[737],
"go":function(anf_array_val11155917) {
return $Hanf_array_val22245918(anf_array_val11155917,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e59075908.stack[R.EXN_STACKHEIGHT++] = $ss59115912;
}
if(R.isPyretException($e59075908)) {
$e59075908.pyretStack.push(L[737]);
}
throw $e59075908;
}
var $ret59135914 = $Hanf_array_val22245918($z59095910,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret59135914;
};
var $Hanf_array_val22245918 = function(anf_array_val11155917,anf_arg11044707,anf_arg11065842,anf_fun11024708,anf_fun11075855,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657) {
var $z59215922 = D;
var $f59275928 = function(_) {
return R.isFunction(anf_fun11075855)?anf_fun11075855.app([anf_array_val11155917]):R.ffi.throwNonFunApp(L[734],anf_fun11075855,[[anf_array_val11155917]]);
};
try {
if(--R.GAS > 0) {
$z59215922 = $f59275928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59275928,
"from":L[734]});
}
} catch($e59195920) {
if(R.isCont($e59195920)) {
var $ss59235924 = {"from":L[734],
"go":function(anf_arg11165929) {
return $Hanf_arg22235930(anf_arg11165929,anf_arg11044707,anf_arg11065842,anf_fun11024708,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e59195920.stack[R.EXN_STACKHEIGHT++] = $ss59235924;
}
if(R.isPyretException($e59195920)) {
$e59195920.pyretStack.push(L[734]);
}
throw $e59195920;
}
var $ret59255926 = $Hanf_arg22235930($z59215922,anf_arg11044707,anf_arg11065842,anf_fun11024708,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret59255926;
};
var $Hanf_arg22235930 = function(anf_arg11165929,anf_arg11044707,anf_arg11065842,anf_fun11024708,arity_DASH_check182675,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657) {
var $z59335934 = D;
var $f59395940 = function(_) {
return R.isFunction(arity_DASH_check182675.$var)?arity_DASH_check182675.$var.app(anf_arg11065842,anf_arg11165929,(1)):R.ffi.throwNonFunApp(L[738],arity_DASH_check182675.$var,[anf_arg11065842,anf_arg11165929,(1)]);
};
try {
if(--R.GAS > 0) {
$z59335934 = $f59395940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59395940,
"from":L[738]});
}
} catch($e59315932) {
if(R.isCont($e59315932)) {
var $ss59355936 = {"from":L[738],
"go":function(anf_arg11175941) {
return $Hanf_arg22225942(anf_arg11175941,anf_arg11044707,anf_fun11024708,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e59315932.stack[R.EXN_STACKHEIGHT++] = $ss59355936;
}
if(R.isPyretException($e59315932)) {
$e59315932.pyretStack.push(L[738]);
}
throw $e59315932;
}
var $ret59375938 = $Hanf_arg22225942($z59335934,anf_arg11044707,anf_fun11024708,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret59375938;
};
var $Hanf_arg22225942 = function(anf_arg11175941,anf_arg11044707,anf_fun11024708,j_DASH_field9979,j_DASH_fun8180,pred_DASH_name4344695,rt_DASH_method173657) {
var $z59455946 = D;
var $f59515952 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg11044707,anf_arg11175941):R.ffi.throwNonFunApp(L[739],j_DASH_fun8180,[anf_arg11044707,anf_arg11175941]);
};
try {
if(--R.GAS > 0) {
$z59455946 = $f59515952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59515952,
"from":L[739]});
}
} catch($e59435944) {
if(R.isCont($e59435944)) {
var $ss59475948 = {"from":L[739],
"go":function(anf_array_val11185953) {
return $Hanf_array_val22215954(anf_array_val11185953,anf_fun11024708,j_DASH_field9979,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e59435944.stack[R.EXN_STACKHEIGHT++] = $ss59475948;
}
if(R.isPyretException($e59435944)) {
$e59435944.pyretStack.push(L[739]);
}
throw $e59435944;
}
var $ret59495950 = $Hanf_array_val22215954($z59455946,anf_fun11024708,j_DASH_field9979,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret59495950;
};
var $Hanf_array_val22215954 = function(anf_array_val11185953,anf_fun11024708,j_DASH_field9979,pred_DASH_name4344695,rt_DASH_method173657) {
var $z59575958 = D;
var $f59635964 = function(_) {
return R.isFunction(anf_fun11024708)?anf_fun11024708.app([anf_array_val11185953]):R.ffi.throwNonFunApp(L[619],anf_fun11024708,[[anf_array_val11185953]]);
};
try {
if(--R.GAS > 0) {
$z59575958 = $f59635964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59635964,
"from":L[619]});
}
} catch($e59555956) {
if(R.isCont($e59555956)) {
var $ss59595960 = {"from":L[619],
"go":function(anf_arg11195965) {
return $Hanf_arg22205966(anf_arg11195965,j_DASH_field9979,pred_DASH_name4344695,rt_DASH_method173657);
}};
$e59555956.stack[R.EXN_STACKHEIGHT++] = $ss59595960;
}
if(R.isPyretException($e59555956)) {
$e59555956.pyretStack.push(L[619]);
}
throw $e59555956;
}
var $ret59615962 = $Hanf_arg22205966($z59575958,j_DASH_field9979,pred_DASH_name4344695,rt_DASH_method173657);
++R.GAS;
return $ret59615962;
};
var $Hanf_arg22205966 = function(anf_arg11195965,j_DASH_field9979,pred_DASH_name4344695,rt_DASH_method173657) {
var $z59695970 = D;
var $f59755976 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeFunction"),anf_arg11195965):R.ffi.throwNonFunApp(L[740],rt_DASH_method173657.$var,[("makeFunction"),anf_arg11195965]);
};
try {
if(--R.GAS > 0) {
$z59695970 = $f59755976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59755976,
"from":L[740]});
}
} catch($e59675968) {
if(R.isCont($e59675968)) {
var $ss59715972 = {"from":L[740],
"go":function(anf_arg11205977) {
return $Hanf_arg22195978(anf_arg11205977,j_DASH_field9979,pred_DASH_name4344695);
}};
$e59675968.stack[R.EXN_STACKHEIGHT++] = $ss59715972;
}
if(R.isPyretException($e59675968)) {
$e59675968.pyretStack.push(L[740]);
}
throw $e59675968;
}
var $ret59735974 = $Hanf_arg22195978($z59695970,j_DASH_field9979,pred_DASH_name4344695);
++R.GAS;
return $ret59735974;
};
var $Hanf_arg22195978 = function(anf_arg11205977,j_DASH_field9979,pred_DASH_name4344695) {
var $z59815982 = D;
var $f59875988 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(pred_DASH_name4344695,anf_arg11205977):R.ffi.throwNonFunApp(L[617],j_DASH_field9979,[pred_DASH_name4344695,anf_arg11205977]);
};
try {
if(--R.GAS > 0) {
$z59815982 = $f59875988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59875988,
"from":L[617]});
}
} catch($e59795980) {
if(R.isCont($e59795980)) {
var $ss59835984 = {"from":L[617],
"go":function(ann_DASH_check_DASH_temp11015989) {
return $Hann_DASH_check_DASH_temp22185990(ann_DASH_check_DASH_temp11015989);
}};
$e59795980.stack[R.EXN_STACKHEIGHT++] = $ss59835984;
}
if(R.isPyretException($e59795980)) {
$e59795980.pyretStack.push(L[617]);
}
throw $e59795980;
}
var $ret59855986 = $Hann_DASH_check_DASH_temp22185990($z59815982);
++R.GAS;
return $ret59855986;
};
var $Hann_DASH_check_DASH_temp22185990 = function(ann_DASH_check_DASH_temp11015989) {
return ann_DASH_check_DASH_temp11015989;
};
var $Hann_DASH_check_DASH_temp2217929 = function(ann_DASH_check_DASH_temp1095928) {
return ann_DASH_check_DASH_temp1095928;
};
var $Hanf_arg2216943 = function(anf_arg1092942,compiler_DASH_name167645) {
var $z59935994 = D;
var $f59996000 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(anf_arg1092942):R.ffi.throwNonFunApp(L[99],compiler_DASH_name167645.$var,[anf_arg1092942]);
};
try {
if(--R.GAS > 0) {
$z59935994 = $f59996000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59996000,
"from":L[99]});
}
} catch($e59915992) {
if(R.isCont($e59915992)) {
var $ss59955996 = {"from":L[99],
"go":function(ann_DASH_check_DASH_temp10916001) {
return $Hann_DASH_check_DASH_temp22156002(ann_DASH_check_DASH_temp10916001);
}};
$e59915992.stack[R.EXN_STACKHEIGHT++] = $ss59955996;
}
if(R.isPyretException($e59915992)) {
$e59915992.pyretStack.push(L[99]);
}
throw $e59915992;
}
var $ret59975998 = $Hann_DASH_check_DASH_temp22156002($z59935994);
++R.GAS;
return $ret59975998;
};
var $Hann_DASH_check_DASH_temp22156002 = function(ann_DASH_check_DASH_temp10916001) {
return ann_DASH_check_DASH_temp10916001;
};
var $Hs2214960 = function(s418955,id416956,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,safe417958,self414959,undefined117140) {
var if_DASH_646028 = safe417958;
var if_helper10666014 = R.makeFunction(function(if_helper_arg10676033) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[743],1,arguments);
}
var ann_DASH_check_DASH_temp10646034 = if_helper_arg10676033;
return ann_DASH_check_DASH_temp10646034;
});
var anf_if10706032 = R.isBoolean(if_DASH_646028);
if(R.isPyretTrue(anf_if10706032)) {
if(R.isPyretTrue(if_DASH_646028)) {
var $z60056006 = D;
var $f60116012 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(s418955):R.ffi.throwNonFunApp(L[741],js_DASH_id_DASH_of162700,[s418955]);
};
try {
if(--R.GAS > 0) {
$z60056006 = $f60116012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60116012,
"from":L[741]});
}
} catch($e60036004) {
if(R.isCont($e60036004)) {
var $ss60076008 = {"from":L[741],
"go":function(anf_arg10856013) {
return $Hanf_arg22026015(anf_arg10856013,if_helper10666014,j_DASH_dot9775,j_DASH_id8381);
}};
$e60036004.stack[R.EXN_STACKHEIGHT++] = $ss60076008;
}
if(R.isPyretException($e60036004)) {
$e60036004.pyretStack.push(L[741]);
}
throw $e60036004;
}
var $ret60096010 = $Hanf_arg22026015($z60056006,if_helper10666014,j_DASH_dot9775,j_DASH_id8381);
++R.GAS;
return $ret60096010;
} else {
var $z60186019 = D;
var $f60246025 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(s418955):R.ffi.throwNonFunApp(L[742],js_DASH_id_DASH_of162700,[s418955]);
};
try {
if(--R.GAS > 0) {
$z60186019 = $f60246025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60246025,
"from":L[742]});
}
} catch($e60166017) {
if(R.isCont($e60166017)) {
var $ss60206021 = {"from":L[742],
"go":function(anf_arg10716026) {
return $Hanf_arg22136027(anf_arg10716026,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140);
}};
$e60166017.stack[R.EXN_STACKHEIGHT++] = $ss60206021;
}
if(R.isPyretException($e60166017)) {
$e60166017.pyretStack.push(L[742]);
}
throw $e60166017;
}
var $ret60226023 = $Hanf_arg22136027($z60186019,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140);
++R.GAS;
return $ret60226023;
}
} else {
var cont_tail_arg10686031 = R.throwNonBooleanCondition(L[743],("if"),if_DASH_646028);
if(--R.GAS > 0) {
$z60296030 = R.isFunction(if_helper10666014)?if_helper10666014.app(cont_tail_arg10686031):R.ffi.throwNonFunApp(L[743],if_helper10666014,[cont_tail_arg10686031]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper10666014)?if_helper10666014.app(cont_tail_arg10686031):R.ffi.throwNonFunApp(L[743],if_helper10666014,[cont_tail_arg10686031]);
},
"from":L[743]});
}
++R.GAS;
return $z60296030;
}
};
var $Hanf_arg22026015 = function(anf_arg10856013,if_helper10666014,j_DASH_dot9775,j_DASH_id8381) {
var $z60376038 = D;
var $f60436044 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg10856013):R.ffi.throwNonFunApp(L[744],j_DASH_id8381,[anf_arg10856013]);
};
try {
if(--R.GAS > 0) {
$z60376038 = $f60436044();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60436044,
"from":L[744]});
}
} catch($e60356036) {
if(R.isCont($e60356036)) {
var $ss60396040 = {"from":L[744],
"go":function(anf_arg10866045) {
return $Hanf_arg22016046(anf_arg10866045,if_helper10666014,j_DASH_dot9775);
}};
$e60356036.stack[R.EXN_STACKHEIGHT++] = $ss60396040;
}
if(R.isPyretException($e60356036)) {
$e60356036.pyretStack.push(L[744]);
}
throw $e60356036;
}
var $ret60416042 = $Hanf_arg22016046($z60376038,if_helper10666014,j_DASH_dot9775);
++R.GAS;
return $ret60416042;
};
var $Hanf_arg22016046 = function(anf_arg10866045,if_helper10666014,j_DASH_dot9775) {
var $z60496050 = D;
var $f60556056 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(anf_arg10866045,("$var")):R.ffi.throwNonFunApp(L[745],j_DASH_dot9775,[anf_arg10866045,("$var")]);
};
try {
if(--R.GAS > 0) {
$z60496050 = $f60556056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60556056,
"from":L[745]});
}
} catch($e60476048) {
if(R.isCont($e60476048)) {
var $ss60516052 = {"from":L[745],
"go":function(cont_tail_arg10876057) {
return $Hcont_tail_arg22006058(cont_tail_arg10876057,if_helper10666014);
}};
$e60476048.stack[R.EXN_STACKHEIGHT++] = $ss60516052;
}
if(R.isPyretException($e60476048)) {
$e60476048.pyretStack.push(L[745]);
}
throw $e60476048;
}
var $ret60536054 = $Hcont_tail_arg22006058($z60496050,if_helper10666014);
++R.GAS;
return $ret60536054;
};
var $Hcont_tail_arg22006058 = function(cont_tail_arg10876057,if_helper10666014) {
if(--R.GAS > 0) {
$z60596060 = R.isFunction(if_helper10666014)?if_helper10666014.app(cont_tail_arg10876057):R.ffi.throwNonFunApp(L[745],if_helper10666014,[cont_tail_arg10876057]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper10666014)?if_helper10666014.app(cont_tail_arg10876057):R.ffi.throwNonFunApp(L[745],if_helper10666014,[cont_tail_arg10876057]);
},
"from":L[745]});
}
++R.GAS;
return $z60596060;
};
var $Hanf_arg22136027 = function(anf_arg10716026,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140) {
var $z60636064 = D;
var $f60696070 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg10716026):R.ffi.throwNonFunApp(L[746],j_DASH_id8381,[anf_arg10716026]);
};
try {
if(--R.GAS > 0) {
$z60636064 = $f60696070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60696070,
"from":L[746]});
}
} catch($e60616062) {
if(R.isCont($e60616062)) {
var $ss60656066 = {"from":L[746],
"go":function(anf_arg10726071) {
return $Hanf_arg22126072(anf_arg10726071,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140);
}};
$e60616062.stack[R.EXN_STACKHEIGHT++] = $ss60656066;
}
if(R.isPyretException($e60616062)) {
$e60616062.pyretStack.push(L[746]);
}
throw $e60616062;
}
var $ret60676068 = $Hanf_arg22126072($z60636064,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140);
++R.GAS;
return $ret60676068;
};
var $Hanf_arg22126072 = function(anf_arg10726071,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140) {
var $z60756076 = D;
var $f60816082 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(anf_arg10726071,("$var")):R.ffi.throwNonFunApp(L[747],j_DASH_dot9775,[anf_arg10726071,("$var")]);
};
try {
if(--R.GAS > 0) {
$z60756076 = $f60816082();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60816082,
"from":L[747]});
}
} catch($e60736074) {
if(R.isCont($e60736074)) {
var $ss60776078 = {"from":L[747],
"go":function(anf_arg10736083) {
return $Hanf_arg22116084(anf_arg10736083,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140);
}};
$e60736074.stack[R.EXN_STACKHEIGHT++] = $ss60776078;
}
if(R.isPyretException($e60736074)) {
$e60736074.pyretStack.push(L[747]);
}
throw $e60736074;
}
var $ret60796080 = $Hanf_arg22116084($z60756076,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140);
++R.GAS;
return $ret60796080;
};
var $Hanf_arg22116084 = function(anf_arg10736083,id416956,if_helper10666014,j_DASH_binop10569,j_DASH_dot9775,j_DASH_eq10676,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959,undefined117140) {
var $z60876088 = D;
var $f60936094 = function(_) {
return R.isFunction(j_DASH_binop10569)?j_DASH_binop10569.app(anf_arg10736083,j_DASH_eq10676,undefined117140):R.ffi.throwNonFunApp(L[748],j_DASH_binop10569,[anf_arg10736083,j_DASH_eq10676,undefined117140]);
};
try {
if(--R.GAS > 0) {
$z60876088 = $f60936094();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60936094,
"from":L[748]});
}
} catch($e60856086) {
if(R.isCont($e60856086)) {
var $ss60896090 = {"from":L[748],
"go":function(anf_arg10746095) {
return $Hanf_arg22106096(anf_arg10746095,id416956,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959);
}};
$e60856086.stack[R.EXN_STACKHEIGHT++] = $ss60896090;
}
if(R.isPyretException($e60856086)) {
$e60856086.pyretStack.push(L[748]);
}
throw $e60856086;
}
var $ret60916092 = $Hanf_arg22106096($z60876088,id416956,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959);
++R.GAS;
return $ret60916092;
};
var $Hanf_arg22106096 = function(anf_arg10746095,id416956,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,l415957,raise_DASH_id_DASH_exn170651,s418955,self414959) {
var anf_fun10756107 = G(self414959,"get-loc",L[750]);
var $z60996100 = D;
var $f61056106 = function(_) {
return R.isFunction(anf_fun10756107)?anf_fun10756107.app(l415957):R.ffi.throwNonFunApp(L[749],anf_fun10756107,[l415957]);
};
try {
if(--R.GAS > 0) {
$z60996100 = $f61056106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61056106,
"from":L[749]});
}
} catch($e60976098) {
if(R.isCont($e60976098)) {
var $ss61016102 = {"from":L[749],
"go":function(anf_arg10766108) {
return $Hanf_arg22096109(anf_arg10766108,anf_arg10746095,id416956,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,raise_DASH_id_DASH_exn170651,s418955);
}};
$e60976098.stack[R.EXN_STACKHEIGHT++] = $ss61016102;
}
if(R.isPyretException($e60976098)) {
$e60976098.pyretStack.push(L[749]);
}
throw $e60976098;
}
var $ret61036104 = $Hanf_arg22096109($z60996100,anf_arg10746095,id416956,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,raise_DASH_id_DASH_exn170651,s418955);
++R.GAS;
return $ret61036104;
};
var $Hanf_arg22096109 = function(anf_arg10766108,anf_arg10746095,id416956,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,raise_DASH_id_DASH_exn170651,s418955) {
var anf_fun10776120 = G(id416956,"toname",L[752]);
var $z61126113 = D;
var $f61186119 = function(_) {
return R.isFunction(anf_fun10776120)?anf_fun10776120.app():R.ffi.throwNonFunApp(L[751],anf_fun10776120,[]);
};
try {
if(--R.GAS > 0) {
$z61126113 = $f61186119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61186119,
"from":L[751]});
}
} catch($e61106111) {
if(R.isCont($e61106111)) {
var $ss61146115 = {"from":L[751],
"go":function(anf_arg10786121) {
return $Hanf_arg22086122(anf_arg10786121,anf_arg10746095,anf_arg10766108,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,raise_DASH_id_DASH_exn170651,s418955);
}};
$e61106111.stack[R.EXN_STACKHEIGHT++] = $ss61146115;
}
if(R.isPyretException($e61106111)) {
$e61106111.pyretStack.push(L[751]);
}
throw $e61106111;
}
var $ret61166117 = $Hanf_arg22086122($z61126113,anf_arg10746095,anf_arg10766108,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,raise_DASH_id_DASH_exn170651,s418955);
++R.GAS;
return $ret61166117;
};
var $Hanf_arg22086122 = function(anf_arg10786121,anf_arg10746095,anf_arg10766108,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,raise_DASH_id_DASH_exn170651,s418955) {
var $z61256126 = D;
var $f61316132 = function(_) {
return R.isFunction(raise_DASH_id_DASH_exn170651.$var)?raise_DASH_id_DASH_exn170651.$var.app(anf_arg10766108,anf_arg10786121):R.ffi.throwNonFunApp(L[753],raise_DASH_id_DASH_exn170651.$var,[anf_arg10766108,anf_arg10786121]);
};
try {
if(--R.GAS > 0) {
$z61256126 = $f61316132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61316132,
"from":L[753]});
}
} catch($e61236124) {
if(R.isCont($e61236124)) {
var $ss61276128 = {"from":L[753],
"go":function(anf_arg10796133) {
return $Hanf_arg22076134(anf_arg10796133,anf_arg10746095,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,s418955);
}};
$e61236124.stack[R.EXN_STACKHEIGHT++] = $ss61276128;
}
if(R.isPyretException($e61236124)) {
$e61236124.pyretStack.push(L[753]);
}
throw $e61236124;
}
var $ret61296130 = $Hanf_arg22076134($z61256126,anf_arg10746095,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,s418955);
++R.GAS;
return $ret61296130;
};
var $Hanf_arg22076134 = function(anf_arg10796133,anf_arg10746095,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194,js_DASH_id_DASH_of162700,s418955) {
var $z61376138 = D;
var $f61436144 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(s418955):R.ffi.throwNonFunApp(L[754],js_DASH_id_DASH_of162700,[s418955]);
};
try {
if(--R.GAS > 0) {
$z61376138 = $f61436144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61436144,
"from":L[754]});
}
} catch($e61356136) {
if(R.isCont($e61356136)) {
var $ss61396140 = {"from":L[754],
"go":function(anf_arg10806145) {
return $Hanf_arg22066146(anf_arg10806145,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194);
}};
$e61356136.stack[R.EXN_STACKHEIGHT++] = $ss61396140;
}
if(R.isPyretException($e61356136)) {
$e61356136.pyretStack.push(L[754]);
}
throw $e61356136;
}
var $ret61416142 = $Hanf_arg22066146($z61376138,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194);
++R.GAS;
return $ret61416142;
};
var $Hanf_arg22066146 = function(anf_arg10806145,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_dot9775,j_DASH_id8381,j_DASH_ternary11194) {
var $z61496150 = D;
var $f61556156 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg10806145):R.ffi.throwNonFunApp(L[755],j_DASH_id8381,[anf_arg10806145]);
};
try {
if(--R.GAS > 0) {
$z61496150 = $f61556156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61556156,
"from":L[755]});
}
} catch($e61476148) {
if(R.isCont($e61476148)) {
var $ss61516152 = {"from":L[755],
"go":function(anf_arg10816157) {
return $Hanf_arg22056158(anf_arg10816157,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_dot9775,j_DASH_ternary11194);
}};
$e61476148.stack[R.EXN_STACKHEIGHT++] = $ss61516152;
}
if(R.isPyretException($e61476148)) {
$e61476148.pyretStack.push(L[755]);
}
throw $e61476148;
}
var $ret61536154 = $Hanf_arg22056158($z61496150,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_dot9775,j_DASH_ternary11194);
++R.GAS;
return $ret61536154;
};
var $Hanf_arg22056158 = function(anf_arg10816157,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_dot9775,j_DASH_ternary11194) {
var $z61616162 = D;
var $f61676168 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(anf_arg10816157,("$var")):R.ffi.throwNonFunApp(L[756],j_DASH_dot9775,[anf_arg10816157,("$var")]);
};
try {
if(--R.GAS > 0) {
$z61616162 = $f61676168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61676168,
"from":L[756]});
}
} catch($e61596160) {
if(R.isCont($e61596160)) {
var $ss61636164 = {"from":L[756],
"go":function(anf_arg10826169) {
return $Hanf_arg22046170(anf_arg10826169,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_ternary11194);
}};
$e61596160.stack[R.EXN_STACKHEIGHT++] = $ss61636164;
}
if(R.isPyretException($e61596160)) {
$e61596160.pyretStack.push(L[756]);
}
throw $e61596160;
}
var $ret61656166 = $Hanf_arg22046170($z61616162,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_ternary11194);
++R.GAS;
return $ret61656166;
};
var $Hanf_arg22046170 = function(anf_arg10826169,anf_arg10746095,anf_arg10796133,if_helper10666014,j_DASH_ternary11194) {
var $z61736174 = D;
var $f61796180 = function(_) {
return R.isFunction(j_DASH_ternary11194)?j_DASH_ternary11194.app(anf_arg10746095,anf_arg10796133,anf_arg10826169):R.ffi.throwNonFunApp(L[757],j_DASH_ternary11194,[anf_arg10746095,anf_arg10796133,anf_arg10826169]);
};
try {
if(--R.GAS > 0) {
$z61736174 = $f61796180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61796180,
"from":L[757]});
}
} catch($e61716172) {
if(R.isCont($e61716172)) {
var $ss61756176 = {"from":L[757],
"go":function(cont_tail_arg10836181) {
return $Hcont_tail_arg22036182(cont_tail_arg10836181,if_helper10666014);
}};
$e61716172.stack[R.EXN_STACKHEIGHT++] = $ss61756176;
}
if(R.isPyretException($e61716172)) {
$e61716172.pyretStack.push(L[757]);
}
throw $e61716172;
}
var $ret61776178 = $Hcont_tail_arg22036182($z61736174,if_helper10666014);
++R.GAS;
return $ret61776178;
};
var $Hcont_tail_arg22036182 = function(cont_tail_arg10836181,if_helper10666014) {
if(--R.GAS > 0) {
$z61836184 = R.isFunction(if_helper10666014)?if_helper10666014.app(cont_tail_arg10836181):R.ffi.throwNonFunApp(L[757],if_helper10666014,[cont_tail_arg10836181]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper10666014)?if_helper10666014.app(cont_tail_arg10836181):R.ffi.throwNonFunApp(L[757],if_helper10666014,[cont_tail_arg10836181]);
},
"from":L[757]});
}
++R.GAS;
return $z61836184;
};
var $Hanf_arg2199973 = function(anf_arg1060972,j_DASH_dot9775,j_DASH_id8381,js_DASH_id_DASH_of162700) {
var $z61876188 = D;
var $f61936194 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg1060972):R.ffi.throwNonFunApp(L[758],js_DASH_id_DASH_of162700,[anf_arg1060972]);
};
try {
if(--R.GAS > 0) {
$z61876188 = $f61936194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61936194,
"from":L[758]});
}
} catch($e61856186) {
if(R.isCont($e61856186)) {
var $ss61896190 = {"from":L[758],
"go":function(anf_arg10616195) {
return $Hanf_arg21986196(anf_arg10616195,j_DASH_dot9775,j_DASH_id8381);
}};
$e61856186.stack[R.EXN_STACKHEIGHT++] = $ss61896190;
}
if(R.isPyretException($e61856186)) {
$e61856186.pyretStack.push(L[758]);
}
throw $e61856186;
}
var $ret61916192 = $Hanf_arg21986196($z61876188,j_DASH_dot9775,j_DASH_id8381);
++R.GAS;
return $ret61916192;
};
var $Hanf_arg21986196 = function(anf_arg10616195,j_DASH_dot9775,j_DASH_id8381) {
var $z61996200 = D;
var $f62056206 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg10616195):R.ffi.throwNonFunApp(L[759],j_DASH_id8381,[anf_arg10616195]);
};
try {
if(--R.GAS > 0) {
$z61996200 = $f62056206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62056206,
"from":L[759]});
}
} catch($e61976198) {
if(R.isCont($e61976198)) {
var $ss62016202 = {"from":L[759],
"go":function(anf_arg10626207) {
return $Hanf_arg21976208(anf_arg10626207,j_DASH_dot9775);
}};
$e61976198.stack[R.EXN_STACKHEIGHT++] = $ss62016202;
}
if(R.isPyretException($e61976198)) {
$e61976198.pyretStack.push(L[759]);
}
throw $e61976198;
}
var $ret62036204 = $Hanf_arg21976208($z61996200,j_DASH_dot9775);
++R.GAS;
return $ret62036204;
};
var $Hanf_arg21976208 = function(anf_arg10626207,j_DASH_dot9775) {
var $z62116212 = D;
var $f62176218 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(anf_arg10626207,("$var")):R.ffi.throwNonFunApp(L[112],j_DASH_dot9775,[anf_arg10626207,("$var")]);
};
try {
if(--R.GAS > 0) {
$z62116212 = $f62176218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62176218,
"from":L[112]});
}
} catch($e62096210) {
if(R.isCont($e62096210)) {
var $ss62136214 = {"from":L[112],
"go":function(ann_DASH_check_DASH_temp10586219) {
return $Hann_DASH_check_DASH_temp21966220(ann_DASH_check_DASH_temp10586219);
}};
$e62096210.stack[R.EXN_STACKHEIGHT++] = $ss62136214;
}
if(R.isPyretException($e62096210)) {
$e62096210.pyretStack.push(L[112]);
}
throw $e62096210;
}
var $ret62156216 = $Hann_DASH_check_DASH_temp21966220($z62116212);
++R.GAS;
return $ret62156216;
};
var $Hann_DASH_check_DASH_temp21966220 = function(ann_DASH_check_DASH_temp10586219) {
return ann_DASH_check_DASH_temp10586219;
};
var $Hanf_arg2195989 = function(anf_arg1055988,j_DASH_id8381,js_DASH_id_DASH_of162700) {
var $z62236224 = D;
var $f62296230 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg1055988):R.ffi.throwNonFunApp(L[760],js_DASH_id_DASH_of162700,[anf_arg1055988]);
};
try {
if(--R.GAS > 0) {
$z62236224 = $f62296230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62296230,
"from":L[760]});
}
} catch($e62216222) {
if(R.isCont($e62216222)) {
var $ss62256226 = {"from":L[760],
"go":function(anf_arg10566231) {
return $Hanf_arg21946232(anf_arg10566231,j_DASH_id8381);
}};
$e62216222.stack[R.EXN_STACKHEIGHT++] = $ss62256226;
}
if(R.isPyretException($e62216222)) {
$e62216222.pyretStack.push(L[760]);
}
throw $e62216222;
}
var $ret62276228 = $Hanf_arg21946232($z62236224,j_DASH_id8381);
++R.GAS;
return $ret62276228;
};
var $Hanf_arg21946232 = function(anf_arg10566231,j_DASH_id8381) {
var $z62356236 = D;
var $f62416242 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg10566231):R.ffi.throwNonFunApp(L[117],j_DASH_id8381,[anf_arg10566231]);
};
try {
if(--R.GAS > 0) {
$z62356236 = $f62416242();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62416242,
"from":L[117]});
}
} catch($e62336234) {
if(R.isCont($e62336234)) {
var $ss62376238 = {"from":L[117],
"go":function(ann_DASH_check_DASH_temp10536243) {
return $Hann_DASH_check_DASH_temp21936244(ann_DASH_check_DASH_temp10536243);
}};
$e62336234.stack[R.EXN_STACKHEIGHT++] = $ss62376238;
}
if(R.isPyretException($e62336234)) {
$e62336234.pyretStack.push(L[117]);
}
throw $e62336234;
}
var $ret62396240 = $Hann_DASH_check_DASH_temp21936244($z62356236);
++R.GAS;
return $ret62396240;
};
var $Hann_DASH_check_DASH_temp21936244 = function(ann_DASH_check_DASH_temp10536243) {
return ann_DASH_check_DASH_temp10536243;
};
var $Hcont_tail_app21911008 = function(cont_tail_app10491007) {
return cont_tail_app10491007;
};
var $Hcont_tail_app21921020 = function(cont_tail_app10481019) {
return cont_tail_app10481019;
};
var $Hann_DASH_check_DASH_temp21901038 = function(ann_DASH_check_DASH_temp10421037) {
return ann_DASH_check_DASH_temp10421037;
};
var $Hanf_arg21891054 = function(anf_arg10401053,j_DASH_parens11391) {
var $z62476248 = D;
var $f62536254 = function(_) {
return R.isFunction(j_DASH_parens11391)?j_DASH_parens11391.app(anf_arg10401053):R.ffi.throwNonFunApp(L[129],j_DASH_parens11391,[anf_arg10401053]);
};
try {
if(--R.GAS > 0) {
$z62476248 = $f62536254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62536254,
"from":L[129]});
}
} catch($e62456246) {
if(R.isCont($e62456246)) {
var $ss62496250 = {"from":L[129],
"go":function(ann_DASH_check_DASH_temp10396255) {
return $Hann_DASH_check_DASH_temp21886256(ann_DASH_check_DASH_temp10396255);
}};
$e62456246.stack[R.EXN_STACKHEIGHT++] = $ss62496250;
}
if(R.isPyretException($e62456246)) {
$e62456246.pyretStack.push(L[129]);
}
throw $e62456246;
}
var $ret62516252 = $Hann_DASH_check_DASH_temp21886256($z62476248);
++R.GAS;
return $ret62516252;
};
var $Hann_DASH_check_DASH_temp21886256 = function(ann_DASH_check_DASH_temp10396255) {
return ann_DASH_check_DASH_temp10396255;
};
var $Hif_DASH_21871069 = function(if_DASH_621068,j_DASH_num8889,j_DASH_parens11391,j_DASH_str8993,list35101,n3991067,rt_DASH_method173657,tostring14) {
var if_helper10246268 = R.makeFunction(function(if_helper_arg10256287) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[130],1,arguments);
}
var ann_DASH_check_DASH_temp10236288 = if_helper_arg10256287;
return ann_DASH_check_DASH_temp10236288;
});
var anf_if10286286 = R.isBoolean(if_DASH_621068);
if(R.isPyretTrue(anf_if10286286)) {
if(R.isPyretTrue(if_DASH_621068)) {
var $z62596260 = D;
var $f62656266 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(n3991067):R.ffi.throwNonFunApp(L[761],j_DASH_num8889,[n3991067]);
};
try {
if(--R.GAS > 0) {
$z62596260 = $f62656266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62656266,
"from":L[761]});
}
} catch($e62576258) {
if(R.isCont($e62576258)) {
var $ss62616262 = {"from":L[761],
"go":function(anf_arg10356267) {
return $Hanf_arg21826269(anf_arg10356267,if_helper10246268,j_DASH_parens11391);
}};
$e62576258.stack[R.EXN_STACKHEIGHT++] = $ss62616262;
}
if(R.isPyretException($e62576258)) {
$e62576258.pyretStack.push(L[761]);
}
throw $e62576258;
}
var $ret62636264 = $Hanf_arg21826269($z62596260,if_helper10246268,j_DASH_parens11391);
++R.GAS;
return $ret62636264;
} else {
var anf_fun10296281 = G(list35101,"make",L[763]);
var $z62726273 = D;
var $f62786279 = function(_) {
return R.isFunction(tostring14)?tostring14.app(n3991067):R.ffi.throwNonFunApp(L[762],tostring14,[n3991067]);
};
try {
if(--R.GAS > 0) {
$z62726273 = $f62786279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62786279,
"from":L[762]});
}
} catch($e62706271) {
if(R.isCont($e62706271)) {
var $ss62746275 = {"from":L[762],
"go":function(anf_arg10306280) {
return $Hanf_arg21866282(anf_arg10306280,anf_fun10296281,if_helper10246268,j_DASH_str8993,rt_DASH_method173657);
}};
$e62706271.stack[R.EXN_STACKHEIGHT++] = $ss62746275;
}
if(R.isPyretException($e62706271)) {
$e62706271.pyretStack.push(L[762]);
}
throw $e62706271;
}
var $ret62766277 = $Hanf_arg21866282($z62726273,anf_fun10296281,if_helper10246268,j_DASH_str8993,rt_DASH_method173657);
++R.GAS;
return $ret62766277;
}
} else {
var cont_tail_arg10266285 = R.throwNonBooleanCondition(L[130],("if"),if_DASH_621068);
if(--R.GAS > 0) {
$z62836284 = R.isFunction(if_helper10246268)?if_helper10246268.app(cont_tail_arg10266285):R.ffi.throwNonFunApp(L[130],if_helper10246268,[cont_tail_arg10266285]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper10246268)?if_helper10246268.app(cont_tail_arg10266285):R.ffi.throwNonFunApp(L[130],if_helper10246268,[cont_tail_arg10266285]);
},
"from":L[130]});
}
++R.GAS;
return $z62836284;
}
};
var $Hanf_arg21826269 = function(anf_arg10356267,if_helper10246268,j_DASH_parens11391) {
var $z62916292 = D;
var $f62976298 = function(_) {
return R.isFunction(j_DASH_parens11391)?j_DASH_parens11391.app(anf_arg10356267):R.ffi.throwNonFunApp(L[764],j_DASH_parens11391,[anf_arg10356267]);
};
try {
if(--R.GAS > 0) {
$z62916292 = $f62976298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62976298,
"from":L[764]});
}
} catch($e62896290) {
if(R.isCont($e62896290)) {
var $ss62936294 = {"from":L[764],
"go":function(cont_tail_arg10366299) {
return $Hcont_tail_arg21816300(cont_tail_arg10366299,if_helper10246268);
}};
$e62896290.stack[R.EXN_STACKHEIGHT++] = $ss62936294;
}
if(R.isPyretException($e62896290)) {
$e62896290.pyretStack.push(L[764]);
}
throw $e62896290;
}
var $ret62956296 = $Hcont_tail_arg21816300($z62916292,if_helper10246268);
++R.GAS;
return $ret62956296;
};
var $Hcont_tail_arg21816300 = function(cont_tail_arg10366299,if_helper10246268) {
if(--R.GAS > 0) {
$z63016302 = R.isFunction(if_helper10246268)?if_helper10246268.app(cont_tail_arg10366299):R.ffi.throwNonFunApp(L[764],if_helper10246268,[cont_tail_arg10366299]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper10246268)?if_helper10246268.app(cont_tail_arg10366299):R.ffi.throwNonFunApp(L[764],if_helper10246268,[cont_tail_arg10366299]);
},
"from":L[764]});
}
++R.GAS;
return $z63016302;
};
var $Hanf_arg21866282 = function(anf_arg10306280,anf_fun10296281,if_helper10246268,j_DASH_str8993,rt_DASH_method173657) {
var $z63056306 = D;
var $f63116312 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(anf_arg10306280):R.ffi.throwNonFunApp(L[765],j_DASH_str8993,[anf_arg10306280]);
};
try {
if(--R.GAS > 0) {
$z63056306 = $f63116312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63116312,
"from":L[765]});
}
} catch($e63036304) {
if(R.isCont($e63036304)) {
var $ss63076308 = {"from":L[765],
"go":function(anf_array_val10316313) {
return $Hanf_array_val21856314(anf_array_val10316313,anf_fun10296281,if_helper10246268,rt_DASH_method173657);
}};
$e63036304.stack[R.EXN_STACKHEIGHT++] = $ss63076308;
}
if(R.isPyretException($e63036304)) {
$e63036304.pyretStack.push(L[765]);
}
throw $e63036304;
}
var $ret63096310 = $Hanf_array_val21856314($z63056306,anf_fun10296281,if_helper10246268,rt_DASH_method173657);
++R.GAS;
return $ret63096310;
};
var $Hanf_array_val21856314 = function(anf_array_val10316313,anf_fun10296281,if_helper10246268,rt_DASH_method173657) {
var $z63176318 = D;
var $f63236324 = function(_) {
return R.isFunction(anf_fun10296281)?anf_fun10296281.app([anf_array_val10316313]):R.ffi.throwNonFunApp(L[763],anf_fun10296281,[[anf_array_val10316313]]);
};
try {
if(--R.GAS > 0) {
$z63176318 = $f63236324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63236324,
"from":L[763]});
}
} catch($e63156316) {
if(R.isCont($e63156316)) {
var $ss63196320 = {"from":L[763],
"go":function(anf_arg10326325) {
return $Hanf_arg21846326(anf_arg10326325,if_helper10246268,rt_DASH_method173657);
}};
$e63156316.stack[R.EXN_STACKHEIGHT++] = $ss63196320;
}
if(R.isPyretException($e63156316)) {
$e63156316.pyretStack.push(L[763]);
}
throw $e63156316;
}
var $ret63216322 = $Hanf_arg21846326($z63176318,if_helper10246268,rt_DASH_method173657);
++R.GAS;
return $ret63216322;
};
var $Hanf_arg21846326 = function(anf_arg10326325,if_helper10246268,rt_DASH_method173657) {
var $z63296330 = D;
var $f63356336 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeNumberFromString"),anf_arg10326325):R.ffi.throwNonFunApp(L[766],rt_DASH_method173657.$var,[("makeNumberFromString"),anf_arg10326325]);
};
try {
if(--R.GAS > 0) {
$z63296330 = $f63356336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63356336,
"from":L[766]});
}
} catch($e63276328) {
if(R.isCont($e63276328)) {
var $ss63316332 = {"from":L[766],
"go":function(cont_tail_arg10336337) {
return $Hcont_tail_arg21836338(cont_tail_arg10336337,if_helper10246268);
}};
$e63276328.stack[R.EXN_STACKHEIGHT++] = $ss63316332;
}
if(R.isPyretException($e63276328)) {
$e63276328.pyretStack.push(L[766]);
}
throw $e63276328;
}
var $ret63336334 = $Hcont_tail_arg21836338($z63296330,if_helper10246268);
++R.GAS;
return $ret63336334;
};
var $Hcont_tail_arg21836338 = function(cont_tail_arg10336337,if_helper10246268) {
if(--R.GAS > 0) {
$z63396340 = R.isFunction(if_helper10246268)?if_helper10246268.app(cont_tail_arg10336337):R.ffi.throwNonFunApp(L[766],if_helper10246268,[cont_tail_arg10336337]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper10246268)?if_helper10246268.app(cont_tail_arg10336337):R.ffi.throwNonFunApp(L[766],if_helper10246268,[cont_tail_arg10336337]);
},
"from":L[766]});
}
++R.GAS;
return $z63396340;
};
var $Hann_DASH_check_DASH_temp21801085 = function(ann_DASH_check_DASH_temp10201084) {
return ann_DASH_check_DASH_temp10201084;
};
var $Hanf_arg21791101 = function(anf_arg10181100,j_DASH_list9585) {
var $z63436344 = D;
var $f63496350 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),anf_arg10181100):R.ffi.throwNonFunApp(L[139],j_DASH_list9585,[(false),anf_arg10181100]);
};
try {
if(--R.GAS > 0) {
$z63436344 = $f63496350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63496350,
"from":L[139]});
}
} catch($e63416342) {
if(R.isCont($e63416342)) {
var $ss63456346 = {"from":L[139],
"go":function(ann_DASH_check_DASH_temp10136351) {
return $Hann_DASH_check_DASH_temp21786352(ann_DASH_check_DASH_temp10136351);
}};
$e63416342.stack[R.EXN_STACKHEIGHT++] = $ss63456346;
}
if(R.isPyretException($e63416342)) {
$e63416342.pyretStack.push(L[139]);
}
throw $e63416342;
}
var $ret63476348 = $Hann_DASH_check_DASH_temp21786352($z63436344);
++R.GAS;
return $ret63476348;
};
var $Hann_DASH_check_DASH_temp21786352 = function(ann_DASH_check_DASH_temp10136351) {
return ann_DASH_check_DASH_temp10136351;
};
var $Hann_DASH_check_DASH_temp21771116 = function(ann_DASH_check_DASH_temp10151115) {
return ann_DASH_check_DASH_temp10151115;
};
var $Hanf_arg21761133 = function(anf_arg10111131,j_DASH_field9979,name3891132) {
var $z63556356 = D;
var $f63616362 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(name3891132,anf_arg10111131):R.ffi.throwNonFunApp(L[145],j_DASH_field9979,[name3891132,anf_arg10111131]);
};
try {
if(--R.GAS > 0) {
$z63556356 = $f63616362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63616362,
"from":L[145]});
}
} catch($e63536354) {
if(R.isCont($e63536354)) {
var $ss63576358 = {"from":L[145],
"go":function(ann_DASH_check_DASH_temp10096363) {
return $Hann_DASH_check_DASH_temp21756364(ann_DASH_check_DASH_temp10096363);
}};
$e63536354.stack[R.EXN_STACKHEIGHT++] = $ss63576358;
}
if(R.isPyretException($e63536354)) {
$e63536354.pyretStack.push(L[145]);
}
throw $e63536354;
}
var $ret63596360 = $Hann_DASH_check_DASH_temp21756364($z63556356);
++R.GAS;
return $ret63596360;
};
var $Hann_DASH_check_DASH_temp21756364 = function(ann_DASH_check_DASH_temp10096363) {
return ann_DASH_check_DASH_temp10096363;
};
var $Hann_DASH_check_DASH_temp21741149 = function(ann_DASH_check_DASH_temp10061148) {
return ann_DASH_check_DASH_temp10061148;
};
var $Hanf_bracket21731167 = function(anf_bracket9631163,args3811164,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,ret3821166,rt_DASH_method173657,self3791162,_minus4) {
var anf_arg9646375 = G(anf_bracket9631163,"stmts",L[768]);
var $z63676368 = D;
var $f63736374 = function(_) {
return R.isFunction(contract_DASH_checks183677.$var)?contract_DASH_checks183677.$var.app(args3811164,ret3821166,anf_arg9646375,self3791162):R.ffi.throwNonFunApp(L[767],contract_DASH_checks183677.$var,[args3811164,ret3821166,anf_arg9646375,self3791162]);
};
try {
if(--R.GAS > 0) {
$z63676368 = $f63736374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63736374,
"from":L[767]});
}
} catch($e63656366) {
if(R.isCont($e63656366)) {
var $ss63696370 = {"from":L[767],
"go":function(compiled_DASH_body_DASH_stmts3846376) {
return $Hcompiled_DASH_body_DASH_stmts21726377(compiled_DASH_body_DASH_stmts3846376,args3811164,arity_DASH_check182675,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
}};
$e63656366.stack[R.EXN_STACKHEIGHT++] = $ss63696370;
}
if(R.isPyretException($e63656366)) {
$e63656366.pyretStack.push(L[767]);
}
throw $e63656366;
}
var $ret63716372 = $Hcompiled_DASH_body_DASH_stmts21726377($z63676368,args3811164,arity_DASH_check182675,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
++R.GAS;
return $ret63716372;
};
var $Hcompiled_DASH_body_DASH_stmts21726377 = function(compiled_DASH_body_DASH_stmts3846376,args3811164,arity_DASH_check182675,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4) {
var anf_fun9656390 = G(list35101,"make",L[774]);
var anf_fun9666391 = G(list35101,"make",L[773]);
var anf_bracket9676394 = G(args3811164,"first",L[772]);
var anf_bracket9686393 = G(anf_bracket9676394,"id",L[771]);
var anf_fun9696388 = G(anf_bracket9686393,"tostring",L[770]);
var $z63806381 = D;
var $f63866387 = function(_) {
return R.isFunction(anf_fun9696388)?anf_fun9696388.app():R.ffi.throwNonFunApp(L[769],anf_fun9696388,[]);
};
try {
if(--R.GAS > 0) {
$z63806381 = $f63866387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63866387,
"from":L[769]});
}
} catch($e63786379) {
if(R.isCont($e63786379)) {
var $ss63826383 = {"from":L[769],
"go":function(anf_arg9706389) {
return $Hanf_arg21716392(anf_arg9706389,anf_fun9656390,anf_fun9666391,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
}};
$e63786379.stack[R.EXN_STACKHEIGHT++] = $ss63826383;
}
if(R.isPyretException($e63786379)) {
$e63786379.pyretStack.push(L[769]);
}
throw $e63786379;
}
var $ret63846385 = $Hanf_arg21716392($z63806381,anf_fun9656390,anf_fun9666391,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
++R.GAS;
return $ret63846385;
};
var $Hanf_arg21716392 = function(anf_arg9706389,anf_fun9656390,anf_fun9666391,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4) {
var $z63976398 = D;
var $f64036404 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg9706389):R.ffi.throwNonFunApp(L[775],js_DASH_id_DASH_of162700,[anf_arg9706389]);
};
try {
if(--R.GAS > 0) {
$z63976398 = $f64036404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64036404,
"from":L[775]});
}
} catch($e63956396) {
if(R.isCont($e63956396)) {
var $ss63996400 = {"from":L[775],
"go":function(anf_array_val9716405) {
return $Hanf_array_val21706406(anf_array_val9716405,anf_fun9656390,anf_fun9666391,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
}};
$e63956396.stack[R.EXN_STACKHEIGHT++] = $ss63996400;
}
if(R.isPyretException($e63956396)) {
$e63956396.pyretStack.push(L[775]);
}
throw $e63956396;
}
var $ret64016402 = $Hanf_array_val21706406($z63976398,anf_fun9656390,anf_fun9666391,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
++R.GAS;
return $ret64016402;
};
var $Hanf_array_val21706406 = function(anf_array_val9716405,anf_fun9656390,anf_fun9666391,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4) {
var $z64096410 = D;
var $f64156416 = function(_) {
return R.isFunction(anf_fun9666391)?anf_fun9666391.app([anf_array_val9716405]):R.ffi.throwNonFunApp(L[773],anf_fun9666391,[[anf_array_val9716405]]);
};
try {
if(--R.GAS > 0) {
$z64096410 = $f64156416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64156416,
"from":L[773]});
}
} catch($e64076408) {
if(R.isCont($e64076408)) {
var $ss64116412 = {"from":L[773],
"go":function(anf_arg9726417) {
return $Hanf_arg21696418(anf_arg9726417,anf_fun9656390,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
}};
$e64076408.stack[R.EXN_STACKHEIGHT++] = $ss64116412;
}
if(R.isPyretException($e64076408)) {
$e64076408.pyretStack.push(L[773]);
}
throw $e64076408;
}
var $ret64136414 = $Hanf_arg21696418($z64096410,anf_fun9656390,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
++R.GAS;
return $ret64136414;
};
var $Hanf_arg21696418 = function(anf_arg9726417,anf_fun9656390,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4) {
var anf_fun9736432 = G(list35101,"make",L[780]);
var anf_bracket9746436 = G(args3811164,"rest",L[779]);
var anf_fun9756429 = G(anf_bracket9746436,"map",L[778]);
var anf_arg9776430 = R.makeFunction(function(recv_DASH_606434) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[777],1,arguments);
}
var ann_DASH_check_DASH_temp9766435 = G(recv_DASH_606434,"id",L[777]);
return ann_DASH_check_DASH_temp9766435;
});
var $z64216422 = D;
var $f64276428 = function(_) {
return R.isFunction(anf_fun9756429)?anf_fun9756429.app(anf_arg9776430):R.ffi.throwNonFunApp(L[776],anf_fun9756429,[anf_arg9776430]);
};
try {
if(--R.GAS > 0) {
$z64216422 = $f64276428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64276428,
"from":L[776]});
}
} catch($e64196420) {
if(R.isCont($e64196420)) {
var $ss64236424 = {"from":L[776],
"go":function(anf_bracket9786431) {
return $Hanf_bracket21686433(anf_bracket9786431,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
}};
$e64196420.stack[R.EXN_STACKHEIGHT++] = $ss64236424;
}
if(R.isPyretException($e64196420)) {
$e64196420.pyretStack.push(L[776]);
}
throw $e64196420;
}
var $ret64256426 = $Hanf_bracket21686433($z64216422,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
++R.GAS;
return $ret64256426;
};
var $Hanf_bracket21686433 = function(anf_bracket9786431,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4) {
var anf_fun9796447 = G(anf_bracket9786431,"map",L[783]);
var anf_arg9826448 = R.makeFunction(function(recv_DASH_596451) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[782],1,arguments);
}
var anf_fun9816462 = G(recv_DASH_596451,"tostring",L[782]);
var $z64546455 = D;
var $f64606461 = function(_) {
return R.isFunction(anf_fun9816462)?anf_fun9816462.app():R.ffi.throwNonFunApp(L[782],anf_fun9816462,[]);
};
try {
if(--R.GAS > 0) {
$z64546455 = $f64606461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64606461,
"from":L[782]});
}
} catch($e64526453) {
if(R.isCont($e64526453)) {
var $ss64566457 = {"from":L[782],
"go":function(ann_DASH_check_DASH_temp9806463) {
return $Hann_DASH_check_DASH_temp21496464(ann_DASH_check_DASH_temp9806463);
}};
$e64526453.stack[R.EXN_STACKHEIGHT++] = $ss64566457;
}
if(R.isPyretException($e64526453)) {
$e64526453.pyretStack.push(L[782]);
}
throw $e64526453;
}
var $ret64586459 = $Hann_DASH_check_DASH_temp21496464($z64546455);
++R.GAS;
return $ret64586459;
});
var $z64396440 = D;
var $f64456446 = function(_) {
return R.isFunction(anf_fun9796447)?anf_fun9796447.app(anf_arg9826448):R.ffi.throwNonFunApp(L[781],anf_fun9796447,[anf_arg9826448]);
};
try {
if(--R.GAS > 0) {
$z64396440 = $f64456446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64456446,
"from":L[781]});
}
} catch($e64376438) {
if(R.isCont($e64376438)) {
var $ss64416442 = {"from":L[781],
"go":function(anf_bracket9836449) {
return $Hanf_bracket21676450(anf_bracket9836449,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
}};
$e64376438.stack[R.EXN_STACKHEIGHT++] = $ss64416442;
}
if(R.isPyretException($e64376438)) {
$e64376438.pyretStack.push(L[781]);
}
throw $e64376438;
}
var $ret64436444 = $Hanf_bracket21676450($z64396440,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
++R.GAS;
return $ret64436444;
};
var $Hanf_bracket21676450 = function(anf_bracket9836449,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,js_DASH_id_DASH_of162700,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4) {
var anf_fun9846475 = G(anf_bracket9836449,"map",L[785]);
var $z64676468 = D;
var $f64736474 = function(_) {
return R.isFunction(anf_fun9846475)?anf_fun9846475.app(js_DASH_id_DASH_of162700):R.ffi.throwNonFunApp(L[784],anf_fun9846475,[js_DASH_id_DASH_of162700]);
};
try {
if(--R.GAS > 0) {
$z64676468 = $f64736474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64736474,
"from":L[784]});
}
} catch($e64656466) {
if(R.isCont($e64656466)) {
var $ss64696470 = {"from":L[784],
"go":function(anf_arg9856476) {
return $Hanf_arg21666477(anf_arg9856476,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
}};
$e64656466.stack[R.EXN_STACKHEIGHT++] = $ss64696470;
}
if(R.isPyretException($e64656466)) {
$e64656466.pyretStack.push(L[784]);
}
throw $e64656466;
}
var $ret64716472 = $Hanf_arg21666477($z64676468,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4);
++R.GAS;
return $ret64716472;
};
var $Hanf_arg21666477 = function(anf_arg9856476,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,l3801165,list35101,rt_DASH_method173657,self3791162,_minus4) {
var anf_fun9866488 = G(self3791162,"get-loc",L[787]);
var $z64806481 = D;
var $f64866487 = function(_) {
return R.isFunction(anf_fun9866488)?anf_fun9866488.app(l3801165):R.ffi.throwNonFunApp(L[786],anf_fun9866488,[l3801165]);
};
try {
if(--R.GAS > 0) {
$z64806481 = $f64866487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64866487,
"from":L[786]});
}
} catch($e64786479) {
if(R.isCont($e64786479)) {
var $ss64826483 = {"from":L[786],
"go":function(anf_arg9876489) {
return $Hanf_arg21656490(anf_arg9876489,anf_arg9726417,anf_arg9856476,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,_minus4);
}};
$e64786479.stack[R.EXN_STACKHEIGHT++] = $ss64826483;
}
if(R.isPyretException($e64786479)) {
$e64786479.pyretStack.push(L[786]);
}
throw $e64786479;
}
var $ret64846485 = $Hanf_arg21656490($z64806481,anf_arg9726417,anf_arg9856476,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,_minus4);
++R.GAS;
return $ret64846485;
};
var $Hanf_arg21656490 = function(anf_arg9876489,anf_arg9726417,anf_arg9856476,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,_minus4) {
var anf_fun9886501 = G(args3811164,"length",L[789]);
var $z64936494 = D;
var $f64996500 = function(_) {
return R.isFunction(anf_fun9886501)?anf_fun9886501.app():R.ffi.throwNonFunApp(L[788],anf_fun9886501,[]);
};
try {
if(--R.GAS > 0) {
$z64936494 = $f64996500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64996500,
"from":L[788]});
}
} catch($e64916492) {
if(R.isCont($e64916492)) {
var $ss64956496 = {"from":L[788],
"go":function(anf_arg9896502) {
return $Hanf_arg21646503(anf_arg9896502,anf_arg9726417,anf_arg9856476,anf_arg9876489,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,_minus4);
}};
$e64916492.stack[R.EXN_STACKHEIGHT++] = $ss64956496;
}
if(R.isPyretException($e64916492)) {
$e64916492.pyretStack.push(L[788]);
}
throw $e64916492;
}
var $ret64976498 = $Hanf_arg21646503($z64936494,anf_arg9726417,anf_arg9856476,anf_arg9876489,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,_minus4);
++R.GAS;
return $ret64976498;
};
var $Hanf_arg21646503 = function(anf_arg9896502,anf_arg9726417,anf_arg9856476,anf_arg9876489,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657,_minus4) {
var $z65066507 = D;
var $f65126513 = function(_) {
return R.isFunction(_minus4)?_minus4.app(anf_arg9896502,(1)):R.ffi.throwNonFunApp(L[790],_minus4,[anf_arg9896502,(1)]);
};
try {
if(--R.GAS > 0) {
$z65066507 = $f65126513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65126513,
"from":L[790]});
}
} catch($e65046505) {
if(R.isCont($e65046505)) {
var $ss65086509 = {"from":L[790],
"go":function(anf_arg9906514) {
return $Hanf_arg21636515(anf_arg9906514,anf_arg9726417,anf_arg9856476,anf_arg9876489,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657);
}};
$e65046505.stack[R.EXN_STACKHEIGHT++] = $ss65086509;
}
if(R.isPyretException($e65046505)) {
$e65046505.pyretStack.push(L[790]);
}
throw $e65046505;
}
var $ret65106511 = $Hanf_arg21636515($z65066507,anf_arg9726417,anf_arg9856476,anf_arg9876489,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657);
++R.GAS;
return $ret65106511;
};
var $Hanf_arg21636515 = function(anf_arg9906514,anf_arg9726417,anf_arg9856476,anf_arg9876489,anf_fun9656390,anf_fun9736432,args3811164,arity_DASH_check182675,compiled_DASH_body_DASH_stmts3846376,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657) {
var $z65186519 = D;
var $f65246525 = function(_) {
return R.isFunction(arity_DASH_check182675.$var)?arity_DASH_check182675.$var.app(anf_arg9876489,compiled_DASH_body_DASH_stmts3846376,anf_arg9906514):R.ffi.throwNonFunApp(L[791],arity_DASH_check182675.$var,[anf_arg9876489,compiled_DASH_body_DASH_stmts3846376,anf_arg9906514]);
};
try {
if(--R.GAS > 0) {
$z65186519 = $f65246525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65246525,
"from":L[791]});
}
} catch($e65166517) {
if(R.isCont($e65166517)) {
var $ss65206521 = {"from":L[791],
"go":function(anf_arg9916526) {
return $Hanf_arg21626527(anf_arg9916526,anf_arg9726417,anf_arg9856476,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657);
}};
$e65166517.stack[R.EXN_STACKHEIGHT++] = $ss65206521;
}
if(R.isPyretException($e65166517)) {
$e65166517.pyretStack.push(L[791]);
}
throw $e65166517;
}
var $ret65226523 = $Hanf_arg21626527($z65186519,anf_arg9726417,anf_arg9856476,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657);
++R.GAS;
return $ret65226523;
};
var $Hanf_arg21626527 = function(anf_arg9916526,anf_arg9726417,anf_arg9856476,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657) {
var $z65306531 = D;
var $f65366537 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg9856476,anf_arg9916526):R.ffi.throwNonFunApp(L[792],j_DASH_fun8180,[anf_arg9856476,anf_arg9916526]);
};
try {
if(--R.GAS > 0) {
$z65306531 = $f65366537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65366537,
"from":L[792]});
}
} catch($e65286529) {
if(R.isCont($e65286529)) {
var $ss65326533 = {"from":L[792],
"go":function(anf_arg9926538) {
return $Hanf_arg21616539(anf_arg9926538,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657);
}};
$e65286529.stack[R.EXN_STACKHEIGHT++] = $ss65326533;
}
if(R.isPyretException($e65286529)) {
$e65286529.pyretStack.push(L[792]);
}
throw $e65286529;
}
var $ret65346535 = $Hanf_arg21616539($z65306531,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657);
++R.GAS;
return $ret65346535;
};
var $Hanf_arg21616539 = function(anf_arg9926538,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,list35101,rt_DASH_method173657) {
var $z65426543 = D;
var $f65486549 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg9926538):R.ffi.throwNonFunApp(L[793],j_DASH_return9092,[anf_arg9926538]);
};
try {
if(--R.GAS > 0) {
$z65426543 = $f65486549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65486549,
"from":L[793]});
}
} catch($e65406541) {
if(R.isCont($e65406541)) {
var $ss65446545 = {"from":L[793],
"go":function(anf_array_val9936550) {
return $Hanf_array_val21606551(anf_array_val9936550,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657);
}};
$e65406541.stack[R.EXN_STACKHEIGHT++] = $ss65446545;
}
if(R.isPyretException($e65406541)) {
$e65406541.pyretStack.push(L[793]);
}
throw $e65406541;
}
var $ret65466547 = $Hanf_array_val21606551($z65426543,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657);
++R.GAS;
return $ret65466547;
};
var $Hanf_array_val21606551 = function(anf_array_val9936550,anf_arg9726417,anf_fun9656390,anf_fun9736432,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657) {
var $z65546555 = D;
var $f65606561 = function(_) {
return R.isFunction(anf_fun9736432)?anf_fun9736432.app([anf_array_val9936550]):R.ffi.throwNonFunApp(L[780],anf_fun9736432,[[anf_array_val9936550]]);
};
try {
if(--R.GAS > 0) {
$z65546555 = $f65606561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65606561,
"from":L[780]});
}
} catch($e65526553) {
if(R.isCont($e65526553)) {
var $ss65566557 = {"from":L[780],
"go":function(anf_arg9946562) {
return $Hanf_arg21596563(anf_arg9946562,anf_arg9726417,anf_fun9656390,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657);
}};
$e65526553.stack[R.EXN_STACKHEIGHT++] = $ss65566557;
}
if(R.isPyretException($e65526553)) {
$e65526553.pyretStack.push(L[780]);
}
throw $e65526553;
}
var $ret65586559 = $Hanf_arg21596563($z65546555,anf_arg9726417,anf_fun9656390,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657);
++R.GAS;
return $ret65586559;
};
var $Hanf_arg21596563 = function(anf_arg9946562,anf_arg9726417,anf_fun9656390,args3811164,j_DASH_block8570,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657) {
var $z65666567 = D;
var $f65726573 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg9946562):R.ffi.throwNonFunApp(L[794],j_DASH_block8570,[anf_arg9946562]);
};
try {
if(--R.GAS > 0) {
$z65666567 = $f65726573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65726573,
"from":L[794]});
}
} catch($e65646565) {
if(R.isCont($e65646565)) {
var $ss65686569 = {"from":L[794],
"go":function(anf_arg9956574) {
return $Hanf_arg21586575(anf_arg9956574,anf_arg9726417,anf_fun9656390,args3811164,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657);
}};
$e65646565.stack[R.EXN_STACKHEIGHT++] = $ss65686569;
}
if(R.isPyretException($e65646565)) {
$e65646565.pyretStack.push(L[794]);
}
throw $e65646565;
}
var $ret65706571 = $Hanf_arg21586575($z65666567,anf_arg9726417,anf_fun9656390,args3811164,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657);
++R.GAS;
return $ret65706571;
};
var $Hanf_arg21586575 = function(anf_arg9956574,anf_arg9726417,anf_fun9656390,args3811164,j_DASH_field9979,j_DASH_fun8180,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657) {
var $z65786579 = D;
var $f65846585 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg9726417,anf_arg9956574):R.ffi.throwNonFunApp(L[795],j_DASH_fun8180,[anf_arg9726417,anf_arg9956574]);
};
try {
if(--R.GAS > 0) {
$z65786579 = $f65846585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65846585,
"from":L[795]});
}
} catch($e65766577) {
if(R.isCont($e65766577)) {
var $ss65806581 = {"from":L[795],
"go":function(anf_array_val9966586) {
return $Hanf_array_val21576587(anf_array_val9966586,anf_fun9656390,args3811164,j_DASH_field9979,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657);
}};
$e65766577.stack[R.EXN_STACKHEIGHT++] = $ss65806581;
}
if(R.isPyretException($e65766577)) {
$e65766577.pyretStack.push(L[795]);
}
throw $e65766577;
}
var $ret65826583 = $Hanf_array_val21576587($z65786579,anf_fun9656390,args3811164,j_DASH_field9979,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657);
++R.GAS;
return $ret65826583;
};
var $Hanf_array_val21576587 = function(anf_array_val9966586,anf_fun9656390,args3811164,j_DASH_field9979,j_DASH_num8889,j_DASH_obj9690,list35101,rt_DASH_method173657) {
var anf_fun9976600 = G(list35101,"make",L[798]);
var anf_fun9986598 = G(args3811164,"length",L[797]);
var $z65906591 = D;
var $f65966597 = function(_) {
return R.isFunction(anf_fun9986598)?anf_fun9986598.app():R.ffi.throwNonFunApp(L[796],anf_fun9986598,[]);
};
try {
if(--R.GAS > 0) {
$z65906591 = $f65966597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65966597,
"from":L[796]});
}
} catch($e65886589) {
if(R.isCont($e65886589)) {
var $ss65926593 = {"from":L[796],
"go":function(anf_arg9996599) {
return $Hanf_arg21566601(anf_arg9996599,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_field9979,j_DASH_num8889,j_DASH_obj9690,rt_DASH_method173657);
}};
$e65886589.stack[R.EXN_STACKHEIGHT++] = $ss65926593;
}
if(R.isPyretException($e65886589)) {
$e65886589.pyretStack.push(L[796]);
}
throw $e65886589;
}
var $ret65946595 = $Hanf_arg21566601($z65906591,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_field9979,j_DASH_num8889,j_DASH_obj9690,rt_DASH_method173657);
++R.GAS;
return $ret65946595;
};
var $Hanf_arg21566601 = function(anf_arg9996599,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_field9979,j_DASH_num8889,j_DASH_obj9690,rt_DASH_method173657) {
var $z66046605 = D;
var $f66106611 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(anf_arg9996599):R.ffi.throwNonFunApp(L[799],j_DASH_num8889,[anf_arg9996599]);
};
try {
if(--R.GAS > 0) {
$z66046605 = $f66106611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66106611,
"from":L[799]});
}
} catch($e66026603) {
if(R.isCont($e66026603)) {
var $ss66066607 = {"from":L[799],
"go":function(anf_arg10006612) {
return $Hanf_arg21556613(anf_arg10006612,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657);
}};
$e66026603.stack[R.EXN_STACKHEIGHT++] = $ss66066607;
}
if(R.isPyretException($e66026603)) {
$e66026603.pyretStack.push(L[799]);
}
throw $e66026603;
}
var $ret66086609 = $Hanf_arg21556613($z66046605,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657);
++R.GAS;
return $ret66086609;
};
var $Hanf_arg21556613 = function(anf_arg10006612,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657) {
var $z66166617 = D;
var $f66226623 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("length"),anf_arg10006612):R.ffi.throwNonFunApp(L[800],j_DASH_field9979,[("length"),anf_arg10006612]);
};
try {
if(--R.GAS > 0) {
$z66166617 = $f66226623();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66226623,
"from":L[800]});
}
} catch($e66146615) {
if(R.isCont($e66146615)) {
var $ss66186619 = {"from":L[800],
"go":function(anf_array_val10016624) {
return $Hanf_array_val21546625(anf_array_val10016624,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_obj9690,rt_DASH_method173657);
}};
$e66146615.stack[R.EXN_STACKHEIGHT++] = $ss66186619;
}
if(R.isPyretException($e66146615)) {
$e66146615.pyretStack.push(L[800]);
}
throw $e66146615;
}
var $ret66206621 = $Hanf_array_val21546625($z66166617,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_obj9690,rt_DASH_method173657);
++R.GAS;
return $ret66206621;
};
var $Hanf_array_val21546625 = function(anf_array_val10016624,anf_array_val9966586,anf_fun9656390,anf_fun9976600,j_DASH_obj9690,rt_DASH_method173657) {
var $z66286629 = D;
var $f66346635 = function(_) {
return R.isFunction(anf_fun9976600)?anf_fun9976600.app([anf_array_val10016624]):R.ffi.throwNonFunApp(L[798],anf_fun9976600,[[anf_array_val10016624]]);
};
try {
if(--R.GAS > 0) {
$z66286629 = $f66346635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66346635,
"from":L[798]});
}
} catch($e66266627) {
if(R.isCont($e66266627)) {
var $ss66306631 = {"from":L[798],
"go":function(anf_arg10026636) {
return $Hanf_arg21536637(anf_arg10026636,anf_array_val9966586,anf_fun9656390,j_DASH_obj9690,rt_DASH_method173657);
}};
$e66266627.stack[R.EXN_STACKHEIGHT++] = $ss66306631;
}
if(R.isPyretException($e66266627)) {
$e66266627.pyretStack.push(L[798]);
}
throw $e66266627;
}
var $ret66326633 = $Hanf_arg21536637($z66286629,anf_array_val9966586,anf_fun9656390,j_DASH_obj9690,rt_DASH_method173657);
++R.GAS;
return $ret66326633;
};
var $Hanf_arg21536637 = function(anf_arg10026636,anf_array_val9966586,anf_fun9656390,j_DASH_obj9690,rt_DASH_method173657) {
var $z66406641 = D;
var $f66466647 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg10026636):R.ffi.throwNonFunApp(L[801],j_DASH_obj9690,[anf_arg10026636]);
};
try {
if(--R.GAS > 0) {
$z66406641 = $f66466647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66466647,
"from":L[801]});
}
} catch($e66386639) {
if(R.isCont($e66386639)) {
var $ss66426643 = {"from":L[801],
"go":function(anf_array_val10036648) {
return $Hanf_array_val21526649(anf_array_val10036648,anf_array_val9966586,anf_fun9656390,rt_DASH_method173657);
}};
$e66386639.stack[R.EXN_STACKHEIGHT++] = $ss66426643;
}
if(R.isPyretException($e66386639)) {
$e66386639.pyretStack.push(L[801]);
}
throw $e66386639;
}
var $ret66446645 = $Hanf_array_val21526649($z66406641,anf_array_val9966586,anf_fun9656390,rt_DASH_method173657);
++R.GAS;
return $ret66446645;
};
var $Hanf_array_val21526649 = function(anf_array_val10036648,anf_array_val9966586,anf_fun9656390,rt_DASH_method173657) {
var $z66526653 = D;
var $f66586659 = function(_) {
return R.isFunction(anf_fun9656390)?anf_fun9656390.app([anf_array_val9966586,anf_array_val10036648]):R.ffi.throwNonFunApp(L[774],anf_fun9656390,[[anf_array_val9966586,anf_array_val10036648]]);
};
try {
if(--R.GAS > 0) {
$z66526653 = $f66586659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66586659,
"from":L[774]});
}
} catch($e66506651) {
if(R.isCont($e66506651)) {
var $ss66546655 = {"from":L[774],
"go":function(anf_arg10046660) {
return $Hanf_arg21516661(anf_arg10046660,rt_DASH_method173657);
}};
$e66506651.stack[R.EXN_STACKHEIGHT++] = $ss66546655;
}
if(R.isPyretException($e66506651)) {
$e66506651.pyretStack.push(L[774]);
}
throw $e66506651;
}
var $ret66566657 = $Hanf_arg21516661($z66526653,rt_DASH_method173657);
++R.GAS;
return $ret66566657;
};
var $Hanf_arg21516661 = function(anf_arg10046660,rt_DASH_method173657) {
var $z66646665 = D;
var $f66706671 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeMethod"),anf_arg10046660):R.ffi.throwNonFunApp(L[154],rt_DASH_method173657.$var,[("makeMethod"),anf_arg10046660]);
};
try {
if(--R.GAS > 0) {
$z66646665 = $f66706671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66706671,
"from":L[154]});
}
} catch($e66626663) {
if(R.isCont($e66626663)) {
var $ss66666667 = {"from":L[154],
"go":function(ann_DASH_check_DASH_temp9616672) {
return $Hann_DASH_check_DASH_temp21506673(ann_DASH_check_DASH_temp9616672);
}};
$e66626663.stack[R.EXN_STACKHEIGHT++] = $ss66666667;
}
if(R.isPyretException($e66626663)) {
$e66626663.pyretStack.push(L[154]);
}
throw $e66626663;
}
var $ret66686669 = $Hann_DASH_check_DASH_temp21506673($z66646665);
++R.GAS;
return $ret66686669;
};
var $Hann_DASH_check_DASH_temp21506673 = function(ann_DASH_check_DASH_temp9616672) {
return ann_DASH_check_DASH_temp9616672;
};
var $Hann_DASH_check_DASH_temp21496464 = function(ann_DASH_check_DASH_temp9806463) {
return ann_DASH_check_DASH_temp9806463;
};
var $Hanf_bracket21481188 = function(anf_bracket9411181,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,js_DASH_id_DASH_of162700,l3751185,ret3771186,rt_DASH_method173657,self3741187) {
var anf_fun9426684 = G(anf_bracket9411181,"map",L[804]);
var anf_arg9456685 = R.makeFunction(function(recv_DASH_576688) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[803],1,arguments);
}
var anf_fun9446699 = G(recv_DASH_576688,"tostring",L[803]);
var $z66916692 = D;
var $f66976698 = function(_) {
return R.isFunction(anf_fun9446699)?anf_fun9446699.app():R.ffi.throwNonFunApp(L[803],anf_fun9446699,[]);
};
try {
if(--R.GAS > 0) {
$z66916692 = $f66976698();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66976698,
"from":L[803]});
}
} catch($e66896690) {
if(R.isCont($e66896690)) {
var $ss66936694 = {"from":L[803],
"go":function(ann_DASH_check_DASH_temp9436700) {
return $Hann_DASH_check_DASH_temp21376701(ann_DASH_check_DASH_temp9436700);
}};
$e66896690.stack[R.EXN_STACKHEIGHT++] = $ss66936694;
}
if(R.isPyretException($e66896690)) {
$e66896690.pyretStack.push(L[803]);
}
throw $e66896690;
}
var $ret66956696 = $Hann_DASH_check_DASH_temp21376701($z66916692);
++R.GAS;
return $ret66956696;
});
var $z66766677 = D;
var $f66826683 = function(_) {
return R.isFunction(anf_fun9426684)?anf_fun9426684.app(anf_arg9456685):R.ffi.throwNonFunApp(L[802],anf_fun9426684,[anf_arg9456685]);
};
try {
if(--R.GAS > 0) {
$z66766677 = $f66826683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66826683,
"from":L[802]});
}
} catch($e66746675) {
if(R.isCont($e66746675)) {
var $ss66786679 = {"from":L[802],
"go":function(anf_bracket9466686) {
return $Hanf_bracket21476687(anf_bracket9466686,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,js_DASH_id_DASH_of162700,l3751185,ret3771186,rt_DASH_method173657,self3741187);
}};
$e66746675.stack[R.EXN_STACKHEIGHT++] = $ss66786679;
}
if(R.isPyretException($e66746675)) {
$e66746675.pyretStack.push(L[802]);
}
throw $e66746675;
}
var $ret66806681 = $Hanf_bracket21476687($z66766677,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,js_DASH_id_DASH_of162700,l3751185,ret3771186,rt_DASH_method173657,self3741187);
++R.GAS;
return $ret66806681;
};
var $Hanf_bracket21476687 = function(anf_bracket9466686,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,js_DASH_id_DASH_of162700,l3751185,ret3771186,rt_DASH_method173657,self3741187) {
var anf_fun9476712 = G(anf_bracket9466686,"map",L[806]);
var $z67046705 = D;
var $f67106711 = function(_) {
return R.isFunction(anf_fun9476712)?anf_fun9476712.app(js_DASH_id_DASH_of162700):R.ffi.throwNonFunApp(L[805],anf_fun9476712,[js_DASH_id_DASH_of162700]);
};
try {
if(--R.GAS > 0) {
$z67046705 = $f67106711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67106711,
"from":L[805]});
}
} catch($e67026703) {
if(R.isCont($e67026703)) {
var $ss67066707 = {"from":L[805],
"go":function(anf_arg9486713) {
return $Hanf_arg21466714(anf_arg9486713,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,l3751185,ret3771186,rt_DASH_method173657,self3741187);
}};
$e67026703.stack[R.EXN_STACKHEIGHT++] = $ss67066707;
}
if(R.isPyretException($e67026703)) {
$e67026703.pyretStack.push(L[805]);
}
throw $e67026703;
}
var $ret67086709 = $Hanf_arg21466714($z67046705,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,l3751185,ret3771186,rt_DASH_method173657,self3741187);
++R.GAS;
return $ret67086709;
};
var $Hanf_arg21466714 = function(anf_arg9486713,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,l3751185,ret3771186,rt_DASH_method173657,self3741187) {
var anf_fun9496725 = G(self3741187,"get-loc",L[808]);
var $z67176718 = D;
var $f67236724 = function(_) {
return R.isFunction(anf_fun9496725)?anf_fun9496725.app(l3751185):R.ffi.throwNonFunApp(L[807],anf_fun9496725,[l3751185]);
};
try {
if(--R.GAS > 0) {
$z67176718 = $f67236724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67236724,
"from":L[807]});
}
} catch($e67156716) {
if(R.isCont($e67156716)) {
var $ss67196720 = {"from":L[807],
"go":function(anf_arg9506726) {
return $Hanf_arg21456727(anf_arg9506726,anf_arg9486713,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,ret3771186,rt_DASH_method173657,self3741187);
}};
$e67156716.stack[R.EXN_STACKHEIGHT++] = $ss67196720;
}
if(R.isPyretException($e67156716)) {
$e67156716.pyretStack.push(L[807]);
}
throw $e67156716;
}
var $ret67216722 = $Hanf_arg21456727($z67176718,anf_arg9486713,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,ret3771186,rt_DASH_method173657,self3741187);
++R.GAS;
return $ret67216722;
};
var $Hanf_arg21456727 = function(anf_arg9506726,anf_arg9486713,anf_fun9371182,args3761183,arity_DASH_check182675,body3781184,contract_DASH_checks183677,j_DASH_fun8180,ret3771186,rt_DASH_method173657,self3741187) {
var anf_fun9516738 = G(body3781184,"visit",L[810]);
var $z67306731 = D;
var $f67366737 = function(_) {
return R.isFunction(anf_fun9516738)?anf_fun9516738.app(self3741187):R.ffi.throwNonFunApp(L[809],anf_fun9516738,[self3741187]);
};
try {
if(--R.GAS > 0) {
$z67306731 = $f67366737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67366737,
"from":L[809]});
}
} catch($e67286729) {
if(R.isCont($e67286729)) {
var $ss67326733 = {"from":L[809],
"go":function(anf_bracket9526739) {
return $Hanf_bracket21446740(anf_bracket9526739,anf_arg9486713,anf_arg9506726,anf_fun9371182,args3761183,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_fun8180,ret3771186,rt_DASH_method173657,self3741187);
}};
$e67286729.stack[R.EXN_STACKHEIGHT++] = $ss67326733;
}
if(R.isPyretException($e67286729)) {
$e67286729.pyretStack.push(L[809]);
}
throw $e67286729;
}
var $ret67346735 = $Hanf_bracket21446740($z67306731,anf_arg9486713,anf_arg9506726,anf_fun9371182,args3761183,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_fun8180,ret3771186,rt_DASH_method173657,self3741187);
++R.GAS;
return $ret67346735;
};
var $Hanf_bracket21446740 = function(anf_bracket9526739,anf_arg9486713,anf_arg9506726,anf_fun9371182,args3761183,arity_DASH_check182675,contract_DASH_checks183677,j_DASH_fun8180,ret3771186,rt_DASH_method173657,self3741187) {
var anf_arg9536751 = G(anf_bracket9526739,"stmts",L[812]);
var $z67436744 = D;
var $f67496750 = function(_) {
return R.isFunction(contract_DASH_checks183677.$var)?contract_DASH_checks183677.$var.app(args3761183,ret3771186,anf_arg9536751,self3741187):R.ffi.throwNonFunApp(L[811],contract_DASH_checks183677.$var,[args3761183,ret3771186,anf_arg9536751,self3741187]);
};
try {
if(--R.GAS > 0) {
$z67436744 = $f67496750();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67496750,
"from":L[811]});
}
} catch($e67416742) {
if(R.isCont($e67416742)) {
var $ss67456746 = {"from":L[811],
"go":function(anf_arg9546752) {
return $Hanf_arg21436753(anf_arg9546752,anf_arg9486713,anf_arg9506726,anf_fun9371182,args3761183,arity_DASH_check182675,j_DASH_fun8180,rt_DASH_method173657);
}};
$e67416742.stack[R.EXN_STACKHEIGHT++] = $ss67456746;
}
if(R.isPyretException($e67416742)) {
$e67416742.pyretStack.push(L[811]);
}
throw $e67416742;
}
var $ret67476748 = $Hanf_arg21436753($z67436744,anf_arg9486713,anf_arg9506726,anf_fun9371182,args3761183,arity_DASH_check182675,j_DASH_fun8180,rt_DASH_method173657);
++R.GAS;
return $ret67476748;
};
var $Hanf_arg21436753 = function(anf_arg9546752,anf_arg9486713,anf_arg9506726,anf_fun9371182,args3761183,arity_DASH_check182675,j_DASH_fun8180,rt_DASH_method173657) {
var anf_fun9556764 = G(args3761183,"length",L[814]);
var $z67566757 = D;
var $f67626763 = function(_) {
return R.isFunction(anf_fun9556764)?anf_fun9556764.app():R.ffi.throwNonFunApp(L[813],anf_fun9556764,[]);
};
try {
if(--R.GAS > 0) {
$z67566757 = $f67626763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67626763,
"from":L[813]});
}
} catch($e67546755) {
if(R.isCont($e67546755)) {
var $ss67586759 = {"from":L[813],
"go":function(anf_arg9566765) {
return $Hanf_arg21426766(anf_arg9566765,anf_arg9486713,anf_arg9506726,anf_arg9546752,anf_fun9371182,arity_DASH_check182675,j_DASH_fun8180,rt_DASH_method173657);
}};
$e67546755.stack[R.EXN_STACKHEIGHT++] = $ss67586759;
}
if(R.isPyretException($e67546755)) {
$e67546755.pyretStack.push(L[813]);
}
throw $e67546755;
}
var $ret67606761 = $Hanf_arg21426766($z67566757,anf_arg9486713,anf_arg9506726,anf_arg9546752,anf_fun9371182,arity_DASH_check182675,j_DASH_fun8180,rt_DASH_method173657);
++R.GAS;
return $ret67606761;
};
var $Hanf_arg21426766 = function(anf_arg9566765,anf_arg9486713,anf_arg9506726,anf_arg9546752,anf_fun9371182,arity_DASH_check182675,j_DASH_fun8180,rt_DASH_method173657) {
var $z67696770 = D;
var $f67756776 = function(_) {
return R.isFunction(arity_DASH_check182675.$var)?arity_DASH_check182675.$var.app(anf_arg9506726,anf_arg9546752,anf_arg9566765):R.ffi.throwNonFunApp(L[815],arity_DASH_check182675.$var,[anf_arg9506726,anf_arg9546752,anf_arg9566765]);
};
try {
if(--R.GAS > 0) {
$z67696770 = $f67756776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67756776,
"from":L[815]});
}
} catch($e67676768) {
if(R.isCont($e67676768)) {
var $ss67716772 = {"from":L[815],
"go":function(anf_arg9576777) {
return $Hanf_arg21416778(anf_arg9576777,anf_arg9486713,anf_fun9371182,j_DASH_fun8180,rt_DASH_method173657);
}};
$e67676768.stack[R.EXN_STACKHEIGHT++] = $ss67716772;
}
if(R.isPyretException($e67676768)) {
$e67676768.pyretStack.push(L[815]);
}
throw $e67676768;
}
var $ret67736774 = $Hanf_arg21416778($z67696770,anf_arg9486713,anf_fun9371182,j_DASH_fun8180,rt_DASH_method173657);
++R.GAS;
return $ret67736774;
};
var $Hanf_arg21416778 = function(anf_arg9576777,anf_arg9486713,anf_fun9371182,j_DASH_fun8180,rt_DASH_method173657) {
var $z67816782 = D;
var $f67876788 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg9486713,anf_arg9576777):R.ffi.throwNonFunApp(L[816],j_DASH_fun8180,[anf_arg9486713,anf_arg9576777]);
};
try {
if(--R.GAS > 0) {
$z67816782 = $f67876788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67876788,
"from":L[816]});
}
} catch($e67796780) {
if(R.isCont($e67796780)) {
var $ss67836784 = {"from":L[816],
"go":function(anf_array_val9586789) {
return $Hanf_array_val21406790(anf_array_val9586789,anf_fun9371182,rt_DASH_method173657);
}};
$e67796780.stack[R.EXN_STACKHEIGHT++] = $ss67836784;
}
if(R.isPyretException($e67796780)) {
$e67796780.pyretStack.push(L[816]);
}
throw $e67796780;
}
var $ret67856786 = $Hanf_array_val21406790($z67816782,anf_fun9371182,rt_DASH_method173657);
++R.GAS;
return $ret67856786;
};
var $Hanf_array_val21406790 = function(anf_array_val9586789,anf_fun9371182,rt_DASH_method173657) {
var $z67936794 = D;
var $f67996800 = function(_) {
return R.isFunction(anf_fun9371182)?anf_fun9371182.app([anf_array_val9586789]):R.ffi.throwNonFunApp(L[158],anf_fun9371182,[[anf_array_val9586789]]);
};
try {
if(--R.GAS > 0) {
$z67936794 = $f67996800();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67996800,
"from":L[158]});
}
} catch($e67916792) {
if(R.isCont($e67916792)) {
var $ss67956796 = {"from":L[158],
"go":function(anf_arg9596801) {
return $Hanf_arg21396802(anf_arg9596801,rt_DASH_method173657);
}};
$e67916792.stack[R.EXN_STACKHEIGHT++] = $ss67956796;
}
if(R.isPyretException($e67916792)) {
$e67916792.pyretStack.push(L[158]);
}
throw $e67916792;
}
var $ret67976798 = $Hanf_arg21396802($z67936794,rt_DASH_method173657);
++R.GAS;
return $ret67976798;
};
var $Hanf_arg21396802 = function(anf_arg9596801,rt_DASH_method173657) {
var $z68056806 = D;
var $f68116812 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeFunction"),anf_arg9596801):R.ffi.throwNonFunApp(L[162],rt_DASH_method173657.$var,[("makeFunction"),anf_arg9596801]);
};
try {
if(--R.GAS > 0) {
$z68056806 = $f68116812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68116812,
"from":L[162]});
}
} catch($e68036804) {
if(R.isCont($e68036804)) {
var $ss68076808 = {"from":L[162],
"go":function(ann_DASH_check_DASH_temp9366813) {
return $Hann_DASH_check_DASH_temp21386814(ann_DASH_check_DASH_temp9366813);
}};
$e68036804.stack[R.EXN_STACKHEIGHT++] = $ss68076808;
}
if(R.isPyretException($e68036804)) {
$e68036804.pyretStack.push(L[162]);
}
throw $e68036804;
}
var $ret68096810 = $Hann_DASH_check_DASH_temp21386814($z68056806);
++R.GAS;
return $ret68096810;
};
var $Hann_DASH_check_DASH_temp21386814 = function(ann_DASH_check_DASH_temp9366813) {
return ann_DASH_check_DASH_temp9366813;
};
var $Hann_DASH_check_DASH_temp21376701 = function(ann_DASH_check_DASH_temp9436700) {
return ann_DASH_check_DASH_temp9436700;
};
var $Hanf_array_val21361206 = function(anf_array_val9321203,anf_fun9301204,field3731205,j_DASH_str8993,rt_DASH_method173657) {
var $z68176818 = D;
var $f68236824 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(field3731205):R.ffi.throwNonFunApp(L[817],j_DASH_str8993,[field3731205]);
};
try {
if(--R.GAS > 0) {
$z68176818 = $f68236824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68236824,
"from":L[817]});
}
} catch($e68156816) {
if(R.isCont($e68156816)) {
var $ss68196820 = {"from":L[817],
"go":function(anf_array_val9336825) {
return $Hanf_array_val21356826(anf_array_val9336825,anf_array_val9321203,anf_fun9301204,rt_DASH_method173657);
}};
$e68156816.stack[R.EXN_STACKHEIGHT++] = $ss68196820;
}
if(R.isPyretException($e68156816)) {
$e68156816.pyretStack.push(L[817]);
}
throw $e68156816;
}
var $ret68216822 = $Hanf_array_val21356826($z68176818,anf_array_val9321203,anf_fun9301204,rt_DASH_method173657);
++R.GAS;
return $ret68216822;
};
var $Hanf_array_val21356826 = function(anf_array_val9336825,anf_array_val9321203,anf_fun9301204,rt_DASH_method173657) {
var $z68296830 = D;
var $f68356836 = function(_) {
return R.isFunction(anf_fun9301204)?anf_fun9301204.app([anf_array_val9321203,anf_array_val9336825]):R.ffi.throwNonFunApp(L[165],anf_fun9301204,[[anf_array_val9321203,anf_array_val9336825]]);
};
try {
if(--R.GAS > 0) {
$z68296830 = $f68356836();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68356836,
"from":L[165]});
}
} catch($e68276828) {
if(R.isCont($e68276828)) {
var $ss68316832 = {"from":L[165],
"go":function(anf_arg9346837) {
return $Hanf_arg21346838(anf_arg9346837,rt_DASH_method173657);
}};
$e68276828.stack[R.EXN_STACKHEIGHT++] = $ss68316832;
}
if(R.isPyretException($e68276828)) {
$e68276828.pyretStack.push(L[165]);
}
throw $e68276828;
}
var $ret68336834 = $Hanf_arg21346838($z68296830,rt_DASH_method173657);
++R.GAS;
return $ret68336834;
};
var $Hanf_arg21346838 = function(anf_arg9346837,rt_DASH_method173657) {
var $z68416842 = D;
var $f68476848 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("getColonField"),anf_arg9346837):R.ffi.throwNonFunApp(L[169],rt_DASH_method173657.$var,[("getColonField"),anf_arg9346837]);
};
try {
if(--R.GAS > 0) {
$z68416842 = $f68476848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68476848,
"from":L[169]});
}
} catch($e68396840) {
if(R.isCont($e68396840)) {
var $ss68436844 = {"from":L[169],
"go":function(ann_DASH_check_DASH_temp9296849) {
return $Hann_DASH_check_DASH_temp21336850(ann_DASH_check_DASH_temp9296849);
}};
$e68396840.stack[R.EXN_STACKHEIGHT++] = $ss68436844;
}
if(R.isPyretException($e68396840)) {
$e68396840.pyretStack.push(L[169]);
}
throw $e68396840;
}
var $ret68456846 = $Hann_DASH_check_DASH_temp21336850($z68416842);
++R.GAS;
return $ret68456846;
};
var $Hann_DASH_check_DASH_temp21336850 = function(ann_DASH_check_DASH_temp9296849) {
return ann_DASH_check_DASH_temp9296849;
};
var $Hanf_arg21321224 = function(anf_arg9241221,field3691222,get_DASH_field169649,j_DASH_str8993,l3671223,self3661220) {
var $z68536854 = D;
var $f68596860 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(field3691222):R.ffi.throwNonFunApp(L[818],j_DASH_str8993,[field3691222]);
};
try {
if(--R.GAS > 0) {
$z68536854 = $f68596860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68596860,
"from":L[818]});
}
} catch($e68516852) {
if(R.isCont($e68516852)) {
var $ss68556856 = {"from":L[818],
"go":function(anf_arg9256861) {
return $Hanf_arg21316862(anf_arg9256861,anf_arg9241221,get_DASH_field169649,l3671223,self3661220);
}};
$e68516852.stack[R.EXN_STACKHEIGHT++] = $ss68556856;
}
if(R.isPyretException($e68516852)) {
$e68516852.pyretStack.push(L[818]);
}
throw $e68516852;
}
var $ret68576858 = $Hanf_arg21316862($z68536854,anf_arg9241221,get_DASH_field169649,l3671223,self3661220);
++R.GAS;
return $ret68576858;
};
var $Hanf_arg21316862 = function(anf_arg9256861,anf_arg9241221,get_DASH_field169649,l3671223,self3661220) {
var anf_fun9266873 = G(self3661220,"get-loc",L[820]);
var $z68656866 = D;
var $f68716872 = function(_) {
return R.isFunction(anf_fun9266873)?anf_fun9266873.app(l3671223):R.ffi.throwNonFunApp(L[819],anf_fun9266873,[l3671223]);
};
try {
if(--R.GAS > 0) {
$z68656866 = $f68716872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68716872,
"from":L[819]});
}
} catch($e68636864) {
if(R.isCont($e68636864)) {
var $ss68676868 = {"from":L[819],
"go":function(anf_arg9276874) {
return $Hanf_arg21306875(anf_arg9276874,anf_arg9241221,anf_arg9256861,get_DASH_field169649);
}};
$e68636864.stack[R.EXN_STACKHEIGHT++] = $ss68676868;
}
if(R.isPyretException($e68636864)) {
$e68636864.pyretStack.push(L[819]);
}
throw $e68636864;
}
var $ret68696870 = $Hanf_arg21306875($z68656866,anf_arg9241221,anf_arg9256861,get_DASH_field169649);
++R.GAS;
return $ret68696870;
};
var $Hanf_arg21306875 = function(anf_arg9276874,anf_arg9241221,anf_arg9256861,get_DASH_field169649) {
var $z68786879 = D;
var $f68846885 = function(_) {
return R.isFunction(get_DASH_field169649.$var)?get_DASH_field169649.$var.app(anf_arg9241221,anf_arg9256861,anf_arg9276874):R.ffi.throwNonFunApp(L[175],get_DASH_field169649.$var,[anf_arg9241221,anf_arg9256861,anf_arg9276874]);
};
try {
if(--R.GAS > 0) {
$z68786879 = $f68846885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68846885,
"from":L[175]});
}
} catch($e68766877) {
if(R.isCont($e68766877)) {
var $ss68806881 = {"from":L[175],
"go":function(ann_DASH_check_DASH_temp9226886) {
return $Hann_DASH_check_DASH_temp21296887(ann_DASH_check_DASH_temp9226886);
}};
$e68766877.stack[R.EXN_STACKHEIGHT++] = $ss68806881;
}
if(R.isPyretException($e68766877)) {
$e68766877.pyretStack.push(L[175]);
}
throw $e68766877;
}
var $ret68826883 = $Hann_DASH_check_DASH_temp21296887($z68786879);
++R.GAS;
return $ret68826883;
};
var $Hann_DASH_check_DASH_temp21296887 = function(ann_DASH_check_DASH_temp9226886) {
return ann_DASH_check_DASH_temp9226886;
};
var $Hanf_arg21281240 = function(anf_arg9121238,fields3651239,j_DASH_method8486,j_DASH_obj9690,list35101,self3621237) {
var anf_fun9136901 = G(list35101,"make",L[824]);
var anf_fun9146898 = G(fields3651239,"map",L[823]);
var anf_arg9176899 = R.makeFunction(function(recv_DASH_566903) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[822],1,arguments);
}
var anf_fun9166914 = G(recv_DASH_566903,"visit",L[822]);
var $z69066907 = D;
var $f69126913 = function(_) {
return R.isFunction(anf_fun9166914)?anf_fun9166914.app(self3621237):R.ffi.throwNonFunApp(L[822],anf_fun9166914,[self3621237]);
};
try {
if(--R.GAS > 0) {
$z69066907 = $f69126913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69126913,
"from":L[822]});
}
} catch($e69046905) {
if(R.isCont($e69046905)) {
var $ss69086909 = {"from":L[822],
"go":function(ann_DASH_check_DASH_temp9156915) {
return $Hann_DASH_check_DASH_temp21236916(ann_DASH_check_DASH_temp9156915);
}};
$e69046905.stack[R.EXN_STACKHEIGHT++] = $ss69086909;
}
if(R.isPyretException($e69046905)) {
$e69046905.pyretStack.push(L[822]);
}
throw $e69046905;
}
var $ret69106911 = $Hann_DASH_check_DASH_temp21236916($z69066907);
++R.GAS;
return $ret69106911;
});
var $z68906891 = D;
var $f68966897 = function(_) {
return R.isFunction(anf_fun9146898)?anf_fun9146898.app(anf_arg9176899):R.ffi.throwNonFunApp(L[821],anf_fun9146898,[anf_arg9176899]);
};
try {
if(--R.GAS > 0) {
$z68906891 = $f68966897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68966897,
"from":L[821]});
}
} catch($e68886889) {
if(R.isCont($e68886889)) {
var $ss68926893 = {"from":L[821],
"go":function(anf_arg9186900) {
return $Hanf_arg21276902(anf_arg9186900,anf_arg9121238,anf_fun9136901,j_DASH_method8486,j_DASH_obj9690);
}};
$e68886889.stack[R.EXN_STACKHEIGHT++] = $ss68926893;
}
if(R.isPyretException($e68886889)) {
$e68886889.pyretStack.push(L[821]);
}
throw $e68886889;
}
var $ret68946895 = $Hanf_arg21276902($z68906891,anf_arg9121238,anf_fun9136901,j_DASH_method8486,j_DASH_obj9690);
++R.GAS;
return $ret68946895;
};
var $Hanf_arg21276902 = function(anf_arg9186900,anf_arg9121238,anf_fun9136901,j_DASH_method8486,j_DASH_obj9690) {
var $z69196920 = D;
var $f69256926 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg9186900):R.ffi.throwNonFunApp(L[825],j_DASH_obj9690,[anf_arg9186900]);
};
try {
if(--R.GAS > 0) {
$z69196920 = $f69256926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69256926,
"from":L[825]});
}
} catch($e69176918) {
if(R.isCont($e69176918)) {
var $ss69216922 = {"from":L[825],
"go":function(anf_array_val9196927) {
return $Hanf_array_val21266928(anf_array_val9196927,anf_arg9121238,anf_fun9136901,j_DASH_method8486);
}};
$e69176918.stack[R.EXN_STACKHEIGHT++] = $ss69216922;
}
if(R.isPyretException($e69176918)) {
$e69176918.pyretStack.push(L[825]);
}
throw $e69176918;
}
var $ret69236924 = $Hanf_array_val21266928($z69196920,anf_arg9121238,anf_fun9136901,j_DASH_method8486);
++R.GAS;
return $ret69236924;
};
var $Hanf_array_val21266928 = function(anf_array_val9196927,anf_arg9121238,anf_fun9136901,j_DASH_method8486) {
var $z69316932 = D;
var $f69376938 = function(_) {
return R.isFunction(anf_fun9136901)?anf_fun9136901.app([anf_array_val9196927]):R.ffi.throwNonFunApp(L[824],anf_fun9136901,[[anf_array_val9196927]]);
};
try {
if(--R.GAS > 0) {
$z69316932 = $f69376938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69376938,
"from":L[824]});
}
} catch($e69296930) {
if(R.isCont($e69296930)) {
var $ss69336934 = {"from":L[824],
"go":function(anf_arg9206939) {
return $Hanf_arg21256940(anf_arg9206939,anf_arg9121238,j_DASH_method8486);
}};
$e69296930.stack[R.EXN_STACKHEIGHT++] = $ss69336934;
}
if(R.isPyretException($e69296930)) {
$e69296930.pyretStack.push(L[824]);
}
throw $e69296930;
}
var $ret69356936 = $Hanf_arg21256940($z69316932,anf_arg9121238,j_DASH_method8486);
++R.GAS;
return $ret69356936;
};
var $Hanf_arg21256940 = function(anf_arg9206939,anf_arg9121238,j_DASH_method8486) {
var $z69436944 = D;
var $f69496950 = function(_) {
return R.isFunction(j_DASH_method8486)?j_DASH_method8486.app(anf_arg9121238,("extendWith"),anf_arg9206939):R.ffi.throwNonFunApp(L[181],j_DASH_method8486,[anf_arg9121238,("extendWith"),anf_arg9206939]);
};
try {
if(--R.GAS > 0) {
$z69436944 = $f69496950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69496950,
"from":L[181]});
}
} catch($e69416942) {
if(R.isCont($e69416942)) {
var $ss69456946 = {"from":L[181],
"go":function(ann_DASH_check_DASH_temp9106951) {
return $Hann_DASH_check_DASH_temp21246952(ann_DASH_check_DASH_temp9106951);
}};
$e69416942.stack[R.EXN_STACKHEIGHT++] = $ss69456946;
}
if(R.isPyretException($e69416942)) {
$e69416942.pyretStack.push(L[181]);
}
throw $e69416942;
}
var $ret69476948 = $Hann_DASH_check_DASH_temp21246952($z69436944);
++R.GAS;
return $ret69476948;
};
var $Hann_DASH_check_DASH_temp21246952 = function(ann_DASH_check_DASH_temp9106951) {
return ann_DASH_check_DASH_temp9106951;
};
var $Hann_DASH_check_DASH_temp21236916 = function(ann_DASH_check_DASH_temp9156915) {
return ann_DASH_check_DASH_temp9156915;
};
var $Hanf_arg21221257 = function(anf_arg9061255,anf_fun8981256,j_DASH_obj9690,rt_DASH_method173657) {
var $z69556956 = D;
var $f69616962 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg9061255):R.ffi.throwNonFunApp(L[826],j_DASH_obj9690,[anf_arg9061255]);
};
try {
if(--R.GAS > 0) {
$z69556956 = $f69616962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69616962,
"from":L[826]});
}
} catch($e69536954) {
if(R.isCont($e69536954)) {
var $ss69576958 = {"from":L[826],
"go":function(anf_array_val9076963) {
return $Hanf_array_val21216964(anf_array_val9076963,anf_fun8981256,rt_DASH_method173657);
}};
$e69536954.stack[R.EXN_STACKHEIGHT++] = $ss69576958;
}
if(R.isPyretException($e69536954)) {
$e69536954.pyretStack.push(L[826]);
}
throw $e69536954;
}
var $ret69596960 = $Hanf_array_val21216964($z69556956,anf_fun8981256,rt_DASH_method173657);
++R.GAS;
return $ret69596960;
};
var $Hanf_array_val21216964 = function(anf_array_val9076963,anf_fun8981256,rt_DASH_method173657) {
var $z69676968 = D;
var $f69736974 = function(_) {
return R.isFunction(anf_fun8981256)?anf_fun8981256.app([anf_array_val9076963]):R.ffi.throwNonFunApp(L[189],anf_fun8981256,[[anf_array_val9076963]]);
};
try {
if(--R.GAS > 0) {
$z69676968 = $f69736974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69736974,
"from":L[189]});
}
} catch($e69656966) {
if(R.isCont($e69656966)) {
var $ss69696970 = {"from":L[189],
"go":function(anf_arg9086975) {
return $Hanf_arg21206976(anf_arg9086975,rt_DASH_method173657);
}};
$e69656966.stack[R.EXN_STACKHEIGHT++] = $ss69696970;
}
if(R.isPyretException($e69656966)) {
$e69656966.pyretStack.push(L[189]);
}
throw $e69656966;
}
var $ret69716972 = $Hanf_arg21206976($z69676968,rt_DASH_method173657);
++R.GAS;
return $ret69716972;
};
var $Hanf_arg21206976 = function(anf_arg9086975,rt_DASH_method173657) {
var $z69796980 = D;
var $f69856986 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeObject"),anf_arg9086975):R.ffi.throwNonFunApp(L[192],rt_DASH_method173657.$var,[("makeObject"),anf_arg9086975]);
};
try {
if(--R.GAS > 0) {
$z69796980 = $f69856986();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69856986,
"from":L[192]});
}
} catch($e69776978) {
if(R.isCont($e69776978)) {
var $ss69816982 = {"from":L[192],
"go":function(ann_DASH_check_DASH_temp8976987) {
return $Hann_DASH_check_DASH_temp21196988(ann_DASH_check_DASH_temp8976987);
}};
$e69776978.stack[R.EXN_STACKHEIGHT++] = $ss69816982;
}
if(R.isPyretException($e69776978)) {
$e69776978.pyretStack.push(L[192]);
}
throw $e69776978;
}
var $ret69836984 = $Hann_DASH_check_DASH_temp21196988($z69796980);
++R.GAS;
return $ret69836984;
};
var $Hann_DASH_check_DASH_temp21196988 = function(ann_DASH_check_DASH_temp8976987) {
return ann_DASH_check_DASH_temp8976987;
};
var $Hanf_arg21181273 = function(anf_arg9041271,anf_arg9011272,j_DASH_field9979) {
var $z69916992 = D;
var $f69976998 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(anf_arg9011272,anf_arg9041271):R.ffi.throwNonFunApp(L[183],j_DASH_field9979,[anf_arg9011272,anf_arg9041271]);
};
try {
if(--R.GAS > 0) {
$z69916992 = $f69976998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69976998,
"from":L[183]});
}
} catch($e69896990) {
if(R.isCont($e69896990)) {
var $ss69936994 = {"from":L[183],
"go":function(ann_DASH_check_DASH_temp9006999) {
return $Hann_DASH_check_DASH_temp21177000(ann_DASH_check_DASH_temp9006999);
}};
$e69896990.stack[R.EXN_STACKHEIGHT++] = $ss69936994;
}
if(R.isPyretException($e69896990)) {
$e69896990.pyretStack.push(L[183]);
}
throw $e69896990;
}
var $ret69956996 = $Hann_DASH_check_DASH_temp21177000($z69916992);
++R.GAS;
return $ret69956996;
};
var $Hann_DASH_check_DASH_temp21177000 = function(ann_DASH_check_DASH_temp9006999) {
return ann_DASH_check_DASH_temp9006999;
};
var $Hanf_arg21161291 = function(anf_arg8951289,f3561290,rt_DASH_method173657) {
var $z70037004 = D;
var $f70097010 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(f3561290,anf_arg8951289):R.ffi.throwNonFunApp(L[199],rt_DASH_method173657.$var,[f3561290,anf_arg8951289]);
};
try {
if(--R.GAS > 0) {
$z70037004 = $f70097010();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70097010,
"from":L[199]});
}
} catch($e70017002) {
if(R.isCont($e70017002)) {
var $ss70057006 = {"from":L[199],
"go":function(ann_DASH_check_DASH_temp8907011) {
return $Hann_DASH_check_DASH_temp21157012(ann_DASH_check_DASH_temp8907011);
}};
$e70017002.stack[R.EXN_STACKHEIGHT++] = $ss70057006;
}
if(R.isPyretException($e70017002)) {
$e70017002.pyretStack.push(L[199]);
}
throw $e70017002;
}
var $ret70077008 = $Hann_DASH_check_DASH_temp21157012($z70037004);
++R.GAS;
return $ret70077008;
};
var $Hann_DASH_check_DASH_temp21157012 = function(ann_DASH_check_DASH_temp8907011) {
return ann_DASH_check_DASH_temp8907011;
};
var $Hann_DASH_check_DASH_temp21141306 = function(ann_DASH_check_DASH_temp8921305) {
return ann_DASH_check_DASH_temp8921305;
};
var $Hanf_arg21131325 = function(anf_arg8811321,app174659,args3531322,f3521323,self3501324) {
var anf_fun8827023 = G(f3521323,"visit",L[828]);
var $z70157016 = D;
var $f70217022 = function(_) {
return R.isFunction(anf_fun8827023)?anf_fun8827023.app(self3501324):R.ffi.throwNonFunApp(L[827],anf_fun8827023,[self3501324]);
};
try {
if(--R.GAS > 0) {
$z70157016 = $f70217022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70217022,
"from":L[827]});
}
} catch($e70137014) {
if(R.isCont($e70137014)) {
var $ss70177018 = {"from":L[827],
"go":function(anf_arg8837024) {
return $Hanf_arg21127025(anf_arg8837024,anf_arg8811321,app174659,args3531322,self3501324);
}};
$e70137014.stack[R.EXN_STACKHEIGHT++] = $ss70177018;
}
if(R.isPyretException($e70137014)) {
$e70137014.pyretStack.push(L[827]);
}
throw $e70137014;
}
var $ret70197020 = $Hanf_arg21127025($z70157016,anf_arg8811321,app174659,args3531322,self3501324);
++R.GAS;
return $ret70197020;
};
var $Hanf_arg21127025 = function(anf_arg8837024,anf_arg8811321,app174659,args3531322,self3501324) {
var anf_fun8847036 = G(args3531322,"map",L[831]);
var anf_arg8877037 = R.makeFunction(function(recv_DASH_547040) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[830],1,arguments);
}
var anf_fun8867051 = G(recv_DASH_547040,"visit",L[830]);
var $z70437044 = D;
var $f70497050 = function(_) {
return R.isFunction(anf_fun8867051)?anf_fun8867051.app(self3501324):R.ffi.throwNonFunApp(L[830],anf_fun8867051,[self3501324]);
};
try {
if(--R.GAS > 0) {
$z70437044 = $f70497050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70497050,
"from":L[830]});
}
} catch($e70417042) {
if(R.isCont($e70417042)) {
var $ss70457046 = {"from":L[830],
"go":function(ann_DASH_check_DASH_temp8857052) {
return $Hann_DASH_check_DASH_temp21097053(ann_DASH_check_DASH_temp8857052);
}};
$e70417042.stack[R.EXN_STACKHEIGHT++] = $ss70457046;
}
if(R.isPyretException($e70417042)) {
$e70417042.pyretStack.push(L[830]);
}
throw $e70417042;
}
var $ret70477048 = $Hann_DASH_check_DASH_temp21097053($z70437044);
++R.GAS;
return $ret70477048;
});
var $z70287029 = D;
var $f70347035 = function(_) {
return R.isFunction(anf_fun8847036)?anf_fun8847036.app(anf_arg8877037):R.ffi.throwNonFunApp(L[829],anf_fun8847036,[anf_arg8877037]);
};
try {
if(--R.GAS > 0) {
$z70287029 = $f70347035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70347035,
"from":L[829]});
}
} catch($e70267027) {
if(R.isCont($e70267027)) {
var $ss70307031 = {"from":L[829],
"go":function(anf_arg8887038) {
return $Hanf_arg21117039(anf_arg8887038,anf_arg8811321,anf_arg8837024,app174659);
}};
$e70267027.stack[R.EXN_STACKHEIGHT++] = $ss70307031;
}
if(R.isPyretException($e70267027)) {
$e70267027.pyretStack.push(L[829]);
}
throw $e70267027;
}
var $ret70327033 = $Hanf_arg21117039($z70287029,anf_arg8811321,anf_arg8837024,app174659);
++R.GAS;
return $ret70327033;
};
var $Hanf_arg21117039 = function(anf_arg8887038,anf_arg8811321,anf_arg8837024,app174659) {
var $z70567057 = D;
var $f70627063 = function(_) {
return R.isFunction(app174659.$var)?app174659.$var.app(anf_arg8811321,anf_arg8837024,anf_arg8887038):R.ffi.throwNonFunApp(L[205],app174659.$var,[anf_arg8811321,anf_arg8837024,anf_arg8887038]);
};
try {
if(--R.GAS > 0) {
$z70567057 = $f70627063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70627063,
"from":L[205]});
}
} catch($e70547055) {
if(R.isCont($e70547055)) {
var $ss70587059 = {"from":L[205],
"go":function(ann_DASH_check_DASH_temp8797064) {
return $Hann_DASH_check_DASH_temp21107065(ann_DASH_check_DASH_temp8797064);
}};
$e70547055.stack[R.EXN_STACKHEIGHT++] = $ss70587059;
}
if(R.isPyretException($e70547055)) {
$e70547055.pyretStack.push(L[205]);
}
throw $e70547055;
}
var $ret70607061 = $Hann_DASH_check_DASH_temp21107065($z70567057);
++R.GAS;
return $ret70607061;
};
var $Hann_DASH_check_DASH_temp21107065 = function(ann_DASH_check_DASH_temp8797064) {
return ann_DASH_check_DASH_temp8797064;
};
var $Hann_DASH_check_DASH_temp21097053 = function(ann_DASH_check_DASH_temp8857052) {
return ann_DASH_check_DASH_temp8857052;
};
var $Hanf_arg21081340 = function(anf_arg8731337,j_DASH_dot_DASH_assign10074,j_DASH_id8381,js_DASH_id_DASH_of162700,self3461338,value3491339) {
var $z70687069 = D;
var $f70747075 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg8731337):R.ffi.throwNonFunApp(L[832],js_DASH_id_DASH_of162700,[anf_arg8731337]);
};
try {
if(--R.GAS > 0) {
$z70687069 = $f70747075();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70747075,
"from":L[832]});
}
} catch($e70667067) {
if(R.isCont($e70667067)) {
var $ss70707071 = {"from":L[832],
"go":function(anf_arg8747076) {
return $Hanf_arg21077077(anf_arg8747076,j_DASH_dot_DASH_assign10074,j_DASH_id8381,self3461338,value3491339);
}};
$e70667067.stack[R.EXN_STACKHEIGHT++] = $ss70707071;
}
if(R.isPyretException($e70667067)) {
$e70667067.pyretStack.push(L[832]);
}
throw $e70667067;
}
var $ret70727073 = $Hanf_arg21077077($z70687069,j_DASH_dot_DASH_assign10074,j_DASH_id8381,self3461338,value3491339);
++R.GAS;
return $ret70727073;
};
var $Hanf_arg21077077 = function(anf_arg8747076,j_DASH_dot_DASH_assign10074,j_DASH_id8381,self3461338,value3491339) {
var $z70807081 = D;
var $f70867087 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg8747076):R.ffi.throwNonFunApp(L[833],j_DASH_id8381,[anf_arg8747076]);
};
try {
if(--R.GAS > 0) {
$z70807081 = $f70867087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70867087,
"from":L[833]});
}
} catch($e70787079) {
if(R.isCont($e70787079)) {
var $ss70827083 = {"from":L[833],
"go":function(anf_arg8757088) {
return $Hanf_arg21067089(anf_arg8757088,j_DASH_dot_DASH_assign10074,self3461338,value3491339);
}};
$e70787079.stack[R.EXN_STACKHEIGHT++] = $ss70827083;
}
if(R.isPyretException($e70787079)) {
$e70787079.pyretStack.push(L[833]);
}
throw $e70787079;
}
var $ret70847085 = $Hanf_arg21067089($z70807081,j_DASH_dot_DASH_assign10074,self3461338,value3491339);
++R.GAS;
return $ret70847085;
};
var $Hanf_arg21067089 = function(anf_arg8757088,j_DASH_dot_DASH_assign10074,self3461338,value3491339) {
var anf_fun8767100 = G(value3491339,"visit",L[835]);
var $z70927093 = D;
var $f70987099 = function(_) {
return R.isFunction(anf_fun8767100)?anf_fun8767100.app(self3461338):R.ffi.throwNonFunApp(L[834],anf_fun8767100,[self3461338]);
};
try {
if(--R.GAS > 0) {
$z70927093 = $f70987099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70987099,
"from":L[834]});
}
} catch($e70907091) {
if(R.isCont($e70907091)) {
var $ss70947095 = {"from":L[834],
"go":function(anf_arg8777101) {
return $Hanf_arg21057102(anf_arg8777101,anf_arg8757088,j_DASH_dot_DASH_assign10074);
}};
$e70907091.stack[R.EXN_STACKHEIGHT++] = $ss70947095;
}
if(R.isPyretException($e70907091)) {
$e70907091.pyretStack.push(L[834]);
}
throw $e70907091;
}
var $ret70967097 = $Hanf_arg21057102($z70927093,anf_arg8757088,j_DASH_dot_DASH_assign10074);
++R.GAS;
return $ret70967097;
};
var $Hanf_arg21057102 = function(anf_arg8777101,anf_arg8757088,j_DASH_dot_DASH_assign10074) {
var $z71057106 = D;
var $f71117112 = function(_) {
return R.isFunction(j_DASH_dot_DASH_assign10074)?j_DASH_dot_DASH_assign10074.app(anf_arg8757088,("$var"),anf_arg8777101):R.ffi.throwNonFunApp(L[211],j_DASH_dot_DASH_assign10074,[anf_arg8757088,("$var"),anf_arg8777101]);
};
try {
if(--R.GAS > 0) {
$z71057106 = $f71117112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71117112,
"from":L[211]});
}
} catch($e71037104) {
if(R.isCont($e71037104)) {
var $ss71077108 = {"from":L[211],
"go":function(ann_DASH_check_DASH_temp8717113) {
return $Hann_DASH_check_DASH_temp21047114(ann_DASH_check_DASH_temp8717113);
}};
$e71037104.stack[R.EXN_STACKHEIGHT++] = $ss71077108;
}
if(R.isPyretException($e71037104)) {
$e71037104.pyretStack.push(L[211]);
}
throw $e71037104;
}
var $ret71097110 = $Hann_DASH_check_DASH_temp21047114($z71057106);
++R.GAS;
return $ret71097110;
};
var $Hann_DASH_check_DASH_temp21047114 = function(ann_DASH_check_DASH_temp8717113) {
return ann_DASH_check_DASH_temp8717113;
};
var $Hanf_arg21031357 = function(anf_arg8671355,anf_fun8651356,j_DASH_block8570,j_DASH_return9092) {
var $z71177118 = D;
var $f71237124 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg8671355):R.ffi.throwNonFunApp(L[836],j_DASH_return9092,[anf_arg8671355]);
};
try {
if(--R.GAS > 0) {
$z71177118 = $f71237124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71237124,
"from":L[836]});
}
} catch($e71157116) {
if(R.isCont($e71157116)) {
var $ss71197120 = {"from":L[836],
"go":function(anf_array_val8687125) {
return $Hanf_array_val21027126(anf_array_val8687125,anf_fun8651356,j_DASH_block8570);
}};
$e71157116.stack[R.EXN_STACKHEIGHT++] = $ss71197120;
}
if(R.isPyretException($e71157116)) {
$e71157116.pyretStack.push(L[836]);
}
throw $e71157116;
}
var $ret71217122 = $Hanf_array_val21027126($z71177118,anf_fun8651356,j_DASH_block8570);
++R.GAS;
return $ret71217122;
};
var $Hanf_array_val21027126 = function(anf_array_val8687125,anf_fun8651356,j_DASH_block8570) {
var $z71297130 = D;
var $f71357136 = function(_) {
return R.isFunction(anf_fun8651356)?anf_fun8651356.app([anf_array_val8687125]):R.ffi.throwNonFunApp(L[214],anf_fun8651356,[[anf_array_val8687125]]);
};
try {
if(--R.GAS > 0) {
$z71297130 = $f71357136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71357136,
"from":L[214]});
}
} catch($e71277128) {
if(R.isCont($e71277128)) {
var $ss71317132 = {"from":L[214],
"go":function(anf_arg8697137) {
return $Hanf_arg21017138(anf_arg8697137,j_DASH_block8570);
}};
$e71277128.stack[R.EXN_STACKHEIGHT++] = $ss71317132;
}
if(R.isPyretException($e71277128)) {
$e71277128.pyretStack.push(L[214]);
}
throw $e71277128;
}
var $ret71337134 = $Hanf_arg21017138($z71297130,j_DASH_block8570);
++R.GAS;
return $ret71337134;
};
var $Hanf_arg21017138 = function(anf_arg8697137,j_DASH_block8570) {
var $z71417142 = D;
var $f71477148 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg8697137):R.ffi.throwNonFunApp(L[216],j_DASH_block8570,[anf_arg8697137]);
};
try {
if(--R.GAS > 0) {
$z71417142 = $f71477148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71477148,
"from":L[216]});
}
} catch($e71397140) {
if(R.isCont($e71397140)) {
var $ss71437144 = {"from":L[216],
"go":function(ann_DASH_check_DASH_temp8647149) {
return $Hann_DASH_check_DASH_temp21007150(ann_DASH_check_DASH_temp8647149);
}};
$e71397140.stack[R.EXN_STACKHEIGHT++] = $ss71437144;
}
if(R.isPyretException($e71397140)) {
$e71397140.pyretStack.push(L[216]);
}
throw $e71397140;
}
var $ret71457146 = $Hann_DASH_check_DASH_temp21007150($z71417142);
++R.GAS;
return $ret71457146;
};
var $Hann_DASH_check_DASH_temp21007150 = function(ann_DASH_check_DASH_temp8647149) {
return ann_DASH_check_DASH_temp8647149;
};
var $Hcompiled_DASH_consq20991374 = function(compiled_DASH_consq3421371,alt3411372,cond3391373,j_DASH_block8570,j_DASH_if9283,list35101,rt_DASH_method173657,self3371370) {
var anf_fun8547161 = G(alt3411372,"visit",L[838]);
var $z71537154 = D;
var $f71597160 = function(_) {
return R.isFunction(anf_fun8547161)?anf_fun8547161.app(self3371370):R.ffi.throwNonFunApp(L[837],anf_fun8547161,[self3371370]);
};
try {
if(--R.GAS > 0) {
$z71537154 = $f71597160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71597160,
"from":L[837]});
}
} catch($e71517152) {
if(R.isCont($e71517152)) {
var $ss71557156 = {"from":L[837],
"go":function(compiled_DASH_alt3437162) {
return $Hcompiled_DASH_alt20987163(compiled_DASH_alt3437162,compiled_DASH_consq3421371,cond3391373,j_DASH_block8570,j_DASH_if9283,list35101,rt_DASH_method173657,self3371370);
}};
$e71517152.stack[R.EXN_STACKHEIGHT++] = $ss71557156;
}
if(R.isPyretException($e71517152)) {
$e71517152.pyretStack.push(L[837]);
}
throw $e71517152;
}
var $ret71577158 = $Hcompiled_DASH_alt20987163($z71537154,compiled_DASH_consq3421371,cond3391373,j_DASH_block8570,j_DASH_if9283,list35101,rt_DASH_method173657,self3371370);
++R.GAS;
return $ret71577158;
};
var $Hcompiled_DASH_alt20987163 = function(compiled_DASH_alt3437162,compiled_DASH_consq3421371,cond3391373,j_DASH_block8570,j_DASH_if9283,list35101,rt_DASH_method173657,self3371370) {
var anf_fun8557176 = G(list35101,"make",L[842]);
var anf_fun8567177 = G(list35101,"make",L[841]);
var anf_fun8577174 = G(cond3391373,"visit",L[840]);
var $z71667167 = D;
var $f71727173 = function(_) {
return R.isFunction(anf_fun8577174)?anf_fun8577174.app(self3371370):R.ffi.throwNonFunApp(L[839],anf_fun8577174,[self3371370]);
};
try {
if(--R.GAS > 0) {
$z71667167 = $f71727173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71727173,
"from":L[839]});
}
} catch($e71647165) {
if(R.isCont($e71647165)) {
var $ss71687169 = {"from":L[839],
"go":function(anf_array_val8587175) {
return $Hanf_array_val20977178(anf_array_val8587175,anf_fun8557176,anf_fun8567177,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283,rt_DASH_method173657);
}};
$e71647165.stack[R.EXN_STACKHEIGHT++] = $ss71687169;
}
if(R.isPyretException($e71647165)) {
$e71647165.pyretStack.push(L[839]);
}
throw $e71647165;
}
var $ret71707171 = $Hanf_array_val20977178($z71667167,anf_fun8557176,anf_fun8567177,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283,rt_DASH_method173657);
++R.GAS;
return $ret71707171;
};
var $Hanf_array_val20977178 = function(anf_array_val8587175,anf_fun8557176,anf_fun8567177,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283,rt_DASH_method173657) {
var $z71817182 = D;
var $f71877188 = function(_) {
return R.isFunction(anf_fun8567177)?anf_fun8567177.app([anf_array_val8587175]):R.ffi.throwNonFunApp(L[841],anf_fun8567177,[[anf_array_val8587175]]);
};
try {
if(--R.GAS > 0) {
$z71817182 = $f71877188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71877188,
"from":L[841]});
}
} catch($e71797180) {
if(R.isCont($e71797180)) {
var $ss71837184 = {"from":L[841],
"go":function(anf_arg8597189) {
return $Hanf_arg20967190(anf_arg8597189,anf_fun8557176,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283,rt_DASH_method173657);
}};
$e71797180.stack[R.EXN_STACKHEIGHT++] = $ss71837184;
}
if(R.isPyretException($e71797180)) {
$e71797180.pyretStack.push(L[841]);
}
throw $e71797180;
}
var $ret71857186 = $Hanf_arg20967190($z71817182,anf_fun8557176,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283,rt_DASH_method173657);
++R.GAS;
return $ret71857186;
};
var $Hanf_arg20967190 = function(anf_arg8597189,anf_fun8557176,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283,rt_DASH_method173657) {
var $z71937194 = D;
var $f71997200 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("isPyretTrue"),anf_arg8597189):R.ffi.throwNonFunApp(L[843],rt_DASH_method173657.$var,[("isPyretTrue"),anf_arg8597189]);
};
try {
if(--R.GAS > 0) {
$z71937194 = $f71997200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71997200,
"from":L[843]});
}
} catch($e71917192) {
if(R.isCont($e71917192)) {
var $ss71957196 = {"from":L[843],
"go":function(anf_arg8607201) {
return $Hanf_arg20957202(anf_arg8607201,anf_fun8557176,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283);
}};
$e71917192.stack[R.EXN_STACKHEIGHT++] = $ss71957196;
}
if(R.isPyretException($e71917192)) {
$e71917192.pyretStack.push(L[843]);
}
throw $e71917192;
}
var $ret71977198 = $Hanf_arg20957202($z71937194,anf_fun8557176,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283);
++R.GAS;
return $ret71977198;
};
var $Hanf_arg20957202 = function(anf_arg8607201,anf_fun8557176,compiled_DASH_alt3437162,compiled_DASH_consq3421371,j_DASH_block8570,j_DASH_if9283) {
var $z72057206 = D;
var $f72117212 = function(_) {
return R.isFunction(j_DASH_if9283)?j_DASH_if9283.app(anf_arg8607201,compiled_DASH_consq3421371,compiled_DASH_alt3437162):R.ffi.throwNonFunApp(L[844],j_DASH_if9283,[anf_arg8607201,compiled_DASH_consq3421371,compiled_DASH_alt3437162]);
};
try {
if(--R.GAS > 0) {
$z72057206 = $f72117212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72117212,
"from":L[844]});
}
} catch($e72037204) {
if(R.isCont($e72037204)) {
var $ss72077208 = {"from":L[844],
"go":function(anf_array_val8617213) {
return $Hanf_array_val20947214(anf_array_val8617213,anf_fun8557176,j_DASH_block8570);
}};
$e72037204.stack[R.EXN_STACKHEIGHT++] = $ss72077208;
}
if(R.isPyretException($e72037204)) {
$e72037204.pyretStack.push(L[844]);
}
throw $e72037204;
}
var $ret72097210 = $Hanf_array_val20947214($z72057206,anf_fun8557176,j_DASH_block8570);
++R.GAS;
return $ret72097210;
};
var $Hanf_array_val20947214 = function(anf_array_val8617213,anf_fun8557176,j_DASH_block8570) {
var $z72177218 = D;
var $f72237224 = function(_) {
return R.isFunction(anf_fun8557176)?anf_fun8557176.app([anf_array_val8617213]):R.ffi.throwNonFunApp(L[842],anf_fun8557176,[[anf_array_val8617213]]);
};
try {
if(--R.GAS > 0) {
$z72177218 = $f72237224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72237224,
"from":L[842]});
}
} catch($e72157216) {
if(R.isCont($e72157216)) {
var $ss72197220 = {"from":L[842],
"go":function(anf_arg8627225) {
return $Hanf_arg20937226(anf_arg8627225,j_DASH_block8570);
}};
$e72157216.stack[R.EXN_STACKHEIGHT++] = $ss72197220;
}
if(R.isPyretException($e72157216)) {
$e72157216.pyretStack.push(L[842]);
}
throw $e72157216;
}
var $ret72217222 = $Hanf_arg20937226($z72177218,j_DASH_block8570);
++R.GAS;
return $ret72217222;
};
var $Hanf_arg20937226 = function(anf_arg8627225,j_DASH_block8570) {
var $z72297230 = D;
var $f72357236 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg8627225):R.ffi.throwNonFunApp(L[223],j_DASH_block8570,[anf_arg8627225]);
};
try {
if(--R.GAS > 0) {
$z72297230 = $f72357236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72357236,
"from":L[223]});
}
} catch($e72277228) {
if(R.isCont($e72277228)) {
var $ss72317232 = {"from":L[223],
"go":function(ann_DASH_check_DASH_temp8527237) {
return $Hann_DASH_check_DASH_temp20927238(ann_DASH_check_DASH_temp8527237);
}};
$e72277228.stack[R.EXN_STACKHEIGHT++] = $ss72317232;
}
if(R.isPyretException($e72277228)) {
$e72277228.pyretStack.push(L[223]);
}
throw $e72277228;
}
var $ret72337234 = $Hann_DASH_check_DASH_temp20927238($z72297230);
++R.GAS;
return $ret72337234;
};
var $Hann_DASH_check_DASH_temp20927238 = function(ann_DASH_check_DASH_temp8527237) {
return ann_DASH_check_DASH_temp8527237;
};
var $He1_DASH_visit20911391 = function(e1_DASH_visit3361389,J721,e23351390,j_DASH_block8570,j_DASH_expr10477,link39100,self3321388) {
var anf_fun8327249 = G(J721,"JStmt",L[846]);
var $z72417242 = D;
var $f72477248 = function(_) {
return R.isFunction(anf_fun8327249)?anf_fun8327249.app(e1_DASH_visit3361389):R.ffi.throwNonFunApp(L[845],anf_fun8327249,[e1_DASH_visit3361389]);
};
try {
if(--R.GAS > 0) {
$z72417242 = $f72477248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72477248,
"from":L[845]});
}
} catch($e72397240) {
if(R.isCont($e72397240)) {
var $ss72437244 = {"from":L[845],
"go":function(if_DASH_537250) {
return $Hif_DASH_20907251(if_DASH_537250,e1_DASH_visit3361389,e23351390,j_DASH_block8570,j_DASH_expr10477,link39100,self3321388);
}};
$e72397240.stack[R.EXN_STACKHEIGHT++] = $ss72437244;
}
if(R.isPyretException($e72397240)) {
$e72397240.pyretStack.push(L[845]);
}
throw $e72397240;
}
var $ret72457246 = $Hif_DASH_20907251($z72417242,e1_DASH_visit3361389,e23351390,j_DASH_block8570,j_DASH_expr10477,link39100,self3321388);
++R.GAS;
return $ret72457246;
};
var $Hif_DASH_20907251 = function(if_DASH_537250,e1_DASH_visit3361389,e23351390,j_DASH_block8570,j_DASH_expr10477,link39100,self3321388) {
var if_helper8337264 = R.makeFunction(function(if_helper_arg8347282) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[845],1,arguments);
}
var ann_DASH_check_DASH_temp8307283 = if_helper_arg8347282;
return ann_DASH_check_DASH_temp8307283;
});
var anf_if8377281 = R.isBoolean(if_DASH_537250);
if(R.isPyretTrue(anf_if8377281)) {
if(R.isPyretTrue(if_DASH_537250)) {
var anf_fun8457262 = G(e23351390,"visit",L[848]);
var $z72547255 = D;
var $f72607261 = function(_) {
return R.isFunction(anf_fun8457262)?anf_fun8457262.app(self3321388):R.ffi.throwNonFunApp(L[847],anf_fun8457262,[self3321388]);
};
try {
if(--R.GAS > 0) {
$z72547255 = $f72607261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72607261,
"from":L[847]});
}
} catch($e72527253) {
if(R.isCont($e72527253)) {
var $ss72567257 = {"from":L[847],
"go":function(anf_bracket8467263) {
return $Hanf_bracket20857265(anf_bracket8467263,e1_DASH_visit3361389,if_helper8337264,j_DASH_block8570,link39100);
}};
$e72527253.stack[R.EXN_STACKHEIGHT++] = $ss72567257;
}
if(R.isPyretException($e72527253)) {
$e72527253.pyretStack.push(L[847]);
}
throw $e72527253;
}
var $ret72587259 = $Hanf_bracket20857265($z72547255,e1_DASH_visit3361389,if_helper8337264,j_DASH_block8570,link39100);
++R.GAS;
return $ret72587259;
} else {
var $z72687269 = D;
var $f72747275 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(e1_DASH_visit3361389):R.ffi.throwNonFunApp(L[849],j_DASH_expr10477,[e1_DASH_visit3361389]);
};
try {
if(--R.GAS > 0) {
$z72687269 = $f72747275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72747275,
"from":L[849]});
}
} catch($e72667267) {
if(R.isCont($e72667267)) {
var $ss72707271 = {"from":L[849],
"go":function(anf_arg8387276) {
return $Hanf_arg20897277(anf_arg8387276,e23351390,if_helper8337264,j_DASH_block8570,link39100,self3321388);
}};
$e72667267.stack[R.EXN_STACKHEIGHT++] = $ss72707271;
}
if(R.isPyretException($e72667267)) {
$e72667267.pyretStack.push(L[849]);
}
throw $e72667267;
}
var $ret72727273 = $Hanf_arg20897277($z72687269,e23351390,if_helper8337264,j_DASH_block8570,link39100,self3321388);
++R.GAS;
return $ret72727273;
}
} else {
var cont_tail_arg8357280 = R.throwNonBooleanCondition(L[845],("if"),if_DASH_537250);
if(--R.GAS > 0) {
$z72787279 = R.isFunction(if_helper8337264)?if_helper8337264.app(cont_tail_arg8357280):R.ffi.throwNonFunApp(L[845],if_helper8337264,[cont_tail_arg8357280]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper8337264)?if_helper8337264.app(cont_tail_arg8357280):R.ffi.throwNonFunApp(L[845],if_helper8337264,[cont_tail_arg8357280]);
},
"from":L[845]});
}
++R.GAS;
return $z72787279;
}
};
var $Hanf_bracket20857265 = function(anf_bracket8467263,e1_DASH_visit3361389,if_helper8337264,j_DASH_block8570,link39100) {
var anf_arg8477294 = G(anf_bracket8467263,"stmts",L[851]);
var $z72867287 = D;
var $f72927293 = function(_) {
return R.isFunction(link39100)?link39100.app(e1_DASH_visit3361389,anf_arg8477294):R.ffi.throwNonFunApp(L[850],link39100,[e1_DASH_visit3361389,anf_arg8477294]);
};
try {
if(--R.GAS > 0) {
$z72867287 = $f72927293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72927293,
"from":L[850]});
}
} catch($e72847285) {
if(R.isCont($e72847285)) {
var $ss72887289 = {"from":L[850],
"go":function(anf_arg8487295) {
return $Hanf_arg20847296(anf_arg8487295,if_helper8337264,j_DASH_block8570);
}};
$e72847285.stack[R.EXN_STACKHEIGHT++] = $ss72887289;
}
if(R.isPyretException($e72847285)) {
$e72847285.pyretStack.push(L[850]);
}
throw $e72847285;
}
var $ret72907291 = $Hanf_arg20847296($z72867287,if_helper8337264,j_DASH_block8570);
++R.GAS;
return $ret72907291;
};
var $Hanf_arg20847296 = function(anf_arg8487295,if_helper8337264,j_DASH_block8570) {
var $z72997300 = D;
var $f73057306 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg8487295):R.ffi.throwNonFunApp(L[852],j_DASH_block8570,[anf_arg8487295]);
};
try {
if(--R.GAS > 0) {
$z72997300 = $f73057306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73057306,
"from":L[852]});
}
} catch($e72977298) {
if(R.isCont($e72977298)) {
var $ss73017302 = {"from":L[852],
"go":function(cont_tail_arg8497307) {
return $Hcont_tail_arg20837308(cont_tail_arg8497307,if_helper8337264);
}};
$e72977298.stack[R.EXN_STACKHEIGHT++] = $ss73017302;
}
if(R.isPyretException($e72977298)) {
$e72977298.pyretStack.push(L[852]);
}
throw $e72977298;
}
var $ret73037304 = $Hcont_tail_arg20837308($z72997300,if_helper8337264);
++R.GAS;
return $ret73037304;
};
var $Hcont_tail_arg20837308 = function(cont_tail_arg8497307,if_helper8337264) {
if(--R.GAS > 0) {
$z73097310 = R.isFunction(if_helper8337264)?if_helper8337264.app(cont_tail_arg8497307):R.ffi.throwNonFunApp(L[852],if_helper8337264,[cont_tail_arg8497307]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper8337264)?if_helper8337264.app(cont_tail_arg8497307):R.ffi.throwNonFunApp(L[852],if_helper8337264,[cont_tail_arg8497307]);
},
"from":L[852]});
}
++R.GAS;
return $z73097310;
};
var $Hanf_arg20897277 = function(anf_arg8387276,e23351390,if_helper8337264,j_DASH_block8570,link39100,self3321388) {
var anf_fun8397321 = G(e23351390,"visit",L[854]);
var $z73137314 = D;
var $f73197320 = function(_) {
return R.isFunction(anf_fun8397321)?anf_fun8397321.app(self3321388):R.ffi.throwNonFunApp(L[853],anf_fun8397321,[self3321388]);
};
try {
if(--R.GAS > 0) {
$z73137314 = $f73197320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73197320,
"from":L[853]});
}
} catch($e73117312) {
if(R.isCont($e73117312)) {
var $ss73157316 = {"from":L[853],
"go":function(anf_bracket8407322) {
return $Hanf_bracket20887323(anf_bracket8407322,anf_arg8387276,if_helper8337264,j_DASH_block8570,link39100);
}};
$e73117312.stack[R.EXN_STACKHEIGHT++] = $ss73157316;
}
if(R.isPyretException($e73117312)) {
$e73117312.pyretStack.push(L[853]);
}
throw $e73117312;
}
var $ret73177318 = $Hanf_bracket20887323($z73137314,anf_arg8387276,if_helper8337264,j_DASH_block8570,link39100);
++R.GAS;
return $ret73177318;
};
var $Hanf_bracket20887323 = function(anf_bracket8407322,anf_arg8387276,if_helper8337264,j_DASH_block8570,link39100) {
var anf_arg8417334 = G(anf_bracket8407322,"stmts",L[856]);
var $z73267327 = D;
var $f73327333 = function(_) {
return R.isFunction(link39100)?link39100.app(anf_arg8387276,anf_arg8417334):R.ffi.throwNonFunApp(L[855],link39100,[anf_arg8387276,anf_arg8417334]);
};
try {
if(--R.GAS > 0) {
$z73267327 = $f73327333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73327333,
"from":L[855]});
}
} catch($e73247325) {
if(R.isCont($e73247325)) {
var $ss73287329 = {"from":L[855],
"go":function(anf_arg8427335) {
return $Hanf_arg20877336(anf_arg8427335,if_helper8337264,j_DASH_block8570);
}};
$e73247325.stack[R.EXN_STACKHEIGHT++] = $ss73287329;
}
if(R.isPyretException($e73247325)) {
$e73247325.pyretStack.push(L[855]);
}
throw $e73247325;
}
var $ret73307331 = $Hanf_arg20877336($z73267327,if_helper8337264,j_DASH_block8570);
++R.GAS;
return $ret73307331;
};
var $Hanf_arg20877336 = function(anf_arg8427335,if_helper8337264,j_DASH_block8570) {
var $z73397340 = D;
var $f73457346 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg8427335):R.ffi.throwNonFunApp(L[857],j_DASH_block8570,[anf_arg8427335]);
};
try {
if(--R.GAS > 0) {
$z73397340 = $f73457346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73457346,
"from":L[857]});
}
} catch($e73377338) {
if(R.isCont($e73377338)) {
var $ss73417342 = {"from":L[857],
"go":function(cont_tail_arg8437347) {
return $Hcont_tail_arg20867348(cont_tail_arg8437347,if_helper8337264);
}};
$e73377338.stack[R.EXN_STACKHEIGHT++] = $ss73417342;
}
if(R.isPyretException($e73377338)) {
$e73377338.pyretStack.push(L[857]);
}
throw $e73377338;
}
var $ret73437344 = $Hcont_tail_arg20867348($z73397340,if_helper8337264);
++R.GAS;
return $ret73437344;
};
var $Hcont_tail_arg20867348 = function(cont_tail_arg8437347,if_helper8337264) {
if(--R.GAS > 0) {
$z73497350 = R.isFunction(if_helper8337264)?if_helper8337264.app(cont_tail_arg8437347):R.ffi.throwNonFunApp(L[857],if_helper8337264,[cont_tail_arg8437347]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper8337264)?if_helper8337264.app(cont_tail_arg8437347):R.ffi.throwNonFunApp(L[857],if_helper8337264,[cont_tail_arg8437347]);
},
"from":L[857]});
}
++R.GAS;
return $z73497350;
};
var $Hann_DASH_check_DASH_temp20821412 = function(ann_DASH_check_DASH_temp8281411) {
return ann_DASH_check_DASH_temp8281411;
};
var $Hann_DASH_check_DASH_temp20811428 = function(ann_DASH_check_DASH_temp8261427) {
return ann_DASH_check_DASH_temp8261427;
};
var $Hcompiled_DASH_body20801444 = function(compiled_DASH_body3201441,b3171442,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,link39100,list35101,self3151440) {
var anf_bracket8077364 = G(b3171442,"id",L[860]);
var anf_fun8087361 = G(anf_bracket8077364,"tostring",L[859]);
var $z73537354 = D;
var $f73597360 = function(_) {
return R.isFunction(anf_fun8087361)?anf_fun8087361.app():R.ffi.throwNonFunApp(L[858],anf_fun8087361,[]);
};
try {
if(--R.GAS > 0) {
$z73537354 = $f73597360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73597360,
"from":L[858]});
}
} catch($e73517352) {
if(R.isCont($e73517352)) {
var $ss73557356 = {"from":L[858],
"go":function(anf_arg8097362) {
return $Hanf_arg20797363(anf_arg8097362,b3171442,compiled_DASH_body3201441,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,link39100,list35101,self3151440);
}};
$e73517352.stack[R.EXN_STACKHEIGHT++] = $ss73557356;
}
if(R.isPyretException($e73517352)) {
$e73517352.pyretStack.push(L[858]);
}
throw $e73517352;
}
var $ret73577358 = $Hanf_arg20797363($z73537354,b3171442,compiled_DASH_body3201441,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,link39100,list35101,self3151440);
++R.GAS;
return $ret73577358;
};
var $Hanf_arg20797363 = function(anf_arg8097362,b3171442,compiled_DASH_body3201441,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,link39100,list35101,self3151440) {
var $z73677368 = D;
var $f73737374 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg8097362):R.ffi.throwNonFunApp(L[861],js_DASH_id_DASH_of162700,[anf_arg8097362]);
};
try {
if(--R.GAS > 0) {
$z73677368 = $f73737374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73737374,
"from":L[861]});
}
} catch($e73657366) {
if(R.isCont($e73657366)) {
var $ss73697370 = {"from":L[861],
"go":function(anf_arg8107375) {
return $Hanf_arg20787376(anf_arg8107375,b3171442,compiled_DASH_body3201441,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100,list35101,self3151440);
}};
$e73657366.stack[R.EXN_STACKHEIGHT++] = $ss73697370;
}
if(R.isPyretException($e73657366)) {
$e73657366.pyretStack.push(L[861]);
}
throw $e73657366;
}
var $ret73717372 = $Hanf_arg20787376($z73677368,b3171442,compiled_DASH_body3201441,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100,list35101,self3151440);
++R.GAS;
return $ret73717372;
};
var $Hanf_arg20787376 = function(anf_arg8107375,b3171442,compiled_DASH_body3201441,e3181443,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100,list35101,self3151440) {
var anf_fun8117389 = G(list35101,"make",L[864]);
var anf_fun8127387 = G(e3181443,"visit",L[863]);
var $z73797380 = D;
var $f73857386 = function(_) {
return R.isFunction(anf_fun8127387)?anf_fun8127387.app(self3151440):R.ffi.throwNonFunApp(L[862],anf_fun8127387,[self3151440]);
};
try {
if(--R.GAS > 0) {
$z73797380 = $f73857386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73857386,
"from":L[862]});
}
} catch($e73777378) {
if(R.isCont($e73777378)) {
var $ss73817382 = {"from":L[862],
"go":function(anf_arg8137388) {
return $Hanf_arg20777390(anf_arg8137388,anf_arg8107375,anf_fun8117389,b3171442,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100);
}};
$e73777378.stack[R.EXN_STACKHEIGHT++] = $ss73817382;
}
if(R.isPyretException($e73777378)) {
$e73777378.pyretStack.push(L[862]);
}
throw $e73777378;
}
var $ret73837384 = $Hanf_arg20777390($z73797380,anf_arg8107375,anf_fun8117389,b3171442,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100);
++R.GAS;
return $ret73837384;
};
var $Hanf_arg20777390 = function(anf_arg8137388,anf_arg8107375,anf_fun8117389,b3171442,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100) {
var $z73937394 = D;
var $f73997400 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("$var"),anf_arg8137388):R.ffi.throwNonFunApp(L[865],j_DASH_field9979,[("$var"),anf_arg8137388]);
};
try {
if(--R.GAS > 0) {
$z73937394 = $f73997400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73997400,
"from":L[865]});
}
} catch($e73917392) {
if(R.isCont($e73917392)) {
var $ss73957396 = {"from":L[865],
"go":function(anf_array_val8147401) {
return $Hanf_array_val20767402(anf_array_val8147401,anf_arg8107375,anf_fun8117389,b3171442,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100);
}};
$e73917392.stack[R.EXN_STACKHEIGHT++] = $ss73957396;
}
if(R.isPyretException($e73917392)) {
$e73917392.pyretStack.push(L[865]);
}
throw $e73917392;
}
var $ret73977398 = $Hanf_array_val20767402($z73937394,anf_arg8107375,anf_fun8117389,b3171442,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100);
++R.GAS;
return $ret73977398;
};
var $Hanf_array_val20767402 = function(anf_array_val8147401,anf_arg8107375,anf_fun8117389,b3171442,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100) {
var anf_bracket8157416 = G(b3171442,"id",L[868]);
var anf_fun8167413 = G(anf_bracket8157416,"toname",L[867]);
var $z74057406 = D;
var $f74117412 = function(_) {
return R.isFunction(anf_fun8167413)?anf_fun8167413.app():R.ffi.throwNonFunApp(L[866],anf_fun8167413,[]);
};
try {
if(--R.GAS > 0) {
$z74057406 = $f74117412();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74117412,
"from":L[866]});
}
} catch($e74037404) {
if(R.isCont($e74037404)) {
var $ss74077408 = {"from":L[866],
"go":function(anf_arg8177414) {
return $Hanf_arg20757415(anf_arg8177414,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100);
}};
$e74037404.stack[R.EXN_STACKHEIGHT++] = $ss74077408;
}
if(R.isPyretException($e74037404)) {
$e74037404.pyretStack.push(L[866]);
}
throw $e74037404;
}
var $ret74097410 = $Hanf_arg20757415($z74057406,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100);
++R.GAS;
return $ret74097410;
};
var $Hanf_arg20757415 = function(anf_arg8177414,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_str8993,j_DASH_var8299,link39100) {
var $z74197420 = D;
var $f74257426 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(anf_arg8177414):R.ffi.throwNonFunApp(L[869],j_DASH_str8993,[anf_arg8177414]);
};
try {
if(--R.GAS > 0) {
$z74197420 = $f74257426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74257426,
"from":L[869]});
}
} catch($e74177418) {
if(R.isCont($e74177418)) {
var $ss74217422 = {"from":L[869],
"go":function(anf_arg8187427) {
return $Hanf_arg20747428(anf_arg8187427,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_var8299,link39100);
}};
$e74177418.stack[R.EXN_STACKHEIGHT++] = $ss74217422;
}
if(R.isPyretException($e74177418)) {
$e74177418.pyretStack.push(L[869]);
}
throw $e74177418;
}
var $ret74237424 = $Hanf_arg20747428($z74197420,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_var8299,link39100);
++R.GAS;
return $ret74237424;
};
var $Hanf_arg20747428 = function(anf_arg8187427,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_field9979,j_DASH_obj9690,j_DASH_var8299,link39100) {
var $z74317432 = D;
var $f74377438 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("$name"),anf_arg8187427):R.ffi.throwNonFunApp(L[870],j_DASH_field9979,[("$name"),anf_arg8187427]);
};
try {
if(--R.GAS > 0) {
$z74317432 = $f74377438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74377438,
"from":L[870]});
}
} catch($e74297430) {
if(R.isCont($e74297430)) {
var $ss74337434 = {"from":L[870],
"go":function(anf_array_val8197439) {
return $Hanf_array_val20737440(anf_array_val8197439,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_obj9690,j_DASH_var8299,link39100);
}};
$e74297430.stack[R.EXN_STACKHEIGHT++] = $ss74337434;
}
if(R.isPyretException($e74297430)) {
$e74297430.pyretStack.push(L[870]);
}
throw $e74297430;
}
var $ret74357436 = $Hanf_array_val20737440($z74317432,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_obj9690,j_DASH_var8299,link39100);
++R.GAS;
return $ret74357436;
};
var $Hanf_array_val20737440 = function(anf_array_val8197439,anf_arg8107375,anf_array_val8147401,anf_fun8117389,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_obj9690,j_DASH_var8299,link39100) {
var $z74437444 = D;
var $f74497450 = function(_) {
return R.isFunction(anf_fun8117389)?anf_fun8117389.app([anf_array_val8147401,anf_array_val8197439]):R.ffi.throwNonFunApp(L[864],anf_fun8117389,[[anf_array_val8147401,anf_array_val8197439]]);
};
try {
if(--R.GAS > 0) {
$z74437444 = $f74497450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74497450,
"from":L[864]});
}
} catch($e74417442) {
if(R.isCont($e74417442)) {
var $ss74457446 = {"from":L[864],
"go":function(anf_arg8207451) {
return $Hanf_arg20727452(anf_arg8207451,anf_arg8107375,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_obj9690,j_DASH_var8299,link39100);
}};
$e74417442.stack[R.EXN_STACKHEIGHT++] = $ss74457446;
}
if(R.isPyretException($e74417442)) {
$e74417442.pyretStack.push(L[864]);
}
throw $e74417442;
}
var $ret74477448 = $Hanf_arg20727452($z74437444,anf_arg8107375,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_obj9690,j_DASH_var8299,link39100);
++R.GAS;
return $ret74477448;
};
var $Hanf_arg20727452 = function(anf_arg8207451,anf_arg8107375,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_obj9690,j_DASH_var8299,link39100) {
var $z74557456 = D;
var $f74617462 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg8207451):R.ffi.throwNonFunApp(L[871],j_DASH_obj9690,[anf_arg8207451]);
};
try {
if(--R.GAS > 0) {
$z74557456 = $f74617462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74617462,
"from":L[871]});
}
} catch($e74537454) {
if(R.isCont($e74537454)) {
var $ss74577458 = {"from":L[871],
"go":function(anf_arg8217463) {
return $Hanf_arg20717464(anf_arg8217463,anf_arg8107375,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_var8299,link39100);
}};
$e74537454.stack[R.EXN_STACKHEIGHT++] = $ss74577458;
}
if(R.isPyretException($e74537454)) {
$e74537454.pyretStack.push(L[871]);
}
throw $e74537454;
}
var $ret74597460 = $Hanf_arg20717464($z74557456,anf_arg8107375,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_var8299,link39100);
++R.GAS;
return $ret74597460;
};
var $Hanf_arg20717464 = function(anf_arg8217463,anf_arg8107375,compiled_DASH_body3201441,j_DASH_block8570,j_DASH_var8299,link39100) {
var $z74677468 = D;
var $f74737474 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(anf_arg8107375,anf_arg8217463):R.ffi.throwNonFunApp(L[872],j_DASH_var8299,[anf_arg8107375,anf_arg8217463]);
};
try {
if(--R.GAS > 0) {
$z74677468 = $f74737474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74737474,
"from":L[872]});
}
} catch($e74657466) {
if(R.isCont($e74657466)) {
var $ss74697470 = {"from":L[872],
"go":function(anf_arg8227475) {
return $Hanf_arg20707476(anf_arg8227475,compiled_DASH_body3201441,j_DASH_block8570,link39100);
}};
$e74657466.stack[R.EXN_STACKHEIGHT++] = $ss74697470;
}
if(R.isPyretException($e74657466)) {
$e74657466.pyretStack.push(L[872]);
}
throw $e74657466;
}
var $ret74717472 = $Hanf_arg20707476($z74677468,compiled_DASH_body3201441,j_DASH_block8570,link39100);
++R.GAS;
return $ret74717472;
};
var $Hanf_arg20707476 = function(anf_arg8227475,compiled_DASH_body3201441,j_DASH_block8570,link39100) {
var anf_arg8237487 = G(compiled_DASH_body3201441,"stmts",L[874]);
var $z74797480 = D;
var $f74857486 = function(_) {
return R.isFunction(link39100)?link39100.app(anf_arg8227475,anf_arg8237487):R.ffi.throwNonFunApp(L[873],link39100,[anf_arg8227475,anf_arg8237487]);
};
try {
if(--R.GAS > 0) {
$z74797480 = $f74857486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74857486,
"from":L[873]});
}
} catch($e74777478) {
if(R.isCont($e74777478)) {
var $ss74817482 = {"from":L[873],
"go":function(anf_arg8247488) {
return $Hanf_arg20697489(anf_arg8247488,j_DASH_block8570);
}};
$e74777478.stack[R.EXN_STACKHEIGHT++] = $ss74817482;
}
if(R.isPyretException($e74777478)) {
$e74777478.pyretStack.push(L[873]);
}
throw $e74777478;
}
var $ret74837484 = $Hanf_arg20697489($z74797480,j_DASH_block8570);
++R.GAS;
return $ret74837484;
};
var $Hanf_arg20697489 = function(anf_arg8247488,j_DASH_block8570) {
var $z74927493 = D;
var $f74987499 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg8247488):R.ffi.throwNonFunApp(L[244],j_DASH_block8570,[anf_arg8247488]);
};
try {
if(--R.GAS > 0) {
$z74927493 = $f74987499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74987499,
"from":L[244]});
}
} catch($e74907491) {
if(R.isCont($e74907491)) {
var $ss74947495 = {"from":L[244],
"go":function(ann_DASH_check_DASH_temp8057500) {
return $Hann_DASH_check_DASH_temp20687501(ann_DASH_check_DASH_temp8057500);
}};
$e74907491.stack[R.EXN_STACKHEIGHT++] = $ss74947495;
}
if(R.isPyretException($e74907491)) {
$e74907491.pyretStack.push(L[244]);
}
throw $e74907491;
}
var $ret74967497 = $Hann_DASH_check_DASH_temp20687501($z74927493);
++R.GAS;
return $ret74967497;
};
var $Hann_DASH_check_DASH_temp20687501 = function(ann_DASH_check_DASH_temp8057500) {
return ann_DASH_check_DASH_temp8057500;
};
var $Hcompiled_DASH_body20671462 = function(compiled_DASH_body3131459,A118,b3101460,compile_DASH_ann181673,e3111461,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458,_plus5) {
var anf_fun7447512 = G(A118,"is-a-blank",L[877]);
var anf_arg7457513 = G(b3101460,"ann",L[876]);
var $z75047505 = D;
var $f75107511 = function(_) {
return R.isFunction(anf_fun7447512)?anf_fun7447512.app(anf_arg7457513):R.ffi.throwNonFunApp(L[875],anf_fun7447512,[anf_arg7457513]);
};
try {
if(--R.GAS > 0) {
$z75047505 = $f75107511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75107511,
"from":L[875]});
}
} catch($e75027503) {
if(R.isCont($e75027503)) {
var $ss75067507 = {"from":L[875],
"go":function(or_DASH_oper_DASH_517514) {
return $Hor_DASH_oper_DASH_20667515(or_DASH_oper_DASH_517514,A118,b3101460,compile_DASH_ann181673,compiled_DASH_body3131459,e3111461,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458,_plus5);
}};
$e75027503.stack[R.EXN_STACKHEIGHT++] = $ss75067507;
}
if(R.isPyretException($e75027503)) {
$e75027503.pyretStack.push(L[875]);
}
throw $e75027503;
}
var $ret75087509 = $Hor_DASH_oper_DASH_20667515($z75047505,A118,b3101460,compile_DASH_ann181673,compiled_DASH_body3131459,e3111461,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458,_plus5);
++R.GAS;
return $ret75087509;
};
var $Hor_DASH_oper_DASH_20667515 = function(or_DASH_oper_DASH_517514,A118,b3101460,compile_DASH_ann181673,compiled_DASH_body3131459,e3111461,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458,_plus5) {
var if_helper7467526 = R.makeFunction(function(if_helper_arg7477547) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[875],1,arguments);
}
var if_DASH_507577 = if_helper_arg7477547;
var if_helper7487561 = R.makeFunction(function(if_helper_arg7497582) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[875],1,arguments);
}
var ann_DASH_check_DASH_temp7427583 = if_helper_arg7497582;
return ann_DASH_check_DASH_temp7427583;
});
var anf_if7527581 = R.isBoolean(if_DASH_507577);
if(R.isPyretTrue(anf_if7527581)) {
if(R.isPyretTrue(if_DASH_507577)) {
var anf_fun7817560 = G(list35101,"make",L[884]);
var anf_bracket7827563 = G(b3101460,"id",L[883]);
var anf_fun7837558 = G(anf_bracket7827563,"tostring",L[882]);
var $z75507551 = D;
var $f75567557 = function(_) {
return R.isFunction(anf_fun7837558)?anf_fun7837558.app():R.ffi.throwNonFunApp(L[881],anf_fun7837558,[]);
};
try {
if(--R.GAS > 0) {
$z75507551 = $f75567557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75567557,
"from":L[881]});
}
} catch($e75487549) {
if(R.isCont($e75487549)) {
var $ss75527553 = {"from":L[881],
"go":function(anf_arg7847559) {
return $Hanf_arg20467562(anf_arg7847559,anf_fun7817560,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_var8299,js_DASH_id_DASH_of162700,self3081458,_plus5);
}};
$e75487549.stack[R.EXN_STACKHEIGHT++] = $ss75527553;
}
if(R.isPyretException($e75487549)) {
$e75487549.pyretStack.push(L[881]);
}
throw $e75487549;
}
var $ret75547555 = $Hanf_arg20467562($z75507551,anf_fun7817560,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_var8299,js_DASH_id_DASH_of162700,self3081458,_plus5);
++R.GAS;
return $ret75547555;
} else {
var anf_fun7537574 = G(list35101,"make",L[885]);
var $z75667567 = D;
var $f75727573 = function(_) {
return R.isFunction(anf_fun7537574)?anf_fun7537574.app([]):R.ffi.throwNonFunApp(L[885],anf_fun7537574,[[]]);
};
try {
if(--R.GAS > 0) {
$z75667567 = $f75727573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75727573,
"from":L[885]});
}
} catch($e75647565) {
if(R.isCont($e75647565)) {
var $ss75687569 = {"from":L[885],
"go":function(anf_arg7547575) {
return $Hanf_arg20627576(anf_arg7547575,b3101460,compile_DASH_ann181673,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
}};
$e75647565.stack[R.EXN_STACKHEIGHT++] = $ss75687569;
}
if(R.isPyretException($e75647565)) {
$e75647565.pyretStack.push(L[885]);
}
throw $e75647565;
}
var $ret75707571 = $Hanf_arg20627576($z75667567,b3101460,compile_DASH_ann181673,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
++R.GAS;
return $ret75707571;
}
} else {
var cont_tail_arg7507580 = R.throwNonBooleanCondition(L[875],("if"),if_DASH_507577);
if(--R.GAS > 0) {
$z75787579 = R.isFunction(if_helper7487561)?if_helper7487561.app(cont_tail_arg7507580):R.ffi.throwNonFunApp(L[875],if_helper7487561,[cont_tail_arg7507580]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper7487561)?if_helper7487561.app(cont_tail_arg7507580):R.ffi.throwNonFunApp(L[875],if_helper7487561,[cont_tail_arg7507580]);
},
"from":L[875]});
}
++R.GAS;
return $z75787579;
}
});
var anf_if7967546 = R.isBoolean(or_DASH_oper_DASH_517514);
if(R.isPyretTrue(anf_if7967546)) {
if(R.isPyretTrue(or_DASH_oper_DASH_517514)) {
var $z75187519 = D;
var $f75247525 = function(_) {
return R.isFunction(if_helper7467526)?if_helper7467526.app((true)):R.ffi.throwNonFunApp(L[875],if_helper7467526,[(true)]);
};
try {
if(--R.GAS > 0) {
$z75187519 = $f75247525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75247525,
"from":L[875]});
}
} catch($e75167517) {
if(R.isCont($e75167517)) {
var $ss75207521 = {"from":L[875],
"go":function(cont_tail_app8037527) {
return $Hcont_tail_app20637528(cont_tail_app8037527);
}};
$e75167517.stack[R.EXN_STACKHEIGHT++] = $ss75207521;
}
if(R.isPyretException($e75167517)) {
$e75167517.pyretStack.push(L[875]);
}
throw $e75167517;
}
var $ret75227523 = $Hcont_tail_app20637528($z75187519);
++R.GAS;
return $ret75227523;
} else {
var anf_fun7977539 = G(A118,"is-a-any",L[879]);
var anf_arg7987540 = G(b3101460,"ann",L[878]);
var $z75317532 = D;
var $f75377538 = function(_) {
return R.isFunction(anf_fun7977539)?anf_fun7977539.app(anf_arg7987540):R.ffi.throwNonFunApp(L[875],anf_fun7977539,[anf_arg7987540]);
};
try {
if(--R.GAS > 0) {
$z75317532 = $f75377538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75377538,
"from":L[875]});
}
} catch($e75297530) {
if(R.isCont($e75297530)) {
var $ss75337534 = {"from":L[875],
"go":function(or_DASH_oper_DASH_527541) {
return $Hor_DASH_oper_DASH_20657542(or_DASH_oper_DASH_527541,if_helper7467526);
}};
$e75297530.stack[R.EXN_STACKHEIGHT++] = $ss75337534;
}
if(R.isPyretException($e75297530)) {
$e75297530.pyretStack.push(L[875]);
}
throw $e75297530;
}
var $ret75357536 = $Hor_DASH_oper_DASH_20657542($z75317532,if_helper7467526);
++R.GAS;
return $ret75357536;
}
} else {
var cont_tail_arg7947545 = R.throwNonBooleanOp(L[880],("first"),("or"),or_DASH_oper_DASH_517514);
if(--R.GAS > 0) {
$z75437544 = R.isFunction(if_helper7467526)?if_helper7467526.app(cont_tail_arg7947545):R.ffi.throwNonFunApp(L[880],if_helper7467526,[cont_tail_arg7947545]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper7467526)?if_helper7467526.app(cont_tail_arg7947545):R.ffi.throwNonFunApp(L[880],if_helper7467526,[cont_tail_arg7947545]);
},
"from":L[880]});
}
++R.GAS;
return $z75437544;
}
};
var $Hcont_tail_app20637528 = function(cont_tail_app8037527) {
return cont_tail_app8037527;
};
var $Hor_DASH_oper_DASH_20657542 = function(or_DASH_oper_DASH_527541,if_helper7467526) {
var anf_if8017599 = R.isBoolean(or_DASH_oper_DASH_527541);
if(R.isPyretTrue(anf_if8017599)) {
var $z75867587 = D;
var $f75927593 = function(_) {
return R.isFunction(if_helper7467526)?if_helper7467526.app(or_DASH_oper_DASH_527541):R.ffi.throwNonFunApp(L[875],if_helper7467526,[or_DASH_oper_DASH_527541]);
};
try {
if(--R.GAS > 0) {
$z75867587 = $f75927593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75927593,
"from":L[875]});
}
} catch($e75847585) {
if(R.isCont($e75847585)) {
var $ss75887589 = {"from":L[875],
"go":function(cont_tail_app8027594) {
return $Hcont_tail_app20647595(cont_tail_app8027594);
}};
$e75847585.stack[R.EXN_STACKHEIGHT++] = $ss75887589;
}
if(R.isPyretException($e75847585)) {
$e75847585.pyretStack.push(L[875]);
}
throw $e75847585;
}
var $ret75907591 = $Hcont_tail_app20647595($z75867587);
++R.GAS;
return $ret75907591;
} else {
var cont_tail_arg7997598 = R.throwNonBooleanOp(L[886],("second"),("or"),or_DASH_oper_DASH_527541);
if(--R.GAS > 0) {
$z75967597 = R.isFunction(if_helper7467526)?if_helper7467526.app(cont_tail_arg7997598):R.ffi.throwNonFunApp(L[886],if_helper7467526,[cont_tail_arg7997598]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper7467526)?if_helper7467526.app(cont_tail_arg7997598):R.ffi.throwNonFunApp(L[886],if_helper7467526,[cont_tail_arg7997598]);
},
"from":L[886]});
}
++R.GAS;
return $z75967597;
}
};
var $Hcont_tail_app20647595 = function(cont_tail_app8027594) {
return cont_tail_app8027594;
};
var $Hanf_arg20467562 = function(anf_arg7847559,anf_fun7817560,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_var8299,js_DASH_id_DASH_of162700,self3081458,_plus5) {
var $z76027603 = D;
var $f76087609 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg7847559):R.ffi.throwNonFunApp(L[887],js_DASH_id_DASH_of162700,[anf_arg7847559]);
};
try {
if(--R.GAS > 0) {
$z76027603 = $f76087609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76087609,
"from":L[887]});
}
} catch($e76007601) {
if(R.isCont($e76007601)) {
var $ss76047605 = {"from":L[887],
"go":function(anf_arg7857610) {
return $Hanf_arg20457611(anf_arg7857610,anf_fun7817560,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_var8299,self3081458,_plus5);
}};
$e76007601.stack[R.EXN_STACKHEIGHT++] = $ss76047605;
}
if(R.isPyretException($e76007601)) {
$e76007601.pyretStack.push(L[887]);
}
throw $e76007601;
}
var $ret76067607 = $Hanf_arg20457611($z76027603,anf_fun7817560,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_var8299,self3081458,_plus5);
++R.GAS;
return $ret76067607;
};
var $Hanf_arg20457611 = function(anf_arg7857610,anf_fun7817560,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_var8299,self3081458,_plus5) {
var anf_fun7867622 = G(e3111461,"visit",L[889]);
var $z76147615 = D;
var $f76207621 = function(_) {
return R.isFunction(anf_fun7867622)?anf_fun7867622.app(self3081458):R.ffi.throwNonFunApp(L[888],anf_fun7867622,[self3081458]);
};
try {
if(--R.GAS > 0) {
$z76147615 = $f76207621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76207621,
"from":L[888]});
}
} catch($e76127613) {
if(R.isCont($e76127613)) {
var $ss76167617 = {"from":L[888],
"go":function(anf_arg7877623) {
return $Hanf_arg20447624(anf_arg7877623,anf_arg7857610,anf_fun7817560,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,j_DASH_var8299,_plus5);
}};
$e76127613.stack[R.EXN_STACKHEIGHT++] = $ss76167617;
}
if(R.isPyretException($e76127613)) {
$e76127613.pyretStack.push(L[888]);
}
throw $e76127613;
}
var $ret76187619 = $Hanf_arg20447624($z76147615,anf_arg7857610,anf_fun7817560,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,j_DASH_var8299,_plus5);
++R.GAS;
return $ret76187619;
};
var $Hanf_arg20447624 = function(anf_arg7877623,anf_arg7857610,anf_fun7817560,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,j_DASH_var8299,_plus5) {
var $z76277628 = D;
var $f76337634 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(anf_arg7857610,anf_arg7877623):R.ffi.throwNonFunApp(L[890],j_DASH_var8299,[anf_arg7857610,anf_arg7877623]);
};
try {
if(--R.GAS > 0) {
$z76277628 = $f76337634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76337634,
"from":L[890]});
}
} catch($e76257626) {
if(R.isCont($e76257626)) {
var $ss76297630 = {"from":L[890],
"go":function(anf_array_val7887635) {
return $Hanf_array_val20437636(anf_array_val7887635,anf_fun7817560,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,_plus5);
}};
$e76257626.stack[R.EXN_STACKHEIGHT++] = $ss76297630;
}
if(R.isPyretException($e76257626)) {
$e76257626.pyretStack.push(L[890]);
}
throw $e76257626;
}
var $ret76317632 = $Hanf_array_val20437636($z76277628,anf_fun7817560,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,_plus5);
++R.GAS;
return $ret76317632;
};
var $Hanf_array_val20437636 = function(anf_array_val7887635,anf_fun7817560,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,_plus5) {
var $z76397640 = D;
var $f76457646 = function(_) {
return R.isFunction(anf_fun7817560)?anf_fun7817560.app([anf_array_val7887635]):R.ffi.throwNonFunApp(L[884],anf_fun7817560,[[anf_array_val7887635]]);
};
try {
if(--R.GAS > 0) {
$z76397640 = $f76457646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76457646,
"from":L[884]});
}
} catch($e76377638) {
if(R.isCont($e76377638)) {
var $ss76417642 = {"from":L[884],
"go":function(anf_arg7897647) {
return $Hanf_arg20427648(anf_arg7897647,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,_plus5);
}};
$e76377638.stack[R.EXN_STACKHEIGHT++] = $ss76417642;
}
if(R.isPyretException($e76377638)) {
$e76377638.pyretStack.push(L[884]);
}
throw $e76377638;
}
var $ret76437644 = $Hanf_arg20427648($z76397640,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,_plus5);
++R.GAS;
return $ret76437644;
};
var $Hanf_arg20427648 = function(anf_arg7897647,compiled_DASH_body3131459,if_helper7487561,j_DASH_block8570,_plus5) {
var anf_arg7907659 = G(compiled_DASH_body3131459,"stmts",L[892]);
var $z76517652 = D;
var $f76577658 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg7897647,anf_arg7907659):R.ffi.throwNonFunApp(L[891],_plus5,[anf_arg7897647,anf_arg7907659]);
};
try {
if(--R.GAS > 0) {
$z76517652 = $f76577658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76577658,
"from":L[891]});
}
} catch($e76497650) {
if(R.isCont($e76497650)) {
var $ss76537654 = {"from":L[891],
"go":function(anf_arg7917660) {
return $Hanf_arg20417661(anf_arg7917660,if_helper7487561,j_DASH_block8570);
}};
$e76497650.stack[R.EXN_STACKHEIGHT++] = $ss76537654;
}
if(R.isPyretException($e76497650)) {
$e76497650.pyretStack.push(L[891]);
}
throw $e76497650;
}
var $ret76557656 = $Hanf_arg20417661($z76517652,if_helper7487561,j_DASH_block8570);
++R.GAS;
return $ret76557656;
};
var $Hanf_arg20417661 = function(anf_arg7917660,if_helper7487561,j_DASH_block8570) {
var $z76647665 = D;
var $f76707671 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg7917660):R.ffi.throwNonFunApp(L[893],j_DASH_block8570,[anf_arg7917660]);
};
try {
if(--R.GAS > 0) {
$z76647665 = $f76707671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76707671,
"from":L[893]});
}
} catch($e76627663) {
if(R.isCont($e76627663)) {
var $ss76667667 = {"from":L[893],
"go":function(cont_tail_arg7927672) {
return $Hcont_tail_arg20407673(cont_tail_arg7927672,if_helper7487561);
}};
$e76627663.stack[R.EXN_STACKHEIGHT++] = $ss76667667;
}
if(R.isPyretException($e76627663)) {
$e76627663.pyretStack.push(L[893]);
}
throw $e76627663;
}
var $ret76687669 = $Hcont_tail_arg20407673($z76647665,if_helper7487561);
++R.GAS;
return $ret76687669;
};
var $Hcont_tail_arg20407673 = function(cont_tail_arg7927672,if_helper7487561) {
if(--R.GAS > 0) {
$z76747675 = R.isFunction(if_helper7487561)?if_helper7487561.app(cont_tail_arg7927672):R.ffi.throwNonFunApp(L[893],if_helper7487561,[cont_tail_arg7927672]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper7487561)?if_helper7487561.app(cont_tail_arg7927672):R.ffi.throwNonFunApp(L[893],if_helper7487561,[cont_tail_arg7927672]);
},
"from":L[893]});
}
++R.GAS;
return $z76747675;
};
var $Hanf_arg20627576 = function(anf_arg7547575,b3101460,compile_DASH_ann181673,compiled_DASH_body3131459,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458) {
var $z76787679 = D;
var $f76847685 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg7547575,compiled_DASH_body3131459):R.ffi.throwNonFunApp(L[894],j_DASH_fun8180,[anf_arg7547575,compiled_DASH_body3131459]);
};
try {
if(--R.GAS > 0) {
$z76787679 = $f76847685();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76847685,
"from":L[894]});
}
} catch($e76767677) {
if(R.isCont($e76767677)) {
var $ss76807681 = {"from":L[894],
"go":function(cont3147686) {
return $Hcont20617687(cont3147686,b3101460,compile_DASH_ann181673,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
}};
$e76767677.stack[R.EXN_STACKHEIGHT++] = $ss76807681;
}
if(R.isPyretException($e76767677)) {
$e76767677.pyretStack.push(L[894]);
}
throw $e76767677;
}
var $ret76827683 = $Hcont20617687($z76787679,b3101460,compile_DASH_ann181673,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
++R.GAS;
return $ret76827683;
};
var $Hcont20617687 = function(cont3147686,b3101460,compile_DASH_ann181673,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458) {
var anf_fun7557700 = G(list35101,"make",L[898]);
var anf_bracket7567702 = G(b3101460,"id",L[897]);
var anf_fun7577698 = G(anf_bracket7567702,"tostring",L[896]);
var $z76907691 = D;
var $f76967697 = function(_) {
return R.isFunction(anf_fun7577698)?anf_fun7577698.app():R.ffi.throwNonFunApp(L[895],anf_fun7577698,[]);
};
try {
if(--R.GAS > 0) {
$z76907691 = $f76967697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76967697,
"from":L[895]});
}
} catch($e76887689) {
if(R.isCont($e76887689)) {
var $ss76927693 = {"from":L[895],
"go":function(anf_arg7587699) {
return $Hanf_arg20607701(anf_arg7587699,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
}};
$e76887689.stack[R.EXN_STACKHEIGHT++] = $ss76927693;
}
if(R.isPyretException($e76887689)) {
$e76887689.pyretStack.push(L[895]);
}
throw $e76887689;
}
var $ret76947695 = $Hanf_arg20607701($z76907691,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
++R.GAS;
return $ret76947695;
};
var $Hanf_arg20607701 = function(anf_arg7587699,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458) {
var $z77057706 = D;
var $f77117712 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg7587699):R.ffi.throwNonFunApp(L[899],js_DASH_id_DASH_of162700,[anf_arg7587699]);
};
try {
if(--R.GAS > 0) {
$z77057706 = $f77117712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77117712,
"from":L[899]});
}
} catch($e77037704) {
if(R.isCont($e77037704)) {
var $ss77077708 = {"from":L[899],
"go":function(anf_arg7597713) {
return $Hanf_arg20597714(anf_arg7597713,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
}};
$e77037704.stack[R.EXN_STACKHEIGHT++] = $ss77077708;
}
if(R.isPyretException($e77037704)) {
$e77037704.pyretStack.push(L[899]);
}
throw $e77037704;
}
var $ret77097710 = $Hanf_arg20597714($z77057706,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
++R.GAS;
return $ret77097710;
};
var $Hanf_arg20597714 = function(anf_arg7597713,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,e3111461,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458) {
var anf_fun7607725 = G(e3111461,"visit",L[901]);
var $z77177718 = D;
var $f77237724 = function(_) {
return R.isFunction(anf_fun7607725)?anf_fun7607725.app(self3081458):R.ffi.throwNonFunApp(L[900],anf_fun7607725,[self3081458]);
};
try {
if(--R.GAS > 0) {
$z77177718 = $f77237724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77237724,
"from":L[900]});
}
} catch($e77157716) {
if(R.isCont($e77157716)) {
var $ss77197720 = {"from":L[900],
"go":function(anf_arg7617726) {
return $Hanf_arg20587727(anf_arg7617726,anf_arg7597713,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
}};
$e77157716.stack[R.EXN_STACKHEIGHT++] = $ss77197720;
}
if(R.isPyretException($e77157716)) {
$e77157716.pyretStack.push(L[900]);
}
throw $e77157716;
}
var $ret77217722 = $Hanf_arg20587727($z77177718,anf_arg7597713,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
++R.GAS;
return $ret77217722;
};
var $Hanf_arg20587727 = function(anf_arg7617726,anf_arg7597713,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458) {
var $z77307731 = D;
var $f77367737 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(anf_arg7597713,anf_arg7617726):R.ffi.throwNonFunApp(L[902],j_DASH_var8299,[anf_arg7597713,anf_arg7617726]);
};
try {
if(--R.GAS > 0) {
$z77307731 = $f77367737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77367737,
"from":L[902]});
}
} catch($e77287729) {
if(R.isCont($e77287729)) {
var $ss77327733 = {"from":L[902],
"go":function(anf_array_val7627738) {
return $Hanf_array_val20577739(anf_array_val7627738,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
}};
$e77287729.stack[R.EXN_STACKHEIGHT++] = $ss77327733;
}
if(R.isPyretException($e77287729)) {
$e77287729.pyretStack.push(L[902]);
}
throw $e77287729;
}
var $ret77347735 = $Hanf_array_val20577739($z77307731,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458);
++R.GAS;
return $ret77347735;
};
var $Hanf_array_val20577739 = function(anf_array_val7627738,anf_fun7557700,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,rt_DASH_method173657,self3081458) {
var anf_fun7637753 = G(list35101,"make",L[907]);
var anf_fun7647750 = G(self3081458,"get-loc",L[906]);
var anf_bracket7657755 = G(b3101460,"ann",L[905]);
var anf_arg7667751 = G(anf_bracket7657755,"l",L[904]);
var $z77427743 = D;
var $f77487749 = function(_) {
return R.isFunction(anf_fun7647750)?anf_fun7647750.app(anf_arg7667751):R.ffi.throwNonFunApp(L[903],anf_fun7647750,[anf_arg7667751]);
};
try {
if(--R.GAS > 0) {
$z77427743 = $f77487749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77487749,
"from":L[903]});
}
} catch($e77407741) {
if(R.isCont($e77407741)) {
var $ss77447745 = {"from":L[903],
"go":function(anf_array_val7677752) {
return $Hanf_array_val20567754(anf_array_val7677752,anf_array_val7627738,anf_fun7557700,anf_fun7637753,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657,self3081458);
}};
$e77407741.stack[R.EXN_STACKHEIGHT++] = $ss77447745;
}
if(R.isPyretException($e77407741)) {
$e77407741.pyretStack.push(L[903]);
}
throw $e77407741;
}
var $ret77467747 = $Hanf_array_val20567754($z77427743,anf_array_val7627738,anf_fun7557700,anf_fun7637753,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657,self3081458);
++R.GAS;
return $ret77467747;
};
var $Hanf_array_val20567754 = function(anf_array_val7677752,anf_array_val7627738,anf_fun7557700,anf_fun7637753,b3101460,compile_DASH_ann181673,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657,self3081458) {
var anf_arg7687766 = G(b3101460,"ann",L[909]);
var $z77587759 = D;
var $f77647765 = function(_) {
return R.isFunction(compile_DASH_ann181673.$var)?compile_DASH_ann181673.$var.app(anf_arg7687766,self3081458):R.ffi.throwNonFunApp(L[908],compile_DASH_ann181673.$var,[anf_arg7687766,self3081458]);
};
try {
if(--R.GAS > 0) {
$z77587759 = $f77647765();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77647765,
"from":L[908]});
}
} catch($e77567757) {
if(R.isCont($e77567757)) {
var $ss77607761 = {"from":L[908],
"go":function(anf_array_val7697767) {
return $Hanf_array_val20557768(anf_array_val7697767,anf_array_val7627738,anf_array_val7677752,anf_fun7557700,anf_fun7637753,b3101460,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657);
}};
$e77567757.stack[R.EXN_STACKHEIGHT++] = $ss77607761;
}
if(R.isPyretException($e77567757)) {
$e77567757.pyretStack.push(L[908]);
}
throw $e77567757;
}
var $ret77627763 = $Hanf_array_val20557768($z77587759,anf_array_val7627738,anf_array_val7677752,anf_fun7557700,anf_fun7637753,b3101460,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657);
++R.GAS;
return $ret77627763;
};
var $Hanf_array_val20557768 = function(anf_array_val7697767,anf_array_val7627738,anf_array_val7677752,anf_fun7557700,anf_fun7637753,b3101460,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657) {
var anf_bracket7707782 = G(b3101460,"id",L[912]);
var anf_fun7717779 = G(anf_bracket7707782,"tostring",L[911]);
var $z77717772 = D;
var $f77777778 = function(_) {
return R.isFunction(anf_fun7717779)?anf_fun7717779.app():R.ffi.throwNonFunApp(L[910],anf_fun7717779,[]);
};
try {
if(--R.GAS > 0) {
$z77717772 = $f77777778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77777778,
"from":L[910]});
}
} catch($e77697770) {
if(R.isCont($e77697770)) {
var $ss77737774 = {"from":L[910],
"go":function(anf_arg7727780) {
return $Hanf_arg20547781(anf_arg7727780,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657);
}};
$e77697770.stack[R.EXN_STACKHEIGHT++] = $ss77737774;
}
if(R.isPyretException($e77697770)) {
$e77697770.pyretStack.push(L[910]);
}
throw $e77697770;
}
var $ret77757776 = $Hanf_arg20547781($z77717772,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657);
++R.GAS;
return $ret77757776;
};
var $Hanf_arg20547781 = function(anf_arg7727780,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,js_DASH_id_DASH_of162700,rt_DASH_method173657) {
var $z77857786 = D;
var $f77917792 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg7727780):R.ffi.throwNonFunApp(L[913],js_DASH_id_DASH_of162700,[anf_arg7727780]);
};
try {
if(--R.GAS > 0) {
$z77857786 = $f77917792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77917792,
"from":L[913]});
}
} catch($e77837784) {
if(R.isCont($e77837784)) {
var $ss77877788 = {"from":L[913],
"go":function(anf_arg7737793) {
return $Hanf_arg20537794(anf_arg7737793,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,rt_DASH_method173657);
}};
$e77837784.stack[R.EXN_STACKHEIGHT++] = $ss77877788;
}
if(R.isPyretException($e77837784)) {
$e77837784.pyretStack.push(L[913]);
}
throw $e77837784;
}
var $ret77897790 = $Hanf_arg20537794($z77857786,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,rt_DASH_method173657);
++R.GAS;
return $ret77897790;
};
var $Hanf_arg20537794 = function(anf_arg7737793,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,rt_DASH_method173657) {
var $z77977798 = D;
var $f78037804 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg7737793):R.ffi.throwNonFunApp(L[914],j_DASH_id8381,[anf_arg7737793]);
};
try {
if(--R.GAS > 0) {
$z77977798 = $f78037804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78037804,
"from":L[914]});
}
} catch($e77957796) {
if(R.isCont($e77957796)) {
var $ss77997800 = {"from":L[914],
"go":function(anf_array_val7747805) {
return $Hanf_array_val20527806(anf_array_val7747805,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_return9092,rt_DASH_method173657);
}};
$e77957796.stack[R.EXN_STACKHEIGHT++] = $ss77997800;
}
if(R.isPyretException($e77957796)) {
$e77957796.pyretStack.push(L[914]);
}
throw $e77957796;
}
var $ret78017802 = $Hanf_array_val20527806($z77977798,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_return9092,rt_DASH_method173657);
++R.GAS;
return $ret78017802;
};
var $Hanf_array_val20527806 = function(anf_array_val7747805,anf_array_val7627738,anf_array_val7677752,anf_array_val7697767,anf_fun7557700,anf_fun7637753,cont3147686,if_helper7487561,j_DASH_block8570,j_DASH_return9092,rt_DASH_method173657) {
var $z78097810 = D;
var $f78157816 = function(_) {
return R.isFunction(anf_fun7637753)?anf_fun7637753.app([anf_array_val7677752,anf_array_val7697767,anf_array_val7747805,cont3147686]):R.ffi.throwNonFunApp(L[907],anf_fun7637753,[[anf_array_val7677752,anf_array_val7697767,anf_array_val7747805,cont3147686]]);
};
try {
if(--R.GAS > 0) {
$z78097810 = $f78157816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78157816,
"from":L[907]});
}
} catch($e78077808) {
if(R.isCont($e78077808)) {
var $ss78117812 = {"from":L[907],
"go":function(anf_arg7757817) {
return $Hanf_arg20517818(anf_arg7757817,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570,j_DASH_return9092,rt_DASH_method173657);
}};
$e78077808.stack[R.EXN_STACKHEIGHT++] = $ss78117812;
}
if(R.isPyretException($e78077808)) {
$e78077808.pyretStack.push(L[907]);
}
throw $e78077808;
}
var $ret78137814 = $Hanf_arg20517818($z78097810,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570,j_DASH_return9092,rt_DASH_method173657);
++R.GAS;
return $ret78137814;
};
var $Hanf_arg20517818 = function(anf_arg7757817,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570,j_DASH_return9092,rt_DASH_method173657) {
var $z78217822 = D;
var $f78277828 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("checkAnn"),anf_arg7757817):R.ffi.throwNonFunApp(L[915],rt_DASH_method173657.$var,[("checkAnn"),anf_arg7757817]);
};
try {
if(--R.GAS > 0) {
$z78217822 = $f78277828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78277828,
"from":L[915]});
}
} catch($e78197820) {
if(R.isCont($e78197820)) {
var $ss78237824 = {"from":L[915],
"go":function(anf_arg7767829) {
return $Hanf_arg20507830(anf_arg7767829,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570,j_DASH_return9092);
}};
$e78197820.stack[R.EXN_STACKHEIGHT++] = $ss78237824;
}
if(R.isPyretException($e78197820)) {
$e78197820.pyretStack.push(L[915]);
}
throw $e78197820;
}
var $ret78257826 = $Hanf_arg20507830($z78217822,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570,j_DASH_return9092);
++R.GAS;
return $ret78257826;
};
var $Hanf_arg20507830 = function(anf_arg7767829,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570,j_DASH_return9092) {
var $z78337834 = D;
var $f78397840 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg7767829):R.ffi.throwNonFunApp(L[916],j_DASH_return9092,[anf_arg7767829]);
};
try {
if(--R.GAS > 0) {
$z78337834 = $f78397840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78397840,
"from":L[916]});
}
} catch($e78317832) {
if(R.isCont($e78317832)) {
var $ss78357836 = {"from":L[916],
"go":function(anf_array_val7777841) {
return $Hanf_array_val20497842(anf_array_val7777841,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570);
}};
$e78317832.stack[R.EXN_STACKHEIGHT++] = $ss78357836;
}
if(R.isPyretException($e78317832)) {
$e78317832.pyretStack.push(L[916]);
}
throw $e78317832;
}
var $ret78377838 = $Hanf_array_val20497842($z78337834,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570);
++R.GAS;
return $ret78377838;
};
var $Hanf_array_val20497842 = function(anf_array_val7777841,anf_array_val7627738,anf_fun7557700,if_helper7487561,j_DASH_block8570) {
var $z78457846 = D;
var $f78517852 = function(_) {
return R.isFunction(anf_fun7557700)?anf_fun7557700.app([anf_array_val7627738,anf_array_val7777841]):R.ffi.throwNonFunApp(L[898],anf_fun7557700,[[anf_array_val7627738,anf_array_val7777841]]);
};
try {
if(--R.GAS > 0) {
$z78457846 = $f78517852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78517852,
"from":L[898]});
}
} catch($e78437844) {
if(R.isCont($e78437844)) {
var $ss78477848 = {"from":L[898],
"go":function(anf_arg7787853) {
return $Hanf_arg20487854(anf_arg7787853,if_helper7487561,j_DASH_block8570);
}};
$e78437844.stack[R.EXN_STACKHEIGHT++] = $ss78477848;
}
if(R.isPyretException($e78437844)) {
$e78437844.pyretStack.push(L[898]);
}
throw $e78437844;
}
var $ret78497850 = $Hanf_arg20487854($z78457846,if_helper7487561,j_DASH_block8570);
++R.GAS;
return $ret78497850;
};
var $Hanf_arg20487854 = function(anf_arg7787853,if_helper7487561,j_DASH_block8570) {
var $z78577858 = D;
var $f78637864 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg7787853):R.ffi.throwNonFunApp(L[917],j_DASH_block8570,[anf_arg7787853]);
};
try {
if(--R.GAS > 0) {
$z78577858 = $f78637864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78637864,
"from":L[917]});
}
} catch($e78557856) {
if(R.isCont($e78557856)) {
var $ss78597860 = {"from":L[917],
"go":function(cont_tail_arg7797865) {
return $Hcont_tail_arg20477866(cont_tail_arg7797865,if_helper7487561);
}};
$e78557856.stack[R.EXN_STACKHEIGHT++] = $ss78597860;
}
if(R.isPyretException($e78557856)) {
$e78557856.pyretStack.push(L[917]);
}
throw $e78557856;
}
var $ret78617862 = $Hcont_tail_arg20477866($z78577858,if_helper7487561);
++R.GAS;
return $ret78617862;
};
var $Hcont_tail_arg20477866 = function(cont_tail_arg7797865,if_helper7487561) {
if(--R.GAS > 0) {
$z78677868 = R.isFunction(if_helper7487561)?if_helper7487561.app(cont_tail_arg7797865):R.ffi.throwNonFunApp(L[917],if_helper7487561,[cont_tail_arg7797865]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper7487561)?if_helper7487561.app(cont_tail_arg7797865):R.ffi.throwNonFunApp(L[917],if_helper7487561,[cont_tail_arg7797865]);
},
"from":L[917]});
}
++R.GAS;
return $z78677868;
};
var $Hann_DASH_check_DASH_temp20391479 = function(ann_DASH_check_DASH_temp6951478) {
return ann_DASH_check_DASH_temp6951478;
};
var $Hanf_arg20381500 = function(anf_arg7121497,body3001498,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var $z78717872 = D;
var $f78777878 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg7121497):R.ffi.throwNonFunApp(L[918],js_DASH_id_DASH_of162700,[anf_arg7121497]);
};
try {
if(--R.GAS > 0) {
$z78717872 = $f78777878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78777878,
"from":L[918]});
}
} catch($e78697870) {
if(R.isCont($e78697870)) {
var $ss78737874 = {"from":L[918],
"go":function(brander_DASH_id3077879) {
return $Hbrander_DASH_id20377880(brander_DASH_id3077879,body3001498,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e78697870.stack[R.EXN_STACKHEIGHT++] = $ss78737874;
}
if(R.isPyretException($e78697870)) {
$e78697870.pyretStack.push(L[918]);
}
throw $e78697870;
}
var $ret78757876 = $Hbrander_DASH_id20377880($z78717872,body3001498,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret78757876;
};
var $Hbrander_DASH_id20377880 = function(brander_DASH_id3077879,body3001498,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var anf_fun7137893 = G(list35101,"make",L[922]);
var anf_fun7147894 = G(list35101,"make",L[921]);
var anf_fun7157891 = G(name3051484,"toname",L[920]);
var $z78837884 = D;
var $f78897890 = function(_) {
return R.isFunction(anf_fun7157891)?anf_fun7157891.app():R.ffi.throwNonFunApp(L[919],anf_fun7157891,[]);
};
try {
if(--R.GAS > 0) {
$z78837884 = $f78897890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78897890,
"from":L[919]});
}
} catch($e78817882) {
if(R.isCont($e78817882)) {
var $ss78857886 = {"from":L[919],
"go":function(anf_arg7167892) {
return $Hanf_arg20367895(anf_arg7167892,anf_fun7137893,anf_fun7147894,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e78817882.stack[R.EXN_STACKHEIGHT++] = $ss78857886;
}
if(R.isPyretException($e78817882)) {
$e78817882.pyretStack.push(L[919]);
}
throw $e78817882;
}
var $ret78877888 = $Hanf_arg20367895($z78837884,anf_fun7137893,anf_fun7147894,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret78877888;
};
var $Hanf_arg20367895 = function(anf_arg7167892,anf_fun7137893,anf_fun7147894,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var $z78987899 = D;
var $f79047905 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(anf_arg7167892):R.ffi.throwNonFunApp(L[923],j_DASH_str8993,[anf_arg7167892]);
};
try {
if(--R.GAS > 0) {
$z78987899 = $f79047905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79047905,
"from":L[923]});
}
} catch($e78967897) {
if(R.isCont($e78967897)) {
var $ss79007901 = {"from":L[923],
"go":function(anf_array_val7177906) {
return $Hanf_array_val20357907(anf_array_val7177906,anf_fun7137893,anf_fun7147894,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e78967897.stack[R.EXN_STACKHEIGHT++] = $ss79007901;
}
if(R.isPyretException($e78967897)) {
$e78967897.pyretStack.push(L[923]);
}
throw $e78967897;
}
var $ret79027903 = $Hanf_array_val20357907($z78987899,anf_fun7137893,anf_fun7147894,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret79027903;
};
var $Hanf_array_val20357907 = function(anf_array_val7177906,anf_fun7137893,anf_fun7147894,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var $z79107911 = D;
var $f79167917 = function(_) {
return R.isFunction(anf_fun7147894)?anf_fun7147894.app([anf_array_val7177906]):R.ffi.throwNonFunApp(L[921],anf_fun7147894,[[anf_array_val7177906]]);
};
try {
if(--R.GAS > 0) {
$z79107911 = $f79167917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79167917,
"from":L[921]});
}
} catch($e79087909) {
if(R.isCont($e79087909)) {
var $ss79127913 = {"from":L[921],
"go":function(anf_arg7187918) {
return $Hanf_arg20347919(anf_arg7187918,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e79087909.stack[R.EXN_STACKHEIGHT++] = $ss79127913;
}
if(R.isPyretException($e79087909)) {
$e79087909.pyretStack.push(L[921]);
}
throw $e79087909;
}
var $ret79147915 = $Hanf_arg20347919($z79107911,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret79147915;
};
var $Hanf_arg20347919 = function(anf_arg7187918,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var $z79227923 = D;
var $f79287929 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("namedBrander"),anf_arg7187918):R.ffi.throwNonFunApp(L[924],rt_DASH_method173657.$var,[("namedBrander"),anf_arg7187918]);
};
try {
if(--R.GAS > 0) {
$z79227923 = $f79287929();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79287929,
"from":L[924]});
}
} catch($e79207921) {
if(R.isCont($e79207921)) {
var $ss79247925 = {"from":L[924],
"go":function(anf_arg7197930) {
return $Hanf_arg20337931(anf_arg7197930,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e79207921.stack[R.EXN_STACKHEIGHT++] = $ss79247925;
}
if(R.isPyretException($e79207921)) {
$e79207921.pyretStack.push(L[924]);
}
throw $e79207921;
}
var $ret79267927 = $Hanf_arg20337931($z79227923,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret79267927;
};
var $Hanf_arg20337931 = function(anf_arg7197930,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var $z79347935 = D;
var $f79407941 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(brander_DASH_id3077879,anf_arg7197930):R.ffi.throwNonFunApp(L[925],j_DASH_var8299,[brander_DASH_id3077879,anf_arg7197930]);
};
try {
if(--R.GAS > 0) {
$z79347935 = $f79407941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79407941,
"from":L[925]});
}
} catch($e79327933) {
if(R.isCont($e79327933)) {
var $ss79367937 = {"from":L[925],
"go":function(anf_array_val7207942) {
return $Hanf_array_val20327943(anf_array_val7207942,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e79327933.stack[R.EXN_STACKHEIGHT++] = $ss79367937;
}
if(R.isPyretException($e79327933)) {
$e79327933.pyretStack.push(L[925]);
}
throw $e79327933;
}
var $ret79387939 = $Hanf_array_val20327943($z79347935,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret79387939;
};
var $Hanf_array_val20327943 = function(anf_array_val7207942,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var anf_fun7217954 = G(name3051484,"tostring",L[927]);
var $z79467947 = D;
var $f79527953 = function(_) {
return R.isFunction(anf_fun7217954)?anf_fun7217954.app():R.ffi.throwNonFunApp(L[926],anf_fun7217954,[]);
};
try {
if(--R.GAS > 0) {
$z79467947 = $f79527953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79527953,
"from":L[926]});
}
} catch($e79447945) {
if(R.isCont($e79447945)) {
var $ss79487949 = {"from":L[926],
"go":function(anf_arg7227955) {
return $Hanf_arg20317956(anf_arg7227955,anf_array_val7207942,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e79447945.stack[R.EXN_STACKHEIGHT++] = $ss79487949;
}
if(R.isPyretException($e79447945)) {
$e79447945.pyretStack.push(L[926]);
}
throw $e79447945;
}
var $ret79507951 = $Hanf_arg20317956($z79467947,anf_array_val7207942,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret79507951;
};
var $Hanf_arg20317956 = function(anf_arg7227955,anf_array_val7207942,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,js_DASH_id_DASH_of162700,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var $z79597960 = D;
var $f79657966 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg7227955):R.ffi.throwNonFunApp(L[928],js_DASH_id_DASH_of162700,[anf_arg7227955]);
};
try {
if(--R.GAS > 0) {
$z79597960 = $f79657966();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79657966,
"from":L[928]});
}
} catch($e79577958) {
if(R.isCont($e79577958)) {
var $ss79617962 = {"from":L[928],
"go":function(anf_arg7237967) {
return $Hanf_arg20307968(anf_arg7237967,anf_array_val7207942,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e79577958.stack[R.EXN_STACKHEIGHT++] = $ss79617962;
}
if(R.isPyretException($e79577958)) {
$e79577958.pyretStack.push(L[928]);
}
throw $e79577958;
}
var $ret79637964 = $Hanf_arg20307968($z79597960,anf_array_val7207942,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret79637964;
};
var $Hanf_arg20307968 = function(anf_arg7237967,anf_array_val7207942,anf_fun7137893,body3001498,brander_DASH_id3077879,j_DASH_block8570,j_DASH_id8381,j_DASH_str8993,j_DASH_var8299,list35101,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var anf_fun7247980 = G(list35101,"make",L[930]);
var $z79717972 = D;
var $f79777978 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(brander_DASH_id3077879):R.ffi.throwNonFunApp(L[929],j_DASH_id8381,[brander_DASH_id3077879]);
};
try {
if(--R.GAS > 0) {
$z79717972 = $f79777978();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79777978,
"from":L[929]});
}
} catch($e79697970) {
if(R.isCont($e79697970)) {
var $ss79737974 = {"from":L[929],
"go":function(anf_array_val7257979) {
return $Hanf_array_val20297981(anf_array_val7257979,anf_arg7237967,anf_array_val7207942,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_str8993,j_DASH_var8299,name3051484,rt_DASH_method173657,self2971499,_plus5);
}};
$e79697970.stack[R.EXN_STACKHEIGHT++] = $ss79737974;
}
if(R.isPyretException($e79697970)) {
$e79697970.pyretStack.push(L[929]);
}
throw $e79697970;
}
var $ret79757976 = $Hanf_array_val20297981($z79717972,anf_arg7237967,anf_array_val7207942,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_str8993,j_DASH_var8299,name3051484,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret79757976;
};
var $Hanf_array_val20297981 = function(anf_array_val7257979,anf_arg7237967,anf_array_val7207942,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_str8993,j_DASH_var8299,name3051484,rt_DASH_method173657,self2971499,_plus5) {
var anf_fun7267992 = G(name3051484,"toname",L[932]);
var $z79847985 = D;
var $f79907991 = function(_) {
return R.isFunction(anf_fun7267992)?anf_fun7267992.app():R.ffi.throwNonFunApp(L[931],anf_fun7267992,[]);
};
try {
if(--R.GAS > 0) {
$z79847985 = $f79907991();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79907991,
"from":L[931]});
}
} catch($e79827983) {
if(R.isCont($e79827983)) {
var $ss79867987 = {"from":L[931],
"go":function(anf_arg7277993) {
return $Hanf_arg20287994(anf_arg7277993,anf_arg7237967,anf_array_val7207942,anf_array_val7257979,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_str8993,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5);
}};
$e79827983.stack[R.EXN_STACKHEIGHT++] = $ss79867987;
}
if(R.isPyretException($e79827983)) {
$e79827983.pyretStack.push(L[931]);
}
throw $e79827983;
}
var $ret79887989 = $Hanf_arg20287994($z79847985,anf_arg7237967,anf_array_val7207942,anf_array_val7257979,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_str8993,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret79887989;
};
var $Hanf_arg20287994 = function(anf_arg7277993,anf_arg7237967,anf_array_val7207942,anf_array_val7257979,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_str8993,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5) {
var $z79977998 = D;
var $f80038004 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(anf_arg7277993):R.ffi.throwNonFunApp(L[933],j_DASH_str8993,[anf_arg7277993]);
};
try {
if(--R.GAS > 0) {
$z79977998 = $f80038004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80038004,
"from":L[933]});
}
} catch($e79957996) {
if(R.isCont($e79957996)) {
var $ss79998000 = {"from":L[933],
"go":function(anf_array_val7288005) {
return $Hanf_array_val20278006(anf_array_val7288005,anf_arg7237967,anf_array_val7207942,anf_array_val7257979,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5);
}};
$e79957996.stack[R.EXN_STACKHEIGHT++] = $ss79998000;
}
if(R.isPyretException($e79957996)) {
$e79957996.pyretStack.push(L[933]);
}
throw $e79957996;
}
var $ret80018002 = $Hanf_array_val20278006($z79977998,anf_arg7237967,anf_array_val7207942,anf_array_val7257979,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret80018002;
};
var $Hanf_array_val20278006 = function(anf_array_val7288005,anf_arg7237967,anf_array_val7207942,anf_array_val7257979,anf_fun7137893,anf_fun7247980,body3001498,j_DASH_block8570,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5) {
var $z80098010 = D;
var $f80158016 = function(_) {
return R.isFunction(anf_fun7247980)?anf_fun7247980.app([anf_array_val7257979,anf_array_val7288005]):R.ffi.throwNonFunApp(L[930],anf_fun7247980,[[anf_array_val7257979,anf_array_val7288005]]);
};
try {
if(--R.GAS > 0) {
$z80098010 = $f80158016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80158016,
"from":L[930]});
}
} catch($e80078008) {
if(R.isCont($e80078008)) {
var $ss80118012 = {"from":L[930],
"go":function(anf_arg7298017) {
return $Hanf_arg20268018(anf_arg7298017,anf_arg7237967,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5);
}};
$e80078008.stack[R.EXN_STACKHEIGHT++] = $ss80118012;
}
if(R.isPyretException($e80078008)) {
$e80078008.pyretStack.push(L[930]);
}
throw $e80078008;
}
var $ret80138014 = $Hanf_arg20268018($z80098010,anf_arg7237967,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5);
++R.GAS;
return $ret80138014;
};
var $Hanf_arg20268018 = function(anf_arg7298017,anf_arg7237967,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,j_DASH_var8299,rt_DASH_method173657,self2971499,_plus5) {
var $z80218022 = D;
var $f80278028 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeBranderAnn"),anf_arg7298017):R.ffi.throwNonFunApp(L[934],rt_DASH_method173657.$var,[("makeBranderAnn"),anf_arg7298017]);
};
try {
if(--R.GAS > 0) {
$z80218022 = $f80278028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80278028,
"from":L[934]});
}
} catch($e80198020) {
if(R.isCont($e80198020)) {
var $ss80238024 = {"from":L[934],
"go":function(anf_arg7308029) {
return $Hanf_arg20258030(anf_arg7308029,anf_arg7237967,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5);
}};
$e80198020.stack[R.EXN_STACKHEIGHT++] = $ss80238024;
}
if(R.isPyretException($e80198020)) {
$e80198020.pyretStack.push(L[934]);
}
throw $e80198020;
}
var $ret80258026 = $Hanf_arg20258030($z80218022,anf_arg7237967,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5);
++R.GAS;
return $ret80258026;
};
var $Hanf_arg20258030 = function(anf_arg7308029,anf_arg7237967,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5) {
var $z80338034 = D;
var $f80398040 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(anf_arg7237967,anf_arg7308029):R.ffi.throwNonFunApp(L[935],j_DASH_var8299,[anf_arg7237967,anf_arg7308029]);
};
try {
if(--R.GAS > 0) {
$z80338034 = $f80398040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80398040,
"from":L[935]});
}
} catch($e80318032) {
if(R.isCont($e80318032)) {
var $ss80358036 = {"from":L[935],
"go":function(anf_array_val7318041) {
return $Hanf_array_val20248042(anf_array_val7318041,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,self2971499,_plus5);
}};
$e80318032.stack[R.EXN_STACKHEIGHT++] = $ss80358036;
}
if(R.isPyretException($e80318032)) {
$e80318032.pyretStack.push(L[935]);
}
throw $e80318032;
}
var $ret80378038 = $Hanf_array_val20248042($z80338034,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,self2971499,_plus5);
++R.GAS;
return $ret80378038;
};
var $Hanf_array_val20248042 = function(anf_array_val7318041,anf_array_val7207942,anf_fun7137893,body3001498,j_DASH_block8570,self2971499,_plus5) {
var $z80458046 = D;
var $f80518052 = function(_) {
return R.isFunction(anf_fun7137893)?anf_fun7137893.app([anf_array_val7207942,anf_array_val7318041]):R.ffi.throwNonFunApp(L[922],anf_fun7137893,[[anf_array_val7207942,anf_array_val7318041]]);
};
try {
if(--R.GAS > 0) {
$z80458046 = $f80518052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80518052,
"from":L[922]});
}
} catch($e80438044) {
if(R.isCont($e80438044)) {
var $ss80478048 = {"from":L[922],
"go":function(anf_arg7328053) {
return $Hanf_arg20238054(anf_arg7328053,body3001498,j_DASH_block8570,self2971499,_plus5);
}};
$e80438044.stack[R.EXN_STACKHEIGHT++] = $ss80478048;
}
if(R.isPyretException($e80438044)) {
$e80438044.pyretStack.push(L[922]);
}
throw $e80438044;
}
var $ret80498050 = $Hanf_arg20238054($z80458046,body3001498,j_DASH_block8570,self2971499,_plus5);
++R.GAS;
return $ret80498050;
};
var $Hanf_arg20238054 = function(anf_arg7328053,body3001498,j_DASH_block8570,self2971499,_plus5) {
var anf_fun7338065 = G(body3001498,"visit",L[937]);
var $z80578058 = D;
var $f80638064 = function(_) {
return R.isFunction(anf_fun7338065)?anf_fun7338065.app(self2971499):R.ffi.throwNonFunApp(L[936],anf_fun7338065,[self2971499]);
};
try {
if(--R.GAS > 0) {
$z80578058 = $f80638064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80638064,
"from":L[936]});
}
} catch($e80558056) {
if(R.isCont($e80558056)) {
var $ss80598060 = {"from":L[936],
"go":function(anf_bracket7348066) {
return $Hanf_bracket20228067(anf_bracket7348066,anf_arg7328053,j_DASH_block8570,_plus5);
}};
$e80558056.stack[R.EXN_STACKHEIGHT++] = $ss80598060;
}
if(R.isPyretException($e80558056)) {
$e80558056.pyretStack.push(L[936]);
}
throw $e80558056;
}
var $ret80618062 = $Hanf_bracket20228067($z80578058,anf_arg7328053,j_DASH_block8570,_plus5);
++R.GAS;
return $ret80618062;
};
var $Hanf_bracket20228067 = function(anf_bracket7348066,anf_arg7328053,j_DASH_block8570,_plus5) {
var anf_arg7358078 = G(anf_bracket7348066,"stmts",L[939]);
var $z80708071 = D;
var $f80768077 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg7328053,anf_arg7358078):R.ffi.throwNonFunApp(L[938],_plus5,[anf_arg7328053,anf_arg7358078]);
};
try {
if(--R.GAS > 0) {
$z80708071 = $f80768077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80768077,
"from":L[938]});
}
} catch($e80688069) {
if(R.isCont($e80688069)) {
var $ss80728073 = {"from":L[938],
"go":function(anf_arg7368079) {
return $Hanf_arg20218080(anf_arg7368079,j_DASH_block8570);
}};
$e80688069.stack[R.EXN_STACKHEIGHT++] = $ss80728073;
}
if(R.isPyretException($e80688069)) {
$e80688069.pyretStack.push(L[938]);
}
throw $e80688069;
}
var $ret80748075 = $Hanf_arg20218080($z80708071,j_DASH_block8570);
++R.GAS;
return $ret80748075;
};
var $Hanf_arg20218080 = function(anf_arg7368079,j_DASH_block8570) {
var $z80838084 = D;
var $f80898090 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg7368079):R.ffi.throwNonFunApp(L[254],j_DASH_block8570,[anf_arg7368079]);
};
try {
if(--R.GAS > 0) {
$z80838084 = $f80898090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80898090,
"from":L[254]});
}
} catch($e80818082) {
if(R.isCont($e80818082)) {
var $ss80858086 = {"from":L[254],
"go":function(ann_DASH_check_DASH_temp7108091) {
return $Hann_DASH_check_DASH_temp20208092(ann_DASH_check_DASH_temp7108091);
}};
$e80818082.stack[R.EXN_STACKHEIGHT++] = $ss80858086;
}
if(R.isPyretException($e80818082)) {
$e80818082.pyretStack.push(L[254]);
}
throw $e80818082;
}
var $ret80878088 = $Hann_DASH_check_DASH_temp20208092($z80838084);
++R.GAS;
return $ret80878088;
};
var $Hann_DASH_check_DASH_temp20208092 = function(ann_DASH_check_DASH_temp7108091) {
return ann_DASH_check_DASH_temp7108091;
};
var $Hanf_arg20191517 = function(anf_arg7001515,anf_fun6981516,ann3031503,body3001498,compile_DASH_ann181673,j_DASH_block8570,j_DASH_var8299,js_DASH_id_DASH_of162700,self2971499,_plus5) {
var $z80958096 = D;
var $f81018102 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg7001515):R.ffi.throwNonFunApp(L[940],js_DASH_id_DASH_of162700,[anf_arg7001515]);
};
try {
if(--R.GAS > 0) {
$z80958096 = $f81018102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81018102,
"from":L[940]});
}
} catch($e80938094) {
if(R.isCont($e80938094)) {
var $ss80978098 = {"from":L[940],
"go":function(anf_arg7018103) {
return $Hanf_arg20188104(anf_arg7018103,anf_fun6981516,ann3031503,body3001498,compile_DASH_ann181673,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5);
}};
$e80938094.stack[R.EXN_STACKHEIGHT++] = $ss80978098;
}
if(R.isPyretException($e80938094)) {
$e80938094.pyretStack.push(L[940]);
}
throw $e80938094;
}
var $ret80998100 = $Hanf_arg20188104($z80958096,anf_fun6981516,ann3031503,body3001498,compile_DASH_ann181673,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5);
++R.GAS;
return $ret80998100;
};
var $Hanf_arg20188104 = function(anf_arg7018103,anf_fun6981516,ann3031503,body3001498,compile_DASH_ann181673,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5) {
var $z81078108 = D;
var $f81138114 = function(_) {
return R.isFunction(compile_DASH_ann181673.$var)?compile_DASH_ann181673.$var.app(ann3031503,self2971499):R.ffi.throwNonFunApp(L[941],compile_DASH_ann181673.$var,[ann3031503,self2971499]);
};
try {
if(--R.GAS > 0) {
$z81078108 = $f81138114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81138114,
"from":L[941]});
}
} catch($e81058106) {
if(R.isCont($e81058106)) {
var $ss81098110 = {"from":L[941],
"go":function(anf_arg7028115) {
return $Hanf_arg20178116(anf_arg7028115,anf_arg7018103,anf_fun6981516,body3001498,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5);
}};
$e81058106.stack[R.EXN_STACKHEIGHT++] = $ss81098110;
}
if(R.isPyretException($e81058106)) {
$e81058106.pyretStack.push(L[941]);
}
throw $e81058106;
}
var $ret81118112 = $Hanf_arg20178116($z81078108,anf_arg7018103,anf_fun6981516,body3001498,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5);
++R.GAS;
return $ret81118112;
};
var $Hanf_arg20178116 = function(anf_arg7028115,anf_arg7018103,anf_fun6981516,body3001498,j_DASH_block8570,j_DASH_var8299,self2971499,_plus5) {
var $z81198120 = D;
var $f81258126 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(anf_arg7018103,anf_arg7028115):R.ffi.throwNonFunApp(L[942],j_DASH_var8299,[anf_arg7018103,anf_arg7028115]);
};
try {
if(--R.GAS > 0) {
$z81198120 = $f81258126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81258126,
"from":L[942]});
}
} catch($e81178118) {
if(R.isCont($e81178118)) {
var $ss81218122 = {"from":L[942],
"go":function(anf_array_val7038127) {
return $Hanf_array_val20168128(anf_array_val7038127,anf_fun6981516,body3001498,j_DASH_block8570,self2971499,_plus5);
}};
$e81178118.stack[R.EXN_STACKHEIGHT++] = $ss81218122;
}
if(R.isPyretException($e81178118)) {
$e81178118.pyretStack.push(L[942]);
}
throw $e81178118;
}
var $ret81238124 = $Hanf_array_val20168128($z81198120,anf_fun6981516,body3001498,j_DASH_block8570,self2971499,_plus5);
++R.GAS;
return $ret81238124;
};
var $Hanf_array_val20168128 = function(anf_array_val7038127,anf_fun6981516,body3001498,j_DASH_block8570,self2971499,_plus5) {
var $z81318132 = D;
var $f81378138 = function(_) {
return R.isFunction(anf_fun6981516)?anf_fun6981516.app([anf_array_val7038127]):R.ffi.throwNonFunApp(L[260],anf_fun6981516,[[anf_array_val7038127]]);
};
try {
if(--R.GAS > 0) {
$z81318132 = $f81378138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81378138,
"from":L[260]});
}
} catch($e81298130) {
if(R.isCont($e81298130)) {
var $ss81338134 = {"from":L[260],
"go":function(anf_arg7048139) {
return $Hanf_arg20158140(anf_arg7048139,body3001498,j_DASH_block8570,self2971499,_plus5);
}};
$e81298130.stack[R.EXN_STACKHEIGHT++] = $ss81338134;
}
if(R.isPyretException($e81298130)) {
$e81298130.pyretStack.push(L[260]);
}
throw $e81298130;
}
var $ret81358136 = $Hanf_arg20158140($z81318132,body3001498,j_DASH_block8570,self2971499,_plus5);
++R.GAS;
return $ret81358136;
};
var $Hanf_arg20158140 = function(anf_arg7048139,body3001498,j_DASH_block8570,self2971499,_plus5) {
var anf_fun7058151 = G(body3001498,"visit",L[944]);
var $z81438144 = D;
var $f81498150 = function(_) {
return R.isFunction(anf_fun7058151)?anf_fun7058151.app(self2971499):R.ffi.throwNonFunApp(L[943],anf_fun7058151,[self2971499]);
};
try {
if(--R.GAS > 0) {
$z81438144 = $f81498150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81498150,
"from":L[943]});
}
} catch($e81418142) {
if(R.isCont($e81418142)) {
var $ss81458146 = {"from":L[943],
"go":function(anf_bracket7068152) {
return $Hanf_bracket20148153(anf_bracket7068152,anf_arg7048139,j_DASH_block8570,_plus5);
}};
$e81418142.stack[R.EXN_STACKHEIGHT++] = $ss81458146;
}
if(R.isPyretException($e81418142)) {
$e81418142.pyretStack.push(L[943]);
}
throw $e81418142;
}
var $ret81478148 = $Hanf_bracket20148153($z81438144,anf_arg7048139,j_DASH_block8570,_plus5);
++R.GAS;
return $ret81478148;
};
var $Hanf_bracket20148153 = function(anf_bracket7068152,anf_arg7048139,j_DASH_block8570,_plus5) {
var anf_arg7078164 = G(anf_bracket7068152,"stmts",L[946]);
var $z81568157 = D;
var $f81628163 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg7048139,anf_arg7078164):R.ffi.throwNonFunApp(L[945],_plus5,[anf_arg7048139,anf_arg7078164]);
};
try {
if(--R.GAS > 0) {
$z81568157 = $f81628163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81628163,
"from":L[945]});
}
} catch($e81548155) {
if(R.isCont($e81548155)) {
var $ss81588159 = {"from":L[945],
"go":function(anf_arg7088165) {
return $Hanf_arg20138166(anf_arg7088165,j_DASH_block8570);
}};
$e81548155.stack[R.EXN_STACKHEIGHT++] = $ss81588159;
}
if(R.isPyretException($e81548155)) {
$e81548155.pyretStack.push(L[945]);
}
throw $e81548155;
}
var $ret81608161 = $Hanf_arg20138166($z81568157,j_DASH_block8570);
++R.GAS;
return $ret81608161;
};
var $Hanf_arg20138166 = function(anf_arg7088165,j_DASH_block8570) {
var $z81698170 = D;
var $f81758176 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg7088165):R.ffi.throwNonFunApp(L[257],j_DASH_block8570,[anf_arg7088165]);
};
try {
if(--R.GAS > 0) {
$z81698170 = $f81758176();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81758176,
"from":L[257]});
}
} catch($e81678168) {
if(R.isCont($e81678168)) {
var $ss81718172 = {"from":L[257],
"go":function(ann_DASH_check_DASH_temp6978177) {
return $Hann_DASH_check_DASH_temp20128178(ann_DASH_check_DASH_temp6978177);
}};
$e81678168.stack[R.EXN_STACKHEIGHT++] = $ss81718172;
}
if(R.isPyretException($e81678168)) {
$e81678168.pyretStack.push(L[257]);
}
throw $e81678168;
}
var $ret81738174 = $Hann_DASH_check_DASH_temp20128178($z81698170);
++R.GAS;
return $ret81738174;
};
var $Hann_DASH_check_DASH_temp20128178 = function(ann_DASH_check_DASH_temp6978177) {
return ann_DASH_check_DASH_temp6978177;
};
var $Htypes_DASH_obj_DASH_fields20111538 = function(types_DASH_obj_DASH_fields2951533,answer2911534,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537) {
var anf_fun6718191 = G(list35101,"make",L[950]);
var anf_fun6728192 = G(list35101,"make",L[949]);
var anf_fun6738189 = G(answer2911534,"visit",L[948]);
var $z81818182 = D;
var $f81878188 = function(_) {
return R.isFunction(anf_fun6738189)?anf_fun6738189.app(self2891537):R.ffi.throwNonFunApp(L[947],anf_fun6738189,[self2891537]);
};
try {
if(--R.GAS > 0) {
$z81818182 = $f81878188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81878188,
"from":L[947]});
}
} catch($e81798180) {
if(R.isCont($e81798180)) {
var $ss81838184 = {"from":L[947],
"go":function(anf_arg6748190) {
return $Hanf_arg20108193(anf_arg6748190,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533);
}};
$e81798180.stack[R.EXN_STACKHEIGHT++] = $ss81838184;
}
if(R.isPyretException($e81798180)) {
$e81798180.pyretStack.push(L[947]);
}
throw $e81798180;
}
var $ret81858186 = $Hanf_arg20108193($z81818182,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533);
++R.GAS;
return $ret81858186;
};
var $Hanf_arg20108193 = function(anf_arg6748190,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533) {
var $z81968197 = D;
var $f82028203 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("answer"),anf_arg6748190):R.ffi.throwNonFunApp(L[951],j_DASH_field9979,[("answer"),anf_arg6748190]);
};
try {
if(--R.GAS > 0) {
$z81968197 = $f82028203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82028203,
"from":L[951]});
}
} catch($e81948195) {
if(R.isCont($e81948195)) {
var $ss81988199 = {"from":L[951],
"go":function(anf_array_val6758204) {
return $Hanf_array_val20098205(anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533);
}};
$e81948195.stack[R.EXN_STACKHEIGHT++] = $ss81988199;
}
if(R.isPyretException($e81948195)) {
$e81948195.pyretStack.push(L[951]);
}
throw $e81948195;
}
var $ret82008201 = $Hanf_array_val20098205($z81968197,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533);
++R.GAS;
return $ret82008201;
};
var $Hanf_array_val20098205 = function(anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,list35101,provides2921536,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533) {
var anf_fun6768218 = G(list35101,"make",L[955]);
var anf_fun6778219 = G(list35101,"make",L[954]);
var anf_fun6788216 = G(provides2921536,"visit",L[953]);
var $z82088209 = D;
var $f82148215 = function(_) {
return R.isFunction(anf_fun6788216)?anf_fun6788216.app(self2891537):R.ffi.throwNonFunApp(L[952],anf_fun6788216,[self2891537]);
};
try {
if(--R.GAS > 0) {
$z82088209 = $f82148215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82148215,
"from":L[952]});
}
} catch($e82068207) {
if(R.isCont($e82068207)) {
var $ss82108211 = {"from":L[952],
"go":function(anf_arg6798217) {
return $Hanf_arg20088220(anf_arg6798217,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533);
}};
$e82068207.stack[R.EXN_STACKHEIGHT++] = $ss82108211;
}
if(R.isPyretException($e82068207)) {
$e82068207.pyretStack.push(L[952]);
}
throw $e82068207;
}
var $ret82128213 = $Hanf_arg20088220($z82088209,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533);
++R.GAS;
return $ret82128213;
};
var $Hanf_arg20088220 = function(anf_arg6798217,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533) {
var $z82238224 = D;
var $f82298230 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("values"),anf_arg6798217):R.ffi.throwNonFunApp(L[956],j_DASH_field9979,[("values"),anf_arg6798217]);
};
try {
if(--R.GAS > 0) {
$z82238224 = $f82298230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82298230,
"from":L[956]});
}
} catch($e82218222) {
if(R.isCont($e82218222)) {
var $ss82258226 = {"from":L[956],
"go":function(anf_array_val6808231) {
return $Hanf_array_val20078232(anf_array_val6808231,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533);
}};
$e82218222.stack[R.EXN_STACKHEIGHT++] = $ss82258226;
}
if(R.isPyretException($e82218222)) {
$e82218222.pyretStack.push(L[956]);
}
throw $e82218222;
}
var $ret82278228 = $Hanf_array_val20078232($z82238224,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533);
++R.GAS;
return $ret82278228;
};
var $Hanf_array_val20078232 = function(anf_array_val6808231,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537,types_DASH_obj_DASH_fields2951533) {
var $z82358236 = D;
var $f82418242 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(types_DASH_obj_DASH_fields2951533):R.ffi.throwNonFunApp(L[957],j_DASH_obj9690,[types_DASH_obj_DASH_fields2951533]);
};
try {
if(--R.GAS > 0) {
$z82358236 = $f82418242();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82418242,
"from":L[957]});
}
} catch($e82338234) {
if(R.isCont($e82338234)) {
var $ss82378238 = {"from":L[957],
"go":function(anf_arg6818243) {
return $Hanf_arg20068244(anf_arg6818243,anf_array_val6758204,anf_array_val6808231,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
}};
$e82338234.stack[R.EXN_STACKHEIGHT++] = $ss82378238;
}
if(R.isPyretException($e82338234)) {
$e82338234.pyretStack.push(L[957]);
}
throw $e82338234;
}
var $ret82398240 = $Hanf_arg20068244($z82358236,anf_array_val6758204,anf_array_val6808231,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
++R.GAS;
return $ret82398240;
};
var $Hanf_arg20068244 = function(anf_arg6818243,anf_array_val6758204,anf_array_val6808231,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537) {
var $z82478248 = D;
var $f82538254 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("types"),anf_arg6818243):R.ffi.throwNonFunApp(L[958],j_DASH_field9979,[("types"),anf_arg6818243]);
};
try {
if(--R.GAS > 0) {
$z82478248 = $f82538254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82538254,
"from":L[958]});
}
} catch($e82458246) {
if(R.isCont($e82458246)) {
var $ss82498250 = {"from":L[958],
"go":function(anf_array_val6828255) {
return $Hanf_array_val20058256(anf_array_val6828255,anf_array_val6758204,anf_array_val6808231,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
}};
$e82458246.stack[R.EXN_STACKHEIGHT++] = $ss82498250;
}
if(R.isPyretException($e82458246)) {
$e82458246.pyretStack.push(L[958]);
}
throw $e82458246;
}
var $ret82518252 = $Hanf_array_val20058256($z82478248,anf_array_val6758204,anf_array_val6808231,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
++R.GAS;
return $ret82518252;
};
var $Hanf_array_val20058256 = function(anf_array_val6828255,anf_array_val6758204,anf_array_val6808231,anf_fun6718191,anf_fun6728192,anf_fun6768218,anf_fun6778219,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537) {
var $z82598260 = D;
var $f82658266 = function(_) {
return R.isFunction(anf_fun6778219)?anf_fun6778219.app([anf_array_val6808231,anf_array_val6828255]):R.ffi.throwNonFunApp(L[954],anf_fun6778219,[[anf_array_val6808231,anf_array_val6828255]]);
};
try {
if(--R.GAS > 0) {
$z82598260 = $f82658266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82658266,
"from":L[954]});
}
} catch($e82578258) {
if(R.isCont($e82578258)) {
var $ss82618262 = {"from":L[954],
"go":function(anf_arg6838267) {
return $Hanf_arg20048268(anf_arg6838267,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
}};
$e82578258.stack[R.EXN_STACKHEIGHT++] = $ss82618262;
}
if(R.isPyretException($e82578258)) {
$e82578258.pyretStack.push(L[954]);
}
throw $e82578258;
}
var $ret82638264 = $Hanf_arg20048268($z82598260,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
++R.GAS;
return $ret82638264;
};
var $Hanf_arg20048268 = function(anf_arg6838267,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537) {
var $z82718272 = D;
var $f82778278 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg6838267):R.ffi.throwNonFunApp(L[959],j_DASH_obj9690,[anf_arg6838267]);
};
try {
if(--R.GAS > 0) {
$z82718272 = $f82778278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82778278,
"from":L[959]});
}
} catch($e82698270) {
if(R.isCont($e82698270)) {
var $ss82738274 = {"from":L[959],
"go":function(anf_array_val6848279) {
return $Hanf_array_val20038280(anf_array_val6848279,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
}};
$e82698270.stack[R.EXN_STACKHEIGHT++] = $ss82738274;
}
if(R.isPyretException($e82698270)) {
$e82698270.pyretStack.push(L[959]);
}
throw $e82698270;
}
var $ret82758276 = $Hanf_array_val20038280($z82718272,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
++R.GAS;
return $ret82758276;
};
var $Hanf_array_val20038280 = function(anf_array_val6848279,anf_array_val6758204,anf_fun6718191,anf_fun6728192,anf_fun6768218,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537) {
var $z82838284 = D;
var $f82898290 = function(_) {
return R.isFunction(anf_fun6768218)?anf_fun6768218.app([anf_array_val6848279]):R.ffi.throwNonFunApp(L[955],anf_fun6768218,[[anf_array_val6848279]]);
};
try {
if(--R.GAS > 0) {
$z82838284 = $f82898290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82898290,
"from":L[955]});
}
} catch($e82818282) {
if(R.isCont($e82818282)) {
var $ss82858286 = {"from":L[955],
"go":function(anf_arg6858291) {
return $Hanf_arg20028292(anf_arg6858291,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
}};
$e82818282.stack[R.EXN_STACKHEIGHT++] = $ss82858286;
}
if(R.isPyretException($e82818282)) {
$e82818282.pyretStack.push(L[955]);
}
throw $e82818282;
}
var $ret82878288 = $Hanf_arg20028292($z82838284,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
++R.GAS;
return $ret82878288;
};
var $Hanf_arg20028292 = function(anf_arg6858291,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537) {
var $z82958296 = D;
var $f83018302 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeObject"),anf_arg6858291):R.ffi.throwNonFunApp(L[960],rt_DASH_method173657.$var,[("makeObject"),anf_arg6858291]);
};
try {
if(--R.GAS > 0) {
$z82958296 = $f83018302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83018302,
"from":L[960]});
}
} catch($e82938294) {
if(R.isCont($e82938294)) {
var $ss82978298 = {"from":L[960],
"go":function(anf_arg6868303) {
return $Hanf_arg20018304(anf_arg6868303,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
}};
$e82938294.stack[R.EXN_STACKHEIGHT++] = $ss82978298;
}
if(R.isPyretException($e82938294)) {
$e82938294.pyretStack.push(L[960]);
}
throw $e82938294;
}
var $ret82998300 = $Hanf_arg20018304($z82958296,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
++R.GAS;
return $ret82998300;
};
var $Hanf_arg20018304 = function(anf_arg6868303,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537) {
var $z83078308 = D;
var $f83138314 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("provide-plus-types"),anf_arg6868303):R.ffi.throwNonFunApp(L[961],j_DASH_field9979,[("provide-plus-types"),anf_arg6868303]);
};
try {
if(--R.GAS > 0) {
$z83078308 = $f83138314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83138314,
"from":L[961]});
}
} catch($e83058306) {
if(R.isCont($e83058306)) {
var $ss83098310 = {"from":L[961],
"go":function(anf_array_val6878315) {
return $Hanf_array_val20008316(anf_array_val6878315,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
}};
$e83058306.stack[R.EXN_STACKHEIGHT++] = $ss83098310;
}
if(R.isPyretException($e83058306)) {
$e83058306.pyretStack.push(L[961]);
}
throw $e83058306;
}
var $ret83118312 = $Hanf_array_val20008316($z83078308,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537);
++R.GAS;
return $ret83118312;
};
var $Hanf_array_val20008316 = function(anf_array_val6878315,anf_array_val6758204,anf_fun6718191,anf_fun6728192,checks2941535,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657,self2891537) {
var anf_fun6888327 = G(checks2941535,"visit",L[963]);
var $z83198320 = D;
var $f83258326 = function(_) {
return R.isFunction(anf_fun6888327)?anf_fun6888327.app(self2891537):R.ffi.throwNonFunApp(L[962],anf_fun6888327,[self2891537]);
};
try {
if(--R.GAS > 0) {
$z83198320 = $f83258326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83258326,
"from":L[962]});
}
} catch($e83178318) {
if(R.isCont($e83178318)) {
var $ss83218322 = {"from":L[962],
"go":function(anf_arg6898328) {
return $Hanf_arg19998329(anf_arg6898328,anf_array_val6758204,anf_array_val6878315,anf_fun6718191,anf_fun6728192,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657);
}};
$e83178318.stack[R.EXN_STACKHEIGHT++] = $ss83218322;
}
if(R.isPyretException($e83178318)) {
$e83178318.pyretStack.push(L[962]);
}
throw $e83178318;
}
var $ret83238324 = $Hanf_arg19998329($z83198320,anf_array_val6758204,anf_array_val6878315,anf_fun6718191,anf_fun6728192,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657);
++R.GAS;
return $ret83238324;
};
var $Hanf_arg19998329 = function(anf_arg6898328,anf_array_val6758204,anf_array_val6878315,anf_fun6718191,anf_fun6728192,j_DASH_field9979,j_DASH_obj9690,rt_DASH_method173657) {
var $z83328333 = D;
var $f83388339 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("checks"),anf_arg6898328):R.ffi.throwNonFunApp(L[964],j_DASH_field9979,[("checks"),anf_arg6898328]);
};
try {
if(--R.GAS > 0) {
$z83328333 = $f83388339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83388339,
"from":L[964]});
}
} catch($e83308331) {
if(R.isCont($e83308331)) {
var $ss83348335 = {"from":L[964],
"go":function(anf_array_val6908340) {
return $Hanf_array_val19988341(anf_array_val6908340,anf_array_val6758204,anf_array_val6878315,anf_fun6718191,anf_fun6728192,j_DASH_obj9690,rt_DASH_method173657);
}};
$e83308331.stack[R.EXN_STACKHEIGHT++] = $ss83348335;
}
if(R.isPyretException($e83308331)) {
$e83308331.pyretStack.push(L[964]);
}
throw $e83308331;
}
var $ret83368337 = $Hanf_array_val19988341($z83328333,anf_array_val6758204,anf_array_val6878315,anf_fun6718191,anf_fun6728192,j_DASH_obj9690,rt_DASH_method173657);
++R.GAS;
return $ret83368337;
};
var $Hanf_array_val19988341 = function(anf_array_val6908340,anf_array_val6758204,anf_array_val6878315,anf_fun6718191,anf_fun6728192,j_DASH_obj9690,rt_DASH_method173657) {
var $z83448345 = D;
var $f83508351 = function(_) {
return R.isFunction(anf_fun6728192)?anf_fun6728192.app([anf_array_val6758204,anf_array_val6878315,anf_array_val6908340]):R.ffi.throwNonFunApp(L[949],anf_fun6728192,[[anf_array_val6758204,anf_array_val6878315,anf_array_val6908340]]);
};
try {
if(--R.GAS > 0) {
$z83448345 = $f83508351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83508351,
"from":L[949]});
}
} catch($e83428343) {
if(R.isCont($e83428343)) {
var $ss83468347 = {"from":L[949],
"go":function(anf_arg6918352) {
return $Hanf_arg19978353(anf_arg6918352,anf_fun6718191,j_DASH_obj9690,rt_DASH_method173657);
}};
$e83428343.stack[R.EXN_STACKHEIGHT++] = $ss83468347;
}
if(R.isPyretException($e83428343)) {
$e83428343.pyretStack.push(L[949]);
}
throw $e83428343;
}
var $ret83488349 = $Hanf_arg19978353($z83448345,anf_fun6718191,j_DASH_obj9690,rt_DASH_method173657);
++R.GAS;
return $ret83488349;
};
var $Hanf_arg19978353 = function(anf_arg6918352,anf_fun6718191,j_DASH_obj9690,rt_DASH_method173657) {
var $z83568357 = D;
var $f83628363 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg6918352):R.ffi.throwNonFunApp(L[965],j_DASH_obj9690,[anf_arg6918352]);
};
try {
if(--R.GAS > 0) {
$z83568357 = $f83628363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83628363,
"from":L[965]});
}
} catch($e83548355) {
if(R.isCont($e83548355)) {
var $ss83588359 = {"from":L[965],
"go":function(anf_array_val6928364) {
return $Hanf_array_val19968365(anf_array_val6928364,anf_fun6718191,rt_DASH_method173657);
}};
$e83548355.stack[R.EXN_STACKHEIGHT++] = $ss83588359;
}
if(R.isPyretException($e83548355)) {
$e83548355.pyretStack.push(L[965]);
}
throw $e83548355;
}
var $ret83608361 = $Hanf_array_val19968365($z83568357,anf_fun6718191,rt_DASH_method173657);
++R.GAS;
return $ret83608361;
};
var $Hanf_array_val19968365 = function(anf_array_val6928364,anf_fun6718191,rt_DASH_method173657) {
var $z83688369 = D;
var $f83748375 = function(_) {
return R.isFunction(anf_fun6718191)?anf_fun6718191.app([anf_array_val6928364]):R.ffi.throwNonFunApp(L[950],anf_fun6718191,[[anf_array_val6928364]]);
};
try {
if(--R.GAS > 0) {
$z83688369 = $f83748375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83748375,
"from":L[950]});
}
} catch($e83668367) {
if(R.isCont($e83668367)) {
var $ss83708371 = {"from":L[950],
"go":function(anf_arg6938376) {
return $Hanf_arg19958377(anf_arg6938376,rt_DASH_method173657);
}};
$e83668367.stack[R.EXN_STACKHEIGHT++] = $ss83708371;
}
if(R.isPyretException($e83668367)) {
$e83668367.pyretStack.push(L[950]);
}
throw $e83668367;
}
var $ret83728373 = $Hanf_arg19958377($z83688369,rt_DASH_method173657);
++R.GAS;
return $ret83728373;
};
var $Hanf_arg19958377 = function(anf_arg6938376,rt_DASH_method173657) {
var $z83808381 = D;
var $f83868387 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeObject"),anf_arg6938376):R.ffi.throwNonFunApp(L[266],rt_DASH_method173657.$var,[("makeObject"),anf_arg6938376]);
};
try {
if(--R.GAS > 0) {
$z83808381 = $f83868387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83868387,
"from":L[266]});
}
} catch($e83788379) {
if(R.isCont($e83788379)) {
var $ss83828383 = {"from":L[266],
"go":function(ann_DASH_check_DASH_temp6658388) {
return $Hann_DASH_check_DASH_temp19948389(ann_DASH_check_DASH_temp6658388);
}};
$e83788379.stack[R.EXN_STACKHEIGHT++] = $ss83828383;
}
if(R.isPyretException($e83788379)) {
$e83788379.pyretStack.push(L[266]);
}
throw $e83788379;
}
var $ret83848385 = $Hann_DASH_check_DASH_temp19948389($z83808381);
++R.GAS;
return $ret83848385;
};
var $Hann_DASH_check_DASH_temp19948389 = function(ann_DASH_check_DASH_temp6658388) {
return ann_DASH_check_DASH_temp6658388;
};
var $Hanf_arg19931553 = function(anf_arg6691551,anf_arg6671552,j_DASH_field9979) {
var $z83928393 = D;
var $f83988399 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(anf_arg6671552,anf_arg6691551):R.ffi.throwNonFunApp(L[262],j_DASH_field9979,[anf_arg6671552,anf_arg6691551]);
};
try {
if(--R.GAS > 0) {
$z83928393 = $f83988399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83988399,
"from":L[262]});
}
} catch($e83908391) {
if(R.isCont($e83908391)) {
var $ss83948395 = {"from":L[262],
"go":function(ann_DASH_check_DASH_temp6668400) {
return $Hann_DASH_check_DASH_temp19928401(ann_DASH_check_DASH_temp6668400);
}};
$e83908391.stack[R.EXN_STACKHEIGHT++] = $ss83948395;
}
if(R.isPyretException($e83908391)) {
$e83908391.pyretStack.push(L[262]);
}
throw $e83908391;
}
var $ret83968397 = $Hann_DASH_check_DASH_temp19928401($z83928393);
++R.GAS;
return $ret83968397;
};
var $Hann_DASH_check_DASH_temp19928401 = function(ann_DASH_check_DASH_temp6668400) {
return ann_DASH_check_DASH_temp6668400;
};
var $Hnonblanks19911571 = function(nonblanks2791570,compile_DASH_ann181673,is_DASH_empty3666,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,rt_DASH_method173657,stmts2771557,visitor2781558) {
var $z84048405 = D;
var $f84108411 = function(_) {
return R.isFunction(is_DASH_empty3666)?is_DASH_empty3666.app(nonblanks2791570):R.ffi.throwNonFunApp(L[966],is_DASH_empty3666,[nonblanks2791570]);
};
try {
if(--R.GAS > 0) {
$z84048405 = $f84108411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84108411,
"from":L[966]});
}
} catch($e84028403) {
if(R.isCont($e84028403)) {
var $ss84068407 = {"from":L[966],
"go":function(if_DASH_488412) {
return $Hif_DASH_19908413(if_DASH_488412,compile_DASH_ann181673,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,stmts2771557,visitor2781558);
}};
$e84028403.stack[R.EXN_STACKHEIGHT++] = $ss84068407;
}
if(R.isPyretException($e84028403)) {
$e84028403.pyretStack.push(L[966]);
}
throw $e84028403;
}
var $ret84088409 = $Hif_DASH_19908413($z84048405,compile_DASH_ann181673,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,stmts2771557,visitor2781558);
++R.GAS;
return $ret84088409;
};
var $Hif_DASH_19908413 = function(if_DASH_488412,compile_DASH_ann181673,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,stmts2771557,visitor2781558) {
var if_helper6318424 = R.makeFunction(function(if_helper_arg6328444) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[966],1,arguments);
}
var ann_DASH_check_DASH_temp6128445 = if_helper_arg6328444;
return ann_DASH_check_DASH_temp6128445;
});
var anf_if6358443 = R.isBoolean(if_DASH_488412);
if(R.isPyretTrue(anf_if6358443)) {
if(R.isPyretTrue(if_DASH_488412)) {
var $z84168417 = D;
var $f84228423 = function(_) {
return R.isFunction(if_helper6318424)?if_helper6318424.app(stmts2771557):R.ffi.throwNonFunApp(L[967],if_helper6318424,[stmts2771557]);
};
try {
if(--R.GAS > 0) {
$z84168417 = $f84228423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84228423,
"from":L[967]});
}
} catch($e84148415) {
if(R.isCont($e84148415)) {
var $ss84188419 = {"from":L[967],
"go":function(cont_tail_app6638425) {
return $Hcont_tail_app19718426(cont_tail_app6638425);
}};
$e84148415.stack[R.EXN_STACKHEIGHT++] = $ss84188419;
}
if(R.isPyretException($e84148415)) {
$e84148415.pyretStack.push(L[967]);
}
throw $e84148415;
}
var $ret84208421 = $Hcont_tail_app19718426($z84168417);
++R.GAS;
return $ret84208421;
} else {
var anf_fun6368437 = G(list35101,"make",L[968]);
var $z84298430 = D;
var $f84358436 = function(_) {
return R.isFunction(anf_fun6368437)?anf_fun6368437.app([]):R.ffi.throwNonFunApp(L[968],anf_fun6368437,[[]]);
};
try {
if(--R.GAS > 0) {
$z84298430 = $f84358436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84358436,
"from":L[968]});
}
} catch($e84278428) {
if(R.isCont($e84278428)) {
var $ss84318432 = {"from":L[968],
"go":function(anf_arg6378438) {
return $Hanf_arg19898439(anf_arg6378438,compile_DASH_ann181673,if_helper6318424,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,stmts2771557,visitor2781558);
}};
$e84278428.stack[R.EXN_STACKHEIGHT++] = $ss84318432;
}
if(R.isPyretException($e84278428)) {
$e84278428.pyretStack.push(L[968]);
}
throw $e84278428;
}
var $ret84338434 = $Hanf_arg19898439($z84298430,compile_DASH_ann181673,if_helper6318424,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,stmts2771557,visitor2781558);
++R.GAS;
return $ret84338434;
}
} else {
var cont_tail_arg6338442 = R.throwNonBooleanCondition(L[966],("if"),if_DASH_488412);
if(--R.GAS > 0) {
$z84408441 = R.isFunction(if_helper6318424)?if_helper6318424.app(cont_tail_arg6338442):R.ffi.throwNonFunApp(L[966],if_helper6318424,[cont_tail_arg6338442]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper6318424)?if_helper6318424.app(cont_tail_arg6338442):R.ffi.throwNonFunApp(L[966],if_helper6318424,[cont_tail_arg6338442]);
},
"from":L[966]});
}
++R.GAS;
return $z84408441;
}
};
var $Hcont_tail_app19718426 = function(cont_tail_app6638425) {
return cont_tail_app6638425;
};
var $Hanf_arg19898439 = function(anf_arg6378438,compile_DASH_ann181673,if_helper6318424,j_DASH_block8570,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,stmts2771557,visitor2781558) {
var $z84488449 = D;
var $f84548455 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(stmts2771557):R.ffi.throwNonFunApp(L[969],j_DASH_block8570,[stmts2771557]);
};
try {
if(--R.GAS > 0) {
$z84488449 = $f84548455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84548455,
"from":L[969]});
}
} catch($e84468447) {
if(R.isCont($e84468447)) {
var $ss84508451 = {"from":L[969],
"go":function(anf_arg6388456) {
return $Hanf_arg19888457(anf_arg6388456,anf_arg6378438,compile_DASH_ann181673,if_helper6318424,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558);
}};
$e84468447.stack[R.EXN_STACKHEIGHT++] = $ss84508451;
}
if(R.isPyretException($e84468447)) {
$e84468447.pyretStack.push(L[969]);
}
throw $e84468447;
}
var $ret84528453 = $Hanf_arg19888457($z84488449,anf_arg6378438,compile_DASH_ann181673,if_helper6318424,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558);
++R.GAS;
return $ret84528453;
};
var $Hanf_arg19888457 = function(anf_arg6388456,anf_arg6378438,compile_DASH_ann181673,if_helper6318424,j_DASH_fun8180,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558) {
var $z84608461 = D;
var $f84668467 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg6378438,anf_arg6388456):R.ffi.throwNonFunApp(L[970],j_DASH_fun8180,[anf_arg6378438,anf_arg6388456]);
};
try {
if(--R.GAS > 0) {
$z84608461 = $f84668467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84668467,
"from":L[970]});
}
} catch($e84588459) {
if(R.isCont($e84588459)) {
var $ss84628463 = {"from":L[970],
"go":function(cont2818468) {
return $Hcont19878469(cont2818468,compile_DASH_ann181673,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558);
}};
$e84588459.stack[R.EXN_STACKHEIGHT++] = $ss84628463;
}
if(R.isPyretException($e84588459)) {
$e84588459.pyretStack.push(L[970]);
}
throw $e84588459;
}
var $ret84648465 = $Hcont19878469($z84608461,compile_DASH_ann181673,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558);
++R.GAS;
return $ret84648465;
};
var $Hcont19878469 = function(cont2818468,compile_DASH_ann181673,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558) {
var anf_arg6418480 = R.makeFunction(function(a2838483) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[972],1,arguments);
}
var anf_arg6408494 = G(a2838483,"ann",L[973]);
var $z84868487 = D;
var $f84928493 = function(_) {
return R.isFunction(compile_DASH_ann181673.$var)?compile_DASH_ann181673.$var.app(anf_arg6408494,visitor2781558):R.ffi.throwNonFunApp(L[972],compile_DASH_ann181673.$var,[anf_arg6408494,visitor2781558]);
};
try {
if(--R.GAS > 0) {
$z84868487 = $f84928493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84928493,
"from":L[972]});
}
} catch($e84848485) {
if(R.isCont($e84848485)) {
var $ss84888489 = {"from":L[972],
"go":function(ann_DASH_check_DASH_temp6398495) {
return $Hann_DASH_check_DASH_temp19728496(ann_DASH_check_DASH_temp6398495);
}};
$e84848485.stack[R.EXN_STACKHEIGHT++] = $ss84888489;
}
if(R.isPyretException($e84848485)) {
$e84848485.pyretStack.push(L[972]);
}
throw $e84848485;
}
var $ret84908491 = $Hann_DASH_check_DASH_temp19728496($z84868487);
++R.GAS;
return $ret84908491;
});
var $z84728473 = D;
var $f84788479 = function(_) {
return R.isFunction(map47104)?map47104.app(anf_arg6418480,nonblanks2791570):R.ffi.throwNonFunApp(L[971],map47104,[anf_arg6418480,nonblanks2791570]);
};
try {
if(--R.GAS > 0) {
$z84728473 = $f84788479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84788479,
"from":L[971]});
}
} catch($e84708471) {
if(R.isCont($e84708471)) {
var $ss84748475 = {"from":L[971],
"go":function(anns2828481) {
return $Hanns19868482(anns2828481,cont2818468,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558);
}};
$e84708471.stack[R.EXN_STACKHEIGHT++] = $ss84748475;
}
if(R.isPyretException($e84708471)) {
$e84708471.pyretStack.push(L[971]);
}
throw $e84708471;
}
var $ret84768477 = $Hanns19868482($z84728473,cont2818468,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558);
++R.GAS;
return $ret84768477;
};
var $Hanns19868482 = function(anns2828481,cont2818468,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657,visitor2781558) {
var anf_arg6468507 = R.makeFunction(function(a2858510) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[975],1,arguments);
}
var anf_fun6438521 = G(visitor2781558,"get-loc",L[978]);
var anf_bracket6448525 = G(a2858510,"ann",L[977]);
var anf_arg6458522 = G(anf_bracket6448525,"l",L[976]);
var $z85138514 = D;
var $f85198520 = function(_) {
return R.isFunction(anf_fun6438521)?anf_fun6438521.app(anf_arg6458522):R.ffi.throwNonFunApp(L[975],anf_fun6438521,[anf_arg6458522]);
};
try {
if(--R.GAS > 0) {
$z85138514 = $f85198520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85198520,
"from":L[975]});
}
} catch($e85118512) {
if(R.isCont($e85118512)) {
var $ss85158516 = {"from":L[975],
"go":function(ann_DASH_check_DASH_temp6428523) {
return $Hann_DASH_check_DASH_temp19738524(ann_DASH_check_DASH_temp6428523);
}};
$e85118512.stack[R.EXN_STACKHEIGHT++] = $ss85158516;
}
if(R.isPyretException($e85118512)) {
$e85118512.pyretStack.push(L[975]);
}
throw $e85118512;
}
var $ret85178518 = $Hann_DASH_check_DASH_temp19738524($z85138514);
++R.GAS;
return $ret85178518;
});
var $z84998500 = D;
var $f85058506 = function(_) {
return R.isFunction(map47104)?map47104.app(anf_arg6468507,nonblanks2791570):R.ffi.throwNonFunApp(L[974],map47104,[anf_arg6468507,nonblanks2791570]);
};
try {
if(--R.GAS > 0) {
$z84998500 = $f85058506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85058506,
"from":L[974]});
}
} catch($e84978498) {
if(R.isCont($e84978498)) {
var $ss85018502 = {"from":L[974],
"go":function(locs2848508) {
return $Hlocs19858509(locs2848508,anns2828481,cont2818468,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657);
}};
$e84978498.stack[R.EXN_STACKHEIGHT++] = $ss85018502;
}
if(R.isPyretException($e84978498)) {
$e84978498.pyretStack.push(L[974]);
}
throw $e84978498;
}
var $ret85038504 = $Hlocs19858509($z84998500,anns2828481,cont2818468,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657);
++R.GAS;
return $ret85038504;
};
var $Hlocs19858509 = function(locs2848508,anns2828481,cont2818468,if_helper6318424,j_DASH_id8381,j_DASH_list9585,j_DASH_return9092,js_DASH_id_DASH_of162700,list35101,map47104,nonblanks2791570,rt_DASH_method173657) {
var anf_arg6528536 = R.makeFunction(function(a2878539) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[980],1,arguments);
}
var anf_bracket6488553 = G(a2878539,"id",L[983]);
var anf_fun6498550 = G(anf_bracket6488553,"tostring",L[982]);
var $z85428543 = D;
var $f85488549 = function(_) {
return R.isFunction(anf_fun6498550)?anf_fun6498550.app():R.ffi.throwNonFunApp(L[981],anf_fun6498550,[]);
};
try {
if(--R.GAS > 0) {
$z85428543 = $f85488549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85488549,
"from":L[981]});
}
} catch($e85408541) {
if(R.isCont($e85408541)) {
var $ss85448545 = {"from":L[981],
"go":function(anf_arg6508551) {
return $Hanf_arg19768552(anf_arg6508551,j_DASH_id8381,js_DASH_id_DASH_of162700);
}};
$e85408541.stack[R.EXN_STACKHEIGHT++] = $ss85448545;
}
if(R.isPyretException($e85408541)) {
$e85408541.pyretStack.push(L[981]);
}
throw $e85408541;
}
var $ret85468547 = $Hanf_arg19768552($z85428543,j_DASH_id8381,js_DASH_id_DASH_of162700);
++R.GAS;
return $ret85468547;
});
var $z85288529 = D;
var $f85348535 = function(_) {
return R.isFunction(map47104)?map47104.app(anf_arg6528536,nonblanks2791570):R.ffi.throwNonFunApp(L[979],map47104,[anf_arg6528536,nonblanks2791570]);
};
try {
if(--R.GAS > 0) {
$z85288529 = $f85348535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85348535,
"from":L[979]});
}
} catch($e85268527) {
if(R.isCont($e85268527)) {
var $ss85308531 = {"from":L[979],
"go":function(vals2868537) {
return $Hvals19848538(vals2868537,anns2828481,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,list35101,locs2848508,rt_DASH_method173657);
}};
$e85268527.stack[R.EXN_STACKHEIGHT++] = $ss85308531;
}
if(R.isPyretException($e85268527)) {
$e85268527.pyretStack.push(L[979]);
}
throw $e85268527;
}
var $ret85328533 = $Hvals19848538($z85288529,anns2828481,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,list35101,locs2848508,rt_DASH_method173657);
++R.GAS;
return $ret85328533;
};
var $Hvals19848538 = function(vals2868537,anns2828481,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,list35101,locs2848508,rt_DASH_method173657) {
var anf_fun6538565 = G(list35101,"make",L[986]);
var anf_fun6548566 = G(list35101,"make",L[985]);
var $z85568557 = D;
var $f85628563 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),anns2828481):R.ffi.throwNonFunApp(L[984],j_DASH_list9585,[(false),anns2828481]);
};
try {
if(--R.GAS > 0) {
$z85568557 = $f85628563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85628563,
"from":L[984]});
}
} catch($e85548555) {
if(R.isCont($e85548555)) {
var $ss85588559 = {"from":L[984],
"go":function(anf_array_val6558564) {
return $Hanf_array_val19838567(anf_array_val6558564,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,locs2848508,rt_DASH_method173657,vals2868537);
}};
$e85548555.stack[R.EXN_STACKHEIGHT++] = $ss85588559;
}
if(R.isPyretException($e85548555)) {
$e85548555.pyretStack.push(L[984]);
}
throw $e85548555;
}
var $ret85608561 = $Hanf_array_val19838567($z85568557,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,locs2848508,rt_DASH_method173657,vals2868537);
++R.GAS;
return $ret85608561;
};
var $Hanf_array_val19838567 = function(anf_array_val6558564,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,locs2848508,rt_DASH_method173657,vals2868537) {
var $z85708571 = D;
var $f85768577 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),vals2868537):R.ffi.throwNonFunApp(L[987],j_DASH_list9585,[(false),vals2868537]);
};
try {
if(--R.GAS > 0) {
$z85708571 = $f85768577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85768577,
"from":L[987]});
}
} catch($e85688569) {
if(R.isCont($e85688569)) {
var $ss85728573 = {"from":L[987],
"go":function(anf_array_val6568578) {
return $Hanf_array_val19828579(anf_array_val6568578,anf_array_val6558564,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,locs2848508,rt_DASH_method173657);
}};
$e85688569.stack[R.EXN_STACKHEIGHT++] = $ss85728573;
}
if(R.isPyretException($e85688569)) {
$e85688569.pyretStack.push(L[987]);
}
throw $e85688569;
}
var $ret85748575 = $Hanf_array_val19828579($z85708571,anf_array_val6558564,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,locs2848508,rt_DASH_method173657);
++R.GAS;
return $ret85748575;
};
var $Hanf_array_val19828579 = function(anf_array_val6568578,anf_array_val6558564,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_list9585,j_DASH_return9092,locs2848508,rt_DASH_method173657) {
var $z85828583 = D;
var $f85888589 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),locs2848508):R.ffi.throwNonFunApp(L[988],j_DASH_list9585,[(false),locs2848508]);
};
try {
if(--R.GAS > 0) {
$z85828583 = $f85888589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85888589,
"from":L[988]});
}
} catch($e85808581) {
if(R.isCont($e85808581)) {
var $ss85848585 = {"from":L[988],
"go":function(anf_array_val6578590) {
return $Hanf_array_val19818591(anf_array_val6578590,anf_array_val6558564,anf_array_val6568578,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_return9092,rt_DASH_method173657);
}};
$e85808581.stack[R.EXN_STACKHEIGHT++] = $ss85848585;
}
if(R.isPyretException($e85808581)) {
$e85808581.pyretStack.push(L[988]);
}
throw $e85808581;
}
var $ret85868587 = $Hanf_array_val19818591($z85828583,anf_array_val6558564,anf_array_val6568578,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_return9092,rt_DASH_method173657);
++R.GAS;
return $ret85868587;
};
var $Hanf_array_val19818591 = function(anf_array_val6578590,anf_array_val6558564,anf_array_val6568578,anf_fun6538565,anf_fun6548566,cont2818468,if_helper6318424,j_DASH_return9092,rt_DASH_method173657) {
var $z85948595 = D;
var $f86008601 = function(_) {
return R.isFunction(anf_fun6548566)?anf_fun6548566.app([anf_array_val6558564,anf_array_val6568578,anf_array_val6578590,cont2818468]):R.ffi.throwNonFunApp(L[985],anf_fun6548566,[[anf_array_val6558564,anf_array_val6568578,anf_array_val6578590,cont2818468]]);
};
try {
if(--R.GAS > 0) {
$z85948595 = $f86008601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86008601,
"from":L[985]});
}
} catch($e85928593) {
if(R.isCont($e85928593)) {
var $ss85968597 = {"from":L[985],
"go":function(anf_arg6588602) {
return $Hanf_arg19808603(anf_arg6588602,anf_fun6538565,if_helper6318424,j_DASH_return9092,rt_DASH_method173657);
}};
$e85928593.stack[R.EXN_STACKHEIGHT++] = $ss85968597;
}
if(R.isPyretException($e85928593)) {
$e85928593.pyretStack.push(L[985]);
}
throw $e85928593;
}
var $ret85988599 = $Hanf_arg19808603($z85948595,anf_fun6538565,if_helper6318424,j_DASH_return9092,rt_DASH_method173657);
++R.GAS;
return $ret85988599;
};
var $Hanf_arg19808603 = function(anf_arg6588602,anf_fun6538565,if_helper6318424,j_DASH_return9092,rt_DASH_method173657) {
var $z86068607 = D;
var $f86128613 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("checkAnnArgs"),anf_arg6588602):R.ffi.throwNonFunApp(L[989],rt_DASH_method173657.$var,[("checkAnnArgs"),anf_arg6588602]);
};
try {
if(--R.GAS > 0) {
$z86068607 = $f86128613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86128613,
"from":L[989]});
}
} catch($e86048605) {
if(R.isCont($e86048605)) {
var $ss86088609 = {"from":L[989],
"go":function(anf_arg6598614) {
return $Hanf_arg19798615(anf_arg6598614,anf_fun6538565,if_helper6318424,j_DASH_return9092);
}};
$e86048605.stack[R.EXN_STACKHEIGHT++] = $ss86088609;
}
if(R.isPyretException($e86048605)) {
$e86048605.pyretStack.push(L[989]);
}
throw $e86048605;
}
var $ret86108611 = $Hanf_arg19798615($z86068607,anf_fun6538565,if_helper6318424,j_DASH_return9092);
++R.GAS;
return $ret86108611;
};
var $Hanf_arg19798615 = function(anf_arg6598614,anf_fun6538565,if_helper6318424,j_DASH_return9092) {
var $z86188619 = D;
var $f86248625 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg6598614):R.ffi.throwNonFunApp(L[990],j_DASH_return9092,[anf_arg6598614]);
};
try {
if(--R.GAS > 0) {
$z86188619 = $f86248625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86248625,
"from":L[990]});
}
} catch($e86168617) {
if(R.isCont($e86168617)) {
var $ss86208621 = {"from":L[990],
"go":function(anf_array_val6608626) {
return $Hanf_array_val19788627(anf_array_val6608626,anf_fun6538565,if_helper6318424);
}};
$e86168617.stack[R.EXN_STACKHEIGHT++] = $ss86208621;
}
if(R.isPyretException($e86168617)) {
$e86168617.pyretStack.push(L[990]);
}
throw $e86168617;
}
var $ret86228623 = $Hanf_array_val19788627($z86188619,anf_fun6538565,if_helper6318424);
++R.GAS;
return $ret86228623;
};
var $Hanf_array_val19788627 = function(anf_array_val6608626,anf_fun6538565,if_helper6318424) {
var $z86308631 = D;
var $f86368637 = function(_) {
return R.isFunction(anf_fun6538565)?anf_fun6538565.app([anf_array_val6608626]):R.ffi.throwNonFunApp(L[986],anf_fun6538565,[[anf_array_val6608626]]);
};
try {
if(--R.GAS > 0) {
$z86308631 = $f86368637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86368637,
"from":L[986]});
}
} catch($e86288629) {
if(R.isCont($e86288629)) {
var $ss86328633 = {"from":L[986],
"go":function(cont_tail_arg6618638) {
return $Hcont_tail_arg19778639(cont_tail_arg6618638,if_helper6318424);
}};
$e86288629.stack[R.EXN_STACKHEIGHT++] = $ss86328633;
}
if(R.isPyretException($e86288629)) {
$e86288629.pyretStack.push(L[986]);
}
throw $e86288629;
}
var $ret86348635 = $Hcont_tail_arg19778639($z86308631,if_helper6318424);
++R.GAS;
return $ret86348635;
};
var $Hcont_tail_arg19778639 = function(cont_tail_arg6618638,if_helper6318424) {
if(--R.GAS > 0) {
$z86408641 = R.isFunction(if_helper6318424)?if_helper6318424.app(cont_tail_arg6618638):R.ffi.throwNonFunApp(L[986],if_helper6318424,[cont_tail_arg6618638]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper6318424)?if_helper6318424.app(cont_tail_arg6618638):R.ffi.throwNonFunApp(L[986],if_helper6318424,[cont_tail_arg6618638]);
},
"from":L[986]});
}
++R.GAS;
return $z86408641;
};
var $Hanf_arg19768552 = function(anf_arg6508551,j_DASH_id8381,js_DASH_id_DASH_of162700) {
var $z86448645 = D;
var $f86508651 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg6508551):R.ffi.throwNonFunApp(L[991],js_DASH_id_DASH_of162700,[anf_arg6508551]);
};
try {
if(--R.GAS > 0) {
$z86448645 = $f86508651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86508651,
"from":L[991]});
}
} catch($e86428643) {
if(R.isCont($e86428643)) {
var $ss86468647 = {"from":L[991],
"go":function(anf_arg6518652) {
return $Hanf_arg19758653(anf_arg6518652,j_DASH_id8381);
}};
$e86428643.stack[R.EXN_STACKHEIGHT++] = $ss86468647;
}
if(R.isPyretException($e86428643)) {
$e86428643.pyretStack.push(L[991]);
}
throw $e86428643;
}
var $ret86488649 = $Hanf_arg19758653($z86448645,j_DASH_id8381);
++R.GAS;
return $ret86488649;
};
var $Hanf_arg19758653 = function(anf_arg6518652,j_DASH_id8381) {
var $z86568657 = D;
var $f86628663 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg6518652):R.ffi.throwNonFunApp(L[980],j_DASH_id8381,[anf_arg6518652]);
};
try {
if(--R.GAS > 0) {
$z86568657 = $f86628663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86628663,
"from":L[980]});
}
} catch($e86548655) {
if(R.isCont($e86548655)) {
var $ss86588659 = {"from":L[980],
"go":function(ann_DASH_check_DASH_temp6478664) {
return $Hann_DASH_check_DASH_temp19748665(ann_DASH_check_DASH_temp6478664);
}};
$e86548655.stack[R.EXN_STACKHEIGHT++] = $ss86588659;
}
if(R.isPyretException($e86548655)) {
$e86548655.pyretStack.push(L[980]);
}
throw $e86548655;
}
var $ret86608661 = $Hann_DASH_check_DASH_temp19748665($z86568657);
++R.GAS;
return $ret86608661;
};
var $Hann_DASH_check_DASH_temp19748665 = function(ann_DASH_check_DASH_temp6478664) {
return ann_DASH_check_DASH_temp6478664;
};
var $Hann_DASH_check_DASH_temp19738524 = function(ann_DASH_check_DASH_temp6428523) {
return ann_DASH_check_DASH_temp6428523;
};
var $Hann_DASH_check_DASH_temp19728496 = function(ann_DASH_check_DASH_temp6398495) {
return ann_DASH_check_DASH_temp6398495;
};
var $Hanf_arg19701586 = function(anf_arg6161585,A118,a2801572,not8) {
var $z86688669 = D;
var $f86748675 = function(_) {
return R.isFunction(not8)?not8.app(anf_arg6161585):R.ffi.throwNonFunApp(L[992],not8,[anf_arg6161585]);
};
try {
if(--R.GAS > 0) {
$z86688669 = $f86748675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86748675,
"from":L[992]});
}
} catch($e86668667) {
if(R.isCont($e86668667)) {
var $ss86708671 = {"from":L[992],
"go":function(and_DASH_oper_DASH_468676) {
return $Hand_DASH_oper_DASH_19698677(and_DASH_oper_DASH_468676,A118,a2801572,not8);
}};
$e86668667.stack[R.EXN_STACKHEIGHT++] = $ss86708671;
}
if(R.isPyretException($e86668667)) {
$e86668667.pyretStack.push(L[992]);
}
throw $e86668667;
}
var $ret86728673 = $Hand_DASH_oper_DASH_19698677($z86688669,A118,a2801572,not8);
++R.GAS;
return $ret86728673;
};
var $Hand_DASH_oper_DASH_19698677 = function(and_DASH_oper_DASH_468676,A118,a2801572,not8) {
var if_helper6178691 = R.makeFunction(function(if_helper_arg6188709) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[992],1,arguments);
}
var ann_DASH_check_DASH_temp6138710 = if_helper_arg6188709;
return ann_DASH_check_DASH_temp6138710;
});
var anf_if6218708 = R.isBoolean(and_DASH_oper_DASH_468676);
if(R.isPyretTrue(anf_if6218708)) {
if(R.isPyretTrue(and_DASH_oper_DASH_468676)) {
var anf_fun6238688 = G(A118,"is-a-any",L[995]);
var anf_arg6248689 = G(a2801572,"ann",L[994]);
var $z86808681 = D;
var $f86868687 = function(_) {
return R.isFunction(anf_fun6238688)?anf_fun6238688.app(anf_arg6248689):R.ffi.throwNonFunApp(L[993],anf_fun6238688,[anf_arg6248689]);
};
try {
if(--R.GAS > 0) {
$z86808681 = $f86868687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86868687,
"from":L[993]});
}
} catch($e86788679) {
if(R.isCont($e86788679)) {
var $ss86828683 = {"from":L[993],
"go":function(anf_arg6258690) {
return $Hanf_arg19678692(anf_arg6258690,if_helper6178691,not8);
}};
$e86788679.stack[R.EXN_STACKHEIGHT++] = $ss86828683;
}
if(R.isPyretException($e86788679)) {
$e86788679.pyretStack.push(L[993]);
}
throw $e86788679;
}
var $ret86848685 = $Hanf_arg19678692($z86808681,if_helper6178691,not8);
++R.GAS;
return $ret86848685;
} else {
var $z86958696 = D;
var $f87018702 = function(_) {
return R.isFunction(if_helper6178691)?if_helper6178691.app((false)):R.ffi.throwNonFunApp(L[992],if_helper6178691,[(false)]);
};
try {
if(--R.GAS > 0) {
$z86958696 = $f87018702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87018702,
"from":L[992]});
}
} catch($e86938694) {
if(R.isCont($e86938694)) {
var $ss86978698 = {"from":L[992],
"go":function(cont_tail_app6228703) {
return $Hcont_tail_app19688704(cont_tail_app6228703);
}};
$e86938694.stack[R.EXN_STACKHEIGHT++] = $ss86978698;
}
if(R.isPyretException($e86938694)) {
$e86938694.pyretStack.push(L[992]);
}
throw $e86938694;
}
var $ret86998700 = $Hcont_tail_app19688704($z86958696);
++R.GAS;
return $ret86998700;
}
} else {
var cont_tail_arg6198707 = R.throwNonBooleanOp(L[996],("first"),("and"),and_DASH_oper_DASH_468676);
if(--R.GAS > 0) {
$z87058706 = R.isFunction(if_helper6178691)?if_helper6178691.app(cont_tail_arg6198707):R.ffi.throwNonFunApp(L[996],if_helper6178691,[cont_tail_arg6198707]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper6178691)?if_helper6178691.app(cont_tail_arg6198707):R.ffi.throwNonFunApp(L[996],if_helper6178691,[cont_tail_arg6198707]);
},
"from":L[996]});
}
++R.GAS;
return $z87058706;
}
};
var $Hanf_arg19678692 = function(anf_arg6258690,if_helper6178691,not8) {
var $z87138714 = D;
var $f87198720 = function(_) {
return R.isFunction(not8)?not8.app(anf_arg6258690):R.ffi.throwNonFunApp(L[992],not8,[anf_arg6258690]);
};
try {
if(--R.GAS > 0) {
$z87138714 = $f87198720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87198720,
"from":L[992]});
}
} catch($e87118712) {
if(R.isCont($e87118712)) {
var $ss87158716 = {"from":L[992],
"go":function(and_DASH_oper_DASH_478721) {
return $Hand_DASH_oper_DASH_19668722(and_DASH_oper_DASH_478721,if_helper6178691);
}};
$e87118712.stack[R.EXN_STACKHEIGHT++] = $ss87158716;
}
if(R.isPyretException($e87118712)) {
$e87118712.pyretStack.push(L[992]);
}
throw $e87118712;
}
var $ret87178718 = $Hand_DASH_oper_DASH_19668722($z87138714,if_helper6178691);
++R.GAS;
return $ret87178718;
};
var $Hand_DASH_oper_DASH_19668722 = function(and_DASH_oper_DASH_478721,if_helper6178691) {
var anf_if6288738 = R.isBoolean(and_DASH_oper_DASH_478721);
if(R.isPyretTrue(anf_if6288738)) {
var $z87258726 = D;
var $f87318732 = function(_) {
return R.isFunction(if_helper6178691)?if_helper6178691.app(and_DASH_oper_DASH_478721):R.ffi.throwNonFunApp(L[992],if_helper6178691,[and_DASH_oper_DASH_478721]);
};
try {
if(--R.GAS > 0) {
$z87258726 = $f87318732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87318732,
"from":L[992]});
}
} catch($e87238724) {
if(R.isCont($e87238724)) {
var $ss87278728 = {"from":L[992],
"go":function(cont_tail_app6298733) {
return $Hcont_tail_app19658734(cont_tail_app6298733);
}};
$e87238724.stack[R.EXN_STACKHEIGHT++] = $ss87278728;
}
if(R.isPyretException($e87238724)) {
$e87238724.pyretStack.push(L[992]);
}
throw $e87238724;
}
var $ret87298730 = $Hcont_tail_app19658734($z87258726);
++R.GAS;
return $ret87298730;
} else {
var cont_tail_arg6268737 = R.throwNonBooleanOp(L[997],("second"),("and"),and_DASH_oper_DASH_478721);
if(--R.GAS > 0) {
$z87358736 = R.isFunction(if_helper6178691)?if_helper6178691.app(cont_tail_arg6268737):R.ffi.throwNonFunApp(L[997],if_helper6178691,[cont_tail_arg6268737]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper6178691)?if_helper6178691.app(cont_tail_arg6268737):R.ffi.throwNonFunApp(L[997],if_helper6178691,[cont_tail_arg6268737]);
},
"from":L[997]});
}
++R.GAS;
return $z87358736;
}
};
var $Hcont_tail_app19658734 = function(cont_tail_app6298733) {
return cont_tail_app6298733;
};
var $Hcont_tail_app19688704 = function(cont_tail_app6228703) {
return cont_tail_app6228703;
};
var $Hanf_arg19641601 = function(anf_arg5951600,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot9775,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655) {
var $z87418742 = D;
var $f87478748 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(anf_arg5951600,("length")):R.ffi.throwNonFunApp(L[998],j_DASH_dot9775,[anf_arg5951600,("length")]);
};
try {
if(--R.GAS > 0) {
$z87418742 = $f87478748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87478748,
"from":L[998]});
}
} catch($e87398740) {
if(R.isCont($e87398740)) {
var $ss87438744 = {"from":L[998],
"go":function(anf_arg5968749) {
return $Hanf_arg19638750(anf_arg5968749,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655);
}};
$e87398740.stack[R.EXN_STACKHEIGHT++] = $ss87438744;
}
if(R.isPyretException($e87398740)) {
$e87398740.pyretStack.push(L[998]);
}
throw $e87398740;
}
var $ret87458746 = $Hanf_arg19638750($z87418742,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655);
++R.GAS;
return $ret87458746;
};
var $Hanf_arg19638750 = function(anf_arg5968749,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655) {
var $z87538754 = D;
var $f87598760 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(arity2741589):R.ffi.throwNonFunApp(L[999],j_DASH_num8889,[arity2741589]);
};
try {
if(--R.GAS > 0) {
$z87538754 = $f87598760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87598760,
"from":L[999]});
}
} catch($e87518752) {
if(R.isCont($e87518752)) {
var $ss87558756 = {"from":L[999],
"go":function(anf_arg5978761) {
return $Hanf_arg19628762(anf_arg5978761,anf_arg5968749,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655);
}};
$e87518752.stack[R.EXN_STACKHEIGHT++] = $ss87558756;
}
if(R.isPyretException($e87518752)) {
$e87518752.pyretStack.push(L[999]);
}
throw $e87518752;
}
var $ret87578758 = $Hanf_arg19628762($z87538754,anf_arg5968749,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655);
++R.GAS;
return $ret87578758;
};
var $Hanf_arg19628762 = function(anf_arg5978761,anf_arg5968749,arity2741589,body_DASH_stmts2731588,j_DASH_binop10569,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_neq10787,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655) {
var $z87658766 = D;
var $f87718772 = function(_) {
return R.isFunction(j_DASH_binop10569)?j_DASH_binop10569.app(anf_arg5968749,j_DASH_neq10787,anf_arg5978761):R.ffi.throwNonFunApp(L[1000],j_DASH_binop10569,[anf_arg5968749,j_DASH_neq10787,anf_arg5978761]);
};
try {
if(--R.GAS > 0) {
$z87658766 = $f87718772();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87718772,
"from":L[1000]});
}
} catch($e87638764) {
if(R.isCont($e87638764)) {
var $ss87678768 = {"from":L[1000],
"go":function(anf_arg5988773) {
return $Hanf_arg19618774(anf_arg5988773,arity2741589,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655);
}};
$e87638764.stack[R.EXN_STACKHEIGHT++] = $ss87678768;
}
if(R.isPyretException($e87638764)) {
$e87638764.pyretStack.push(L[1000]);
}
throw $e87638764;
}
var $ret87698770 = $Hanf_arg19618774($z87658766,arity2741589,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655);
++R.GAS;
return $ret87698770;
};
var $Hanf_arg19618774 = function(anf_arg5988773,arity2741589,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587,rt_DASH_field172655) {
var anf_fun5998786 = G(list35101,"make",L[1002]);
var $z87778778 = D;
var $f87838784 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("ffi")):R.ffi.throwNonFunApp(L[1001],rt_DASH_field172655.$var,[("ffi")]);
};
try {
if(--R.GAS > 0) {
$z87778778 = $f87838784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87838784,
"from":L[1001]});
}
} catch($e87758776) {
if(R.isCont($e87758776)) {
var $ss87798780 = {"from":L[1001],
"go":function(anf_arg6008785) {
return $Hanf_arg19608787(anf_arg6008785,anf_arg5988773,anf_fun5998786,arity2741589,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587);
}};
$e87758776.stack[R.EXN_STACKHEIGHT++] = $ss87798780;
}
if(R.isPyretException($e87758776)) {
$e87758776.pyretStack.push(L[1001]);
}
throw $e87758776;
}
var $ret87818782 = $Hanf_arg19608787($z87778778,anf_arg5988773,anf_fun5998786,arity2741589,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587);
++R.GAS;
return $ret87818782;
};
var $Hanf_arg19608787 = function(anf_arg6008785,anf_arg5988773,anf_fun5998786,arity2741589,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_num8889,j_DASH_throw10395,link39100,list35101,loc_DASH_expr2721587) {
var anf_fun6018799 = G(list35101,"make",L[1004]);
var $z87908791 = D;
var $f87968797 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(arity2741589):R.ffi.throwNonFunApp(L[1003],j_DASH_num8889,[arity2741589]);
};
try {
if(--R.GAS > 0) {
$z87908791 = $f87968797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87968797,
"from":L[1003]});
}
} catch($e87888789) {
if(R.isCont($e87888789)) {
var $ss87928793 = {"from":L[1003],
"go":function(anf_array_val6028798) {
return $Hanf_array_val19598800(anf_array_val6028798,anf_arg5988773,anf_arg6008785,anf_fun5998786,anf_fun6018799,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100,loc_DASH_expr2721587);
}};
$e87888789.stack[R.EXN_STACKHEIGHT++] = $ss87928793;
}
if(R.isPyretException($e87888789)) {
$e87888789.pyretStack.push(L[1003]);
}
throw $e87888789;
}
var $ret87948795 = $Hanf_array_val19598800($z87908791,anf_arg5988773,anf_arg6008785,anf_fun5998786,anf_fun6018799,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100,loc_DASH_expr2721587);
++R.GAS;
return $ret87948795;
};
var $Hanf_array_val19598800 = function(anf_array_val6028798,anf_arg5988773,anf_arg6008785,anf_fun5998786,anf_fun6018799,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_id8381,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100,loc_DASH_expr2721587) {
var $z88038804 = D;
var $f88098810 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("arguments")):R.ffi.throwNonFunApp(L[1005],j_DASH_id8381,[("arguments")]);
};
try {
if(--R.GAS > 0) {
$z88038804 = $f88098810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88098810,
"from":L[1005]});
}
} catch($e88018802) {
if(R.isCont($e88018802)) {
var $ss88058806 = {"from":L[1005],
"go":function(anf_array_val6038811) {
return $Hanf_array_val19588812(anf_array_val6038811,anf_arg5988773,anf_arg6008785,anf_array_val6028798,anf_fun5998786,anf_fun6018799,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100,loc_DASH_expr2721587);
}};
$e88018802.stack[R.EXN_STACKHEIGHT++] = $ss88058806;
}
if(R.isPyretException($e88018802)) {
$e88018802.pyretStack.push(L[1005]);
}
throw $e88018802;
}
var $ret88078808 = $Hanf_array_val19588812($z88038804,anf_arg5988773,anf_arg6008785,anf_array_val6028798,anf_fun5998786,anf_fun6018799,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100,loc_DASH_expr2721587);
++R.GAS;
return $ret88078808;
};
var $Hanf_array_val19588812 = function(anf_array_val6038811,anf_arg5988773,anf_arg6008785,anf_array_val6028798,anf_fun5998786,anf_fun6018799,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100,loc_DASH_expr2721587) {
var $z88158816 = D;
var $f88218822 = function(_) {
return R.isFunction(anf_fun6018799)?anf_fun6018799.app([loc_DASH_expr2721587,anf_array_val6028798,anf_array_val6038811]):R.ffi.throwNonFunApp(L[1004],anf_fun6018799,[[loc_DASH_expr2721587,anf_array_val6028798,anf_array_val6038811]]);
};
try {
if(--R.GAS > 0) {
$z88158816 = $f88218822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88218822,
"from":L[1004]});
}
} catch($e88138814) {
if(R.isCont($e88138814)) {
var $ss88178818 = {"from":L[1004],
"go":function(anf_arg6048823) {
return $Hanf_arg19578824(anf_arg6048823,anf_arg5988773,anf_arg6008785,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100);
}};
$e88138814.stack[R.EXN_STACKHEIGHT++] = $ss88178818;
}
if(R.isPyretException($e88138814)) {
$e88138814.pyretStack.push(L[1004]);
}
throw $e88138814;
}
var $ret88198820 = $Hanf_arg19578824($z88158816,anf_arg5988773,anf_arg6008785,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100);
++R.GAS;
return $ret88198820;
};
var $Hanf_arg19578824 = function(anf_arg6048823,anf_arg5988773,anf_arg6008785,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_method8486,j_DASH_throw10395,link39100) {
var $z88278828 = D;
var $f88338834 = function(_) {
return R.isFunction(j_DASH_method8486)?j_DASH_method8486.app(anf_arg6008785,("throwArityErrorC"),anf_arg6048823):R.ffi.throwNonFunApp(L[1006],j_DASH_method8486,[anf_arg6008785,("throwArityErrorC"),anf_arg6048823]);
};
try {
if(--R.GAS > 0) {
$z88278828 = $f88338834();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88338834,
"from":L[1006]});
}
} catch($e88258826) {
if(R.isCont($e88258826)) {
var $ss88298830 = {"from":L[1006],
"go":function(anf_arg6058835) {
return $Hanf_arg19568836(anf_arg6058835,anf_arg5988773,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_throw10395,link39100);
}};
$e88258826.stack[R.EXN_STACKHEIGHT++] = $ss88298830;
}
if(R.isPyretException($e88258826)) {
$e88258826.pyretStack.push(L[1006]);
}
throw $e88258826;
}
var $ret88318832 = $Hanf_arg19568836($z88278828,anf_arg5988773,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_throw10395,link39100);
++R.GAS;
return $ret88318832;
};
var $Hanf_arg19568836 = function(anf_arg6058835,anf_arg5988773,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,j_DASH_throw10395,link39100) {
var $z88398840 = D;
var $f88458846 = function(_) {
return R.isFunction(j_DASH_throw10395)?j_DASH_throw10395.app(anf_arg6058835):R.ffi.throwNonFunApp(L[1007],j_DASH_throw10395,[anf_arg6058835]);
};
try {
if(--R.GAS > 0) {
$z88398840 = $f88458846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88458846,
"from":L[1007]});
}
} catch($e88378838) {
if(R.isCont($e88378838)) {
var $ss88418842 = {"from":L[1007],
"go":function(anf_array_val6068847) {
return $Hanf_array_val19558848(anf_array_val6068847,anf_arg5988773,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100);
}};
$e88378838.stack[R.EXN_STACKHEIGHT++] = $ss88418842;
}
if(R.isPyretException($e88378838)) {
$e88378838.pyretStack.push(L[1007]);
}
throw $e88378838;
}
var $ret88438844 = $Hanf_array_val19558848($z88398840,anf_arg5988773,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100);
++R.GAS;
return $ret88438844;
};
var $Hanf_array_val19558848 = function(anf_array_val6068847,anf_arg5988773,anf_fun5998786,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100) {
var $z88518852 = D;
var $f88578858 = function(_) {
return R.isFunction(anf_fun5998786)?anf_fun5998786.app([anf_array_val6068847]):R.ffi.throwNonFunApp(L[1002],anf_fun5998786,[[anf_array_val6068847]]);
};
try {
if(--R.GAS > 0) {
$z88518852 = $f88578858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88578858,
"from":L[1002]});
}
} catch($e88498850) {
if(R.isCont($e88498850)) {
var $ss88538854 = {"from":L[1002],
"go":function(anf_arg6078859) {
return $Hanf_arg19548860(anf_arg6078859,anf_arg5988773,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100);
}};
$e88498850.stack[R.EXN_STACKHEIGHT++] = $ss88538854;
}
if(R.isPyretException($e88498850)) {
$e88498850.pyretStack.push(L[1002]);
}
throw $e88498850;
}
var $ret88558856 = $Hanf_arg19548860($z88518852,anf_arg5988773,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100);
++R.GAS;
return $ret88558856;
};
var $Hanf_arg19548860 = function(anf_arg6078859,anf_arg5988773,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100) {
var $z88638864 = D;
var $f88698870 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg6078859):R.ffi.throwNonFunApp(L[1008],j_DASH_block8570,[anf_arg6078859]);
};
try {
if(--R.GAS > 0) {
$z88638864 = $f88698870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88698870,
"from":L[1008]});
}
} catch($e88618862) {
if(R.isCont($e88618862)) {
var $ss88658866 = {"from":L[1008],
"go":function(anf_arg6088871) {
return $Hanf_arg19538872(anf_arg6088871,anf_arg5988773,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100);
}};
$e88618862.stack[R.EXN_STACKHEIGHT++] = $ss88658866;
}
if(R.isPyretException($e88618862)) {
$e88618862.pyretStack.push(L[1008]);
}
throw $e88618862;
}
var $ret88678868 = $Hanf_arg19538872($z88638864,anf_arg5988773,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100);
++R.GAS;
return $ret88678868;
};
var $Hanf_arg19538872 = function(anf_arg6088871,anf_arg5988773,body_DASH_stmts2731588,j_DASH_block8570,j_DASH_if19382,link39100) {
var $z88758876 = D;
var $f88818882 = function(_) {
return R.isFunction(j_DASH_if19382)?j_DASH_if19382.app(anf_arg5988773,anf_arg6088871):R.ffi.throwNonFunApp(L[1009],j_DASH_if19382,[anf_arg5988773,anf_arg6088871]);
};
try {
if(--R.GAS > 0) {
$z88758876 = $f88818882();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88818882,
"from":L[1009]});
}
} catch($e88738874) {
if(R.isCont($e88738874)) {
var $ss88778878 = {"from":L[1009],
"go":function(anf_arg6098883) {
return $Hanf_arg19528884(anf_arg6098883,body_DASH_stmts2731588,j_DASH_block8570,link39100);
}};
$e88738874.stack[R.EXN_STACKHEIGHT++] = $ss88778878;
}
if(R.isPyretException($e88738874)) {
$e88738874.pyretStack.push(L[1009]);
}
throw $e88738874;
}
var $ret88798880 = $Hanf_arg19528884($z88758876,body_DASH_stmts2731588,j_DASH_block8570,link39100);
++R.GAS;
return $ret88798880;
};
var $Hanf_arg19528884 = function(anf_arg6098883,body_DASH_stmts2731588,j_DASH_block8570,link39100) {
var $z88878888 = D;
var $f88938894 = function(_) {
return R.isFunction(link39100)?link39100.app(anf_arg6098883,body_DASH_stmts2731588):R.ffi.throwNonFunApp(L[1010],link39100,[anf_arg6098883,body_DASH_stmts2731588]);
};
try {
if(--R.GAS > 0) {
$z88878888 = $f88938894();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88938894,
"from":L[1010]});
}
} catch($e88858886) {
if(R.isCont($e88858886)) {
var $ss88898890 = {"from":L[1010],
"go":function(anf_arg6108895) {
return $Hanf_arg19518896(anf_arg6108895,j_DASH_block8570);
}};
$e88858886.stack[R.EXN_STACKHEIGHT++] = $ss88898890;
}
if(R.isPyretException($e88858886)) {
$e88858886.pyretStack.push(L[1010]);
}
throw $e88858886;
}
var $ret88918892 = $Hanf_arg19518896($z88878888,j_DASH_block8570);
++R.GAS;
return $ret88918892;
};
var $Hanf_arg19518896 = function(anf_arg6108895,j_DASH_block8570) {
var $z88998900 = D;
var $f89058906 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg6108895):R.ffi.throwNonFunApp(L[273],j_DASH_block8570,[anf_arg6108895]);
};
try {
if(--R.GAS > 0) {
$z88998900 = $f89058906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89058906,
"from":L[273]});
}
} catch($e88978898) {
if(R.isCont($e88978898)) {
var $ss89018902 = {"from":L[273],
"go":function(ann_DASH_check_DASH_temp5948907) {
return $Hann_DASH_check_DASH_temp19508908(ann_DASH_check_DASH_temp5948907);
}};
$e88978898.stack[R.EXN_STACKHEIGHT++] = $ss89018902;
}
if(R.isPyretException($e88978898)) {
$e88978898.pyretStack.push(L[273]);
}
throw $e88978898;
}
var $ret89038904 = $Hann_DASH_check_DASH_temp19508908($z88998900);
++R.GAS;
return $ret89038904;
};
var $Hann_DASH_check_DASH_temp19508908 = function(ann_DASH_check_DASH_temp5948907) {
return ann_DASH_check_DASH_temp5948907;
};
var $Hann_DASH_check_DASH_temp19491618 = function(ann_DASH_check_DASH_temp5081617) {
return ann_DASH_check_DASH_temp5081617;
};
var $Hann_DASH_check_DASH_temp19481640 = function(ann_DASH_check_DASH_temp5881639) {
return ann_DASH_check_DASH_temp5881639;
};
var $Hann_DASH_check_DASH_temp19471652 = function(ann_DASH_check_DASH_temp5861651) {
return ann_DASH_check_DASH_temp5861651;
};
var $Hanf_array_val19461669 = function(anf_array_val5751667,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657) {
var anf_fun5768919 = G(m2701654,"toname",L[1012]);
var $z89118912 = D;
var $f89178918 = function(_) {
return R.isFunction(anf_fun5768919)?anf_fun5768919.app():R.ffi.throwNonFunApp(L[1011],anf_fun5768919,[]);
};
try {
if(--R.GAS > 0) {
$z89118912 = $f89178918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89178918,
"from":L[1011]});
}
} catch($e89098910) {
if(R.isCont($e89098910)) {
var $ss89138914 = {"from":L[1011],
"go":function(anf_arg5778920) {
return $Hanf_arg19458921(anf_arg5778920,anf_array_val5751667,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657);
}};
$e89098910.stack[R.EXN_STACKHEIGHT++] = $ss89138914;
}
if(R.isPyretException($e89098910)) {
$e89098910.pyretStack.push(L[1011]);
}
throw $e89098910;
}
var $ret89158916 = $Hanf_arg19458921($z89118912,anf_array_val5751667,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657);
++R.GAS;
return $ret89158916;
};
var $Hanf_arg19458921 = function(anf_arg5778920,anf_array_val5751667,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657) {
var $z89248925 = D;
var $f89308931 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(anf_arg5778920):R.ffi.throwNonFunApp(L[1013],j_DASH_str8993,[anf_arg5778920]);
};
try {
if(--R.GAS > 0) {
$z89248925 = $f89308931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89308931,
"from":L[1013]});
}
} catch($e89228923) {
if(R.isCont($e89228923)) {
var $ss89268927 = {"from":L[1013],
"go":function(anf_array_val5788932) {
return $Hanf_array_val19448933(anf_array_val5788932,anf_array_val5751667,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657);
}};
$e89228923.stack[R.EXN_STACKHEIGHT++] = $ss89268927;
}
if(R.isPyretException($e89228923)) {
$e89228923.pyretStack.push(L[1013]);
}
throw $e89228923;
}
var $ret89288929 = $Hanf_array_val19448933($z89248925,anf_array_val5751667,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657);
++R.GAS;
return $ret89288929;
};
var $Hanf_array_val19448933 = function(anf_array_val5788932,anf_array_val5751667,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,m2701654,rt_DASH_method173657) {
var anf_fun5798944 = G(m2701654,"tostring",L[1015]);
var $z89368937 = D;
var $f89428943 = function(_) {
return R.isFunction(anf_fun5798944)?anf_fun5798944.app():R.ffi.throwNonFunApp(L[1014],anf_fun5798944,[]);
};
try {
if(--R.GAS > 0) {
$z89368937 = $f89428943();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89428943,
"from":L[1014]});
}
} catch($e89348935) {
if(R.isCont($e89348935)) {
var $ss89388939 = {"from":L[1014],
"go":function(anf_arg5808945) {
return $Hanf_arg19438946(anf_arg5808945,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,rt_DASH_method173657);
}};
$e89348935.stack[R.EXN_STACKHEIGHT++] = $ss89388939;
}
if(R.isPyretException($e89348935)) {
$e89348935.pyretStack.push(L[1014]);
}
throw $e89348935;
}
var $ret89408941 = $Hanf_arg19438946($z89368937,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,rt_DASH_method173657);
++R.GAS;
return $ret89408941;
};
var $Hanf_arg19438946 = function(anf_arg5808945,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,js_DASH_id_DASH_of162700,rt_DASH_method173657) {
var $z89498950 = D;
var $f89558956 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg5808945):R.ffi.throwNonFunApp(L[1016],js_DASH_id_DASH_of162700,[anf_arg5808945]);
};
try {
if(--R.GAS > 0) {
$z89498950 = $f89558956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89558956,
"from":L[1016]});
}
} catch($e89478948) {
if(R.isCont($e89478948)) {
var $ss89518952 = {"from":L[1016],
"go":function(anf_arg5818957) {
return $Hanf_arg19428958(anf_arg5818957,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,rt_DASH_method173657);
}};
$e89478948.stack[R.EXN_STACKHEIGHT++] = $ss89518952;
}
if(R.isPyretException($e89478948)) {
$e89478948.pyretStack.push(L[1016]);
}
throw $e89478948;
}
var $ret89538954 = $Hanf_arg19428958($z89498950,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,rt_DASH_method173657);
++R.GAS;
return $ret89538954;
};
var $Hanf_arg19428958 = function(anf_arg5818957,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_id8381,j_DASH_str8993,rt_DASH_method173657) {
var $z89618962 = D;
var $f89678968 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg5818957):R.ffi.throwNonFunApp(L[1017],j_DASH_id8381,[anf_arg5818957]);
};
try {
if(--R.GAS > 0) {
$z89618962 = $f89678968();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89678968,
"from":L[1017]});
}
} catch($e89598960) {
if(R.isCont($e89598960)) {
var $ss89638964 = {"from":L[1017],
"go":function(anf_array_val5828969) {
return $Hanf_array_val19418970(anf_array_val5828969,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_str8993,rt_DASH_method173657);
}};
$e89598960.stack[R.EXN_STACKHEIGHT++] = $ss89638964;
}
if(R.isPyretException($e89598960)) {
$e89598960.pyretStack.push(L[1017]);
}
throw $e89598960;
}
var $ret89658966 = $Hanf_array_val19418970($z89618962,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_str8993,rt_DASH_method173657);
++R.GAS;
return $ret89658966;
};
var $Hanf_array_val19418970 = function(anf_array_val5828969,anf_array_val5751667,anf_array_val5788932,anf_fun5731668,field2711655,j_DASH_str8993,rt_DASH_method173657) {
var $z89738974 = D;
var $f89798980 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(field2711655):R.ffi.throwNonFunApp(L[1018],j_DASH_str8993,[field2711655]);
};
try {
if(--R.GAS > 0) {
$z89738974 = $f89798980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89798980,
"from":L[1018]});
}
} catch($e89718972) {
if(R.isCont($e89718972)) {
var $ss89758976 = {"from":L[1018],
"go":function(anf_array_val5838981) {
return $Hanf_array_val19408982(anf_array_val5838981,anf_array_val5751667,anf_array_val5788932,anf_array_val5828969,anf_fun5731668,rt_DASH_method173657);
}};
$e89718972.stack[R.EXN_STACKHEIGHT++] = $ss89758976;
}
if(R.isPyretException($e89718972)) {
$e89718972.pyretStack.push(L[1018]);
}
throw $e89718972;
}
var $ret89778978 = $Hanf_array_val19408982($z89738974,anf_array_val5751667,anf_array_val5788932,anf_array_val5828969,anf_fun5731668,rt_DASH_method173657);
++R.GAS;
return $ret89778978;
};
var $Hanf_array_val19408982 = function(anf_array_val5838981,anf_array_val5751667,anf_array_val5788932,anf_array_val5828969,anf_fun5731668,rt_DASH_method173657) {
var $z89858986 = D;
var $f89918992 = function(_) {
return R.isFunction(anf_fun5731668)?anf_fun5731668.app([anf_array_val5751667,anf_array_val5788932,anf_array_val5828969,anf_array_val5838981]):R.ffi.throwNonFunApp(L[282],anf_fun5731668,[[anf_array_val5751667,anf_array_val5788932,anf_array_val5828969,anf_array_val5838981]]);
};
try {
if(--R.GAS > 0) {
$z89858986 = $f89918992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89918992,
"from":L[282]});
}
} catch($e89838984) {
if(R.isCont($e89838984)) {
var $ss89878988 = {"from":L[282],
"go":function(anf_arg5848993) {
return $Hanf_arg19398994(anf_arg5848993,rt_DASH_method173657);
}};
$e89838984.stack[R.EXN_STACKHEIGHT++] = $ss89878988;
}
if(R.isPyretException($e89838984)) {
$e89838984.pyretStack.push(L[282]);
}
throw $e89838984;
}
var $ret89898990 = $Hanf_arg19398994($z89858986,rt_DASH_method173657);
++R.GAS;
return $ret89898990;
};
var $Hanf_arg19398994 = function(anf_arg5848993,rt_DASH_method173657) {
var $z89978998 = D;
var $f90039004 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("getDotAnn"),anf_arg5848993):R.ffi.throwNonFunApp(L[279],rt_DASH_method173657.$var,[("getDotAnn"),anf_arg5848993]);
};
try {
if(--R.GAS > 0) {
$z89978998 = $f90039004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90039004,
"from":L[279]});
}
} catch($e89958996) {
if(R.isCont($e89958996)) {
var $ss89999000 = {"from":L[279],
"go":function(ann_DASH_check_DASH_temp5729005) {
return $Hann_DASH_check_DASH_temp19389006(ann_DASH_check_DASH_temp5729005);
}};
$e89958996.stack[R.EXN_STACKHEIGHT++] = $ss89999000;
}
if(R.isPyretException($e89958996)) {
$e89958996.pyretStack.push(L[279]);
}
throw $e89958996;
}
var $ret90019002 = $Hann_DASH_check_DASH_temp19389006($z89978998);
++R.GAS;
return $ret90019002;
};
var $Hann_DASH_check_DASH_temp19389006 = function(ann_DASH_check_DASH_temp5729005) {
return ann_DASH_check_DASH_temp5729005;
};
var $Hname19371687 = function(name2571686,N319,base2551671,compile_DASH_ann181673,exp2561672,j_DASH_str8993,list35101,rt_DASH_method173657,visitor2351603) {
var cases_DASH_val449056 = exp2561672;
var anf_fun5559017 = G(cases_DASH_val449056,"_match",L[1020]);
var anf_obj5589023 = R.makeFunction(function(l22649041,id2659042) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1023],2,arguments);
}
var anf_fun5579053 = G(N319,"a-id",L[1024]);
var $z90459046 = D;
var $f90519052 = function(_) {
return R.isFunction(anf_fun5579053)?anf_fun5579053.app(l22649041,id2659042):R.ffi.throwNonFunApp(L[1023],anf_fun5579053,[l22649041,id2659042]);
};
try {
if(--R.GAS > 0) {
$z90459046 = $f90519052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90519052,
"from":L[1023]});
}
} catch($e90439044) {
if(R.isCont($e90439044)) {
var $ss90479048 = {"from":L[1023],
"go":function(ann_DASH_check_DASH_temp5569054) {
return $Hann_DASH_check_DASH_temp19299055(ann_DASH_check_DASH_temp5569054);
}};
$e90439044.stack[R.EXN_STACKHEIGHT++] = $ss90479048;
}
if(R.isPyretException($e90439044)) {
$e90439044.pyretStack.push(L[1023]);
}
throw $e90439044;
}
var $ret90499050 = $Hann_DASH_check_DASH_temp19299055($z90459046);
++R.GAS;
return $ret90499050;
});
var anf_obj5619024 = R.makeFunction(function(l22669025,id2679026,ok2689027) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1021],3,arguments);
}
var anf_fun5609038 = G(N319,"a-id-letrec",L[1022]);
var $z90309031 = D;
var $f90369037 = function(_) {
return R.isFunction(anf_fun5609038)?anf_fun5609038.app(l22669025,id2679026,ok2689027):R.ffi.throwNonFunApp(L[1021],anf_fun5609038,[l22669025,id2679026,ok2689027]);
};
try {
if(--R.GAS > 0) {
$z90309031 = $f90369037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90369037,
"from":L[1021]});
}
} catch($e90289029) {
if(R.isCont($e90289029)) {
var $ss90329033 = {"from":L[1021],
"go":function(ann_DASH_check_DASH_temp5599039) {
return $Hann_DASH_check_DASH_temp19309040(ann_DASH_check_DASH_temp5599039);
}};
$e90289029.stack[R.EXN_STACKHEIGHT++] = $ss90329033;
}
if(R.isPyretException($e90289029)) {
$e90289029.pyretStack.push(L[1021]);
}
throw $e90289029;
}
var $ret90349035 = $Hann_DASH_check_DASH_temp19309040($z90309031);
++R.GAS;
return $ret90349035;
});
var anf_arg5629018 = R.makeObject({"s-id":anf_obj5589023,
"s-id-letrec":anf_obj5619024});
var anf_arg5649019 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1020],0,arguments);
}
var ann_DASH_check_DASH_temp5639022 = R.throwNoBranchesMatched(L[1020],("cases"));
return ann_DASH_check_DASH_temp5639022;
});
var $z90099010 = D;
var $f90159016 = function(_) {
return R.isFunction(anf_fun5559017)?anf_fun5559017.app(anf_arg5629018,anf_arg5649019):R.ffi.throwNonFunApp(L[1019],anf_fun5559017,[anf_arg5629018,anf_arg5649019]);
};
try {
if(--R.GAS > 0) {
$z90099010 = $f90159016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90159016,
"from":L[1019]});
}
} catch($e90079008) {
if(R.isCont($e90079008)) {
var $ss90119012 = {"from":L[1019],
"go":function(expr_DASH_to_DASH_compile2639020) {
return $Hexpr_DASH_to_DASH_compile19369021(expr_DASH_to_DASH_compile2639020,base2551671,compile_DASH_ann181673,j_DASH_str8993,list35101,name2571686,rt_DASH_method173657,visitor2351603);
}};
$e90079008.stack[R.EXN_STACKHEIGHT++] = $ss90119012;
}
if(R.isPyretException($e90079008)) {
$e90079008.pyretStack.push(L[1019]);
}
throw $e90079008;
}
var $ret90139014 = $Hexpr_DASH_to_DASH_compile19369021($z90099010,base2551671,compile_DASH_ann181673,j_DASH_str8993,list35101,name2571686,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret90139014;
};
var $Hexpr_DASH_to_DASH_compile19369021 = function(expr_DASH_to_DASH_compile2639020,base2551671,compile_DASH_ann181673,j_DASH_str8993,list35101,name2571686,rt_DASH_method173657,visitor2351603) {
var anf_fun5659068 = G(list35101,"make",L[1026]);
var $z90599060 = D;
var $f90659066 = function(_) {
return R.isFunction(compile_DASH_ann181673.$var)?compile_DASH_ann181673.$var.app(base2551671,visitor2351603):R.ffi.throwNonFunApp(L[1025],compile_DASH_ann181673.$var,[base2551671,visitor2351603]);
};
try {
if(--R.GAS > 0) {
$z90599060 = $f90659066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90659066,
"from":L[1025]});
}
} catch($e90579058) {
if(R.isCont($e90579058)) {
var $ss90619062 = {"from":L[1025],
"go":function(anf_array_val5669067) {
return $Hanf_array_val19359069(anf_array_val5669067,anf_fun5659068,expr_DASH_to_DASH_compile2639020,j_DASH_str8993,name2571686,rt_DASH_method173657,visitor2351603);
}};
$e90579058.stack[R.EXN_STACKHEIGHT++] = $ss90619062;
}
if(R.isPyretException($e90579058)) {
$e90579058.pyretStack.push(L[1025]);
}
throw $e90579058;
}
var $ret90639064 = $Hanf_array_val19359069($z90599060,anf_fun5659068,expr_DASH_to_DASH_compile2639020,j_DASH_str8993,name2571686,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret90639064;
};
var $Hanf_array_val19359069 = function(anf_array_val5669067,anf_fun5659068,expr_DASH_to_DASH_compile2639020,j_DASH_str8993,name2571686,rt_DASH_method173657,visitor2351603) {
var anf_fun5679080 = G(expr_DASH_to_DASH_compile2639020,"visit",L[1028]);
var $z90729073 = D;
var $f90789079 = function(_) {
return R.isFunction(anf_fun5679080)?anf_fun5679080.app(visitor2351603):R.ffi.throwNonFunApp(L[1027],anf_fun5679080,[visitor2351603]);
};
try {
if(--R.GAS > 0) {
$z90729073 = $f90789079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90789079,
"from":L[1027]});
}
} catch($e90709071) {
if(R.isCont($e90709071)) {
var $ss90749075 = {"from":L[1027],
"go":function(anf_array_val5689081) {
return $Hanf_array_val19349082(anf_array_val5689081,anf_array_val5669067,anf_fun5659068,j_DASH_str8993,name2571686,rt_DASH_method173657);
}};
$e90709071.stack[R.EXN_STACKHEIGHT++] = $ss90749075;
}
if(R.isPyretException($e90709071)) {
$e90709071.pyretStack.push(L[1027]);
}
throw $e90709071;
}
var $ret90769077 = $Hanf_array_val19349082($z90729073,anf_array_val5669067,anf_fun5659068,j_DASH_str8993,name2571686,rt_DASH_method173657);
++R.GAS;
return $ret90769077;
};
var $Hanf_array_val19349082 = function(anf_array_val5689081,anf_array_val5669067,anf_fun5659068,j_DASH_str8993,name2571686,rt_DASH_method173657) {
var $z90859086 = D;
var $f90919092 = function(_) {
return R.isFunction(j_DASH_str8993)?j_DASH_str8993.app(name2571686):R.ffi.throwNonFunApp(L[1029],j_DASH_str8993,[name2571686]);
};
try {
if(--R.GAS > 0) {
$z90859086 = $f90919092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90919092,
"from":L[1029]});
}
} catch($e90839084) {
if(R.isCont($e90839084)) {
var $ss90879088 = {"from":L[1029],
"go":function(anf_array_val5699093) {
return $Hanf_array_val19339094(anf_array_val5699093,anf_array_val5669067,anf_array_val5689081,anf_fun5659068,rt_DASH_method173657);
}};
$e90839084.stack[R.EXN_STACKHEIGHT++] = $ss90879088;
}
if(R.isPyretException($e90839084)) {
$e90839084.pyretStack.push(L[1029]);
}
throw $e90839084;
}
var $ret90899090 = $Hanf_array_val19339094($z90859086,anf_array_val5669067,anf_array_val5689081,anf_fun5659068,rt_DASH_method173657);
++R.GAS;
return $ret90899090;
};
var $Hanf_array_val19339094 = function(anf_array_val5699093,anf_array_val5669067,anf_array_val5689081,anf_fun5659068,rt_DASH_method173657) {
var $z90979098 = D;
var $f91039104 = function(_) {
return R.isFunction(anf_fun5659068)?anf_fun5659068.app([anf_array_val5669067,anf_array_val5689081,anf_array_val5699093]):R.ffi.throwNonFunApp(L[1026],anf_fun5659068,[[anf_array_val5669067,anf_array_val5689081,anf_array_val5699093]]);
};
try {
if(--R.GAS > 0) {
$z90979098 = $f91039104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91039104,
"from":L[1026]});
}
} catch($e90959096) {
if(R.isCont($e90959096)) {
var $ss90999100 = {"from":L[1026],
"go":function(anf_arg5709105) {
return $Hanf_arg19329106(anf_arg5709105,rt_DASH_method173657);
}};
$e90959096.stack[R.EXN_STACKHEIGHT++] = $ss90999100;
}
if(R.isPyretException($e90959096)) {
$e90959096.pyretStack.push(L[1026]);
}
throw $e90959096;
}
var $ret91019102 = $Hanf_arg19329106($z90979098,rt_DASH_method173657);
++R.GAS;
return $ret91019102;
};
var $Hanf_arg19329106 = function(anf_arg5709105,rt_DASH_method173657) {
var $z91099110 = D;
var $f91159116 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makePredAnn"),anf_arg5709105):R.ffi.throwNonFunApp(L[283],rt_DASH_method173657.$var,[("makePredAnn"),anf_arg5709105]);
};
try {
if(--R.GAS > 0) {
$z91099110 = $f91159116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91159116,
"from":L[283]});
}
} catch($e91079108) {
if(R.isCont($e91079108)) {
var $ss91119112 = {"from":L[283],
"go":function(ann_DASH_check_DASH_temp5449117) {
return $Hann_DASH_check_DASH_temp19319118(ann_DASH_check_DASH_temp5449117);
}};
$e91079108.stack[R.EXN_STACKHEIGHT++] = $ss91119112;
}
if(R.isPyretException($e91079108)) {
$e91079108.pyretStack.push(L[283]);
}
throw $e91079108;
}
var $ret91139114 = $Hann_DASH_check_DASH_temp19319118($z91099110);
++R.GAS;
return $ret91139114;
};
var $Hann_DASH_check_DASH_temp19319118 = function(ann_DASH_check_DASH_temp5449117) {
return ann_DASH_check_DASH_temp5449117;
};
var $Hann_DASH_check_DASH_temp19309040 = function(ann_DASH_check_DASH_temp5599039) {
return ann_DASH_check_DASH_temp5599039;
};
var $Hann_DASH_check_DASH_temp19299055 = function(ann_DASH_check_DASH_temp5569054) {
return ann_DASH_check_DASH_temp5569054;
};
var $Hann_DASH_check_DASH_temp19281706 = function(ann_DASH_check_DASH_temp5491705) {
return ann_DASH_check_DASH_temp5491705;
};
var $Hann_DASH_check_DASH_temp19271721 = function(ann_DASH_check_DASH_temp5461720) {
return ann_DASH_check_DASH_temp5461720;
};
var $Hanf_bracket19261738 = function(anf_bracket5251737,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,j_DASH_str8993,list35101,map47104,rt_DASH_method173657,visitor2351603) {
var anf_fun5269129 = G(anf_bracket5251737,"map",L[1031]);
var $z91219122 = D;
var $f91279128 = function(_) {
return R.isFunction(anf_fun5269129)?anf_fun5269129.app(j_DASH_str8993):R.ffi.throwNonFunApp(L[1030],anf_fun5269129,[j_DASH_str8993]);
};
try {
if(--R.GAS > 0) {
$z91219122 = $f91279128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91279128,
"from":L[1030]});
}
} catch($e91199120) {
if(R.isCont($e91199120)) {
var $ss91239124 = {"from":L[1030],
"go":function(anf_arg5279130) {
return $Hanf_arg19259131(anf_arg5279130,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,rt_DASH_method173657,visitor2351603);
}};
$e91199120.stack[R.EXN_STACKHEIGHT++] = $ss91239124;
}
if(R.isPyretException($e91199120)) {
$e91199120.pyretStack.push(L[1030]);
}
throw $e91199120;
}
var $ret91259126 = $Hanf_arg19259131($z91219122,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret91259126;
};
var $Hanf_arg19259131 = function(anf_arg5279130,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,rt_DASH_method173657,visitor2351603) {
var $z91349135 = D;
var $f91409141 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),anf_arg5279130):R.ffi.throwNonFunApp(L[1032],j_DASH_list9585,[(false),anf_arg5279130]);
};
try {
if(--R.GAS > 0) {
$z91349135 = $f91409141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91409141,
"from":L[1032]});
}
} catch($e91329133) {
if(R.isCont($e91329133)) {
var $ss91369137 = {"from":L[1032],
"go":function(names2509142) {
return $Hnames19249143(names2509142,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,rt_DASH_method173657,visitor2351603);
}};
$e91329133.stack[R.EXN_STACKHEIGHT++] = $ss91369137;
}
if(R.isPyretException($e91329133)) {
$e91329133.pyretStack.push(L[1032]);
}
throw $e91329133;
}
var $ret91389139 = $Hnames19249143($z91349135,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret91389139;
};
var $Hnames19249143 = function(names2509142,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,rt_DASH_method173657,visitor2351603) {
var anf_fun5289154 = G(fields2491724,"map",L[1035]);
var anf_arg5309155 = R.makeFunction(function(recv_DASH_429158) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1034],1,arguments);
}
var ann_DASH_check_DASH_temp5299159 = G(recv_DASH_429158,"l",L[1034]);
return ann_DASH_check_DASH_temp5299159;
});
var $z91469147 = D;
var $f91529153 = function(_) {
return R.isFunction(anf_fun5289154)?anf_fun5289154.app(anf_arg5309155):R.ffi.throwNonFunApp(L[1033],anf_fun5289154,[anf_arg5309155]);
};
try {
if(--R.GAS > 0) {
$z91469147 = $f91529153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91529153,
"from":L[1033]});
}
} catch($e91449145) {
if(R.isCont($e91449145)) {
var $ss91489149 = {"from":L[1033],
"go":function(anf_bracket5319156) {
return $Hanf_bracket19239157(anf_bracket5319156,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603);
}};
$e91449145.stack[R.EXN_STACKHEIGHT++] = $ss91489149;
}
if(R.isPyretException($e91449145)) {
$e91449145.pyretStack.push(L[1033]);
}
throw $e91449145;
}
var $ret91509151 = $Hanf_bracket19239157($z91469147,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret91509151;
};
var $Hanf_bracket19239157 = function(anf_bracket5319156,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603) {
var anf_fun5329170 = G(anf_bracket5319156,"map",L[1038]);
var anf_arg5339171 = G(visitor2351603,"get-loc",L[1037]);
var $z91629163 = D;
var $f91689169 = function(_) {
return R.isFunction(anf_fun5329170)?anf_fun5329170.app(anf_arg5339171):R.ffi.throwNonFunApp(L[1036],anf_fun5329170,[anf_arg5339171]);
};
try {
if(--R.GAS > 0) {
$z91629163 = $f91689169();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91689169,
"from":L[1036]});
}
} catch($e91609161) {
if(R.isCont($e91609161)) {
var $ss91649165 = {"from":L[1036],
"go":function(anf_arg5349172) {
return $Hanf_arg19229173(anf_arg5349172,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603);
}};
$e91609161.stack[R.EXN_STACKHEIGHT++] = $ss91649165;
}
if(R.isPyretException($e91609161)) {
$e91609161.pyretStack.push(L[1036]);
}
throw $e91609161;
}
var $ret91669167 = $Hanf_arg19229173($z91629163,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret91669167;
};
var $Hanf_arg19229173 = function(anf_arg5349172,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_list9585,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603) {
var $z91769177 = D;
var $f91829183 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),anf_arg5349172):R.ffi.throwNonFunApp(L[1039],j_DASH_list9585,[(false),anf_arg5349172]);
};
try {
if(--R.GAS > 0) {
$z91769177 = $f91829183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91829183,
"from":L[1039]});
}
} catch($e91749175) {
if(R.isCont($e91749175)) {
var $ss91789179 = {"from":L[1039],
"go":function(locs2519184) {
return $Hlocs19219185(locs2519184,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603);
}};
$e91749175.stack[R.EXN_STACKHEIGHT++] = $ss91789179;
}
if(R.isPyretException($e91749175)) {
$e91749175.pyretStack.push(L[1039]);
}
throw $e91749175;
}
var $ret91809181 = $Hlocs19219185($z91769177,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603);
++R.GAS;
return $ret91809181;
};
var $Hlocs19219185 = function(locs2519184,compile_DASH_ann181673,fields2491724,j_DASH_field9979,j_DASH_obj9690,list35101,map47104,names2509142,rt_DASH_method173657,visitor2351603) {
var anf_arg5399196 = R.makeFunction(function(f2539199) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1041],1,arguments);
}
var anf_arg5369212 = G(f2539199,"name",L[1044]);
var anf_arg5379210 = G(f2539199,"ann",L[1043]);
var $z92029203 = D;
var $f92089209 = function(_) {
return R.isFunction(compile_DASH_ann181673.$var)?compile_DASH_ann181673.$var.app(anf_arg5379210,visitor2351603):R.ffi.throwNonFunApp(L[1042],compile_DASH_ann181673.$var,[anf_arg5379210,visitor2351603]);
};
try {
if(--R.GAS > 0) {
$z92029203 = $f92089209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92089209,
"from":L[1042]});
}
} catch($e92009201) {
if(R.isCont($e92009201)) {
var $ss92049205 = {"from":L[1042],
"go":function(anf_arg5389211) {
return $Hanf_arg19169213(anf_arg5389211,anf_arg5369212,j_DASH_field9979);
}};
$e92009201.stack[R.EXN_STACKHEIGHT++] = $ss92049205;
}
if(R.isPyretException($e92009201)) {
$e92009201.pyretStack.push(L[1042]);
}
throw $e92009201;
}
var $ret92069207 = $Hanf_arg19169213($z92029203,anf_arg5369212,j_DASH_field9979);
++R.GAS;
return $ret92069207;
});
var $z91889189 = D;
var $f91949195 = function(_) {
return R.isFunction(map47104)?map47104.app(anf_arg5399196,fields2491724):R.ffi.throwNonFunApp(L[1040],map47104,[anf_arg5399196,fields2491724]);
};
try {
if(--R.GAS > 0) {
$z91889189 = $f91949195();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91949195,
"from":L[1040]});
}
} catch($e91869187) {
if(R.isCont($e91869187)) {
var $ss91909191 = {"from":L[1040],
"go":function(anns2529197) {
return $Hanns19209198(anns2529197,j_DASH_obj9690,list35101,locs2519184,names2509142,rt_DASH_method173657);
}};
$e91869187.stack[R.EXN_STACKHEIGHT++] = $ss91909191;
}
if(R.isPyretException($e91869187)) {
$e91869187.pyretStack.push(L[1040]);
}
throw $e91869187;
}
var $ret91929193 = $Hanns19209198($z91889189,j_DASH_obj9690,list35101,locs2519184,names2509142,rt_DASH_method173657);
++R.GAS;
return $ret91929193;
};
var $Hanns19209198 = function(anns2529197,j_DASH_obj9690,list35101,locs2519184,names2509142,rt_DASH_method173657) {
var anf_fun5409225 = G(list35101,"make",L[1046]);
var $z92169217 = D;
var $f92229223 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anns2529197):R.ffi.throwNonFunApp(L[1045],j_DASH_obj9690,[anns2529197]);
};
try {
if(--R.GAS > 0) {
$z92169217 = $f92229223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92229223,
"from":L[1045]});
}
} catch($e92149215) {
if(R.isCont($e92149215)) {
var $ss92189219 = {"from":L[1045],
"go":function(anf_array_val5419224) {
return $Hanf_array_val19199226(anf_array_val5419224,anf_fun5409225,locs2519184,names2509142,rt_DASH_method173657);
}};
$e92149215.stack[R.EXN_STACKHEIGHT++] = $ss92189219;
}
if(R.isPyretException($e92149215)) {
$e92149215.pyretStack.push(L[1045]);
}
throw $e92149215;
}
var $ret92209221 = $Hanf_array_val19199226($z92169217,anf_fun5409225,locs2519184,names2509142,rt_DASH_method173657);
++R.GAS;
return $ret92209221;
};
var $Hanf_array_val19199226 = function(anf_array_val5419224,anf_fun5409225,locs2519184,names2509142,rt_DASH_method173657) {
var $z92299230 = D;
var $f92359236 = function(_) {
return R.isFunction(anf_fun5409225)?anf_fun5409225.app([names2509142,locs2519184,anf_array_val5419224]):R.ffi.throwNonFunApp(L[1046],anf_fun5409225,[[names2509142,locs2519184,anf_array_val5419224]]);
};
try {
if(--R.GAS > 0) {
$z92299230 = $f92359236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92359236,
"from":L[1046]});
}
} catch($e92279228) {
if(R.isCont($e92279228)) {
var $ss92319232 = {"from":L[1046],
"go":function(anf_arg5429237) {
return $Hanf_arg19189238(anf_arg5429237,rt_DASH_method173657);
}};
$e92279228.stack[R.EXN_STACKHEIGHT++] = $ss92319232;
}
if(R.isPyretException($e92279228)) {
$e92279228.pyretStack.push(L[1046]);
}
throw $e92279228;
}
var $ret92339234 = $Hanf_arg19189238($z92299230,rt_DASH_method173657);
++R.GAS;
return $ret92339234;
};
var $Hanf_arg19189238 = function(anf_arg5429237,rt_DASH_method173657) {
var $z92419242 = D;
var $f92479248 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeRecordAnn"),anf_arg5429237):R.ffi.throwNonFunApp(L[290],rt_DASH_method173657.$var,[("makeRecordAnn"),anf_arg5429237]);
};
try {
if(--R.GAS > 0) {
$z92419242 = $f92479248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92479248,
"from":L[290]});
}
} catch($e92399240) {
if(R.isCont($e92399240)) {
var $ss92439244 = {"from":L[290],
"go":function(ann_DASH_check_DASH_temp5219249) {
return $Hann_DASH_check_DASH_temp19179250(ann_DASH_check_DASH_temp5219249);
}};
$e92399240.stack[R.EXN_STACKHEIGHT++] = $ss92439244;
}
if(R.isPyretException($e92399240)) {
$e92399240.pyretStack.push(L[290]);
}
throw $e92399240;
}
var $ret92459246 = $Hann_DASH_check_DASH_temp19179250($z92419242);
++R.GAS;
return $ret92459246;
};
var $Hann_DASH_check_DASH_temp19179250 = function(ann_DASH_check_DASH_temp5219249) {
return ann_DASH_check_DASH_temp5219249;
};
var $Hanf_arg19169213 = function(anf_arg5389211,anf_arg5369212,j_DASH_field9979) {
var $z92539254 = D;
var $f92599260 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(anf_arg5369212,anf_arg5389211):R.ffi.throwNonFunApp(L[1041],j_DASH_field9979,[anf_arg5369212,anf_arg5389211]);
};
try {
if(--R.GAS > 0) {
$z92539254 = $f92599260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92599260,
"from":L[1041]});
}
} catch($e92519252) {
if(R.isCont($e92519252)) {
var $ss92559256 = {"from":L[1041],
"go":function(ann_DASH_check_DASH_temp5359261) {
return $Hann_DASH_check_DASH_temp19159262(ann_DASH_check_DASH_temp5359261);
}};
$e92519252.stack[R.EXN_STACKHEIGHT++] = $ss92559256;
}
if(R.isPyretException($e92519252)) {
$e92519252.pyretStack.push(L[1041]);
}
throw $e92519252;
}
var $ret92579258 = $Hann_DASH_check_DASH_temp19159262($z92539254);
++R.GAS;
return $ret92579258;
};
var $Hann_DASH_check_DASH_temp19159262 = function(ann_DASH_check_DASH_temp5359261) {
return ann_DASH_check_DASH_temp5359261;
};
var $Hann_DASH_check_DASH_temp19141755 = function(ann_DASH_check_DASH_temp5191754) {
return ann_DASH_check_DASH_temp5191754;
};
var $Hann_DASH_check_DASH_temp19131770 = function(ann_DASH_check_DASH_temp5171769) {
return ann_DASH_check_DASH_temp5171769;
};
var $Hann_DASH_check_DASH_temp19121786 = function(ann_DASH_check_DASH_temp5151785) {
return ann_DASH_check_DASH_temp5151785;
};
var $Hanf_arg19111801 = function(anf_arg5121800,j_DASH_id8381,js_DASH_id_DASH_of162700) {
var $z92659266 = D;
var $f92719272 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg5121800):R.ffi.throwNonFunApp(L[1047],js_DASH_id_DASH_of162700,[anf_arg5121800]);
};
try {
if(--R.GAS > 0) {
$z92659266 = $f92719272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92719272,
"from":L[1047]});
}
} catch($e92639264) {
if(R.isCont($e92639264)) {
var $ss92679268 = {"from":L[1047],
"go":function(anf_arg5139273) {
return $Hanf_arg19109274(anf_arg5139273,j_DASH_id8381);
}};
$e92639264.stack[R.EXN_STACKHEIGHT++] = $ss92679268;
}
if(R.isPyretException($e92639264)) {
$e92639264.pyretStack.push(L[1047]);
}
throw $e92639264;
}
var $ret92699270 = $Hanf_arg19109274($z92659266,j_DASH_id8381);
++R.GAS;
return $ret92699270;
};
var $Hanf_arg19109274 = function(anf_arg5139273,j_DASH_id8381) {
var $z92779278 = D;
var $f92839284 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg5139273):R.ffi.throwNonFunApp(L[297],j_DASH_id8381,[anf_arg5139273]);
};
try {
if(--R.GAS > 0) {
$z92779278 = $f92839284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92839284,
"from":L[297]});
}
} catch($e92759276) {
if(R.isCont($e92759276)) {
var $ss92799280 = {"from":L[297],
"go":function(ann_DASH_check_DASH_temp5109285) {
return $Hann_DASH_check_DASH_temp19099286(ann_DASH_check_DASH_temp5109285);
}};
$e92759276.stack[R.EXN_STACKHEIGHT++] = $ss92799280;
}
if(R.isPyretException($e92759276)) {
$e92759276.pyretStack.push(L[297]);
}
throw $e92759276;
}
var $ret92819282 = $Hann_DASH_check_DASH_temp19099286($z92779278);
++R.GAS;
return $ret92819282;
};
var $Hann_DASH_check_DASH_temp19099286 = function(ann_DASH_check_DASH_temp5109285) {
return ann_DASH_check_DASH_temp5109285;
};
var $Hanf_begin_app_dropped19071822 = function(anf_begin_app_dropped19051820,if_helper3471821,nothing9) {
var $z92899290 = D;
var $f92959296 = function(_) {
return R.isFunction(if_helper3471821)?if_helper3471821.app(nothing9):R.ffi.throwNonFunApp(L[302],if_helper3471821,[nothing9]);
};
try {
if(--R.GAS > 0) {
$z92899290 = $f92959296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92959296,
"from":L[302]});
}
} catch($e92879288) {
if(R.isCont($e92879288)) {
var $ss92919292 = {"from":L[302],
"go":function(cont_tail_app5069297) {
return $Hcont_tail_app19069298(cont_tail_app5069297);
}};
$e92879288.stack[R.EXN_STACKHEIGHT++] = $ss92919292;
}
if(R.isPyretException($e92879288)) {
$e92879288.pyretStack.push(L[302]);
}
throw $e92879288;
}
var $ret92939294 = $Hcont_tail_app19069298($z92899290);
++R.GAS;
return $ret92939294;
};
var $Hcont_tail_app19069298 = function(cont_tail_app5069297) {
return cont_tail_app5069297;
};
var $Hcont_tail_app19081834 = function(cont_tail_app5051833) {
return cont_tail_app5051833;
};
var $Hanf_arg19041852 = function(anf_arg3491851,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5) {
var $z93019302 = D;
var $f93079308 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg3491851):R.ffi.throwNonFunApp(L[1048],js_DASH_id_DASH_of162700,[anf_arg3491851]);
};
try {
if(--R.GAS > 0) {
$z93019302 = $f93079308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93079308,
"from":L[1048]});
}
} catch($e92999300) {
if(R.isCont($e92999300)) {
var $ss93039304 = {"from":L[1048],
"go":function(e2229309) {
return $He19039310(e2229309,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5);
}};
$e92999300.stack[R.EXN_STACKHEIGHT++] = $ss93039304;
}
if(R.isPyretException($e92999300)) {
$e92999300.pyretStack.push(L[1048]);
}
throw $e92999300;
}
var $ret93059306 = $He19039310($z93019302,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5);
++R.GAS;
return $ret93059306;
};
var $He19039310 = function(e2229309,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5) {
var $z93139314 = D;
var $f93199320 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(("z")):R.ffi.throwNonFunApp(L[1049],compiler_DASH_name167645.$var,[("z")]);
};
try {
if(--R.GAS > 0) {
$z93139314 = $f93199320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93199320,
"from":L[1049]});
}
} catch($e93119312) {
if(R.isCont($e93119312)) {
var $ss93159316 = {"from":L[1049],
"go":function(anf_arg3509321) {
return $Hanf_arg19029322(anf_arg3509321,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5);
}};
$e93119312.stack[R.EXN_STACKHEIGHT++] = $ss93159316;
}
if(R.isPyretException($e93119312)) {
$e93119312.pyretStack.push(L[1049]);
}
throw $e93119312;
}
var $ret93179318 = $Hanf_arg19029322($z93139314,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5);
++R.GAS;
return $ret93179318;
};
var $Hanf_arg19029322 = function(anf_arg3509321,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5) {
var $z93259326 = D;
var $f93319332 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg3509321):R.ffi.throwNonFunApp(L[1050],js_DASH_id_DASH_of162700,[anf_arg3509321]);
};
try {
if(--R.GAS > 0) {
$z93259326 = $f93319332();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93319332,
"from":L[1050]});
}
} catch($e93239324) {
if(R.isCont($e93239324)) {
var $ss93279328 = {"from":L[1050],
"go":function(z2239333) {
return $Hz19019334(z2239333,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5);
}};
$e93239324.stack[R.EXN_STACKHEIGHT++] = $ss93279328;
}
if(R.isPyretException($e93239324)) {
$e93239324.pyretStack.push(L[1050]);
}
throw $e93239324;
}
var $ret93299330 = $Hz19019334($z93259326,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5);
++R.GAS;
return $ret93299330;
};
var $Hz19019334 = function(z2239333,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,_plus5) {
var $z93379338 = D;
var $f93439344 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(("ss")):R.ffi.throwNonFunApp(L[1051],compiler_DASH_name167645.$var,[("ss")]);
};
try {
if(--R.GAS > 0) {
$z93379338 = $f93439344();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93439344,
"from":L[1051]});
}
} catch($e93359336) {
if(R.isCont($e93359336)) {
var $ss93399340 = {"from":L[1051],
"go":function(anf_arg3519345) {
return $Hanf_arg19009346(anf_arg3519345,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e93359336.stack[R.EXN_STACKHEIGHT++] = $ss93399340;
}
if(R.isPyretException($e93359336)) {
$e93359336.pyretStack.push(L[1051]);
}
throw $e93359336;
}
var $ret93419342 = $Hanf_arg19009346($z93379338,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret93419342;
};
var $Hanf_arg19009346 = function(anf_arg3519345,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z93499350 = D;
var $f93559356 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg3519345):R.ffi.throwNonFunApp(L[1052],js_DASH_id_DASH_of162700,[anf_arg3519345]);
};
try {
if(--R.GAS > 0) {
$z93499350 = $f93559356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93559356,
"from":L[1052]});
}
} catch($e93479348) {
if(R.isCont($e93479348)) {
var $ss93519352 = {"from":L[1052],
"go":function(ss2249357) {
return $Hss18999358(ss2249357,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e93479348.stack[R.EXN_STACKHEIGHT++] = $ss93519352;
}
if(R.isPyretException($e93479348)) {
$e93479348.pyretStack.push(L[1052]);
}
throw $e93479348;
}
var $ret93539354 = $Hss18999358($z93499350,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret93539354;
};
var $Hss18999358 = function(ss2249357,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z93619362 = D;
var $f93679368 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(("ret")):R.ffi.throwNonFunApp(L[1053],compiler_DASH_name167645.$var,[("ret")]);
};
try {
if(--R.GAS > 0) {
$z93619362 = $f93679368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93679368,
"from":L[1053]});
}
} catch($e93599360) {
if(R.isCont($e93599360)) {
var $ss93639364 = {"from":L[1053],
"go":function(anf_arg3529369) {
return $Hanf_arg18989370(anf_arg3529369,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e93599360.stack[R.EXN_STACKHEIGHT++] = $ss93639364;
}
if(R.isPyretException($e93599360)) {
$e93599360.pyretStack.push(L[1053]);
}
throw $e93599360;
}
var $ret93659366 = $Hanf_arg18989370($z93619362,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret93659366;
};
var $Hanf_arg18989370 = function(anf_arg3529369,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z93739374 = D;
var $f93799380 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg3529369):R.ffi.throwNonFunApp(L[1054],js_DASH_id_DASH_of162700,[anf_arg3529369]);
};
try {
if(--R.GAS > 0) {
$z93739374 = $f93799380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93799380,
"from":L[1054]});
}
} catch($e93719372) {
if(R.isCont($e93719372)) {
var $ss93759376 = {"from":L[1054],
"go":function(ret2259381) {
return $Hret18979382(ret2259381,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e93719372.stack[R.EXN_STACKHEIGHT++] = $ss93759376;
}
if(R.isPyretException($e93719372)) {
$e93719372.pyretStack.push(L[1054]);
}
throw $e93719372;
}
var $ret93779378 = $Hret18979382($z93739374,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret93779378;
};
var $Hret18979382 = function(ret2259381,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler_DASH_name167645,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z93859386 = D;
var $f93919392 = function(_) {
return R.isFunction(compiler_DASH_name167645.$var)?compiler_DASH_name167645.$var.app(("f")):R.ffi.throwNonFunApp(L[1055],compiler_DASH_name167645.$var,[("f")]);
};
try {
if(--R.GAS > 0) {
$z93859386 = $f93919392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93919392,
"from":L[1055]});
}
} catch($e93839384) {
if(R.isCont($e93839384)) {
var $ss93879388 = {"from":L[1055],
"go":function(anf_arg3539393) {
return $Hanf_arg18969394(anf_arg3539393,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e93839384.stack[R.EXN_STACKHEIGHT++] = $ss93879388;
}
if(R.isPyretException($e93839384)) {
$e93839384.pyretStack.push(L[1055]);
}
throw $e93839384;
}
var $ret93899390 = $Hanf_arg18969394($z93859386,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret93899390;
};
var $Hanf_arg18969394 = function(anf_arg3539393,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z93979398 = D;
var $f94039404 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg3539393):R.ffi.throwNonFunApp(L[1056],js_DASH_id_DASH_of162700,[anf_arg3539393]);
};
try {
if(--R.GAS > 0) {
$z93979398 = $f94039404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94039404,
"from":L[1056]});
}
} catch($e93959396) {
if(R.isCont($e93959396)) {
var $ss93999400 = {"from":L[1056],
"go":function(f_DASH_app2269405) {
return $Hf_DASH_app18959406(f_DASH_app2269405,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e93959396.stack[R.EXN_STACKHEIGHT++] = $ss93999400;
}
if(R.isPyretException($e93959396)) {
$e93959396.pyretStack.push(L[1056]);
}
throw $e93959396;
}
var $ret94019402 = $Hf_DASH_app18959406($z93979398,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret94019402;
};
var $Hf_DASH_app18959406 = function(f_DASH_app2269405,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f2181806,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun3549417 = G(f2181806,"visit",L[1058]);
var $z94099410 = D;
var $f94159416 = function(_) {
return R.isFunction(anf_fun3549417)?anf_fun3549417.app(compiler2151803):R.ffi.throwNonFunApp(L[1057],anf_fun3549417,[compiler2151803]);
};
try {
if(--R.GAS > 0) {
$z94099410 = $f94159416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94159416,
"from":L[1057]});
}
} catch($e94079408) {
if(R.isCont($e94079408)) {
var $ss94119412 = {"from":L[1057],
"go":function(compiled_DASH_f2279418) {
return $Hcompiled_DASH_f18949419(compiled_DASH_f2279418,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e94079408.stack[R.EXN_STACKHEIGHT++] = $ss94119412;
}
if(R.isPyretException($e94079408)) {
$e94079408.pyretStack.push(L[1057]);
}
throw $e94079408;
}
var $ret94139414 = $Hcompiled_DASH_f18949419($z94099410,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret94139414;
};
var $Hcompiled_DASH_f18949419 = function(compiled_DASH_f2279418,J721,add_DASH_stack_DASH_frame171653,app174659,args2191807,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun3559430 = G(args2191807,"map",L[1061]);
var anf_arg3589431 = R.makeFunction(function(recv_DASH_379434) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1060],1,arguments);
}
var anf_fun3579445 = G(recv_DASH_379434,"visit",L[1060]);
var $z94379438 = D;
var $f94439444 = function(_) {
return R.isFunction(anf_fun3579445)?anf_fun3579445.app(compiler2151803):R.ffi.throwNonFunApp(L[1060],anf_fun3579445,[compiler2151803]);
};
try {
if(--R.GAS > 0) {
$z94379438 = $f94439444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94439444,
"from":L[1060]});
}
} catch($e94359436) {
if(R.isCont($e94359436)) {
var $ss94399440 = {"from":L[1060],
"go":function(ann_DASH_check_DASH_temp3569446) {
return $Hann_DASH_check_DASH_temp17879447(ann_DASH_check_DASH_temp3569446);
}};
$e94359436.stack[R.EXN_STACKHEIGHT++] = $ss94399440;
}
if(R.isPyretException($e94359436)) {
$e94359436.pyretStack.push(L[1060]);
}
throw $e94359436;
}
var $ret94419442 = $Hann_DASH_check_DASH_temp17879447($z94379438);
++R.GAS;
return $ret94419442;
});
var $z94229423 = D;
var $f94289429 = function(_) {
return R.isFunction(anf_fun3559430)?anf_fun3559430.app(anf_arg3589431):R.ffi.throwNonFunApp(L[1059],anf_fun3559430,[anf_arg3589431]);
};
try {
if(--R.GAS > 0) {
$z94229423 = $f94289429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94289429,
"from":L[1059]});
}
} catch($e94209421) {
if(R.isCont($e94209421)) {
var $ss94249425 = {"from":L[1059],
"go":function(compiled_DASH_args2289432) {
return $Hcompiled_DASH_args18939433(compiled_DASH_args2289432,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_f2279418,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e94209421.stack[R.EXN_STACKHEIGHT++] = $ss94249425;
}
if(R.isPyretException($e94209421)) {
$e94209421.pyretStack.push(L[1059]);
}
throw $e94209421;
}
var $ret94269427 = $Hcompiled_DASH_args18939433($z94229423,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_f2279418,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret94269427;
};
var $Hcompiled_DASH_args18939433 = function(compiled_DASH_args2289432,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_f2279418,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun3599458 = G(helper_DASH_args2211809,"map",L[1064]);
var anf_arg3629459 = R.makeFunction(function(recv_DASH_389462) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1063],1,arguments);
}
var anf_fun3619473 = G(recv_DASH_389462,"visit",L[1063]);
var $z94659466 = D;
var $f94719472 = function(_) {
return R.isFunction(anf_fun3619473)?anf_fun3619473.app(compiler2151803):R.ffi.throwNonFunApp(L[1063],anf_fun3619473,[compiler2151803]);
};
try {
if(--R.GAS > 0) {
$z94659466 = $f94719472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94719472,
"from":L[1063]});
}
} catch($e94639464) {
if(R.isCont($e94639464)) {
var $ss94679468 = {"from":L[1063],
"go":function(ann_DASH_check_DASH_temp3609474) {
return $Hann_DASH_check_DASH_temp17889475(ann_DASH_check_DASH_temp3609474);
}};
$e94639464.stack[R.EXN_STACKHEIGHT++] = $ss94679468;
}
if(R.isPyretException($e94639464)) {
$e94639464.pyretStack.push(L[1063]);
}
throw $e94639464;
}
var $ret94699470 = $Hann_DASH_check_DASH_temp17889475($z94659466);
++R.GAS;
return $ret94699470;
});
var $z94509451 = D;
var $f94569457 = function(_) {
return R.isFunction(anf_fun3599458)?anf_fun3599458.app(anf_arg3629459):R.ffi.throwNonFunApp(L[1062],anf_fun3599458,[anf_arg3629459]);
};
try {
if(--R.GAS > 0) {
$z94509451 = $f94569457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94569457,
"from":L[1062]});
}
} catch($e94489449) {
if(R.isCont($e94489449)) {
var $ss94529453 = {"from":L[1062],
"go":function(compiled_DASH_helper_DASH_args2299460) {
return $Hcompiled_DASH_helper_DASH_args18929461(compiled_DASH_helper_DASH_args2299460,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e94489449.stack[R.EXN_STACKHEIGHT++] = $ss94529453;
}
if(R.isPyretException($e94489449)) {
$e94489449.pyretStack.push(L[1062]);
}
throw $e94489449;
}
var $ret94549455 = $Hcompiled_DASH_helper_DASH_args18929461($z94509451,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret94549455;
};
var $Hcompiled_DASH_helper_DASH_args18929461 = function(compiled_DASH_helper_DASH_args2299460,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z94789479 = D;
var $f94849485 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("GAS")):R.ffi.throwNonFunApp(L[1065],rt_DASH_field172655.$var,[("GAS")]);
};
try {
if(--R.GAS > 0) {
$z94789479 = $f94849485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94849485,
"from":L[1065]});
}
} catch($e94769477) {
if(R.isCont($e94769477)) {
var $ss94809481 = {"from":L[1065],
"go":function(anf_arg3639486) {
return $Hanf_arg18919487(anf_arg3639486,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e94769477.stack[R.EXN_STACKHEIGHT++] = $ss94809481;
}
if(R.isPyretException($e94769477)) {
$e94769477.pyretStack.push(L[1065]);
}
throw $e94769477;
}
var $ret94829483 = $Hanf_arg18919487($z94789479,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret94829483;
};
var $Hanf_arg18919487 = function(anf_arg3639486,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z94909491 = D;
var $f94969497 = function(_) {
return R.isFunction(j_DASH_unop10898)?j_DASH_unop10898.app(anf_arg3639486,j_DASH_decr10973):R.ffi.throwNonFunApp(L[1066],j_DASH_unop10898,[anf_arg3639486,j_DASH_decr10973]);
};
try {
if(--R.GAS > 0) {
$z94909491 = $f94969497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94969497,
"from":L[1066]});
}
} catch($e94889489) {
if(R.isCont($e94889489)) {
var $ss94929493 = {"from":L[1066],
"go":function(anf_arg3649498) {
return $Hanf_arg18909499(anf_arg3649498,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e94889489.stack[R.EXN_STACKHEIGHT++] = $ss94929493;
}
if(R.isPyretException($e94889489)) {
$e94889489.pyretStack.push(L[1066]);
}
throw $e94889489;
}
var $ret94949495 = $Hanf_arg18909499($z94909491,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret94949495;
};
var $Hanf_arg18909499 = function(anf_arg3649498,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_arg3659511 = G(J721,"j-gt",L[1068]);
var $z95029503 = D;
var $f95089509 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app((0)):R.ffi.throwNonFunApp(L[1067],j_DASH_num8889,[(0)]);
};
try {
if(--R.GAS > 0) {
$z95029503 = $f95089509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95089509,
"from":L[1067]});
}
} catch($e95009501) {
if(R.isCont($e95009501)) {
var $ss95049505 = {"from":L[1067],
"go":function(anf_arg3669510) {
return $Hanf_arg18899512(anf_arg3669510,J721,add_DASH_stack_DASH_frame171653,anf_arg3649498,anf_arg3659511,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95009501.stack[R.EXN_STACKHEIGHT++] = $ss95049505;
}
if(R.isPyretException($e95009501)) {
$e95009501.pyretStack.push(L[1067]);
}
throw $e95009501;
}
var $ret95069507 = $Hanf_arg18899512($z95029503,J721,add_DASH_stack_DASH_frame171653,anf_arg3649498,anf_arg3659511,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret95069507;
};
var $Hanf_arg18899512 = function(anf_arg3669510,J721,add_DASH_stack_DASH_frame171653,anf_arg3649498,anf_arg3659511,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z95159516 = D;
var $f95219522 = function(_) {
return R.isFunction(j_DASH_binop10569)?j_DASH_binop10569.app(anf_arg3649498,anf_arg3659511,anf_arg3669510):R.ffi.throwNonFunApp(L[1069],j_DASH_binop10569,[anf_arg3649498,anf_arg3659511,anf_arg3669510]);
};
try {
if(--R.GAS > 0) {
$z95159516 = $f95219522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95219522,
"from":L[1069]});
}
} catch($e95139514) {
if(R.isCont($e95139514)) {
var $ss95179518 = {"from":L[1069],
"go":function(anf_arg3679523) {
return $Hanf_arg18889524(anf_arg3679523,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95139514.stack[R.EXN_STACKHEIGHT++] = $ss95179518;
}
if(R.isPyretException($e95139514)) {
$e95139514.pyretStack.push(L[1069]);
}
throw $e95139514;
}
var $ret95199520 = $Hanf_arg18889524($z95159516,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret95199520;
};
var $Hanf_arg18889524 = function(anf_arg3679523,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun3689536 = G(list35101,"make",L[1071]);
var $z95279528 = D;
var $f95339534 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(f_DASH_app2269405):R.ffi.throwNonFunApp(L[1070],j_DASH_id8381,[f_DASH_app2269405]);
};
try {
if(--R.GAS > 0) {
$z95279528 = $f95339534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95339534,
"from":L[1070]});
}
} catch($e95259526) {
if(R.isCont($e95259526)) {
var $ss95299530 = {"from":L[1070],
"go":function(anf_arg3699535) {
return $Hanf_arg18879537(anf_arg3699535,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95259526.stack[R.EXN_STACKHEIGHT++] = $ss95299530;
}
if(R.isPyretException($e95259526)) {
$e95259526.pyretStack.push(L[1070]);
}
throw $e95259526;
}
var $ret95319532 = $Hanf_arg18879537($z95279528,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret95319532;
};
var $Hanf_arg18879537 = function(anf_arg3699535,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun3709548 = G(list35101,"make",L[1072]);
var $z95409541 = D;
var $f95469547 = function(_) {
return R.isFunction(anf_fun3709548)?anf_fun3709548.app([]):R.ffi.throwNonFunApp(L[1072],anf_fun3709548,[[]]);
};
try {
if(--R.GAS > 0) {
$z95409541 = $f95469547();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95469547,
"from":L[1072]});
}
} catch($e95389539) {
if(R.isCont($e95389539)) {
var $ss95429543 = {"from":L[1072],
"go":function(anf_arg3719549) {
return $Hanf_arg18869550(anf_arg3719549,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3699535,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95389539.stack[R.EXN_STACKHEIGHT++] = $ss95429543;
}
if(R.isPyretException($e95389539)) {
$e95389539.pyretStack.push(L[1072]);
}
throw $e95389539;
}
var $ret95449545 = $Hanf_arg18869550($z95409541,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3699535,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret95449545;
};
var $Hanf_arg18869550 = function(anf_arg3719549,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3699535,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z95539554 = D;
var $f95599560 = function(_) {
return R.isFunction(j_DASH_app9467)?j_DASH_app9467.app(anf_arg3699535,anf_arg3719549):R.ffi.throwNonFunApp(L[1073],j_DASH_app9467,[anf_arg3699535,anf_arg3719549]);
};
try {
if(--R.GAS > 0) {
$z95539554 = $f95599560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95599560,
"from":L[1073]});
}
} catch($e95519552) {
if(R.isCont($e95519552)) {
var $ss95559556 = {"from":L[1073],
"go":function(anf_arg3729561) {
return $Hanf_arg18859562(anf_arg3729561,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95519552.stack[R.EXN_STACKHEIGHT++] = $ss95559556;
}
if(R.isPyretException($e95519552)) {
$e95519552.pyretStack.push(L[1073]);
}
throw $e95519552;
}
var $ret95579558 = $Hanf_arg18859562($z95539554,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret95579558;
};
var $Hanf_arg18859562 = function(anf_arg3729561,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_assign9168,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z95659566 = D;
var $f95719572 = function(_) {
return R.isFunction(j_DASH_assign9168)?j_DASH_assign9168.app(z2239333,anf_arg3729561):R.ffi.throwNonFunApp(L[1074],j_DASH_assign9168,[z2239333,anf_arg3729561]);
};
try {
if(--R.GAS > 0) {
$z95659566 = $f95719572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95719572,
"from":L[1074]});
}
} catch($e95639564) {
if(R.isCont($e95639564)) {
var $ss95679568 = {"from":L[1074],
"go":function(anf_arg3739573) {
return $Hanf_arg18849574(anf_arg3739573,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95639564.stack[R.EXN_STACKHEIGHT++] = $ss95679568;
}
if(R.isPyretException($e95639564)) {
$e95639564.pyretStack.push(L[1074]);
}
throw $e95639564;
}
var $ret95699570 = $Hanf_arg18849574($z95659566,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret95699570;
};
var $Hanf_arg18849574 = function(anf_arg3739573,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z95779578 = D;
var $f95839584 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(anf_arg3739573):R.ffi.throwNonFunApp(L[1075],j_DASH_expr10477,[anf_arg3739573]);
};
try {
if(--R.GAS > 0) {
$z95779578 = $f95839584();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95839584,
"from":L[1075]});
}
} catch($e95759576) {
if(R.isCont($e95759576)) {
var $ss95799580 = {"from":L[1075],
"go":function(anf_array_val3749585) {
return $Hanf_array_val18839586(anf_array_val3749585,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95759576.stack[R.EXN_STACKHEIGHT++] = $ss95799580;
}
if(R.isPyretException($e95759576)) {
$e95759576.pyretStack.push(L[1075]);
}
throw $e95759576;
}
var $ret95819582 = $Hanf_array_val18839586($z95779578,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret95819582;
};
var $Hanf_array_val18839586 = function(anf_array_val3749585,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_fun3689536,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z95899590 = D;
var $f95959596 = function(_) {
return R.isFunction(anf_fun3689536)?anf_fun3689536.app([anf_array_val3749585]):R.ffi.throwNonFunApp(L[1071],anf_fun3689536,[[anf_array_val3749585]]);
};
try {
if(--R.GAS > 0) {
$z95899590 = $f95959596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95959596,
"from":L[1071]});
}
} catch($e95879588) {
if(R.isCont($e95879588)) {
var $ss95919592 = {"from":L[1071],
"go":function(anf_arg3759597) {
return $Hanf_arg18829598(anf_arg3759597,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95879588.stack[R.EXN_STACKHEIGHT++] = $ss95919592;
}
if(R.isPyretException($e95879588)) {
$e95879588.pyretStack.push(L[1071]);
}
throw $e95879588;
}
var $ret95939594 = $Hanf_arg18829598($z95899590,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret95939594;
};
var $Hanf_arg18829598 = function(anf_arg3759597,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z96019602 = D;
var $f96079608 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg3759597):R.ffi.throwNonFunApp(L[1076],j_DASH_block8570,[anf_arg3759597]);
};
try {
if(--R.GAS > 0) {
$z96019602 = $f96079608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96079608,
"from":L[1076]});
}
} catch($e95999600) {
if(R.isCont($e95999600)) {
var $ss96039604 = {"from":L[1076],
"go":function(anf_arg3769609) {
return $Hanf_arg18819610(anf_arg3769609,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e95999600.stack[R.EXN_STACKHEIGHT++] = $ss96039604;
}
if(R.isPyretException($e95999600)) {
$e95999600.pyretStack.push(L[1076]);
}
throw $e95999600;
}
var $ret96059606 = $Hanf_arg18819610($z96019602,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret96059606;
};
var $Hanf_arg18819610 = function(anf_arg3769609,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun3779622 = G(list35101,"make",L[1078]);
var $z96139614 = D;
var $f96199620 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("R")):R.ffi.throwNonFunApp(L[1077],j_DASH_id8381,[("R")]);
};
try {
if(--R.GAS > 0) {
$z96139614 = $f96199620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96199620,
"from":L[1077]});
}
} catch($e96119612) {
if(R.isCont($e96119612)) {
var $ss96159616 = {"from":L[1077],
"go":function(anf_arg3789621) {
return $Hanf_arg18809623(anf_arg3789621,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e96119612.stack[R.EXN_STACKHEIGHT++] = $ss96159616;
}
if(R.isPyretException($e96119612)) {
$e96119612.pyretStack.push(L[1077]);
}
throw $e96119612;
}
var $ret96179618 = $Hanf_arg18809623($z96139614,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret96179618;
};
var $Hanf_arg18809623 = function(anf_arg3789621,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z96269627 = D;
var $f96329633 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app((0)):R.ffi.throwNonFunApp(L[1079],j_DASH_num8889,[(0)]);
};
try {
if(--R.GAS > 0) {
$z96269627 = $f96329633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96329633,
"from":L[1079]});
}
} catch($e96249625) {
if(R.isCont($e96249625)) {
var $ss96289629 = {"from":L[1079],
"go":function(anf_arg3799634) {
return $Hanf_arg18799635(anf_arg3799634,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_arg3789621,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e96249625.stack[R.EXN_STACKHEIGHT++] = $ss96289629;
}
if(R.isPyretException($e96249625)) {
$e96249625.pyretStack.push(L[1079]);
}
throw $e96249625;
}
var $ret96309631 = $Hanf_arg18799635($z96269627,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_arg3789621,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret96309631;
};
var $Hanf_arg18799635 = function(anf_arg3799634,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_arg3789621,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z96389639 = D;
var $f96449645 = function(_) {
return R.isFunction(j_DASH_dot_DASH_assign10074)?j_DASH_dot_DASH_assign10074.app(anf_arg3789621,("EXN_STACKHEIGHT"),anf_arg3799634):R.ffi.throwNonFunApp(L[1080],j_DASH_dot_DASH_assign10074,[anf_arg3789621,("EXN_STACKHEIGHT"),anf_arg3799634]);
};
try {
if(--R.GAS > 0) {
$z96389639 = $f96449645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96449645,
"from":L[1080]});
}
} catch($e96369637) {
if(R.isCont($e96369637)) {
var $ss96409641 = {"from":L[1080],
"go":function(anf_arg3809646) {
return $Hanf_arg18789647(anf_arg3809646,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e96369637.stack[R.EXN_STACKHEIGHT++] = $ss96409641;
}
if(R.isPyretException($e96369637)) {
$e96369637.pyretStack.push(L[1080]);
}
throw $e96369637;
}
var $ret96429643 = $Hanf_arg18789647($z96389639,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret96429643;
};
var $Hanf_arg18789647 = function(anf_arg3809646,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z96509651 = D;
var $f96569657 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(anf_arg3809646):R.ffi.throwNonFunApp(L[1081],j_DASH_expr10477,[anf_arg3809646]);
};
try {
if(--R.GAS > 0) {
$z96509651 = $f96569657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96569657,
"from":L[1081]});
}
} catch($e96489649) {
if(R.isCont($e96489649)) {
var $ss96529653 = {"from":L[1081],
"go":function(anf_array_val3819658) {
return $Hanf_array_val18779659(anf_array_val3819658,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e96489649.stack[R.EXN_STACKHEIGHT++] = $ss96529653;
}
if(R.isPyretException($e96489649)) {
$e96489649.pyretStack.push(L[1081]);
}
throw $e96489649;
}
var $ret96549655 = $Hanf_array_val18779659($z96509651,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret96549655;
};
var $Hanf_array_val18779659 = function(anf_array_val3819658,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun3829671 = G(list35101,"make",L[1084]);
var anf_fun3839672 = G(list35101,"make",L[1083]);
var $z96629663 = D;
var $f96689669 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(f_DASH_app2269405):R.ffi.throwNonFunApp(L[1082],j_DASH_id8381,[f_DASH_app2269405]);
};
try {
if(--R.GAS > 0) {
$z96629663 = $f96689669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96689669,
"from":L[1082]});
}
} catch($e96609661) {
if(R.isCont($e96609661)) {
var $ss96649665 = {"from":L[1082],
"go":function(anf_arg3849670) {
return $Hanf_arg18769673(anf_arg3849670,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e96609661.stack[R.EXN_STACKHEIGHT++] = $ss96649665;
}
if(R.isPyretException($e96609661)) {
$e96609661.pyretStack.push(L[1082]);
}
throw $e96609661;
}
var $ret96669667 = $Hanf_arg18769673($z96629663,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret96669667;
};
var $Hanf_arg18769673 = function(anf_arg3849670,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z96769677 = D;
var $f96829683 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("go"),anf_arg3849670):R.ffi.throwNonFunApp(L[1085],j_DASH_field9979,[("go"),anf_arg3849670]);
};
try {
if(--R.GAS > 0) {
$z96769677 = $f96829683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96829683,
"from":L[1085]});
}
} catch($e96749675) {
if(R.isCont($e96749675)) {
var $ss96789679 = {"from":L[1085],
"go":function(anf_array_val3859684) {
return $Hanf_array_val18759685(anf_array_val3859684,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e96749675.stack[R.EXN_STACKHEIGHT++] = $ss96789679;
}
if(R.isPyretException($e96749675)) {
$e96749675.pyretStack.push(L[1085]);
}
throw $e96749675;
}
var $ret96809681 = $Hanf_array_val18759685($z96769677,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret96809681;
};
var $Hanf_array_val18759685 = function(anf_array_val3859684,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun3869696 = G(compiler2151803,"get-loc",L[1087]);
var $z96889689 = D;
var $f96949695 = function(_) {
return R.isFunction(anf_fun3869696)?anf_fun3869696.app(l2161804):R.ffi.throwNonFunApp(L[1086],anf_fun3869696,[l2161804]);
};
try {
if(--R.GAS > 0) {
$z96889689 = $f96949695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96949695,
"from":L[1086]});
}
} catch($e96869687) {
if(R.isCont($e96869687)) {
var $ss96909691 = {"from":L[1086],
"go":function(anf_arg3879697) {
return $Hanf_arg18749698(anf_arg3879697,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_array_val3859684,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e96869687.stack[R.EXN_STACKHEIGHT++] = $ss96909691;
}
if(R.isPyretException($e96869687)) {
$e96869687.pyretStack.push(L[1086]);
}
throw $e96869687;
}
var $ret96929693 = $Hanf_arg18749698($z96889689,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_array_val3859684,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret96929693;
};
var $Hanf_arg18749698 = function(anf_arg3879697,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_array_val3859684,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97019702 = D;
var $f97079708 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("from"),anf_arg3879697):R.ffi.throwNonFunApp(L[1088],j_DASH_field9979,[("from"),anf_arg3879697]);
};
try {
if(--R.GAS > 0) {
$z97019702 = $f97079708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97079708,
"from":L[1088]});
}
} catch($e96999700) {
if(R.isCont($e96999700)) {
var $ss97039704 = {"from":L[1088],
"go":function(anf_array_val3889709) {
return $Hanf_array_val18739710(anf_array_val3889709,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_array_val3859684,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e96999700.stack[R.EXN_STACKHEIGHT++] = $ss97039704;
}
if(R.isPyretException($e96999700)) {
$e96999700.pyretStack.push(L[1088]);
}
throw $e96999700;
}
var $ret97059706 = $Hanf_array_val18739710($z97019702,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_array_val3859684,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret97059706;
};
var $Hanf_array_val18739710 = function(anf_array_val3889709,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_array_val3859684,anf_fun3779622,anf_fun3829671,anf_fun3839672,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97139714 = D;
var $f97199720 = function(_) {
return R.isFunction(anf_fun3839672)?anf_fun3839672.app([anf_array_val3859684,anf_array_val3889709]):R.ffi.throwNonFunApp(L[1083],anf_fun3839672,[[anf_array_val3859684,anf_array_val3889709]]);
};
try {
if(--R.GAS > 0) {
$z97139714 = $f97199720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97199720,
"from":L[1083]});
}
} catch($e97119712) {
if(R.isCont($e97119712)) {
var $ss97159716 = {"from":L[1083],
"go":function(anf_arg3899721) {
return $Hanf_arg18729722(anf_arg3899721,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e97119712.stack[R.EXN_STACKHEIGHT++] = $ss97159716;
}
if(R.isPyretException($e97119712)) {
$e97119712.pyretStack.push(L[1083]);
}
throw $e97119712;
}
var $ret97179718 = $Hanf_arg18729722($z97139714,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret97179718;
};
var $Hanf_arg18729722 = function(anf_arg3899721,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97259726 = D;
var $f97319732 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg3899721):R.ffi.throwNonFunApp(L[1089],j_DASH_obj9690,[anf_arg3899721]);
};
try {
if(--R.GAS > 0) {
$z97259726 = $f97319732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97319732,
"from":L[1089]});
}
} catch($e97239724) {
if(R.isCont($e97239724)) {
var $ss97279728 = {"from":L[1089],
"go":function(anf_array_val3909733) {
return $Hanf_array_val18719734(anf_array_val3909733,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e97239724.stack[R.EXN_STACKHEIGHT++] = $ss97279728;
}
if(R.isPyretException($e97239724)) {
$e97239724.pyretStack.push(L[1089]);
}
throw $e97239724;
}
var $ret97299730 = $Hanf_array_val18719734($z97259726,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret97299730;
};
var $Hanf_array_val18719734 = function(anf_array_val3909733,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,anf_fun3829671,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97379738 = D;
var $f97439744 = function(_) {
return R.isFunction(anf_fun3829671)?anf_fun3829671.app([anf_array_val3909733]):R.ffi.throwNonFunApp(L[1084],anf_fun3829671,[[anf_array_val3909733]]);
};
try {
if(--R.GAS > 0) {
$z97379738 = $f97439744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97439744,
"from":L[1084]});
}
} catch($e97359736) {
if(R.isCont($e97359736)) {
var $ss97399740 = {"from":L[1084],
"go":function(anf_arg3919745) {
return $Hanf_arg18709746(anf_arg3919745,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e97359736.stack[R.EXN_STACKHEIGHT++] = $ss97399740;
}
if(R.isPyretException($e97359736)) {
$e97359736.pyretStack.push(L[1084]);
}
throw $e97359736;
}
var $ret97419742 = $Hanf_arg18709746($z97379738,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret97419742;
};
var $Hanf_arg18709746 = function(anf_arg3919745,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97499750 = D;
var $f97559756 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeCont"),anf_arg3919745):R.ffi.throwNonFunApp(L[1090],rt_DASH_method173657.$var,[("makeCont"),anf_arg3919745]);
};
try {
if(--R.GAS > 0) {
$z97499750 = $f97559756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97559756,
"from":L[1090]});
}
} catch($e97479748) {
if(R.isCont($e97479748)) {
var $ss97519752 = {"from":L[1090],
"go":function(anf_arg3929757) {
return $Hanf_arg18699758(anf_arg3929757,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e97479748.stack[R.EXN_STACKHEIGHT++] = $ss97519752;
}
if(R.isPyretException($e97479748)) {
$e97479748.pyretStack.push(L[1090]);
}
throw $e97479748;
}
var $ret97539754 = $Hanf_arg18699758($z97499750,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret97539754;
};
var $Hanf_arg18699758 = function(anf_arg3929757,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97619762 = D;
var $f97679768 = function(_) {
return R.isFunction(j_DASH_throw10395)?j_DASH_throw10395.app(anf_arg3929757):R.ffi.throwNonFunApp(L[1091],j_DASH_throw10395,[anf_arg3929757]);
};
try {
if(--R.GAS > 0) {
$z97619762 = $f97679768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97679768,
"from":L[1091]});
}
} catch($e97599760) {
if(R.isCont($e97599760)) {
var $ss97639764 = {"from":L[1091],
"go":function(anf_array_val3939769) {
return $Hanf_array_val18689770(anf_array_val3939769,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e97599760.stack[R.EXN_STACKHEIGHT++] = $ss97639764;
}
if(R.isPyretException($e97599760)) {
$e97599760.pyretStack.push(L[1091]);
}
throw $e97599760;
}
var $ret97659766 = $Hanf_array_val18689770($z97619762,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret97659766;
};
var $Hanf_array_val18689770 = function(anf_array_val3939769,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,anf_array_val3819658,anf_fun3779622,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97739774 = D;
var $f97799780 = function(_) {
return R.isFunction(anf_fun3779622)?anf_fun3779622.app([anf_array_val3819658,anf_array_val3939769]):R.ffi.throwNonFunApp(L[1078],anf_fun3779622,[[anf_array_val3819658,anf_array_val3939769]]);
};
try {
if(--R.GAS > 0) {
$z97739774 = $f97799780();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97799780,
"from":L[1078]});
}
} catch($e97719772) {
if(R.isCont($e97719772)) {
var $ss97759776 = {"from":L[1078],
"go":function(anf_arg3949781) {
return $Hanf_arg18679782(anf_arg3949781,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e97719772.stack[R.EXN_STACKHEIGHT++] = $ss97759776;
}
if(R.isPyretException($e97719772)) {
$e97719772.pyretStack.push(L[1078]);
}
throw $e97719772;
}
var $ret97779778 = $Hanf_arg18679782($z97739774,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret97779778;
};
var $Hanf_arg18679782 = function(anf_arg3949781,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97859786 = D;
var $f97919792 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg3949781):R.ffi.throwNonFunApp(L[1092],j_DASH_block8570,[anf_arg3949781]);
};
try {
if(--R.GAS > 0) {
$z97859786 = $f97919792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97919792,
"from":L[1092]});
}
} catch($e97839784) {
if(R.isCont($e97839784)) {
var $ss97879788 = {"from":L[1092],
"go":function(anf_arg3959793) {
return $Hanf_arg18669794(anf_arg3959793,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e97839784.stack[R.EXN_STACKHEIGHT++] = $ss97879788;
}
if(R.isPyretException($e97839784)) {
$e97839784.pyretStack.push(L[1092]);
}
throw $e97839784;
}
var $ret97899790 = $Hanf_arg18669794($z97859786,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret97899790;
};
var $Hanf_arg18669794 = function(anf_arg3959793,J721,add_DASH_stack_DASH_frame171653,anf_arg3679523,anf_arg3769609,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z97979798 = D;
var $f98039804 = function(_) {
return R.isFunction(j_DASH_if9283)?j_DASH_if9283.app(anf_arg3679523,anf_arg3769609,anf_arg3959793):R.ffi.throwNonFunApp(L[1093],j_DASH_if9283,[anf_arg3679523,anf_arg3769609,anf_arg3959793]);
};
try {
if(--R.GAS > 0) {
$z97979798 = $f98039804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98039804,
"from":L[1093]});
}
} catch($e97959796) {
if(R.isCont($e97959796)) {
var $ss97999800 = {"from":L[1093],
"go":function(body2309805) {
return $Hbody18659806(body2309805,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e97959796.stack[R.EXN_STACKHEIGHT++] = $ss97999800;
}
if(R.isPyretException($e97959796)) {
$e97959796.pyretStack.push(L[1093]);
}
throw $e97959796;
}
var $ret98019802 = $Hbody18659806($z97979798,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret98019802;
};
var $Hbody18659806 = function(body2309805,J721,add_DASH_stack_DASH_frame171653,app174659,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_bracket3969823 = G(helper_DASH_args2211809,"rest",L[1097]);
var anf_fun3979817 = G(anf_bracket3969823,"map",L[1096]);
var anf_arg3999818 = R.makeFunction(function(recv_DASH_409821) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1095],1,arguments);
}
var ann_DASH_check_DASH_temp3989822 = G(recv_DASH_409821,"id",L[1095]);
return ann_DASH_check_DASH_temp3989822;
});
var $z98099810 = D;
var $f98159816 = function(_) {
return R.isFunction(anf_fun3979817)?anf_fun3979817.app(anf_arg3999818):R.ffi.throwNonFunApp(L[1094],anf_fun3979817,[anf_arg3999818]);
};
try {
if(--R.GAS > 0) {
$z98099810 = $f98159816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98159816,
"from":L[1094]});
}
} catch($e98079808) {
if(R.isCont($e98079808)) {
var $ss98119812 = {"from":L[1094],
"go":function(anf_bracket4009819) {
return $Hanf_bracket18649820(anf_bracket4009819,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e98079808.stack[R.EXN_STACKHEIGHT++] = $ss98119812;
}
if(R.isPyretException($e98079808)) {
$e98079808.pyretStack.push(L[1094]);
}
throw $e98079808;
}
var $ret98139814 = $Hanf_bracket18649820($z98099810,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret98139814;
};
var $Hanf_bracket18649820 = function(anf_bracket4009819,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun4019834 = G(anf_bracket4009819,"map",L[1100]);
var anf_arg4049835 = R.makeFunction(function(recv_DASH_399838) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1099],1,arguments);
}
var anf_fun4039849 = G(recv_DASH_399838,"tostring",L[1099]);
var $z98419842 = D;
var $f98479848 = function(_) {
return R.isFunction(anf_fun4039849)?anf_fun4039849.app():R.ffi.throwNonFunApp(L[1099],anf_fun4039849,[]);
};
try {
if(--R.GAS > 0) {
$z98419842 = $f98479848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98479848,
"from":L[1099]});
}
} catch($e98399840) {
if(R.isCont($e98399840)) {
var $ss98439844 = {"from":L[1099],
"go":function(ann_DASH_check_DASH_temp4029850) {
return $Hann_DASH_check_DASH_temp17899851(ann_DASH_check_DASH_temp4029850);
}};
$e98399840.stack[R.EXN_STACKHEIGHT++] = $ss98439844;
}
if(R.isPyretException($e98399840)) {
$e98399840.pyretStack.push(L[1099]);
}
throw $e98399840;
}
var $ret98459846 = $Hann_DASH_check_DASH_temp17899851($z98419842);
++R.GAS;
return $ret98459846;
});
var $z98269827 = D;
var $f98329833 = function(_) {
return R.isFunction(anf_fun4019834)?anf_fun4019834.app(anf_arg4049835):R.ffi.throwNonFunApp(L[1098],anf_fun4019834,[anf_arg4049835]);
};
try {
if(--R.GAS > 0) {
$z98269827 = $f98329833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98329833,
"from":L[1098]});
}
} catch($e98249825) {
if(R.isCont($e98249825)) {
var $ss98289829 = {"from":L[1098],
"go":function(anf_bracket4059836) {
return $Hanf_bracket18639837(anf_bracket4059836,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e98249825.stack[R.EXN_STACKHEIGHT++] = $ss98289829;
}
if(R.isPyretException($e98249825)) {
$e98249825.pyretStack.push(L[1098]);
}
throw $e98249825;
}
var $ret98309831 = $Hanf_bracket18639837($z98269827,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret98309831;
};
var $Hanf_bracket18639837 = function(anf_bracket4059836,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun4069862 = G(anf_bracket4059836,"map",L[1102]);
var $z98549855 = D;
var $f98609861 = function(_) {
return R.isFunction(anf_fun4069862)?anf_fun4069862.app(js_DASH_id_DASH_of162700):R.ffi.throwNonFunApp(L[1101],anf_fun4069862,[js_DASH_id_DASH_of162700]);
};
try {
if(--R.GAS > 0) {
$z98549855 = $f98609861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98609861,
"from":L[1101]});
}
} catch($e98529853) {
if(R.isCont($e98529853)) {
var $ss98569857 = {"from":L[1101],
"go":function(helper_DASH_ids2319863) {
return $Hhelper_DASH_ids18629864(helper_DASH_ids2319863,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e98529853.stack[R.EXN_STACKHEIGHT++] = $ss98569857;
}
if(R.isPyretException($e98529853)) {
$e98529853.pyretStack.push(L[1101]);
}
throw $e98529853;
}
var $ret98589859 = $Hhelper_DASH_ids18629864($z98549855,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret98589859;
};
var $Hhelper_DASH_ids18629864 = function(helper_DASH_ids2319863,J721,add_DASH_stack_DASH_frame171653,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun4079876 = G(list35101,"make",L[1105]);
var anf_fun4089877 = G(list35101,"make",L[1104]);
var $z98679868 = D;
var $f98739874 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(e2229309):R.ffi.throwNonFunApp(L[1103],j_DASH_id8381,[e2229309]);
};
try {
if(--R.GAS > 0) {
$z98679868 = $f98739874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98739874,
"from":L[1103]});
}
} catch($e98659866) {
if(R.isCont($e98659866)) {
var $ss98699870 = {"from":L[1103],
"go":function(anf_array_val4099875) {
return $Hanf_array_val18619878(anf_array_val4099875,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,anf_fun4089877,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e98659866.stack[R.EXN_STACKHEIGHT++] = $ss98699870;
}
if(R.isPyretException($e98659866)) {
$e98659866.pyretStack.push(L[1103]);
}
throw $e98659866;
}
var $ret98719872 = $Hanf_array_val18619878($z98679868,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,anf_fun4089877,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret98719872;
};
var $Hanf_array_val18619878 = function(anf_array_val4099875,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,anf_fun4089877,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z98819882 = D;
var $f98879888 = function(_) {
return R.isFunction(anf_fun4089877)?anf_fun4089877.app([anf_array_val4099875]):R.ffi.throwNonFunApp(L[1104],anf_fun4089877,[[anf_array_val4099875]]);
};
try {
if(--R.GAS > 0) {
$z98819882 = $f98879888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98879888,
"from":L[1104]});
}
} catch($e98799880) {
if(R.isCont($e98799880)) {
var $ss98839884 = {"from":L[1104],
"go":function(anf_arg4109889) {
return $Hanf_arg18609890(anf_arg4109889,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e98799880.stack[R.EXN_STACKHEIGHT++] = $ss98839884;
}
if(R.isPyretException($e98799880)) {
$e98799880.pyretStack.push(L[1104]);
}
throw $e98799880;
}
var $ret98859886 = $Hanf_arg18609890($z98819882,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret98859886;
};
var $Hanf_arg18609890 = function(anf_arg4109889,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z98939894 = D;
var $f98999900 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("isCont"),anf_arg4109889):R.ffi.throwNonFunApp(L[1106],rt_DASH_method173657.$var,[("isCont"),anf_arg4109889]);
};
try {
if(--R.GAS > 0) {
$z98939894 = $f98999900();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98999900,
"from":L[1106]});
}
} catch($e98919892) {
if(R.isCont($e98919892)) {
var $ss98959896 = {"from":L[1106],
"go":function(anf_arg4119901) {
return $Hanf_arg18599902(anf_arg4119901,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e98919892.stack[R.EXN_STACKHEIGHT++] = $ss98959896;
}
if(R.isPyretException($e98919892)) {
$e98919892.pyretStack.push(L[1106]);
}
throw $e98919892;
}
var $ret98979898 = $Hanf_arg18599902($z98939894,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret98979898;
};
var $Hanf_arg18599902 = function(anf_arg4119901,J721,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun4129915 = G(list35101,"make",L[1110]);
var anf_fun4139916 = G(list35101,"make",L[1109]);
var anf_fun4149913 = G(compiler2151803,"get-loc",L[1108]);
var $z99059906 = D;
var $f99119912 = function(_) {
return R.isFunction(anf_fun4149913)?anf_fun4149913.app(l2161804):R.ffi.throwNonFunApp(L[1107],anf_fun4149913,[l2161804]);
};
try {
if(--R.GAS > 0) {
$z99059906 = $f99119912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99119912,
"from":L[1107]});
}
} catch($e99039904) {
if(R.isCont($e99039904)) {
var $ss99079908 = {"from":L[1107],
"go":function(anf_arg4159914) {
return $Hanf_arg18589917(anf_arg4159914,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e99039904.stack[R.EXN_STACKHEIGHT++] = $ss99079908;
}
if(R.isPyretException($e99039904)) {
$e99039904.pyretStack.push(L[1107]);
}
throw $e99039904;
}
var $ret99099910 = $Hanf_arg18589917($z99059906,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret99099910;
};
var $Hanf_arg18589917 = function(anf_arg4159914,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z99209921 = D;
var $f99269927 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("from"),anf_arg4159914):R.ffi.throwNonFunApp(L[1111],j_DASH_field9979,[("from"),anf_arg4159914]);
};
try {
if(--R.GAS > 0) {
$z99209921 = $f99269927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99269927,
"from":L[1111]});
}
} catch($e99189919) {
if(R.isCont($e99189919)) {
var $ss99229923 = {"from":L[1111],
"go":function(anf_array_val4169928) {
return $Hanf_array_val18579929(anf_array_val4169928,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e99189919.stack[R.EXN_STACKHEIGHT++] = $ss99229923;
}
if(R.isPyretException($e99189919)) {
$e99189919.pyretStack.push(L[1111]);
}
throw $e99189919;
}
var $ret99249925 = $Hanf_array_val18579929($z99209921,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret99249925;
};
var $Hanf_array_val18579929 = function(anf_array_val4169928,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun4179942 = G(list35101,"make",L[1116]);
var anf_bracket4189945 = G(helper_DASH_args2211809,"first",L[1115]);
var anf_bracket4199944 = G(anf_bracket4189945,"id",L[1114]);
var anf_fun4209940 = G(anf_bracket4199944,"tostring",L[1113]);
var $z99329933 = D;
var $f99389939 = function(_) {
return R.isFunction(anf_fun4209940)?anf_fun4209940.app():R.ffi.throwNonFunApp(L[1112],anf_fun4209940,[]);
};
try {
if(--R.GAS > 0) {
$z99329933 = $f99389939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99389939,
"from":L[1112]});
}
} catch($e99309931) {
if(R.isCont($e99309931)) {
var $ss99349935 = {"from":L[1112],
"go":function(anf_arg4219941) {
return $Hanf_arg18569943(anf_arg4219941,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4179942,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e99309931.stack[R.EXN_STACKHEIGHT++] = $ss99349935;
}
if(R.isPyretException($e99309931)) {
$e99309931.pyretStack.push(L[1112]);
}
throw $e99309931;
}
var $ret99369937 = $Hanf_arg18569943($z99329933,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4179942,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret99369937;
};
var $Hanf_arg18569943 = function(anf_arg4219941,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4179942,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z99489949 = D;
var $f99549955 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg4219941):R.ffi.throwNonFunApp(L[1117],js_DASH_id_DASH_of162700,[anf_arg4219941]);
};
try {
if(--R.GAS > 0) {
$z99489949 = $f99549955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99549955,
"from":L[1117]});
}
} catch($e99469947) {
if(R.isCont($e99469947)) {
var $ss99509951 = {"from":L[1117],
"go":function(anf_array_val4229956) {
return $Hanf_array_val18559957(anf_array_val4229956,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4179942,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e99469947.stack[R.EXN_STACKHEIGHT++] = $ss99509951;
}
if(R.isPyretException($e99469947)) {
$e99469947.pyretStack.push(L[1117]);
}
throw $e99469947;
}
var $ret99529953 = $Hanf_array_val18559957($z99489949,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4179942,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret99529953;
};
var $Hanf_array_val18559957 = function(anf_array_val4229956,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4179942,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z99609961 = D;
var $f99669967 = function(_) {
return R.isFunction(anf_fun4179942)?anf_fun4179942.app([anf_array_val4229956]):R.ffi.throwNonFunApp(L[1116],anf_fun4179942,[[anf_array_val4229956]]);
};
try {
if(--R.GAS > 0) {
$z99609961 = $f99669967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99669967,
"from":L[1116]});
}
} catch($e99589959) {
if(R.isCont($e99589959)) {
var $ss99629963 = {"from":L[1116],
"go":function(anf_arg4239968) {
return $Hanf_arg18549969(anf_arg4239968,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e99589959.stack[R.EXN_STACKHEIGHT++] = $ss99629963;
}
if(R.isPyretException($e99589959)) {
$e99589959.pyretStack.push(L[1116]);
}
throw $e99589959;
}
var $ret99649965 = $Hanf_arg18549969($z99609961,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret99649965;
};
var $Hanf_arg18549969 = function(anf_arg4239968,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun4249981 = G(list35101,"make",L[1119]);
var $z99729973 = D;
var $f99789979 = function(_) {
return R.isFunction(helper_DASH_name177665.$var)?helper_DASH_name177665.$var.app(name2201808):R.ffi.throwNonFunApp(L[1118],helper_DASH_name177665.$var,[name2201808]);
};
try {
if(--R.GAS > 0) {
$z99729973 = $f99789979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99789979,
"from":L[1118]});
}
} catch($e99709971) {
if(R.isCont($e99709971)) {
var $ss99749975 = {"from":L[1118],
"go":function(anf_arg4259980) {
return $Hanf_arg18539982(anf_arg4259980,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e99709971.stack[R.EXN_STACKHEIGHT++] = $ss99749975;
}
if(R.isPyretException($e99709971)) {
$e99709971.pyretStack.push(L[1118]);
}
throw $e99709971;
}
var $ret99769977 = $Hanf_arg18539982($z99729973,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret99769977;
};
var $Hanf_arg18539982 = function(anf_arg4259980,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z99859986 = D;
var $f99919992 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg4259980):R.ffi.throwNonFunApp(L[1120],j_DASH_id8381,[anf_arg4259980]);
};
try {
if(--R.GAS > 0) {
$z99859986 = $f99919992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99919992,
"from":L[1120]});
}
} catch($e99839984) {
if(R.isCont($e99839984)) {
var $ss99879988 = {"from":L[1120],
"go":function(anf_arg4269993) {
return $Hanf_arg18529994(anf_arg4269993,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e99839984.stack[R.EXN_STACKHEIGHT++] = $ss99879988;
}
if(R.isPyretException($e99839984)) {
$e99839984.pyretStack.push(L[1120]);
}
throw $e99839984;
}
var $ret99899990 = $Hanf_arg18529994($z99859986,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret99899990;
};
var $Hanf_arg18529994 = function(anf_arg4269993,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_args2211809,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_bracket42710009 = G(helper_DASH_args2211809,"first",L[1124]);
var anf_bracket42810008 = G(anf_bracket42710009,"id",L[1123]);
var anf_fun42910005 = G(anf_bracket42810008,"tostring",L[1122]);
var $z99979998 = D;
var $f1000310004 = function(_) {
return R.isFunction(anf_fun42910005)?anf_fun42910005.app():R.ffi.throwNonFunApp(L[1121],anf_fun42910005,[]);
};
try {
if(--R.GAS > 0) {
$z99979998 = $f1000310004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1000310004,
"from":L[1121]});
}
} catch($e99959996) {
if(R.isCont($e99959996)) {
var $ss999910000 = {"from":L[1121],
"go":function(anf_arg43010006) {
return $Hanf_arg185110007(anf_arg43010006,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e99959996.stack[R.EXN_STACKHEIGHT++] = $ss999910000;
}
if(R.isPyretException($e99959996)) {
$e99959996.pyretStack.push(L[1121]);
}
throw $e99959996;
}
var $ret1000110002 = $Hanf_arg185110007($z99979998,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1000110002;
};
var $Hanf_arg185110007 = function(anf_arg43010006,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,js_DASH_id_DASH_of162700,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1001210013 = D;
var $f1001810019 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg43010006):R.ffi.throwNonFunApp(L[1125],js_DASH_id_DASH_of162700,[anf_arg43010006]);
};
try {
if(--R.GAS > 0) {
$z1001210013 = $f1001810019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1001810019,
"from":L[1125]});
}
} catch($e1001010011) {
if(R.isCont($e1001010011)) {
var $ss1001410015 = {"from":L[1125],
"go":function(anf_arg43110020) {
return $Hanf_arg185010021(anf_arg43110020,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1001010011.stack[R.EXN_STACKHEIGHT++] = $ss1001410015;
}
if(R.isPyretException($e1001010011)) {
$e1001010011.pyretStack.push(L[1125]);
}
throw $e1001010011;
}
var $ret1001610017 = $Hanf_arg185010021($z1001210013,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1001610017;
};
var $Hanf_arg185010021 = function(anf_arg43110020,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1002410025 = D;
var $f1003010031 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg43110020):R.ffi.throwNonFunApp(L[1126],j_DASH_id8381,[anf_arg43110020]);
};
try {
if(--R.GAS > 0) {
$z1002410025 = $f1003010031();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1003010031,
"from":L[1126]});
}
} catch($e1002210023) {
if(R.isCont($e1002210023)) {
var $ss1002610027 = {"from":L[1126],
"go":function(anf_arg43210032) {
return $Hanf_arg184910033(anf_arg43210032,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1002210023.stack[R.EXN_STACKHEIGHT++] = $ss1002610027;
}
if(R.isPyretException($e1002210023)) {
$e1002210023.pyretStack.push(L[1126]);
}
throw $e1002210023;
}
var $ret1002810029 = $Hanf_arg184910033($z1002410025,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1002810029;
};
var $Hanf_arg184910033 = function(anf_arg43210032,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_ids2319863,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_fun43310044 = G(helper_DASH_ids2319863,"map",L[1129]);
var anf_arg43510045 = R.makeFunction(function(a23310048) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1128],1,arguments);
}
var $z1005110052 = D;
var $f1005710058 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(a23310048):R.ffi.throwNonFunApp(L[1128],j_DASH_id8381,[a23310048]);
};
try {
if(--R.GAS > 0) {
$z1005110052 = $f1005710058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1005710058,
"from":L[1128]});
}
} catch($e1004910050) {
if(R.isCont($e1004910050)) {
var $ss1005310054 = {"from":L[1128],
"go":function(ann_DASH_check_DASH_temp43410059) {
return $Hann_DASH_check_DASH_temp179010060(ann_DASH_check_DASH_temp43410059);
}};
$e1004910050.stack[R.EXN_STACKHEIGHT++] = $ss1005310054;
}
if(R.isPyretException($e1004910050)) {
$e1004910050.pyretStack.push(L[1128]);
}
throw $e1004910050;
}
var $ret1005510056 = $Hann_DASH_check_DASH_temp179010060($z1005110052);
++R.GAS;
return $ret1005510056;
});
var $z1003610037 = D;
var $f1004210043 = function(_) {
return R.isFunction(anf_fun43310044)?anf_fun43310044.app(anf_arg43510045):R.ffi.throwNonFunApp(L[1127],anf_fun43310044,[anf_arg43510045]);
};
try {
if(--R.GAS > 0) {
$z1003610037 = $f1004210043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1004210043,
"from":L[1127]});
}
} catch($e1003410035) {
if(R.isCont($e1003410035)) {
var $ss1003810039 = {"from":L[1127],
"go":function(anf_arg43610046) {
return $Hanf_arg184810047(anf_arg43610046,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_arg43210032,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1003410035.stack[R.EXN_STACKHEIGHT++] = $ss1003810039;
}
if(R.isPyretException($e1003410035)) {
$e1003410035.pyretStack.push(L[1127]);
}
throw $e1003410035;
}
var $ret1004010041 = $Hanf_arg184810047($z1003610037,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_arg43210032,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1004010041;
};
var $Hanf_arg184810047 = function(anf_arg43610046,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_arg43210032,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,link39100,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1006310064 = D;
var $f1006910070 = function(_) {
return R.isFunction(link39100)?link39100.app(anf_arg43210032,anf_arg43610046):R.ffi.throwNonFunApp(L[1130],link39100,[anf_arg43210032,anf_arg43610046]);
};
try {
if(--R.GAS > 0) {
$z1006310064 = $f1006910070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1006910070,
"from":L[1130]});
}
} catch($e1006110062) {
if(R.isCont($e1006110062)) {
var $ss1006510066 = {"from":L[1130],
"go":function(anf_arg43710071) {
return $Hanf_arg184710072(anf_arg43710071,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1006110062.stack[R.EXN_STACKHEIGHT++] = $ss1006510066;
}
if(R.isPyretException($e1006110062)) {
$e1006110062.pyretStack.push(L[1130]);
}
throw $e1006110062;
}
var $ret1006710068 = $Hanf_arg184710072($z1006310064,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1006710068;
};
var $Hanf_arg184710072 = function(anf_arg43710071,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_arg4269993,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1007510076 = D;
var $f1008110082 = function(_) {
return R.isFunction(j_DASH_app9467)?j_DASH_app9467.app(anf_arg4269993,anf_arg43710071):R.ffi.throwNonFunApp(L[1131],j_DASH_app9467,[anf_arg4269993,anf_arg43710071]);
};
try {
if(--R.GAS > 0) {
$z1007510076 = $f1008110082();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1008110082,
"from":L[1131]});
}
} catch($e1007310074) {
if(R.isCont($e1007310074)) {
var $ss1007710078 = {"from":L[1131],
"go":function(anf_arg43810083) {
return $Hanf_arg184610084(anf_arg43810083,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1007310074.stack[R.EXN_STACKHEIGHT++] = $ss1007710078;
}
if(R.isPyretException($e1007310074)) {
$e1007310074.pyretStack.push(L[1131]);
}
throw $e1007310074;
}
var $ret1007910080 = $Hanf_arg184610084($z1007510076,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1007910080;
};
var $Hanf_arg184610084 = function(anf_arg43810083,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1008710088 = D;
var $f1009310094 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg43810083):R.ffi.throwNonFunApp(L[1132],j_DASH_return9092,[anf_arg43810083]);
};
try {
if(--R.GAS > 0) {
$z1008710088 = $f1009310094();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1009310094,
"from":L[1132]});
}
} catch($e1008510086) {
if(R.isCont($e1008510086)) {
var $ss1008910090 = {"from":L[1132],
"go":function(anf_array_val43910095) {
return $Hanf_array_val184510096(anf_array_val43910095,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1008510086.stack[R.EXN_STACKHEIGHT++] = $ss1008910090;
}
if(R.isPyretException($e1008510086)) {
$e1008510086.pyretStack.push(L[1132]);
}
throw $e1008510086;
}
var $ret1009110092 = $Hanf_array_val184510096($z1008710088,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1009110092;
};
var $Hanf_array_val184510096 = function(anf_array_val43910095,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,anf_fun4249981,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1009910100 = D;
var $f1010510106 = function(_) {
return R.isFunction(anf_fun4249981)?anf_fun4249981.app([anf_array_val43910095]):R.ffi.throwNonFunApp(L[1119],anf_fun4249981,[[anf_array_val43910095]]);
};
try {
if(--R.GAS > 0) {
$z1009910100 = $f1010510106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1010510106,
"from":L[1119]});
}
} catch($e1009710098) {
if(R.isCont($e1009710098)) {
var $ss1010110102 = {"from":L[1119],
"go":function(anf_arg44010107) {
return $Hanf_arg184410108(anf_arg44010107,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1009710098.stack[R.EXN_STACKHEIGHT++] = $ss1010110102;
}
if(R.isPyretException($e1009710098)) {
$e1009710098.pyretStack.push(L[1119]);
}
throw $e1009710098;
}
var $ret1010310104 = $Hanf_arg184410108($z1009910100,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1010310104;
};
var $Hanf_arg184410108 = function(anf_arg44010107,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1011110112 = D;
var $f1011710118 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg44010107):R.ffi.throwNonFunApp(L[1133],j_DASH_block8570,[anf_arg44010107]);
};
try {
if(--R.GAS > 0) {
$z1011110112 = $f1011710118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1011710118,
"from":L[1133]});
}
} catch($e1010910110) {
if(R.isCont($e1010910110)) {
var $ss1011310114 = {"from":L[1133],
"go":function(anf_arg44110119) {
return $Hanf_arg184310120(anf_arg44110119,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1010910110.stack[R.EXN_STACKHEIGHT++] = $ss1011310114;
}
if(R.isPyretException($e1010910110)) {
$e1010910110.pyretStack.push(L[1133]);
}
throw $e1010910110;
}
var $ret1011510116 = $Hanf_arg184310120($z1011110112,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1011510116;
};
var $Hanf_arg184310120 = function(anf_arg44110119,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg4239968,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1012310124 = D;
var $f1012910130 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg4239968,anf_arg44110119):R.ffi.throwNonFunApp(L[1134],j_DASH_fun8180,[anf_arg4239968,anf_arg44110119]);
};
try {
if(--R.GAS > 0) {
$z1012310124 = $f1012910130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1012910130,
"from":L[1134]});
}
} catch($e1012110122) {
if(R.isCont($e1012110122)) {
var $ss1012510126 = {"from":L[1134],
"go":function(anf_arg44210131) {
return $Hanf_arg184210132(anf_arg44210131,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1012110122.stack[R.EXN_STACKHEIGHT++] = $ss1012510126;
}
if(R.isPyretException($e1012110122)) {
$e1012110122.pyretStack.push(L[1134]);
}
throw $e1012110122;
}
var $ret1012710128 = $Hanf_arg184210132($z1012310124,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1012710128;
};
var $Hanf_arg184210132 = function(anf_arg44210131,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1013510136 = D;
var $f1014110142 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("go"),anf_arg44210131):R.ffi.throwNonFunApp(L[1135],j_DASH_field9979,[("go"),anf_arg44210131]);
};
try {
if(--R.GAS > 0) {
$z1013510136 = $f1014110142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1014110142,
"from":L[1135]});
}
} catch($e1013310134) {
if(R.isCont($e1013310134)) {
var $ss1013710138 = {"from":L[1135],
"go":function(anf_array_val44310143) {
return $Hanf_array_val184110144(anf_array_val44310143,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1013310134.stack[R.EXN_STACKHEIGHT++] = $ss1013710138;
}
if(R.isPyretException($e1013310134)) {
$e1013310134.pyretStack.push(L[1135]);
}
throw $e1013310134;
}
var $ret1013910140 = $Hanf_array_val184110144($z1013510136,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1013910140;
};
var $Hanf_array_val184110144 = function(anf_array_val44310143,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val4169928,anf_fun4079876,anf_fun4129915,anf_fun4139916,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1014710148 = D;
var $f1015310154 = function(_) {
return R.isFunction(anf_fun4139916)?anf_fun4139916.app([anf_array_val4169928,anf_array_val44310143]):R.ffi.throwNonFunApp(L[1109],anf_fun4139916,[[anf_array_val4169928,anf_array_val44310143]]);
};
try {
if(--R.GAS > 0) {
$z1014710148 = $f1015310154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1015310154,
"from":L[1109]});
}
} catch($e1014510146) {
if(R.isCont($e1014510146)) {
var $ss1014910150 = {"from":L[1109],
"go":function(anf_arg44410155) {
return $Hanf_arg184010156(anf_arg44410155,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1014510146.stack[R.EXN_STACKHEIGHT++] = $ss1014910150;
}
if(R.isPyretException($e1014510146)) {
$e1014510146.pyretStack.push(L[1109]);
}
throw $e1014510146;
}
var $ret1015110152 = $Hanf_arg184010156($z1014710148,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1015110152;
};
var $Hanf_arg184010156 = function(anf_arg44410155,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1015910160 = D;
var $f1016510166 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg44410155):R.ffi.throwNonFunApp(L[1136],j_DASH_obj9690,[anf_arg44410155]);
};
try {
if(--R.GAS > 0) {
$z1015910160 = $f1016510166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1016510166,
"from":L[1136]});
}
} catch($e1015710158) {
if(R.isCont($e1015710158)) {
var $ss1016110162 = {"from":L[1136],
"go":function(anf_arg44510167) {
return $Hanf_arg183910168(anf_arg44510167,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1015710158.stack[R.EXN_STACKHEIGHT++] = $ss1016110162;
}
if(R.isPyretException($e1015710158)) {
$e1015710158.pyretStack.push(L[1136]);
}
throw $e1015710158;
}
var $ret1016310164 = $Hanf_arg183910168($z1015910160,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1016310164;
};
var $Hanf_arg183910168 = function(anf_arg44510167,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1017110172 = D;
var $f1017710178 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(ss2249357,anf_arg44510167):R.ffi.throwNonFunApp(L[1137],j_DASH_var8299,[ss2249357,anf_arg44510167]);
};
try {
if(--R.GAS > 0) {
$z1017110172 = $f1017710178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1017710178,
"from":L[1137]});
}
} catch($e1016910170) {
if(R.isCont($e1016910170)) {
var $ss1017310174 = {"from":L[1137],
"go":function(anf_array_val44610179) {
return $Hanf_array_val183810180(anf_array_val44610179,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1016910170.stack[R.EXN_STACKHEIGHT++] = $ss1017310174;
}
if(R.isPyretException($e1016910170)) {
$e1016910170.pyretStack.push(L[1137]);
}
throw $e1016910170;
}
var $ret1017510176 = $Hanf_array_val183810180($z1017110172,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1017510176;
};
var $Hanf_array_val183810180 = function(anf_array_val44610179,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1018310184 = D;
var $f1018910190 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(e2229309):R.ffi.throwNonFunApp(L[1138],j_DASH_id8381,[e2229309]);
};
try {
if(--R.GAS > 0) {
$z1018310184 = $f1018910190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1018910190,
"from":L[1138]});
}
} catch($e1018110182) {
if(R.isCont($e1018110182)) {
var $ss1018510186 = {"from":L[1138],
"go":function(anf_arg44710191) {
return $Hanf_arg183710192(anf_arg44710191,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1018110182.stack[R.EXN_STACKHEIGHT++] = $ss1018510186;
}
if(R.isPyretException($e1018110182)) {
$e1018110182.pyretStack.push(L[1138]);
}
throw $e1018110182;
}
var $ret1018710188 = $Hanf_arg183710192($z1018310184,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1018710188;
};
var $Hanf_arg183710192 = function(anf_arg44710191,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_dot9775,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1019510196 = D;
var $f1020110202 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(anf_arg44710191,("stack")):R.ffi.throwNonFunApp(L[1139],j_DASH_dot9775,[anf_arg44710191,("stack")]);
};
try {
if(--R.GAS > 0) {
$z1019510196 = $f1020110202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1020110202,
"from":L[1139]});
}
} catch($e1019310194) {
if(R.isCont($e1019310194)) {
var $ss1019710198 = {"from":L[1139],
"go":function(anf_arg44810203) {
return $Hanf_arg183610204(anf_arg44810203,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1019310194.stack[R.EXN_STACKHEIGHT++] = $ss1019710198;
}
if(R.isPyretException($e1019310194)) {
$e1019310194.pyretStack.push(L[1139]);
}
throw $e1019310194;
}
var $ret1019910200 = $Hanf_arg183610204($z1019510196,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1019910200;
};
var $Hanf_arg183610204 = function(anf_arg44810203,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1020710208 = D;
var $f1021310214 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("EXN_STACKHEIGHT")):R.ffi.throwNonFunApp(L[1140],rt_DASH_field172655.$var,[("EXN_STACKHEIGHT")]);
};
try {
if(--R.GAS > 0) {
$z1020710208 = $f1021310214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1021310214,
"from":L[1140]});
}
} catch($e1020510206) {
if(R.isCont($e1020510206)) {
var $ss1020910210 = {"from":L[1140],
"go":function(anf_arg44910215) {
return $Hanf_arg183510216(anf_arg44910215,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1020510206.stack[R.EXN_STACKHEIGHT++] = $ss1020910210;
}
if(R.isPyretException($e1020510206)) {
$e1020510206.pyretStack.push(L[1140]);
}
throw $e1020510206;
}
var $ret1021110212 = $Hanf_arg183510216($z1020710208,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1021110212;
};
var $Hanf_arg183510216 = function(anf_arg44910215,J721,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var anf_arg45010227 = G(J721,"j-postincr",L[1142]);
var $z1021910220 = D;
var $f1022510226 = function(_) {
return R.isFunction(j_DASH_unop10898)?j_DASH_unop10898.app(anf_arg44910215,anf_arg45010227):R.ffi.throwNonFunApp(L[1141],j_DASH_unop10898,[anf_arg44910215,anf_arg45010227]);
};
try {
if(--R.GAS > 0) {
$z1021910220 = $f1022510226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1022510226,
"from":L[1141]});
}
} catch($e1021710218) {
if(R.isCont($e1021710218)) {
var $ss1022110222 = {"from":L[1141],
"go":function(anf_arg45110228) {
return $Hanf_arg183410229(anf_arg45110228,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
}};
$e1021710218.stack[R.EXN_STACKHEIGHT++] = $ss1022110222;
}
if(R.isPyretException($e1021710218)) {
$e1021710218.pyretStack.push(L[1141]);
}
throw $e1021710218;
}
var $ret1022310224 = $Hanf_arg183410229($z1021910220,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1022310224;
};
var $Hanf_arg183410229 = function(anf_arg45110228,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,ss2249357,undefined117140,z2239333,_plus5) {
var $z1023210233 = D;
var $f1023810239 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(ss2249357):R.ffi.throwNonFunApp(L[1143],j_DASH_id8381,[ss2249357]);
};
try {
if(--R.GAS > 0) {
$z1023210233 = $f1023810239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1023810239,
"from":L[1143]});
}
} catch($e1023010231) {
if(R.isCont($e1023010231)) {
var $ss1023410235 = {"from":L[1143],
"go":function(anf_arg45210240) {
return $Hanf_arg183310241(anf_arg45210240,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_arg45110228,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e1023010231.stack[R.EXN_STACKHEIGHT++] = $ss1023410235;
}
if(R.isPyretException($e1023010231)) {
$e1023010231.pyretStack.push(L[1143]);
}
throw $e1023010231;
}
var $ret1023610237 = $Hanf_arg183310241($z1023210233,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_arg45110228,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1023610237;
};
var $Hanf_arg183310241 = function(anf_arg45210240,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_arg44810203,anf_arg45110228,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z1024410245 = D;
var $f1025010251 = function(_) {
return R.isFunction(j_DASH_bracket_DASH_assign10171)?j_DASH_bracket_DASH_assign10171.app(anf_arg44810203,anf_arg45110228,anf_arg45210240):R.ffi.throwNonFunApp(L[1144],j_DASH_bracket_DASH_assign10171,[anf_arg44810203,anf_arg45110228,anf_arg45210240]);
};
try {
if(--R.GAS > 0) {
$z1024410245 = $f1025010251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1025010251,
"from":L[1144]});
}
} catch($e1024210243) {
if(R.isCont($e1024210243)) {
var $ss1024610247 = {"from":L[1144],
"go":function(anf_arg45310252) {
return $Hanf_arg183210253(anf_arg45310252,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e1024210243.stack[R.EXN_STACKHEIGHT++] = $ss1024610247;
}
if(R.isPyretException($e1024210243)) {
$e1024210243.pyretStack.push(L[1144]);
}
throw $e1024210243;
}
var $ret1024810249 = $Hanf_arg183210253($z1024410245,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1024810249;
};
var $Hanf_arg183210253 = function(anf_arg45310252,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z1025610257 = D;
var $f1026210263 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(anf_arg45310252):R.ffi.throwNonFunApp(L[1145],j_DASH_expr10477,[anf_arg45310252]);
};
try {
if(--R.GAS > 0) {
$z1025610257 = $f1026210263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1026210263,
"from":L[1145]});
}
} catch($e1025410255) {
if(R.isCont($e1025410255)) {
var $ss1025810259 = {"from":L[1145],
"go":function(anf_array_val45410264) {
return $Hanf_array_val183110265(anf_array_val45410264,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e1025410255.stack[R.EXN_STACKHEIGHT++] = $ss1025810259;
}
if(R.isPyretException($e1025410255)) {
$e1025410255.pyretStack.push(L[1145]);
}
throw $e1025410255;
}
var $ret1026010261 = $Hanf_array_val183110265($z1025610257,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1026010261;
};
var $Hanf_array_val183110265 = function(anf_array_val45410264,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_array_val44610179,anf_fun4079876,anf_fun4129915,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z1026810269 = D;
var $f1027410275 = function(_) {
return R.isFunction(anf_fun4129915)?anf_fun4129915.app([anf_array_val44610179,anf_array_val45410264]):R.ffi.throwNonFunApp(L[1110],anf_fun4129915,[[anf_array_val44610179,anf_array_val45410264]]);
};
try {
if(--R.GAS > 0) {
$z1026810269 = $f1027410275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1027410275,
"from":L[1110]});
}
} catch($e1026610267) {
if(R.isCont($e1026610267)) {
var $ss1027010271 = {"from":L[1110],
"go":function(anf_arg45510276) {
return $Hanf_arg183010277(anf_arg45510276,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e1026610267.stack[R.EXN_STACKHEIGHT++] = $ss1027010271;
}
if(R.isPyretException($e1026610267)) {
$e1026610267.pyretStack.push(L[1110]);
}
throw $e1026610267;
}
var $ret1027210273 = $Hanf_arg183010277($z1026810269,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1027210273;
};
var $Hanf_arg183010277 = function(anf_arg45510276,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z1028010281 = D;
var $f1028610287 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg45510276):R.ffi.throwNonFunApp(L[1146],j_DASH_block8570,[anf_arg45510276]);
};
try {
if(--R.GAS > 0) {
$z1028010281 = $f1028610287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1028610287,
"from":L[1146]});
}
} catch($e1027810279) {
if(R.isCont($e1027810279)) {
var $ss1028210283 = {"from":L[1146],
"go":function(anf_arg45610288) {
return $Hanf_arg182910289(anf_arg45610288,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e1027810279.stack[R.EXN_STACKHEIGHT++] = $ss1028210283;
}
if(R.isPyretException($e1027810279)) {
$e1027810279.pyretStack.push(L[1146]);
}
throw $e1027810279;
}
var $ret1028410285 = $Hanf_arg182910289($z1028010281,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1028410285;
};
var $Hanf_arg182910289 = function(anf_arg45610288,add_DASH_stack_DASH_frame171653,anf_arg4119901,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z1029210293 = D;
var $f1029810299 = function(_) {
return R.isFunction(j_DASH_if19382)?j_DASH_if19382.app(anf_arg4119901,anf_arg45610288):R.ffi.throwNonFunApp(L[1147],j_DASH_if19382,[anf_arg4119901,anf_arg45610288]);
};
try {
if(--R.GAS > 0) {
$z1029210293 = $f1029810299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1029810299,
"from":L[1147]});
}
} catch($e1029010291) {
if(R.isCont($e1029010291)) {
var $ss1029410295 = {"from":L[1147],
"go":function(anf_array_val45710300) {
return $Hanf_array_val182810301(anf_array_val45710300,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e1029010291.stack[R.EXN_STACKHEIGHT++] = $ss1029410295;
}
if(R.isPyretException($e1029010291)) {
$e1029010291.pyretStack.push(L[1147]);
}
throw $e1029010291;
}
var $ret1029610297 = $Hanf_array_val182810301($z1029210293,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1029610297;
};
var $Hanf_array_val182810301 = function(anf_array_val45710300,add_DASH_stack_DASH_frame171653,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var anf_fun45810313 = G(list35101,"make",L[1149]);
var $z1030410305 = D;
var $f1031010311 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(e2229309):R.ffi.throwNonFunApp(L[1148],j_DASH_id8381,[e2229309]);
};
try {
if(--R.GAS > 0) {
$z1030410305 = $f1031010311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1031010311,
"from":L[1148]});
}
} catch($e1030210303) {
if(R.isCont($e1030210303)) {
var $ss1030610307 = {"from":L[1148],
"go":function(anf_array_val45910312) {
return $Hanf_array_val182710314(anf_array_val45910312,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,anf_fun45810313,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e1030210303.stack[R.EXN_STACKHEIGHT++] = $ss1030610307;
}
if(R.isPyretException($e1030210303)) {
$e1030210303.pyretStack.push(L[1148]);
}
throw $e1030210303;
}
var $ret1030810309 = $Hanf_array_val182710314($z1030410305,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,anf_fun45810313,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1030810309;
};
var $Hanf_array_val182710314 = function(anf_array_val45910312,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,anf_fun45810313,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z1031710318 = D;
var $f1032310324 = function(_) {
return R.isFunction(anf_fun45810313)?anf_fun45810313.app([anf_array_val45910312]):R.ffi.throwNonFunApp(L[1149],anf_fun45810313,[[anf_array_val45910312]]);
};
try {
if(--R.GAS > 0) {
$z1031710318 = $f1032310324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1032310324,
"from":L[1149]});
}
} catch($e1031510316) {
if(R.isCont($e1031510316)) {
var $ss1031910320 = {"from":L[1149],
"go":function(anf_arg46010325) {
return $Hanf_arg182610326(anf_arg46010325,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
}};
$e1031510316.stack[R.EXN_STACKHEIGHT++] = $ss1031910320;
}
if(R.isPyretException($e1031510316)) {
$e1031510316.pyretStack.push(L[1149]);
}
throw $e1031510316;
}
var $ret1032110322 = $Hanf_arg182610326($z1031710318,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1032110322;
};
var $Hanf_arg182610326 = function(anf_arg46010325,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,rt_DASH_method173657,undefined117140,z2239333,_plus5) {
var $z1032910330 = D;
var $f1033510336 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("isPyretException"),anf_arg46010325):R.ffi.throwNonFunApp(L[1150],rt_DASH_method173657.$var,[("isPyretException"),anf_arg46010325]);
};
try {
if(--R.GAS > 0) {
$z1032910330 = $f1033510336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1033510336,
"from":L[1150]});
}
} catch($e1032710328) {
if(R.isCont($e1032710328)) {
var $ss1033110332 = {"from":L[1150],
"go":function(anf_arg46110337) {
return $Hanf_arg182510338(anf_arg46110337,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1032710328.stack[R.EXN_STACKHEIGHT++] = $ss1033110332;
}
if(R.isPyretException($e1032710328)) {
$e1032710328.pyretStack.push(L[1150]);
}
throw $e1032710328;
}
var $ret1033310334 = $Hanf_arg182510338($z1032910330,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1033310334;
};
var $Hanf_arg182510338 = function(anf_arg46110337,add_DASH_stack_DASH_frame171653,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var anf_fun46210351 = G(list35101,"make",L[1153]);
var anf_fun46310349 = G(compiler2151803,"get-loc",L[1152]);
var $z1034110342 = D;
var $f1034710348 = function(_) {
return R.isFunction(anf_fun46310349)?anf_fun46310349.app(l2161804):R.ffi.throwNonFunApp(L[1151],anf_fun46310349,[l2161804]);
};
try {
if(--R.GAS > 0) {
$z1034110342 = $f1034710348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1034710348,
"from":L[1151]});
}
} catch($e1033910340) {
if(R.isCont($e1033910340)) {
var $ss1034310344 = {"from":L[1151],
"go":function(anf_arg46410350) {
return $Hanf_arg182410352(anf_arg46410350,add_DASH_stack_DASH_frame171653,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1033910340.stack[R.EXN_STACKHEIGHT++] = $ss1034310344;
}
if(R.isPyretException($e1033910340)) {
$e1033910340.pyretStack.push(L[1151]);
}
throw $e1033910340;
}
var $ret1034510346 = $Hanf_arg182410352($z1034110342,add_DASH_stack_DASH_frame171653,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1034510346;
};
var $Hanf_arg182410352 = function(anf_arg46410350,add_DASH_stack_DASH_frame171653,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1035510356 = D;
var $f1036110362 = function(_) {
return R.isFunction(add_DASH_stack_DASH_frame171653.$var)?add_DASH_stack_DASH_frame171653.$var.app(e2229309,anf_arg46410350):R.ffi.throwNonFunApp(L[1154],add_DASH_stack_DASH_frame171653.$var,[e2229309,anf_arg46410350]);
};
try {
if(--R.GAS > 0) {
$z1035510356 = $f1036110362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1036110362,
"from":L[1154]});
}
} catch($e1035310354) {
if(R.isCont($e1035310354)) {
var $ss1035710358 = {"from":L[1154],
"go":function(anf_arg46510363) {
return $Hanf_arg182310364(anf_arg46510363,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1035310354.stack[R.EXN_STACKHEIGHT++] = $ss1035710358;
}
if(R.isPyretException($e1035310354)) {
$e1035310354.pyretStack.push(L[1154]);
}
throw $e1035310354;
}
var $ret1035910360 = $Hanf_arg182310364($z1035510356,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1035910360;
};
var $Hanf_arg182310364 = function(anf_arg46510363,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1036710368 = D;
var $f1037310374 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(anf_arg46510363):R.ffi.throwNonFunApp(L[1155],j_DASH_expr10477,[anf_arg46510363]);
};
try {
if(--R.GAS > 0) {
$z1036710368 = $f1037310374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1037310374,
"from":L[1155]});
}
} catch($e1036510366) {
if(R.isCont($e1036510366)) {
var $ss1036910370 = {"from":L[1155],
"go":function(anf_array_val46610375) {
return $Hanf_array_val182210376(anf_array_val46610375,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1036510366.stack[R.EXN_STACKHEIGHT++] = $ss1036910370;
}
if(R.isPyretException($e1036510366)) {
$e1036510366.pyretStack.push(L[1155]);
}
throw $e1036510366;
}
var $ret1037110372 = $Hanf_array_val182210376($z1036710368,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1037110372;
};
var $Hanf_array_val182210376 = function(anf_array_val46610375,anf_arg46110337,anf_array_val45710300,anf_fun4079876,anf_fun46210351,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1037910380 = D;
var $f1038510386 = function(_) {
return R.isFunction(anf_fun46210351)?anf_fun46210351.app([anf_array_val46610375]):R.ffi.throwNonFunApp(L[1153],anf_fun46210351,[[anf_array_val46610375]]);
};
try {
if(--R.GAS > 0) {
$z1037910380 = $f1038510386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1038510386,
"from":L[1153]});
}
} catch($e1037710378) {
if(R.isCont($e1037710378)) {
var $ss1038110382 = {"from":L[1153],
"go":function(anf_arg46710387) {
return $Hanf_arg182110388(anf_arg46710387,anf_arg46110337,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1037710378.stack[R.EXN_STACKHEIGHT++] = $ss1038110382;
}
if(R.isPyretException($e1037710378)) {
$e1037710378.pyretStack.push(L[1153]);
}
throw $e1037710378;
}
var $ret1038310384 = $Hanf_arg182110388($z1037910380,anf_arg46110337,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1038310384;
};
var $Hanf_arg182110388 = function(anf_arg46710387,anf_arg46110337,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1039110392 = D;
var $f1039710398 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg46710387):R.ffi.throwNonFunApp(L[1156],j_DASH_block8570,[anf_arg46710387]);
};
try {
if(--R.GAS > 0) {
$z1039110392 = $f1039710398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1039710398,
"from":L[1156]});
}
} catch($e1038910390) {
if(R.isCont($e1038910390)) {
var $ss1039310394 = {"from":L[1156],
"go":function(anf_arg46810399) {
return $Hanf_arg182010400(anf_arg46810399,anf_arg46110337,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1038910390.stack[R.EXN_STACKHEIGHT++] = $ss1039310394;
}
if(R.isPyretException($e1038910390)) {
$e1038910390.pyretStack.push(L[1156]);
}
throw $e1038910390;
}
var $ret1039510396 = $Hanf_arg182010400($z1039110392,anf_arg46110337,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1039510396;
};
var $Hanf_arg182010400 = function(anf_arg46810399,anf_arg46110337,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1040310404 = D;
var $f1040910410 = function(_) {
return R.isFunction(j_DASH_if19382)?j_DASH_if19382.app(anf_arg46110337,anf_arg46810399):R.ffi.throwNonFunApp(L[1157],j_DASH_if19382,[anf_arg46110337,anf_arg46810399]);
};
try {
if(--R.GAS > 0) {
$z1040310404 = $f1040910410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1040910410,
"from":L[1157]});
}
} catch($e1040110402) {
if(R.isCont($e1040110402)) {
var $ss1040510406 = {"from":L[1157],
"go":function(anf_array_val46910411) {
return $Hanf_array_val181910412(anf_array_val46910411,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1040110402.stack[R.EXN_STACKHEIGHT++] = $ss1040510406;
}
if(R.isPyretException($e1040110402)) {
$e1040110402.pyretStack.push(L[1157]);
}
throw $e1040110402;
}
var $ret1040710408 = $Hanf_array_val181910412($z1040310404,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1040710408;
};
var $Hanf_array_val181910412 = function(anf_array_val46910411,anf_array_val45710300,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1041510416 = D;
var $f1042110422 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(e2229309):R.ffi.throwNonFunApp(L[1158],j_DASH_id8381,[e2229309]);
};
try {
if(--R.GAS > 0) {
$z1041510416 = $f1042110422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1042110422,
"from":L[1158]});
}
} catch($e1041310414) {
if(R.isCont($e1041310414)) {
var $ss1041710418 = {"from":L[1158],
"go":function(anf_arg47010423) {
return $Hanf_arg181810424(anf_arg47010423,anf_array_val45710300,anf_array_val46910411,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1041310414.stack[R.EXN_STACKHEIGHT++] = $ss1041710418;
}
if(R.isPyretException($e1041310414)) {
$e1041310414.pyretStack.push(L[1158]);
}
throw $e1041310414;
}
var $ret1041910420 = $Hanf_arg181810424($z1041510416,anf_array_val45710300,anf_array_val46910411,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1041910420;
};
var $Hanf_arg181810424 = function(anf_arg47010423,anf_array_val45710300,anf_array_val46910411,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1042710428 = D;
var $f1043310434 = function(_) {
return R.isFunction(j_DASH_throw10395)?j_DASH_throw10395.app(anf_arg47010423):R.ffi.throwNonFunApp(L[1159],j_DASH_throw10395,[anf_arg47010423]);
};
try {
if(--R.GAS > 0) {
$z1042710428 = $f1043310434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1043310434,
"from":L[1159]});
}
} catch($e1042510426) {
if(R.isCont($e1042510426)) {
var $ss1042910430 = {"from":L[1159],
"go":function(anf_array_val47110435) {
return $Hanf_array_val181710436(anf_array_val47110435,anf_array_val45710300,anf_array_val46910411,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1042510426.stack[R.EXN_STACKHEIGHT++] = $ss1042910430;
}
if(R.isPyretException($e1042510426)) {
$e1042510426.pyretStack.push(L[1159]);
}
throw $e1042510426;
}
var $ret1043110432 = $Hanf_array_val181710436($z1042710428,anf_array_val45710300,anf_array_val46910411,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1043110432;
};
var $Hanf_array_val181710436 = function(anf_array_val47110435,anf_array_val45710300,anf_array_val46910411,anf_fun4079876,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1043910440 = D;
var $f1044510446 = function(_) {
return R.isFunction(anf_fun4079876)?anf_fun4079876.app([anf_array_val45710300,anf_array_val46910411,anf_array_val47110435]):R.ffi.throwNonFunApp(L[1105],anf_fun4079876,[[anf_array_val45710300,anf_array_val46910411,anf_array_val47110435]]);
};
try {
if(--R.GAS > 0) {
$z1043910440 = $f1044510446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1044510446,
"from":L[1105]});
}
} catch($e1043710438) {
if(R.isCont($e1043710438)) {
var $ss1044110442 = {"from":L[1105],
"go":function(anf_arg47210447) {
return $Hanf_arg181610448(anf_arg47210447,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1043710438.stack[R.EXN_STACKHEIGHT++] = $ss1044110442;
}
if(R.isPyretException($e1043710438)) {
$e1043710438.pyretStack.push(L[1105]);
}
throw $e1043710438;
}
var $ret1044310444 = $Hanf_arg181610448($z1043910440,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1044310444;
};
var $Hanf_arg181610448 = function(anf_arg47210447,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var $z1045110452 = D;
var $f1045710458 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg47210447):R.ffi.throwNonFunApp(L[1160],j_DASH_block8570,[anf_arg47210447]);
};
try {
if(--R.GAS > 0) {
$z1045110452 = $f1045710458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1045710458,
"from":L[1160]});
}
} catch($e1044910450) {
if(R.isCont($e1044910450)) {
var $ss1045310454 = {"from":L[1160],
"go":function(catch23210459) {
return $Hcatch181510460(catch23210459,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
}};
$e1044910450.stack[R.EXN_STACKHEIGHT++] = $ss1045310454;
}
if(R.isPyretException($e1044910450)) {
$e1044910450.pyretStack.push(L[1160]);
}
throw $e1044910450;
}
var $ret1045510456 = $Hcatch181510460($z1045110452,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5);
++R.GAS;
return $ret1045510456;
};
var $Hcatch181510460 = function(catch23210459,app174659,body2309805,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,undefined117140,z2239333,_plus5) {
var anf_fun47310472 = G(list35101,"make",L[1162]);
var $z1046310464 = D;
var $f1046910470 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(z2239333,undefined117140):R.ffi.throwNonFunApp(L[1161],j_DASH_var8299,[z2239333,undefined117140]);
};
try {
if(--R.GAS > 0) {
$z1046310464 = $f1046910470();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1046910470,
"from":L[1161]});
}
} catch($e1046110462) {
if(R.isCont($e1046110462)) {
var $ss1046510466 = {"from":L[1161],
"go":function(anf_array_val47410471) {
return $Hanf_array_val181410473(anf_array_val47410471,anf_fun47310472,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1046110462.stack[R.EXN_STACKHEIGHT++] = $ss1046510466;
}
if(R.isPyretException($e1046110462)) {
$e1046110462.pyretStack.push(L[1161]);
}
throw $e1046110462;
}
var $ret1046710468 = $Hanf_array_val181410473($z1046310464,anf_fun47310472,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1046710468;
};
var $Hanf_array_val181410473 = function(anf_array_val47410471,anf_fun47310472,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var anf_fun47510484 = G(list35101,"make",L[1163]);
var $z1047610477 = D;
var $f1048210483 = function(_) {
return R.isFunction(anf_fun47510484)?anf_fun47510484.app([("_")]):R.ffi.throwNonFunApp(L[1163],anf_fun47510484,[[("_")]]);
};
try {
if(--R.GAS > 0) {
$z1047610477 = $f1048210483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1048210483,
"from":L[1163]});
}
} catch($e1047410475) {
if(R.isCont($e1047410475)) {
var $ss1047810479 = {"from":L[1163],
"go":function(anf_arg47610485) {
return $Hanf_arg181310486(anf_arg47610485,anf_array_val47410471,anf_fun47310472,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1047410475.stack[R.EXN_STACKHEIGHT++] = $ss1047810479;
}
if(R.isPyretException($e1047410475)) {
$e1047410475.pyretStack.push(L[1163]);
}
throw $e1047410475;
}
var $ret1048010481 = $Hanf_arg181310486($z1047610477,anf_array_val47410471,anf_fun47310472,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1048010481;
};
var $Hanf_arg181310486 = function(anf_arg47610485,anf_array_val47410471,anf_fun47310472,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,compiler2151803,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,l2161804,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var anf_fun47710499 = G(list35101,"make",L[1166]);
var anf_fun47810497 = G(compiler2151803,"get-loc",L[1165]);
var $z1048910490 = D;
var $f1049510496 = function(_) {
return R.isFunction(anf_fun47810497)?anf_fun47810497.app(l2161804):R.ffi.throwNonFunApp(L[1164],anf_fun47810497,[l2161804]);
};
try {
if(--R.GAS > 0) {
$z1048910490 = $f1049510496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1049510496,
"from":L[1164]});
}
} catch($e1048710488) {
if(R.isCont($e1048710488)) {
var $ss1049110492 = {"from":L[1164],
"go":function(anf_arg47910498) {
return $Hanf_arg181210500(anf_arg47910498,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1048710488.stack[R.EXN_STACKHEIGHT++] = $ss1049110492;
}
if(R.isPyretException($e1048710488)) {
$e1048710488.pyretStack.push(L[1164]);
}
throw $e1048710488;
}
var $ret1049310494 = $Hanf_arg181210500($z1048910490,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1049310494;
};
var $Hanf_arg181210500 = function(anf_arg47910498,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,app174659,body2309805,catch23210459,compiled_DASH_args2289432,compiled_DASH_f2279418,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1050310504 = D;
var $f1050910510 = function(_) {
return R.isFunction(app174659.$var)?app174659.$var.app(anf_arg47910498,compiled_DASH_f2279418,compiled_DASH_args2289432):R.ffi.throwNonFunApp(L[1167],app174659.$var,[anf_arg47910498,compiled_DASH_f2279418,compiled_DASH_args2289432]);
};
try {
if(--R.GAS > 0) {
$z1050310504 = $f1050910510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1050910510,
"from":L[1167]});
}
} catch($e1050110502) {
if(R.isCont($e1050110502)) {
var $ss1050510506 = {"from":L[1167],
"go":function(anf_arg48010511) {
return $Hanf_arg181110512(anf_arg48010511,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1050110502.stack[R.EXN_STACKHEIGHT++] = $ss1050510506;
}
if(R.isPyretException($e1050110502)) {
$e1050110502.pyretStack.push(L[1167]);
}
throw $e1050110502;
}
var $ret1050710508 = $Hanf_arg181110512($z1050310504,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1050710508;
};
var $Hanf_arg181110512 = function(anf_arg48010511,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1051510516 = D;
var $f1052110522 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg48010511):R.ffi.throwNonFunApp(L[1168],j_DASH_return9092,[anf_arg48010511]);
};
try {
if(--R.GAS > 0) {
$z1051510516 = $f1052110522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1052110522,
"from":L[1168]});
}
} catch($e1051310514) {
if(R.isCont($e1051310514)) {
var $ss1051710518 = {"from":L[1168],
"go":function(anf_array_val48110523) {
return $Hanf_array_val181010524(anf_array_val48110523,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1051310514.stack[R.EXN_STACKHEIGHT++] = $ss1051710518;
}
if(R.isPyretException($e1051310514)) {
$e1051310514.pyretStack.push(L[1168]);
}
throw $e1051310514;
}
var $ret1051910520 = $Hanf_array_val181010524($z1051510516,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1051910520;
};
var $Hanf_array_val181010524 = function(anf_array_val48110523,anf_arg47610485,anf_array_val47410471,anf_fun47310472,anf_fun47710499,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1052710528 = D;
var $f1053310534 = function(_) {
return R.isFunction(anf_fun47710499)?anf_fun47710499.app([anf_array_val48110523]):R.ffi.throwNonFunApp(L[1166],anf_fun47710499,[[anf_array_val48110523]]);
};
try {
if(--R.GAS > 0) {
$z1052710528 = $f1053310534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1053310534,
"from":L[1166]});
}
} catch($e1052510526) {
if(R.isCont($e1052510526)) {
var $ss1052910530 = {"from":L[1166],
"go":function(anf_arg48210535) {
return $Hanf_arg180910536(anf_arg48210535,anf_arg47610485,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1052510526.stack[R.EXN_STACKHEIGHT++] = $ss1052910530;
}
if(R.isPyretException($e1052510526)) {
$e1052510526.pyretStack.push(L[1166]);
}
throw $e1052510526;
}
var $ret1053110532 = $Hanf_arg180910536($z1052710528,anf_arg47610485,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1053110532;
};
var $Hanf_arg180910536 = function(anf_arg48210535,anf_arg47610485,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1053910540 = D;
var $f1054510546 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg48210535):R.ffi.throwNonFunApp(L[1169],j_DASH_block8570,[anf_arg48210535]);
};
try {
if(--R.GAS > 0) {
$z1053910540 = $f1054510546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1054510546,
"from":L[1169]});
}
} catch($e1053710538) {
if(R.isCont($e1053710538)) {
var $ss1054110542 = {"from":L[1169],
"go":function(anf_arg48310547) {
return $Hanf_arg180810548(anf_arg48310547,anf_arg47610485,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1053710538.stack[R.EXN_STACKHEIGHT++] = $ss1054110542;
}
if(R.isPyretException($e1053710538)) {
$e1053710538.pyretStack.push(L[1169]);
}
throw $e1053710538;
}
var $ret1054310544 = $Hanf_arg180810548($z1053910540,anf_arg47610485,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1054310544;
};
var $Hanf_arg180810548 = function(anf_arg48310547,anf_arg47610485,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_fun8180,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1055110552 = D;
var $f1055710558 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg47610485,anf_arg48310547):R.ffi.throwNonFunApp(L[1170],j_DASH_fun8180,[anf_arg47610485,anf_arg48310547]);
};
try {
if(--R.GAS > 0) {
$z1055110552 = $f1055710558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1055710558,
"from":L[1170]});
}
} catch($e1054910550) {
if(R.isCont($e1054910550)) {
var $ss1055310554 = {"from":L[1170],
"go":function(anf_arg48410559) {
return $Hanf_arg180710560(anf_arg48410559,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1054910550.stack[R.EXN_STACKHEIGHT++] = $ss1055310554;
}
if(R.isPyretException($e1054910550)) {
$e1054910550.pyretStack.push(L[1170]);
}
throw $e1054910550;
}
var $ret1055510556 = $Hanf_arg180710560($z1055110552,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1055510556;
};
var $Hanf_arg180710560 = function(anf_arg48410559,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,f_DASH_app2269405,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1056310564 = D;
var $f1056910570 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(f_DASH_app2269405,anf_arg48410559):R.ffi.throwNonFunApp(L[1171],j_DASH_var8299,[f_DASH_app2269405,anf_arg48410559]);
};
try {
if(--R.GAS > 0) {
$z1056310564 = $f1056910570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1056910570,
"from":L[1171]});
}
} catch($e1056110562) {
if(R.isCont($e1056110562)) {
var $ss1056510566 = {"from":L[1171],
"go":function(anf_array_val48510571) {
return $Hanf_array_val180610572(anf_array_val48510571,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1056110562.stack[R.EXN_STACKHEIGHT++] = $ss1056510566;
}
if(R.isPyretException($e1056110562)) {
$e1056110562.pyretStack.push(L[1171]);
}
throw $e1056110562;
}
var $ret1056710568 = $Hanf_array_val180610572($z1056310564,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1056710568;
};
var $Hanf_array_val180610572 = function(anf_array_val48510571,anf_array_val47410471,anf_fun47310472,body2309805,catch23210459,compiled_DASH_helper_DASH_args2299460,e2229309,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1057510576 = D;
var $f1058110582 = function(_) {
return R.isFunction(j_DASH_try_DASH_catch10297)?j_DASH_try_DASH_catch10297.app(body2309805,e2229309,catch23210459):R.ffi.throwNonFunApp(L[1172],j_DASH_try_DASH_catch10297,[body2309805,e2229309,catch23210459]);
};
try {
if(--R.GAS > 0) {
$z1057510576 = $f1058110582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1058110582,
"from":L[1172]});
}
} catch($e1057310574) {
if(R.isCont($e1057310574)) {
var $ss1057710578 = {"from":L[1172],
"go":function(anf_array_val48610583) {
return $Hanf_array_val180510584(anf_array_val48610583,anf_array_val47410471,anf_array_val48510571,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1057310574.stack[R.EXN_STACKHEIGHT++] = $ss1057710578;
}
if(R.isPyretException($e1057310574)) {
$e1057310574.pyretStack.push(L[1172]);
}
throw $e1057310574;
}
var $ret1057910580 = $Hanf_array_val180510584($z1057510576,anf_array_val47410471,anf_array_val48510571,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1057910580;
};
var $Hanf_array_val180510584 = function(anf_array_val48610583,anf_array_val47410471,anf_array_val48510571,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,helper_DASH_name177665,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,name2201808,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1058710588 = D;
var $f1059310594 = function(_) {
return R.isFunction(helper_DASH_name177665.$var)?helper_DASH_name177665.$var.app(name2201808):R.ffi.throwNonFunApp(L[1173],helper_DASH_name177665.$var,[name2201808]);
};
try {
if(--R.GAS > 0) {
$z1058710588 = $f1059310594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1059310594,
"from":L[1173]});
}
} catch($e1058510586) {
if(R.isCont($e1058510586)) {
var $ss1058910590 = {"from":L[1173],
"go":function(anf_arg48710595) {
return $Hanf_arg180410596(anf_arg48710595,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1058510586.stack[R.EXN_STACKHEIGHT++] = $ss1058910590;
}
if(R.isPyretException($e1058510586)) {
$e1058510586.pyretStack.push(L[1173]);
}
throw $e1058510586;
}
var $ret1059110592 = $Hanf_arg180410596($z1058710588,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1059110592;
};
var $Hanf_arg180410596 = function(anf_arg48710595,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var $z1059910600 = D;
var $f1060510606 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(anf_arg48710595):R.ffi.throwNonFunApp(L[1174],j_DASH_id8381,[anf_arg48710595]);
};
try {
if(--R.GAS > 0) {
$z1059910600 = $f1060510606();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1060510606,
"from":L[1174]});
}
} catch($e1059710598) {
if(R.isCont($e1059710598)) {
var $ss1060110602 = {"from":L[1174],
"go":function(anf_arg48810607) {
return $Hanf_arg180310608(anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,ret2259381,rt_DASH_field172655,z2239333,_plus5);
}};
$e1059710598.stack[R.EXN_STACKHEIGHT++] = $ss1060110602;
}
if(R.isPyretException($e1059710598)) {
$e1059710598.pyretStack.push(L[1174]);
}
throw $e1059710598;
}
var $ret1060310604 = $Hanf_arg180310608($z1059910600,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,ret2259381,rt_DASH_field172655,z2239333,_plus5);
++R.GAS;
return $ret1060310604;
};
var $Hanf_arg180310608 = function(anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,list35101,ret2259381,rt_DASH_field172655,z2239333,_plus5) {
var anf_fun48910620 = G(list35101,"make",L[1176]);
var $z1061110612 = D;
var $f1061710618 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(z2239333):R.ffi.throwNonFunApp(L[1175],j_DASH_id8381,[z2239333]);
};
try {
if(--R.GAS > 0) {
$z1061110612 = $f1061710618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1061710618,
"from":L[1175]});
}
} catch($e1060910610) {
if(R.isCont($e1060910610)) {
var $ss1061310614 = {"from":L[1175],
"go":function(anf_array_val49010619) {
return $Hanf_array_val180210621(anf_array_val49010619,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,anf_fun48910620,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655,_plus5);
}};
$e1060910610.stack[R.EXN_STACKHEIGHT++] = $ss1061310614;
}
if(R.isPyretException($e1060910610)) {
$e1060910610.pyretStack.push(L[1175]);
}
throw $e1060910610;
}
var $ret1061510616 = $Hanf_array_val180210621($z1061110612,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,anf_fun48910620,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655,_plus5);
++R.GAS;
return $ret1061510616;
};
var $Hanf_array_val180210621 = function(anf_array_val49010619,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,anf_fun48910620,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655,_plus5) {
var $z1062410625 = D;
var $f1063010631 = function(_) {
return R.isFunction(anf_fun48910620)?anf_fun48910620.app([anf_array_val49010619]):R.ffi.throwNonFunApp(L[1176],anf_fun48910620,[[anf_array_val49010619]]);
};
try {
if(--R.GAS > 0) {
$z1062410625 = $f1063010631();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1063010631,
"from":L[1176]});
}
} catch($e1062210623) {
if(R.isCont($e1062210623)) {
var $ss1062610627 = {"from":L[1176],
"go":function(anf_arg49110632) {
return $Hanf_arg180110633(anf_arg49110632,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655,_plus5);
}};
$e1062210623.stack[R.EXN_STACKHEIGHT++] = $ss1062610627;
}
if(R.isPyretException($e1062210623)) {
$e1062210623.pyretStack.push(L[1176]);
}
throw $e1062210623;
}
var $ret1062810629 = $Hanf_arg180110633($z1062410625,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655,_plus5);
++R.GAS;
return $ret1062810629;
};
var $Hanf_arg180110633 = function(anf_arg49110632,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,compiled_DASH_helper_DASH_args2299460,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655,_plus5) {
var anf_arg49210644 = G(compiled_DASH_helper_DASH_args2299460,"rest",L[1178]);
var $z1063610637 = D;
var $f1064210643 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg49110632,anf_arg49210644):R.ffi.throwNonFunApp(L[1177],_plus5,[anf_arg49110632,anf_arg49210644]);
};
try {
if(--R.GAS > 0) {
$z1063610637 = $f1064210643();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1064210643,
"from":L[1177]});
}
} catch($e1063410635) {
if(R.isCont($e1063410635)) {
var $ss1063810639 = {"from":L[1177],
"go":function(anf_arg49310645) {
return $Hanf_arg180010646(anf_arg49310645,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655);
}};
$e1063410635.stack[R.EXN_STACKHEIGHT++] = $ss1063810639;
}
if(R.isPyretException($e1063410635)) {
$e1063410635.pyretStack.push(L[1177]);
}
throw $e1063410635;
}
var $ret1064010641 = $Hanf_arg180010646($z1063610637,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655);
++R.GAS;
return $ret1064010641;
};
var $Hanf_arg180010646 = function(anf_arg49310645,anf_arg48810607,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_app9467,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655) {
var $z1064910650 = D;
var $f1065510656 = function(_) {
return R.isFunction(j_DASH_app9467)?j_DASH_app9467.app(anf_arg48810607,anf_arg49310645):R.ffi.throwNonFunApp(L[1179],j_DASH_app9467,[anf_arg48810607,anf_arg49310645]);
};
try {
if(--R.GAS > 0) {
$z1064910650 = $f1065510656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1065510656,
"from":L[1179]});
}
} catch($e1064710648) {
if(R.isCont($e1064710648)) {
var $ss1065110652 = {"from":L[1179],
"go":function(anf_arg49410657) {
return $Hanf_arg179910658(anf_arg49410657,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655);
}};
$e1064710648.stack[R.EXN_STACKHEIGHT++] = $ss1065110652;
}
if(R.isPyretException($e1064710648)) {
$e1064710648.pyretStack.push(L[1179]);
}
throw $e1064710648;
}
var $ret1065310654 = $Hanf_arg179910658($z1064910650,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655);
++R.GAS;
return $ret1065310654;
};
var $Hanf_arg179910658 = function(anf_arg49410657,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,j_DASH_var8299,ret2259381,rt_DASH_field172655) {
var $z1066110662 = D;
var $f1066710668 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(ret2259381,anf_arg49410657):R.ffi.throwNonFunApp(L[1180],j_DASH_var8299,[ret2259381,anf_arg49410657]);
};
try {
if(--R.GAS > 0) {
$z1066110662 = $f1066710668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1066710668,
"from":L[1180]});
}
} catch($e1065910660) {
if(R.isCont($e1065910660)) {
var $ss1066310664 = {"from":L[1180],
"go":function(anf_array_val49510669) {
return $Hanf_array_val179810670(anf_array_val49510669,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,ret2259381,rt_DASH_field172655);
}};
$e1065910660.stack[R.EXN_STACKHEIGHT++] = $ss1066310664;
}
if(R.isPyretException($e1065910660)) {
$e1065910660.pyretStack.push(L[1180]);
}
throw $e1065910660;
}
var $ret1066510666 = $Hanf_array_val179810670($z1066110662,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,ret2259381,rt_DASH_field172655);
++R.GAS;
return $ret1066510666;
};
var $Hanf_array_val179810670 = function(anf_array_val49510669,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,ret2259381,rt_DASH_field172655) {
var $z1067310674 = D;
var $f1067910680 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("GAS")):R.ffi.throwNonFunApp(L[1181],rt_DASH_field172655.$var,[("GAS")]);
};
try {
if(--R.GAS > 0) {
$z1067310674 = $f1067910680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1067910680,
"from":L[1181]});
}
} catch($e1067110672) {
if(R.isCont($e1067110672)) {
var $ss1067510676 = {"from":L[1181],
"go":function(anf_arg49610681) {
return $Hanf_arg179710682(anf_arg49610681,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,ret2259381);
}};
$e1067110672.stack[R.EXN_STACKHEIGHT++] = $ss1067510676;
}
if(R.isPyretException($e1067110672)) {
$e1067110672.pyretStack.push(L[1181]);
}
throw $e1067110672;
}
var $ret1067710678 = $Hanf_arg179710682($z1067310674,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,ret2259381);
++R.GAS;
return $ret1067710678;
};
var $Hanf_arg179710682 = function(anf_arg49610681,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,ret2259381) {
var $z1068510686 = D;
var $f1069110692 = function(_) {
return R.isFunction(j_DASH_unop10898)?j_DASH_unop10898.app(anf_arg49610681,j_DASH_incr11084):R.ffi.throwNonFunApp(L[1182],j_DASH_unop10898,[anf_arg49610681,j_DASH_incr11084]);
};
try {
if(--R.GAS > 0) {
$z1068510686 = $f1069110692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1069110692,
"from":L[1182]});
}
} catch($e1068310684) {
if(R.isCont($e1068310684)) {
var $ss1068710688 = {"from":L[1182],
"go":function(anf_arg49710693) {
return $Hanf_arg179610694(anf_arg49710693,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_return9092,ret2259381);
}};
$e1068310684.stack[R.EXN_STACKHEIGHT++] = $ss1068710688;
}
if(R.isPyretException($e1068310684)) {
$e1068310684.pyretStack.push(L[1182]);
}
throw $e1068310684;
}
var $ret1068910690 = $Hanf_arg179610694($z1068510686,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_return9092,ret2259381);
++R.GAS;
return $ret1068910690;
};
var $Hanf_arg179610694 = function(anf_arg49710693,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_return9092,ret2259381) {
var $z1069710698 = D;
var $f1070310704 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(anf_arg49710693):R.ffi.throwNonFunApp(L[1183],j_DASH_expr10477,[anf_arg49710693]);
};
try {
if(--R.GAS > 0) {
$z1069710698 = $f1070310704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1070310704,
"from":L[1183]});
}
} catch($e1069510696) {
if(R.isCont($e1069510696)) {
var $ss1069910700 = {"from":L[1183],
"go":function(anf_array_val49810705) {
return $Hanf_array_val179510706(anf_array_val49810705,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,ret2259381);
}};
$e1069510696.stack[R.EXN_STACKHEIGHT++] = $ss1069910700;
}
if(R.isPyretException($e1069510696)) {
$e1069510696.pyretStack.push(L[1183]);
}
throw $e1069510696;
}
var $ret1070110702 = $Hanf_array_val179510706($z1069710698,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,ret2259381);
++R.GAS;
return $ret1070110702;
};
var $Hanf_array_val179510706 = function(anf_array_val49810705,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_fun47310472,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,ret2259381) {
var $z1070910710 = D;
var $f1071510716 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(ret2259381):R.ffi.throwNonFunApp(L[1184],j_DASH_id8381,[ret2259381]);
};
try {
if(--R.GAS > 0) {
$z1070910710 = $f1071510716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1071510716,
"from":L[1184]});
}
} catch($e1070710708) {
if(R.isCont($e1070710708)) {
var $ss1071110712 = {"from":L[1184],
"go":function(anf_arg49910717) {
return $Hanf_arg179410718(anf_arg49910717,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_array_val49810705,anf_fun47310472,j_DASH_block8570,j_DASH_return9092);
}};
$e1070710708.stack[R.EXN_STACKHEIGHT++] = $ss1071110712;
}
if(R.isPyretException($e1070710708)) {
$e1070710708.pyretStack.push(L[1184]);
}
throw $e1070710708;
}
var $ret1071310714 = $Hanf_arg179410718($z1070910710,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_array_val49810705,anf_fun47310472,j_DASH_block8570,j_DASH_return9092);
++R.GAS;
return $ret1071310714;
};
var $Hanf_arg179410718 = function(anf_arg49910717,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_array_val49810705,anf_fun47310472,j_DASH_block8570,j_DASH_return9092) {
var $z1072110722 = D;
var $f1072710728 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg49910717):R.ffi.throwNonFunApp(L[1185],j_DASH_return9092,[anf_arg49910717]);
};
try {
if(--R.GAS > 0) {
$z1072110722 = $f1072710728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1072710728,
"from":L[1185]});
}
} catch($e1071910720) {
if(R.isCont($e1071910720)) {
var $ss1072310724 = {"from":L[1185],
"go":function(anf_array_val50010729) {
return $Hanf_array_val179310730(anf_array_val50010729,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_array_val49810705,anf_fun47310472,j_DASH_block8570);
}};
$e1071910720.stack[R.EXN_STACKHEIGHT++] = $ss1072310724;
}
if(R.isPyretException($e1071910720)) {
$e1071910720.pyretStack.push(L[1185]);
}
throw $e1071910720;
}
var $ret1072510726 = $Hanf_array_val179310730($z1072110722,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_array_val49810705,anf_fun47310472,j_DASH_block8570);
++R.GAS;
return $ret1072510726;
};
var $Hanf_array_val179310730 = function(anf_array_val50010729,anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_array_val49810705,anf_fun47310472,j_DASH_block8570) {
var $z1073310734 = D;
var $f1073910740 = function(_) {
return R.isFunction(anf_fun47310472)?anf_fun47310472.app([anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_array_val49810705,anf_array_val50010729]):R.ffi.throwNonFunApp(L[1162],anf_fun47310472,[[anf_array_val47410471,anf_array_val48510571,anf_array_val48610583,anf_array_val49510669,anf_array_val49810705,anf_array_val50010729]]);
};
try {
if(--R.GAS > 0) {
$z1073310734 = $f1073910740();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1073910740,
"from":L[1162]});
}
} catch($e1073110732) {
if(R.isCont($e1073110732)) {
var $ss1073510736 = {"from":L[1162],
"go":function(anf_arg50110741) {
return $Hanf_arg179210742(anf_arg50110741,j_DASH_block8570);
}};
$e1073110732.stack[R.EXN_STACKHEIGHT++] = $ss1073510736;
}
if(R.isPyretException($e1073110732)) {
$e1073110732.pyretStack.push(L[1162]);
}
throw $e1073110732;
}
var $ret1073710738 = $Hanf_arg179210742($z1073310734,j_DASH_block8570);
++R.GAS;
return $ret1073710738;
};
var $Hanf_arg179210742 = function(anf_arg50110741,j_DASH_block8570) {
var $z1074510746 = D;
var $f1075110752 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg50110741):R.ffi.throwNonFunApp(L[300],j_DASH_block8570,[anf_arg50110741]);
};
try {
if(--R.GAS > 0) {
$z1074510746 = $f1075110752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1075110752,
"from":L[300]});
}
} catch($e1074310744) {
if(R.isCont($e1074310744)) {
var $ss1074710748 = {"from":L[300],
"go":function(ann_DASH_check_DASH_temp34610753) {
return $Hann_DASH_check_DASH_temp179110754(ann_DASH_check_DASH_temp34610753);
}};
$e1074310744.stack[R.EXN_STACKHEIGHT++] = $ss1074710748;
}
if(R.isPyretException($e1074310744)) {
$e1074310744.pyretStack.push(L[300]);
}
throw $e1074310744;
}
var $ret1074910750 = $Hann_DASH_check_DASH_temp179110754($z1074510746);
++R.GAS;
return $ret1074910750;
};
var $Hann_DASH_check_DASH_temp179110754 = function(ann_DASH_check_DASH_temp34610753) {
return ann_DASH_check_DASH_temp34610753;
};
var $Hann_DASH_check_DASH_temp179010060 = function(ann_DASH_check_DASH_temp43410059) {
return ann_DASH_check_DASH_temp43410059;
};
var $Hann_DASH_check_DASH_temp17899851 = function(ann_DASH_check_DASH_temp4029850) {
return ann_DASH_check_DASH_temp4029850;
};
var $Hann_DASH_check_DASH_temp17889475 = function(ann_DASH_check_DASH_temp3609474) {
return ann_DASH_check_DASH_temp3609474;
};
var $Hann_DASH_check_DASH_temp17879447 = function(ann_DASH_check_DASH_temp3569446) {
return ann_DASH_check_DASH_temp3569446;
};
var $Hanf_arg17861868 = function(anf_arg2901867,J721,app174659,args2101856,compiler2071853,f2091855,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657) {
var $z1075710758 = D;
var $f1076310764 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg2901867):R.ffi.throwNonFunApp(L[1186],js_DASH_id_DASH_of162700,[anf_arg2901867]);
};
try {
if(--R.GAS > 0) {
$z1075710758 = $f1076310764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1076310764,
"from":L[1186]});
}
} catch($e1075510756) {
if(R.isCont($e1075510756)) {
var $ss1075910760 = {"from":L[1186],
"go":function(z21110765) {
return $Hz178510766(z21110765,J721,app174659,args2101856,compiler2071853,f2091855,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657);
}};
$e1075510756.stack[R.EXN_STACKHEIGHT++] = $ss1075910760;
}
if(R.isPyretException($e1075510756)) {
$e1075510756.pyretStack.push(L[1186]);
}
throw $e1075510756;
}
var $ret1076110762 = $Hz178510766($z1075710758,J721,app174659,args2101856,compiler2071853,f2091855,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657);
++R.GAS;
return $ret1076110762;
};
var $Hz178510766 = function(z21110765,J721,app174659,args2101856,compiler2071853,f2091855,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657) {
var anf_fun29110777 = G(f2091855,"visit",L[1188]);
var $z1076910770 = D;
var $f1077510776 = function(_) {
return R.isFunction(anf_fun29110777)?anf_fun29110777.app(compiler2071853):R.ffi.throwNonFunApp(L[1187],anf_fun29110777,[compiler2071853]);
};
try {
if(--R.GAS > 0) {
$z1076910770 = $f1077510776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1077510776,
"from":L[1187]});
}
} catch($e1076710768) {
if(R.isCont($e1076710768)) {
var $ss1077110772 = {"from":L[1187],
"go":function(compiled_DASH_f21210778) {
return $Hcompiled_DASH_f178410779(compiled_DASH_f21210778,J721,app174659,args2101856,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1076710768.stack[R.EXN_STACKHEIGHT++] = $ss1077110772;
}
if(R.isPyretException($e1076710768)) {
$e1076710768.pyretStack.push(L[1187]);
}
throw $e1076710768;
}
var $ret1077310774 = $Hcompiled_DASH_f178410779($z1076910770,J721,app174659,args2101856,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1077310774;
};
var $Hcompiled_DASH_f178410779 = function(compiled_DASH_f21210778,J721,app174659,args2101856,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var anf_fun29210790 = G(args2101856,"map",L[1191]);
var anf_arg29510791 = R.makeFunction(function(recv_DASH_3510794) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1190],1,arguments);
}
var anf_fun29410805 = G(recv_DASH_3510794,"visit",L[1190]);
var $z1079710798 = D;
var $f1080310804 = function(_) {
return R.isFunction(anf_fun29410805)?anf_fun29410805.app(compiler2071853):R.ffi.throwNonFunApp(L[1190],anf_fun29410805,[compiler2071853]);
};
try {
if(--R.GAS > 0) {
$z1079710798 = $f1080310804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1080310804,
"from":L[1190]});
}
} catch($e1079510796) {
if(R.isCont($e1079510796)) {
var $ss1079910800 = {"from":L[1190],
"go":function(ann_DASH_check_DASH_temp29310806) {
return $Hann_DASH_check_DASH_temp174210807(ann_DASH_check_DASH_temp29310806);
}};
$e1079510796.stack[R.EXN_STACKHEIGHT++] = $ss1079910800;
}
if(R.isPyretException($e1079510796)) {
$e1079510796.pyretStack.push(L[1190]);
}
throw $e1079510796;
}
var $ret1080110802 = $Hann_DASH_check_DASH_temp174210807($z1079710798);
++R.GAS;
return $ret1080110802;
});
var $z1078210783 = D;
var $f1078810789 = function(_) {
return R.isFunction(anf_fun29210790)?anf_fun29210790.app(anf_arg29510791):R.ffi.throwNonFunApp(L[1189],anf_fun29210790,[anf_arg29510791]);
};
try {
if(--R.GAS > 0) {
$z1078210783 = $f1078810789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1078810789,
"from":L[1189]});
}
} catch($e1078010781) {
if(R.isCont($e1078010781)) {
var $ss1078410785 = {"from":L[1189],
"go":function(compiled_DASH_args21310792) {
return $Hcompiled_DASH_args178310793(compiled_DASH_args21310792,J721,app174659,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1078010781.stack[R.EXN_STACKHEIGHT++] = $ss1078410785;
}
if(R.isPyretException($e1078010781)) {
$e1078010781.pyretStack.push(L[1189]);
}
throw $e1078010781;
}
var $ret1078610787 = $Hcompiled_DASH_args178310793($z1078210783,J721,app174659,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1078610787;
};
var $Hcompiled_DASH_args178310793 = function(compiled_DASH_args21310792,J721,app174659,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1081010811 = D;
var $f1081610817 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("GAS")):R.ffi.throwNonFunApp(L[1192],rt_DASH_field172655.$var,[("GAS")]);
};
try {
if(--R.GAS > 0) {
$z1081010811 = $f1081610817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1081610817,
"from":L[1192]});
}
} catch($e1080810809) {
if(R.isCont($e1080810809)) {
var $ss1081210813 = {"from":L[1192],
"go":function(anf_arg29610818) {
return $Hanf_arg178210819(anf_arg29610818,J721,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1080810809.stack[R.EXN_STACKHEIGHT++] = $ss1081210813;
}
if(R.isPyretException($e1080810809)) {
$e1080810809.pyretStack.push(L[1192]);
}
throw $e1080810809;
}
var $ret1081410815 = $Hanf_arg178210819($z1081010811,J721,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1081410815;
};
var $Hanf_arg178210819 = function(anf_arg29610818,J721,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1082210823 = D;
var $f1082810829 = function(_) {
return R.isFunction(j_DASH_unop10898)?j_DASH_unop10898.app(anf_arg29610818,j_DASH_decr10973):R.ffi.throwNonFunApp(L[1193],j_DASH_unop10898,[anf_arg29610818,j_DASH_decr10973]);
};
try {
if(--R.GAS > 0) {
$z1082210823 = $f1082810829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1082810829,
"from":L[1193]});
}
} catch($e1082010821) {
if(R.isCont($e1082010821)) {
var $ss1082410825 = {"from":L[1193],
"go":function(anf_arg29710830) {
return $Hanf_arg178110831(anf_arg29710830,J721,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1082010821.stack[R.EXN_STACKHEIGHT++] = $ss1082410825;
}
if(R.isPyretException($e1082010821)) {
$e1082010821.pyretStack.push(L[1193]);
}
throw $e1082010821;
}
var $ret1082610827 = $Hanf_arg178110831($z1082210823,J721,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1082610827;
};
var $Hanf_arg178110831 = function(anf_arg29710830,J721,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var anf_arg29810843 = G(J721,"j-gt",L[1195]);
var $z1083410835 = D;
var $f1084010841 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app((0)):R.ffi.throwNonFunApp(L[1194],j_DASH_num8889,[(0)]);
};
try {
if(--R.GAS > 0) {
$z1083410835 = $f1084010841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1084010841,
"from":L[1194]});
}
} catch($e1083210833) {
if(R.isCont($e1083210833)) {
var $ss1083610837 = {"from":L[1194],
"go":function(anf_arg29910842) {
return $Hanf_arg178010844(anf_arg29910842,anf_arg29710830,anf_arg29810843,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1083210833.stack[R.EXN_STACKHEIGHT++] = $ss1083610837;
}
if(R.isPyretException($e1083210833)) {
$e1083210833.pyretStack.push(L[1194]);
}
throw $e1083210833;
}
var $ret1083810839 = $Hanf_arg178010844($z1083410835,anf_arg29710830,anf_arg29810843,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1083810839;
};
var $Hanf_arg178010844 = function(anf_arg29910842,anf_arg29710830,anf_arg29810843,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1084710848 = D;
var $f1085310854 = function(_) {
return R.isFunction(j_DASH_binop10569)?j_DASH_binop10569.app(anf_arg29710830,anf_arg29810843,anf_arg29910842):R.ffi.throwNonFunApp(L[1196],j_DASH_binop10569,[anf_arg29710830,anf_arg29810843,anf_arg29910842]);
};
try {
if(--R.GAS > 0) {
$z1084710848 = $f1085310854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1085310854,
"from":L[1196]});
}
} catch($e1084510846) {
if(R.isCont($e1084510846)) {
var $ss1084910850 = {"from":L[1196],
"go":function(anf_arg30010855) {
return $Hanf_arg177910856(anf_arg30010855,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1084510846.stack[R.EXN_STACKHEIGHT++] = $ss1084910850;
}
if(R.isPyretException($e1084510846)) {
$e1084510846.pyretStack.push(L[1196]);
}
throw $e1084510846;
}
var $ret1085110852 = $Hanf_arg177910856($z1084710848,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1085110852;
};
var $Hanf_arg177910856 = function(anf_arg30010855,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var anf_fun30110869 = G(list35101,"make",L[1199]);
var anf_fun30210867 = G(compiler2071853,"get-loc",L[1198]);
var $z1085910860 = D;
var $f1086510866 = function(_) {
return R.isFunction(anf_fun30210867)?anf_fun30210867.app(l2081854):R.ffi.throwNonFunApp(L[1197],anf_fun30210867,[l2081854]);
};
try {
if(--R.GAS > 0) {
$z1085910860 = $f1086510866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1086510866,
"from":L[1197]});
}
} catch($e1085710858) {
if(R.isCont($e1085710858)) {
var $ss1086110862 = {"from":L[1197],
"go":function(anf_arg30310868) {
return $Hanf_arg177810870(anf_arg30310868,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1085710858.stack[R.EXN_STACKHEIGHT++] = $ss1086110862;
}
if(R.isPyretException($e1085710858)) {
$e1085710858.pyretStack.push(L[1197]);
}
throw $e1085710858;
}
var $ret1086310864 = $Hanf_arg177810870($z1085910860,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1086310864;
};
var $Hanf_arg177810870 = function(anf_arg30310868,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1087310874 = D;
var $f1087910880 = function(_) {
return R.isFunction(app174659.$var)?app174659.$var.app(anf_arg30310868,compiled_DASH_f21210778,compiled_DASH_args21310792):R.ffi.throwNonFunApp(L[1200],app174659.$var,[anf_arg30310868,compiled_DASH_f21210778,compiled_DASH_args21310792]);
};
try {
if(--R.GAS > 0) {
$z1087310874 = $f1087910880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1087910880,
"from":L[1200]});
}
} catch($e1087110872) {
if(R.isCont($e1087110872)) {
var $ss1087510876 = {"from":L[1200],
"go":function(anf_arg30410881) {
return $Hanf_arg177710882(anf_arg30410881,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1087110872.stack[R.EXN_STACKHEIGHT++] = $ss1087510876;
}
if(R.isPyretException($e1087110872)) {
$e1087110872.pyretStack.push(L[1200]);
}
throw $e1087110872;
}
var $ret1087710878 = $Hanf_arg177710882($z1087310874,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1087710878;
};
var $Hanf_arg177710882 = function(anf_arg30410881,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_assign9168,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1088510886 = D;
var $f1089110892 = function(_) {
return R.isFunction(j_DASH_assign9168)?j_DASH_assign9168.app(z21110765,anf_arg30410881):R.ffi.throwNonFunApp(L[1201],j_DASH_assign9168,[z21110765,anf_arg30410881]);
};
try {
if(--R.GAS > 0) {
$z1088510886 = $f1089110892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1089110892,
"from":L[1201]});
}
} catch($e1088310884) {
if(R.isCont($e1088310884)) {
var $ss1088710888 = {"from":L[1201],
"go":function(anf_arg30510893) {
return $Hanf_arg177610894(anf_arg30510893,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1088310884.stack[R.EXN_STACKHEIGHT++] = $ss1088710888;
}
if(R.isPyretException($e1088310884)) {
$e1088310884.pyretStack.push(L[1201]);
}
throw $e1088310884;
}
var $ret1088910890 = $Hanf_arg177610894($z1088510886,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1088910890;
};
var $Hanf_arg177610894 = function(anf_arg30510893,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1089710898 = D;
var $f1090310904 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(anf_arg30510893):R.ffi.throwNonFunApp(L[1202],j_DASH_expr10477,[anf_arg30510893]);
};
try {
if(--R.GAS > 0) {
$z1089710898 = $f1090310904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1090310904,
"from":L[1202]});
}
} catch($e1089510896) {
if(R.isCont($e1089510896)) {
var $ss1089910900 = {"from":L[1202],
"go":function(anf_array_val30610905) {
return $Hanf_array_val177510906(anf_array_val30610905,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1089510896.stack[R.EXN_STACKHEIGHT++] = $ss1089910900;
}
if(R.isPyretException($e1089510896)) {
$e1089510896.pyretStack.push(L[1202]);
}
throw $e1089510896;
}
var $ret1090110902 = $Hanf_array_val177510906($z1089710898,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1090110902;
};
var $Hanf_array_val177510906 = function(anf_array_val30610905,anf_arg30010855,anf_fun30110869,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1090910910 = D;
var $f1091510916 = function(_) {
return R.isFunction(anf_fun30110869)?anf_fun30110869.app([anf_array_val30610905]):R.ffi.throwNonFunApp(L[1199],anf_fun30110869,[[anf_array_val30610905]]);
};
try {
if(--R.GAS > 0) {
$z1090910910 = $f1091510916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1091510916,
"from":L[1199]});
}
} catch($e1090710908) {
if(R.isCont($e1090710908)) {
var $ss1091110912 = {"from":L[1199],
"go":function(anf_arg30710917) {
return $Hanf_arg177410918(anf_arg30710917,anf_arg30010855,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1090710908.stack[R.EXN_STACKHEIGHT++] = $ss1091110912;
}
if(R.isPyretException($e1090710908)) {
$e1090710908.pyretStack.push(L[1199]);
}
throw $e1090710908;
}
var $ret1091310914 = $Hanf_arg177410918($z1090910910,anf_arg30010855,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1091310914;
};
var $Hanf_arg177410918 = function(anf_arg30710917,anf_arg30010855,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1092110922 = D;
var $f1092710928 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg30710917):R.ffi.throwNonFunApp(L[1203],j_DASH_block8570,[anf_arg30710917]);
};
try {
if(--R.GAS > 0) {
$z1092110922 = $f1092710928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1092710928,
"from":L[1203]});
}
} catch($e1091910920) {
if(R.isCont($e1091910920)) {
var $ss1092310924 = {"from":L[1203],
"go":function(anf_arg30810929) {
return $Hanf_arg177310930(anf_arg30810929,anf_arg30010855,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1091910920.stack[R.EXN_STACKHEIGHT++] = $ss1092310924;
}
if(R.isPyretException($e1091910920)) {
$e1091910920.pyretStack.push(L[1203]);
}
throw $e1091910920;
}
var $ret1092510926 = $Hanf_arg177310930($z1092110922,anf_arg30010855,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1092510926;
};
var $Hanf_arg177310930 = function(anf_arg30810929,anf_arg30010855,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var anf_fun30910942 = G(list35101,"make",L[1205]);
var $z1093310934 = D;
var $f1093910940 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("R")):R.ffi.throwNonFunApp(L[1204],j_DASH_id8381,[("R")]);
};
try {
if(--R.GAS > 0) {
$z1093310934 = $f1093910940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1093910940,
"from":L[1204]});
}
} catch($e1093110932) {
if(R.isCont($e1093110932)) {
var $ss1093510936 = {"from":L[1204],
"go":function(anf_arg31010941) {
return $Hanf_arg177210943(anf_arg31010941,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1093110932.stack[R.EXN_STACKHEIGHT++] = $ss1093510936;
}
if(R.isPyretException($e1093110932)) {
$e1093110932.pyretStack.push(L[1204]);
}
throw $e1093110932;
}
var $ret1093710938 = $Hanf_arg177210943($z1093310934,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1093710938;
};
var $Hanf_arg177210943 = function(anf_arg31010941,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_num8889,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1094610947 = D;
var $f1095210953 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app((0)):R.ffi.throwNonFunApp(L[1206],j_DASH_num8889,[(0)]);
};
try {
if(--R.GAS > 0) {
$z1094610947 = $f1095210953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1095210953,
"from":L[1206]});
}
} catch($e1094410945) {
if(R.isCont($e1094410945)) {
var $ss1094810949 = {"from":L[1206],
"go":function(anf_arg31110954) {
return $Hanf_arg177110955(anf_arg31110954,anf_arg30010855,anf_arg30810929,anf_arg31010941,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1094410945.stack[R.EXN_STACKHEIGHT++] = $ss1094810949;
}
if(R.isPyretException($e1094410945)) {
$e1094410945.pyretStack.push(L[1206]);
}
throw $e1094410945;
}
var $ret1095010951 = $Hanf_arg177110955($z1094610947,anf_arg30010855,anf_arg30810929,anf_arg31010941,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1095010951;
};
var $Hanf_arg177110955 = function(anf_arg31110954,anf_arg30010855,anf_arg30810929,anf_arg31010941,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_dot_DASH_assign10074,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1095810959 = D;
var $f1096410965 = function(_) {
return R.isFunction(j_DASH_dot_DASH_assign10074)?j_DASH_dot_DASH_assign10074.app(anf_arg31010941,("EXN_STACKHEIGHT"),anf_arg31110954):R.ffi.throwNonFunApp(L[1207],j_DASH_dot_DASH_assign10074,[anf_arg31010941,("EXN_STACKHEIGHT"),anf_arg31110954]);
};
try {
if(--R.GAS > 0) {
$z1095810959 = $f1096410965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1096410965,
"from":L[1207]});
}
} catch($e1095610957) {
if(R.isCont($e1095610957)) {
var $ss1096010961 = {"from":L[1207],
"go":function(anf_arg31210966) {
return $Hanf_arg177010967(anf_arg31210966,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1095610957.stack[R.EXN_STACKHEIGHT++] = $ss1096010961;
}
if(R.isPyretException($e1095610957)) {
$e1095610957.pyretStack.push(L[1207]);
}
throw $e1095610957;
}
var $ret1096210963 = $Hanf_arg177010967($z1095810959,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1096210963;
};
var $Hanf_arg177010967 = function(anf_arg31210966,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1097010971 = D;
var $f1097610977 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(anf_arg31210966):R.ffi.throwNonFunApp(L[1208],j_DASH_expr10477,[anf_arg31210966]);
};
try {
if(--R.GAS > 0) {
$z1097010971 = $f1097610977();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1097610977,
"from":L[1208]});
}
} catch($e1096810969) {
if(R.isCont($e1096810969)) {
var $ss1097210973 = {"from":L[1208],
"go":function(anf_array_val31310978) {
return $Hanf_array_val176910979(anf_array_val31310978,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1096810969.stack[R.EXN_STACKHEIGHT++] = $ss1097210973;
}
if(R.isPyretException($e1096810969)) {
$e1096810969.pyretStack.push(L[1208]);
}
throw $e1096810969;
}
var $ret1097410975 = $Hanf_array_val176910979($z1097010971,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1097410975;
};
var $Hanf_array_val176910979 = function(anf_array_val31310978,anf_arg30010855,anf_arg30810929,anf_fun30910942,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,js_DASH_id_DASH_of162700,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var anf_fun31410991 = G(list35101,"make",L[1212]);
var anf_fun31510992 = G(list35101,"make",L[1211]);
var anf_fun31610993 = G(list35101,"make",L[1210]);
var $z1098210983 = D;
var $f1098810989 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(("ignored")):R.ffi.throwNonFunApp(L[1209],js_DASH_id_DASH_of162700,[("ignored")]);
};
try {
if(--R.GAS > 0) {
$z1098210983 = $f1098810989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1098810989,
"from":L[1209]});
}
} catch($e1098010981) {
if(R.isCont($e1098010981)) {
var $ss1098410985 = {"from":L[1209],
"go":function(anf_array_val31710990) {
return $Hanf_array_val176810994(anf_array_val31710990,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31610993,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1098010981.stack[R.EXN_STACKHEIGHT++] = $ss1098410985;
}
if(R.isPyretException($e1098010981)) {
$e1098010981.pyretStack.push(L[1209]);
}
throw $e1098010981;
}
var $ret1098610987 = $Hanf_array_val176810994($z1098210983,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31610993,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1098610987;
};
var $Hanf_array_val176810994 = function(anf_array_val31710990,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31610993,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1099710998 = D;
var $f1100311004 = function(_) {
return R.isFunction(anf_fun31610993)?anf_fun31610993.app([anf_array_val31710990]):R.ffi.throwNonFunApp(L[1210],anf_fun31610993,[[anf_array_val31710990]]);
};
try {
if(--R.GAS > 0) {
$z1099710998 = $f1100311004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1100311004,
"from":L[1210]});
}
} catch($e1099510996) {
if(R.isCont($e1099510996)) {
var $ss1099911000 = {"from":L[1210],
"go":function(anf_arg31811005) {
return $Hanf_arg176711006(anf_arg31811005,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1099510996.stack[R.EXN_STACKHEIGHT++] = $ss1099911000;
}
if(R.isPyretException($e1099510996)) {
$e1099510996.pyretStack.push(L[1210]);
}
throw $e1099510996;
}
var $ret1100111002 = $Hanf_arg176711006($z1099710998,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1100111002;
};
var $Hanf_arg176711006 = function(anf_arg31811005,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var anf_fun31911019 = G(list35101,"make",L[1215]);
var anf_fun32011017 = G(compiler2071853,"get-loc",L[1214]);
var $z1100911010 = D;
var $f1101511016 = function(_) {
return R.isFunction(anf_fun32011017)?anf_fun32011017.app(l2081854):R.ffi.throwNonFunApp(L[1213],anf_fun32011017,[l2081854]);
};
try {
if(--R.GAS > 0) {
$z1100911010 = $f1101511016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1101511016,
"from":L[1213]});
}
} catch($e1100711008) {
if(R.isCont($e1100711008)) {
var $ss1101111012 = {"from":L[1213],
"go":function(anf_arg32111018) {
return $Hanf_arg176611020(anf_arg32111018,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1100711008.stack[R.EXN_STACKHEIGHT++] = $ss1101111012;
}
if(R.isPyretException($e1100711008)) {
$e1100711008.pyretStack.push(L[1213]);
}
throw $e1100711008;
}
var $ret1101311014 = $Hanf_arg176611020($z1100911010,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1101311014;
};
var $Hanf_arg176611020 = function(anf_arg32111018,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,app174659,compiled_DASH_args21310792,compiled_DASH_f21210778,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1102311024 = D;
var $f1102911030 = function(_) {
return R.isFunction(app174659.$var)?app174659.$var.app(anf_arg32111018,compiled_DASH_f21210778,compiled_DASH_args21310792):R.ffi.throwNonFunApp(L[1216],app174659.$var,[anf_arg32111018,compiled_DASH_f21210778,compiled_DASH_args21310792]);
};
try {
if(--R.GAS > 0) {
$z1102311024 = $f1102911030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1102911030,
"from":L[1216]});
}
} catch($e1102111022) {
if(R.isCont($e1102111022)) {
var $ss1102511026 = {"from":L[1216],
"go":function(anf_arg32211031) {
return $Hanf_arg176511032(anf_arg32211031,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1102111022.stack[R.EXN_STACKHEIGHT++] = $ss1102511026;
}
if(R.isPyretException($e1102111022)) {
$e1102111022.pyretStack.push(L[1216]);
}
throw $e1102111022;
}
var $ret1102711028 = $Hanf_arg176511032($z1102311024,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1102711028;
};
var $Hanf_arg176511032 = function(anf_arg32211031,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1103511036 = D;
var $f1104111042 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg32211031):R.ffi.throwNonFunApp(L[1217],j_DASH_return9092,[anf_arg32211031]);
};
try {
if(--R.GAS > 0) {
$z1103511036 = $f1104111042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1104111042,
"from":L[1217]});
}
} catch($e1103311034) {
if(R.isCont($e1103311034)) {
var $ss1103711038 = {"from":L[1217],
"go":function(anf_array_val32311043) {
return $Hanf_array_val176411044(anf_array_val32311043,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1103311034.stack[R.EXN_STACKHEIGHT++] = $ss1103711038;
}
if(R.isPyretException($e1103311034)) {
$e1103311034.pyretStack.push(L[1217]);
}
throw $e1103311034;
}
var $ret1103911040 = $Hanf_array_val176411044($z1103511036,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1103911040;
};
var $Hanf_array_val176411044 = function(anf_array_val32311043,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,anf_fun31911019,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1104711048 = D;
var $f1105311054 = function(_) {
return R.isFunction(anf_fun31911019)?anf_fun31911019.app([anf_array_val32311043]):R.ffi.throwNonFunApp(L[1215],anf_fun31911019,[[anf_array_val32311043]]);
};
try {
if(--R.GAS > 0) {
$z1104711048 = $f1105311054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1105311054,
"from":L[1215]});
}
} catch($e1104511046) {
if(R.isCont($e1104511046)) {
var $ss1104911050 = {"from":L[1215],
"go":function(anf_arg32411055) {
return $Hanf_arg176311056(anf_arg32411055,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1104511046.stack[R.EXN_STACKHEIGHT++] = $ss1104911050;
}
if(R.isPyretException($e1104511046)) {
$e1104511046.pyretStack.push(L[1215]);
}
throw $e1104511046;
}
var $ret1105111052 = $Hanf_arg176311056($z1104711048,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1105111052;
};
var $Hanf_arg176311056 = function(anf_arg32411055,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1105911060 = D;
var $f1106511066 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg32411055):R.ffi.throwNonFunApp(L[1218],j_DASH_block8570,[anf_arg32411055]);
};
try {
if(--R.GAS > 0) {
$z1105911060 = $f1106511066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1106511066,
"from":L[1218]});
}
} catch($e1105711058) {
if(R.isCont($e1105711058)) {
var $ss1106111062 = {"from":L[1218],
"go":function(anf_arg32511067) {
return $Hanf_arg176211068(anf_arg32511067,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1105711058.stack[R.EXN_STACKHEIGHT++] = $ss1106111062;
}
if(R.isPyretException($e1105711058)) {
$e1105711058.pyretStack.push(L[1218]);
}
throw $e1105711058;
}
var $ret1106311064 = $Hanf_arg176211068($z1105911060,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1106311064;
};
var $Hanf_arg176211068 = function(anf_arg32511067,anf_arg30010855,anf_arg30810929,anf_arg31811005,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1107111072 = D;
var $f1107711078 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg31811005,anf_arg32511067):R.ffi.throwNonFunApp(L[1219],j_DASH_fun8180,[anf_arg31811005,anf_arg32511067]);
};
try {
if(--R.GAS > 0) {
$z1107111072 = $f1107711078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1107711078,
"from":L[1219]});
}
} catch($e1106911070) {
if(R.isCont($e1106911070)) {
var $ss1107311074 = {"from":L[1219],
"go":function(anf_arg32611079) {
return $Hanf_arg176111080(anf_arg32611079,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1106911070.stack[R.EXN_STACKHEIGHT++] = $ss1107311074;
}
if(R.isPyretException($e1106911070)) {
$e1106911070.pyretStack.push(L[1219]);
}
throw $e1106911070;
}
var $ret1107511076 = $Hanf_arg176111080($z1107111072,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1107511076;
};
var $Hanf_arg176111080 = function(anf_arg32611079,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1108311084 = D;
var $f1108911090 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("go"),anf_arg32611079):R.ffi.throwNonFunApp(L[1220],j_DASH_field9979,[("go"),anf_arg32611079]);
};
try {
if(--R.GAS > 0) {
$z1108311084 = $f1108911090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1108911090,
"from":L[1220]});
}
} catch($e1108111082) {
if(R.isCont($e1108111082)) {
var $ss1108511086 = {"from":L[1220],
"go":function(anf_array_val32711091) {
return $Hanf_array_val176011092(anf_array_val32711091,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1108111082.stack[R.EXN_STACKHEIGHT++] = $ss1108511086;
}
if(R.isPyretException($e1108111082)) {
$e1108111082.pyretStack.push(L[1220]);
}
throw $e1108111082;
}
var $ret1108711088 = $Hanf_array_val176011092($z1108311084,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1108711088;
};
var $Hanf_array_val176011092 = function(anf_array_val32711091,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,anf_fun31510992,compiler2071853,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,l2081854,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var anf_fun32811103 = G(compiler2071853,"get-loc",L[1222]);
var $z1109511096 = D;
var $f1110111102 = function(_) {
return R.isFunction(anf_fun32811103)?anf_fun32811103.app(l2081854):R.ffi.throwNonFunApp(L[1221],anf_fun32811103,[l2081854]);
};
try {
if(--R.GAS > 0) {
$z1109511096 = $f1110111102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1110111102,
"from":L[1221]});
}
} catch($e1109311094) {
if(R.isCont($e1109311094)) {
var $ss1109711098 = {"from":L[1221],
"go":function(anf_arg32911104) {
return $Hanf_arg175911105(anf_arg32911104,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_array_val32711091,anf_fun30910942,anf_fun31410991,anf_fun31510992,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1109311094.stack[R.EXN_STACKHEIGHT++] = $ss1109711098;
}
if(R.isPyretException($e1109311094)) {
$e1109311094.pyretStack.push(L[1221]);
}
throw $e1109311094;
}
var $ret1109911100 = $Hanf_arg175911105($z1109511096,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_array_val32711091,anf_fun30910942,anf_fun31410991,anf_fun31510992,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1109911100;
};
var $Hanf_arg175911105 = function(anf_arg32911104,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_array_val32711091,anf_fun30910942,anf_fun31410991,anf_fun31510992,j_DASH_block8570,j_DASH_expr10477,j_DASH_field9979,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1110811109 = D;
var $f1111411115 = function(_) {
return R.isFunction(j_DASH_field9979)?j_DASH_field9979.app(("from"),anf_arg32911104):R.ffi.throwNonFunApp(L[1223],j_DASH_field9979,[("from"),anf_arg32911104]);
};
try {
if(--R.GAS > 0) {
$z1110811109 = $f1111411115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1111411115,
"from":L[1223]});
}
} catch($e1110611107) {
if(R.isCont($e1110611107)) {
var $ss1111011111 = {"from":L[1223],
"go":function(anf_array_val33011116) {
return $Hanf_array_val175811117(anf_array_val33011116,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_array_val32711091,anf_fun30910942,anf_fun31410991,anf_fun31510992,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1110611107.stack[R.EXN_STACKHEIGHT++] = $ss1111011111;
}
if(R.isPyretException($e1110611107)) {
$e1110611107.pyretStack.push(L[1223]);
}
throw $e1110611107;
}
var $ret1111211113 = $Hanf_array_val175811117($z1110811109,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_array_val32711091,anf_fun30910942,anf_fun31410991,anf_fun31510992,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1111211113;
};
var $Hanf_array_val175811117 = function(anf_array_val33011116,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_array_val32711091,anf_fun30910942,anf_fun31410991,anf_fun31510992,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1112011121 = D;
var $f1112611127 = function(_) {
return R.isFunction(anf_fun31510992)?anf_fun31510992.app([anf_array_val32711091,anf_array_val33011116]):R.ffi.throwNonFunApp(L[1211],anf_fun31510992,[[anf_array_val32711091,anf_array_val33011116]]);
};
try {
if(--R.GAS > 0) {
$z1112011121 = $f1112611127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1112611127,
"from":L[1211]});
}
} catch($e1111811119) {
if(R.isCont($e1111811119)) {
var $ss1112211123 = {"from":L[1211],
"go":function(anf_arg33111128) {
return $Hanf_arg175711129(anf_arg33111128,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1111811119.stack[R.EXN_STACKHEIGHT++] = $ss1112211123;
}
if(R.isPyretException($e1111811119)) {
$e1111811119.pyretStack.push(L[1211]);
}
throw $e1111811119;
}
var $ret1112411125 = $Hanf_arg175711129($z1112011121,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1112411125;
};
var $Hanf_arg175711129 = function(anf_arg33111128,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_obj9690,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1113211133 = D;
var $f1113811139 = function(_) {
return R.isFunction(j_DASH_obj9690)?j_DASH_obj9690.app(anf_arg33111128):R.ffi.throwNonFunApp(L[1224],j_DASH_obj9690,[anf_arg33111128]);
};
try {
if(--R.GAS > 0) {
$z1113211133 = $f1113811139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1113811139,
"from":L[1224]});
}
} catch($e1113011131) {
if(R.isCont($e1113011131)) {
var $ss1113411135 = {"from":L[1224],
"go":function(anf_array_val33211140) {
return $Hanf_array_val175611141(anf_array_val33211140,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1113011131.stack[R.EXN_STACKHEIGHT++] = $ss1113411135;
}
if(R.isPyretException($e1113011131)) {
$e1113011131.pyretStack.push(L[1224]);
}
throw $e1113011131;
}
var $ret1113611137 = $Hanf_array_val175611141($z1113211133,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1113611137;
};
var $Hanf_array_val175611141 = function(anf_array_val33211140,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,anf_fun31410991,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1114411145 = D;
var $f1115011151 = function(_) {
return R.isFunction(anf_fun31410991)?anf_fun31410991.app([anf_array_val33211140]):R.ffi.throwNonFunApp(L[1212],anf_fun31410991,[[anf_array_val33211140]]);
};
try {
if(--R.GAS > 0) {
$z1114411145 = $f1115011151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1115011151,
"from":L[1212]});
}
} catch($e1114211143) {
if(R.isCont($e1114211143)) {
var $ss1114611147 = {"from":L[1212],
"go":function(anf_arg33311152) {
return $Hanf_arg175511153(anf_arg33311152,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
}};
$e1114211143.stack[R.EXN_STACKHEIGHT++] = $ss1114611147;
}
if(R.isPyretException($e1114211143)) {
$e1114211143.pyretStack.push(L[1212]);
}
throw $e1114211143;
}
var $ret1114811149 = $Hanf_arg175511153($z1114411145,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765);
++R.GAS;
return $ret1114811149;
};
var $Hanf_arg175511153 = function(anf_arg33311152,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,rt_DASH_method173657,z21110765) {
var $z1115611157 = D;
var $f1116211163 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("makeCont"),anf_arg33311152):R.ffi.throwNonFunApp(L[1225],rt_DASH_method173657.$var,[("makeCont"),anf_arg33311152]);
};
try {
if(--R.GAS > 0) {
$z1115611157 = $f1116211163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1116211163,
"from":L[1225]});
}
} catch($e1115411155) {
if(R.isCont($e1115411155)) {
var $ss1115811159 = {"from":L[1225],
"go":function(anf_arg33411164) {
return $Hanf_arg175411165(anf_arg33411164,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
}};
$e1115411155.stack[R.EXN_STACKHEIGHT++] = $ss1115811159;
}
if(R.isPyretException($e1115411155)) {
$e1115411155.pyretStack.push(L[1225]);
}
throw $e1115411155;
}
var $ret1116011161 = $Hanf_arg175411165($z1115611157,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
++R.GAS;
return $ret1116011161;
};
var $Hanf_arg175411165 = function(anf_arg33411164,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_throw10395,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765) {
var $z1116811169 = D;
var $f1117411175 = function(_) {
return R.isFunction(j_DASH_throw10395)?j_DASH_throw10395.app(anf_arg33411164):R.ffi.throwNonFunApp(L[1226],j_DASH_throw10395,[anf_arg33411164]);
};
try {
if(--R.GAS > 0) {
$z1116811169 = $f1117411175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1117411175,
"from":L[1226]});
}
} catch($e1116611167) {
if(R.isCont($e1116611167)) {
var $ss1117011171 = {"from":L[1226],
"go":function(anf_array_val33511176) {
return $Hanf_array_val175311177(anf_array_val33511176,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
}};
$e1116611167.stack[R.EXN_STACKHEIGHT++] = $ss1117011171;
}
if(R.isPyretException($e1116611167)) {
$e1116611167.pyretStack.push(L[1226]);
}
throw $e1116611167;
}
var $ret1117211173 = $Hanf_array_val175311177($z1116811169,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
++R.GAS;
return $ret1117211173;
};
var $Hanf_array_val175311177 = function(anf_array_val33511176,anf_arg30010855,anf_arg30810929,anf_array_val31310978,anf_fun30910942,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765) {
var $z1118011181 = D;
var $f1118611187 = function(_) {
return R.isFunction(anf_fun30910942)?anf_fun30910942.app([anf_array_val31310978,anf_array_val33511176]):R.ffi.throwNonFunApp(L[1205],anf_fun30910942,[[anf_array_val31310978,anf_array_val33511176]]);
};
try {
if(--R.GAS > 0) {
$z1118011181 = $f1118611187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1118611187,
"from":L[1205]});
}
} catch($e1117811179) {
if(R.isCont($e1117811179)) {
var $ss1118211183 = {"from":L[1205],
"go":function(anf_arg33611188) {
return $Hanf_arg175211189(anf_arg33611188,anf_arg30010855,anf_arg30810929,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
}};
$e1117811179.stack[R.EXN_STACKHEIGHT++] = $ss1118211183;
}
if(R.isPyretException($e1117811179)) {
$e1117811179.pyretStack.push(L[1205]);
}
throw $e1117811179;
}
var $ret1118411185 = $Hanf_arg175211189($z1118011181,anf_arg30010855,anf_arg30810929,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
++R.GAS;
return $ret1118411185;
};
var $Hanf_arg175211189 = function(anf_arg33611188,anf_arg30010855,anf_arg30810929,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765) {
var $z1119211193 = D;
var $f1119811199 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg33611188):R.ffi.throwNonFunApp(L[1227],j_DASH_block8570,[anf_arg33611188]);
};
try {
if(--R.GAS > 0) {
$z1119211193 = $f1119811199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1119811199,
"from":L[1227]});
}
} catch($e1119011191) {
if(R.isCont($e1119011191)) {
var $ss1119411195 = {"from":L[1227],
"go":function(anf_arg33711200) {
return $Hanf_arg175111201(anf_arg33711200,anf_arg30010855,anf_arg30810929,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
}};
$e1119011191.stack[R.EXN_STACKHEIGHT++] = $ss1119411195;
}
if(R.isPyretException($e1119011191)) {
$e1119011191.pyretStack.push(L[1227]);
}
throw $e1119011191;
}
var $ret1119611197 = $Hanf_arg175111201($z1119211193,anf_arg30010855,anf_arg30810929,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
++R.GAS;
return $ret1119611197;
};
var $Hanf_arg175111201 = function(anf_arg33711200,anf_arg30010855,anf_arg30810929,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_if9283,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765) {
var $z1120411205 = D;
var $f1121011211 = function(_) {
return R.isFunction(j_DASH_if9283)?j_DASH_if9283.app(anf_arg30010855,anf_arg30810929,anf_arg33711200):R.ffi.throwNonFunApp(L[1228],j_DASH_if9283,[anf_arg30010855,anf_arg30810929,anf_arg33711200]);
};
try {
if(--R.GAS > 0) {
$z1120411205 = $f1121011211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1121011211,
"from":L[1228]});
}
} catch($e1120211203) {
if(R.isCont($e1120211203)) {
var $ss1120611207 = {"from":L[1228],
"go":function(body21411212) {
return $Hbody175011213(body21411212,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
}};
$e1120211203.stack[R.EXN_STACKHEIGHT++] = $ss1120611207;
}
if(R.isPyretException($e1120211203)) {
$e1120211203.pyretStack.push(L[1228]);
}
throw $e1120211203;
}
var $ret1120811209 = $Hbody175011213($z1120411205,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765);
++R.GAS;
return $ret1120811209;
};
var $Hbody175011213 = function(body21411212,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,list35101,rt_DASH_field172655,z21110765) {
var anf_fun33811225 = G(list35101,"make",L[1230]);
var $z1121611217 = D;
var $f1122211223 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("GAS")):R.ffi.throwNonFunApp(L[1229],rt_DASH_field172655.$var,[("GAS")]);
};
try {
if(--R.GAS > 0) {
$z1121611217 = $f1122211223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1122211223,
"from":L[1229]});
}
} catch($e1121411215) {
if(R.isCont($e1121411215)) {
var $ss1121811219 = {"from":L[1229],
"go":function(anf_arg33911224) {
return $Hanf_arg174911226(anf_arg33911224,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,z21110765);
}};
$e1121411215.stack[R.EXN_STACKHEIGHT++] = $ss1121811219;
}
if(R.isPyretException($e1121411215)) {
$e1121411215.pyretStack.push(L[1229]);
}
throw $e1121411215;
}
var $ret1122011221 = $Hanf_arg174911226($z1121611217,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,z21110765);
++R.GAS;
return $ret1122011221;
};
var $Hanf_arg174911226 = function(anf_arg33911224,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_incr11084,j_DASH_return9092,j_DASH_unop10898,z21110765) {
var $z1122911230 = D;
var $f1123511236 = function(_) {
return R.isFunction(j_DASH_unop10898)?j_DASH_unop10898.app(anf_arg33911224,j_DASH_incr11084):R.ffi.throwNonFunApp(L[1231],j_DASH_unop10898,[anf_arg33911224,j_DASH_incr11084]);
};
try {
if(--R.GAS > 0) {
$z1122911230 = $f1123511236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1123511236,
"from":L[1231]});
}
} catch($e1122711228) {
if(R.isCont($e1122711228)) {
var $ss1123111232 = {"from":L[1231],
"go":function(anf_arg34011237) {
return $Hanf_arg174811238(anf_arg34011237,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_return9092,z21110765);
}};
$e1122711228.stack[R.EXN_STACKHEIGHT++] = $ss1123111232;
}
if(R.isPyretException($e1122711228)) {
$e1122711228.pyretStack.push(L[1231]);
}
throw $e1122711228;
}
var $ret1123311234 = $Hanf_arg174811238($z1122911230,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_return9092,z21110765);
++R.GAS;
return $ret1123311234;
};
var $Hanf_arg174811238 = function(anf_arg34011237,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_expr10477,j_DASH_id8381,j_DASH_return9092,z21110765) {
var $z1124111242 = D;
var $f1124711248 = function(_) {
return R.isFunction(j_DASH_expr10477)?j_DASH_expr10477.app(anf_arg34011237):R.ffi.throwNonFunApp(L[1232],j_DASH_expr10477,[anf_arg34011237]);
};
try {
if(--R.GAS > 0) {
$z1124111242 = $f1124711248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1124711248,
"from":L[1232]});
}
} catch($e1123911240) {
if(R.isCont($e1123911240)) {
var $ss1124311244 = {"from":L[1232],
"go":function(anf_array_val34111249) {
return $Hanf_array_val174711250(anf_array_val34111249,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,z21110765);
}};
$e1123911240.stack[R.EXN_STACKHEIGHT++] = $ss1124311244;
}
if(R.isPyretException($e1123911240)) {
$e1123911240.pyretStack.push(L[1232]);
}
throw $e1123911240;
}
var $ret1124511246 = $Hanf_array_val174711250($z1124111242,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,z21110765);
++R.GAS;
return $ret1124511246;
};
var $Hanf_array_val174711250 = function(anf_array_val34111249,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_id8381,j_DASH_return9092,z21110765) {
var $z1125311254 = D;
var $f1125911260 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(z21110765):R.ffi.throwNonFunApp(L[1233],j_DASH_id8381,[z21110765]);
};
try {
if(--R.GAS > 0) {
$z1125311254 = $f1125911260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1125911260,
"from":L[1233]});
}
} catch($e1125111252) {
if(R.isCont($e1125111252)) {
var $ss1125511256 = {"from":L[1233],
"go":function(anf_arg34211261) {
return $Hanf_arg174611262(anf_arg34211261,anf_array_val34111249,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_return9092);
}};
$e1125111252.stack[R.EXN_STACKHEIGHT++] = $ss1125511256;
}
if(R.isPyretException($e1125111252)) {
$e1125111252.pyretStack.push(L[1233]);
}
throw $e1125111252;
}
var $ret1125711258 = $Hanf_arg174611262($z1125311254,anf_array_val34111249,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_return9092);
++R.GAS;
return $ret1125711258;
};
var $Hanf_arg174611262 = function(anf_arg34211261,anf_array_val34111249,anf_fun33811225,body21411212,j_DASH_block8570,j_DASH_return9092) {
var $z1126511266 = D;
var $f1127111272 = function(_) {
return R.isFunction(j_DASH_return9092)?j_DASH_return9092.app(anf_arg34211261):R.ffi.throwNonFunApp(L[1234],j_DASH_return9092,[anf_arg34211261]);
};
try {
if(--R.GAS > 0) {
$z1126511266 = $f1127111272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1127111272,
"from":L[1234]});
}
} catch($e1126311264) {
if(R.isCont($e1126311264)) {
var $ss1126711268 = {"from":L[1234],
"go":function(anf_array_val34311273) {
return $Hanf_array_val174511274(anf_array_val34311273,anf_array_val34111249,anf_fun33811225,body21411212,j_DASH_block8570);
}};
$e1126311264.stack[R.EXN_STACKHEIGHT++] = $ss1126711268;
}
if(R.isPyretException($e1126311264)) {
$e1126311264.pyretStack.push(L[1234]);
}
throw $e1126311264;
}
var $ret1126911270 = $Hanf_array_val174511274($z1126511266,anf_array_val34111249,anf_fun33811225,body21411212,j_DASH_block8570);
++R.GAS;
return $ret1126911270;
};
var $Hanf_array_val174511274 = function(anf_array_val34311273,anf_array_val34111249,anf_fun33811225,body21411212,j_DASH_block8570) {
var $z1127711278 = D;
var $f1128311284 = function(_) {
return R.isFunction(anf_fun33811225)?anf_fun33811225.app([body21411212,anf_array_val34111249,anf_array_val34311273]):R.ffi.throwNonFunApp(L[1230],anf_fun33811225,[[body21411212,anf_array_val34111249,anf_array_val34311273]]);
};
try {
if(--R.GAS > 0) {
$z1127711278 = $f1128311284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1128311284,
"from":L[1230]});
}
} catch($e1127511276) {
if(R.isCont($e1127511276)) {
var $ss1127911280 = {"from":L[1230],
"go":function(anf_arg34411285) {
return $Hanf_arg174411286(anf_arg34411285,j_DASH_block8570);
}};
$e1127511276.stack[R.EXN_STACKHEIGHT++] = $ss1127911280;
}
if(R.isPyretException($e1127511276)) {
$e1127511276.pyretStack.push(L[1230]);
}
throw $e1127511276;
}
var $ret1128111282 = $Hanf_arg174411286($z1127711278,j_DASH_block8570);
++R.GAS;
return $ret1128111282;
};
var $Hanf_arg174411286 = function(anf_arg34411285,j_DASH_block8570) {
var $z1128911290 = D;
var $f1129511296 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg34411285):R.ffi.throwNonFunApp(L[311],j_DASH_block8570,[anf_arg34411285]);
};
try {
if(--R.GAS > 0) {
$z1128911290 = $f1129511296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1129511296,
"from":L[311]});
}
} catch($e1128711288) {
if(R.isCont($e1128711288)) {
var $ss1129111292 = {"from":L[311],
"go":function(ann_DASH_check_DASH_temp28911297) {
return $Hann_DASH_check_DASH_temp174311298(ann_DASH_check_DASH_temp28911297);
}};
$e1128711288.stack[R.EXN_STACKHEIGHT++] = $ss1129111292;
}
if(R.isPyretException($e1128711288)) {
$e1128711288.pyretStack.push(L[311]);
}
throw $e1128711288;
}
var $ret1129311294 = $Hann_DASH_check_DASH_temp174311298($z1128911290);
++R.GAS;
return $ret1129311294;
};
var $Hann_DASH_check_DASH_temp174311298 = function(ann_DASH_check_DASH_temp28911297) {
return ann_DASH_check_DASH_temp28911297;
};
var $Hann_DASH_check_DASH_temp174210807 = function(ann_DASH_check_DASH_temp29310806) {
return ann_DASH_check_DASH_temp29310806;
};
var $Hann_DASH_check_DASH_temp17411885 = function(ann_DASH_check_DASH_temp2701884,J834) {
return ann_DASH_check_DASH_temp2701884;
};
var $Hanf_arg17401902 = function(anf_arg2731901,args2051889,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299,js_DASH_id_DASH_of162700) {
var anf_fun27411309 = G(args2051889,"map",L[1237]);
var anf_arg27711310 = R.makeFunction(function(recv_DASH_3311313) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1236],1,arguments);
}
var anf_fun27611324 = G(recv_DASH_3311313,"tostring",L[1236]);
var $z1131611317 = D;
var $f1132211323 = function(_) {
return R.isFunction(anf_fun27611324)?anf_fun27611324.app():R.ffi.throwNonFunApp(L[1236],anf_fun27611324,[]);
};
try {
if(--R.GAS > 0) {
$z1131611317 = $f1132211323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1132211323,
"from":L[1236]});
}
} catch($e1131411315) {
if(R.isCont($e1131411315)) {
var $ss1131811319 = {"from":L[1236],
"go":function(ann_DASH_check_DASH_temp27511325) {
return $Hann_DASH_check_DASH_temp173411326(ann_DASH_check_DASH_temp27511325);
}};
$e1131411315.stack[R.EXN_STACKHEIGHT++] = $ss1131811319;
}
if(R.isPyretException($e1131411315)) {
$e1131411315.pyretStack.push(L[1236]);
}
throw $e1131411315;
}
var $ret1132011321 = $Hann_DASH_check_DASH_temp173411326($z1131611317);
++R.GAS;
return $ret1132011321;
});
var $z1130111302 = D;
var $f1130711308 = function(_) {
return R.isFunction(anf_fun27411309)?anf_fun27411309.app(anf_arg27711310):R.ffi.throwNonFunApp(L[1235],anf_fun27411309,[anf_arg27711310]);
};
try {
if(--R.GAS > 0) {
$z1130111302 = $f1130711308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1130711308,
"from":L[1235]});
}
} catch($e1129911300) {
if(R.isCont($e1129911300)) {
var $ss1130311304 = {"from":L[1235],
"go":function(anf_bracket27811311) {
return $Hanf_bracket173911312(anf_bracket27811311,anf_arg2731901,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299,js_DASH_id_DASH_of162700);
}};
$e1129911300.stack[R.EXN_STACKHEIGHT++] = $ss1130311304;
}
if(R.isPyretException($e1129911300)) {
$e1129911300.pyretStack.push(L[1235]);
}
throw $e1129911300;
}
var $ret1130511306 = $Hanf_bracket173911312($z1130111302,anf_arg2731901,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299,js_DASH_id_DASH_of162700);
++R.GAS;
return $ret1130511306;
};
var $Hanf_bracket173911312 = function(anf_bracket27811311,anf_arg2731901,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299,js_DASH_id_DASH_of162700) {
var anf_fun27911337 = G(anf_bracket27811311,"map",L[1239]);
var $z1132911330 = D;
var $f1133511336 = function(_) {
return R.isFunction(anf_fun27911337)?anf_fun27911337.app(js_DASH_id_DASH_of162700):R.ffi.throwNonFunApp(L[1238],anf_fun27911337,[js_DASH_id_DASH_of162700]);
};
try {
if(--R.GAS > 0) {
$z1132911330 = $f1133511336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1133511336,
"from":L[1238]});
}
} catch($e1132711328) {
if(R.isCont($e1132711328)) {
var $ss1133111332 = {"from":L[1238],
"go":function(anf_arg28011338) {
return $Hanf_arg173811339(anf_arg28011338,anf_arg2731901,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299);
}};
$e1132711328.stack[R.EXN_STACKHEIGHT++] = $ss1133111332;
}
if(R.isPyretException($e1132711328)) {
$e1132711328.pyretStack.push(L[1238]);
}
throw $e1132711328;
}
var $ret1133311334 = $Hanf_arg173811339($z1132911330,anf_arg2731901,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299);
++R.GAS;
return $ret1133311334;
};
var $Hanf_arg173811339 = function(anf_arg28011338,anf_arg2731901,body2061890,compiler2021869,j_DASH_fun8180,j_DASH_var8299) {
var anf_fun28111350 = G(body2061890,"visit",L[1241]);
var $z1134211343 = D;
var $f1134811349 = function(_) {
return R.isFunction(anf_fun28111350)?anf_fun28111350.app(compiler2021869):R.ffi.throwNonFunApp(L[1240],anf_fun28111350,[compiler2021869]);
};
try {
if(--R.GAS > 0) {
$z1134211343 = $f1134811349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1134811349,
"from":L[1240]});
}
} catch($e1134011341) {
if(R.isCont($e1134011341)) {
var $ss1134411345 = {"from":L[1240],
"go":function(anf_arg28211351) {
return $Hanf_arg173711352(anf_arg28211351,anf_arg2731901,anf_arg28011338,j_DASH_fun8180,j_DASH_var8299);
}};
$e1134011341.stack[R.EXN_STACKHEIGHT++] = $ss1134411345;
}
if(R.isPyretException($e1134011341)) {
$e1134011341.pyretStack.push(L[1240]);
}
throw $e1134011341;
}
var $ret1134611347 = $Hanf_arg173711352($z1134211343,anf_arg2731901,anf_arg28011338,j_DASH_fun8180,j_DASH_var8299);
++R.GAS;
return $ret1134611347;
};
var $Hanf_arg173711352 = function(anf_arg28211351,anf_arg2731901,anf_arg28011338,j_DASH_fun8180,j_DASH_var8299) {
var $z1135511356 = D;
var $f1136111362 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg28011338,anf_arg28211351):R.ffi.throwNonFunApp(L[1242],j_DASH_fun8180,[anf_arg28011338,anf_arg28211351]);
};
try {
if(--R.GAS > 0) {
$z1135511356 = $f1136111362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1136111362,
"from":L[1242]});
}
} catch($e1135311354) {
if(R.isCont($e1135311354)) {
var $ss1135711358 = {"from":L[1242],
"go":function(anf_arg28311363) {
return $Hanf_arg173611364(anf_arg28311363,anf_arg2731901,j_DASH_var8299);
}};
$e1135311354.stack[R.EXN_STACKHEIGHT++] = $ss1135711358;
}
if(R.isPyretException($e1135311354)) {
$e1135311354.pyretStack.push(L[1242]);
}
throw $e1135311354;
}
var $ret1135911360 = $Hanf_arg173611364($z1135511356,anf_arg2731901,j_DASH_var8299);
++R.GAS;
return $ret1135911360;
};
var $Hanf_arg173611364 = function(anf_arg28311363,anf_arg2731901,j_DASH_var8299) {
var $z1136711368 = D;
var $f1137311374 = function(_) {
return R.isFunction(j_DASH_var8299)?j_DASH_var8299.app(anf_arg2731901,anf_arg28311363):R.ffi.throwNonFunApp(L[315],j_DASH_var8299,[anf_arg2731901,anf_arg28311363]);
};
try {
if(--R.GAS > 0) {
$z1136711368 = $f1137311374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1137311374,
"from":L[315]});
}
} catch($e1136511366) {
if(R.isCont($e1136511366)) {
var $ss1136911370 = {"from":L[315],
"go":function(ann_DASH_check_DASH_temp27211375) {
return $Hann_DASH_check_DASH_temp173511376(ann_DASH_check_DASH_temp27211375);
}};
$e1136511366.stack[R.EXN_STACKHEIGHT++] = $ss1136911370;
}
if(R.isPyretException($e1136511366)) {
$e1136511366.pyretStack.push(L[315]);
}
throw $e1136511366;
}
var $ret1137111372 = $Hann_DASH_check_DASH_temp173511376($z1136711368);
++R.GAS;
return $ret1137111372;
};
var $Hann_DASH_check_DASH_temp173511376 = function(ann_DASH_check_DASH_temp27211375) {
return ann_DASH_check_DASH_temp27211375;
};
var $Hann_DASH_check_DASH_temp173411326 = function(ann_DASH_check_DASH_temp27511325) {
return ann_DASH_check_DASH_temp27511325;
};
var $Hanf_arg17331917 = function(anf_arg2671916,js_DASH_id_DASH_of162700,_plus5) {
var $z1137911380 = D;
var $f1138511386 = function(_) {
return R.isFunction(js_DASH_id_DASH_of162700)?js_DASH_id_DASH_of162700.app(anf_arg2671916):R.ffi.throwNonFunApp(L[1243],js_DASH_id_DASH_of162700,[anf_arg2671916]);
};
try {
if(--R.GAS > 0) {
$z1137911380 = $f1138511386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1138511386,
"from":L[1243]});
}
} catch($e1137711378) {
if(R.isCont($e1137711378)) {
var $ss1138111382 = {"from":L[1243],
"go":function(anf_arg26811387) {
return $Hanf_arg173211388(anf_arg26811387,_plus5);
}};
$e1137711378.stack[R.EXN_STACKHEIGHT++] = $ss1138111382;
}
if(R.isPyretException($e1137711378)) {
$e1137711378.pyretStack.push(L[1243]);
}
throw $e1137711378;
}
var $ret1138311384 = $Hanf_arg173211388($z1137911380,_plus5);
++R.GAS;
return $ret1138311384;
};
var $Hanf_arg173211388 = function(anf_arg26811387,_plus5) {
var $z1139111392 = D;
var $f1139711398 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("$H"),anf_arg26811387):R.ffi.throwNonFunApp(L[318],_plus5,[("$H"),anf_arg26811387]);
};
try {
if(--R.GAS > 0) {
$z1139111392 = $f1139711398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1139711398,
"from":L[318]});
}
} catch($e1138911390) {
if(R.isCont($e1138911390)) {
var $ss1139311394 = {"from":L[318],
"go":function(ann_DASH_check_DASH_temp26511399) {
return $Hann_DASH_check_DASH_temp173111400(ann_DASH_check_DASH_temp26511399);
}};
$e1138911390.stack[R.EXN_STACKHEIGHT++] = $ss1139311394;
}
if(R.isPyretException($e1138911390)) {
$e1138911390.pyretStack.push(L[318]);
}
throw $e1138911390;
}
var $ret1139511396 = $Hann_DASH_check_DASH_temp173111400($z1139111392);
++R.GAS;
return $ret1139511396;
};
var $Hann_DASH_check_DASH_temp173111400 = function(ann_DASH_check_DASH_temp26511399) {
return ann_DASH_check_DASH_temp26511399;
};
var $Hanf_arg17301931 = function(anf_arg2621930,j_DASH_block8570,thunk_DASH_app175661) {
var $z1140311404 = D;
var $f1140911410 = function(_) {
return R.isFunction(j_DASH_block8570)?j_DASH_block8570.app(anf_arg2621930):R.ffi.throwNonFunApp(L[1244],j_DASH_block8570,[anf_arg2621930]);
};
try {
if(--R.GAS > 0) {
$z1140311404 = $f1140911410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1140911410,
"from":L[1244]});
}
} catch($e1140111402) {
if(R.isCont($e1140111402)) {
var $ss1140511406 = {"from":L[1244],
"go":function(anf_arg26311411) {
return $Hanf_arg172911412(anf_arg26311411,thunk_DASH_app175661);
}};
$e1140111402.stack[R.EXN_STACKHEIGHT++] = $ss1140511406;
}
if(R.isPyretException($e1140111402)) {
$e1140111402.pyretStack.push(L[1244]);
}
throw $e1140111402;
}
var $ret1140711408 = $Hanf_arg172911412($z1140311404,thunk_DASH_app175661);
++R.GAS;
return $ret1140711408;
};
var $Hanf_arg172911412 = function(anf_arg26311411,thunk_DASH_app175661) {
var $z1141511416 = D;
var $f1142111422 = function(_) {
return R.isFunction(thunk_DASH_app175661.$var)?thunk_DASH_app175661.$var.app(anf_arg26311411):R.ffi.throwNonFunApp(L[322],thunk_DASH_app175661.$var,[anf_arg26311411]);
};
try {
if(--R.GAS > 0) {
$z1141511416 = $f1142111422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1142111422,
"from":L[322]});
}
} catch($e1141311414) {
if(R.isCont($e1141311414)) {
var $ss1141711418 = {"from":L[322],
"go":function(ann_DASH_check_DASH_temp26011423) {
return $Hann_DASH_check_DASH_temp172811424(ann_DASH_check_DASH_temp26011423);
}};
$e1141311414.stack[R.EXN_STACKHEIGHT++] = $ss1141711418;
}
if(R.isPyretException($e1141311414)) {
$e1141311414.pyretStack.push(L[322]);
}
throw $e1141311414;
}
var $ret1141911420 = $Hann_DASH_check_DASH_temp172811424($z1141511416);
++R.GAS;
return $ret1141911420;
};
var $Hann_DASH_check_DASH_temp172811424 = function(ann_DASH_check_DASH_temp26011423) {
return ann_DASH_check_DASH_temp26011423;
};
var $Hanf_arg17271945 = function(anf_arg2541944,block1991932,j_DASH_app9467,j_DASH_fun8180,j_DASH_parens11391,list35101) {
var $z1142711428 = D;
var $f1143311434 = function(_) {
return R.isFunction(j_DASH_fun8180)?j_DASH_fun8180.app(anf_arg2541944,block1991932):R.ffi.throwNonFunApp(L[1245],j_DASH_fun8180,[anf_arg2541944,block1991932]);
};
try {
if(--R.GAS > 0) {
$z1142711428 = $f1143311434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1143311434,
"from":L[1245]});
}
} catch($e1142511426) {
if(R.isCont($e1142511426)) {
var $ss1142911430 = {"from":L[1245],
"go":function(anf_arg25511435) {
return $Hanf_arg172611436(anf_arg25511435,j_DASH_app9467,j_DASH_parens11391,list35101);
}};
$e1142511426.stack[R.EXN_STACKHEIGHT++] = $ss1142911430;
}
if(R.isPyretException($e1142511426)) {
$e1142511426.pyretStack.push(L[1245]);
}
throw $e1142511426;
}
var $ret1143111432 = $Hanf_arg172611436($z1142711428,j_DASH_app9467,j_DASH_parens11391,list35101);
++R.GAS;
return $ret1143111432;
};
var $Hanf_arg172611436 = function(anf_arg25511435,j_DASH_app9467,j_DASH_parens11391,list35101) {
var $z1143911440 = D;
var $f1144511446 = function(_) {
return R.isFunction(j_DASH_parens11391)?j_DASH_parens11391.app(anf_arg25511435):R.ffi.throwNonFunApp(L[1246],j_DASH_parens11391,[anf_arg25511435]);
};
try {
if(--R.GAS > 0) {
$z1143911440 = $f1144511446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1144511446,
"from":L[1246]});
}
} catch($e1143711438) {
if(R.isCont($e1143711438)) {
var $ss1144111442 = {"from":L[1246],
"go":function(anf_arg25611447) {
return $Hanf_arg172511448(anf_arg25611447,j_DASH_app9467,list35101);
}};
$e1143711438.stack[R.EXN_STACKHEIGHT++] = $ss1144111442;
}
if(R.isPyretException($e1143711438)) {
$e1143711438.pyretStack.push(L[1246]);
}
throw $e1143711438;
}
var $ret1144311444 = $Hanf_arg172511448($z1143911440,j_DASH_app9467,list35101);
++R.GAS;
return $ret1144311444;
};
var $Hanf_arg172511448 = function(anf_arg25611447,j_DASH_app9467,list35101) {
var anf_fun25711459 = G(list35101,"make",L[1247]);
var $z1145111452 = D;
var $f1145711458 = function(_) {
return R.isFunction(anf_fun25711459)?anf_fun25711459.app([]):R.ffi.throwNonFunApp(L[1247],anf_fun25711459,[[]]);
};
try {
if(--R.GAS > 0) {
$z1145111452 = $f1145711458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1145711458,
"from":L[1247]});
}
} catch($e1144911450) {
if(R.isCont($e1144911450)) {
var $ss1145311454 = {"from":L[1247],
"go":function(anf_arg25811460) {
return $Hanf_arg172411461(anf_arg25811460,anf_arg25611447,j_DASH_app9467);
}};
$e1144911450.stack[R.EXN_STACKHEIGHT++] = $ss1145311454;
}
if(R.isPyretException($e1144911450)) {
$e1144911450.pyretStack.push(L[1247]);
}
throw $e1144911450;
}
var $ret1145511456 = $Hanf_arg172411461($z1145111452,anf_arg25611447,j_DASH_app9467);
++R.GAS;
return $ret1145511456;
};
var $Hanf_arg172411461 = function(anf_arg25811460,anf_arg25611447,j_DASH_app9467) {
var $z1146411465 = D;
var $f1147011471 = function(_) {
return R.isFunction(j_DASH_app9467)?j_DASH_app9467.app(anf_arg25611447,anf_arg25811460):R.ffi.throwNonFunApp(L[324],j_DASH_app9467,[anf_arg25611447,anf_arg25811460]);
};
try {
if(--R.GAS > 0) {
$z1146411465 = $f1147011471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1147011471,
"from":L[324]});
}
} catch($e1146211463) {
if(R.isCont($e1146211463)) {
var $ss1146611467 = {"from":L[324],
"go":function(ann_DASH_check_DASH_temp25211472) {
return $Hann_DASH_check_DASH_temp172311473(ann_DASH_check_DASH_temp25211472);
}};
$e1146211463.stack[R.EXN_STACKHEIGHT++] = $ss1146611467;
}
if(R.isPyretException($e1146211463)) {
$e1146211463.pyretStack.push(L[324]);
}
throw $e1146211463;
}
var $ret1146811469 = $Hann_DASH_check_DASH_temp172311473($z1146411465);
++R.GAS;
return $ret1146811469;
};
var $Hann_DASH_check_DASH_temp172311473 = function(ann_DASH_check_DASH_temp25211472) {
return ann_DASH_check_DASH_temp25211472;
};
var $Hanf_arg17221961 = function(anf_arg2431960,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655,rt_DASH_method173657) {
var $z1147611477 = D;
var $f1148211483 = function(_) {
return R.isFunction(rt_DASH_method173657.$var)?rt_DASH_method173657.$var.app(("isFunction"),anf_arg2431960):R.ffi.throwNonFunApp(L[1248],rt_DASH_method173657.$var,[("isFunction"),anf_arg2431960]);
};
try {
if(--R.GAS > 0) {
$z1147611477 = $f1148211483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1148211483,
"from":L[1248]});
}
} catch($e1147411475) {
if(R.isCont($e1147411475)) {
var $ss1147811479 = {"from":L[1248],
"go":function(anf_arg24411484) {
return $Hanf_arg172111485(anf_arg24411484,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655);
}};
$e1147411475.stack[R.EXN_STACKHEIGHT++] = $ss1147811479;
}
if(R.isPyretException($e1147411475)) {
$e1147411475.pyretStack.push(L[1248]);
}
throw $e1147411475;
}
var $ret1148011481 = $Hanf_arg172111485($z1147611477,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655);
++R.GAS;
return $ret1148011481;
};
var $Hanf_arg172111485 = function(anf_arg24411484,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655) {
var $z1148811489 = D;
var $f1149411495 = function(_) {
return R.isFunction(j_DASH_method8486)?j_DASH_method8486.app(f1971947,("app"),args1981948):R.ffi.throwNonFunApp(L[1249],j_DASH_method8486,[f1971947,("app"),args1981948]);
};
try {
if(--R.GAS > 0) {
$z1148811489 = $f1149411495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1149411495,
"from":L[1249]});
}
} catch($e1148611487) {
if(R.isCont($e1148611487)) {
var $ss1149011491 = {"from":L[1249],
"go":function(anf_arg24511496) {
return $Hanf_arg172011497(anf_arg24511496,anf_arg24411484,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655);
}};
$e1148611487.stack[R.EXN_STACKHEIGHT++] = $ss1149011491;
}
if(R.isPyretException($e1148611487)) {
$e1148611487.pyretStack.push(L[1249]);
}
throw $e1148611487;
}
var $ret1149211493 = $Hanf_arg172011497($z1148811489,anf_arg24411484,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655);
++R.GAS;
return $ret1149211493;
};
var $Hanf_arg172011497 = function(anf_arg24511496,anf_arg24411484,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101,rt_DASH_field172655) {
var $z1150011501 = D;
var $f1150611507 = function(_) {
return R.isFunction(rt_DASH_field172655.$var)?rt_DASH_field172655.$var.app(("ffi")):R.ffi.throwNonFunApp(L[1250],rt_DASH_field172655.$var,[("ffi")]);
};
try {
if(--R.GAS > 0) {
$z1150011501 = $f1150611507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1150611507,
"from":L[1250]});
}
} catch($e1149811499) {
if(R.isCont($e1149811499)) {
var $ss1150211503 = {"from":L[1250],
"go":function(anf_arg24611508) {
return $Hanf_arg171911509(anf_arg24611508,anf_arg24411484,anf_arg24511496,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101);
}};
$e1149811499.stack[R.EXN_STACKHEIGHT++] = $ss1150211503;
}
if(R.isPyretException($e1149811499)) {
$e1149811499.pyretStack.push(L[1250]);
}
throw $e1149811499;
}
var $ret1150411505 = $Hanf_arg171911509($z1150011501,anf_arg24411484,anf_arg24511496,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101);
++R.GAS;
return $ret1150411505;
};
var $Hanf_arg171911509 = function(anf_arg24611508,anf_arg24411484,anf_arg24511496,args1981948,f1971947,j_DASH_list9585,j_DASH_method8486,j_DASH_ternary11194,l1961946,list35101) {
var anf_fun24711521 = G(list35101,"make",L[1252]);
var $z1151211513 = D;
var $f1151811519 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),args1981948):R.ffi.throwNonFunApp(L[1251],j_DASH_list9585,[(false),args1981948]);
};
try {
if(--R.GAS > 0) {
$z1151211513 = $f1151811519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1151811519,
"from":L[1251]});
}
} catch($e1151011511) {
if(R.isCont($e1151011511)) {
var $ss1151411515 = {"from":L[1251],
"go":function(anf_array_val24811520) {
return $Hanf_array_val171811522(anf_array_val24811520,anf_arg24411484,anf_arg24511496,anf_arg24611508,anf_fun24711521,f1971947,j_DASH_method8486,j_DASH_ternary11194,l1961946);
}};
$e1151011511.stack[R.EXN_STACKHEIGHT++] = $ss1151411515;
}
if(R.isPyretException($e1151011511)) {
$e1151011511.pyretStack.push(L[1251]);
}
throw $e1151011511;
}
var $ret1151611517 = $Hanf_array_val171811522($z1151211513,anf_arg24411484,anf_arg24511496,anf_arg24611508,anf_fun24711521,f1971947,j_DASH_method8486,j_DASH_ternary11194,l1961946);
++R.GAS;
return $ret1151611517;
};
var $Hanf_array_val171811522 = function(anf_array_val24811520,anf_arg24411484,anf_arg24511496,anf_arg24611508,anf_fun24711521,f1971947,j_DASH_method8486,j_DASH_ternary11194,l1961946) {
var $z1152511526 = D;
var $f1153111532 = function(_) {
return R.isFunction(anf_fun24711521)?anf_fun24711521.app([l1961946,f1971947,anf_array_val24811520]):R.ffi.throwNonFunApp(L[1252],anf_fun24711521,[[l1961946,f1971947,anf_array_val24811520]]);
};
try {
if(--R.GAS > 0) {
$z1152511526 = $f1153111532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1153111532,
"from":L[1252]});
}
} catch($e1152311524) {
if(R.isCont($e1152311524)) {
var $ss1152711528 = {"from":L[1252],
"go":function(anf_arg24911533) {
return $Hanf_arg171711534(anf_arg24911533,anf_arg24411484,anf_arg24511496,anf_arg24611508,j_DASH_method8486,j_DASH_ternary11194);
}};
$e1152311524.stack[R.EXN_STACKHEIGHT++] = $ss1152711528;
}
if(R.isPyretException($e1152311524)) {
$e1152311524.pyretStack.push(L[1252]);
}
throw $e1152311524;
}
var $ret1152911530 = $Hanf_arg171711534($z1152511526,anf_arg24411484,anf_arg24511496,anf_arg24611508,j_DASH_method8486,j_DASH_ternary11194);
++R.GAS;
return $ret1152911530;
};
var $Hanf_arg171711534 = function(anf_arg24911533,anf_arg24411484,anf_arg24511496,anf_arg24611508,j_DASH_method8486,j_DASH_ternary11194) {
var $z1153711538 = D;
var $f1154311544 = function(_) {
return R.isFunction(j_DASH_method8486)?j_DASH_method8486.app(anf_arg24611508,("throwNonFunApp"),anf_arg24911533):R.ffi.throwNonFunApp(L[1253],j_DASH_method8486,[anf_arg24611508,("throwNonFunApp"),anf_arg24911533]);
};
try {
if(--R.GAS > 0) {
$z1153711538 = $f1154311544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1154311544,
"from":L[1253]});
}
} catch($e1153511536) {
if(R.isCont($e1153511536)) {
var $ss1153911540 = {"from":L[1253],
"go":function(anf_arg25011545) {
return $Hanf_arg171611546(anf_arg25011545,anf_arg24411484,anf_arg24511496,j_DASH_ternary11194);
}};
$e1153511536.stack[R.EXN_STACKHEIGHT++] = $ss1153911540;
}
if(R.isPyretException($e1153511536)) {
$e1153511536.pyretStack.push(L[1253]);
}
throw $e1153511536;
}
var $ret1154111542 = $Hanf_arg171611546($z1153711538,anf_arg24411484,anf_arg24511496,j_DASH_ternary11194);
++R.GAS;
return $ret1154111542;
};
var $Hanf_arg171611546 = function(anf_arg25011545,anf_arg24411484,anf_arg24511496,j_DASH_ternary11194) {
var $z1154911550 = D;
var $f1155511556 = function(_) {
return R.isFunction(j_DASH_ternary11194)?j_DASH_ternary11194.app(anf_arg24411484,anf_arg24511496,anf_arg25011545):R.ffi.throwNonFunApp(L[326],j_DASH_ternary11194,[anf_arg24411484,anf_arg24511496,anf_arg25011545]);
};
try {
if(--R.GAS > 0) {
$z1154911550 = $f1155511556();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1155511556,
"from":L[326]});
}
} catch($e1154711548) {
if(R.isCont($e1154711548)) {
var $ss1155111552 = {"from":L[326],
"go":function(ann_DASH_check_DASH_temp24111557) {
return $Hann_DASH_check_DASH_temp171511558(ann_DASH_check_DASH_temp24111557);
}};
$e1154711548.stack[R.EXN_STACKHEIGHT++] = $ss1155111552;
}
if(R.isPyretException($e1154711548)) {
$e1154711548.pyretStack.push(L[326]);
}
throw $e1154711548;
}
var $ret1155311554 = $Hann_DASH_check_DASH_temp171511558($z1154911550);
++R.GAS;
return $ret1155311554;
};
var $Hann_DASH_check_DASH_temp171511558 = function(ann_DASH_check_DASH_temp24111557) {
return ann_DASH_check_DASH_temp24111557;
};
var $Hanf_arg17141975 = function(anf_arg2391974,args1951963,j_DASH_method8486,name1941962) {
var $z1156111562 = D;
var $f1156711568 = function(_) {
return R.isFunction(j_DASH_method8486)?j_DASH_method8486.app(anf_arg2391974,name1941962,args1951963):R.ffi.throwNonFunApp(L[328],j_DASH_method8486,[anf_arg2391974,name1941962,args1951963]);
};
try {
if(--R.GAS > 0) {
$z1156111562 = $f1156711568();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1156711568,
"from":L[328]});
}
} catch($e1155911560) {
if(R.isCont($e1155911560)) {
var $ss1156311564 = {"from":L[328],
"go":function(ann_DASH_check_DASH_temp23811569) {
return $Hann_DASH_check_DASH_temp171311570(ann_DASH_check_DASH_temp23811569);
}};
$e1155911560.stack[R.EXN_STACKHEIGHT++] = $ss1156311564;
}
if(R.isPyretException($e1155911560)) {
$e1155911560.pyretStack.push(L[328]);
}
throw $e1155911560;
}
var $ret1156511566 = $Hann_DASH_check_DASH_temp171311570($z1156111562);
++R.GAS;
return $ret1156511566;
};
var $Hann_DASH_check_DASH_temp171311570 = function(ann_DASH_check_DASH_temp23811569) {
return ann_DASH_check_DASH_temp23811569;
};
var $Hanf_arg17121988 = function(anf_arg2361987,j_DASH_dot9775,name1931976) {
var $z1157311574 = D;
var $f1157911580 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(anf_arg2361987,name1931976):R.ffi.throwNonFunApp(L[330],j_DASH_dot9775,[anf_arg2361987,name1931976]);
};
try {
if(--R.GAS > 0) {
$z1157311574 = $f1157911580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1157911580,
"from":L[330]});
}
} catch($e1157111572) {
if(R.isCont($e1157111572)) {
var $ss1157511576 = {"from":L[330],
"go":function(ann_DASH_check_DASH_temp23511581) {
return $Hann_DASH_check_DASH_temp171111582(ann_DASH_check_DASH_temp23511581);
}};
$e1157111572.stack[R.EXN_STACKHEIGHT++] = $ss1157511576;
}
if(R.isPyretException($e1157111572)) {
$e1157111572.pyretStack.push(L[330]);
}
throw $e1157111572;
}
var $ret1157711578 = $Hann_DASH_check_DASH_temp171111582($z1157311574);
++R.GAS;
return $ret1157711578;
};
var $Hann_DASH_check_DASH_temp171111582 = function(ann_DASH_check_DASH_temp23511581) {
return ann_DASH_check_DASH_temp23511581;
};
var $Hanf_arg17102002 = function(anf_arg2302001,j_DASH_dot9775,j_DASH_method8486,list35101,loc1921990) {
var $z1158511586 = D;
var $f1159111592 = function(_) {
return R.isFunction(j_DASH_dot9775)?j_DASH_dot9775.app(anf_arg2302001,("pyretStack")):R.ffi.throwNonFunApp(L[1254],j_DASH_dot9775,[anf_arg2302001,("pyretStack")]);
};
try {
if(--R.GAS > 0) {
$z1158511586 = $f1159111592();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1159111592,
"from":L[1254]});
}
} catch($e1158311584) {
if(R.isCont($e1158311584)) {
var $ss1158711588 = {"from":L[1254],
"go":function(anf_arg23111593) {
return $Hanf_arg170911594(anf_arg23111593,j_DASH_method8486,list35101,loc1921990);
}};
$e1158311584.stack[R.EXN_STACKHEIGHT++] = $ss1158711588;
}
if(R.isPyretException($e1158311584)) {
$e1158311584.pyretStack.push(L[1254]);
}
throw $e1158311584;
}
var $ret1158911590 = $Hanf_arg170911594($z1158511586,j_DASH_method8486,list35101,loc1921990);
++R.GAS;
return $ret1158911590;
};
var $Hanf_arg170911594 = function(anf_arg23111593,j_DASH_method8486,list35101,loc1921990) {
var anf_fun23211605 = G(list35101,"make",L[1255]);
var $z1159711598 = D;
var $f1160311604 = function(_) {
return R.isFunction(anf_fun23211605)?anf_fun23211605.app([loc1921990]):R.ffi.throwNonFunApp(L[1255],anf_fun23211605,[[loc1921990]]);
};
try {
if(--R.GAS > 0) {
$z1159711598 = $f1160311604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1160311604,
"from":L[1255]});
}
} catch($e1159511596) {
if(R.isCont($e1159511596)) {
var $ss1159911600 = {"from":L[1255],
"go":function(anf_arg23311606) {
return $Hanf_arg170811607(anf_arg23311606,anf_arg23111593,j_DASH_method8486);
}};
$e1159511596.stack[R.EXN_STACKHEIGHT++] = $ss1159911600;
}
if(R.isPyretException($e1159511596)) {
$e1159511596.pyretStack.push(L[1255]);
}
throw $e1159511596;
}
var $ret1160111602 = $Hanf_arg170811607($z1159711598,anf_arg23111593,j_DASH_method8486);
++R.GAS;
return $ret1160111602;
};
var $Hanf_arg170811607 = function(anf_arg23311606,anf_arg23111593,j_DASH_method8486) {
var $z1161011611 = D;
var $f1161611617 = function(_) {
return R.isFunction(j_DASH_method8486)?j_DASH_method8486.app(anf_arg23111593,("push"),anf_arg23311606):R.ffi.throwNonFunApp(L[332],j_DASH_method8486,[anf_arg23111593,("push"),anf_arg23311606]);
};
try {
if(--R.GAS > 0) {
$z1161011611 = $f1161611617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1161611617,
"from":L[332]});
}
} catch($e1160811609) {
if(R.isCont($e1160811609)) {
var $ss1161211613 = {"from":L[332],
"go":function(ann_DASH_check_DASH_temp22911618) {
return $Hann_DASH_check_DASH_temp170711619(ann_DASH_check_DASH_temp22911618);
}};
$e1160811609.stack[R.EXN_STACKHEIGHT++] = $ss1161211613;
}
if(R.isPyretException($e1160811609)) {
$e1160811609.pyretStack.push(L[332]);
}
throw $e1160811609;
}
var $ret1161411615 = $Hann_DASH_check_DASH_temp170711619($z1161011611);
++R.GAS;
return $ret1161411615;
};
var $Hann_DASH_check_DASH_temp170711619 = function(ann_DASH_check_DASH_temp22911618) {
return ann_DASH_check_DASH_temp22911618;
};
var $Hanf_array_val17062017 = function(anf_array_val2262015,anf_fun2252016,j_DASH_app9467,loc1892003,throw_DASH_uninitialized115116) {
var $z1162211623 = D;
var $f1162811629 = function(_) {
return R.isFunction(anf_fun2252016)?anf_fun2252016.app([loc1892003,anf_array_val2262015]):R.ffi.throwNonFunApp(L[336],anf_fun2252016,[[loc1892003,anf_array_val2262015]]);
};
try {
if(--R.GAS > 0) {
$z1162211623 = $f1162811629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1162811629,
"from":L[336]});
}
} catch($e1162011621) {
if(R.isCont($e1162011621)) {
var $ss1162411625 = {"from":L[336],
"go":function(anf_arg22711630) {
return $Hanf_arg170511631(anf_arg22711630,j_DASH_app9467,throw_DASH_uninitialized115116);
}};
$e1162011621.stack[R.EXN_STACKHEIGHT++] = $ss1162411625;
}
if(R.isPyretException($e1162011621)) {
$e1162011621.pyretStack.push(L[336]);
}
throw $e1162011621;
}
var $ret1162611627 = $Hanf_arg170511631($z1162211623,j_DASH_app9467,throw_DASH_uninitialized115116);
++R.GAS;
return $ret1162611627;
};
var $Hanf_arg170511631 = function(anf_arg22711630,j_DASH_app9467,throw_DASH_uninitialized115116) {
var $z1163411635 = D;
var $f1164011641 = function(_) {
return R.isFunction(j_DASH_app9467)?j_DASH_app9467.app(throw_DASH_uninitialized115116,anf_arg22711630):R.ffi.throwNonFunApp(L[334],j_DASH_app9467,[throw_DASH_uninitialized115116,anf_arg22711630]);
};
try {
if(--R.GAS > 0) {
$z1163411635 = $f1164011641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1164011641,
"from":L[334]});
}
} catch($e1163211633) {
if(R.isCont($e1163211633)) {
var $ss1163611637 = {"from":L[334],
"go":function(ann_DASH_check_DASH_temp22411642) {
return $Hann_DASH_check_DASH_temp170411643(ann_DASH_check_DASH_temp22411642);
}};
$e1163211633.stack[R.EXN_STACKHEIGHT++] = $ss1163611637;
}
if(R.isPyretException($e1163211633)) {
$e1163211633.pyretStack.push(L[334]);
}
throw $e1163211633;
}
var $ret1163811639 = $Hann_DASH_check_DASH_temp170411643($z1163411635);
++R.GAS;
return $ret1163811639;
};
var $Hann_DASH_check_DASH_temp170411643 = function(ann_DASH_check_DASH_temp22411642) {
return ann_DASH_check_DASH_temp22411642;
};
var $Hanf_arg17032033 = function(anf_arg2222032,get_DASH_field_DASH_loc11459,j_DASH_app9467) {
var $z1164611647 = D;
var $f1165211653 = function(_) {
return R.isFunction(j_DASH_app9467)?j_DASH_app9467.app(get_DASH_field_DASH_loc11459,anf_arg2222032):R.ffi.throwNonFunApp(L[337],j_DASH_app9467,[get_DASH_field_DASH_loc11459,anf_arg2222032]);
};
try {
if(--R.GAS > 0) {
$z1164611647 = $f1165211653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1165211653,
"from":L[337]});
}
} catch($e1164411645) {
if(R.isCont($e1164411645)) {
var $ss1164811649 = {"from":L[337],
"go":function(ann_DASH_check_DASH_temp22011654) {
return $Hann_DASH_check_DASH_temp170211655(ann_DASH_check_DASH_temp22011654);
}};
$e1164411645.stack[R.EXN_STACKHEIGHT++] = $ss1164811649;
}
if(R.isPyretException($e1164411645)) {
$e1164411645.pyretStack.push(L[337]);
}
throw $e1164411645;
}
var $ret1165011651 = $Hann_DASH_check_DASH_temp170211655($z1164611647);
++R.GAS;
return $ret1165011651;
};
var $Hann_DASH_check_DASH_temp170211655 = function(ann_DASH_check_DASH_temp22011654) {
return ann_DASH_check_DASH_temp22011654;
};
var $Hanf_array_val17012047 = function(anf_array_val2052045,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034) {
var anf_arg20611666 = G(l1852034,"start-line",L[1257]);
var $z1165811659 = D;
var $f1166411665 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(anf_arg20611666):R.ffi.throwNonFunApp(L[1256],j_DASH_num8889,[anf_arg20611666]);
};
try {
if(--R.GAS > 0) {
$z1165811659 = $f1166411665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1166411665,
"from":L[1256]});
}
} catch($e1165611657) {
if(R.isCont($e1165611657)) {
var $ss1166011661 = {"from":L[1256],
"go":function(anf_array_val20711667) {
return $Hanf_array_val170011668(anf_array_val20711667,anf_array_val2052045,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
}};
$e1165611657.stack[R.EXN_STACKHEIGHT++] = $ss1166011661;
}
if(R.isPyretException($e1165611657)) {
$e1165611657.pyretStack.push(L[1256]);
}
throw $e1165611657;
}
var $ret1166211663 = $Hanf_array_val170011668($z1165811659,anf_array_val2052045,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
++R.GAS;
return $ret1166211663;
};
var $Hanf_array_val170011668 = function(anf_array_val20711667,anf_array_val2052045,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034) {
var anf_arg20811679 = G(l1852034,"start-column",L[1259]);
var $z1167111672 = D;
var $f1167711678 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(anf_arg20811679):R.ffi.throwNonFunApp(L[1258],j_DASH_num8889,[anf_arg20811679]);
};
try {
if(--R.GAS > 0) {
$z1167111672 = $f1167711678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1167711678,
"from":L[1258]});
}
} catch($e1166911670) {
if(R.isCont($e1166911670)) {
var $ss1167311674 = {"from":L[1258],
"go":function(anf_array_val20911680) {
return $Hanf_array_val169911681(anf_array_val20911680,anf_array_val2052045,anf_array_val20711667,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
}};
$e1166911670.stack[R.EXN_STACKHEIGHT++] = $ss1167311674;
}
if(R.isPyretException($e1166911670)) {
$e1166911670.pyretStack.push(L[1258]);
}
throw $e1166911670;
}
var $ret1167511676 = $Hanf_array_val169911681($z1167111672,anf_array_val2052045,anf_array_val20711667,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
++R.GAS;
return $ret1167511676;
};
var $Hanf_array_val169911681 = function(anf_array_val20911680,anf_array_val2052045,anf_array_val20711667,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034) {
var anf_arg21011692 = G(l1852034,"start-char",L[1261]);
var $z1168411685 = D;
var $f1169011691 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(anf_arg21011692):R.ffi.throwNonFunApp(L[1260],j_DASH_num8889,[anf_arg21011692]);
};
try {
if(--R.GAS > 0) {
$z1168411685 = $f1169011691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1169011691,
"from":L[1260]});
}
} catch($e1168211683) {
if(R.isCont($e1168211683)) {
var $ss1168611687 = {"from":L[1260],
"go":function(anf_array_val21111693) {
return $Hanf_array_val169811694(anf_array_val21111693,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
}};
$e1168211683.stack[R.EXN_STACKHEIGHT++] = $ss1168611687;
}
if(R.isPyretException($e1168211683)) {
$e1168211683.pyretStack.push(L[1260]);
}
throw $e1168211683;
}
var $ret1168811689 = $Hanf_array_val169811694($z1168411685,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
++R.GAS;
return $ret1168811689;
};
var $Hanf_array_val169811694 = function(anf_array_val21111693,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034) {
var anf_arg21211705 = G(l1852034,"end-line",L[1263]);
var $z1169711698 = D;
var $f1170311704 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(anf_arg21211705):R.ffi.throwNonFunApp(L[1262],j_DASH_num8889,[anf_arg21211705]);
};
try {
if(--R.GAS > 0) {
$z1169711698 = $f1170311704();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1170311704,
"from":L[1262]});
}
} catch($e1169511696) {
if(R.isCont($e1169511696)) {
var $ss1169911700 = {"from":L[1262],
"go":function(anf_array_val21311706) {
return $Hanf_array_val169711707(anf_array_val21311706,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
}};
$e1169511696.stack[R.EXN_STACKHEIGHT++] = $ss1169911700;
}
if(R.isPyretException($e1169511696)) {
$e1169511696.pyretStack.push(L[1262]);
}
throw $e1169511696;
}
var $ret1170111702 = $Hanf_array_val169711707($z1169711698,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
++R.GAS;
return $ret1170111702;
};
var $Hanf_array_val169711707 = function(anf_array_val21311706,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034) {
var anf_arg21411718 = G(l1852034,"end-column",L[1265]);
var $z1171011711 = D;
var $f1171611717 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(anf_arg21411718):R.ffi.throwNonFunApp(L[1264],j_DASH_num8889,[anf_arg21411718]);
};
try {
if(--R.GAS > 0) {
$z1171011711 = $f1171611717();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1171611717,
"from":L[1264]});
}
} catch($e1170811709) {
if(R.isCont($e1170811709)) {
var $ss1171211713 = {"from":L[1264],
"go":function(anf_array_val21511719) {
return $Hanf_array_val169611720(anf_array_val21511719,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_array_val21311706,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
}};
$e1170811709.stack[R.EXN_STACKHEIGHT++] = $ss1171211713;
}
if(R.isPyretException($e1170811709)) {
$e1170811709.pyretStack.push(L[1264]);
}
throw $e1170811709;
}
var $ret1171411715 = $Hanf_array_val169611720($z1171011711,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_array_val21311706,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034);
++R.GAS;
return $ret1171411715;
};
var $Hanf_array_val169611720 = function(anf_array_val21511719,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_array_val21311706,anf_fun2042046,j_DASH_list9585,j_DASH_num8889,l1852034) {
var anf_arg21611731 = G(l1852034,"end-char",L[1267]);
var $z1172311724 = D;
var $f1172911730 = function(_) {
return R.isFunction(j_DASH_num8889)?j_DASH_num8889.app(anf_arg21611731):R.ffi.throwNonFunApp(L[1266],j_DASH_num8889,[anf_arg21611731]);
};
try {
if(--R.GAS > 0) {
$z1172311724 = $f1172911730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1172911730,
"from":L[1266]});
}
} catch($e1172111722) {
if(R.isCont($e1172111722)) {
var $ss1172511726 = {"from":L[1266],
"go":function(anf_array_val21711732) {
return $Hanf_array_val169511733(anf_array_val21711732,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_array_val21311706,anf_array_val21511719,anf_fun2042046,j_DASH_list9585);
}};
$e1172111722.stack[R.EXN_STACKHEIGHT++] = $ss1172511726;
}
if(R.isPyretException($e1172111722)) {
$e1172111722.pyretStack.push(L[1266]);
}
throw $e1172111722;
}
var $ret1172711728 = $Hanf_array_val169511733($z1172311724,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_array_val21311706,anf_array_val21511719,anf_fun2042046,j_DASH_list9585);
++R.GAS;
return $ret1172711728;
};
var $Hanf_array_val169511733 = function(anf_array_val21711732,anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_array_val21311706,anf_array_val21511719,anf_fun2042046,j_DASH_list9585) {
var $z1173611737 = D;
var $f1174211743 = function(_) {
return R.isFunction(anf_fun2042046)?anf_fun2042046.app([anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_array_val21311706,anf_array_val21511719,anf_array_val21711732]):R.ffi.throwNonFunApp(L[341],anf_fun2042046,[[anf_array_val2052045,anf_array_val20711667,anf_array_val20911680,anf_array_val21111693,anf_array_val21311706,anf_array_val21511719,anf_array_val21711732]]);
};
try {
if(--R.GAS > 0) {
$z1173611737 = $f1174211743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1174211743,
"from":L[341]});
}
} catch($e1173411735) {
if(R.isCont($e1173411735)) {
var $ss1173811739 = {"from":L[341],
"go":function(anf_arg21811744) {
return $Hanf_arg169411745(anf_arg21811744,j_DASH_list9585);
}};
$e1173411735.stack[R.EXN_STACKHEIGHT++] = $ss1173811739;
}
if(R.isPyretException($e1173411735)) {
$e1173411735.pyretStack.push(L[341]);
}
throw $e1173411735;
}
var $ret1174011741 = $Hanf_arg169411745($z1173611737,j_DASH_list9585);
++R.GAS;
return $ret1174011741;
};
var $Hanf_arg169411745 = function(anf_arg21811744,j_DASH_list9585) {
var $z1174811749 = D;
var $f1175411755 = function(_) {
return R.isFunction(j_DASH_list9585)?j_DASH_list9585.app((false),anf_arg21811744):R.ffi.throwNonFunApp(L[339],j_DASH_list9585,[(false),anf_arg21811744]);
};
try {
if(--R.GAS > 0) {
$z1174811749 = $f1175411755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1175411755,
"from":L[339]});
}
} catch($e1174611747) {
if(R.isCont($e1174611747)) {
var $ss1175011751 = {"from":L[339],
"go":function(ann_DASH_check_DASH_temp20311756) {
return $Hann_DASH_check_DASH_temp169311757(ann_DASH_check_DASH_temp20311756);
}};
$e1174611747.stack[R.EXN_STACKHEIGHT++] = $ss1175011751;
}
if(R.isPyretException($e1174611747)) {
$e1174611747.pyretStack.push(L[339]);
}
throw $e1174611747;
}
var $ret1175211753 = $Hann_DASH_check_DASH_temp169311757($z1174811749);
++R.GAS;
return $ret1175211753;
};
var $Hann_DASH_check_DASH_temp169311757 = function(ann_DASH_check_DASH_temp20311756) {
return ann_DASH_check_DASH_temp20311756;
};
var $Hanf_arg16922061 = function(anf_arg2012059,anf_fun2002060) {
var $z1176011761 = D;
var $f1176611767 = function(_) {
return R.isFunction(anf_fun2002060)?anf_fun2002060.app(anf_arg2012059):R.ffi.throwNonFunApp(L[342],anf_fun2002060,[anf_arg2012059]);
};
try {
if(--R.GAS > 0) {
$z1176011761 = $f1176611767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1176611767,
"from":L[342]});
}
} catch($e1175811759) {
if(R.isCont($e1175811759)) {
var $ss1176211763 = {"from":L[342],
"go":function(ann_DASH_check_DASH_temp19911768) {
return $Hann_DASH_check_DASH_temp169111769(ann_DASH_check_DASH_temp19911768);
}};
$e1175811759.stack[R.EXN_STACKHEIGHT++] = $ss1176211763;
}
if(R.isPyretException($e1175811759)) {
$e1175811759.pyretStack.push(L[342]);
}
throw $e1175811759;
}
var $ret1176411765 = $Hann_DASH_check_DASH_temp169111769($z1176011761);
++R.GAS;
return $ret1176411765;
};
var $Hann_DASH_check_DASH_temp169111769 = function(ann_DASH_check_DASH_temp19911768) {
return ann_DASH_check_DASH_temp19911768;
};
var $Hanf_arg16902075 = function(anf_arg1772073,G922,id1642062,js_DASH_ids1632074,_plus5,not8,nothing9,raise11,string_DASH_replace12,torepr13) {
var $z1177211773 = D;
var $f1177811779 = function(_) {
return R.isFunction(not8)?not8.app(anf_arg1772073):R.ffi.throwNonFunApp(L[1268],not8,[anf_arg1772073]);
};
try {
if(--R.GAS > 0) {
$z1177211773 = $f1177811779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1177811779,
"from":L[1268]});
}
} catch($e1177011771) {
if(R.isCont($e1177011771)) {
var $ss1177411775 = {"from":L[1268],
"go":function(when_DASH_3111780) {
return $Hwhen_DASH_168911781(when_DASH_3111780,G922,id1642062,js_DASH_ids1632074,_plus5,nothing9,raise11,string_DASH_replace12,torepr13);
}};
$e1177011771.stack[R.EXN_STACKHEIGHT++] = $ss1177411775;
}
if(R.isPyretException($e1177011771)) {
$e1177011771.pyretStack.push(L[1268]);
}
throw $e1177011771;
}
var $ret1177611777 = $Hwhen_DASH_168911781($z1177211773,G922,id1642062,js_DASH_ids1632074,_plus5,nothing9,raise11,string_DASH_replace12,torepr13);
++R.GAS;
return $ret1177611777;
};
var $Hwhen_DASH_168911781 = function(when_DASH_3111780,G922,id1642062,js_DASH_ids1632074,_plus5,nothing9,raise11,string_DASH_replace12,torepr13) {
var if_helper17811793 = R.makeFunction(function(if_helper_arg17911811) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1268],1,arguments);
}
if_helper_arg17911811;
var anf_fun18011822 = G(js_DASH_ids1632074.$var,"has-key",L[1272]);
var $z1181411815 = D;
var $f1182011821 = function(_) {
return R.isFunction(anf_fun18011822)?anf_fun18011822.app(id1642062):R.ffi.throwNonFunApp(L[1271],anf_fun18011822,[id1642062]);
};
try {
if(--R.GAS > 0) {
$z1181411815 = $f1182011821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1182011821,
"from":L[1271]});
}
} catch($e1181211813) {
if(R.isCont($e1181211813)) {
var $ss1181611817 = {"from":L[1271],
"go":function(if_DASH_3211823) {
return $Hif_DASH_168211824(if_DASH_3211823,G922,id1642062,js_DASH_ids1632074,string_DASH_replace12);
}};
$e1181211813.stack[R.EXN_STACKHEIGHT++] = $ss1181611817;
}
if(R.isPyretException($e1181211813)) {
$e1181211813.pyretStack.push(L[1271]);
}
throw $e1181211813;
}
var $ret1181811819 = $Hif_DASH_168211824($z1181411815,G922,id1642062,js_DASH_ids1632074,string_DASH_replace12);
++R.GAS;
return $ret1181811819;
});
var anf_if19411810 = R.isBoolean(when_DASH_3111780);
if(R.isPyretTrue(anf_if19411810)) {
if(R.isPyretTrue(when_DASH_3111780)) {
var $z1178411785 = D;
var $f1179011791 = function(_) {
return R.isFunction(torepr13)?torepr13.app(id1642062):R.ffi.throwNonFunApp(L[1269],torepr13,[id1642062]);
};
try {
if(--R.GAS > 0) {
$z1178411785 = $f1179011791();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1179011791,
"from":L[1269]});
}
} catch($e1178211783) {
if(R.isCont($e1178211783)) {
var $ss1178611787 = {"from":L[1269],
"go":function(anf_arg19611792) {
return $Hanf_arg168711794(anf_arg19611792,if_helper17811793,_plus5,nothing9,raise11);
}};
$e1178211783.stack[R.EXN_STACKHEIGHT++] = $ss1178611787;
}
if(R.isPyretException($e1178211783)) {
$e1178211783.pyretStack.push(L[1269]);
}
throw $e1178211783;
}
var $ret1178811789 = $Hanf_arg168711794($z1178411785,if_helper17811793,_plus5,nothing9,raise11);
++R.GAS;
return $ret1178811789;
} else {
var $z1179711798 = D;
var $f1180311804 = function(_) {
return R.isFunction(if_helper17811793)?if_helper17811793.app(nothing9):R.ffi.throwNonFunApp(L[1268],if_helper17811793,[nothing9]);
};
try {
if(--R.GAS > 0) {
$z1179711798 = $f1180311804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1180311804,
"from":L[1268]});
}
} catch($e1179511796) {
if(R.isCont($e1179511796)) {
var $ss1179911800 = {"from":L[1268],
"go":function(cont_tail_app19511805) {
return $Hcont_tail_app168811806(cont_tail_app19511805);
}};
$e1179511796.stack[R.EXN_STACKHEIGHT++] = $ss1179911800;
}
if(R.isPyretException($e1179511796)) {
$e1179511796.pyretStack.push(L[1268]);
}
throw $e1179511796;
}
var $ret1180111802 = $Hcont_tail_app168811806($z1179711798);
++R.GAS;
return $ret1180111802;
}
} else {
var cont_tail_arg19211809 = R.throwNonBooleanCondition(L[1270],("when"),when_DASH_3111780);
if(--R.GAS > 0) {
$z1180711808 = R.isFunction(if_helper17811793)?if_helper17811793.app(cont_tail_arg19211809):R.ffi.throwNonFunApp(L[1270],if_helper17811793,[cont_tail_arg19211809]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper17811793)?if_helper17811793.app(cont_tail_arg19211809):R.ffi.throwNonFunApp(L[1270],if_helper17811793,[cont_tail_arg19211809]);
},
"from":L[1270]});
}
++R.GAS;
return $z1180711808;
}
};
var $Hanf_arg168711794 = function(anf_arg19611792,if_helper17811793,_plus5,nothing9,raise11) {
var $z1182711828 = D;
var $f1183311834 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("js-id-of got non-string: "),anf_arg19611792):R.ffi.throwNonFunApp(L[1273],_plus5,[("js-id-of got non-string: "),anf_arg19611792]);
};
try {
if(--R.GAS > 0) {
$z1182711828 = $f1183311834();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1183311834,
"from":L[1273]});
}
} catch($e1182511826) {
if(R.isCont($e1182511826)) {
var $ss1182911830 = {"from":L[1273],
"go":function(anf_arg19711835) {
return $Hanf_arg168611836(anf_arg19711835,if_helper17811793,nothing9,raise11);
}};
$e1182511826.stack[R.EXN_STACKHEIGHT++] = $ss1182911830;
}
if(R.isPyretException($e1182511826)) {
$e1182511826.pyretStack.push(L[1273]);
}
throw $e1182511826;
}
var $ret1183111832 = $Hanf_arg168611836($z1182711828,if_helper17811793,nothing9,raise11);
++R.GAS;
return $ret1183111832;
};
var $Hanf_arg168611836 = function(anf_arg19711835,if_helper17811793,nothing9,raise11) {
var $z1183911840 = D;
var $f1184511846 = function(_) {
return R.isFunction(raise11)?raise11.app(anf_arg19711835):R.ffi.throwNonFunApp(L[1274],raise11,[anf_arg19711835]);
};
try {
if(--R.GAS > 0) {
$z1183911840 = $f1184511846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1184511846,
"from":L[1274]});
}
} catch($e1183711838) {
if(R.isCont($e1183711838)) {
var $ss1184111842 = {"from":L[1274],
"go":function(anf_begin_app_dropped168311847) {
return $Hanf_begin_app_dropped168511848(anf_begin_app_dropped168311847,if_helper17811793,nothing9);
}};
$e1183711838.stack[R.EXN_STACKHEIGHT++] = $ss1184111842;
}
if(R.isPyretException($e1183711838)) {
$e1183711838.pyretStack.push(L[1274]);
}
throw $e1183711838;
}
var $ret1184311844 = $Hanf_begin_app_dropped168511848($z1183911840,if_helper17811793,nothing9);
++R.GAS;
return $ret1184311844;
};
var $Hanf_begin_app_dropped168511848 = function(anf_begin_app_dropped168311847,if_helper17811793,nothing9) {
var $z1185111852 = D;
var $f1185711858 = function(_) {
return R.isFunction(if_helper17811793)?if_helper17811793.app(nothing9):R.ffi.throwNonFunApp(L[1268],if_helper17811793,[nothing9]);
};
try {
if(--R.GAS > 0) {
$z1185111852 = $f1185711858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1185711858,
"from":L[1268]});
}
} catch($e1184911850) {
if(R.isCont($e1184911850)) {
var $ss1185311854 = {"from":L[1268],
"go":function(cont_tail_app19811859) {
return $Hcont_tail_app168411860(cont_tail_app19811859);
}};
$e1184911850.stack[R.EXN_STACKHEIGHT++] = $ss1185311854;
}
if(R.isPyretException($e1184911850)) {
$e1184911850.pyretStack.push(L[1268]);
}
throw $e1184911850;
}
var $ret1185511856 = $Hcont_tail_app168411860($z1185111852);
++R.GAS;
return $ret1185511856;
};
var $Hcont_tail_app168411860 = function(cont_tail_app19811859) {
return cont_tail_app19811859;
};
var $Hcont_tail_app168811806 = function(cont_tail_app19511805) {
return cont_tail_app19511805;
};
var $Hif_DASH_168211824 = function(if_DASH_3211823,G922,id1642062,js_DASH_ids1632074,string_DASH_replace12) {
var if_helper18111873 = R.makeFunction(function(if_helper_arg18211891) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1271],1,arguments);
}
var ann_DASH_check_DASH_temp17611892 = if_helper_arg18211891;
return ann_DASH_check_DASH_temp17611892;
});
var anf_if18511890 = R.isBoolean(if_DASH_3211823);
if(R.isPyretTrue(anf_if18511890)) {
if(R.isPyretTrue(if_DASH_3211823)) {
var anf_fun18911871 = G(js_DASH_ids1632074.$var,"get",L[1276]);
var $z1186311864 = D;
var $f1186911870 = function(_) {
return R.isFunction(anf_fun18911871)?anf_fun18911871.app(id1642062):R.ffi.throwNonFunApp(L[1275],anf_fun18911871,[id1642062]);
};
try {
if(--R.GAS > 0) {
$z1186311864 = $f1186911870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1186911870,
"from":L[1275]});
}
} catch($e1186111862) {
if(R.isCont($e1186111862)) {
var $ss1186511866 = {"from":L[1275],
"go":function(cont_tail_arg19011872) {
return $Hcont_tail_arg167611874(cont_tail_arg19011872,if_helper18111873);
}};
$e1186111862.stack[R.EXN_STACKHEIGHT++] = $ss1186511866;
}
if(R.isPyretException($e1186111862)) {
$e1186111862.pyretStack.push(L[1275]);
}
throw $e1186111862;
}
var $ret1186711868 = $Hcont_tail_arg167611874($z1186311864,if_helper18111873);
++R.GAS;
return $ret1186711868;
} else {
var $z1187711878 = D;
var $f1188311884 = function(_) {
return R.isFunction(string_DASH_replace12)?string_DASH_replace12.app(id1642062,("-"),("_DASH_")):R.ffi.throwNonFunApp(L[1277],string_DASH_replace12,[id1642062,("-"),("_DASH_")]);
};
try {
if(--R.GAS > 0) {
$z1187711878 = $f1188311884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1188311884,
"from":L[1277]});
}
} catch($e1187511876) {
if(R.isCont($e1187511876)) {
var $ss1187911880 = {"from":L[1277],
"go":function(no_DASH_hyphens16511885) {
return $Hno_DASH_hyphens168111886(no_DASH_hyphens16511885,G922,id1642062,if_helper18111873,js_DASH_ids1632074);
}};
$e1187511876.stack[R.EXN_STACKHEIGHT++] = $ss1187911880;
}
if(R.isPyretException($e1187511876)) {
$e1187511876.pyretStack.push(L[1277]);
}
throw $e1187511876;
}
var $ret1188111882 = $Hno_DASH_hyphens168111886($z1187711878,G922,id1642062,if_helper18111873,js_DASH_ids1632074);
++R.GAS;
return $ret1188111882;
}
} else {
var cont_tail_arg18311889 = R.throwNonBooleanCondition(L[1271],("if"),if_DASH_3211823);
if(--R.GAS > 0) {
$z1188711888 = R.isFunction(if_helper18111873)?if_helper18111873.app(cont_tail_arg18311889):R.ffi.throwNonFunApp(L[1271],if_helper18111873,[cont_tail_arg18311889]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper18111873)?if_helper18111873.app(cont_tail_arg18311889):R.ffi.throwNonFunApp(L[1271],if_helper18111873,[cont_tail_arg18311889]);
},
"from":L[1271]});
}
++R.GAS;
return $z1188711888;
}
};
var $Hcont_tail_arg167611874 = function(cont_tail_arg19011872,if_helper18111873) {
if(--R.GAS > 0) {
$z1189311894 = R.isFunction(if_helper18111873)?if_helper18111873.app(cont_tail_arg19011872):R.ffi.throwNonFunApp(L[1275],if_helper18111873,[cont_tail_arg19011872]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper18111873)?if_helper18111873.app(cont_tail_arg19011872):R.ffi.throwNonFunApp(L[1275],if_helper18111873,[cont_tail_arg19011872]);
},
"from":L[1275]});
}
++R.GAS;
return $z1189311894;
};
var $Hno_DASH_hyphens168111886 = function(no_DASH_hyphens16511885,G922,id1642062,if_helper18111873,js_DASH_ids1632074) {
var anf_fun18611905 = G(G922,"make-name",L[1279]);
var $z1189711898 = D;
var $f1190311904 = function(_) {
return R.isFunction(anf_fun18611905)?anf_fun18611905.app(no_DASH_hyphens16511885):R.ffi.throwNonFunApp(L[1278],anf_fun18611905,[no_DASH_hyphens16511885]);
};
try {
if(--R.GAS > 0) {
$z1189711898 = $f1190311904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1190311904,
"from":L[1278]});
}
} catch($e1189511896) {
if(R.isCont($e1189511896)) {
var $ss1189911900 = {"from":L[1278],
"go":function(safe_DASH_id16611906) {
return $Hsafe_DASH_id168011907(safe_DASH_id16611906,id1642062,if_helper18111873,js_DASH_ids1632074);
}};
$e1189511896.stack[R.EXN_STACKHEIGHT++] = $ss1189911900;
}
if(R.isPyretException($e1189511896)) {
$e1189511896.pyretStack.push(L[1278]);
}
throw $e1189511896;
}
var $ret1190111902 = $Hsafe_DASH_id168011907($z1189711898,id1642062,if_helper18111873,js_DASH_ids1632074);
++R.GAS;
return $ret1190111902;
};
var $Hsafe_DASH_id168011907 = function(safe_DASH_id16611906,id1642062,if_helper18111873,js_DASH_ids1632074) {
var anf_fun18711918 = G(js_DASH_ids1632074.$var,"set",L[1281]);
var $z1191011911 = D;
var $f1191611917 = function(_) {
return R.isFunction(anf_fun18711918)?anf_fun18711918.app(id1642062,safe_DASH_id16611906):R.ffi.throwNonFunApp(L[1280],anf_fun18711918,[id1642062,safe_DASH_id16611906]);
};
try {
if(--R.GAS > 0) {
$z1191011911 = $f1191611917();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1191611917,
"from":L[1280]});
}
} catch($e1190811909) {
if(R.isCont($e1190811909)) {
var $ss1191211913 = {"from":L[1280],
"go":function(anf_begin_app_dropped167711919) {
return $Hanf_begin_app_dropped167911920(anf_begin_app_dropped167711919,if_helper18111873,safe_DASH_id16611906);
}};
$e1190811909.stack[R.EXN_STACKHEIGHT++] = $ss1191211913;
}
if(R.isPyretException($e1190811909)) {
$e1190811909.pyretStack.push(L[1280]);
}
throw $e1190811909;
}
var $ret1191411915 = $Hanf_begin_app_dropped167911920($z1191011911,if_helper18111873,safe_DASH_id16611906);
++R.GAS;
return $ret1191411915;
};
var $Hanf_begin_app_dropped167911920 = function(anf_begin_app_dropped167711919,if_helper18111873,safe_DASH_id16611906) {
var $z1192311924 = D;
var $f1192911930 = function(_) {
return R.isFunction(if_helper18111873)?if_helper18111873.app(safe_DASH_id16611906):R.ffi.throwNonFunApp(L[1282],if_helper18111873,[safe_DASH_id16611906]);
};
try {
if(--R.GAS > 0) {
$z1192311924 = $f1192911930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1192911930,
"from":L[1282]});
}
} catch($e1192111922) {
if(R.isCont($e1192111922)) {
var $ss1192511926 = {"from":L[1282],
"go":function(cont_tail_app18811931) {
return $Hcont_tail_app167811932(cont_tail_app18811931);
}};
$e1192111922.stack[R.EXN_STACKHEIGHT++] = $ss1192511926;
}
if(R.isPyretException($e1192111922)) {
$e1192111922.pyretStack.push(L[1282]);
}
throw $e1192111922;
}
var $ret1192711928 = $Hcont_tail_app167811932($z1192311924);
++R.GAS;
return $ret1192711928;
};
var $Hcont_tail_app167811932 = function(cont_tail_app18811931) {
return cont_tail_app18811931;
};
var $Hanf_arg1674249 = function(anf_arg158247,concat_DASH_snoc130166,f158246,self157248) {
var anf_arg15911943 = G(self157248,"last",L[1284]);
var $z1193511936 = D;
var $f1194111942 = function(_) {
return R.isFunction(f158246)?f158246.app(anf_arg15911943):R.ffi.throwNonFunApp(L[1283],f158246,[anf_arg15911943]);
};
try {
if(--R.GAS > 0) {
$z1193511936 = $f1194111942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1194111942,
"from":L[1283]});
}
} catch($e1193311934) {
if(R.isCont($e1193311934)) {
var $ss1193711938 = {"from":L[1283],
"go":function(anf_arg16011944) {
return $Hanf_arg167311945(anf_arg16011944,anf_arg158247,concat_DASH_snoc130166);
}};
$e1193311934.stack[R.EXN_STACKHEIGHT++] = $ss1193711938;
}
if(R.isPyretException($e1193311934)) {
$e1193311934.pyretStack.push(L[1283]);
}
throw $e1193311934;
}
var $ret1193911940 = $Hanf_arg167311945($z1193511936,anf_arg158247,concat_DASH_snoc130166);
++R.GAS;
return $ret1193911940;
};
var $Hanf_arg167311945 = function(anf_arg16011944,anf_arg158247,concat_DASH_snoc130166) {
var $z1194811949 = D;
var $f1195411955 = function(_) {
return R.isFunction(concat_DASH_snoc130166.$var === D?U(L[1285],"concat-snoc"):concat_DASH_snoc130166.$var)?concat_DASH_snoc130166.$var === D?U(L[1285],"concat-snoc"):concat_DASH_snoc130166.$var.app(anf_arg158247,anf_arg16011944):R.ffi.throwNonFunApp(L[22],concat_DASH_snoc130166.$var === D?U(L[1285],"concat-snoc"):concat_DASH_snoc130166.$var,[anf_arg158247,anf_arg16011944]);
};
try {
if(--R.GAS > 0) {
$z1194811949 = $f1195411955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1195411955,
"from":L[22]});
}
} catch($e1194611947) {
if(R.isCont($e1194611947)) {
var $ss1195011951 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp15511956) {
return $Hann_DASH_check_DASH_temp167211957(ann_DASH_check_DASH_temp15511956);
}};
$e1194611947.stack[R.EXN_STACKHEIGHT++] = $ss1195011951;
}
if(R.isPyretException($e1194611947)) {
$e1194611947.pyretStack.push(L[22]);
}
throw $e1194611947;
}
var $ret1195211953 = $Hann_DASH_check_DASH_temp167211957($z1194811949);
++R.GAS;
return $ret1195211953;
};
var $Hann_DASH_check_DASH_temp167211957 = function(ann_DASH_check_DASH_temp15511956) {
return ann_DASH_check_DASH_temp15511956;
};
var $Hanf_arg1671265 = function(anf_arg153263,anf_fun151264) {
var $z1196011961 = D;
var $f1196611967 = function(_) {
return R.isFunction(anf_fun151264)?anf_fun151264.app(anf_arg153263):R.ffi.throwNonFunApp(L[27],anf_fun151264,[anf_arg153263]);
};
try {
if(--R.GAS > 0) {
$z1196011961 = $f1196611967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1196611967,
"from":L[27]});
}
} catch($e1195811959) {
if(R.isCont($e1195811959)) {
var $ss1196211963 = {"from":L[27],
"go":function(ann_DASH_check_DASH_temp14911968) {
return $Hann_DASH_check_DASH_temp167011969(ann_DASH_check_DASH_temp14911968);
}};
$e1195811959.stack[R.EXN_STACKHEIGHT++] = $ss1196211963;
}
if(R.isPyretException($e1195811959)) {
$e1195811959.pyretStack.push(L[27]);
}
throw $e1195811959;
}
var $ret1196411965 = $Hann_DASH_check_DASH_temp167011969($z1196011961);
++R.GAS;
return $ret1196411965;
};
var $Hann_DASH_check_DASH_temp167011969 = function(ann_DASH_check_DASH_temp14911968) {
return ann_DASH_check_DASH_temp14911968;
};
var $Hanf_arg1669281 = function(anf_arg141279,self29280,_plus5,torepr13) {
var anf_arg14211980 = G(self29280,"last",L[5]);
var $z1197211973 = D;
var $f1197811979 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg14211980):R.ffi.throwNonFunApp(L[5],torepr13,[anf_arg14211980]);
};
try {
if(--R.GAS > 0) {
$z1197211973 = $f1197811979();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1197811979,
"from":L[5]});
}
} catch($e1197011971) {
if(R.isCont($e1197011971)) {
var $ss1197411975 = {"from":L[5],
"go":function(anf_arg14311981) {
return $Hanf_arg166811982(anf_arg14311981,anf_arg141279,_plus5);
}};
$e1197011971.stack[R.EXN_STACKHEIGHT++] = $ss1197411975;
}
if(R.isPyretException($e1197011971)) {
$e1197011971.pyretStack.push(L[5]);
}
throw $e1197011971;
}
var $ret1197611977 = $Hanf_arg166811982($z1197211973,anf_arg141279,_plus5);
++R.GAS;
return $ret1197611977;
};
var $Hanf_arg166811982 = function(anf_arg14311981,anf_arg141279,_plus5) {
var $z1198511986 = D;
var $f1199111992 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg14311981):R.ffi.throwNonFunApp(L[5],_plus5,[(", "),anf_arg14311981]);
};
try {
if(--R.GAS > 0) {
$z1198511986 = $f1199111992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1199111992,
"from":L[5]});
}
} catch($e1198311984) {
if(R.isCont($e1198311984)) {
var $ss1198711988 = {"from":L[5],
"go":function(anf_arg14411993) {
return $Hanf_arg166711994(anf_arg14411993,anf_arg141279,_plus5);
}};
$e1198311984.stack[R.EXN_STACKHEIGHT++] = $ss1198711988;
}
if(R.isPyretException($e1198311984)) {
$e1198311984.pyretStack.push(L[5]);
}
throw $e1198311984;
}
var $ret1198911990 = $Hanf_arg166711994($z1198511986,anf_arg141279,_plus5);
++R.GAS;
return $ret1198911990;
};
var $Hanf_arg166711994 = function(anf_arg14411993,anf_arg141279,_plus5) {
var $z1199711998 = D;
var $f1200312004 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg141279,anf_arg14411993):R.ffi.throwNonFunApp(L[5],_plus5,[anf_arg141279,anf_arg14411993]);
};
try {
if(--R.GAS > 0) {
$z1199711998 = $f1200312004();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1200312004,
"from":L[5]});
}
} catch($e1199511996) {
if(R.isCont($e1199511996)) {
var $ss1199912000 = {"from":L[5],
"go":function(anf_arg14512005) {
return $Hanf_arg166612006(anf_arg14512005,_plus5);
}};
$e1199511996.stack[R.EXN_STACKHEIGHT++] = $ss1199912000;
}
if(R.isPyretException($e1199511996)) {
$e1199511996.pyretStack.push(L[5]);
}
throw $e1199511996;
}
var $ret1200112002 = $Hanf_arg166612006($z1199711998,_plus5);
++R.GAS;
return $ret1200112002;
};
var $Hanf_arg166612006 = function(anf_arg14512005,_plus5) {
var $z1200912010 = D;
var $f1201512016 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg14512005,(")")):R.ffi.throwNonFunApp(L[5],_plus5,[anf_arg14512005,(")")]);
};
try {
if(--R.GAS > 0) {
$z1200912010 = $f1201512016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1201512016,
"from":L[5]});
}
} catch($e1200712008) {
if(R.isCont($e1200712008)) {
var $ss1201112012 = {"from":L[5],
"go":function(anf_arg14612017) {
return $Hanf_arg166512018(anf_arg14612017,_plus5);
}};
$e1200712008.stack[R.EXN_STACKHEIGHT++] = $ss1201112012;
}
if(R.isPyretException($e1200712008)) {
$e1200712008.pyretStack.push(L[5]);
}
throw $e1200712008;
}
var $ret1201312014 = $Hanf_arg166512018($z1200912010,_plus5);
++R.GAS;
return $ret1201312014;
};
var $Hanf_arg166512018 = function(anf_arg14612017,_plus5) {
var $z1202112022 = D;
var $f1202712028 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg14612017):R.ffi.throwNonFunApp(L[5],_plus5,[("("),anf_arg14612017]);
};
try {
if(--R.GAS > 0) {
$z1202112022 = $f1202712028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1202712028,
"from":L[5]});
}
} catch($e1201912020) {
if(R.isCont($e1201912020)) {
var $ss1202312024 = {"from":L[5],
"go":function(anf_arg14712029) {
return $Hanf_arg166412030(anf_arg14712029,_plus5);
}};
$e1201912020.stack[R.EXN_STACKHEIGHT++] = $ss1202312024;
}
if(R.isPyretException($e1201912020)) {
$e1201912020.pyretStack.push(L[5]);
}
throw $e1201912020;
}
var $ret1202512026 = $Hanf_arg166412030($z1202112022,_plus5);
++R.GAS;
return $ret1202512026;
};
var $Hanf_arg166412030 = function(anf_arg14712029,_plus5) {
var $z1203312034 = D;
var $f1203912040 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("concat-snoc"),anf_arg14712029):R.ffi.throwNonFunApp(L[5],_plus5,[("concat-snoc"),anf_arg14712029]);
};
try {
if(--R.GAS > 0) {
$z1203312034 = $f1203912040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1203912040,
"from":L[5]});
}
} catch($e1203112032) {
if(R.isCont($e1203112032)) {
var $ss1203512036 = {"from":L[5],
"go":function(ann_DASH_check_DASH_temp13912041) {
return $Hann_DASH_check_DASH_temp166312042(ann_DASH_check_DASH_temp13912041);
}};
$e1203112032.stack[R.EXN_STACKHEIGHT++] = $ss1203512036;
}
if(R.isPyretException($e1203112032)) {
$e1203112032.pyretStack.push(L[5]);
}
throw $e1203112032;
}
var $ret1203712038 = $Hann_DASH_check_DASH_temp166312042($z1203312034);
++R.GAS;
return $ret1203712038;
};
var $Hann_DASH_check_DASH_temp166312042 = function(ann_DASH_check_DASH_temp13912041) {
return ann_DASH_check_DASH_temp13912041;
};
var $Hcont_tail_arg1661297 = function(cont_tail_arg136295,if_helper127296) {
if(--R.GAS > 0) {
$z1204312044 = R.isFunction(if_helper127296)?if_helper127296.app(cont_tail_arg136295):R.ffi.throwNonFunApp(L[5],if_helper127296,[cont_tail_arg136295]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper127296)?if_helper127296.app(cont_tail_arg136295):R.ffi.throwNonFunApp(L[5],if_helper127296,[cont_tail_arg136295]);
},
"from":L[5]});
}
++R.GAS;
return $z1204312044;
};
var $Hcont_tail_arg1662312 = function(cont_tail_arg132311,if_helper127296) {
if(--R.GAS > 0) {
$z1204512046 = R.isFunction(if_helper127296)?if_helper127296.app(cont_tail_arg132311):R.ffi.throwNonFunApp(L[5],if_helper127296,[cont_tail_arg132311]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper127296)?if_helper127296.app(cont_tail_arg132311):R.ffi.throwNonFunApp(L[5],if_helper127296,[cont_tail_arg132311]);
},
"from":L[5]});
}
++R.GAS;
return $z1204512046;
};
var $Hanf_arg1660335 = function(anf_arg121333,concat_DASH_cons128162,f152331,self151334) {
var anf_bracket12212060 = G(self151334,"rest",L[1288]);
var anf_fun12312057 = G(anf_bracket12212060,"map",L[1287]);
var $z1204912050 = D;
var $f1205512056 = function(_) {
return R.isFunction(anf_fun12312057)?anf_fun12312057.app(f152331):R.ffi.throwNonFunApp(L[1286],anf_fun12312057,[f152331]);
};
try {
if(--R.GAS > 0) {
$z1204912050 = $f1205512056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1205512056,
"from":L[1286]});
}
} catch($e1204712048) {
if(R.isCont($e1204712048)) {
var $ss1205112052 = {"from":L[1286],
"go":function(anf_arg12412058) {
return $Hanf_arg165912059(anf_arg12412058,anf_arg121333,concat_DASH_cons128162);
}};
$e1204712048.stack[R.EXN_STACKHEIGHT++] = $ss1205112052;
}
if(R.isPyretException($e1204712048)) {
$e1204712048.pyretStack.push(L[1286]);
}
throw $e1204712048;
}
var $ret1205312054 = $Hanf_arg165912059($z1204912050,anf_arg121333,concat_DASH_cons128162);
++R.GAS;
return $ret1205312054;
};
var $Hanf_arg165912059 = function(anf_arg12412058,anf_arg121333,concat_DASH_cons128162) {
var $z1206312064 = D;
var $f1206912070 = function(_) {
return R.isFunction(concat_DASH_cons128162.$var === D?U(L[1289],"concat-cons"):concat_DASH_cons128162.$var)?concat_DASH_cons128162.$var === D?U(L[1289],"concat-cons"):concat_DASH_cons128162.$var.app(anf_arg121333,anf_arg12412058):R.ffi.throwNonFunApp(L[32],concat_DASH_cons128162.$var === D?U(L[1289],"concat-cons"):concat_DASH_cons128162.$var,[anf_arg121333,anf_arg12412058]);
};
try {
if(--R.GAS > 0) {
$z1206312064 = $f1206912070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1206912070,
"from":L[32]});
}
} catch($e1206112062) {
if(R.isCont($e1206112062)) {
var $ss1206512066 = {"from":L[32],
"go":function(ann_DASH_check_DASH_temp11912071) {
return $Hann_DASH_check_DASH_temp165812072(ann_DASH_check_DASH_temp11912071);
}};
$e1206112062.stack[R.EXN_STACKHEIGHT++] = $ss1206512066;
}
if(R.isPyretException($e1206112062)) {
$e1206112062.pyretStack.push(L[32]);
}
throw $e1206112062;
}
var $ret1206712068 = $Hann_DASH_check_DASH_temp165812072($z1206312064);
++R.GAS;
return $ret1206712068;
};
var $Hann_DASH_check_DASH_temp165812072 = function(ann_DASH_check_DASH_temp11912071) {
return ann_DASH_check_DASH_temp11912071;
};
var $Hanf_arg1657350 = function(anf_arg117348,anf_arg114349,link39100) {
var $z1207512076 = D;
var $f1208112082 = function(_) {
return R.isFunction(link39100)?link39100.app(anf_arg114349,anf_arg117348):R.ffi.throwNonFunApp(L[37],link39100,[anf_arg114349,anf_arg117348]);
};
try {
if(--R.GAS > 0) {
$z1207512076 = $f1208112082();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1208112082,
"from":L[37]});
}
} catch($e1207312074) {
if(R.isCont($e1207312074)) {
var $ss1207712078 = {"from":L[37],
"go":function(ann_DASH_check_DASH_temp11312083) {
return $Hann_DASH_check_DASH_temp165612084(ann_DASH_check_DASH_temp11312083);
}};
$e1207312074.stack[R.EXN_STACKHEIGHT++] = $ss1207712078;
}
if(R.isPyretException($e1207312074)) {
$e1207312074.pyretStack.push(L[37]);
}
throw $e1207312074;
}
var $ret1207912080 = $Hann_DASH_check_DASH_temp165612084($z1207512076);
++R.GAS;
return $ret1207912080;
};
var $Hann_DASH_check_DASH_temp165612084 = function(ann_DASH_check_DASH_temp11312083) {
return ann_DASH_check_DASH_temp11312083;
};
var $Hanf_arg1655366 = function(anf_arg105364,self23365,_plus5,torepr13) {
var anf_arg10612095 = G(self23365,"rest",L[6]);
var $z1208712088 = D;
var $f1209312094 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg10612095):R.ffi.throwNonFunApp(L[6],torepr13,[anf_arg10612095]);
};
try {
if(--R.GAS > 0) {
$z1208712088 = $f1209312094();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1209312094,
"from":L[6]});
}
} catch($e1208512086) {
if(R.isCont($e1208512086)) {
var $ss1208912090 = {"from":L[6],
"go":function(anf_arg10712096) {
return $Hanf_arg165412097(anf_arg10712096,anf_arg105364,_plus5);
}};
$e1208512086.stack[R.EXN_STACKHEIGHT++] = $ss1208912090;
}
if(R.isPyretException($e1208512086)) {
$e1208512086.pyretStack.push(L[6]);
}
throw $e1208512086;
}
var $ret1209112092 = $Hanf_arg165412097($z1208712088,anf_arg105364,_plus5);
++R.GAS;
return $ret1209112092;
};
var $Hanf_arg165412097 = function(anf_arg10712096,anf_arg105364,_plus5) {
var $z1210012101 = D;
var $f1210612107 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg10712096):R.ffi.throwNonFunApp(L[6],_plus5,[(", "),anf_arg10712096]);
};
try {
if(--R.GAS > 0) {
$z1210012101 = $f1210612107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1210612107,
"from":L[6]});
}
} catch($e1209812099) {
if(R.isCont($e1209812099)) {
var $ss1210212103 = {"from":L[6],
"go":function(anf_arg10812108) {
return $Hanf_arg165312109(anf_arg10812108,anf_arg105364,_plus5);
}};
$e1209812099.stack[R.EXN_STACKHEIGHT++] = $ss1210212103;
}
if(R.isPyretException($e1209812099)) {
$e1209812099.pyretStack.push(L[6]);
}
throw $e1209812099;
}
var $ret1210412105 = $Hanf_arg165312109($z1210012101,anf_arg105364,_plus5);
++R.GAS;
return $ret1210412105;
};
var $Hanf_arg165312109 = function(anf_arg10812108,anf_arg105364,_plus5) {
var $z1211212113 = D;
var $f1211812119 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg105364,anf_arg10812108):R.ffi.throwNonFunApp(L[6],_plus5,[anf_arg105364,anf_arg10812108]);
};
try {
if(--R.GAS > 0) {
$z1211212113 = $f1211812119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1211812119,
"from":L[6]});
}
} catch($e1211012111) {
if(R.isCont($e1211012111)) {
var $ss1211412115 = {"from":L[6],
"go":function(anf_arg10912120) {
return $Hanf_arg165212121(anf_arg10912120,_plus5);
}};
$e1211012111.stack[R.EXN_STACKHEIGHT++] = $ss1211412115;
}
if(R.isPyretException($e1211012111)) {
$e1211012111.pyretStack.push(L[6]);
}
throw $e1211012111;
}
var $ret1211612117 = $Hanf_arg165212121($z1211212113,_plus5);
++R.GAS;
return $ret1211612117;
};
var $Hanf_arg165212121 = function(anf_arg10912120,_plus5) {
var $z1212412125 = D;
var $f1213012131 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg10912120,(")")):R.ffi.throwNonFunApp(L[6],_plus5,[anf_arg10912120,(")")]);
};
try {
if(--R.GAS > 0) {
$z1212412125 = $f1213012131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1213012131,
"from":L[6]});
}
} catch($e1212212123) {
if(R.isCont($e1212212123)) {
var $ss1212612127 = {"from":L[6],
"go":function(anf_arg11012132) {
return $Hanf_arg165112133(anf_arg11012132,_plus5);
}};
$e1212212123.stack[R.EXN_STACKHEIGHT++] = $ss1212612127;
}
if(R.isPyretException($e1212212123)) {
$e1212212123.pyretStack.push(L[6]);
}
throw $e1212212123;
}
var $ret1212812129 = $Hanf_arg165112133($z1212412125,_plus5);
++R.GAS;
return $ret1212812129;
};
var $Hanf_arg165112133 = function(anf_arg11012132,_plus5) {
var $z1213612137 = D;
var $f1214212143 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg11012132):R.ffi.throwNonFunApp(L[6],_plus5,[("("),anf_arg11012132]);
};
try {
if(--R.GAS > 0) {
$z1213612137 = $f1214212143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1214212143,
"from":L[6]});
}
} catch($e1213412135) {
if(R.isCont($e1213412135)) {
var $ss1213812139 = {"from":L[6],
"go":function(anf_arg11112144) {
return $Hanf_arg165012145(anf_arg11112144,_plus5);
}};
$e1213412135.stack[R.EXN_STACKHEIGHT++] = $ss1213812139;
}
if(R.isPyretException($e1213412135)) {
$e1213412135.pyretStack.push(L[6]);
}
throw $e1213412135;
}
var $ret1214012141 = $Hanf_arg165012145($z1213612137,_plus5);
++R.GAS;
return $ret1214012141;
};
var $Hanf_arg165012145 = function(anf_arg11112144,_plus5) {
var $z1214812149 = D;
var $f1215412155 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("concat-cons"),anf_arg11112144):R.ffi.throwNonFunApp(L[6],_plus5,[("concat-cons"),anf_arg11112144]);
};
try {
if(--R.GAS > 0) {
$z1214812149 = $f1215412155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1215412155,
"from":L[6]});
}
} catch($e1214612147) {
if(R.isCont($e1214612147)) {
var $ss1215012151 = {"from":L[6],
"go":function(ann_DASH_check_DASH_temp10312156) {
return $Hann_DASH_check_DASH_temp164912157(ann_DASH_check_DASH_temp10312156);
}};
$e1214612147.stack[R.EXN_STACKHEIGHT++] = $ss1215012151;
}
if(R.isPyretException($e1214612147)) {
$e1214612147.pyretStack.push(L[6]);
}
throw $e1214612147;
}
var $ret1215212153 = $Hann_DASH_check_DASH_temp164912157($z1214812149);
++R.GAS;
return $ret1215212153;
};
var $Hann_DASH_check_DASH_temp164912157 = function(ann_DASH_check_DASH_temp10312156) {
return ann_DASH_check_DASH_temp10312156;
};
var $Hcont_tail_arg1647382 = function(cont_tail_arg100380,if_helper91381) {
if(--R.GAS > 0) {
$z1215812159 = R.isFunction(if_helper91381)?if_helper91381.app(cont_tail_arg100380):R.ffi.throwNonFunApp(L[6],if_helper91381,[cont_tail_arg100380]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper91381)?if_helper91381.app(cont_tail_arg100380):R.ffi.throwNonFunApp(L[6],if_helper91381,[cont_tail_arg100380]);
},
"from":L[6]});
}
++R.GAS;
return $z1215812159;
};
var $Hcont_tail_arg1648397 = function(cont_tail_arg96396,if_helper91381) {
if(--R.GAS > 0) {
$z1216012161 = R.isFunction(if_helper91381)?if_helper91381.app(cont_tail_arg96396):R.ffi.throwNonFunApp(L[6],if_helper91381,[cont_tail_arg96396]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper91381)?if_helper91381.app(cont_tail_arg96396):R.ffi.throwNonFunApp(L[6],if_helper91381,[cont_tail_arg96396]);
},
"from":L[6]});
}
++R.GAS;
return $z1216012161;
};
var $Hanf_arg1646419 = function(anf_arg85417,concat_DASH_append126158,f146416,self145418) {
var anf_bracket8612175 = G(self145418,"right",L[1292]);
var anf_fun8712172 = G(anf_bracket8612175,"map",L[1291]);
var $z1216412165 = D;
var $f1217012171 = function(_) {
return R.isFunction(anf_fun8712172)?anf_fun8712172.app(f146416):R.ffi.throwNonFunApp(L[1290],anf_fun8712172,[f146416]);
};
try {
if(--R.GAS > 0) {
$z1216412165 = $f1217012171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1217012171,
"from":L[1290]});
}
} catch($e1216212163) {
if(R.isCont($e1216212163)) {
var $ss1216612167 = {"from":L[1290],
"go":function(anf_arg8812173) {
return $Hanf_arg164512174(anf_arg8812173,anf_arg85417,concat_DASH_append126158);
}};
$e1216212163.stack[R.EXN_STACKHEIGHT++] = $ss1216612167;
}
if(R.isPyretException($e1216212163)) {
$e1216212163.pyretStack.push(L[1290]);
}
throw $e1216212163;
}
var $ret1216812169 = $Hanf_arg164512174($z1216412165,anf_arg85417,concat_DASH_append126158);
++R.GAS;
return $ret1216812169;
};
var $Hanf_arg164512174 = function(anf_arg8812173,anf_arg85417,concat_DASH_append126158) {
var $z1217812179 = D;
var $f1218412185 = function(_) {
return R.isFunction(concat_DASH_append126158.$var === D?U(L[1293],"concat-append"):concat_DASH_append126158.$var)?concat_DASH_append126158.$var === D?U(L[1293],"concat-append"):concat_DASH_append126158.$var.app(anf_arg85417,anf_arg8812173):R.ffi.throwNonFunApp(L[43],concat_DASH_append126158.$var === D?U(L[1293],"concat-append"):concat_DASH_append126158.$var,[anf_arg85417,anf_arg8812173]);
};
try {
if(--R.GAS > 0) {
$z1217812179 = $f1218412185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1218412185,
"from":L[43]});
}
} catch($e1217612177) {
if(R.isCont($e1217612177)) {
var $ss1218012181 = {"from":L[43],
"go":function(ann_DASH_check_DASH_temp8212186) {
return $Hann_DASH_check_DASH_temp164412187(ann_DASH_check_DASH_temp8212186);
}};
$e1217612177.stack[R.EXN_STACKHEIGHT++] = $ss1218012181;
}
if(R.isPyretException($e1217612177)) {
$e1217612177.pyretStack.push(L[43]);
}
throw $e1217612177;
}
var $ret1218212183 = $Hann_DASH_check_DASH_temp164412187($z1217812179);
++R.GAS;
return $ret1218212183;
};
var $Hann_DASH_check_DASH_temp164412187 = function(ann_DASH_check_DASH_temp8212186) {
return ann_DASH_check_DASH_temp8212186;
};
var $Hanf_arg1643435 = function(anf_arg80433,anf_fun77434) {
var $z1219012191 = D;
var $f1219612197 = function(_) {
return R.isFunction(anf_fun77434)?anf_fun77434.app(anf_arg80433):R.ffi.throwNonFunApp(L[50],anf_fun77434,[anf_arg80433]);
};
try {
if(--R.GAS > 0) {
$z1219012191 = $f1219612197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1219612197,
"from":L[50]});
}
} catch($e1218812189) {
if(R.isCont($e1218812189)) {
var $ss1219212193 = {"from":L[50],
"go":function(ann_DASH_check_DASH_temp7512198) {
return $Hann_DASH_check_DASH_temp164212199(ann_DASH_check_DASH_temp7512198);
}};
$e1218812189.stack[R.EXN_STACKHEIGHT++] = $ss1219212193;
}
if(R.isPyretException($e1218812189)) {
$e1218812189.pyretStack.push(L[50]);
}
throw $e1218812189;
}
var $ret1219412195 = $Hann_DASH_check_DASH_temp164212199($z1219012191);
++R.GAS;
return $ret1219412195;
};
var $Hann_DASH_check_DASH_temp164212199 = function(ann_DASH_check_DASH_temp7512198) {
return ann_DASH_check_DASH_temp7512198;
};
var $Hanf_arg1641452 = function(anf_arg67450,self17451,_plus5,torepr13) {
var anf_arg6812210 = G(self17451,"right",L[7]);
var $z1220212203 = D;
var $f1220812209 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg6812210):R.ffi.throwNonFunApp(L[7],torepr13,[anf_arg6812210]);
};
try {
if(--R.GAS > 0) {
$z1220212203 = $f1220812209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1220812209,
"from":L[7]});
}
} catch($e1220012201) {
if(R.isCont($e1220012201)) {
var $ss1220412205 = {"from":L[7],
"go":function(anf_arg6912211) {
return $Hanf_arg164012212(anf_arg6912211,anf_arg67450,_plus5);
}};
$e1220012201.stack[R.EXN_STACKHEIGHT++] = $ss1220412205;
}
if(R.isPyretException($e1220012201)) {
$e1220012201.pyretStack.push(L[7]);
}
throw $e1220012201;
}
var $ret1220612207 = $Hanf_arg164012212($z1220212203,anf_arg67450,_plus5);
++R.GAS;
return $ret1220612207;
};
var $Hanf_arg164012212 = function(anf_arg6912211,anf_arg67450,_plus5) {
var $z1221512216 = D;
var $f1222112222 = function(_) {
return R.isFunction(_plus5)?_plus5.app((", "),anf_arg6912211):R.ffi.throwNonFunApp(L[7],_plus5,[(", "),anf_arg6912211]);
};
try {
if(--R.GAS > 0) {
$z1221512216 = $f1222112222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1222112222,
"from":L[7]});
}
} catch($e1221312214) {
if(R.isCont($e1221312214)) {
var $ss1221712218 = {"from":L[7],
"go":function(anf_arg7012223) {
return $Hanf_arg163912224(anf_arg7012223,anf_arg67450,_plus5);
}};
$e1221312214.stack[R.EXN_STACKHEIGHT++] = $ss1221712218;
}
if(R.isPyretException($e1221312214)) {
$e1221312214.pyretStack.push(L[7]);
}
throw $e1221312214;
}
var $ret1221912220 = $Hanf_arg163912224($z1221512216,anf_arg67450,_plus5);
++R.GAS;
return $ret1221912220;
};
var $Hanf_arg163912224 = function(anf_arg7012223,anf_arg67450,_plus5) {
var $z1222712228 = D;
var $f1223312234 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg67450,anf_arg7012223):R.ffi.throwNonFunApp(L[7],_plus5,[anf_arg67450,anf_arg7012223]);
};
try {
if(--R.GAS > 0) {
$z1222712228 = $f1223312234();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1223312234,
"from":L[7]});
}
} catch($e1222512226) {
if(R.isCont($e1222512226)) {
var $ss1222912230 = {"from":L[7],
"go":function(anf_arg7112235) {
return $Hanf_arg163812236(anf_arg7112235,_plus5);
}};
$e1222512226.stack[R.EXN_STACKHEIGHT++] = $ss1222912230;
}
if(R.isPyretException($e1222512226)) {
$e1222512226.pyretStack.push(L[7]);
}
throw $e1222512226;
}
var $ret1223112232 = $Hanf_arg163812236($z1222712228,_plus5);
++R.GAS;
return $ret1223112232;
};
var $Hanf_arg163812236 = function(anf_arg7112235,_plus5) {
var $z1223912240 = D;
var $f1224512246 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg7112235,(")")):R.ffi.throwNonFunApp(L[7],_plus5,[anf_arg7112235,(")")]);
};
try {
if(--R.GAS > 0) {
$z1223912240 = $f1224512246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1224512246,
"from":L[7]});
}
} catch($e1223712238) {
if(R.isCont($e1223712238)) {
var $ss1224112242 = {"from":L[7],
"go":function(anf_arg7212247) {
return $Hanf_arg163712248(anf_arg7212247,_plus5);
}};
$e1223712238.stack[R.EXN_STACKHEIGHT++] = $ss1224112242;
}
if(R.isPyretException($e1223712238)) {
$e1223712238.pyretStack.push(L[7]);
}
throw $e1223712238;
}
var $ret1224312244 = $Hanf_arg163712248($z1223912240,_plus5);
++R.GAS;
return $ret1224312244;
};
var $Hanf_arg163712248 = function(anf_arg7212247,_plus5) {
var $z1225112252 = D;
var $f1225712258 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg7212247):R.ffi.throwNonFunApp(L[7],_plus5,[("("),anf_arg7212247]);
};
try {
if(--R.GAS > 0) {
$z1225112252 = $f1225712258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1225712258,
"from":L[7]});
}
} catch($e1224912250) {
if(R.isCont($e1224912250)) {
var $ss1225312254 = {"from":L[7],
"go":function(anf_arg7312259) {
return $Hanf_arg163612260(anf_arg7312259,_plus5);
}};
$e1224912250.stack[R.EXN_STACKHEIGHT++] = $ss1225312254;
}
if(R.isPyretException($e1224912250)) {
$e1224912250.pyretStack.push(L[7]);
}
throw $e1224912250;
}
var $ret1225512256 = $Hanf_arg163612260($z1225112252,_plus5);
++R.GAS;
return $ret1225512256;
};
var $Hanf_arg163612260 = function(anf_arg7312259,_plus5) {
var $z1226312264 = D;
var $f1226912270 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("concat-append"),anf_arg7312259):R.ffi.throwNonFunApp(L[7],_plus5,[("concat-append"),anf_arg7312259]);
};
try {
if(--R.GAS > 0) {
$z1226312264 = $f1226912270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1226912270,
"from":L[7]});
}
} catch($e1226112262) {
if(R.isCont($e1226112262)) {
var $ss1226512266 = {"from":L[7],
"go":function(ann_DASH_check_DASH_temp6512271) {
return $Hann_DASH_check_DASH_temp163512272(ann_DASH_check_DASH_temp6512271);
}};
$e1226112262.stack[R.EXN_STACKHEIGHT++] = $ss1226512266;
}
if(R.isPyretException($e1226112262)) {
$e1226112262.pyretStack.push(L[7]);
}
throw $e1226112262;
}
var $ret1226712268 = $Hann_DASH_check_DASH_temp163512272($z1226312264);
++R.GAS;
return $ret1226712268;
};
var $Hann_DASH_check_DASH_temp163512272 = function(ann_DASH_check_DASH_temp6512271) {
return ann_DASH_check_DASH_temp6512271;
};
var $Hcont_tail_arg1633468 = function(cont_tail_arg62466,if_helper53467) {
if(--R.GAS > 0) {
$z1227312274 = R.isFunction(if_helper53467)?if_helper53467.app(cont_tail_arg62466):R.ffi.throwNonFunApp(L[7],if_helper53467,[cont_tail_arg62466]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper53467)?if_helper53467.app(cont_tail_arg62466):R.ffi.throwNonFunApp(L[7],if_helper53467,[cont_tail_arg62466]);
},
"from":L[7]});
}
++R.GAS;
return $z1227312274;
};
var $Hcont_tail_arg1634483 = function(cont_tail_arg58482,if_helper53467) {
if(--R.GAS > 0) {
$z1227512276 = R.isFunction(if_helper53467)?if_helper53467.app(cont_tail_arg58482):R.ffi.throwNonFunApp(L[7],if_helper53467,[cont_tail_arg58482]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper53467)?if_helper53467.app(cont_tail_arg58482):R.ffi.throwNonFunApp(L[7],if_helper53467,[cont_tail_arg58482]);
},
"from":L[7]});
}
++R.GAS;
return $z1227512276;
};
var $Hanf_arg1632504 = function(anf_arg50503,concat_DASH_singleton124154) {
var $z1227912280 = D;
var $f1228512286 = function(_) {
return R.isFunction(concat_DASH_singleton124154.$var === D?U(L[1294],"concat-singleton"):concat_DASH_singleton124154.$var)?concat_DASH_singleton124154.$var === D?U(L[1294],"concat-singleton"):concat_DASH_singleton124154.$var.app(anf_arg50503):R.ffi.throwNonFunApp(L[55],concat_DASH_singleton124154.$var === D?U(L[1294],"concat-singleton"):concat_DASH_singleton124154.$var,[anf_arg50503]);
};
try {
if(--R.GAS > 0) {
$z1227912280 = $f1228512286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1228512286,
"from":L[55]});
}
} catch($e1227712278) {
if(R.isCont($e1227712278)) {
var $ss1228112282 = {"from":L[55],
"go":function(ann_DASH_check_DASH_temp4812287) {
return $Hann_DASH_check_DASH_temp163112288(ann_DASH_check_DASH_temp4812287);
}};
$e1227712278.stack[R.EXN_STACKHEIGHT++] = $ss1228112282;
}
if(R.isPyretException($e1227712278)) {
$e1227712278.pyretStack.push(L[55]);
}
throw $e1227712278;
}
var $ret1228312284 = $Hann_DASH_check_DASH_temp163112288($z1227912280);
++R.GAS;
return $ret1228312284;
};
var $Hann_DASH_check_DASH_temp163112288 = function(ann_DASH_check_DASH_temp4812287) {
return ann_DASH_check_DASH_temp4812287;
};
var $Hann_DASH_check_DASH_temp1630519 = function(ann_DASH_check_DASH_temp45518) {
return ann_DASH_check_DASH_temp45518;
};
var $Hanf_arg1629533 = function(anf_arg41532,_plus5) {
var $z1229112292 = D;
var $f1229712298 = function(_) {
return R.isFunction(_plus5)?_plus5.app(anf_arg41532,(")")):R.ffi.throwNonFunApp(L[8],_plus5,[anf_arg41532,(")")]);
};
try {
if(--R.GAS > 0) {
$z1229112292 = $f1229712298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1229712298,
"from":L[8]});
}
} catch($e1228912290) {
if(R.isCont($e1228912290)) {
var $ss1229312294 = {"from":L[8],
"go":function(anf_arg4212299) {
return $Hanf_arg162812300(anf_arg4212299,_plus5);
}};
$e1228912290.stack[R.EXN_STACKHEIGHT++] = $ss1229312294;
}
if(R.isPyretException($e1228912290)) {
$e1228912290.pyretStack.push(L[8]);
}
throw $e1228912290;
}
var $ret1229512296 = $Hanf_arg162812300($z1229112292,_plus5);
++R.GAS;
return $ret1229512296;
};
var $Hanf_arg162812300 = function(anf_arg4212299,_plus5) {
var $z1230312304 = D;
var $f1230912310 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("("),anf_arg4212299):R.ffi.throwNonFunApp(L[8],_plus5,[("("),anf_arg4212299]);
};
try {
if(--R.GAS > 0) {
$z1230312304 = $f1230912310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1230912310,
"from":L[8]});
}
} catch($e1230112302) {
if(R.isCont($e1230112302)) {
var $ss1230512306 = {"from":L[8],
"go":function(anf_arg4312311) {
return $Hanf_arg162712312(anf_arg4312311,_plus5);
}};
$e1230112302.stack[R.EXN_STACKHEIGHT++] = $ss1230512306;
}
if(R.isPyretException($e1230112302)) {
$e1230112302.pyretStack.push(L[8]);
}
throw $e1230112302;
}
var $ret1230712308 = $Hanf_arg162712312($z1230312304,_plus5);
++R.GAS;
return $ret1230712308;
};
var $Hanf_arg162712312 = function(anf_arg4312311,_plus5) {
var $z1231512316 = D;
var $f1232112322 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("concat-singleton"),anf_arg4312311):R.ffi.throwNonFunApp(L[8],_plus5,[("concat-singleton"),anf_arg4312311]);
};
try {
if(--R.GAS > 0) {
$z1231512316 = $f1232112322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1232112322,
"from":L[8]});
}
} catch($e1231312314) {
if(R.isCont($e1231312314)) {
var $ss1231712318 = {"from":L[8],
"go":function(ann_DASH_check_DASH_temp3912323) {
return $Hann_DASH_check_DASH_temp162612324(ann_DASH_check_DASH_temp3912323);
}};
$e1231312314.stack[R.EXN_STACKHEIGHT++] = $ss1231712318;
}
if(R.isPyretException($e1231312314)) {
$e1231312314.pyretStack.push(L[8]);
}
throw $e1231312314;
}
var $ret1231912320 = $Hann_DASH_check_DASH_temp162612324($z1231512316);
++R.GAS;
return $ret1231912320;
};
var $Hann_DASH_check_DASH_temp162612324 = function(ann_DASH_check_DASH_temp3912323) {
return ann_DASH_check_DASH_temp3912323;
};
var $Hcont_tail_arg1624549 = function(cont_tail_arg36547,if_helper28548) {
if(--R.GAS > 0) {
$z1232512326 = R.isFunction(if_helper28548)?if_helper28548.app(cont_tail_arg36547):R.ffi.throwNonFunApp(L[8],if_helper28548,[cont_tail_arg36547]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper28548)?if_helper28548.app(cont_tail_arg36547):R.ffi.throwNonFunApp(L[8],if_helper28548,[cont_tail_arg36547]);
},
"from":L[8]});
}
++R.GAS;
return $z1232512326;
};
var $Hcont_tail_arg1625564 = function(cont_tail_arg33563,if_helper28548) {
if(--R.GAS > 0) {
$z1232712328 = R.isFunction(if_helper28548)?if_helper28548.app(cont_tail_arg33563):R.ffi.throwNonFunApp(L[8],if_helper28548,[cont_tail_arg33563]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper28548)?if_helper28548.app(cont_tail_arg33563):R.ffi.throwNonFunApp(L[8],if_helper28548,[cont_tail_arg33563]);
},
"from":L[8]});
}
++R.GAS;
return $z1232712328;
};
var $Hcont_tail_arg1622593 = function(cont_tail_arg18591,if_helper11592) {
if(--R.GAS > 0) {
$z1232912330 = R.isFunction(if_helper11592)?if_helper11592.app(cont_tail_arg18591):R.ffi.throwNonFunApp(L[9],if_helper11592,[cont_tail_arg18591]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper11592)?if_helper11592.app(cont_tail_arg18591):R.ffi.throwNonFunApp(L[9],if_helper11592,[cont_tail_arg18591]);
},
"from":L[9]});
}
++R.GAS;
return $z1232912330;
};
var $Hcont_tail_arg1623607 = function(cont_tail_arg16606,if_helper11592) {
if(--R.GAS > 0) {
$z1233112332 = R.isFunction(if_helper11592)?if_helper11592.app(cont_tail_arg16606):R.ffi.throwNonFunApp(L[9],if_helper11592,[cont_tail_arg16606]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored317) {
return R.isFunction(if_helper11592)?if_helper11592.app(cont_tail_arg16606):R.ffi.throwNonFunApp(L[9],if_helper11592,[cont_tail_arg16606]);
},
"from":L[9]});
}
++R.GAS;
return $z1233112332;
};
var $Hanf_arg1621629 = function(anf_arg8627,anf_fun6628) {
var $z1233512336 = D;
var $f1234112342 = function(_) {
return R.isFunction(anf_fun6628)?anf_fun6628.app(anf_arg8627):R.ffi.throwNonFunApp(L[63],anf_fun6628,[anf_arg8627]);
};
try {
if(--R.GAS > 0) {
$z1233512336 = $f1234112342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1234112342,
"from":L[63]});
}
} catch($e1233312334) {
if(R.isCont($e1233312334)) {
var $ss1233712338 = {"from":L[63],
"go":function(ann_DASH_check_DASH_temp512343) {
return $Hann_DASH_check_DASH_temp162012344(ann_DASH_check_DASH_temp512343);
}};
$e1233312334.stack[R.EXN_STACKHEIGHT++] = $ss1233712338;
}
if(R.isPyretException($e1233312334)) {
$e1233312334.pyretStack.push(L[63]);
}
throw $e1233312334;
}
var $ret1233912340 = $Hann_DASH_check_DASH_temp162012344($z1233512336);
++R.GAS;
return $ret1233912340;
};
var $Hann_DASH_check_DASH_temp162012344 = function(ann_DASH_check_DASH_temp512343) {
return ann_DASH_check_DASH_temp512343;
};
var $Hann_DASH_check_DASH_temp1619644 = function(ann_DASH_check_DASH_temp3643) {
return ann_DASH_check_DASH_temp3643;
};
var $Hann_DASH_check_DASH_temp161812345 = function(ann_DASH_check_DASH_temp112346) {
return ann_DASH_check_DASH_temp112346;
};
return R.loadModulesNew(NAMESPACE,[$A11845,$N31946,$S52047,$J72148,$G92249,$CS112350,$D132451,$SL152552,$arrays172653,$lists192754,$option212855,$error232956,$sets253057],function($A11845,$N31946,$S52047,$J72148,$G92249,$CS112350,$D132451,$SL152552,$arrays172653,$lists192754,$option212855,$error232956,$sets253057) {
var A118 = R.getField($A11845,"values");
var N319 = R.getField($N31946,"values");
var S520 = R.getField($S52047,"values");
var J721 = R.getField($J72148,"values");
var G922 = R.getField($G92249,"values");
var CS1123 = R.getField($CS112350,"values");
var D1324 = R.getField($D132451,"values");
var SL1525 = R.getField($SL152552,"values");
var arrays1726 = R.getField($arrays172653,"values");
var lists1927 = R.getField($lists192754,"values");
var option2128 = R.getField($option212855,"values");
var error2329 = R.getField($error232956,"values");
var sets2530 = R.getField($sets253057,"values");
var A231 = R.getField($A11845,"types");
var N432 = R.getField($N31946,"types");
var S633 = R.getField($S52047,"types");
var J834 = R.getField($J72148,"types");
var G1035 = R.getField($G92249,"types");
var CS1236 = R.getField($CS112350,"types");
var D1437 = R.getField($D132451,"types");
var SL1638 = R.getField($SL152552,"types");
var arrays1839 = R.getField($arrays172653,"types");
var lists2040 = R.getField($lists192754,"types");
var option2241 = R.getField($option212855,"types");
var error2442 = R.getField($error232956,"types");
var sets2643 = R.getField($sets253057,"types");
return R.safeCall(function() {
var List2762 = R.getDotAnn(L[1295],"lists",lists2040,"List");
var Option2812347 = R.getDotAnn(L[1295],"option",option2241,"Option");
var Array2912348 = R.getDotAnn(L[1295],"arrays",arrays1839,"Array");
var Set3012349 = R.getDotAnn(L[1295],"sets",sets2643,"Set");
var array3112408 = G(arrays1726,"array",L[1295]);
var build_DASH_array3212407 = G(arrays1726,"build-array",L[1295]);
var array_DASH_from_DASH_list3312406 = G(arrays1726,"array-from-list",L[1295]);
var is_DASH_array3412405 = G(arrays1726,"is-array",L[1295]);
var list35101 = G(lists1927,"list",L[1295]);
var is_DASH_empty3666 = G(lists1927,"is-empty",L[1295]);
var is_DASH_link3712404 = G(lists1927,"is-link",L[1295]);
var empty3812403 = G(lists1927,"empty",L[1295]);
var link39100 = G(lists1927,"link",L[1295]);
var range4012402 = G(lists1927,"range",L[1295]);
var repeat4112401 = G(lists1927,"repeat",L[1295]);
var filter4264 = G(lists1927,"filter",L[1295]);
var partition4312400 = G(lists1927,"partition",L[1295]);
var split_DASH_at4412399 = G(lists1927,"split-at",L[1295]);
var any4512398 = G(lists1927,"any",L[1295]);
var find4612397 = G(lists1927,"find",L[1295]);
var map47104 = G(lists1927,"map",L[1295]);
var map248102 = G(lists1927,"map2",L[1295]);
var map349103 = G(lists1927,"map3",L[1295]);
var map45012396 = G(lists1927,"map4",L[1295]);
var map_n5112395 = G(lists1927,"map_n",L[1295]);
var map2_n5212394 = G(lists1927,"map2_n",L[1295]);
var map3_n5312393 = G(lists1927,"map3_n",L[1295]);
var map4_n5412392 = G(lists1927,"map4_n",L[1295]);
var each5512391 = G(lists1927,"each",L[1295]);
var each25612390 = G(lists1927,"each2",L[1295]);
var each35712389 = G(lists1927,"each3",L[1295]);
var each45812388 = G(lists1927,"each4",L[1295]);
var each_n5912387 = G(lists1927,"each_n",L[1295]);
var each2_n6012386 = G(lists1927,"each2_n",L[1295]);
var each3_n6112385 = G(lists1927,"each3_n",L[1295]);
var each4_n6212384 = G(lists1927,"each4_n",L[1295]);
var fold6365 = G(lists1927,"fold",L[1295]);
var fold26412383 = G(lists1927,"fold2",L[1295]);
var fold36512382 = G(lists1927,"fold3",L[1295]);
var fold46612381 = G(lists1927,"fold4",L[1295]);
var index6712380 = G(lists1927,"index",L[1295]);
var Option6812379 = G(option2128,"Option",L[1295]);
var is_DASH_none6912378 = G(option2128,"is-none",L[1295]);
var is_DASH_some7012377 = G(option2128,"is-some",L[1295]);
var none7112376 = G(option2128,"none",L[1295]);
var some7212375 = G(option2128,"some",L[1295]);
var set7312374 = G(sets2530,"set",L[1295]);
var tree_DASH_set7412373 = G(sets2530,"tree-set",L[1295]);
var list_DASH_set7512372 = G(sets2530,"list-set",L[1295]);
var ConcatListT27761 = R.namedBrander("ConcatList");
var ConcatList7660 = R.makeBranderAnn(ConcatListT27761,"ConcatList");
var Loc7863 = R.getDotAnn(L[1296],"SL",SL1638,"Srcloc");
var type_DASH_name79105 = {"$var":D,
"$name":"type-name"};
var anf_assign212350 = R.makeFunction(function(str8012361) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1331],1,arguments);
}
var $z1236412365 = D;
var $f1237012371 = function(_) {
return R.isFunction(_plus5)?_plus5.app(("$type$"),str8012361):R.ffi.throwNonFunApp(L[1331],_plus5,[("$type$"),str8012361]);
};
try {
if(--R.GAS > 0) {
$z1236412365 = $f1237012371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1237012371,
"from":L[1331]});
}
} catch($e1236212363) {
if(R.isCont($e1236212363)) {
var $ss1236612367 = {"from":L[1331],
"go":function(ann_DASH_check_DASH_temp112346) {
return $Hann_DASH_check_DASH_temp161812345(ann_DASH_check_DASH_temp112346);
}};
$e1236212363.stack[R.EXN_STACKHEIGHT++] = $ss1236612367;
}
if(R.isPyretException($e1236212363)) {
$e1236212363.pyretStack.push(L[1331]);
}
throw $e1236212363;
}
var $ret1236812369 = $Hann_DASH_check_DASH_temp161812345($z1236412365);
++R.GAS;
return $ret1236812369;
});
type_DASH_name79105.$var = anf_assign212350;
var j_DASH_fun8180 = G(J721,"j-fun",L[1330]);
var j_DASH_var8299 = G(J721,"j-var",L[1329]);
var j_DASH_id8381 = G(J721,"j-id",L[1328]);
var j_DASH_method8486 = G(J721,"j-method",L[1327]);
var j_DASH_block8570 = G(J721,"j-block",L[1326]);
var j_DASH_true8696 = G(J721,"j-true",L[1325]);
var j_DASH_false8778 = G(J721,"j-false",L[1324]);
var j_DASH_num8889 = G(J721,"j-num",L[1323]);
var j_DASH_str8993 = G(J721,"j-str",L[1322]);
var j_DASH_return9092 = G(J721,"j-return",L[1321]);
var j_DASH_assign9168 = G(J721,"j-assign",L[1320]);
var j_DASH_if9283 = G(J721,"j-if",L[1319]);
var j_DASH_if19382 = G(J721,"j-if1",L[1318]);
var j_DASH_app9467 = G(J721,"j-app",L[1317]);
var j_DASH_list9585 = G(J721,"j-list",L[1316]);
var j_DASH_obj9690 = G(J721,"j-obj",L[1315]);
var j_DASH_dot9775 = G(J721,"j-dot",L[1314]);
var j_DASH_bracket9872 = G(J721,"j-bracket",L[1313]);
var j_DASH_field9979 = G(J721,"j-field",L[1312]);
var j_DASH_dot_DASH_assign10074 = G(J721,"j-dot-assign",L[1311]);
var j_DASH_bracket_DASH_assign10171 = G(J721,"j-bracket-assign",L[1310]);
var j_DASH_try_DASH_catch10297 = G(J721,"j-try-catch",L[1309]);
var j_DASH_throw10395 = G(J721,"j-throw",L[1308]);
var j_DASH_expr10477 = G(J721,"j-expr",L[1307]);
var j_DASH_binop10569 = G(J721,"j-binop",L[1306]);
var j_DASH_eq10676 = G(J721,"j-eq",L[1305]);
var j_DASH_neq10787 = G(J721,"j-neq",L[1304]);
var j_DASH_unop10898 = G(J721,"j-unop",L[1303]);
var j_DASH_decr10973 = G(J721,"j-decr",L[1302]);
var j_DASH_incr11084 = G(J721,"j-incr",L[1301]);
var j_DASH_ternary11194 = G(J721,"j-ternary",L[1300]);
var j_DASH_null11288 = G(J721,"j-null",L[1299]);
var j_DASH_parens11391 = G(J721,"j-parens",L[1298]);
var $z1235312354 = D;
var $f1235912360 = function(_) {
return R.isFunction(j_DASH_id8381)?j_DASH_id8381.app(("G")):R.ffi.throwNonFunApp(L[1297],j_DASH_id8381,[("G")]);
};
try {
if(--R.GAS > 0) {
$z1235312354 = $f1235912360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1235912360,
"from":L[1297]});
}
} catch($e1235112352) {
if(R.isCont($e1235112352)) {
var $ss1235512356 = {"from":L[1297],
"go":function(get_DASH_field_DASH_loc11459) {
return $Hget_DASH_field_DASH_loc253958(get_DASH_field_DASH_loc11459,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
}};
$e1235112352.stack[R.EXN_STACKHEIGHT++] = $ss1235512356;
}
if(R.isPyretException($e1235112352)) {
$e1235112352.pyretStack.push(L[1297]);
}
throw $e1235112352;
}
var $ret1235712358 = $Hget_DASH_field_DASH_loc253958($z1235312354,A118,A231,ConcatList7660,ConcatListT27761,D1324,G922,J721,J834,List2762,Loc7863,N319,N432,S520,S633,filter4264,fold6365,is_DASH_empty3666,j_DASH_app9467,j_DASH_assign9168,j_DASH_binop10569,j_DASH_block8570,j_DASH_bracket_DASH_assign10171,j_DASH_bracket9872,j_DASH_decr10973,j_DASH_dot_DASH_assign10074,j_DASH_dot9775,j_DASH_eq10676,j_DASH_expr10477,j_DASH_false8778,j_DASH_field9979,j_DASH_fun8180,j_DASH_id8381,j_DASH_if19382,j_DASH_if9283,j_DASH_incr11084,j_DASH_list9585,j_DASH_method8486,j_DASH_neq10787,j_DASH_null11288,j_DASH_num8889,j_DASH_obj9690,j_DASH_parens11391,j_DASH_return9092,j_DASH_str8993,j_DASH_ternary11194,j_DASH_throw10395,j_DASH_true8696,j_DASH_try_DASH_catch10297,j_DASH_unop10898,j_DASH_var8299,link39100,list35101,map248102,map349103,map47104,sets2530,type_DASH_name79105,_minus4,_plus5,builtins6,is_DASH_string7,not8,nothing9,num_DASH_is_DASH_fixnum10,raise11,string_DASH_replace12,torepr13,tostring14,$type$Boolean15,$type$Number16,$type$String17);
++R.GAS;
return $ret1235712358;
},function(moduleVal) {
R.modules["$src/arr/compiler/anf-visitor-compiler.arr44"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/ast-util.arr',["trove/srcloc",
"trove/ast",
"trove/parse-pyret",
"compiler/compile-structs.arr",
"trove/string-dict",
"trove/either",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($SL11639,$A31740,$PP51841,$CS71942,$SD92043,$E112144,$arrays132245,$lists152346,$option172447,$error192548,$sets212649) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/ast-util.arr38"]) {
return R.modules["$src/arr/compiler/ast-util.arr38"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/ast-util.arr";
var D = R.undefined;
var L = [[M,12,0,189,579,1,20221],
[M,577,38,20203,577,46,20211],
[M,577,38,20203,577,44,20209],
[M,577,25,20190,577,37,20202],
[M,577,25,20190,577,33,20198],
[M,577,4,20169,577,17,20182],
[M,576,2,20136,578,5,20219],
[M,556,56,19483,556,70,19497],
[M,556,56,19483,556,68,19495],
[M,556,16,19443,568,7,19859],
[M,557,6,19507,557,62,19563],
[M,557,53,19554,557,61,19562],
[M,557,44,19545,557,51,19552],
[M,557,44,19545,557,48,19549],
[M,555,2,19395,575,5,20132],
[M,500,0,17882,547,3,19230],
[M,544,43,19193,544,49,19199],
[M,544,27,19177,544,41,19191],
[M,543,6,19122,543,33,19149],
[M,543,6,19122,543,22,19138],
[M,59,0,1558,63,3,1715],
[M,61,2,1585,62,34,1711],
[M,60,6,1571,60,17,1582],
[M,90,0,2318,97,3,2758],
[M,544,2,19152,544,50,19200],
[M,545,2,19203,545,24,19225],
[M,545,2,19203,545,19,19220],
[M,545,2,19203,545,17,19218],
[M,61,2,1585,61,31,1614],
[M,61,2,1585,61,18,1601],
[M,61,2,1585,61,66,1649],
[M,61,2,1585,61,43,1626],
[M,61,2,1585,61,37,1620],
[M,61,2,1585,61,93,1676],
[M,61,73,1656,61,92,1675],
[M,61,2,1585,61,72,1655],
[M,62,17,1694,62,33,1710],
[M,62,17,1694,62,25,1702],
[M,62,7,1684,62,13,1690],
[M,62,7,1684,62,34,1711],
[M,577,25,20190,577,47,20212],
[M,556,47,19474,556,71,19498],
[M,556,4,19431,568,7,19859],
[M,569,4,19864,571,7,19970],
[M,569,16,19876,571,7,19970],
[M,570,6,19931,570,13,19938],
[M,572,15,19986,572,31,20002],
[M,572,15,19986,572,29,20000],
[M,572,36,20007,572,48,20019],
[M,572,36,20007,572,46,20017],
[M,572,15,19986,572,35,20006],
[M,572,36,20007,572,59,20030],
[M,572,36,20007,572,57,20028],
[M,572,36,20007,572,53,20024],
[M,572,36,20007,572,50,20021],
[M,572,4,19975,572,66,20037],
[M,573,4,20042,573,49,20087],
[M,573,15,20053,573,25,20063],
[M,574,4,20092,574,14,20102],
[M,558,66,19630,558,80,19644],
[M,558,66,19630,558,78,19642],
[M,558,25,19589,558,33,19597],
[M,558,6,19570,567,9,19851],
[M,559,8,19656,559,27,19675],
[M,559,14,19662,559,25,19673],
[M,559,14,19662,559,21,19669],
[M,559,14,19662,559,18,19666],
[M,558,57,19621,558,81,19645],
[M,560,11,19687,560,17,19693],
[M,561,10,19704,561,29,19723],
[M,561,10,19704,561,17,19711],
[M,563,10,19758,563,38,19786],
[M,563,10,19758,563,17,19765],
[M,565,10,19811,565,28,19829],
[M,565,10,19811,565,17,19818],
[M,562,16,19740,562,23,19747],
[M,550,2,19272,550,41,19311],
[M,550,22,19292,550,35,19305],
[M,550,2,19272,550,18,19288],
[M,550,22,19292,550,41,19311],
[M,513,12,18302,513,49,18339],
[M,513,2,18292,513,11,18301],
[M,508,2,18164,512,5,18289],
[M,509,25,18219,509,37,18231],
[M,509,25,18219,509,35,18229],
[M,509,25,18219,509,31,18225],
[M,509,13,18207,509,24,18218],
[M,503,2,18037,507,5,18161],
[M,504,17,18083,504,39,18105],
[M,502,2,17979,502,57,18034],
[M,502,38,18015,502,53,18030],
[M,513,2,18292,540,6,19099],
[M,537,23,19034,537,42,19053],
[M,537,23,19034,537,31,19042],
[M,536,6,18980,539,9,19092],
[M,533,23,18916,533,40,18933],
[M,533,23,18916,533,31,18924],
[M,532,6,18870,535,9,18972],
[M,527,30,18732,527,45,18747],
[M,527,30,18732,527,36,18738],
[M,526,6,18670,531,9,18862],
[M,523,18,18600,523,46,18628],
[M,523,18,18600,523,31,18613],
[M,522,6,18548,525,9,18662],
[M,519,18,18487,519,37,18506],
[M,519,18,18487,519,28,18497],
[M,518,6,18444,521,9,18540],
[M,515,18,18387,515,33,18402],
[M,515,18,18387,515,24,18393],
[M,514,6,18348,517,9,18436],
[M,537,8,19019,537,58,19069],
[M,537,44,19055,537,57,19068],
[M,533,8,18901,533,56,18949],
[M,533,42,18935,533,55,18948],
[M,527,21,18723,527,56,18758],
[M,527,47,18749,527,55,18757],
[M,527,8,18710,529,11,18826],
[M,528,35,18796,528,46,18807],
[M,528,35,18796,528,44,18805],
[M,528,20,18781,528,34,18795],
[M,527,13,18715,527,57,18759],
[M,530,8,18835,530,19,18846],
[M,528,20,18781,528,52,18813],
[M,528,10,18771,528,53,18814],
[M,523,8,18590,523,57,18639],
[M,523,48,18630,523,56,18638],
[M,519,8,18477,519,48,18517],
[M,519,39,18508,519,47,18516],
[M,515,8,18377,515,44,18413],
[M,515,35,18404,515,43,18412],
[M,509,13,18207,509,38,18232],
[M,509,4,18198,511,7,18283],
[M,510,16,18251,510,39,18274],
[M,510,16,18251,510,34,18269],
[M,509,9,18203,509,39,18233],
[M,510,6,18241,510,40,18275],
[M,504,4,18070,506,7,18155],
[M,505,16,18124,505,38,18146],
[M,505,16,18124,505,29,18137],
[M,504,9,18075,504,40,18106],
[M,505,6,18114,505,39,18147],
[M,495,44,17840,495,67,17863],
[M,495,53,17849,495,66,17862],
[M,495,44,17840,495,52,17848],
[M,489,4,17564,496,7,17872],
[M,490,6,17587,494,40,17795],
[M,494,8,17763,494,20,17775],
[M,491,20,17645,493,11,17754],
[M,472,12,17135,472,49,17172],
[M,472,2,17125,472,11,17134],
[M,471,2,17067,471,57,17122],
[M,471,38,17103,471,53,17118],
[M,472,2,17125,483,4,17478],
[M,474,38,17249,474,53,17264],
[M,474,38,17249,474,44,17255],
[M,473,4,17179,482,7,17472],
[M,474,6,17217,480,9,17440],
[M,474,55,17266,474,63,17274],
[M,476,8,17311,479,13,17430],
[M,477,10,17334,479,13,17430],
[M,477,19,17343,477,24,17348],
[M,475,8,17285,475,25,17302],
[M,481,6,17447,481,17,17458],
[M,478,40,17391,478,51,17402],
[M,478,40,17391,478,49,17400],
[M,478,22,17373,478,39,17390],
[M,477,15,17339,477,25,17349],
[M,478,22,17373,478,64,17415],
[M,478,58,17409,478,63,17414],
[M,478,12,17363,478,65,17416],
[M,420,9,15213,420,48,15252],
[M,420,9,15213,420,19,15223],
[M,419,4,15179,465,7,16963],
[M,420,26,15230,420,47,15251],
[M,420,28,15232,420,35,15239],
[M,420,9,15213,420,22,15226],
[M,422,8,15284,461,11,16874],
[M,460,23,16823,460,36,16836],
[M,460,23,16823,460,30,16830],
[M,460,12,16812,460,19,16819],
[M,448,10,16360,458,15,16779],
[M,449,12,16392,458,15,16779],
[M,449,55,16435,449,63,16443],
[M,437,10,15934,447,15,16349],
[M,438,12,15962,447,15,16349],
[M,438,55,16005,438,63,16013],
[M,423,10,15316,436,15,15923],
[M,424,12,15355,436,15,15923],
[M,424,52,15395,424,60,15403],
[M,421,17,15270,421,22,15275],
[M,463,19,16906,463,32,16919],
[M,463,19,16906,463,26,16913],
[M,463,8,16895,463,15,16902],
[M,460,38,16838,460,61,16861],
[M,460,47,16847,460,60,16860],
[M,460,38,16838,460,46,16846],
[M,457,27,16724,457,40,16737],
[M,457,27,16724,457,34,16731],
[M,457,16,16713,457,23,16720],
[M,450,14,16460,455,19,16672],
[M,452,18,16539,452,40,16561],
[M,452,18,16539,452,34,16555],
[M,452,18,16539,452,28,16549],
[M,454,29,16613,454,42,16626],
[M,454,29,16613,454,36,16620],
[M,454,18,16602,454,25,16609],
[M,451,18,16496,451,41,16519],
[M,457,42,16739,457,65,16762],
[M,457,51,16748,457,64,16761],
[M,457,42,16739,457,50,16747],
[M,454,44,16628,454,67,16651],
[M,454,53,16637,454,66,16650],
[M,454,44,16628,454,52,16636],
[M,454,18,16602,454,68,16652],
[M,446,27,16294,446,40,16307],
[M,446,27,16294,446,34,16301],
[M,446,16,16283,446,23,16290],
[M,439,14,16030,444,19,16242],
[M,441,18,16109,441,40,16131],
[M,441,18,16109,441,34,16125],
[M,441,18,16109,441,28,16119],
[M,443,29,16183,443,42,16196],
[M,443,29,16183,443,36,16190],
[M,443,18,16172,443,25,16179],
[M,440,18,16066,440,41,16089],
[M,446,42,16309,446,65,16332],
[M,446,51,16318,446,64,16331],
[M,446,42,16309,446,50,16317],
[M,443,44,16198,443,67,16221],
[M,443,53,16207,443,66,16220],
[M,443,44,16198,443,52,16206],
[M,443,18,16172,443,68,16222],
[M,435,27,15868,435,40,15881],
[M,435,27,15868,435,34,15875],
[M,435,16,15857,435,23,15864],
[M,425,14,15420,433,19,15816],
[M,428,33,15560,428,72,15599],
[M,428,64,15591,428,71,15598],
[M,428,46,15573,428,62,15589],
[M,428,46,15573,428,56,15583],
[M,428,41,15568,428,44,15571],
[M,428,33,15560,428,40,15567],
[M,428,22,15549,428,29,15556],
[M,427,42,15514,427,53,15525],
[M,427,35,15507,428,92,15619],
[M,427,18,15490,427,25,15497],
[M,430,18,15683,430,40,15705],
[M,430,18,15683,430,34,15699],
[M,430,18,15683,430,28,15693],
[M,432,29,15757,432,42,15770],
[M,432,29,15757,432,36,15764],
[M,432,18,15746,432,25,15753],
[M,429,24,15646,429,42,15664],
[M,426,19,15454,426,36,15471],
[M,435,42,15883,435,65,15906],
[M,435,51,15892,435,64,15905],
[M,435,42,15883,435,50,15891],
[M,428,22,15549,428,79,15606],
[M,428,22,15549,428,91,15618],
[M,428,22,15549,428,85,15612],
[M,427,18,15490,428,93,15620],
[M,432,44,15772,432,67,15795],
[M,432,53,15781,432,66,15794],
[M,432,44,15772,432,52,15780],
[M,432,18,15746,432,68,15796],
[M,463,34,16921,463,57,16944],
[M,463,43,16930,463,56,16943],
[M,463,34,16921,463,42,16929],
[M,463,8,16895,463,58,16945],
[M,414,62,15035,414,100,15073],
[M,413,0,14930,415,3,15096],
[M,411,61,14868,411,99,14906],
[M,410,0,14765,412,3,14929],
[M,407,24,14726,407,53,14755],
[M,407,31,14733,407,34,14736],
[M,406,2,14683,408,5,14762],
[M,404,27,14640,404,58,14671],
[M,404,43,14656,404,52,14665],
[M,404,13,14626,404,18,14631],
[M,404,6,14619,404,59,14672],
[M,402,2,14557,405,5,14679],
[M,399,31,14511,399,58,14538],
[M,398,6,14449,399,59,14539],
[M,397,49,14415,397,74,14440],
[M,397,31,14397,397,75,14441],
[M,396,6,14335,397,76,14442],
[M,389,40,14152,389,67,14179],
[M,389,19,14131,389,68,14180],
[M,390,33,14215,390,44,14226],
[M,390,33,14215,390,42,14224],
[M,390,20,14202,390,32,14214],
[M,390,46,14228,390,69,14251],
[M,390,20,14202,390,70,14252],
[M,385,45,14024,385,68,14047],
[M,385,20,13999,385,69,14048],
[M,378,30,13804,378,53,13827],
[M,377,2,13737,379,5,13834],
[M,373,39,13613,373,70,13644],
[M,373,46,13620,373,51,13625],
[M,373,15,13589,373,71,13645],
[M,374,29,13676,374,44,13691],
[M,374,29,13676,374,42,13689],
[M,374,29,13676,374,38,13685],
[M,374,16,13663,374,28,13675],
[M,374,46,13693,374,73,13720],
[M,374,53,13700,374,58,13705],
[M,374,16,13663,374,74,13721],
[M,362,6,13327,365,43,13494],
[M,362,16,13337,362,29,13350],
[M,362,6,13327,362,15,13336],
[M,363,8,13370,363,17,13379],
[M,362,6,13327,362,36,13357],
[M,364,8,13414,364,18,13424],
[M,363,8,13370,363,39,13401],
[M,365,8,13459,365,35,13486],
[M,364,8,13414,364,40,13446],
[M,365,8,13459,365,43,13494],
[M,352,6,12921,356,36,13142],
[M,352,6,12921,352,17,12932],
[M,353,20,12966,353,40,12986],
[M,353,10,12956,353,19,12965],
[M,352,6,12921,352,30,12945],
[M,354,20,13016,354,40,13036],
[M,354,10,13006,354,19,13015],
[M,353,10,12956,353,49,12995],
[M,355,20,13068,355,40,13088],
[M,355,10,13058,355,19,13067],
[M,354,10,13006,354,51,13047],
[M,356,10,13116,356,28,13134],
[M,355,10,13058,355,57,13105],
[M,356,10,13116,356,36,13142],
[M,337,6,12286,337,56,12336],
[M,337,29,12309,337,49,12329],
[M,337,19,12299,337,28,12308],
[M,338,6,12343,340,9,12459],
[M,338,41,12378,338,56,12393],
[M,338,17,12354,340,9,12459],
[M,339,8,12419,339,28,12439],
[M,338,21,12358,338,31,12368],
[M,342,6,12512,345,32,12626],
[M,343,8,12535,343,17,12544],
[M,342,6,12512,342,16,12522],
[M,344,8,12568,344,18,12578],
[M,343,8,12535,343,28,12555],
[M,345,8,12602,345,24,12618],
[M,344,8,12568,344,29,12589],
[M,345,8,12602,345,32,12626],
[M,327,6,11825,329,9,11973],
[M,327,23,11842,329,9,11973],
[M,328,11,11904,328,31,11924],
[M,328,11,11904,328,18,11911],
[M,327,27,11846,327,43,11862],
[M,330,6,11980,330,48,12022],
[M,330,25,11999,330,35,12009],
[M,330,6,11980,330,20,11994],
[M,330,25,11999,330,48,12022],
[M,328,33,11926,328,45,11938],
[M,328,33,11926,328,39,11932],
[M,328,52,11945,328,66,11959],
[M,328,52,11945,328,59,11952],
[M,320,6,11560,320,58,11612],
[M,320,45,11599,320,56,11610],
[M,320,23,11577,320,33,11587],
[M,320,6,11560,320,18,11572],
[M,320,23,11577,320,58,11612],
[M,313,8,11368,313,46,11406],
[M,313,39,11399,313,44,11404],
[M,313,19,11379,313,26,11386],
[M,315,10,11438,315,43,11471],
[M,315,10,11438,315,16,11444],
[M,317,10,11496,317,45,11531],
[M,317,10,11496,317,17,11503],
[M,314,11,11418,314,19,11426],
[M,308,6,11078,308,96,11168],
[M,308,75,11147,308,93,11165],
[M,308,46,11118,308,63,11135],
[M,308,23,11095,308,33,11105],
[M,308,6,11078,308,18,11090],
[M,308,23,11095,308,96,11168],
[M,301,8,10905,301,38,10935],
[M,301,19,10916,301,26,10923],
[M,300,60,10878,300,76,10894],
[M,300,33,10851,300,48,10866],
[M,303,10,10967,303,38,10995],
[M,303,10,10967,303,16,10973],
[M,305,10,11020,305,39,11049],
[M,305,10,11020,305,17,11027],
[M,302,11,10947,302,19,10955],
[M,285,9,10070,285,61,10122],
[M,285,34,10095,285,54,10115],
[M,285,9,10070,285,29,10090],
[M,287,8,10197,289,11,10332],
[M,287,24,10213,289,11,10332],
[M,288,49,10307,288,61,10319],
[M,288,36,10294,288,47,10305],
[M,288,10,10268,288,32,10290],
[M,286,50,10173,286,63,10186],
[M,286,30,10153,286,38,10161],
[M,293,8,10522,293,13,10527],
[M,285,34,10095,285,60,10121],
[M,291,8,10433,291,76,10501],
[M,291,18,10443,291,38,10463],
[M,291,8,10433,291,17,10442],
[M,290,67,10400,290,89,10422],
[M,290,34,10367,290,55,10388],
[M,291,53,10478,291,63,10488],
[M,291,8,10433,291,48,10473],
[M,291,53,10478,291,76,10501],
[M,257,6,9133,259,9,9246],
[M,257,41,9168,257,49,9176],
[M,257,17,9144,259,9,9246],
[M,258,8,9206,258,28,9226],
[M,257,21,9148,257,31,9158],
[M,260,6,9253,260,49,9296],
[M,260,17,9264,260,27,9274],
[M,261,6,9303,261,53,9350],
[M,261,18,9315,261,45,9342],
[M,262,30,9381,262,61,9412],
[M,262,30,9381,262,39,9390],
[M,262,6,9357,262,16,9367],
[M,255,4,9037,263,7,9447],
[M,251,29,8834,251,53,8858],
[M,251,29,8834,251,40,8845],
[M,251,6,8811,251,19,8824],
[M,252,8,8876,252,40,8908],
[M,252,19,8887,252,39,8907],
[M,252,8,8876,252,18,8886],
[M,252,42,8910,252,76,8944],
[M,252,55,8923,252,75,8943],
[M,252,42,8910,252,54,8922],
[M,253,8,8954,253,48,8994],
[M,253,27,8973,253,47,8993],
[M,253,8,8954,253,26,8972],
[M,253,50,8996,253,76,9022],
[M,253,50,8996,253,68,9014],
[M,246,4,8530,254,7,9031],
[M,237,6,8133,237,47,8174],
[M,237,26,8153,237,46,8173],
[M,237,17,8144,237,25,8152],
[M,238,6,8181,240,9,8305],
[M,238,41,8216,238,56,8231],
[M,238,17,8192,240,9,8305],
[M,239,8,8261,239,28,8281],
[M,238,21,8196,238,31,8206],
[M,242,6,8358,242,38,8390],
[M,242,17,8369,242,27,8379],
[M,243,6,8397,243,42,8433],
[M,243,18,8409,243,34,8425],
[M,244,35,8469,244,55,8489],
[M,244,35,8469,244,44,8478],
[M,244,6,8440,244,13,8447],
[M,232,4,7883,245,7,8524],
[M,228,6,7736,228,51,7781],
[M,228,30,7760,228,50,7780],
[M,228,20,7750,228,29,7759],
[M,229,6,7788,229,42,7824],
[M,229,19,7801,229,29,7811],
[M,223,4,7543,231,7,7877],
[M,230,6,7831,230,16,7841],
[M,211,6,7110,218,9,7384],
[M,219,6,7391,219,42,7427],
[M,219,20,7405,219,40,7425],
[M,219,20,7405,219,32,7417],
[M,220,6,7434,220,54,7482],
[M,220,41,7469,220,52,7480],
[M,220,19,7447,220,29,7457],
[M,210,4,7070,222,7,7537],
[M,221,6,7489,221,18,7501],
[M,213,8,7242,213,60,7294],
[M,213,54,7288,213,59,7293],
[M,213,19,7253,213,43,7277],
[M,216,14,7342,216,36,7364],
[M,216,29,7357,216,35,7363],
[M,202,6,6610,207,9,6940],
[M,208,41,6982,208,114,7055],
[M,208,93,7034,208,111,7052],
[M,208,64,7005,208,81,7022],
[M,208,41,6982,208,51,6992],
[M,208,27,6968,208,39,6980],
[M,208,6,6947,208,23,6964],
[M,200,4,6501,209,7,7064],
[M,205,8,6853,205,38,6883],
[M,205,19,6864,205,26,6871],
[M,204,60,6826,204,76,6842],
[M,204,33,6799,204,48,6814],
[M,206,22,6906,206,44,6928],
[M,206,37,6921,206,43,6927],
[M,189,6,5968,189,54,6016],
[M,189,28,5990,189,48,6010],
[M,190,6,6023,192,9,6095],
[M,190,22,6039,192,9,6095],
[M,191,8,6072,191,15,6079],
[M,194,6,6166,196,9,6303],
[M,194,22,6182,196,9,6303],
[M,195,47,6280,195,59,6292],
[M,195,34,6267,195,45,6278],
[M,195,8,6241,195,30,6263],
[M,193,48,6144,193,61,6157],
[M,193,28,6124,193,36,6132],
[M,197,6,6310,197,99,6403],
[M,197,74,6378,197,96,6400],
[M,197,41,6345,197,62,6366],
[M,197,19,6323,197,29,6333],
[M,187,4,5858,199,7,6495],
[M,198,6,6410,198,17,6421],
[M,158,0,4712,169,3,5316],
[M,159,67,4818,159,87,4838],
[M,166,36,5233,166,58,5255],
[M,166,36,5233,166,56,5253],
[M,166,87,5284,166,99,5296],
[M,166,67,5264,166,78,5275],
[M,166,60,5257,166,100,5297],
[M,166,6,5203,166,101,5298],
[M,162,8,4924,164,11,5104],
[M,165,16,5121,165,43,5148],
[M,165,25,5130,165,36,5141],
[M,165,16,5121,165,24,5129],
[M,165,8,5113,165,15,5120],
[M,165,16,5121,165,49,5154],
[M,165,16,5121,165,47,5152],
[M,165,78,5183,165,89,5194],
[M,165,58,5163,165,69,5174],
[M,165,51,5156,165,90,5195],
[M,161,6,4884,165,91,5196],
[M,163,16,5009,163,46,5039],
[M,163,16,5009,163,44,5037],
[M,163,82,5075,163,97,5090],
[M,163,55,5048,163,66,5059],
[M,163,75,5068,163,97,5090],
[M,163,48,5041,163,98,5091],
[M,162,14,4930,164,11,5104],
[M,146,0,4118,157,3,4711],
[M,147,67,4229,147,84,4246],
[M,154,33,4630,154,60,4657],
[M,154,33,4630,154,58,4655],
[M,154,62,4659,154,95,4692],
[M,154,69,4666,154,80,4677],
[M,154,6,4603,154,96,4693],
[M,150,8,4341,152,11,4504],
[M,153,16,4521,153,43,4548],
[M,153,25,4530,153,36,4541],
[M,153,16,4521,153,24,4529],
[M,153,8,4513,153,15,4520],
[M,153,16,4521,153,49,4554],
[M,153,16,4521,153,47,4552],
[M,153,78,4583,153,89,4594],
[M,153,58,4563,153,69,4574],
[M,153,51,4556,153,90,4595],
[M,149,6,4296,153,91,4596],
[M,151,16,4426,151,46,4456],
[M,151,16,4426,151,44,4454],
[M,151,48,4458,151,81,4491],
[M,151,55,4465,151,66,4476],
[M,150,14,4347,152,11,4504],
[M,134,0,3804,144,3,4116],
[M,135,2,3860,143,5,4112],
[M,137,4,3929,142,12,4106],
[M,138,15,3957,138,27,3969],
[M,136,4,3905,136,23,3924],
[M,138,6,3948,141,9,4093],
[M,139,69,4041,139,78,4050],
[M,138,11,3953,138,28,3970],
[M,142,6,4100,142,12,4106],
[M,139,52,4024,139,87,4059],
[M,139,20,3992,139,88,4060],
[M,139,8,3980,139,88,4060],
[M,139,8,3980,140,22,4083],
[M,130,19,3755,130,55,3791],
[M,104,2,2892,131,5,3798],
[M,127,9,3658,127,32,3681],
[M,127,47,3696,127,57,3706],
[M,127,47,3696,127,55,3704],
[M,127,39,3688,127,46,3695],
[M,128,12,3721,128,16,3725],
[M,127,39,3688,127,58,3707],
[M,127,34,3683,127,59,3708],
[M,123,9,3538,123,32,3561],
[M,123,47,3576,123,57,3586],
[M,123,47,3576,123,55,3584],
[M,123,39,3568,123,46,3575],
[M,124,12,3601,124,16,3605],
[M,123,39,3568,123,58,3587],
[M,123,34,3563,123,59,3588],
[M,119,9,3424,119,32,3447],
[M,119,47,3462,119,57,3472],
[M,119,47,3462,119,55,3470],
[M,119,39,3454,119,46,3461],
[M,120,12,3487,120,16,3491],
[M,119,39,3454,119,58,3473],
[M,119,34,3449,119,59,3474],
[M,105,4,2913,117,9,3391],
[M,106,6,2942,117,9,3391],
[M,116,8,3367,116,22,3381],
[M,107,8,2991,115,13,3358],
[M,109,10,3037,115,13,3358],
[M,114,54,3328,114,68,3342],
[M,114,34,3308,114,45,3319],
[M,110,12,3071,113,17,3273],
[M,111,30,3119,111,40,3129],
[M,111,30,3119,111,38,3127],
[M,111,17,3106,111,29,3118],
[M,108,14,3019,108,21,3026],
[M,114,27,3301,114,69,3343],
[M,111,17,3106,111,41,3130],
[M,111,84,3173,111,94,3183],
[M,111,84,3173,111,92,3181],
[M,111,75,3164,111,83,3172],
[M,111,55,3144,111,66,3155],
[M,112,52,3239,112,66,3253],
[M,112,32,3219,112,43,3230],
[M,111,75,3164,111,95,3184],
[M,111,48,3137,111,96,3185],
[M,111,43,3132,111,97,3186],
[M,112,25,3212,112,67,3254],
[M,112,20,3207,112,68,3255],
[M,100,2,2776,100,59,2833],
[M,96,2,2723,96,14,2735],
[M,95,2,2704,96,0,2721],
[M,94,2,2603,95,0,2702],
[M,93,2,2510,94,0,2601],
[M,92,2,2426,93,0,2508],
[M,91,2,2338,92,0,2424],
[M,83,8,2225,83,49,2266],
[M,83,8,2225,83,15,2232],
[M,83,35,2252,83,48,2265],
[M,83,26,2243,83,34,2251],
[M,83,8,2225,83,21,2238],
[M,83,26,2243,83,49,2266],
[M,67,6,1798,72,9,2026],
[M,73,19,2046,73,41,2068],
[M,73,19,2046,73,39,2066],
[M,73,6,2033,73,15,2042],
[M,66,4,1767,74,7,2077],
[M,67,21,1813,72,9,2026],
[M,68,8,1870,71,11,2016],
[M,70,20,1983,70,29,1992],
[M,69,10,1909,69,63,1962],
[M,69,35,1934,69,51,1950],
[M,69,35,1934,69,49,1948],
[M,53,30,1460,53,53,1483],
[M,53,30,1460,53,47,1477],
[M,53,30,1460,53,41,1471],
[M,54,25,1509,54,49,1533],
[M,54,35,1519,54,48,1532],
[M,54,25,1509,54,34,1518],
[M,54,12,1496,54,21,1505],
[M,53,9,1439,53,29,1459],
[M,54,12,1496,54,50,1534],
[M,40,17,1071,40,35,1089],
[M,40,37,1091,40,41,1095],
[M,43,60,1248,43,83,1271],
[M,43,60,1248,43,68,1256],
[M,43,49,1237,43,55,1243],
[M,43,42,1230,43,85,1273],
[M,43,20,1208,43,29,1217],
[M,42,21,1137,42,32,1148],
[M,43,49,1237,43,84,1272],
[M,43,34,1222,43,86,1274],
[M,43,20,1208,43,86,1274],
[M,42,21,1137,43,87,1275],
[M,42,16,1132,43,88,1276],
[M,37,91,947,37,126,982],
[M,37,84,940,37,127,983],
[M,37,70,926,37,128,984],
[M,37,19,875,37,129,985],
[M,36,12,845,37,130,986],
[M,28,39,513,28,73,547],
[M,28,28,502,28,93,567],
[M,28,95,569,28,103,577],
[M,28,0,474,28,108,582],
[M,16,4,241,24,24,464],
[M,17,4,265,17,14,275],
[M,16,4,241,16,20,257],
[M,14,0,211,26,3,472],
[M,18,4,289,18,14,299],
[M,17,4,265,17,20,281],
[M,19,4,313,19,15,324],
[M,18,4,289,18,20,305],
[M,20,4,338,20,16,350],
[M,19,4,313,19,21,330],
[M,21,4,364,21,19,379],
[M,20,4,338,20,22,356],
[M,22,4,393,22,16,405],
[M,21,4,364,21,25,385],
[M,23,4,419,23,15,430],
[M,22,4,393,22,22,411],
[M,24,4,444,24,18,458],
[M,23,4,419,23,21,436],
[M,24,4,444,24,24,464],
[M,3,0,13,579,1,20221],
[M,12,11,200,12,20,209],
[M,554,7,19365,554,33,19391],
[M,554,7,19365,554,31,19389],
[M,553,17,19334,553,38,19355],
[M,549,0,19232,551,3,19315],
[M,550,2,19272,550,12,19282],
[M,501,2,17921,502,0,17977],
[M,501,15,17934,501,23,17942],
[M,488,2,17533,497,5,17878],
[M,495,29,17825,495,42,17838],
[M,495,29,17825,495,36,17832],
[M,495,16,17812,495,23,17819],
[M,491,8,17633,493,11,17754],
[M,492,35,17726,492,50,17741],
[M,492,35,17726,492,44,17735],
[M,492,23,17714,492,28,17719],
[M,492,10,17701,492,22,17713],
[M,491,24,17649,491,34,17659],
[M,487,14,17507,487,35,17528],
[M,469,0,16973,485,3,17491],
[M,470,2,17014,471,0,17065],
[M,470,15,17027,470,23,17035],
[M,417,0,15098,467,3,16971],
[M,418,2,15136,418,38,15172],
[M,414,27,15000,414,60,15033],
[M,411,26,14833,411,59,14866],
[M,407,12,14714,407,22,14724],
[M,407,12,14714,407,20,14722],
[M,407,12,14714,407,16,14718],
[M,407,4,14706,407,11,14713],
[M,403,12,14597,403,26,14611],
[M,403,12,14597,403,24,14609],
[M,403,12,14597,403,20,14605],
[M,403,12,14597,403,17,14602],
[M,403,4,14589,403,11,14596],
[M,394,2,14280,401,5,14553],
[M,395,4,14308,400,7,14547],
[M,399,16,14496,399,29,14509],
[M,399,16,14496,399,27,14507],
[M,399,16,14496,399,23,14503],
[M,399,8,14488,399,15,14495],
[M,397,16,14382,397,29,14395],
[M,397,16,14382,397,27,14393],
[M,397,16,14382,397,23,14389],
[M,397,8,14374,397,15,14381],
[M,380,2,13838,393,5,14276],
[M,381,4,13882,392,7,14270],
[M,387,6,14065,391,9,14262],
[M,389,27,14139,389,38,14150],
[M,389,27,14139,389,36,14148],
[M,389,19,14131,389,26,14138],
[M,382,6,13914,386,9,14058],
[M,385,33,14012,385,43,14022],
[M,385,33,14012,385,41,14020],
[M,385,20,13999,385,32,14011],
[M,378,17,13791,378,28,13802],
[M,378,17,13791,378,26,13800],
[M,378,4,13778,378,16,13790],
[M,373,23,13597,373,37,13611],
[M,373,23,13597,373,35,13609],
[M,373,23,13597,373,31,13605],
[M,373,15,13589,373,22,13596],
[M,371,2,13535,376,5,13733],
[M,268,0,9458,368,3,13510],
[M,359,6,13211,361,9,13320],
[M,359,41,13246,359,49,13254],
[M,359,17,13222,361,9,13320],
[M,360,8,13280,360,28,13300],
[M,359,21,13226,359,31,13236],
[M,358,4,13156,366,7,13502],
[M,348,6,12731,350,9,12864],
[M,348,45,12770,348,58,12783],
[M,348,21,12746,350,9,12864],
[M,349,8,12813,349,34,12839],
[M,348,25,12750,348,35,12760],
[M,347,4,12640,357,7,13150],
[M,333,6,12096,335,9,12229],
[M,333,45,12135,333,58,12148],
[M,333,21,12111,335,9,12229],
[M,334,8,12178,334,34,12204],
[M,333,25,12115,333,35,12125],
[M,332,4,12036,346,7,12634],
[M,323,6,11664,325,9,11777],
[M,323,41,11699,323,49,11707],
[M,323,17,11675,325,9,11777],
[M,324,8,11732,324,35,11759],
[M,323,21,11679,323,31,11689],
[M,322,4,11626,331,7,12030],
[M,311,6,11222,319,9,11553],
[M,311,53,11269,311,61,11277],
[M,311,18,11234,319,9,11553],
[M,312,8,11314,312,53,11359],
[M,312,47,11353,312,52,11358],
[M,312,19,11325,312,43,11349],
[M,311,22,11238,311,38,11254],
[M,310,4,11182,321,7,11620],
[M,298,6,10660,307,9,11071],
[M,298,18,10672,307,9,11071],
[M,299,8,10748,299,77,10817],
[M,299,64,10804,299,76,10816],
[M,299,51,10791,299,62,10802],
[M,299,18,10758,299,47,10787],
[M,298,22,10676,298,38,10692],
[M,297,48,10638,297,61,10651],
[M,297,28,10618,297,36,10626],
[M,296,4,10551,309,7,11176],
[M,285,9,10070,285,23,10084],
[M,284,4,10000,295,7,10545],
[M,280,2,9916,280,24,9938],
[M,272,8,9575,272,47,9614],
[M,273,8,9624,273,41,9657],
[M,274,8,9667,274,34,9693],
[M,275,8,9703,275,71,9766],
[M,276,8,9776,276,83,9851],
[M,277,8,9861,277,45,9898],
[M,271,21,9565,278,7,9906],
[M,171,0,5318,265,3,9455],
[M,256,6,9092,256,40,9126],
[M,256,26,9112,256,39,9125],
[M,256,17,9103,256,25,9111],
[M,247,6,8621,249,9,8754],
[M,247,45,8660,247,58,8673],
[M,247,21,8636,249,9,8754],
[M,248,8,8703,248,34,8729],
[M,247,25,8640,247,35,8650],
[M,233,6,7943,235,9,8076],
[M,233,45,7982,233,58,7995],
[M,233,21,7958,235,9,8076],
[M,234,8,8025,234,34,8051],
[M,233,25,7962,233,35,7972],
[M,224,6,7581,226,9,7688],
[M,224,35,7610,224,43,7618],
[M,224,17,7592,226,9,7688],
[M,225,8,7643,225,35,7670],
[M,211,56,7160,211,64,7168],
[M,211,41,7145,211,49,7153],
[M,211,18,7122,218,9,7384],
[M,212,8,7195,212,46,7233],
[M,212,39,7226,212,44,7231],
[M,212,19,7206,212,26,7213],
[M,202,57,6661,202,65,6669],
[M,202,18,6622,207,9,6940],
[M,203,8,6696,203,77,6765],
[M,203,64,6752,203,76,6764],
[M,203,51,6739,203,62,6750],
[M,203,18,6706,203,47,6735],
[M,202,22,6626,202,32,6636],
[M,201,48,6588,201,61,6601],
[M,201,28,6568,201,36,6576],
[M,188,6,5925,188,42,5961],
[M,188,22,5941,188,36,5955],
[M,183,2,5775,183,23,5796],
[M,175,8,5434,175,47,5473],
[M,176,8,5483,176,41,5516],
[M,177,8,5526,177,34,5552],
[M,178,8,5562,178,71,5625],
[M,179,8,5635,179,83,5710],
[M,180,8,5720,180,45,5757],
[M,174,21,5424,181,7,5765],
[M,159,26,4777,159,52,4803],
[M,159,26,4777,159,50,4801],
[M,159,2,4753,168,5,5312],
[M,160,4,4845,167,7,5306],
[M,166,36,5233,166,52,5249],
[M,166,36,5233,166,46,5243],
[M,166,28,5225,166,35,5232],
[M,162,36,4952,162,62,4978],
[M,162,36,4952,162,60,4976],
[M,163,16,5009,163,40,5033],
[M,163,25,5018,163,36,5029],
[M,163,16,5009,163,24,5017],
[M,163,10,5003,163,15,5008],
[M,162,18,4934,162,28,4944],
[M,159,6,4757,159,16,4767],
[M,147,26,4188,147,52,4214],
[M,147,26,4188,147,50,4212],
[M,147,2,4164,156,5,4707],
[M,148,4,4253,155,7,4701],
[M,154,33,4630,154,54,4651],
[M,154,33,4630,154,48,4645],
[M,154,25,4622,154,32,4629],
[M,150,36,4369,150,62,4395],
[M,150,36,4369,150,60,4393],
[M,151,16,4426,151,40,4450],
[M,151,25,4435,151,36,4446],
[M,151,16,4426,151,24,4434],
[M,151,10,4420,151,15,4425],
[M,150,18,4351,150,28,4361],
[M,147,6,4168,147,16,4178],
[M,134,25,3829,134,31,3835],
[M,103,0,2839,132,3,3802],
[M,130,46,3782,130,54,3790],
[M,130,26,3762,130,37,3773],
[M,126,4,3620,129,9,3735],
[M,127,21,3670,127,31,3680],
[M,127,21,3670,127,29,3678],
[M,127,9,3658,127,20,3669],
[M,122,4,3506,125,9,3615],
[M,123,21,3550,123,31,3560],
[M,123,21,3550,123,29,3558],
[M,123,9,3538,123,20,3549],
[M,118,4,3396,121,9,3501],
[M,119,21,3436,119,31,3446],
[M,119,21,3436,119,29,3444],
[M,119,9,3424,119,20,3435],
[M,103,18,2857,103,24,2863],
[M,99,0,2760,101,3,2837],
[M,100,4,2778,100,59,2833],
[M,100,18,2792,100,21,2795],
[M,100,30,2804,100,37,2811],
[M,100,47,2821,100,58,2832],
[M,100,39,2813,100,58,2832],
[M,100,23,2797,100,37,2811],
[M,100,11,2785,100,21,2795],
[M,91,4,2340,91,26,2362],
[M,91,19,2355,91,25,2361],
[M,92,4,2428,92,33,2457],
[M,92,19,2443,92,32,2456],
[M,93,4,2512,93,24,2532],
[M,93,17,2525,93,23,2531],
[M,94,4,2605,94,46,2647],
[M,94,18,2619,94,29,2630],
[M,94,39,2640,94,45,2646],
[M,94,31,2632,94,45,2646],
[M,94,10,2611,94,29,2630],
[M,93,10,2518,93,23,2531],
[M,92,11,2435,92,32,2456],
[M,91,11,2347,91,25,2361],
[M,78,0,2084,88,3,2316],
[M,86,2,2285,86,21,2304],
[M,86,2,2285,86,12,2295],
[M,82,17,2207,82,26,2216],
[M,81,6,2165,84,9,2276],
[M,80,12,2134,80,34,2156],
[M,67,45,1837,67,53,1845],
[M,68,22,1884,68,29,1891],
[M,65,22,1739,65,43,1760],
[M,53,9,1439,53,23,1453],
[M,53,9,1439,53,21,1451],
[M,52,4,1405,56,7,1552],
[M,51,24,1377,51,45,1398],
[M,30,0,584,49,3,1351],
[M,31,2,659,48,5,1347],
[M,32,4,686,47,9,1341],
[M,33,6,752,47,9,1341],
[M,34,8,780,45,13,1308],
[M,35,10,814,45,13,1308],
[M,38,12,999,44,17,1294],
[M,39,14,1029,39,38,1053],
[M,39,26,1041,39,36,1051],
[M,37,102,958,37,125,981],
[M,37,102,958,37,110,966],
[M,37,91,947,37,97,953],
[M,37,70,926,37,79,935],
[M,37,19,875,37,30,886],
[M,30,40,624,30,49,633],
[M,28,49,523,28,72,546],
[M,28,49,523,28,57,531],
[M,28,39,513,28,45,519],
[M,28,28,502,28,35,509],
[M,28,17,491,28,24,498],
[M,16,4,241,16,14,251]];
var _lessthan6 = NAMESPACE.get("_lessthan");
var _plus7 = NAMESPACE.get("_plus");
var builtins8 = NAMESPACE.get("builtins");
var not9 = NAMESPACE.get("not");
var nothing10 = NAMESPACE.get("nothing");
var print_DASH_error11 = NAMESPACE.get("print-error");
var string_DASH_substring12 = NAMESPACE.get("string-substring");
var torepr13 = NAMESPACE.get("torepr");
var $type$Boolean14 = NAMESPACE.get("$type$Boolean");
var $type$String15 = NAMESPACE.get("$type$String");
var $Hanf_extend204250 = function(anf_extend139251,A317,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,CS719,Loc7656,PP518,anf_extend139057,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,fold26080,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,link_DASH_list_DASH_visitor40491,list3192,map24493,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,range3696,value_DASH_delays_DASH_exec_DASH_of45197,_lessthan6,builtins8,nothing10) {
var anf_extend1444113 = R.makeMethod(function(self487151) {
return function(l488150,binds489148,body490149) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[14],3,arguments);
}
var anf_arg1424147 = R.makeFunction(function(b1492153,i493154) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[9],2,arguments);
}
var anf_bracket1395169 = G(b1492153,"b",L[13]);
var anf_arg1396165 = G(anf_bracket1395169,"id",L[12]);
var anf_arg1397166 = G(b1492153,"value",L[11]);
var $z157158 = D;
var $f163164 = function(_) {
return R.isFunction(value_DASH_delays_DASH_exec_DASH_of45197.$var)?value_DASH_delays_DASH_exec_DASH_of45197.$var.app(anf_arg1396165,anf_arg1397166):R.ffi.throwNonFunApp(L[10],value_DASH_delays_DASH_exec_DASH_of45197.$var,[anf_arg1396165,anf_arg1397166]);
};
try {
if(--R.GAS > 0) {
$z157158 = $f163164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f163164,
"from":L[10]});
}
} catch($e155156) {
if(R.isCont($e155156)) {
var $ss159160 = {"from":L[10],
"go":function(rhs_DASH_is_DASH_delayed494167) {
return $Hrhs_DASH_is_DASH_delayed2008168(rhs_DASH_is_DASH_delayed494167,binds489148,fold26080,i493154,range3696,self487151,_lessthan6);
}};
$e155156.stack[R.EXN_STACKHEIGHT++] = $ss159160;
}
if(R.isPyretException($e155156)) {
$e155156.pyretStack.push(L[10]);
}
throw $e155156;
}
var $ret161162 = $Hrhs_DASH_is_DASH_delayed2008168($z157158,binds489148,fold26080,i493154,range3696,self487151,_lessthan6);
++R.GAS;
return $ret161162;
});
var anf_fun1425145 = G(binds489148,"length",L[8]);
var $z137138 = D;
var $f143144 = function(_) {
return R.isFunction(anf_fun1425145)?anf_fun1425145.app():R.ffi.throwNonFunApp(L[7],anf_fun1425145,[]);
};
try {
if(--R.GAS > 0) {
$z137138 = $f143144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f143144,
"from":L[7]});
}
} catch($e135136) {
if(R.isCont($e135136)) {
var $ss139140 = {"from":L[7],
"go":function(anf_arg1426146) {
return $Hanf_arg2019152(anf_arg1426146,A317,anf_arg1424147,binds489148,body490149,l488150,map24493,range3696,self487151);
}};
$e135136.stack[R.EXN_STACKHEIGHT++] = $ss139140;
}
if(R.isPyretException($e135136)) {
$e135136.pyretStack.push(L[7]);
}
throw $e135136;
}
var $ret141142 = $Hanf_arg2019152($z137138,A317,anf_arg1424147,binds489148,body490149,l488150,map24493,range3696,self487151);
++R.GAS;
return $ret141142;
};
},{"length":4});
var anf_extend1452114 = R.makeMethod(function(self504133) {
return function(l505130,id506129,$underscore507134) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[6],3,arguments);
}
var anf_fun1446127 = G(A317,"s-id-letrec",L[5]);
var anf_bracket1447132 = G(self504133,"env",L[4]);
var anf_fun1448128 = G(anf_bracket1447132,"get",L[3]);
var anf_fun1449125 = G(id506129,"key",L[2]);
var $z117118 = D;
var $f123124 = function(_) {
return R.isFunction(anf_fun1449125)?anf_fun1449125.app():R.ffi.throwNonFunApp(L[1],anf_fun1449125,[]);
};
try {
if(--R.GAS > 0) {
$z117118 = $f123124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f123124,
"from":L[1]});
}
} catch($e115116) {
if(R.isCont($e115116)) {
var $ss119120 = {"from":L[1],
"go":function(anf_arg1450126) {
return $Hanf_arg2022131(anf_arg1450126,anf_fun1446127,anf_fun1448128,id506129,l505130);
}};
$e115116.stack[R.EXN_STACKHEIGHT++] = $ss119120;
}
if(R.isPyretException($e115116)) {
$e115116.pyretStack.push(L[1]);
}
throw $e115116;
}
var $ret121122 = $Hanf_arg2022131($z117118,anf_fun1446127,anf_fun1448128,id506129,l505130);
++R.GAS;
return $ret121122;
};
},{"length":4});
var letrec_DASH_visitor486110 = anf_extend139057.extendWith({"env":anf_extend139251,
"s-letrec":anf_extend1444113,
"s-id-letrec":anf_extend1452114});
var result_DASH_after_DASH_checks1508111 = nothing10;
var anf_fun1453108 = G(builtins8,"current-checker",L[0]);
var $z100101 = D;
var $f106107 = function(_) {
return R.isFunction(anf_fun1453108)?anf_fun1453108.app():R.ffi.throwNonFunApp(L[0],anf_fun1453108,[]);
};
try {
if(--R.GAS > 0) {
$z100101 = $f106107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f106107,
"from":L[0]});
}
} catch($e9899) {
if(R.isCont($e9899)) {
var $ss102103 = {"from":L[0],
"go":function(anf_bracket1454109) {
return $Hanf_bracket2041112(anf_bracket1454109,A317,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,CS719,Loc7656,PP518,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,list3192,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8);
}};
$e9899.stack[R.EXN_STACKHEIGHT++] = $ss102103;
}
if(R.isPyretException($e9899)) {
$e9899.pyretStack.push(L[0]);
}
throw $e9899;
}
var $ret104105 = $Hanf_bracket2041112($z100101,A317,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,CS719,Loc7656,PP518,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,list3192,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8);
++R.GAS;
return $ret104105;
};
var $Hanf_bracket2041112 = function(anf_bracket1454109,A317,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,CS719,Loc7656,PP518,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,list3192,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8) {
var anf_fun1455184 = G(anf_bracket1454109,"run-checks",L[0]);
var anf_fun1456180 = G(list3192,"make",L[0]);
var anf_obj1474216 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[20],0,arguments);
}
var d509230 = G(A317,"dummy-loc",L[22]);
var anf_fun1458228 = G(builtins8,"current-checker",L[21]);
var $z220221 = D;
var $f226227 = function(_) {
return R.isFunction(anf_fun1458228)?anf_fun1458228.app():R.ffi.throwNonFunApp(L[21],anf_fun1458228,[]);
};
try {
if(--R.GAS > 0) {
$z220221 = $f226227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f226227,
"from":L[21]});
}
} catch($e218219) {
if(R.isCont($e218219)) {
var $ss222223 = {"from":L[21],
"go":function(anf_bracket1459229) {
return $Hanf_bracket2029231(anf_bracket1459229,A317,PP518,d509230,flatten_DASH_single_DASH_blocks9379);
}};
$e218219.stack[R.EXN_STACKHEIGHT++] = $ss222223;
}
if(R.isPyretException($e218219)) {
$e218219.pyretStack.push(L[21]);
}
throw $e218219;
}
var $ret224225 = $Hanf_bracket2029231($z220221,A317,PP518,d509230,flatten_DASH_single_DASH_blocks9379);
++R.GAS;
return $ret224225;
});
var anf_obj1475217 = R.makeSrcloc(L[20]);
var anf_array_val1476181 = R.makeObject({"name":("check-block-1"),
"run":anf_obj1474216,
"location":anf_obj1475217});
var anf_obj1488186 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[15],0,arguments);
}
var p510198 = R.makeFunction(function(arg_DASH_146202) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[18],1,arguments);
}
var anf_fun1479213 = G(PP518,"surface-parse",L[19]);
var $z205206 = D;
var $f211212 = function(_) {
return R.isFunction(anf_fun1479213)?anf_fun1479213.app(arg_DASH_146202,("test")):R.ffi.throwNonFunApp(L[18],anf_fun1479213,[arg_DASH_146202,("test")]);
};
try {
if(--R.GAS > 0) {
$z205206 = $f211212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f211212,
"from":L[18]});
}
} catch($e203204) {
if(R.isCont($e203204)) {
var $ss207208 = {"from":L[18],
"go":function(ann_DASH_check_DASH_temp1478214) {
return $Hann_DASH_check_DASH_temp2030215(ann_DASH_check_DASH_temp1478214);
}};
$e203204.stack[R.EXN_STACKHEIGHT++] = $ss207208;
}
if(R.isPyretException($e203204)) {
$e203204.pyretStack.push(L[18]);
}
throw $e203204;
}
var $ret209210 = $Hann_DASH_check_DASH_temp2030215($z205206);
++R.GAS;
return $ret209210;
});
var anf_arg1480200 = G(CS719,"no-builtins",L[17]);
var $z190191 = D;
var $f196197 = function(_) {
return R.isFunction(p510198)?p510198.app(("x")):R.ffi.throwNonFunApp(L[16],p510198,[("x")]);
};
try {
if(--R.GAS > 0) {
$z190191 = $f196197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f196197,
"from":L[16]});
}
} catch($e188189) {
if(R.isCont($e188189)) {
var $ss192193 = {"from":L[16],
"go":function(anf_arg1481199) {
return $Hanf_arg2035201(anf_arg1481199,anf_arg1480200,check_DASH_unbound45073,builtins8);
}};
$e188189.stack[R.EXN_STACKHEIGHT++] = $ss192193;
}
if(R.isPyretException($e188189)) {
$e188189.pyretStack.push(L[16]);
}
throw $e188189;
}
var $ret194195 = $Hanf_arg2035201($z190191,anf_arg1480200,check_DASH_unbound45073,builtins8);
++R.GAS;
return $ret194195;
});
var anf_obj1489187 = R.makeSrcloc(L[15]);
var anf_array_val1490182 = R.makeObject({"name":("check-unbound"),
"run":anf_obj1488186,
"location":anf_obj1489187});
var $z172173 = D;
var $f178179 = function(_) {
return R.isFunction(anf_fun1456180)?anf_fun1456180.app([anf_array_val1476181,anf_array_val1490182]):R.ffi.throwNonFunApp(L[0],anf_fun1456180,[[anf_array_val1476181,anf_array_val1490182]]);
};
try {
if(--R.GAS > 0) {
$z172173 = $f178179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f178179,
"from":L[0]});
}
} catch($e170171) {
if(R.isCont($e170171)) {
var $ss174175 = {"from":L[0],
"go":function(anf_arg1491183) {
return $Hanf_arg2040185(anf_arg1491183,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,Loc7656,anf_fun1455184,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8);
}};
$e170171.stack[R.EXN_STACKHEIGHT++] = $ss174175;
}
if(R.isPyretException($e170171)) {
$e170171.pyretStack.push(L[0]);
}
throw $e170171;
}
var $ret176177 = $Hanf_arg2040185($z172173,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,Loc7656,anf_fun1455184,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8);
++R.GAS;
return $ret176177;
};
var $Hanf_arg2040185 = function(anf_arg1491183,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,Loc7656,anf_fun1455184,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8) {
var $z234235 = D;
var $f240241 = function(_) {
return R.isFunction(anf_fun1455184)?anf_fun1455184.app(("src/arr/compiler/ast-util.arr"),anf_arg1491183):R.ffi.throwNonFunApp(L[0],anf_fun1455184,[("src/arr/compiler/ast-util.arr"),anf_arg1491183]);
};
try {
if(--R.GAS > 0) {
$z234235 = $f240241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f240241,
"from":L[0]});
}
} catch($e232233) {
if(R.isCont($e232233)) {
var $ss236237 = {"from":L[0],
"go":function(anf_begin_app_dropped2036242) {
return $Hanf_begin_app_dropped2039243(anf_begin_app_dropped2036242,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,Loc7656,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8);
}};
$e232233.stack[R.EXN_STACKHEIGHT++] = $ss236237;
}
if(R.isPyretException($e232233)) {
$e232233.pyretStack.push(L[0]);
}
throw $e232233;
}
var $ret238239 = $Hanf_begin_app_dropped2039243($z234235,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,Loc7656,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8);
++R.GAS;
return $ret238239;
};
var $Hanf_begin_app_dropped2039243 = function(anf_begin_app_dropped2036242,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,Loc7656,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,letrec_DASH_visitor486110,link_DASH_list_DASH_visitor40491,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,result_DASH_after_DASH_checks1508111,value_DASH_delays_DASH_exec_DASH_of45197,builtins8) {
var provides1492256 = R.makeObject({"ok-last":ok_DASH_last7795.$var,
"checkers":checkers7874.$var,
"append-nothing-if-necessary":append_DASH_nothing_DASH_if_DASH_necessary7958.$var,
"flatten-single-blocks":flatten_DASH_single_DASH_blocks9379,
"merge-nested-blocks":merge_DASH_nested_DASH_blocks9794,
"count-apps":count_DASH_apps10675.$var,
"BindingInfo":BindingInfo10854.$var,
"is-BindingInfo":is_DASH_BindingInfo10983.$var,
"b-prim":b_DASH_prim11162.$var,
"is-b-prim":is_DASH_b_DASH_prim11087.$var,
"b-dict":b_DASH_dict11359.$var,
"is-b-dict":is_DASH_b_DASH_dict11284.$var,
"b-exp":b_DASH_exp11561.$var,
"is-b-exp":is_DASH_b_DASH_exp11486.$var,
"b-dot":b_DASH_dot11760.$var,
"is-b-dot":is_DASH_b_DASH_dot11685.$var,
"b-typ":b_DASH_typ11963.$var,
"is-b-typ":is_DASH_b_DASH_typ11888.$var,
"b-unknown":b_DASH_unknown12164.$var,
"is-b-unknown":is_DASH_b_DASH_unknown12089.$var,
"Binding":Binding12352.$var,
"is-Binding":is_DASH_Binding12482.$var,
"e-bind":e_DASH_bind12678.$var,
"is-e-bind":is_DASH_e_DASH_bind12590.$var,
"bind-exp":bind_DASH_exp12766.$var,
"bind-or-unknown":bind_DASH_or_DASH_unknown12867.$var,
"binding-type-env-from-env":binding_DASH_type_DASH_env_DASH_from_DASH_env12972.$var,
"binding-env-from-env":binding_DASH_env_DASH_from_DASH_env13068.$var,
"default-env-map-visitor":default_DASH_env_DASH_map_DASH_visitor13177.$var,
"default-env-iter-visitor":default_DASH_env_DASH_iter_DASH_visitor13276.$var,
"binding-handlers":binding_DASH_handlers36871,
"binding-env-map-visitor":binding_DASH_env_DASH_map_DASH_visitor40270.$var,
"binding-env-iter-visitor":binding_DASH_env_DASH_iter_DASH_visitor40369.$var,
"link-list-visitor":link_DASH_list_DASH_visitor40491.$var,
"bad-assignments":bad_DASH_assignments40565.$var,
"inline-lams":inline_DASH_lams43581,
"check-unbound":check_DASH_unbound45073.$var,
"value-delays-exec-of":value_DASH_delays_DASH_exec_DASH_of45197.$var,
"letrec-visitor":letrec_DASH_visitor486110,
"result-after-checks1":result_DASH_after_DASH_checks1508111});
var anf_fun1493254 = G(builtins8,"current-checker",L[23]);
var $z246247 = D;
var $f252253 = function(_) {
return R.isFunction(anf_fun1493254)?anf_fun1493254.app():R.ffi.throwNonFunApp(L[23],anf_fun1493254,[]);
};
try {
if(--R.GAS > 0) {
$z246247 = $f252253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f252253,
"from":L[23]});
}
} catch($e244245) {
if(R.isCont($e244245)) {
var $ss248249 = {"from":L[23],
"go":function(anf_bracket1494255) {
return $Hanf_bracket2038257(anf_bracket1494255,Binding7453,BindingInfo7255,Loc7656,provides1492256,result_DASH_after_DASH_checks1508111);
}};
$e244245.stack[R.EXN_STACKHEIGHT++] = $ss248249;
}
if(R.isPyretException($e244245)) {
$e244245.pyretStack.push(L[23]);
}
throw $e244245;
}
var $ret250251 = $Hanf_bracket2038257($z246247,Binding7453,BindingInfo7255,Loc7656,provides1492256,result_DASH_after_DASH_checks1508111);
++R.GAS;
return $ret250251;
};
var $Hanf_bracket2038257 = function(anf_bracket1494255,Binding7453,BindingInfo7255,Loc7656,provides1492256,result_DASH_after_DASH_checks1508111) {
var anf_fun1495268 = G(anf_bracket1494255,"results",L[23]);
var $z260261 = D;
var $f266267 = function(_) {
return R.isFunction(anf_fun1495268)?anf_fun1495268.app():R.ffi.throwNonFunApp(L[23],anf_fun1495268,[]);
};
try {
if(--R.GAS > 0) {
$z260261 = $f266267();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f266267,
"from":L[23]});
}
} catch($e258259) {
if(R.isCont($e258259)) {
var $ss262263 = {"from":L[23],
"go":function(checks1496269) {
return $Hchecks2037270(checks1496269,Binding7453,BindingInfo7255,Loc7656,provides1492256,result_DASH_after_DASH_checks1508111);
}};
$e258259.stack[R.EXN_STACKHEIGHT++] = $ss262263;
}
if(R.isPyretException($e258259)) {
$e258259.pyretStack.push(L[23]);
}
throw $e258259;
}
var $ret264265 = $Hchecks2037270($z260261,Binding7453,BindingInfo7255,Loc7656,provides1492256,result_DASH_after_DASH_checks1508111);
++R.GAS;
return $ret264265;
};
var $Hchecks2037270 = function(checks1496269,Binding7453,BindingInfo7255,Loc7656,provides1492256,result_DASH_after_DASH_checks1508111) {
return R.makeObject({"answer":result_DASH_after_DASH_checks1508111,
"provide-plus-types":R.makeObject({"values":provides1492256,
"types":{"Loc":Loc7656,
"BindingInfo":BindingInfo7255,
"Binding":Binding7453}}),
"checks":checks1496269});
};
var $Hanf_arg2035201 = function(anf_arg1481199,anf_arg1480200,check_DASH_unbound45073,builtins8) {
var $z273274 = D;
var $f279280 = function(_) {
return R.isFunction(check_DASH_unbound45073.$var)?check_DASH_unbound45073.$var.app(anf_arg1480200,anf_arg1481199):R.ffi.throwNonFunApp(L[24],check_DASH_unbound45073.$var,[anf_arg1480200,anf_arg1481199]);
};
try {
if(--R.GAS > 0) {
$z273274 = $f279280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f279280,
"from":L[24]});
}
} catch($e271272) {
if(R.isCont($e271272)) {
var $ss275276 = {"from":L[24],
"go":function(unbound1511281) {
return $Hunbound12034282(unbound1511281,builtins8);
}};
$e271272.stack[R.EXN_STACKHEIGHT++] = $ss275276;
}
if(R.isPyretException($e271272)) {
$e271272.pyretStack.push(L[24]);
}
throw $e271272;
}
var $ret277278 = $Hunbound12034282($z273274,builtins8);
++R.GAS;
return $ret277278;
};
var $Hunbound12034282 = function(unbound1511281,builtins8) {
var anf_fun1482293 = G(builtins8,"current-checker",L[25]);
var $z285286 = D;
var $f291292 = function(_) {
return R.isFunction(anf_fun1482293)?anf_fun1482293.app():R.ffi.throwNonFunApp(L[25],anf_fun1482293,[]);
};
try {
if(--R.GAS > 0) {
$z285286 = $f291292();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f291292,
"from":L[25]});
}
} catch($e283284) {
if(R.isCont($e283284)) {
var $ss287288 = {"from":L[25],
"go":function(anf_bracket1483294) {
return $Hanf_bracket2033295(anf_bracket1483294,unbound1511281);
}};
$e283284.stack[R.EXN_STACKHEIGHT++] = $ss287288;
}
if(R.isPyretException($e283284)) {
$e283284.pyretStack.push(L[25]);
}
throw $e283284;
}
var $ret289290 = $Hanf_bracket2033295($z285286,unbound1511281);
++R.GAS;
return $ret289290;
};
var $Hanf_bracket2033295 = function(anf_bracket1483294,unbound1511281) {
var anf_fun1484308 = G(anf_bracket1483294,"check-is",L[25]);
var anf_fun1485306 = G(unbound1511281,"length",L[27]);
var $z298299 = D;
var $f304305 = function(_) {
return R.isFunction(anf_fun1485306)?anf_fun1485306.app():R.ffi.throwNonFunApp(L[26],anf_fun1485306,[]);
};
try {
if(--R.GAS > 0) {
$z298299 = $f304305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f304305,
"from":L[26]});
}
} catch($e296297) {
if(R.isCont($e296297)) {
var $ss300301 = {"from":L[26],
"go":function(anf_arg1486307) {
return $Hanf_arg2032309(anf_arg1486307,anf_fun1484308);
}};
$e296297.stack[R.EXN_STACKHEIGHT++] = $ss300301;
}
if(R.isPyretException($e296297)) {
$e296297.pyretStack.push(L[26]);
}
throw $e296297;
}
var $ret302303 = $Hanf_arg2032309($z298299,anf_fun1484308);
++R.GAS;
return $ret302303;
};
var $Hanf_arg2032309 = function(anf_arg1486307,anf_fun1484308) {
var anf_arg1487320 = R.makeSrcloc(L[25]);
var $z312313 = D;
var $f318319 = function(_) {
return R.isFunction(anf_fun1484308)?anf_fun1484308.app(("unbound1.length() is 1"),anf_arg1486307,(1),anf_arg1487320):R.ffi.throwNonFunApp(L[15],anf_fun1484308,[("unbound1.length() is 1"),anf_arg1486307,(1),anf_arg1487320]);
};
try {
if(--R.GAS > 0) {
$z312313 = $f318319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f318319,
"from":L[15]});
}
} catch($e310311) {
if(R.isCont($e310311)) {
var $ss314315 = {"from":L[15],
"go":function(ann_DASH_check_DASH_temp1477321) {
return $Hann_DASH_check_DASH_temp2031322(ann_DASH_check_DASH_temp1477321);
}};
$e310311.stack[R.EXN_STACKHEIGHT++] = $ss314315;
}
if(R.isPyretException($e310311)) {
$e310311.pyretStack.push(L[15]);
}
throw $e310311;
}
var $ret316317 = $Hann_DASH_check_DASH_temp2031322($z312313);
++R.GAS;
return $ret316317;
};
var $Hann_DASH_check_DASH_temp2031322 = function(ann_DASH_check_DASH_temp1477321) {
return ann_DASH_check_DASH_temp1477321;
};
var $Hann_DASH_check_DASH_temp2030215 = function(ann_DASH_check_DASH_temp1478214) {
return ann_DASH_check_DASH_temp1478214;
};
var $Hanf_bracket2029231 = function(anf_bracket1459229,A317,PP518,d509230,flatten_DASH_single_DASH_blocks9379) {
var anf_fun1460335 = G(anf_bracket1459229,"check-is",L[21]);
var anf_fun1461333 = G(PP518,"surface-parse",L[29]);
var $z325326 = D;
var $f331332 = function(_) {
return R.isFunction(anf_fun1461333)?anf_fun1461333.app(("x"),("test")):R.ffi.throwNonFunApp(L[28],anf_fun1461333,[("x"),("test")]);
};
try {
if(--R.GAS > 0) {
$z325326 = $f331332();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f331332,
"from":L[28]});
}
} catch($e323324) {
if(R.isCont($e323324)) {
var $ss327328 = {"from":L[28],
"go":function(anf_bracket1462334) {
return $Hanf_bracket2028336(anf_bracket1462334,A317,anf_fun1460335,d509230,flatten_DASH_single_DASH_blocks9379);
}};
$e323324.stack[R.EXN_STACKHEIGHT++] = $ss327328;
}
if(R.isPyretException($e323324)) {
$e323324.pyretStack.push(L[28]);
}
throw $e323324;
}
var $ret329330 = $Hanf_bracket2028336($z325326,A317,anf_fun1460335,d509230,flatten_DASH_single_DASH_blocks9379);
++R.GAS;
return $ret329330;
};
var $Hanf_bracket2028336 = function(anf_bracket1462334,A317,anf_fun1460335,d509230,flatten_DASH_single_DASH_blocks9379) {
var anf_bracket1463350 = G(anf_bracket1462334,"block",L[32]);
var anf_fun1464347 = G(anf_bracket1463350,"visit",L[31]);
var $z339340 = D;
var $f345346 = function(_) {
return R.isFunction(anf_fun1464347)?anf_fun1464347.app(flatten_DASH_single_DASH_blocks9379):R.ffi.throwNonFunApp(L[30],anf_fun1464347,[flatten_DASH_single_DASH_blocks9379]);
};
try {
if(--R.GAS > 0) {
$z339340 = $f345346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f345346,
"from":L[30]});
}
} catch($e337338) {
if(R.isCont($e337338)) {
var $ss341342 = {"from":L[30],
"go":function(anf_bracket1465348) {
return $Hanf_bracket2027349(anf_bracket1465348,A317,anf_fun1460335,d509230);
}};
$e337338.stack[R.EXN_STACKHEIGHT++] = $ss341342;
}
if(R.isPyretException($e337338)) {
$e337338.pyretStack.push(L[30]);
}
throw $e337338;
}
var $ret343344 = $Hanf_bracket2027349($z339340,A317,anf_fun1460335,d509230);
++R.GAS;
return $ret343344;
};
var $Hanf_bracket2027349 = function(anf_bracket1465348,A317,anf_fun1460335,d509230) {
var anf_fun1466361 = G(anf_bracket1465348,"visit",L[35]);
var anf_arg1467362 = G(A317,"dummy-loc-visitor",L[34]);
var $z353354 = D;
var $f359360 = function(_) {
return R.isFunction(anf_fun1466361)?anf_fun1466361.app(anf_arg1467362):R.ffi.throwNonFunApp(L[33],anf_fun1466361,[anf_arg1467362]);
};
try {
if(--R.GAS > 0) {
$z353354 = $f359360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f359360,
"from":L[33]});
}
} catch($e351352) {
if(R.isCont($e351352)) {
var $ss355356 = {"from":L[33],
"go":function(anf_arg1468363) {
return $Hanf_arg2026364(anf_arg1468363,A317,anf_fun1460335,d509230);
}};
$e351352.stack[R.EXN_STACKHEIGHT++] = $ss355356;
}
if(R.isPyretException($e351352)) {
$e351352.pyretStack.push(L[33]);
}
throw $e351352;
}
var $ret357358 = $Hanf_arg2026364($z353354,A317,anf_fun1460335,d509230);
++R.GAS;
return $ret357358;
};
var $Hanf_arg2026364 = function(anf_arg1468363,A317,anf_fun1460335,d509230) {
var anf_fun1469377 = G(A317,"s-id",L[38]);
var anf_fun1470375 = G(A317,"s-name",L[37]);
var $z367368 = D;
var $f373374 = function(_) {
return R.isFunction(anf_fun1470375)?anf_fun1470375.app(d509230,("x")):R.ffi.throwNonFunApp(L[36],anf_fun1470375,[d509230,("x")]);
};
try {
if(--R.GAS > 0) {
$z367368 = $f373374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f373374,
"from":L[36]});
}
} catch($e365366) {
if(R.isCont($e365366)) {
var $ss369370 = {"from":L[36],
"go":function(anf_arg1471376) {
return $Hanf_arg2025378(anf_arg1471376,anf_arg1468363,anf_fun1460335,anf_fun1469377,d509230);
}};
$e365366.stack[R.EXN_STACKHEIGHT++] = $ss369370;
}
if(R.isPyretException($e365366)) {
$e365366.pyretStack.push(L[36]);
}
throw $e365366;
}
var $ret371372 = $Hanf_arg2025378($z367368,anf_arg1468363,anf_fun1460335,anf_fun1469377,d509230);
++R.GAS;
return $ret371372;
};
var $Hanf_arg2025378 = function(anf_arg1471376,anf_arg1468363,anf_fun1460335,anf_fun1469377,d509230) {
var $z381382 = D;
var $f387388 = function(_) {
return R.isFunction(anf_fun1469377)?anf_fun1469377.app(d509230,anf_arg1471376):R.ffi.throwNonFunApp(L[39],anf_fun1469377,[d509230,anf_arg1471376]);
};
try {
if(--R.GAS > 0) {
$z381382 = $f387388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f387388,
"from":L[39]});
}
} catch($e379380) {
if(R.isCont($e379380)) {
var $ss383384 = {"from":L[39],
"go":function(anf_arg1472389) {
return $Hanf_arg2024390(anf_arg1472389,anf_arg1468363,anf_fun1460335);
}};
$e379380.stack[R.EXN_STACKHEIGHT++] = $ss383384;
}
if(R.isPyretException($e379380)) {
$e379380.pyretStack.push(L[39]);
}
throw $e379380;
}
var $ret385386 = $Hanf_arg2024390($z381382,anf_arg1468363,anf_fun1460335);
++R.GAS;
return $ret385386;
};
var $Hanf_arg2024390 = function(anf_arg1472389,anf_arg1468363,anf_fun1460335) {
var anf_arg1473401 = R.makeSrcloc(L[21]);
var $z393394 = D;
var $f399400 = function(_) {
return R.isFunction(anf_fun1460335)?anf_fun1460335.app(("PP.surface-parse(\"x\", \"test\").block.visit(flatten-single-blocks).visit(A\n    .dummy-loc-visitor) is\n  A.s-id(d, A.s-name(d, \"x\"))"),anf_arg1468363,anf_arg1472389,anf_arg1473401):R.ffi.throwNonFunApp(L[20],anf_fun1460335,[("PP.surface-parse(\"x\", \"test\").block.visit(flatten-single-blocks).visit(A\n    .dummy-loc-visitor) is\n  A.s-id(d, A.s-name(d, \"x\"))"),anf_arg1468363,anf_arg1472389,anf_arg1473401]);
};
try {
if(--R.GAS > 0) {
$z393394 = $f399400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f399400,
"from":L[20]});
}
} catch($e391392) {
if(R.isCont($e391392)) {
var $ss395396 = {"from":L[20],
"go":function(ann_DASH_check_DASH_temp1457402) {
return $Hann_DASH_check_DASH_temp2023403(ann_DASH_check_DASH_temp1457402);
}};
$e391392.stack[R.EXN_STACKHEIGHT++] = $ss395396;
}
if(R.isPyretException($e391392)) {
$e391392.pyretStack.push(L[20]);
}
throw $e391392;
}
var $ret397398 = $Hann_DASH_check_DASH_temp2023403($z393394);
++R.GAS;
return $ret397398;
};
var $Hann_DASH_check_DASH_temp2023403 = function(ann_DASH_check_DASH_temp1457402) {
return ann_DASH_check_DASH_temp1457402;
};
var $Hanf_arg2022131 = function(anf_arg1450126,anf_fun1446127,anf_fun1448128,id506129,l505130) {
var $z406407 = D;
var $f412413 = function(_) {
return R.isFunction(anf_fun1448128)?anf_fun1448128.app(anf_arg1450126):R.ffi.throwNonFunApp(L[40],anf_fun1448128,[anf_arg1450126]);
};
try {
if(--R.GAS > 0) {
$z406407 = $f412413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f412413,
"from":L[40]});
}
} catch($e404405) {
if(R.isCont($e404405)) {
var $ss408409 = {"from":L[40],
"go":function(anf_arg1451414) {
return $Hanf_arg2021415(anf_arg1451414,anf_fun1446127,id506129,l505130);
}};
$e404405.stack[R.EXN_STACKHEIGHT++] = $ss408409;
}
if(R.isPyretException($e404405)) {
$e404405.pyretStack.push(L[40]);
}
throw $e404405;
}
var $ret410411 = $Hanf_arg2021415($z406407,anf_fun1446127,id506129,l505130);
++R.GAS;
return $ret410411;
};
var $Hanf_arg2021415 = function(anf_arg1451414,anf_fun1446127,id506129,l505130) {
var $z418419 = D;
var $f424425 = function(_) {
return R.isFunction(anf_fun1446127)?anf_fun1446127.app(l505130,id506129,anf_arg1451414):R.ffi.throwNonFunApp(L[6],anf_fun1446127,[l505130,id506129,anf_arg1451414]);
};
try {
if(--R.GAS > 0) {
$z418419 = $f424425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f424425,
"from":L[6]});
}
} catch($e416417) {
if(R.isCont($e416417)) {
var $ss420421 = {"from":L[6],
"go":function(ann_DASH_check_DASH_temp1445426) {
return $Hann_DASH_check_DASH_temp2020427(ann_DASH_check_DASH_temp1445426);
}};
$e416417.stack[R.EXN_STACKHEIGHT++] = $ss420421;
}
if(R.isPyretException($e416417)) {
$e416417.pyretStack.push(L[6]);
}
throw $e416417;
}
var $ret422423 = $Hann_DASH_check_DASH_temp2020427($z418419);
++R.GAS;
return $ret422423;
};
var $Hann_DASH_check_DASH_temp2020427 = function(ann_DASH_check_DASH_temp1445426) {
return ann_DASH_check_DASH_temp1445426;
};
var $Hanf_arg2019152 = function(anf_arg1426146,A317,anf_arg1424147,binds489148,body490149,l488150,map24493,range3696,self487151) {
var $z430431 = D;
var $f436437 = function(_) {
return R.isFunction(range3696)?range3696.app((0),anf_arg1426146):R.ffi.throwNonFunApp(L[41],range3696,[(0),anf_arg1426146]);
};
try {
if(--R.GAS > 0) {
$z430431 = $f436437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f436437,
"from":L[41]});
}
} catch($e428429) {
if(R.isCont($e428429)) {
var $ss432433 = {"from":L[41],
"go":function(anf_arg1427438) {
return $Hanf_arg2018439(anf_arg1427438,A317,anf_arg1424147,binds489148,body490149,l488150,map24493,self487151);
}};
$e428429.stack[R.EXN_STACKHEIGHT++] = $ss432433;
}
if(R.isPyretException($e428429)) {
$e428429.pyretStack.push(L[41]);
}
throw $e428429;
}
var $ret434435 = $Hanf_arg2018439($z430431,A317,anf_arg1424147,binds489148,body490149,l488150,map24493,self487151);
++R.GAS;
return $ret434435;
};
var $Hanf_arg2018439 = function(anf_arg1427438,A317,anf_arg1424147,binds489148,body490149,l488150,map24493,self487151) {
var $z442443 = D;
var $f448449 = function(_) {
return R.isFunction(map24493)?map24493.app(anf_arg1424147,binds489148,anf_arg1427438):R.ffi.throwNonFunApp(L[42],map24493,[anf_arg1424147,binds489148,anf_arg1427438]);
};
try {
if(--R.GAS > 0) {
$z442443 = $f448449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f448449,
"from":L[42]});
}
} catch($e440441) {
if(R.isCont($e440441)) {
var $ss444445 = {"from":L[42],
"go":function(bind_DASH_envs491450) {
return $Hbind_DASH_envs2017451(bind_DASH_envs491450,A317,binds489148,body490149,l488150,map24493,self487151);
}};
$e440441.stack[R.EXN_STACKHEIGHT++] = $ss444445;
}
if(R.isPyretException($e440441)) {
$e440441.pyretStack.push(L[42]);
}
throw $e440441;
}
var $ret446447 = $Hbind_DASH_envs2017451($z442443,A317,binds489148,body490149,l488150,map24493,self487151);
++R.GAS;
return $ret446447;
};
var $Hbind_DASH_envs2017451 = function(bind_DASH_envs491450,A317,binds489148,body490149,l488150,map24493,self487151) {
var anf_arg1431462 = R.makeFunction(function(b500465,bind_DASH_env501466) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[44],2,arguments);
}
var anf_fun1429477 = G(b500465,"visit",L[45]);
var anf_arg1430478 = self487151.extendWith({"env":bind_DASH_env501466});
var $z469470 = D;
var $f475476 = function(_) {
return R.isFunction(anf_fun1429477)?anf_fun1429477.app(anf_arg1430478):R.ffi.throwNonFunApp(L[44],anf_fun1429477,[anf_arg1430478]);
};
try {
if(--R.GAS > 0) {
$z469470 = $f475476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f475476,
"from":L[44]});
}
} catch($e467468) {
if(R.isCont($e467468)) {
var $ss471472 = {"from":L[44],
"go":function(ann_DASH_check_DASH_temp1428479) {
return $Hann_DASH_check_DASH_temp2009480(ann_DASH_check_DASH_temp1428479);
}};
$e467468.stack[R.EXN_STACKHEIGHT++] = $ss471472;
}
if(R.isPyretException($e467468)) {
$e467468.pyretStack.push(L[44]);
}
throw $e467468;
}
var $ret473474 = $Hann_DASH_check_DASH_temp2009480($z469470);
++R.GAS;
return $ret473474;
});
var $z454455 = D;
var $f460461 = function(_) {
return R.isFunction(map24493)?map24493.app(anf_arg1431462,binds489148,bind_DASH_envs491450):R.ffi.throwNonFunApp(L[43],map24493,[anf_arg1431462,binds489148,bind_DASH_envs491450]);
};
try {
if(--R.GAS > 0) {
$z454455 = $f460461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f460461,
"from":L[43]});
}
} catch($e452453) {
if(R.isCont($e452453)) {
var $ss456457 = {"from":L[43],
"go":function(new_DASH_binds499463) {
return $Hnew_DASH_binds2016464(new_DASH_binds499463,A317,bind_DASH_envs491450,binds489148,body490149,l488150,self487151);
}};
$e452453.stack[R.EXN_STACKHEIGHT++] = $ss456457;
}
if(R.isPyretException($e452453)) {
$e452453.pyretStack.push(L[43]);
}
throw $e452453;
}
var $ret458459 = $Hnew_DASH_binds2016464($z454455,A317,bind_DASH_envs491450,binds489148,body490149,l488150,self487151);
++R.GAS;
return $ret458459;
};
var $Hnew_DASH_binds2016464 = function(new_DASH_binds499463,A317,bind_DASH_envs491450,binds489148,body490149,l488150,self487151) {
var anf_fun1432491 = G(bind_DASH_envs491450,"last",L[47]);
var $z483484 = D;
var $f489490 = function(_) {
return R.isFunction(anf_fun1432491)?anf_fun1432491.app():R.ffi.throwNonFunApp(L[46],anf_fun1432491,[]);
};
try {
if(--R.GAS > 0) {
$z483484 = $f489490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f489490,
"from":L[46]});
}
} catch($e481482) {
if(R.isCont($e481482)) {
var $ss485486 = {"from":L[46],
"go":function(anf_bracket1433492) {
return $Hanf_bracket2015493(anf_bracket1433492,A317,binds489148,body490149,l488150,new_DASH_binds499463,self487151);
}};
$e481482.stack[R.EXN_STACKHEIGHT++] = $ss485486;
}
if(R.isPyretException($e481482)) {
$e481482.pyretStack.push(L[46]);
}
throw $e481482;
}
var $ret487488 = $Hanf_bracket2015493($z483484,A317,binds489148,body490149,l488150,new_DASH_binds499463,self487151);
++R.GAS;
return $ret487488;
};
var $Hanf_bracket2015493 = function(anf_bracket1433492,A317,binds489148,body490149,l488150,new_DASH_binds499463,self487151) {
var anf_fun1434506 = G(anf_bracket1433492,"set",L[50]);
var anf_fun1435504 = G(binds489148,"last",L[49]);
var $z496497 = D;
var $f502503 = function(_) {
return R.isFunction(anf_fun1435504)?anf_fun1435504.app():R.ffi.throwNonFunApp(L[48],anf_fun1435504,[]);
};
try {
if(--R.GAS > 0) {
$z496497 = $f502503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f502503,
"from":L[48]});
}
} catch($e494495) {
if(R.isCont($e494495)) {
var $ss498499 = {"from":L[48],
"go":function(anf_bracket1436505) {
return $Hanf_bracket2014507(anf_bracket1436505,A317,anf_fun1434506,body490149,l488150,new_DASH_binds499463,self487151);
}};
$e494495.stack[R.EXN_STACKHEIGHT++] = $ss498499;
}
if(R.isPyretException($e494495)) {
$e494495.pyretStack.push(L[48]);
}
throw $e494495;
}
var $ret500501 = $Hanf_bracket2014507($z496497,A317,anf_fun1434506,body490149,l488150,new_DASH_binds499463,self487151);
++R.GAS;
return $ret500501;
};
var $Hanf_bracket2014507 = function(anf_bracket1436505,A317,anf_fun1434506,body490149,l488150,new_DASH_binds499463,self487151) {
var anf_bracket1437522 = G(anf_bracket1436505,"b",L[54]);
var anf_bracket1438521 = G(anf_bracket1437522,"id",L[53]);
var anf_fun1439518 = G(anf_bracket1438521,"key",L[52]);
var $z510511 = D;
var $f516517 = function(_) {
return R.isFunction(anf_fun1439518)?anf_fun1439518.app():R.ffi.throwNonFunApp(L[51],anf_fun1439518,[]);
};
try {
if(--R.GAS > 0) {
$z510511 = $f516517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f516517,
"from":L[51]});
}
} catch($e508509) {
if(R.isCont($e508509)) {
var $ss512513 = {"from":L[51],
"go":function(anf_arg1440519) {
return $Hanf_arg2013520(anf_arg1440519,A317,anf_fun1434506,body490149,l488150,new_DASH_binds499463,self487151);
}};
$e508509.stack[R.EXN_STACKHEIGHT++] = $ss512513;
}
if(R.isPyretException($e508509)) {
$e508509.pyretStack.push(L[51]);
}
throw $e508509;
}
var $ret514515 = $Hanf_arg2013520($z510511,A317,anf_fun1434506,body490149,l488150,new_DASH_binds499463,self487151);
++R.GAS;
return $ret514515;
};
var $Hanf_arg2013520 = function(anf_arg1440519,A317,anf_fun1434506,body490149,l488150,new_DASH_binds499463,self487151) {
var $z525526 = D;
var $f531532 = function(_) {
return R.isFunction(anf_fun1434506)?anf_fun1434506.app(anf_arg1440519,(true)):R.ffi.throwNonFunApp(L[55],anf_fun1434506,[anf_arg1440519,(true)]);
};
try {
if(--R.GAS > 0) {
$z525526 = $f531532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f531532,
"from":L[55]});
}
} catch($e523524) {
if(R.isCont($e523524)) {
var $ss527528 = {"from":L[55],
"go":function(body_DASH_env502533) {
return $Hbody_DASH_env2012534(body_DASH_env502533,A317,body490149,l488150,new_DASH_binds499463,self487151);
}};
$e523524.stack[R.EXN_STACKHEIGHT++] = $ss527528;
}
if(R.isPyretException($e523524)) {
$e523524.pyretStack.push(L[55]);
}
throw $e523524;
}
var $ret529530 = $Hbody_DASH_env2012534($z525526,A317,body490149,l488150,new_DASH_binds499463,self487151);
++R.GAS;
return $ret529530;
};
var $Hbody_DASH_env2012534 = function(body_DASH_env502533,A317,body490149,l488150,new_DASH_binds499463,self487151) {
var anf_fun1441545 = G(body490149,"visit",L[57]);
var anf_arg1442546 = self487151.extendWith({"env":body_DASH_env502533});
var $z537538 = D;
var $f543544 = function(_) {
return R.isFunction(anf_fun1441545)?anf_fun1441545.app(anf_arg1442546):R.ffi.throwNonFunApp(L[56],anf_fun1441545,[anf_arg1442546]);
};
try {
if(--R.GAS > 0) {
$z537538 = $f543544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f543544,
"from":L[56]});
}
} catch($e535536) {
if(R.isCont($e535536)) {
var $ss539540 = {"from":L[56],
"go":function(new_DASH_body503547) {
return $Hnew_DASH_body2011548(new_DASH_body503547,A317,l488150,new_DASH_binds499463);
}};
$e535536.stack[R.EXN_STACKHEIGHT++] = $ss539540;
}
if(R.isPyretException($e535536)) {
$e535536.pyretStack.push(L[56]);
}
throw $e535536;
}
var $ret541542 = $Hnew_DASH_body2011548($z537538,A317,l488150,new_DASH_binds499463);
++R.GAS;
return $ret541542;
};
var $Hnew_DASH_body2011548 = function(new_DASH_body503547,A317,l488150,new_DASH_binds499463) {
var anf_fun1443559 = G(A317,"s-letrec",L[58]);
var $z551552 = D;
var $f557558 = function(_) {
return R.isFunction(anf_fun1443559)?anf_fun1443559.app(l488150,new_DASH_binds499463,new_DASH_body503547):R.ffi.throwNonFunApp(L[14],anf_fun1443559,[l488150,new_DASH_binds499463,new_DASH_body503547]);
};
try {
if(--R.GAS > 0) {
$z551552 = $f557558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f557558,
"from":L[14]});
}
} catch($e549550) {
if(R.isCont($e549550)) {
var $ss553554 = {"from":L[14],
"go":function(ann_DASH_check_DASH_temp1393560) {
return $Hann_DASH_check_DASH_temp2010561(ann_DASH_check_DASH_temp1393560);
}};
$e549550.stack[R.EXN_STACKHEIGHT++] = $ss553554;
}
if(R.isPyretException($e549550)) {
$e549550.pyretStack.push(L[14]);
}
throw $e549550;
}
var $ret555556 = $Hann_DASH_check_DASH_temp2010561($z551552);
++R.GAS;
return $ret555556;
};
var $Hann_DASH_check_DASH_temp2010561 = function(ann_DASH_check_DASH_temp1393560) {
return ann_DASH_check_DASH_temp1393560;
};
var $Hann_DASH_check_DASH_temp2009480 = function(ann_DASH_check_DASH_temp1428479) {
return ann_DASH_check_DASH_temp1428479;
};
var $Hrhs_DASH_is_DASH_delayed2008168 = function(rhs_DASH_is_DASH_delayed494167,binds489148,fold26080,i493154,range3696,self487151,_lessthan6) {
var anf_arg1419574 = R.makeFunction(function(acc495577,b2496578,j497579) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[62],3,arguments);
}
var anf_bracket1399594 = G(b2496578,"b",L[66]);
var anf_bracket1400593 = G(anf_bracket1399594,"id",L[65]);
var anf_fun1401590 = G(anf_bracket1400593,"key",L[64]);
var $z582583 = D;
var $f588589 = function(_) {
return R.isFunction(anf_fun1401590)?anf_fun1401590.app():R.ffi.throwNonFunApp(L[63],anf_fun1401590,[]);
};
try {
if(--R.GAS > 0) {
$z582583 = $f588589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f588589,
"from":L[63]});
}
} catch($e580581) {
if(R.isCont($e580581)) {
var $ss584585 = {"from":L[63],
"go":function(key498591) {
return $Hkey2004592(key498591,acc495577,i493154,j497579,rhs_DASH_is_DASH_delayed494167,_lessthan6);
}};
$e580581.stack[R.EXN_STACKHEIGHT++] = $ss584585;
}
if(R.isPyretException($e580581)) {
$e580581.pyretStack.push(L[63]);
}
throw $e580581;
}
var $ret586587 = $Hkey2004592($z582583,acc495577,i493154,j497579,rhs_DASH_is_DASH_delayed494167,_lessthan6);
++R.GAS;
return $ret586587;
});
var anf_arg1420575 = G(self487151,"env",L[61]);
var anf_fun1421572 = G(binds489148,"length",L[60]);
var $z564565 = D;
var $f570571 = function(_) {
return R.isFunction(anf_fun1421572)?anf_fun1421572.app():R.ffi.throwNonFunApp(L[59],anf_fun1421572,[]);
};
try {
if(--R.GAS > 0) {
$z564565 = $f570571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f570571,
"from":L[59]});
}
} catch($e562563) {
if(R.isCont($e562563)) {
var $ss566567 = {"from":L[59],
"go":function(anf_arg1422573) {
return $Hanf_arg2007576(anf_arg1422573,anf_arg1419574,anf_arg1420575,binds489148,fold26080,range3696);
}};
$e562563.stack[R.EXN_STACKHEIGHT++] = $ss566567;
}
if(R.isPyretException($e562563)) {
$e562563.pyretStack.push(L[59]);
}
throw $e562563;
}
var $ret568569 = $Hanf_arg2007576($z564565,anf_arg1419574,anf_arg1420575,binds489148,fold26080,range3696);
++R.GAS;
return $ret568569;
};
var $Hanf_arg2007576 = function(anf_arg1422573,anf_arg1419574,anf_arg1420575,binds489148,fold26080,range3696) {
var $z597598 = D;
var $f603604 = function(_) {
return R.isFunction(range3696)?range3696.app((0),anf_arg1422573):R.ffi.throwNonFunApp(L[67],range3696,[(0),anf_arg1422573]);
};
try {
if(--R.GAS > 0) {
$z597598 = $f603604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f603604,
"from":L[67]});
}
} catch($e595596) {
if(R.isCont($e595596)) {
var $ss599600 = {"from":L[67],
"go":function(anf_arg1423605) {
return $Hanf_arg2006606(anf_arg1423605,anf_arg1419574,anf_arg1420575,binds489148,fold26080);
}};
$e595596.stack[R.EXN_STACKHEIGHT++] = $ss599600;
}
if(R.isPyretException($e595596)) {
$e595596.pyretStack.push(L[67]);
}
throw $e595596;
}
var $ret601602 = $Hanf_arg2006606($z597598,anf_arg1419574,anf_arg1420575,binds489148,fold26080);
++R.GAS;
return $ret601602;
};
var $Hanf_arg2006606 = function(anf_arg1423605,anf_arg1419574,anf_arg1420575,binds489148,fold26080) {
var $z609610 = D;
var $f615616 = function(_) {
return R.isFunction(fold26080)?fold26080.app(anf_arg1419574,anf_arg1420575,binds489148,anf_arg1423605):R.ffi.throwNonFunApp(L[9],fold26080,[anf_arg1419574,anf_arg1420575,binds489148,anf_arg1423605]);
};
try {
if(--R.GAS > 0) {
$z609610 = $f615616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f615616,
"from":L[9]});
}
} catch($e607608) {
if(R.isCont($e607608)) {
var $ss611612 = {"from":L[9],
"go":function(ann_DASH_check_DASH_temp1394617) {
return $Hann_DASH_check_DASH_temp2005618(ann_DASH_check_DASH_temp1394617);
}};
$e607608.stack[R.EXN_STACKHEIGHT++] = $ss611612;
}
if(R.isPyretException($e607608)) {
$e607608.pyretStack.push(L[9]);
}
throw $e607608;
}
var $ret613614 = $Hann_DASH_check_DASH_temp2005618($z609610);
++R.GAS;
return $ret613614;
};
var $Hann_DASH_check_DASH_temp2005618 = function(ann_DASH_check_DASH_temp1394617) {
return ann_DASH_check_DASH_temp1394617;
};
var $Hkey2004592 = function(key498591,acc495577,i493154,j497579,rhs_DASH_is_DASH_delayed494167,_lessthan6) {
var $z621622 = D;
var $f627628 = function(_) {
return R.isFunction(_lessthan6)?_lessthan6.app(i493154,j497579):R.ffi.throwNonFunApp(L[68],_lessthan6,[i493154,j497579]);
};
try {
if(--R.GAS > 0) {
$z621622 = $f627628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f627628,
"from":L[68]});
}
} catch($e619620) {
if(R.isCont($e619620)) {
var $ss623624 = {"from":L[68],
"go":function(if_DASH_145629) {
return $Hif_DASH_2003630(if_DASH_145629,acc495577,i493154,j497579,key498591,rhs_DASH_is_DASH_delayed494167);
}};
$e619620.stack[R.EXN_STACKHEIGHT++] = $ss623624;
}
if(R.isPyretException($e619620)) {
$e619620.pyretStack.push(L[68]);
}
throw $e619620;
}
var $ret625626 = $Hif_DASH_2003630($z621622,acc495577,i493154,j497579,key498591,rhs_DASH_is_DASH_delayed494167);
++R.GAS;
return $ret625626;
};
var $Hif_DASH_2003630 = function(if_DASH_145629,acc495577,i493154,j497579,key498591,rhs_DASH_is_DASH_delayed494167) {
var if_helper1402643 = R.makeFunction(function(if_helper_arg1403681) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[68],1,arguments);
}
var ann_DASH_check_DASH_temp1398682 = if_helper_arg1403681;
return ann_DASH_check_DASH_temp1398682;
});
var anf_if1406680 = R.isBoolean(if_DASH_145629);
if(R.isPyretTrue(anf_if1406680)) {
if(R.isPyretTrue(if_DASH_145629)) {
var anf_fun1416641 = G(acc495577,"set",L[70]);
var $z633634 = D;
var $f639640 = function(_) {
return R.isFunction(anf_fun1416641)?anf_fun1416641.app(key498591,(false)):R.ffi.throwNonFunApp(L[69],anf_fun1416641,[key498591,(false)]);
};
try {
if(--R.GAS > 0) {
$z633634 = $f639640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f639640,
"from":L[69]});
}
} catch($e631632) {
if(R.isCont($e631632)) {
var $ss635636 = {"from":L[69],
"go":function(cont_tail_arg1417642) {
return $Hcont_tail_arg2000644(cont_tail_arg1417642,if_helper1402643);
}};
$e631632.stack[R.EXN_STACKHEIGHT++] = $ss635636;
}
if(R.isPyretException($e631632)) {
$e631632.pyretStack.push(L[69]);
}
throw $e631632;
}
var $ret637638 = $Hcont_tail_arg2000644($z633634,if_helper1402643);
++R.GAS;
return $ret637638;
} else {
var if_DASH_144671 = R.equiv(i493154,j497579);
var anf_if1409676 = R.isBoolean(if_DASH_144671);
if(R.isPyretTrue(anf_if1409676)) {
if(R.isPyretTrue(if_DASH_144671)) {
var anf_fun1413655 = G(acc495577,"set",L[72]);
var $z647648 = D;
var $f653654 = function(_) {
return R.isFunction(anf_fun1413655)?anf_fun1413655.app(key498591,rhs_DASH_is_DASH_delayed494167):R.ffi.throwNonFunApp(L[71],anf_fun1413655,[key498591,rhs_DASH_is_DASH_delayed494167]);
};
try {
if(--R.GAS > 0) {
$z647648 = $f653654();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f653654,
"from":L[71]});
}
} catch($e645646) {
if(R.isCont($e645646)) {
var $ss649650 = {"from":L[71],
"go":function(cont_tail_arg1414656) {
return $Hcont_tail_arg2001657(cont_tail_arg1414656,if_helper1402643);
}};
$e645646.stack[R.EXN_STACKHEIGHT++] = $ss649650;
}
if(R.isPyretException($e645646)) {
$e645646.pyretStack.push(L[71]);
}
throw $e645646;
}
var $ret651652 = $Hcont_tail_arg2001657($z647648,if_helper1402643);
++R.GAS;
return $ret651652;
} else {
var anf_fun1410668 = G(acc495577,"set",L[74]);
var $z660661 = D;
var $f666667 = function(_) {
return R.isFunction(anf_fun1410668)?anf_fun1410668.app(key498591,(true)):R.ffi.throwNonFunApp(L[73],anf_fun1410668,[key498591,(true)]);
};
try {
if(--R.GAS > 0) {
$z660661 = $f666667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f666667,
"from":L[73]});
}
} catch($e658659) {
if(R.isCont($e658659)) {
var $ss662663 = {"from":L[73],
"go":function(cont_tail_arg1411669) {
return $Hcont_tail_arg2002670(cont_tail_arg1411669,if_helper1402643);
}};
$e658659.stack[R.EXN_STACKHEIGHT++] = $ss662663;
}
if(R.isPyretException($e658659)) {
$e658659.pyretStack.push(L[73]);
}
throw $e658659;
}
var $ret664665 = $Hcont_tail_arg2002670($z660661,if_helper1402643);
++R.GAS;
return $ret664665;
}
} else {
var cont_tail_arg1407674 = R.throwNonBooleanCondition(L[75],("if"),if_DASH_144671);
if(--R.GAS > 0) {
$z672673 = R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1407674):R.ffi.throwNonFunApp(L[75],if_helper1402643,[cont_tail_arg1407674]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1407674):R.ffi.throwNonFunApp(L[75],if_helper1402643,[cont_tail_arg1407674]);
},
"from":L[75]});
}
++R.GAS;
return $z672673;
}
}
} else {
var cont_tail_arg1404679 = R.throwNonBooleanCondition(L[68],("if"),if_DASH_145629);
if(--R.GAS > 0) {
$z677678 = R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1404679):R.ffi.throwNonFunApp(L[68],if_helper1402643,[cont_tail_arg1404679]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1404679):R.ffi.throwNonFunApp(L[68],if_helper1402643,[cont_tail_arg1404679]);
},
"from":L[68]});
}
++R.GAS;
return $z677678;
}
};
var $Hcont_tail_arg2000644 = function(cont_tail_arg1417642,if_helper1402643) {
if(--R.GAS > 0) {
$z683684 = R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1417642):R.ffi.throwNonFunApp(L[69],if_helper1402643,[cont_tail_arg1417642]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1417642):R.ffi.throwNonFunApp(L[69],if_helper1402643,[cont_tail_arg1417642]);
},
"from":L[69]});
}
++R.GAS;
return $z683684;
};
var $Hcont_tail_arg2001657 = function(cont_tail_arg1414656,if_helper1402643) {
if(--R.GAS > 0) {
$z685686 = R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1414656):R.ffi.throwNonFunApp(L[71],if_helper1402643,[cont_tail_arg1414656]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1414656):R.ffi.throwNonFunApp(L[71],if_helper1402643,[cont_tail_arg1414656]);
},
"from":L[71]});
}
++R.GAS;
return $z685686;
};
var $Hcont_tail_arg2002670 = function(cont_tail_arg1411669,if_helper1402643) {
if(--R.GAS > 0) {
$z687688 = R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1411669):R.ffi.throwNonFunApp(L[73],if_helper1402643,[cont_tail_arg1411669]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1402643)?if_helper1402643.app(cont_tail_arg1411669):R.ffi.throwNonFunApp(L[73],if_helper1402643,[cont_tail_arg1411669]);
},
"from":L[73]});
}
++R.GAS;
return $z687688;
};
var $Hor_DASH_oper_DASH_1999689 = function(or_DASH_oper_DASH_142690,A317,expr485691) {
var if_helper1378702 = R.makeFunction(function(if_helper_arg1379722) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[76],1,arguments);
}
var ann_DASH_check_DASH_temp1376723 = if_helper_arg1379722;
return ann_DASH_check_DASH_temp1376723;
});
var anf_if1382721 = R.isBoolean(or_DASH_oper_DASH_142690);
if(R.isPyretTrue(anf_if1382721)) {
if(R.isPyretTrue(or_DASH_oper_DASH_142690)) {
var $z694695 = D;
var $f700701 = function(_) {
return R.isFunction(if_helper1378702)?if_helper1378702.app((true)):R.ffi.throwNonFunApp(L[76],if_helper1378702,[(true)]);
};
try {
if(--R.GAS > 0) {
$z694695 = $f700701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f700701,
"from":L[76]});
}
} catch($e692693) {
if(R.isCont($e692693)) {
var $ss696697 = {"from":L[76],
"go":function(cont_tail_app1388703) {
return $Hcont_tail_app1996704(cont_tail_app1388703);
}};
$e692693.stack[R.EXN_STACKHEIGHT++] = $ss696697;
}
if(R.isPyretException($e692693)) {
$e692693.pyretStack.push(L[76]);
}
throw $e692693;
}
var $ret698699 = $Hcont_tail_app1996704($z694695);
++R.GAS;
return $ret698699;
} else {
var anf_fun1383715 = G(A317,"is-s-method",L[77]);
var $z707708 = D;
var $f713714 = function(_) {
return R.isFunction(anf_fun1383715)?anf_fun1383715.app(expr485691):R.ffi.throwNonFunApp(L[76],anf_fun1383715,[expr485691]);
};
try {
if(--R.GAS > 0) {
$z707708 = $f713714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f713714,
"from":L[76]});
}
} catch($e705706) {
if(R.isCont($e705706)) {
var $ss709710 = {"from":L[76],
"go":function(or_DASH_oper_DASH_143716) {
return $Hor_DASH_oper_DASH_1998717(or_DASH_oper_DASH_143716,if_helper1378702);
}};
$e705706.stack[R.EXN_STACKHEIGHT++] = $ss709710;
}
if(R.isPyretException($e705706)) {
$e705706.pyretStack.push(L[76]);
}
throw $e705706;
}
var $ret711712 = $Hor_DASH_oper_DASH_1998717($z707708,if_helper1378702);
++R.GAS;
return $ret711712;
}
} else {
var cont_tail_arg1380720 = R.throwNonBooleanOp(L[78],("first"),("or"),or_DASH_oper_DASH_142690);
if(--R.GAS > 0) {
$z718719 = R.isFunction(if_helper1378702)?if_helper1378702.app(cont_tail_arg1380720):R.ffi.throwNonFunApp(L[78],if_helper1378702,[cont_tail_arg1380720]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1378702)?if_helper1378702.app(cont_tail_arg1380720):R.ffi.throwNonFunApp(L[78],if_helper1378702,[cont_tail_arg1380720]);
},
"from":L[78]});
}
++R.GAS;
return $z718719;
}
};
var $Hcont_tail_app1996704 = function(cont_tail_app1388703) {
return cont_tail_app1388703;
};
var $Hor_DASH_oper_DASH_1998717 = function(or_DASH_oper_DASH_143716,if_helper1378702) {
var anf_if1386739 = R.isBoolean(or_DASH_oper_DASH_143716);
if(R.isPyretTrue(anf_if1386739)) {
var $z726727 = D;
var $f732733 = function(_) {
return R.isFunction(if_helper1378702)?if_helper1378702.app(or_DASH_oper_DASH_143716):R.ffi.throwNonFunApp(L[76],if_helper1378702,[or_DASH_oper_DASH_143716]);
};
try {
if(--R.GAS > 0) {
$z726727 = $f732733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f732733,
"from":L[76]});
}
} catch($e724725) {
if(R.isCont($e724725)) {
var $ss728729 = {"from":L[76],
"go":function(cont_tail_app1387734) {
return $Hcont_tail_app1997735(cont_tail_app1387734);
}};
$e724725.stack[R.EXN_STACKHEIGHT++] = $ss728729;
}
if(R.isPyretException($e724725)) {
$e724725.pyretStack.push(L[76]);
}
throw $e724725;
}
var $ret730731 = $Hcont_tail_app1997735($z726727);
++R.GAS;
return $ret730731;
} else {
var cont_tail_arg1384738 = R.throwNonBooleanOp(L[79],("second"),("or"),or_DASH_oper_DASH_143716);
if(--R.GAS > 0) {
$z736737 = R.isFunction(if_helper1378702)?if_helper1378702.app(cont_tail_arg1384738):R.ffi.throwNonFunApp(L[79],if_helper1378702,[cont_tail_arg1384738]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1378702)?if_helper1378702.app(cont_tail_arg1384738):R.ffi.throwNonFunApp(L[79],if_helper1378702,[cont_tail_arg1384738]);
},
"from":L[79]});
}
++R.GAS;
return $z736737;
}
};
var $Hcont_tail_app1997735 = function(cont_tail_app1387734) {
return cont_tail_app1387734;
};
var $Hvar_DASH_bind1995740 = function(var_DASH_bind1949741,A317,CS719,ast453742,bind_DASH_exp12766,binding_DASH_env_DASH_iter_DASH_visitor40369,initial_DASH_env452743,is_DASH_none65744,link35745,not9,nothing10) {
var errors454764 = {"$var":var_DASH_bind1949741,
"$name":"errors"};
var add_DASH_error455746 = {"$var":D,
"$name":"add-error"};
var handle_DASH_id456748 = {"$var":D,
"$name":"handle-id"};
var handle_DASH_type_DASH_id457750 = {"$var":D,
"$name":"handle-type-id"};
var anf_assign1300747 = R.makeFunction(function(err458797) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[89],1,arguments);
}
var anf_fun1298808 = R.makeFunction(function(arg_DASH_138811) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[90],1,arguments);
}
var $z814815 = D;
var $f820821 = function(_) {
return R.isFunction(link35745)?link35745.app(arg_DASH_138811,errors454764.$var):R.ffi.throwNonFunApp(L[90],link35745,[arg_DASH_138811,errors454764.$var]);
};
try {
if(--R.GAS > 0) {
$z814815 = $f820821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f820821,
"from":L[90]});
}
} catch($e812813) {
if(R.isCont($e812813)) {
var $ss816817 = {"from":L[90],
"go":function(ann_DASH_check_DASH_temp1297822) {
return $Hann_DASH_check_DASH_temp1950823(ann_DASH_check_DASH_temp1297822);
}};
$e812813.stack[R.EXN_STACKHEIGHT++] = $ss816817;
}
if(R.isPyretException($e812813)) {
$e812813.pyretStack.push(L[90]);
}
throw $e812813;
}
var $ret818819 = $Hann_DASH_check_DASH_temp1950823($z814815);
++R.GAS;
return $ret818819;
});
var $z800801 = D;
var $f806807 = function(_) {
return R.isFunction(anf_fun1298808)?anf_fun1298808.app(err458797):R.ffi.throwNonFunApp(L[90],anf_fun1298808,[err458797]);
};
try {
if(--R.GAS > 0) {
$z800801 = $f806807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f806807,
"from":L[90]});
}
} catch($e798799) {
if(R.isCont($e798799)) {
var $ss802803 = {"from":L[90],
"go":function(anf_assign1299809) {
return $Hanf_assign1951810(anf_assign1299809,errors454764);
}};
$e798799.stack[R.EXN_STACKHEIGHT++] = $ss802803;
}
if(R.isPyretException($e798799)) {
$e798799.pyretStack.push(L[90]);
}
throw $e798799;
}
var $ret804805 = $Hanf_assign1951810($z800801,errors454764);
++R.GAS;
return $ret804805;
});
add_DASH_error455746.$var = anf_assign1300747;
var anf_assign1312749 = R.makeFunction(function(this_DASH_id459783,env460784) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[87],2,arguments);
}
var $z787788 = D;
var $f793794 = function(_) {
return R.isFunction(bind_DASH_exp12766.$var)?bind_DASH_exp12766.$var.app(this_DASH_id459783,env460784):R.ffi.throwNonFunApp(L[88],bind_DASH_exp12766.$var,[this_DASH_id459783,env460784]);
};
try {
if(--R.GAS > 0) {
$z787788 = $f793794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f793794,
"from":L[88]});
}
} catch($e785786) {
if(R.isCont($e785786)) {
var $ss789790 = {"from":L[88],
"go":function(anf_arg1302795) {
return $Hanf_arg1958796(anf_arg1302795,CS719,add_DASH_error455746,is_DASH_none65744,this_DASH_id459783,nothing10);
}};
$e785786.stack[R.EXN_STACKHEIGHT++] = $ss789790;
}
if(R.isPyretException($e785786)) {
$e785786.pyretStack.push(L[88]);
}
throw $e785786;
}
var $ret791792 = $Hanf_arg1958796($z787788,CS719,add_DASH_error455746,is_DASH_none65744,this_DASH_id459783,nothing10);
++R.GAS;
return $ret791792;
});
handle_DASH_id456748.$var = anf_assign1312749;
var anf_assign1328751 = R.makeFunction(function(ann461766,env462767) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[82],2,arguments);
}
var anf_fun1314780 = G(env462767,"has-key",L[86]);
var anf_bracket1315782 = G(ann461766,"id",L[85]);
var anf_fun1316778 = G(anf_bracket1315782,"key",L[84]);
var $z770771 = D;
var $f776777 = function(_) {
return R.isFunction(anf_fun1316778)?anf_fun1316778.app():R.ffi.throwNonFunApp(L[83],anf_fun1316778,[]);
};
try {
if(--R.GAS > 0) {
$z770771 = $f776777();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f776777,
"from":L[83]});
}
} catch($e768769) {
if(R.isCont($e768769)) {
var $ss772773 = {"from":L[83],
"go":function(anf_arg1317779) {
return $Hanf_arg1966781(anf_arg1317779,CS719,add_DASH_error455746,anf_fun1314780,ann461766,not9,nothing10);
}};
$e768769.stack[R.EXN_STACKHEIGHT++] = $ss772773;
}
if(R.isPyretException($e768769)) {
$e768769.pyretStack.push(L[83]);
}
throw $e768769;
}
var $ret774775 = $Hanf_arg1966781($z770771,CS719,add_DASH_error455746,anf_fun1314780,ann461766,not9,nothing10);
++R.GAS;
return $ret774775;
});
handle_DASH_type_DASH_id457750.$var = anf_assign1328751;
var anf_fun1329763 = G(ast453742,"visit",L[81]);
var $z754755 = D;
var $f760761 = function(_) {
return R.isFunction(binding_DASH_env_DASH_iter_DASH_visitor40369.$var)?binding_DASH_env_DASH_iter_DASH_visitor40369.$var.app(initial_DASH_env452743):R.ffi.throwNonFunApp(L[80],binding_DASH_env_DASH_iter_DASH_visitor40369.$var,[initial_DASH_env452743]);
};
try {
if(--R.GAS > 0) {
$z754755 = $f760761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f760761,
"from":L[80]});
}
} catch($e752753) {
if(R.isCont($e752753)) {
var $ss756757 = {"from":L[80],
"go":function(anf_extend1330762) {
return $Hanf_extend1994765(anf_extend1330762,A317,CS719,add_DASH_error455746,anf_fun1329763,bind_DASH_exp12766,errors454764,handle_DASH_id456748,handle_DASH_type_DASH_id457750,is_DASH_none65744,nothing10);
}};
$e752753.stack[R.EXN_STACKHEIGHT++] = $ss756757;
}
if(R.isPyretException($e752753)) {
$e752753.pyretStack.push(L[80]);
}
throw $e752753;
}
var $ret758759 = $Hanf_extend1994765($z754755,A317,CS719,add_DASH_error455746,anf_fun1329763,bind_DASH_exp12766,errors454764,handle_DASH_id456748,handle_DASH_type_DASH_id457750,is_DASH_none65744,nothing10);
++R.GAS;
return $ret758759;
};
var $Hanf_extend1994765 = function(anf_extend1330762,A317,CS719,add_DASH_error455746,anf_fun1329763,bind_DASH_exp12766,errors454764,handle_DASH_id456748,handle_DASH_type_DASH_id457750,is_DASH_none65744,nothing10) {
var anf_extend1335837 = R.makeMethod(function(self463940) {
return function(loc464937,id465938) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[109],2,arguments);
}
var anf_fun1332936 = G(A317,"s-id",L[108]);
var $z928929 = D;
var $f934935 = function(_) {
return R.isFunction(anf_fun1332936)?anf_fun1332936.app(loc464937,id465938):R.ffi.throwNonFunApp(L[107],anf_fun1332936,[loc464937,id465938]);
};
try {
if(--R.GAS > 0) {
$z928929 = $f934935();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f934935,
"from":L[107]});
}
} catch($e926927) {
if(R.isCont($e926927)) {
var $ss930931 = {"from":L[107],
"go":function(anf_arg1333939) {
return $Hanf_arg1969941(anf_arg1333939,handle_DASH_id456748,self463940);
}};
$e926927.stack[R.EXN_STACKHEIGHT++] = $ss930931;
}
if(R.isPyretException($e926927)) {
$e926927.pyretStack.push(L[107]);
}
throw $e926927;
}
var $ret932933 = $Hanf_arg1969941($z928929,handle_DASH_id456748,self463940);
++R.GAS;
return $ret932933;
};
},{"length":3});
var anf_extend1340838 = R.makeMethod(function(self466924) {
return function(loc467921,id468922) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[106],2,arguments);
}
var anf_fun1337920 = G(A317,"s-id-var",L[105]);
var $z912913 = D;
var $f918919 = function(_) {
return R.isFunction(anf_fun1337920)?anf_fun1337920.app(loc467921,id468922):R.ffi.throwNonFunApp(L[104],anf_fun1337920,[loc467921,id468922]);
};
try {
if(--R.GAS > 0) {
$z912913 = $f918919();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f918919,
"from":L[104]});
}
} catch($e910911) {
if(R.isCont($e910911)) {
var $ss914915 = {"from":L[104],
"go":function(anf_arg1338923) {
return $Hanf_arg1972925(anf_arg1338923,handle_DASH_id456748,self466924);
}};
$e910911.stack[R.EXN_STACKHEIGHT++] = $ss914915;
}
if(R.isPyretException($e910911)) {
$e910911.pyretStack.push(L[104]);
}
throw $e910911;
}
var $ret916917 = $Hanf_arg1972925($z912913,handle_DASH_id456748,self466924);
++R.GAS;
return $ret916917;
};
},{"length":3});
var anf_extend1345839 = R.makeMethod(function(self469908) {
return function(loc470904,id471905,safe472906) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[103],3,arguments);
}
var anf_fun1342903 = G(A317,"s-id-letrec",L[102]);
var $z895896 = D;
var $f901902 = function(_) {
return R.isFunction(anf_fun1342903)?anf_fun1342903.app(loc470904,id471905,safe472906):R.ffi.throwNonFunApp(L[101],anf_fun1342903,[loc470904,id471905,safe472906]);
};
try {
if(--R.GAS > 0) {
$z895896 = $f901902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f901902,
"from":L[101]});
}
} catch($e893894) {
if(R.isCont($e893894)) {
var $ss897898 = {"from":L[101],
"go":function(anf_arg1343907) {
return $Hanf_arg1975909(anf_arg1343907,handle_DASH_id456748,self469908);
}};
$e893894.stack[R.EXN_STACKHEIGHT++] = $ss897898;
}
if(R.isPyretException($e893894)) {
$e893894.pyretStack.push(L[101]);
}
throw $e893894;
}
var $ret899900 = $Hanf_arg1975909($z895896,handle_DASH_id456748,self469908);
++R.GAS;
return $ret899900;
};
},{"length":4});
var anf_extend1363840 = R.makeMethod(function(self473890) {
return function(loc474887,id475888,value476891) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[100],3,arguments);
}
var anf_fun1347886 = G(A317,"s-id",L[99]);
var $z878879 = D;
var $f884885 = function(_) {
return R.isFunction(anf_fun1347886)?anf_fun1347886.app(loc474887,id475888):R.ffi.throwNonFunApp(L[98],anf_fun1347886,[loc474887,id475888]);
};
try {
if(--R.GAS > 0) {
$z878879 = $f884885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f884885,
"from":L[98]});
}
} catch($e876877) {
if(R.isCont($e876877)) {
var $ss880881 = {"from":L[98],
"go":function(anf_arg1348889) {
return $Hanf_arg1985892(anf_arg1348889,CS719,add_DASH_error455746,bind_DASH_exp12766,id475888,is_DASH_none65744,loc474887,self473890,value476891,nothing10);
}};
$e876877.stack[R.EXN_STACKHEIGHT++] = $ss880881;
}
if(R.isPyretException($e876877)) {
$e876877.pyretStack.push(L[98]);
}
throw $e876877;
}
var $ret882883 = $Hanf_arg1985892($z878879,CS719,add_DASH_error455746,bind_DASH_exp12766,id475888,is_DASH_none65744,loc474887,self473890,value476891,nothing10);
++R.GAS;
return $ret882883;
};
},{"length":4});
var anf_extend1368841 = R.makeMethod(function(self477874) {
return function(loc478871,id479872) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[97],2,arguments);
}
var anf_fun1365870 = G(A317,"a-name",L[96]);
var $z862863 = D;
var $f868869 = function(_) {
return R.isFunction(anf_fun1365870)?anf_fun1365870.app(loc478871,id479872):R.ffi.throwNonFunApp(L[95],anf_fun1365870,[loc478871,id479872]);
};
try {
if(--R.GAS > 0) {
$z862863 = $f868869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f868869,
"from":L[95]});
}
} catch($e860861) {
if(R.isCont($e860861)) {
var $ss864865 = {"from":L[95],
"go":function(anf_arg1366873) {
return $Hanf_arg1988875(anf_arg1366873,handle_DASH_type_DASH_id457750,self477874);
}};
$e860861.stack[R.EXN_STACKHEIGHT++] = $ss864865;
}
if(R.isPyretException($e860861)) {
$e860861.pyretStack.push(L[95]);
}
throw $e860861;
}
var $ret866867 = $Hanf_arg1988875($z862863,handle_DASH_type_DASH_id457750,self477874);
++R.GAS;
return $ret866867;
};
},{"length":3});
var anf_extend1373842 = R.makeMethod(function(self480857) {
return function(loc481854,name482855,field483859) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[94],3,arguments);
}
var anf_fun1370853 = G(A317,"a-name",L[93]);
var $z845846 = D;
var $f851852 = function(_) {
return R.isFunction(anf_fun1370853)?anf_fun1370853.app(loc481854,name482855):R.ffi.throwNonFunApp(L[92],anf_fun1370853,[loc481854,name482855]);
};
try {
if(--R.GAS > 0) {
$z845846 = $f851852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f851852,
"from":L[92]});
}
} catch($e843844) {
if(R.isCont($e843844)) {
var $ss847848 = {"from":L[92],
"go":function(anf_arg1371856) {
return $Hanf_arg1991858(anf_arg1371856,handle_DASH_type_DASH_id457750,self480857);
}};
$e843844.stack[R.EXN_STACKHEIGHT++] = $ss847848;
}
if(R.isPyretException($e843844)) {
$e843844.pyretStack.push(L[92]);
}
throw $e843844;
}
var $ret849850 = $Hanf_arg1991858($z845846,handle_DASH_type_DASH_id457750,self480857);
++R.GAS;
return $ret849850;
};
},{"length":4});
var anf_arg1374834 = anf_extend1330762.extendWith({"s-id":anf_extend1335837,
"s-id-var":anf_extend1340838,
"s-id-letrec":anf_extend1345839,
"s-assign":anf_extend1363840,
"a-name":anf_extend1368841,
"a-dot":anf_extend1373842});
var $z826827 = D;
var $f832833 = function(_) {
return R.isFunction(anf_fun1329763)?anf_fun1329763.app(anf_arg1374834):R.ffi.throwNonFunApp(L[91],anf_fun1329763,[anf_arg1374834]);
};
try {
if(--R.GAS > 0) {
$z826827 = $f832833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f832833,
"from":L[91]});
}
} catch($e824825) {
if(R.isCont($e824825)) {
var $ss828829 = {"from":L[91],
"go":function(anf_begin_app_dropped1992835) {
return $Hanf_begin_app_dropped1993836(anf_begin_app_dropped1992835,errors454764);
}};
$e824825.stack[R.EXN_STACKHEIGHT++] = $ss828829;
}
if(R.isPyretException($e824825)) {
$e824825.pyretStack.push(L[91]);
}
throw $e824825;
}
var $ret830831 = $Hanf_begin_app_dropped1993836($z826827,errors454764);
++R.GAS;
return $ret830831;
};
var $Hanf_begin_app_dropped1993836 = function(anf_begin_app_dropped1992835,errors454764) {
var ann_DASH_check_DASH_temp1294942 = errors454764.$var;
return ann_DASH_check_DASH_temp1294942;
};
var $Hanf_arg1991858 = function(anf_arg1371856,handle_DASH_type_DASH_id457750,self480857) {
var anf_arg1372953 = G(self480857,"type-env",L[111]);
var $z945946 = D;
var $f951952 = function(_) {
return R.isFunction(handle_DASH_type_DASH_id457750.$var)?handle_DASH_type_DASH_id457750.$var.app(anf_arg1371856,anf_arg1372953):R.ffi.throwNonFunApp(L[110],handle_DASH_type_DASH_id457750.$var,[anf_arg1371856,anf_arg1372953]);
};
try {
if(--R.GAS > 0) {
$z945946 = $f951952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f951952,
"from":L[110]});
}
} catch($e943944) {
if(R.isCont($e943944)) {
var $ss947948 = {"from":L[110],
"go":function(anf_begin_app_dropped1989954) {
return $Hanf_begin_app_dropped1990955(anf_begin_app_dropped1989954);
}};
$e943944.stack[R.EXN_STACKHEIGHT++] = $ss947948;
}
if(R.isPyretException($e943944)) {
$e943944.pyretStack.push(L[110]);
}
throw $e943944;
}
var $ret949950 = $Hanf_begin_app_dropped1990955($z945946);
++R.GAS;
return $ret949950;
};
var $Hanf_begin_app_dropped1990955 = function(anf_begin_app_dropped1989954) {
var ann_DASH_check_DASH_temp1369956 = (true);
return ann_DASH_check_DASH_temp1369956;
};
var $Hanf_arg1988875 = function(anf_arg1366873,handle_DASH_type_DASH_id457750,self477874) {
var anf_arg1367967 = G(self477874,"type-env",L[113]);
var $z959960 = D;
var $f965966 = function(_) {
return R.isFunction(handle_DASH_type_DASH_id457750.$var)?handle_DASH_type_DASH_id457750.$var.app(anf_arg1366873,anf_arg1367967):R.ffi.throwNonFunApp(L[112],handle_DASH_type_DASH_id457750.$var,[anf_arg1366873,anf_arg1367967]);
};
try {
if(--R.GAS > 0) {
$z959960 = $f965966();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f965966,
"from":L[112]});
}
} catch($e957958) {
if(R.isCont($e957958)) {
var $ss961962 = {"from":L[112],
"go":function(anf_begin_app_dropped1986968) {
return $Hanf_begin_app_dropped1987969(anf_begin_app_dropped1986968);
}};
$e957958.stack[R.EXN_STACKHEIGHT++] = $ss961962;
}
if(R.isPyretException($e957958)) {
$e957958.pyretStack.push(L[112]);
}
throw $e957958;
}
var $ret963964 = $Hanf_begin_app_dropped1987969($z959960);
++R.GAS;
return $ret963964;
};
var $Hanf_begin_app_dropped1987969 = function(anf_begin_app_dropped1986968) {
var ann_DASH_check_DASH_temp1364970 = (true);
return ann_DASH_check_DASH_temp1364970;
};
var $Hanf_arg1985892 = function(anf_arg1348889,CS719,add_DASH_error455746,bind_DASH_exp12766,id475888,is_DASH_none65744,loc474887,self473890,value476891,nothing10) {
var anf_arg1349981 = G(self473890,"env",L[115]);
var $z973974 = D;
var $f979980 = function(_) {
return R.isFunction(bind_DASH_exp12766.$var)?bind_DASH_exp12766.$var.app(anf_arg1348889,anf_arg1349981):R.ffi.throwNonFunApp(L[114],bind_DASH_exp12766.$var,[anf_arg1348889,anf_arg1349981]);
};
try {
if(--R.GAS > 0) {
$z973974 = $f979980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f979980,
"from":L[114]});
}
} catch($e971972) {
if(R.isCont($e971972)) {
var $ss975976 = {"from":L[114],
"go":function(anf_arg1350982) {
return $Hanf_arg1984983(anf_arg1350982,CS719,add_DASH_error455746,id475888,is_DASH_none65744,loc474887,self473890,value476891,nothing10);
}};
$e971972.stack[R.EXN_STACKHEIGHT++] = $ss975976;
}
if(R.isPyretException($e971972)) {
$e971972.pyretStack.push(L[114]);
}
throw $e971972;
}
var $ret977978 = $Hanf_arg1984983($z973974,CS719,add_DASH_error455746,id475888,is_DASH_none65744,loc474887,self473890,value476891,nothing10);
++R.GAS;
return $ret977978;
};
var $Hanf_arg1984983 = function(anf_arg1350982,CS719,add_DASH_error455746,id475888,is_DASH_none65744,loc474887,self473890,value476891,nothing10) {
var $z986987 = D;
var $f992993 = function(_) {
return R.isFunction(is_DASH_none65744)?is_DASH_none65744.app(anf_arg1350982):R.ffi.throwNonFunApp(L[116],is_DASH_none65744,[anf_arg1350982]);
};
try {
if(--R.GAS > 0) {
$z986987 = $f992993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f992993,
"from":L[116]});
}
} catch($e984985) {
if(R.isCont($e984985)) {
var $ss988989 = {"from":L[116],
"go":function(when_DASH_141994) {
return $Hwhen_DASH_1983995(when_DASH_141994,CS719,add_DASH_error455746,id475888,loc474887,self473890,value476891,nothing10);
}};
$e984985.stack[R.EXN_STACKHEIGHT++] = $ss988989;
}
if(R.isPyretException($e984985)) {
$e984985.pyretStack.push(L[116]);
}
throw $e984985;
}
var $ret990991 = $Hwhen_DASH_1983995($z986987,CS719,add_DASH_error455746,id475888,loc474887,self473890,value476891,nothing10);
++R.GAS;
return $ret990991;
};
var $Hwhen_DASH_1983995 = function(when_DASH_141994,CS719,add_DASH_error455746,id475888,loc474887,self473890,value476891,nothing10) {
var if_helper13511009 = R.makeFunction(function(if_helper_arg13521027) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[116],1,arguments);
}
if_helper_arg13521027;
var anf_fun13531038 = G(value476891,"visit",L[121]);
var $z10301031 = D;
var $f10361037 = function(_) {
return R.isFunction(anf_fun13531038)?anf_fun13531038.app(self473890):R.ffi.throwNonFunApp(L[100],anf_fun13531038,[self473890]);
};
try {
if(--R.GAS > 0) {
$z10301031 = $f10361037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10361037,
"from":L[100]});
}
} catch($e10281029) {
if(R.isCont($e10281029)) {
var $ss10321033 = {"from":L[100],
"go":function(ann_DASH_check_DASH_temp13461039) {
return $Hann_DASH_check_DASH_temp19761040(ann_DASH_check_DASH_temp13461039);
}};
$e10281029.stack[R.EXN_STACKHEIGHT++] = $ss10321033;
}
if(R.isPyretException($e10281029)) {
$e10281029.pyretStack.push(L[100]);
}
throw $e10281029;
}
var $ret10341035 = $Hann_DASH_check_DASH_temp19761040($z10301031);
++R.GAS;
return $ret10341035;
});
var anf_if13561026 = R.isBoolean(when_DASH_141994);
if(R.isPyretTrue(anf_if13561026)) {
if(R.isPyretTrue(when_DASH_141994)) {
var anf_fun13581008 = G(CS719,"unbound-var",L[119]);
var anf_fun13591006 = G(id475888,"toname",L[118]);
var $z998999 = D;
var $f10041005 = function(_) {
return R.isFunction(anf_fun13591006)?anf_fun13591006.app():R.ffi.throwNonFunApp(L[117],anf_fun13591006,[]);
};
try {
if(--R.GAS > 0) {
$z998999 = $f10041005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10041005,
"from":L[117]});
}
} catch($e996997) {
if(R.isCont($e996997)) {
var $ss10001001 = {"from":L[117],
"go":function(anf_arg13601007) {
return $Hanf_arg19811010(anf_arg13601007,add_DASH_error455746,anf_fun13581008,if_helper13511009,loc474887,nothing10);
}};
$e996997.stack[R.EXN_STACKHEIGHT++] = $ss10001001;
}
if(R.isPyretException($e996997)) {
$e996997.pyretStack.push(L[117]);
}
throw $e996997;
}
var $ret10021003 = $Hanf_arg19811010($z998999,add_DASH_error455746,anf_fun13581008,if_helper13511009,loc474887,nothing10);
++R.GAS;
return $ret10021003;
} else {
var $z10131014 = D;
var $f10191020 = function(_) {
return R.isFunction(if_helper13511009)?if_helper13511009.app(nothing10):R.ffi.throwNonFunApp(L[116],if_helper13511009,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z10131014 = $f10191020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10191020,
"from":L[116]});
}
} catch($e10111012) {
if(R.isCont($e10111012)) {
var $ss10151016 = {"from":L[116],
"go":function(cont_tail_app13571021) {
return $Hcont_tail_app19821022(cont_tail_app13571021);
}};
$e10111012.stack[R.EXN_STACKHEIGHT++] = $ss10151016;
}
if(R.isPyretException($e10111012)) {
$e10111012.pyretStack.push(L[116]);
}
throw $e10111012;
}
var $ret10171018 = $Hcont_tail_app19821022($z10131014);
++R.GAS;
return $ret10171018;
}
} else {
var cont_tail_arg13541025 = R.throwNonBooleanCondition(L[120],("when"),when_DASH_141994);
if(--R.GAS > 0) {
$z10231024 = R.isFunction(if_helper13511009)?if_helper13511009.app(cont_tail_arg13541025):R.ffi.throwNonFunApp(L[120],if_helper13511009,[cont_tail_arg13541025]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper13511009)?if_helper13511009.app(cont_tail_arg13541025):R.ffi.throwNonFunApp(L[120],if_helper13511009,[cont_tail_arg13541025]);
},
"from":L[120]});
}
++R.GAS;
return $z10231024;
}
};
var $Hanf_arg19811010 = function(anf_arg13601007,add_DASH_error455746,anf_fun13581008,if_helper13511009,loc474887,nothing10) {
var $z10431044 = D;
var $f10491050 = function(_) {
return R.isFunction(anf_fun13581008)?anf_fun13581008.app(anf_arg13601007,loc474887):R.ffi.throwNonFunApp(L[122],anf_fun13581008,[anf_arg13601007,loc474887]);
};
try {
if(--R.GAS > 0) {
$z10431044 = $f10491050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10491050,
"from":L[122]});
}
} catch($e10411042) {
if(R.isCont($e10411042)) {
var $ss10451046 = {"from":L[122],
"go":function(anf_arg13611051) {
return $Hanf_arg19801052(anf_arg13611051,add_DASH_error455746,if_helper13511009,nothing10);
}};
$e10411042.stack[R.EXN_STACKHEIGHT++] = $ss10451046;
}
if(R.isPyretException($e10411042)) {
$e10411042.pyretStack.push(L[122]);
}
throw $e10411042;
}
var $ret10471048 = $Hanf_arg19801052($z10431044,add_DASH_error455746,if_helper13511009,nothing10);
++R.GAS;
return $ret10471048;
};
var $Hanf_arg19801052 = function(anf_arg13611051,add_DASH_error455746,if_helper13511009,nothing10) {
var $z10551056 = D;
var $f10611062 = function(_) {
return R.isFunction(add_DASH_error455746.$var)?add_DASH_error455746.$var.app(anf_arg13611051):R.ffi.throwNonFunApp(L[123],add_DASH_error455746.$var,[anf_arg13611051]);
};
try {
if(--R.GAS > 0) {
$z10551056 = $f10611062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10611062,
"from":L[123]});
}
} catch($e10531054) {
if(R.isCont($e10531054)) {
var $ss10571058 = {"from":L[123],
"go":function(anf_begin_app_dropped19771063) {
return $Hanf_begin_app_dropped19791064(anf_begin_app_dropped19771063,if_helper13511009,nothing10);
}};
$e10531054.stack[R.EXN_STACKHEIGHT++] = $ss10571058;
}
if(R.isPyretException($e10531054)) {
$e10531054.pyretStack.push(L[123]);
}
throw $e10531054;
}
var $ret10591060 = $Hanf_begin_app_dropped19791064($z10551056,if_helper13511009,nothing10);
++R.GAS;
return $ret10591060;
};
var $Hanf_begin_app_dropped19791064 = function(anf_begin_app_dropped19771063,if_helper13511009,nothing10) {
var $z10671068 = D;
var $f10731074 = function(_) {
return R.isFunction(if_helper13511009)?if_helper13511009.app(nothing10):R.ffi.throwNonFunApp(L[116],if_helper13511009,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z10671068 = $f10731074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10731074,
"from":L[116]});
}
} catch($e10651066) {
if(R.isCont($e10651066)) {
var $ss10691070 = {"from":L[116],
"go":function(cont_tail_app13621075) {
return $Hcont_tail_app19781076(cont_tail_app13621075);
}};
$e10651066.stack[R.EXN_STACKHEIGHT++] = $ss10691070;
}
if(R.isPyretException($e10651066)) {
$e10651066.pyretStack.push(L[116]);
}
throw $e10651066;
}
var $ret10711072 = $Hcont_tail_app19781076($z10671068);
++R.GAS;
return $ret10711072;
};
var $Hcont_tail_app19781076 = function(cont_tail_app13621075) {
return cont_tail_app13621075;
};
var $Hcont_tail_app19821022 = function(cont_tail_app13571021) {
return cont_tail_app13571021;
};
var $Hann_DASH_check_DASH_temp19761040 = function(ann_DASH_check_DASH_temp13461039) {
return ann_DASH_check_DASH_temp13461039;
};
var $Hanf_arg1975909 = function(anf_arg1343907,handle_DASH_id456748,self469908) {
var anf_arg13441087 = G(self469908,"env",L[125]);
var $z10791080 = D;
var $f10851086 = function(_) {
return R.isFunction(handle_DASH_id456748.$var)?handle_DASH_id456748.$var.app(anf_arg1343907,anf_arg13441087):R.ffi.throwNonFunApp(L[124],handle_DASH_id456748.$var,[anf_arg1343907,anf_arg13441087]);
};
try {
if(--R.GAS > 0) {
$z10791080 = $f10851086();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10851086,
"from":L[124]});
}
} catch($e10771078) {
if(R.isCont($e10771078)) {
var $ss10811082 = {"from":L[124],
"go":function(anf_begin_app_dropped19731088) {
return $Hanf_begin_app_dropped19741089(anf_begin_app_dropped19731088);
}};
$e10771078.stack[R.EXN_STACKHEIGHT++] = $ss10811082;
}
if(R.isPyretException($e10771078)) {
$e10771078.pyretStack.push(L[124]);
}
throw $e10771078;
}
var $ret10831084 = $Hanf_begin_app_dropped19741089($z10791080);
++R.GAS;
return $ret10831084;
};
var $Hanf_begin_app_dropped19741089 = function(anf_begin_app_dropped19731088) {
var ann_DASH_check_DASH_temp13411090 = (true);
return ann_DASH_check_DASH_temp13411090;
};
var $Hanf_arg1972925 = function(anf_arg1338923,handle_DASH_id456748,self466924) {
var anf_arg13391101 = G(self466924,"env",L[127]);
var $z10931094 = D;
var $f10991100 = function(_) {
return R.isFunction(handle_DASH_id456748.$var)?handle_DASH_id456748.$var.app(anf_arg1338923,anf_arg13391101):R.ffi.throwNonFunApp(L[126],handle_DASH_id456748.$var,[anf_arg1338923,anf_arg13391101]);
};
try {
if(--R.GAS > 0) {
$z10931094 = $f10991100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10991100,
"from":L[126]});
}
} catch($e10911092) {
if(R.isCont($e10911092)) {
var $ss10951096 = {"from":L[126],
"go":function(anf_begin_app_dropped19701102) {
return $Hanf_begin_app_dropped19711103(anf_begin_app_dropped19701102);
}};
$e10911092.stack[R.EXN_STACKHEIGHT++] = $ss10951096;
}
if(R.isPyretException($e10911092)) {
$e10911092.pyretStack.push(L[126]);
}
throw $e10911092;
}
var $ret10971098 = $Hanf_begin_app_dropped19711103($z10931094);
++R.GAS;
return $ret10971098;
};
var $Hanf_begin_app_dropped19711103 = function(anf_begin_app_dropped19701102) {
var ann_DASH_check_DASH_temp13361104 = (true);
return ann_DASH_check_DASH_temp13361104;
};
var $Hanf_arg1969941 = function(anf_arg1333939,handle_DASH_id456748,self463940) {
var anf_arg13341115 = G(self463940,"env",L[129]);
var $z11071108 = D;
var $f11131114 = function(_) {
return R.isFunction(handle_DASH_id456748.$var)?handle_DASH_id456748.$var.app(anf_arg1333939,anf_arg13341115):R.ffi.throwNonFunApp(L[128],handle_DASH_id456748.$var,[anf_arg1333939,anf_arg13341115]);
};
try {
if(--R.GAS > 0) {
$z11071108 = $f11131114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11131114,
"from":L[128]});
}
} catch($e11051106) {
if(R.isCont($e11051106)) {
var $ss11091110 = {"from":L[128],
"go":function(anf_begin_app_dropped19671116) {
return $Hanf_begin_app_dropped19681117(anf_begin_app_dropped19671116);
}};
$e11051106.stack[R.EXN_STACKHEIGHT++] = $ss11091110;
}
if(R.isPyretException($e11051106)) {
$e11051106.pyretStack.push(L[128]);
}
throw $e11051106;
}
var $ret11111112 = $Hanf_begin_app_dropped19681117($z11071108);
++R.GAS;
return $ret11111112;
};
var $Hanf_begin_app_dropped19681117 = function(anf_begin_app_dropped19671116) {
var ann_DASH_check_DASH_temp13311118 = (true);
return ann_DASH_check_DASH_temp13311118;
};
var $Hanf_arg1966781 = function(anf_arg1317779,CS719,add_DASH_error455746,anf_fun1314780,ann461766,not9,nothing10) {
var $z11211122 = D;
var $f11271128 = function(_) {
return R.isFunction(anf_fun1314780)?anf_fun1314780.app(anf_arg1317779):R.ffi.throwNonFunApp(L[130],anf_fun1314780,[anf_arg1317779]);
};
try {
if(--R.GAS > 0) {
$z11211122 = $f11271128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11271128,
"from":L[130]});
}
} catch($e11191120) {
if(R.isCont($e11191120)) {
var $ss11231124 = {"from":L[130],
"go":function(anf_arg13181129) {
return $Hanf_arg19651130(anf_arg13181129,CS719,add_DASH_error455746,ann461766,not9,nothing10);
}};
$e11191120.stack[R.EXN_STACKHEIGHT++] = $ss11231124;
}
if(R.isPyretException($e11191120)) {
$e11191120.pyretStack.push(L[130]);
}
throw $e11191120;
}
var $ret11251126 = $Hanf_arg19651130($z11211122,CS719,add_DASH_error455746,ann461766,not9,nothing10);
++R.GAS;
return $ret11251126;
};
var $Hanf_arg19651130 = function(anf_arg13181129,CS719,add_DASH_error455746,ann461766,not9,nothing10) {
var $z11331134 = D;
var $f11391140 = function(_) {
return R.isFunction(not9)?not9.app(anf_arg13181129):R.ffi.throwNonFunApp(L[131],not9,[anf_arg13181129]);
};
try {
if(--R.GAS > 0) {
$z11331134 = $f11391140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11391140,
"from":L[131]});
}
} catch($e11311132) {
if(R.isCont($e11311132)) {
var $ss11351136 = {"from":L[131],
"go":function(when_DASH_1401141) {
return $Hwhen_DASH_19641142(when_DASH_1401141,CS719,add_DASH_error455746,ann461766,nothing10);
}};
$e11311132.stack[R.EXN_STACKHEIGHT++] = $ss11351136;
}
if(R.isPyretException($e11311132)) {
$e11311132.pyretStack.push(L[131]);
}
throw $e11311132;
}
var $ret11371138 = $Hwhen_DASH_19641142($z11331134,CS719,add_DASH_error455746,ann461766,nothing10);
++R.GAS;
return $ret11371138;
};
var $Hwhen_DASH_19641142 = function(when_DASH_1401141,CS719,add_DASH_error455746,ann461766,nothing10) {
var if_helper13191155 = R.makeFunction(function(if_helper_arg13201173) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[131],1,arguments);
}
var ann_DASH_check_DASH_temp13131174 = if_helper_arg13201173;
return ann_DASH_check_DASH_temp13131174;
});
var anf_if13231172 = R.isBoolean(when_DASH_1401141);
if(R.isPyretTrue(anf_if13231172)) {
if(R.isPyretTrue(when_DASH_1401141)) {
var anf_fun13251153 = G(CS719,"unbound-type-id",L[133]);
var $z11451146 = D;
var $f11511152 = function(_) {
return R.isFunction(anf_fun13251153)?anf_fun13251153.app(ann461766):R.ffi.throwNonFunApp(L[132],anf_fun13251153,[ann461766]);
};
try {
if(--R.GAS > 0) {
$z11451146 = $f11511152();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11511152,
"from":L[132]});
}
} catch($e11431144) {
if(R.isCont($e11431144)) {
var $ss11471148 = {"from":L[132],
"go":function(anf_arg13261154) {
return $Hanf_arg19621156(anf_arg13261154,add_DASH_error455746,if_helper13191155,nothing10);
}};
$e11431144.stack[R.EXN_STACKHEIGHT++] = $ss11471148;
}
if(R.isPyretException($e11431144)) {
$e11431144.pyretStack.push(L[132]);
}
throw $e11431144;
}
var $ret11491150 = $Hanf_arg19621156($z11451146,add_DASH_error455746,if_helper13191155,nothing10);
++R.GAS;
return $ret11491150;
} else {
var $z11591160 = D;
var $f11651166 = function(_) {
return R.isFunction(if_helper13191155)?if_helper13191155.app(nothing10):R.ffi.throwNonFunApp(L[131],if_helper13191155,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z11591160 = $f11651166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11651166,
"from":L[131]});
}
} catch($e11571158) {
if(R.isCont($e11571158)) {
var $ss11611162 = {"from":L[131],
"go":function(cont_tail_app13241167) {
return $Hcont_tail_app19631168(cont_tail_app13241167);
}};
$e11571158.stack[R.EXN_STACKHEIGHT++] = $ss11611162;
}
if(R.isPyretException($e11571158)) {
$e11571158.pyretStack.push(L[131]);
}
throw $e11571158;
}
var $ret11631164 = $Hcont_tail_app19631168($z11591160);
++R.GAS;
return $ret11631164;
}
} else {
var cont_tail_arg13211171 = R.throwNonBooleanCondition(L[134],("when"),when_DASH_1401141);
if(--R.GAS > 0) {
$z11691170 = R.isFunction(if_helper13191155)?if_helper13191155.app(cont_tail_arg13211171):R.ffi.throwNonFunApp(L[134],if_helper13191155,[cont_tail_arg13211171]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper13191155)?if_helper13191155.app(cont_tail_arg13211171):R.ffi.throwNonFunApp(L[134],if_helper13191155,[cont_tail_arg13211171]);
},
"from":L[134]});
}
++R.GAS;
return $z11691170;
}
};
var $Hanf_arg19621156 = function(anf_arg13261154,add_DASH_error455746,if_helper13191155,nothing10) {
var $z11771178 = D;
var $f11831184 = function(_) {
return R.isFunction(add_DASH_error455746.$var)?add_DASH_error455746.$var.app(anf_arg13261154):R.ffi.throwNonFunApp(L[135],add_DASH_error455746.$var,[anf_arg13261154]);
};
try {
if(--R.GAS > 0) {
$z11771178 = $f11831184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11831184,
"from":L[135]});
}
} catch($e11751176) {
if(R.isCont($e11751176)) {
var $ss11791180 = {"from":L[135],
"go":function(anf_begin_app_dropped19591185) {
return $Hanf_begin_app_dropped19611186(anf_begin_app_dropped19591185,if_helper13191155,nothing10);
}};
$e11751176.stack[R.EXN_STACKHEIGHT++] = $ss11791180;
}
if(R.isPyretException($e11751176)) {
$e11751176.pyretStack.push(L[135]);
}
throw $e11751176;
}
var $ret11811182 = $Hanf_begin_app_dropped19611186($z11771178,if_helper13191155,nothing10);
++R.GAS;
return $ret11811182;
};
var $Hanf_begin_app_dropped19611186 = function(anf_begin_app_dropped19591185,if_helper13191155,nothing10) {
var $z11891190 = D;
var $f11951196 = function(_) {
return R.isFunction(if_helper13191155)?if_helper13191155.app(nothing10):R.ffi.throwNonFunApp(L[131],if_helper13191155,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z11891190 = $f11951196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11951196,
"from":L[131]});
}
} catch($e11871188) {
if(R.isCont($e11871188)) {
var $ss11911192 = {"from":L[131],
"go":function(cont_tail_app13271197) {
return $Hcont_tail_app19601198(cont_tail_app13271197);
}};
$e11871188.stack[R.EXN_STACKHEIGHT++] = $ss11911192;
}
if(R.isPyretException($e11871188)) {
$e11871188.pyretStack.push(L[131]);
}
throw $e11871188;
}
var $ret11931194 = $Hcont_tail_app19601198($z11891190);
++R.GAS;
return $ret11931194;
};
var $Hcont_tail_app19601198 = function(cont_tail_app13271197) {
return cont_tail_app13271197;
};
var $Hcont_tail_app19631168 = function(cont_tail_app13241167) {
return cont_tail_app13241167;
};
var $Hanf_arg1958796 = function(anf_arg1302795,CS719,add_DASH_error455746,is_DASH_none65744,this_DASH_id459783,nothing10) {
var $z12011202 = D;
var $f12071208 = function(_) {
return R.isFunction(is_DASH_none65744)?is_DASH_none65744.app(anf_arg1302795):R.ffi.throwNonFunApp(L[136],is_DASH_none65744,[anf_arg1302795]);
};
try {
if(--R.GAS > 0) {
$z12011202 = $f12071208();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12071208,
"from":L[136]});
}
} catch($e11991200) {
if(R.isCont($e11991200)) {
var $ss12031204 = {"from":L[136],
"go":function(when_DASH_1391209) {
return $Hwhen_DASH_19571210(when_DASH_1391209,CS719,add_DASH_error455746,this_DASH_id459783,nothing10);
}};
$e11991200.stack[R.EXN_STACKHEIGHT++] = $ss12031204;
}
if(R.isPyretException($e11991200)) {
$e11991200.pyretStack.push(L[136]);
}
throw $e11991200;
}
var $ret12051206 = $Hwhen_DASH_19571210($z12011202,CS719,add_DASH_error455746,this_DASH_id459783,nothing10);
++R.GAS;
return $ret12051206;
};
var $Hwhen_DASH_19571210 = function(when_DASH_1391209,CS719,add_DASH_error455746,this_DASH_id459783,nothing10) {
var if_helper13031223 = R.makeFunction(function(if_helper_arg13041241) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[136],1,arguments);
}
var ann_DASH_check_DASH_temp13011242 = if_helper_arg13041241;
return ann_DASH_check_DASH_temp13011242;
});
var anf_if13071240 = R.isBoolean(when_DASH_1391209);
if(R.isPyretTrue(anf_if13071240)) {
if(R.isPyretTrue(when_DASH_1391209)) {
var anf_fun13091221 = G(CS719,"unbound-id",L[138]);
var $z12131214 = D;
var $f12191220 = function(_) {
return R.isFunction(anf_fun13091221)?anf_fun13091221.app(this_DASH_id459783):R.ffi.throwNonFunApp(L[137],anf_fun13091221,[this_DASH_id459783]);
};
try {
if(--R.GAS > 0) {
$z12131214 = $f12191220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12191220,
"from":L[137]});
}
} catch($e12111212) {
if(R.isCont($e12111212)) {
var $ss12151216 = {"from":L[137],
"go":function(anf_arg13101222) {
return $Hanf_arg19551224(anf_arg13101222,add_DASH_error455746,if_helper13031223,nothing10);
}};
$e12111212.stack[R.EXN_STACKHEIGHT++] = $ss12151216;
}
if(R.isPyretException($e12111212)) {
$e12111212.pyretStack.push(L[137]);
}
throw $e12111212;
}
var $ret12171218 = $Hanf_arg19551224($z12131214,add_DASH_error455746,if_helper13031223,nothing10);
++R.GAS;
return $ret12171218;
} else {
var $z12271228 = D;
var $f12331234 = function(_) {
return R.isFunction(if_helper13031223)?if_helper13031223.app(nothing10):R.ffi.throwNonFunApp(L[136],if_helper13031223,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z12271228 = $f12331234();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12331234,
"from":L[136]});
}
} catch($e12251226) {
if(R.isCont($e12251226)) {
var $ss12291230 = {"from":L[136],
"go":function(cont_tail_app13081235) {
return $Hcont_tail_app19561236(cont_tail_app13081235);
}};
$e12251226.stack[R.EXN_STACKHEIGHT++] = $ss12291230;
}
if(R.isPyretException($e12251226)) {
$e12251226.pyretStack.push(L[136]);
}
throw $e12251226;
}
var $ret12311232 = $Hcont_tail_app19561236($z12271228);
++R.GAS;
return $ret12311232;
}
} else {
var cont_tail_arg13051239 = R.throwNonBooleanCondition(L[139],("when"),when_DASH_1391209);
if(--R.GAS > 0) {
$z12371238 = R.isFunction(if_helper13031223)?if_helper13031223.app(cont_tail_arg13051239):R.ffi.throwNonFunApp(L[139],if_helper13031223,[cont_tail_arg13051239]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper13031223)?if_helper13031223.app(cont_tail_arg13051239):R.ffi.throwNonFunApp(L[139],if_helper13031223,[cont_tail_arg13051239]);
},
"from":L[139]});
}
++R.GAS;
return $z12371238;
}
};
var $Hanf_arg19551224 = function(anf_arg13101222,add_DASH_error455746,if_helper13031223,nothing10) {
var $z12451246 = D;
var $f12511252 = function(_) {
return R.isFunction(add_DASH_error455746.$var)?add_DASH_error455746.$var.app(anf_arg13101222):R.ffi.throwNonFunApp(L[140],add_DASH_error455746.$var,[anf_arg13101222]);
};
try {
if(--R.GAS > 0) {
$z12451246 = $f12511252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12511252,
"from":L[140]});
}
} catch($e12431244) {
if(R.isCont($e12431244)) {
var $ss12471248 = {"from":L[140],
"go":function(anf_begin_app_dropped19521253) {
return $Hanf_begin_app_dropped19541254(anf_begin_app_dropped19521253,if_helper13031223,nothing10);
}};
$e12431244.stack[R.EXN_STACKHEIGHT++] = $ss12471248;
}
if(R.isPyretException($e12431244)) {
$e12431244.pyretStack.push(L[140]);
}
throw $e12431244;
}
var $ret12491250 = $Hanf_begin_app_dropped19541254($z12451246,if_helper13031223,nothing10);
++R.GAS;
return $ret12491250;
};
var $Hanf_begin_app_dropped19541254 = function(anf_begin_app_dropped19521253,if_helper13031223,nothing10) {
var $z12571258 = D;
var $f12631264 = function(_) {
return R.isFunction(if_helper13031223)?if_helper13031223.app(nothing10):R.ffi.throwNonFunApp(L[136],if_helper13031223,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z12571258 = $f12631264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12631264,
"from":L[136]});
}
} catch($e12551256) {
if(R.isCont($e12551256)) {
var $ss12591260 = {"from":L[136],
"go":function(cont_tail_app13111265) {
return $Hcont_tail_app19531266(cont_tail_app13111265);
}};
$e12551256.stack[R.EXN_STACKHEIGHT++] = $ss12591260;
}
if(R.isPyretException($e12551256)) {
$e12551256.pyretStack.push(L[136]);
}
throw $e12551256;
}
var $ret12611262 = $Hcont_tail_app19531266($z12571258);
++R.GAS;
return $ret12611262;
};
var $Hcont_tail_app19531266 = function(cont_tail_app13111265) {
return cont_tail_app13111265;
};
var $Hcont_tail_app19561236 = function(cont_tail_app13081235) {
return cont_tail_app13081235;
};
var $Hanf_assign1951810 = function(anf_assign1299809,errors454764) {
var ann_DASH_check_DASH_temp12961267 = errors454764.$var = anf_assign1299809;
return ann_DASH_check_DASH_temp12961267;
};
var $Hann_DASH_check_DASH_temp1950823 = function(ann_DASH_check_DASH_temp1297822) {
return ann_DASH_check_DASH_temp1297822;
};
var $Hann_DASH_check_DASH_temp19481268 = function(ann_DASH_check_DASH_temp12701269) {
return ann_DASH_check_DASH_temp12701269;
};
var $Hanf_arg19471270 = function(anf_arg12861271,anf_fun12841272,exps4391273,loc4371274,self4361275) {
var anf_fun12871286 = G(exps4391273,"map",L[143]);
var anf_arg12901287 = R.makeFunction(function(recv_DASH_1361290) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[142],1,arguments);
}
var anf_fun12891301 = G(recv_DASH_1361290,"visit",L[142]);
var $z12931294 = D;
var $f12991300 = function(_) {
return R.isFunction(anf_fun12891301)?anf_fun12891301.app(self4361275):R.ffi.throwNonFunApp(L[142],anf_fun12891301,[self4361275]);
};
try {
if(--R.GAS > 0) {
$z12931294 = $f12991300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12991300,
"from":L[142]});
}
} catch($e12911292) {
if(R.isCont($e12911292)) {
var $ss12951296 = {"from":L[142],
"go":function(ann_DASH_check_DASH_temp12881302) {
return $Hann_DASH_check_DASH_temp19441303(ann_DASH_check_DASH_temp12881302);
}};
$e12911292.stack[R.EXN_STACKHEIGHT++] = $ss12951296;
}
if(R.isPyretException($e12911292)) {
$e12911292.pyretStack.push(L[142]);
}
throw $e12911292;
}
var $ret12971298 = $Hann_DASH_check_DASH_temp19441303($z12931294);
++R.GAS;
return $ret12971298;
});
var $z12781279 = D;
var $f12841285 = function(_) {
return R.isFunction(anf_fun12871286)?anf_fun12871286.app(anf_arg12901287):R.ffi.throwNonFunApp(L[141],anf_fun12871286,[anf_arg12901287]);
};
try {
if(--R.GAS > 0) {
$z12781279 = $f12841285();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12841285,
"from":L[141]});
}
} catch($e12761277) {
if(R.isCont($e12761277)) {
var $ss12801281 = {"from":L[141],
"go":function(anf_arg12911288) {
return $Hanf_arg19461289(anf_arg12911288,anf_arg12861271,anf_fun12841272,loc4371274);
}};
$e12761277.stack[R.EXN_STACKHEIGHT++] = $ss12801281;
}
if(R.isPyretException($e12761277)) {
$e12761277.pyretStack.push(L[141]);
}
throw $e12761277;
}
var $ret12821283 = $Hanf_arg19461289($z12781279,anf_arg12861271,anf_fun12841272,loc4371274);
++R.GAS;
return $ret12821283;
};
var $Hanf_arg19461289 = function(anf_arg12911288,anf_arg12861271,anf_fun12841272,loc4371274) {
var $z13061307 = D;
var $f13121313 = function(_) {
return R.isFunction(anf_fun12841272)?anf_fun12841272.app(loc4371274,anf_arg12861271,anf_arg12911288):R.ffi.throwNonFunApp(L[144],anf_fun12841272,[loc4371274,anf_arg12861271,anf_arg12911288]);
};
try {
if(--R.GAS > 0) {
$z13061307 = $f13121313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13121313,
"from":L[144]});
}
} catch($e13041305) {
if(R.isCont($e13041305)) {
var $ss13081309 = {"from":L[144],
"go":function(ann_DASH_check_DASH_temp12831314) {
return $Hann_DASH_check_DASH_temp19451315(ann_DASH_check_DASH_temp12831314);
}};
$e13041305.stack[R.EXN_STACKHEIGHT++] = $ss13081309;
}
if(R.isPyretException($e13041305)) {
$e13041305.pyretStack.push(L[144]);
}
throw $e13041305;
}
var $ret13101311 = $Hann_DASH_check_DASH_temp19451315($z13061307);
++R.GAS;
return $ret13101311;
};
var $Hann_DASH_check_DASH_temp19451315 = function(ann_DASH_check_DASH_temp12831314) {
return ann_DASH_check_DASH_temp12831314;
};
var $Hann_DASH_check_DASH_temp19441303 = function(ann_DASH_check_DASH_temp12881302) {
return ann_DASH_check_DASH_temp12881302;
};
var $Hlet_DASH_binds19431316 = function(let_DASH_binds4471317,A317,body4451318,l4401319) {
var anf_fun12801330 = G(A317,"s-let-expr",L[146]);
var $z13221323 = D;
var $f13281329 = function(_) {
return R.isFunction(anf_fun12801330)?anf_fun12801330.app(l4401319,let_DASH_binds4471317,body4451318):R.ffi.throwNonFunApp(L[145],anf_fun12801330,[l4401319,let_DASH_binds4471317,body4451318]);
};
try {
if(--R.GAS > 0) {
$z13221323 = $f13281329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13281329,
"from":L[145]});
}
} catch($e13201321) {
if(R.isCont($e13201321)) {
var $ss13241325 = {"from":L[145],
"go":function(ann_DASH_check_DASH_temp12721331) {
return $Hann_DASH_check_DASH_temp19421332(ann_DASH_check_DASH_temp12721331);
}};
$e13201321.stack[R.EXN_STACKHEIGHT++] = $ss13241325;
}
if(R.isPyretException($e13201321)) {
$e13201321.pyretStack.push(L[145]);
}
throw $e13201321;
}
var $ret13261327 = $Hann_DASH_check_DASH_temp19421332($z13221323);
++R.GAS;
return $ret13261327;
};
var $Hann_DASH_check_DASH_temp19421332 = function(ann_DASH_check_DASH_temp12721331) {
return ann_DASH_check_DASH_temp12721331;
};
var $Hanf_arg19411333 = function(anf_arg12781334,anf_arg12761335,anf_fun12751336,arg4481337) {
var $z13401341 = D;
var $f13461347 = function(_) {
return R.isFunction(anf_fun12751336)?anf_fun12751336.app(anf_arg12761335,arg4481337,anf_arg12781334):R.ffi.throwNonFunApp(L[147],anf_fun12751336,[anf_arg12761335,arg4481337,anf_arg12781334]);
};
try {
if(--R.GAS > 0) {
$z13401341 = $f13461347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13461347,
"from":L[147]});
}
} catch($e13381339) {
if(R.isCont($e13381339)) {
var $ss13421343 = {"from":L[147],
"go":function(ann_DASH_check_DASH_temp12741348) {
return $Hann_DASH_check_DASH_temp19401349(ann_DASH_check_DASH_temp12741348);
}};
$e13381339.stack[R.EXN_STACKHEIGHT++] = $ss13421343;
}
if(R.isPyretException($e13381339)) {
$e13381339.pyretStack.push(L[147]);
}
throw $e13381339;
}
var $ret13441345 = $Hann_DASH_check_DASH_temp19401349($z13401341);
++R.GAS;
return $ret13441345;
};
var $Hann_DASH_check_DASH_temp19401349 = function(ann_DASH_check_DASH_temp12741348) {
return ann_DASH_check_DASH_temp12741348;
};
var $Hvar_DASH_bind19391350 = function(var_DASH_bind19211351,A317,CS719,ast4261352,bind_DASH_exp12766,binding_DASH_env_DASH_iter_DASH_visitor40369,initial_DASH_env4251353,link35745,not9,nothing10) {
var errors4271368 = {"$var":var_DASH_bind19211351,
"$name":"errors"};
var add_DASH_error4281354 = {"$var":D,
"$name":"add-error"};
var anf_assign12371355 = R.makeFunction(function(err4291370) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[150],1,arguments);
}
var anf_fun12351381 = R.makeFunction(function(arg_DASH_1331384) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[151],1,arguments);
}
var $z13871388 = D;
var $f13931394 = function(_) {
return R.isFunction(link35745)?link35745.app(arg_DASH_1331384,errors4271368.$var):R.ffi.throwNonFunApp(L[151],link35745,[arg_DASH_1331384,errors4271368.$var]);
};
try {
if(--R.GAS > 0) {
$z13871388 = $f13931394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13931394,
"from":L[151]});
}
} catch($e13851386) {
if(R.isCont($e13851386)) {
var $ss13891390 = {"from":L[151],
"go":function(ann_DASH_check_DASH_temp12341395) {
return $Hann_DASH_check_DASH_temp19221396(ann_DASH_check_DASH_temp12341395);
}};
$e13851386.stack[R.EXN_STACKHEIGHT++] = $ss13891390;
}
if(R.isPyretException($e13851386)) {
$e13851386.pyretStack.push(L[151]);
}
throw $e13851386;
}
var $ret13911392 = $Hann_DASH_check_DASH_temp19221396($z13871388);
++R.GAS;
return $ret13911392;
});
var $z13731374 = D;
var $f13791380 = function(_) {
return R.isFunction(anf_fun12351381)?anf_fun12351381.app(err4291370):R.ffi.throwNonFunApp(L[151],anf_fun12351381,[err4291370]);
};
try {
if(--R.GAS > 0) {
$z13731374 = $f13791380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13791380,
"from":L[151]});
}
} catch($e13711372) {
if(R.isCont($e13711372)) {
var $ss13751376 = {"from":L[151],
"go":function(anf_assign12361382) {
return $Hanf_assign19231383(anf_assign12361382,errors4271368);
}};
$e13711372.stack[R.EXN_STACKHEIGHT++] = $ss13751376;
}
if(R.isPyretException($e13711372)) {
$e13711372.pyretStack.push(L[151]);
}
throw $e13711372;
}
var $ret13771378 = $Hanf_assign19231383($z13731374,errors4271368);
++R.GAS;
return $ret13771378;
});
add_DASH_error4281354.$var = anf_assign12371355;
var anf_fun12381367 = G(ast4261352,"visit",L[149]);
var $z13581359 = D;
var $f13641365 = function(_) {
return R.isFunction(binding_DASH_env_DASH_iter_DASH_visitor40369.$var)?binding_DASH_env_DASH_iter_DASH_visitor40369.$var.app(initial_DASH_env4251353):R.ffi.throwNonFunApp(L[148],binding_DASH_env_DASH_iter_DASH_visitor40369.$var,[initial_DASH_env4251353]);
};
try {
if(--R.GAS > 0) {
$z13581359 = $f13641365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13641365,
"from":L[148]});
}
} catch($e13561357) {
if(R.isCont($e13561357)) {
var $ss13601361 = {"from":L[148],
"go":function(anf_extend12391366) {
return $Hanf_extend19381369(anf_extend12391366,A317,CS719,add_DASH_error4281354,anf_fun12381367,bind_DASH_exp12766,errors4271368,not9,nothing10);
}};
$e13561357.stack[R.EXN_STACKHEIGHT++] = $ss13601361;
}
if(R.isPyretException($e13561357)) {
$e13561357.pyretStack.push(L[148]);
}
throw $e13561357;
}
var $ret13621363 = $Hanf_extend19381369($z13581359,A317,CS719,add_DASH_error4281354,anf_fun12381367,bind_DASH_exp12766,errors4271368,not9,nothing10);
++R.GAS;
return $ret13621363;
};
var $Hanf_extend19381369 = function(anf_extend12391366,A317,CS719,add_DASH_error4281354,anf_fun12381367,bind_DASH_exp12766,errors4271368,not9,nothing10) {
var anf_extend12661410 = R.makeMethod(function(self4301425) {
return function(loc4311422,id4321423,value4331426) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[155],3,arguments);
}
var anf_fun12411421 = G(A317,"s-id",L[154]);
var $z14131414 = D;
var $f14191420 = function(_) {
return R.isFunction(anf_fun12411421)?anf_fun12411421.app(loc4311422,id4321423):R.ffi.throwNonFunApp(L[153],anf_fun12411421,[loc4311422,id4321423]);
};
try {
if(--R.GAS > 0) {
$z14131414 = $f14191420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14191420,
"from":L[153]});
}
} catch($e14111412) {
if(R.isCont($e14111412)) {
var $ss14151416 = {"from":L[153],
"go":function(anf_arg12421424) {
return $Hanf_arg19351427(anf_arg12421424,CS719,add_DASH_error4281354,bind_DASH_exp12766,id4321423,loc4311422,self4301425,value4331426,not9,nothing10);
}};
$e14111412.stack[R.EXN_STACKHEIGHT++] = $ss14151416;
}
if(R.isPyretException($e14111412)) {
$e14111412.pyretStack.push(L[153]);
}
throw $e14111412;
}
var $ret14171418 = $Hanf_arg19351427($z14131414,CS719,add_DASH_error4281354,bind_DASH_exp12766,id4321423,loc4311422,self4301425,value4331426,not9,nothing10);
++R.GAS;
return $ret14171418;
};
},{"length":4});
var anf_arg12671407 = anf_extend12391366.extendWith({"s-assign":anf_extend12661410});
var $z13991400 = D;
var $f14051406 = function(_) {
return R.isFunction(anf_fun12381367)?anf_fun12381367.app(anf_arg12671407):R.ffi.throwNonFunApp(L[152],anf_fun12381367,[anf_arg12671407]);
};
try {
if(--R.GAS > 0) {
$z13991400 = $f14051406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14051406,
"from":L[152]});
}
} catch($e13971398) {
if(R.isCont($e13971398)) {
var $ss14011402 = {"from":L[152],
"go":function(anf_begin_app_dropped19361408) {
return $Hanf_begin_app_dropped19371409(anf_begin_app_dropped19361408,errors4271368);
}};
$e13971398.stack[R.EXN_STACKHEIGHT++] = $ss14011402;
}
if(R.isPyretException($e13971398)) {
$e13971398.pyretStack.push(L[152]);
}
throw $e13971398;
}
var $ret14031404 = $Hanf_begin_app_dropped19371409($z13991400,errors4271368);
++R.GAS;
return $ret14031404;
};
var $Hanf_begin_app_dropped19371409 = function(anf_begin_app_dropped19361408,errors4271368) {
var ann_DASH_check_DASH_temp12311428 = errors4271368.$var;
return ann_DASH_check_DASH_temp12311428;
};
var $Hanf_arg19351427 = function(anf_arg12421424,CS719,add_DASH_error4281354,bind_DASH_exp12766,id4321423,loc4311422,self4301425,value4331426,not9,nothing10) {
var anf_arg12431439 = G(self4301425,"env",L[157]);
var $z14311432 = D;
var $f14371438 = function(_) {
return R.isFunction(bind_DASH_exp12766.$var)?bind_DASH_exp12766.$var.app(anf_arg12421424,anf_arg12431439):R.ffi.throwNonFunApp(L[156],bind_DASH_exp12766.$var,[anf_arg12421424,anf_arg12431439]);
};
try {
if(--R.GAS > 0) {
$z14311432 = $f14371438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14371438,
"from":L[156]});
}
} catch($e14291430) {
if(R.isCont($e14291430)) {
var $ss14331434 = {"from":L[156],
"go":function(cases_DASH_val1351440) {
return $Hcases_DASH_val19341441(cases_DASH_val1351440,CS719,add_DASH_error4281354,id4321423,loc4311422,self4301425,value4331426,not9,nothing10);
}};
$e14291430.stack[R.EXN_STACKHEIGHT++] = $ss14331434;
}
if(R.isPyretException($e14291430)) {
$e14291430.pyretStack.push(L[156]);
}
throw $e14291430;
}
var $ret14351436 = $Hcases_DASH_val19341441($z14311432,CS719,add_DASH_error4281354,id4321423,loc4311422,self4301425,value4331426,not9,nothing10);
++R.GAS;
return $ret14351436;
};
var $Hcases_DASH_val19341441 = function(cases_DASH_val1351440,CS719,add_DASH_error4281354,id4321423,loc4311422,self4301425,value4331426,not9,nothing10) {
var anf_fun12441452 = G(cases_DASH_val1351440,"_match",L[156]);
var anf_obj12461458 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[161],0,arguments);
}
var ann_DASH_check_DASH_temp12451474 = nothing10;
return ann_DASH_check_DASH_temp12451474;
});
var anf_obj12611459 = R.makeFunction(function(b4341460) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[158],1,arguments);
}
var anf_arg12481471 = G(b4341460,"mut",L[160]);
var $z14631464 = D;
var $f14691470 = function(_) {
return R.isFunction(not9)?not9.app(anf_arg12481471):R.ffi.throwNonFunApp(L[159],not9,[anf_arg12481471]);
};
try {
if(--R.GAS > 0) {
$z14631464 = $f14691470();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14691470,
"from":L[159]});
}
} catch($e14611462) {
if(R.isCont($e14611462)) {
var $ss14651466 = {"from":L[159],
"go":function(when_DASH_1341472) {
return $Hwhen_DASH_19301473(when_DASH_1341472,CS719,add_DASH_error4281354,b4341460,id4321423,loc4311422,nothing10);
}};
$e14611462.stack[R.EXN_STACKHEIGHT++] = $ss14651466;
}
if(R.isPyretException($e14611462)) {
$e14611462.pyretStack.push(L[159]);
}
throw $e14611462;
}
var $ret14671468 = $Hwhen_DASH_19301473($z14631464,CS719,add_DASH_error4281354,b4341460,id4321423,loc4311422,nothing10);
++R.GAS;
return $ret14671468;
});
var anf_arg12621453 = R.makeObject({"none":anf_obj12461458,
"some":anf_obj12611459});
var anf_arg12641454 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[156],0,arguments);
}
var ann_DASH_check_DASH_temp12631457 = R.throwNoBranchesMatched(L[156],("cases"));
return ann_DASH_check_DASH_temp12631457;
});
var $z14441445 = D;
var $f14501451 = function(_) {
return R.isFunction(anf_fun12441452)?anf_fun12441452.app(anf_arg12621453,anf_arg12641454):R.ffi.throwNonFunApp(L[156],anf_fun12441452,[anf_arg12621453,anf_arg12641454]);
};
try {
if(--R.GAS > 0) {
$z14441445 = $f14501451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14501451,
"from":L[156]});
}
} catch($e14421443) {
if(R.isCont($e14421443)) {
var $ss14461447 = {"from":L[156],
"go":function(anf_begin_app_dropped19311455) {
return $Hanf_begin_app_dropped19331456(anf_begin_app_dropped19311455,self4301425,value4331426);
}};
$e14421443.stack[R.EXN_STACKHEIGHT++] = $ss14461447;
}
if(R.isPyretException($e14421443)) {
$e14421443.pyretStack.push(L[156]);
}
throw $e14421443;
}
var $ret14481449 = $Hanf_begin_app_dropped19331456($z14441445,self4301425,value4331426);
++R.GAS;
return $ret14481449;
};
var $Hanf_begin_app_dropped19331456 = function(anf_begin_app_dropped19311455,self4301425,value4331426) {
var anf_fun12651485 = G(value4331426,"visit",L[162]);
var $z14771478 = D;
var $f14831484 = function(_) {
return R.isFunction(anf_fun12651485)?anf_fun12651485.app(self4301425):R.ffi.throwNonFunApp(L[155],anf_fun12651485,[self4301425]);
};
try {
if(--R.GAS > 0) {
$z14771478 = $f14831484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14831484,
"from":L[155]});
}
} catch($e14751476) {
if(R.isCont($e14751476)) {
var $ss14791480 = {"from":L[155],
"go":function(ann_DASH_check_DASH_temp12401486) {
return $Hann_DASH_check_DASH_temp19321487(ann_DASH_check_DASH_temp12401486);
}};
$e14751476.stack[R.EXN_STACKHEIGHT++] = $ss14791480;
}
if(R.isPyretException($e14751476)) {
$e14751476.pyretStack.push(L[155]);
}
throw $e14751476;
}
var $ret14811482 = $Hann_DASH_check_DASH_temp19321487($z14771478);
++R.GAS;
return $ret14811482;
};
var $Hann_DASH_check_DASH_temp19321487 = function(ann_DASH_check_DASH_temp12401486) {
return ann_DASH_check_DASH_temp12401486;
};
var $Hwhen_DASH_19301473 = function(when_DASH_1341472,CS719,add_DASH_error4281354,b4341460,id4321423,loc4311422,nothing10) {
var if_helper12491501 = R.makeFunction(function(if_helper_arg12501519) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[159],1,arguments);
}
var ann_DASH_check_DASH_temp12471520 = if_helper_arg12501519;
return ann_DASH_check_DASH_temp12471520;
});
var anf_if12531518 = R.isBoolean(when_DASH_1341472);
if(R.isPyretTrue(anf_if12531518)) {
if(R.isPyretTrue(when_DASH_1341472)) {
var anf_fun12551500 = G(CS719,"bad-assignment",L[165]);
var anf_fun12561498 = G(id4321423,"toname",L[164]);
var $z14901491 = D;
var $f14961497 = function(_) {
return R.isFunction(anf_fun12561498)?anf_fun12561498.app():R.ffi.throwNonFunApp(L[163],anf_fun12561498,[]);
};
try {
if(--R.GAS > 0) {
$z14901491 = $f14961497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14961497,
"from":L[163]});
}
} catch($e14881489) {
if(R.isCont($e14881489)) {
var $ss14921493 = {"from":L[163],
"go":function(anf_arg12571499) {
return $Hanf_arg19281502(anf_arg12571499,add_DASH_error4281354,anf_fun12551500,b4341460,if_helper12491501,loc4311422,nothing10);
}};
$e14881489.stack[R.EXN_STACKHEIGHT++] = $ss14921493;
}
if(R.isPyretException($e14881489)) {
$e14881489.pyretStack.push(L[163]);
}
throw $e14881489;
}
var $ret14941495 = $Hanf_arg19281502($z14901491,add_DASH_error4281354,anf_fun12551500,b4341460,if_helper12491501,loc4311422,nothing10);
++R.GAS;
return $ret14941495;
} else {
var $z15051506 = D;
var $f15111512 = function(_) {
return R.isFunction(if_helper12491501)?if_helper12491501.app(nothing10):R.ffi.throwNonFunApp(L[159],if_helper12491501,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z15051506 = $f15111512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15111512,
"from":L[159]});
}
} catch($e15031504) {
if(R.isCont($e15031504)) {
var $ss15071508 = {"from":L[159],
"go":function(cont_tail_app12541513) {
return $Hcont_tail_app19291514(cont_tail_app12541513);
}};
$e15031504.stack[R.EXN_STACKHEIGHT++] = $ss15071508;
}
if(R.isPyretException($e15031504)) {
$e15031504.pyretStack.push(L[159]);
}
throw $e15031504;
}
var $ret15091510 = $Hcont_tail_app19291514($z15051506);
++R.GAS;
return $ret15091510;
}
} else {
var cont_tail_arg12511517 = R.throwNonBooleanCondition(L[166],("when"),when_DASH_1341472);
if(--R.GAS > 0) {
$z15151516 = R.isFunction(if_helper12491501)?if_helper12491501.app(cont_tail_arg12511517):R.ffi.throwNonFunApp(L[166],if_helper12491501,[cont_tail_arg12511517]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper12491501)?if_helper12491501.app(cont_tail_arg12511517):R.ffi.throwNonFunApp(L[166],if_helper12491501,[cont_tail_arg12511517]);
},
"from":L[166]});
}
++R.GAS;
return $z15151516;
}
};
var $Hanf_arg19281502 = function(anf_arg12571499,add_DASH_error4281354,anf_fun12551500,b4341460,if_helper12491501,loc4311422,nothing10) {
var anf_arg12581531 = G(b4341460,"loc",L[168]);
var $z15231524 = D;
var $f15291530 = function(_) {
return R.isFunction(anf_fun12551500)?anf_fun12551500.app(anf_arg12571499,loc4311422,anf_arg12581531):R.ffi.throwNonFunApp(L[167],anf_fun12551500,[anf_arg12571499,loc4311422,anf_arg12581531]);
};
try {
if(--R.GAS > 0) {
$z15231524 = $f15291530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15291530,
"from":L[167]});
}
} catch($e15211522) {
if(R.isCont($e15211522)) {
var $ss15251526 = {"from":L[167],
"go":function(anf_arg12591532) {
return $Hanf_arg19271533(anf_arg12591532,add_DASH_error4281354,if_helper12491501,nothing10);
}};
$e15211522.stack[R.EXN_STACKHEIGHT++] = $ss15251526;
}
if(R.isPyretException($e15211522)) {
$e15211522.pyretStack.push(L[167]);
}
throw $e15211522;
}
var $ret15271528 = $Hanf_arg19271533($z15231524,add_DASH_error4281354,if_helper12491501,nothing10);
++R.GAS;
return $ret15271528;
};
var $Hanf_arg19271533 = function(anf_arg12591532,add_DASH_error4281354,if_helper12491501,nothing10) {
var $z15361537 = D;
var $f15421543 = function(_) {
return R.isFunction(add_DASH_error4281354.$var)?add_DASH_error4281354.$var.app(anf_arg12591532):R.ffi.throwNonFunApp(L[169],add_DASH_error4281354.$var,[anf_arg12591532]);
};
try {
if(--R.GAS > 0) {
$z15361537 = $f15421543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15421543,
"from":L[169]});
}
} catch($e15341535) {
if(R.isCont($e15341535)) {
var $ss15381539 = {"from":L[169],
"go":function(anf_begin_app_dropped19241544) {
return $Hanf_begin_app_dropped19261545(anf_begin_app_dropped19241544,if_helper12491501,nothing10);
}};
$e15341535.stack[R.EXN_STACKHEIGHT++] = $ss15381539;
}
if(R.isPyretException($e15341535)) {
$e15341535.pyretStack.push(L[169]);
}
throw $e15341535;
}
var $ret15401541 = $Hanf_begin_app_dropped19261545($z15361537,if_helper12491501,nothing10);
++R.GAS;
return $ret15401541;
};
var $Hanf_begin_app_dropped19261545 = function(anf_begin_app_dropped19241544,if_helper12491501,nothing10) {
var $z15481549 = D;
var $f15541555 = function(_) {
return R.isFunction(if_helper12491501)?if_helper12491501.app(nothing10):R.ffi.throwNonFunApp(L[159],if_helper12491501,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z15481549 = $f15541555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15541555,
"from":L[159]});
}
} catch($e15461547) {
if(R.isCont($e15461547)) {
var $ss15501551 = {"from":L[159],
"go":function(cont_tail_app12601556) {
return $Hcont_tail_app19251557(cont_tail_app12601556);
}};
$e15461547.stack[R.EXN_STACKHEIGHT++] = $ss15501551;
}
if(R.isPyretException($e15461547)) {
$e15461547.pyretStack.push(L[159]);
}
throw $e15461547;
}
var $ret15521553 = $Hcont_tail_app19251557($z15481549);
++R.GAS;
return $ret15521553;
};
var $Hcont_tail_app19251557 = function(cont_tail_app12601556) {
return cont_tail_app12601556;
};
var $Hcont_tail_app19291514 = function(cont_tail_app12541513) {
return cont_tail_app12541513;
};
var $Hanf_assign19231383 = function(anf_assign12361382,errors4271368) {
var ann_DASH_check_DASH_temp12331558 = errors4271368.$var = anf_assign12361382;
return ann_DASH_check_DASH_temp12331558;
};
var $Hann_DASH_check_DASH_temp19221396 = function(ann_DASH_check_DASH_temp12341395) {
return ann_DASH_check_DASH_temp12341395;
};
var $Hanf_extend19201559 = function(anf_extend10591560,A317,bind_DASH_or_DASH_unknown12867,list3192) {
var anf_extend12291562 = R.makeMethod(function(self4091578) {
return function(l4101577,f4111574,args4121576) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[172],3,arguments);
}
var anf_fun10611573 = G(A317,"is-s-dot",L[171]);
var $z15651566 = D;
var $f15711572 = function(_) {
return R.isFunction(anf_fun10611573)?anf_fun10611573.app(f4111574):R.ffi.throwNonFunApp(L[170],anf_fun10611573,[f4111574]);
};
try {
if(--R.GAS > 0) {
$z15651566 = $f15711572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15711572,
"from":L[170]});
}
} catch($e15631564) {
if(R.isCont($e15631564)) {
var $ss15671568 = {"from":L[170],
"go":function(and_DASH_oper_DASH_1161575) {
return $Hand_DASH_oper_DASH_19191579(and_DASH_oper_DASH_1161575,A317,args4121576,bind_DASH_or_DASH_unknown12867,f4111574,l4101577,list3192,self4091578);
}};
$e15631564.stack[R.EXN_STACKHEIGHT++] = $ss15671568;
}
if(R.isPyretException($e15631564)) {
$e15631564.pyretStack.push(L[170]);
}
throw $e15631564;
}
var $ret15691570 = $Hand_DASH_oper_DASH_19191579($z15651566,A317,args4121576,bind_DASH_or_DASH_unknown12867,f4111574,l4101577,list3192,self4091578);
++R.GAS;
return $ret15691570;
};
},{"length":4});
var ann_DASH_check_DASH_temp10581561 = anf_extend10591560.extendWith({"s-app":anf_extend12291562});
return ann_DASH_check_DASH_temp10581561;
};
var $Hand_DASH_oper_DASH_19191579 = function(and_DASH_oper_DASH_1161575,A317,args4121576,bind_DASH_or_DASH_unknown12867,f4111574,l4101577,list3192,self4091578) {
var if_helper10621590 = R.makeFunction(function(if_helper_arg10631615) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[170],1,arguments);
}
var if_DASH_1151712 = if_helper_arg10631615;
var if_helper10641630 = R.makeFunction(function(if_helper_arg10651717) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[170],1,arguments);
}
var ann_DASH_check_DASH_temp10601718 = if_helper_arg10651717;
return ann_DASH_check_DASH_temp10601718;
});
var anf_if10681716 = R.isBoolean(if_DASH_1151712);
if(R.isPyretTrue(anf_if10681716)) {
if(R.isPyretTrue(if_DASH_1151712)) {
var target4131662 = G(f4111574,"obj",L[189]);
var cases_DASH_val1321697 = target4131662;
var anf_fun10791626 = G(cases_DASH_val1321697,"_match",L[176]);
var anf_obj11341646 = R.makeFunction(function(l24141681,lnk4151682,_args4161683) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[186],3,arguments);
}
var anf_arg10811694 = G(self4091578,"env",L[188]);
var $z16861687 = D;
var $f16921693 = function(_) {
return R.isFunction(bind_DASH_or_DASH_unknown12867.$var)?bind_DASH_or_DASH_unknown12867.$var.app(lnk4151682,anf_arg10811694):R.ffi.throwNonFunApp(L[187],bind_DASH_or_DASH_unknown12867.$var,[lnk4151682,anf_arg10811694]);
};
try {
if(--R.GAS > 0) {
$z16861687 = $f16921693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16921693,
"from":L[187]});
}
} catch($e16841685) {
if(R.isCont($e16841685)) {
var $ss16881689 = {"from":L[187],
"go":function(cases_DASH_val1221695) {
return $Hcases_DASH_val18851696(cases_DASH_val1221695,A317,_args4161683,args4121576,f4111574,l24141681,l4101577,list3192,lnk4151682,self4091578);
}};
$e16841685.stack[R.EXN_STACKHEIGHT++] = $ss16881689;
}
if(R.isPyretException($e16841685)) {
$e16841685.pyretStack.push(L[187]);
}
throw $e16841685;
}
var $ret16901691 = $Hcases_DASH_val18851696($z16861687,A317,_args4161683,args4121576,f4111574,l24141681,l4101577,list3192,lnk4151682,self4091578);
++R.GAS;
return $ret16901691;
});
var anf_obj11701647 = R.makeFunction(function($underscore4181666,$underscore4191667) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[183],2,arguments);
}
var anf_arg11361678 = G(self4091578,"env",L[185]);
var $z16701671 = D;
var $f16761677 = function(_) {
return R.isFunction(bind_DASH_or_DASH_unknown12867.$var)?bind_DASH_or_DASH_unknown12867.$var.app(target4131662,anf_arg11361678):R.ffi.throwNonFunApp(L[184],bind_DASH_or_DASH_unknown12867.$var,[target4131662,anf_arg11361678]);
};
try {
if(--R.GAS > 0) {
$z16701671 = $f16761677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16761677,
"from":L[184]});
}
} catch($e16681669) {
if(R.isCont($e16681669)) {
var $ss16721673 = {"from":L[184],
"go":function(cases_DASH_val1261679) {
return $Hcases_DASH_val18961680(cases_DASH_val1261679,A317,args4121576,f4111574,l4101577,self4091578);
}};
$e16681669.stack[R.EXN_STACKHEIGHT++] = $ss16721673;
}
if(R.isPyretException($e16681669)) {
$e16681669.pyretStack.push(L[184]);
}
throw $e16681669;
}
var $ret16741675 = $Hcases_DASH_val18961680($z16701671,A317,args4121576,f4111574,l4101577,self4091578);
++R.GAS;
return $ret16741675;
});
var anf_obj12061648 = R.makeFunction(function($underscore4211649,$underscore4221650,$underscore4231651) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[180],3,arguments);
}
var anf_arg11721663 = G(self4091578,"env",L[182]);
var $z16541655 = D;
var $f16601661 = function(_) {
return R.isFunction(bind_DASH_or_DASH_unknown12867.$var)?bind_DASH_or_DASH_unknown12867.$var.app(target4131662,anf_arg11721663):R.ffi.throwNonFunApp(L[181],bind_DASH_or_DASH_unknown12867.$var,[target4131662,anf_arg11721663]);
};
try {
if(--R.GAS > 0) {
$z16541655 = $f16601661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16601661,
"from":L[181]});
}
} catch($e16521653) {
if(R.isCont($e16521653)) {
var $ss16561657 = {"from":L[181],
"go":function(cases_DASH_val1301664) {
return $Hcases_DASH_val19071665(cases_DASH_val1301664,A317,args4121576,f4111574,l4101577,self4091578);
}};
$e16521653.stack[R.EXN_STACKHEIGHT++] = $ss16561657;
}
if(R.isPyretException($e16521653)) {
$e16521653.pyretStack.push(L[181]);
}
throw $e16521653;
}
var $ret16581659 = $Hcases_DASH_val19071665($z16541655,A317,args4121576,f4111574,l4101577,self4091578);
++R.GAS;
return $ret16581659;
});
var anf_arg12071627 = R.makeObject({"s-app":anf_obj11341646,
"s-id":anf_obj11701647,
"s-dot":anf_obj12061648});
var anf_arg12171628 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[176],0,arguments);
}
var anf_fun12091644 = G(A317,"s-app",L[179]);
var anf_fun12101642 = G(f4111574,"visit",L[178]);
var $z16341635 = D;
var $f16401641 = function(_) {
return R.isFunction(anf_fun12101642)?anf_fun12101642.app(self4091578):R.ffi.throwNonFunApp(L[177],anf_fun12101642,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z16341635 = $f16401641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16401641,
"from":L[177]});
}
} catch($e16321633) {
if(R.isCont($e16321633)) {
var $ss16361637 = {"from":L[177],
"go":function(anf_arg12111643) {
return $Hanf_arg19111645(anf_arg12111643,anf_fun12091644,args4121576,l4101577,self4091578);
}};
$e16321633.stack[R.EXN_STACKHEIGHT++] = $ss16361637;
}
if(R.isPyretException($e16321633)) {
$e16321633.pyretStack.push(L[177]);
}
throw $e16321633;
}
var $ret16381639 = $Hanf_arg19111645($z16341635,anf_fun12091644,args4121576,l4101577,self4091578);
++R.GAS;
return $ret16381639;
});
var $z16181619 = D;
var $f16241625 = function(_) {
return R.isFunction(anf_fun10791626)?anf_fun10791626.app(anf_arg12071627,anf_arg12171628):R.ffi.throwNonFunApp(L[176],anf_fun10791626,[anf_arg12071627,anf_arg12171628]);
};
try {
if(--R.GAS > 0) {
$z16181619 = $f16241625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16241625,
"from":L[176]});
}
} catch($e16161617) {
if(R.isCont($e16161617)) {
var $ss16201621 = {"from":L[176],
"go":function(cont_tail_arg12181629) {
return $Hcont_tail_arg19121631(cont_tail_arg12181629,if_helper10641630);
}};
$e16161617.stack[R.EXN_STACKHEIGHT++] = $ss16201621;
}
if(R.isPyretException($e16161617)) {
$e16161617.pyretStack.push(L[176]);
}
throw $e16161617;
}
var $ret16221623 = $Hcont_tail_arg19121631($z16181619,if_helper10641630);
++R.GAS;
return $ret16221623;
} else {
var anf_fun10691710 = G(A317,"s-app",L[192]);
var anf_fun10701708 = G(f4111574,"visit",L[191]);
var $z17001701 = D;
var $f17061707 = function(_) {
return R.isFunction(anf_fun10701708)?anf_fun10701708.app(self4091578):R.ffi.throwNonFunApp(L[190],anf_fun10701708,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z17001701 = $f17061707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17061707,
"from":L[190]});
}
} catch($e16981699) {
if(R.isCont($e16981699)) {
var $ss17021703 = {"from":L[190],
"go":function(anf_arg10711709) {
return $Hanf_arg19161711(anf_arg10711709,anf_fun10691710,args4121576,if_helper10641630,l4101577,self4091578);
}};
$e16981699.stack[R.EXN_STACKHEIGHT++] = $ss17021703;
}
if(R.isPyretException($e16981699)) {
$e16981699.pyretStack.push(L[190]);
}
throw $e16981699;
}
var $ret17041705 = $Hanf_arg19161711($z17001701,anf_fun10691710,args4121576,if_helper10641630,l4101577,self4091578);
++R.GAS;
return $ret17041705;
}
} else {
var cont_tail_arg10661715 = R.throwNonBooleanCondition(L[170],("if"),if_DASH_1151712);
if(--R.GAS > 0) {
$z17131714 = R.isFunction(if_helper10641630)?if_helper10641630.app(cont_tail_arg10661715):R.ffi.throwNonFunApp(L[170],if_helper10641630,[cont_tail_arg10661715]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10641630)?if_helper10641630.app(cont_tail_arg10661715):R.ffi.throwNonFunApp(L[170],if_helper10641630,[cont_tail_arg10661715]);
},
"from":L[170]});
}
++R.GAS;
return $z17131714;
}
});
var anf_if12221614 = R.isBoolean(and_DASH_oper_DASH_1161575);
if(R.isPyretTrue(anf_if12221614)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1161575)) {
var anf_arg12241598 = G(f4111574,"field",L[174]);
var and_DASH_oper_DASH_1171591 = R.equiv(anf_arg12241598,("_plus"));
var anf_if12271597 = R.isBoolean(and_DASH_oper_DASH_1171591);
if(R.isPyretTrue(anf_if12271597)) {
var $z15821583 = D;
var $f15881589 = function(_) {
return R.isFunction(if_helper10621590)?if_helper10621590.app(and_DASH_oper_DASH_1171591):R.ffi.throwNonFunApp(L[170],if_helper10621590,[and_DASH_oper_DASH_1171591]);
};
try {
if(--R.GAS > 0) {
$z15821583 = $f15881589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15881589,
"from":L[170]});
}
} catch($e15801581) {
if(R.isCont($e15801581)) {
var $ss15841585 = {"from":L[170],
"go":function(cont_tail_app12281592) {
return $Hcont_tail_app19171593(cont_tail_app12281592);
}};
$e15801581.stack[R.EXN_STACKHEIGHT++] = $ss15841585;
}
if(R.isPyretException($e15801581)) {
$e15801581.pyretStack.push(L[170]);
}
throw $e15801581;
}
var $ret15861587 = $Hcont_tail_app19171593($z15821583);
++R.GAS;
return $ret15861587;
} else {
var cont_tail_arg12251596 = R.throwNonBooleanOp(L[173],("second"),("and"),and_DASH_oper_DASH_1171591);
if(--R.GAS > 0) {
$z15941595 = R.isFunction(if_helper10621590)?if_helper10621590.app(cont_tail_arg12251596):R.ffi.throwNonFunApp(L[173],if_helper10621590,[cont_tail_arg12251596]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10621590)?if_helper10621590.app(cont_tail_arg12251596):R.ffi.throwNonFunApp(L[173],if_helper10621590,[cont_tail_arg12251596]);
},
"from":L[173]});
}
++R.GAS;
return $z15941595;
}
} else {
var $z16011602 = D;
var $f16071608 = function(_) {
return R.isFunction(if_helper10621590)?if_helper10621590.app((false)):R.ffi.throwNonFunApp(L[170],if_helper10621590,[(false)]);
};
try {
if(--R.GAS > 0) {
$z16011602 = $f16071608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16071608,
"from":L[170]});
}
} catch($e15991600) {
if(R.isCont($e15991600)) {
var $ss16031604 = {"from":L[170],
"go":function(cont_tail_app12231609) {
return $Hcont_tail_app19181610(cont_tail_app12231609);
}};
$e15991600.stack[R.EXN_STACKHEIGHT++] = $ss16031604;
}
if(R.isPyretException($e15991600)) {
$e15991600.pyretStack.push(L[170]);
}
throw $e15991600;
}
var $ret16051606 = $Hcont_tail_app19181610($z16011602);
++R.GAS;
return $ret16051606;
}
} else {
var cont_tail_arg12201613 = R.throwNonBooleanOp(L[175],("first"),("and"),and_DASH_oper_DASH_1161575);
if(--R.GAS > 0) {
$z16111612 = R.isFunction(if_helper10621590)?if_helper10621590.app(cont_tail_arg12201613):R.ffi.throwNonFunApp(L[175],if_helper10621590,[cont_tail_arg12201613]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10621590)?if_helper10621590.app(cont_tail_arg12201613):R.ffi.throwNonFunApp(L[175],if_helper10621590,[cont_tail_arg12201613]);
},
"from":L[175]});
}
++R.GAS;
return $z16111612;
}
};
var $Hcont_tail_app19171593 = function(cont_tail_app12281592) {
return cont_tail_app12281592;
};
var $Hcont_tail_app19181610 = function(cont_tail_app12231609) {
return cont_tail_app12231609;
};
var $Hcont_tail_arg19121631 = function(cont_tail_arg12181629,if_helper10641630) {
if(--R.GAS > 0) {
$z17191720 = R.isFunction(if_helper10641630)?if_helper10641630.app(cont_tail_arg12181629):R.ffi.throwNonFunApp(L[176],if_helper10641630,[cont_tail_arg12181629]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10641630)?if_helper10641630.app(cont_tail_arg12181629):R.ffi.throwNonFunApp(L[176],if_helper10641630,[cont_tail_arg12181629]);
},
"from":L[176]});
}
++R.GAS;
return $z17191720;
};
var $Hanf_arg19111645 = function(anf_arg12111643,anf_fun12091644,args4121576,l4101577,self4091578) {
var anf_fun12121731 = G(args4121576,"map",L[195]);
var anf_arg12151732 = R.makeFunction(function(recv_DASH_1311735) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[194],1,arguments);
}
var anf_fun12141746 = G(recv_DASH_1311735,"visit",L[194]);
var $z17381739 = D;
var $f17441745 = function(_) {
return R.isFunction(anf_fun12141746)?anf_fun12141746.app(self4091578):R.ffi.throwNonFunApp(L[194],anf_fun12141746,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z17381739 = $f17441745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17441745,
"from":L[194]});
}
} catch($e17361737) {
if(R.isCont($e17361737)) {
var $ss17401741 = {"from":L[194],
"go":function(ann_DASH_check_DASH_temp12131747) {
return $Hann_DASH_check_DASH_temp19081748(ann_DASH_check_DASH_temp12131747);
}};
$e17361737.stack[R.EXN_STACKHEIGHT++] = $ss17401741;
}
if(R.isPyretException($e17361737)) {
$e17361737.pyretStack.push(L[194]);
}
throw $e17361737;
}
var $ret17421743 = $Hann_DASH_check_DASH_temp19081748($z17381739);
++R.GAS;
return $ret17421743;
});
var $z17231724 = D;
var $f17291730 = function(_) {
return R.isFunction(anf_fun12121731)?anf_fun12121731.app(anf_arg12151732):R.ffi.throwNonFunApp(L[193],anf_fun12121731,[anf_arg12151732]);
};
try {
if(--R.GAS > 0) {
$z17231724 = $f17291730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17291730,
"from":L[193]});
}
} catch($e17211722) {
if(R.isCont($e17211722)) {
var $ss17251726 = {"from":L[193],
"go":function(anf_arg12161733) {
return $Hanf_arg19101734(anf_arg12161733,anf_arg12111643,anf_fun12091644,l4101577);
}};
$e17211722.stack[R.EXN_STACKHEIGHT++] = $ss17251726;
}
if(R.isPyretException($e17211722)) {
$e17211722.pyretStack.push(L[193]);
}
throw $e17211722;
}
var $ret17271728 = $Hanf_arg19101734($z17231724,anf_arg12111643,anf_fun12091644,l4101577);
++R.GAS;
return $ret17271728;
};
var $Hanf_arg19101734 = function(anf_arg12161733,anf_arg12111643,anf_fun12091644,l4101577) {
var $z17511752 = D;
var $f17571758 = function(_) {
return R.isFunction(anf_fun12091644)?anf_fun12091644.app(l4101577,anf_arg12111643,anf_arg12161733):R.ffi.throwNonFunApp(L[176],anf_fun12091644,[l4101577,anf_arg12111643,anf_arg12161733]);
};
try {
if(--R.GAS > 0) {
$z17511752 = $f17571758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17571758,
"from":L[176]});
}
} catch($e17491750) {
if(R.isCont($e17491750)) {
var $ss17531754 = {"from":L[176],
"go":function(ann_DASH_check_DASH_temp12081759) {
return $Hann_DASH_check_DASH_temp19091760(ann_DASH_check_DASH_temp12081759);
}};
$e17491750.stack[R.EXN_STACKHEIGHT++] = $ss17531754;
}
if(R.isPyretException($e17491750)) {
$e17491750.pyretStack.push(L[176]);
}
throw $e17491750;
}
var $ret17551756 = $Hann_DASH_check_DASH_temp19091760($z17511752);
++R.GAS;
return $ret17551756;
};
var $Hann_DASH_check_DASH_temp19091760 = function(ann_DASH_check_DASH_temp12081759) {
return ann_DASH_check_DASH_temp12081759;
};
var $Hann_DASH_check_DASH_temp19081748 = function(ann_DASH_check_DASH_temp12131747) {
return ann_DASH_check_DASH_temp12131747;
};
var $Hcases_DASH_val19071665 = function(cases_DASH_val1301664,A317,args4121576,f4111574,l4101577,self4091578) {
var anf_fun11731771 = G(cases_DASH_val1301664,"_match",L[181]);
var anf_obj11941790 = R.makeFunction(function(name4241791) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[199],1,arguments);
}
var if_DASH_1281821 = R.equiv(name4241791,("list:empty"));
var if_helper11751804 = R.makeFunction(function(if_helper_arg11761826) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[206],1,arguments);
}
var ann_DASH_check_DASH_temp11741827 = if_helper_arg11761826;
return ann_DASH_check_DASH_temp11741827;
});
var anf_if11791825 = R.isBoolean(if_DASH_1281821);
if(R.isPyretTrue(anf_if11791825)) {
if(R.isPyretTrue(if_DASH_1281821)) {
var anf_bracket11901806 = G(args4121576,"first",L[202]);
var anf_fun11911802 = G(anf_bracket11901806,"visit",L[201]);
var $z17941795 = D;
var $f18001801 = function(_) {
return R.isFunction(anf_fun11911802)?anf_fun11911802.app(self4091578):R.ffi.throwNonFunApp(L[200],anf_fun11911802,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z17941795 = $f18001801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18001801,
"from":L[200]});
}
} catch($e17921793) {
if(R.isCont($e17921793)) {
var $ss17961797 = {"from":L[200],
"go":function(cont_tail_arg11921803) {
return $Hcont_tail_arg18971805(cont_tail_arg11921803,if_helper11751804);
}};
$e17921793.stack[R.EXN_STACKHEIGHT++] = $ss17961797;
}
if(R.isPyretException($e17921793)) {
$e17921793.pyretStack.push(L[200]);
}
throw $e17921793;
}
var $ret17981799 = $Hcont_tail_arg18971805($z17941795,if_helper11751804);
++R.GAS;
return $ret17981799;
} else {
var anf_fun11801819 = G(A317,"s-app",L[205]);
var anf_fun11811817 = G(f4111574,"visit",L[204]);
var $z18091810 = D;
var $f18151816 = function(_) {
return R.isFunction(anf_fun11811817)?anf_fun11811817.app(self4091578):R.ffi.throwNonFunApp(L[203],anf_fun11811817,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z18091810 = $f18151816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18151816,
"from":L[203]});
}
} catch($e18071808) {
if(R.isCont($e18071808)) {
var $ss18111812 = {"from":L[203],
"go":function(anf_arg11821818) {
return $Hanf_arg19011820(anf_arg11821818,anf_fun11801819,args4121576,if_helper11751804,l4101577,self4091578);
}};
$e18071808.stack[R.EXN_STACKHEIGHT++] = $ss18111812;
}
if(R.isPyretException($e18071808)) {
$e18071808.pyretStack.push(L[203]);
}
throw $e18071808;
}
var $ret18131814 = $Hanf_arg19011820($z18091810,anf_fun11801819,args4121576,if_helper11751804,l4101577,self4091578);
++R.GAS;
return $ret18131814;
}
} else {
var cont_tail_arg11771824 = R.throwNonBooleanCondition(L[206],("if"),if_DASH_1281821);
if(--R.GAS > 0) {
$z18221823 = R.isFunction(if_helper11751804)?if_helper11751804.app(cont_tail_arg11771824):R.ffi.throwNonFunApp(L[206],if_helper11751804,[cont_tail_arg11771824]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper11751804)?if_helper11751804.app(cont_tail_arg11771824):R.ffi.throwNonFunApp(L[206],if_helper11751804,[cont_tail_arg11771824]);
},
"from":L[206]});
}
++R.GAS;
return $z18221823;
}
});
var anf_arg11951772 = R.makeObject({"b-prim":anf_obj11941790});
var anf_arg12051773 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[181],0,arguments);
}
var anf_fun11971788 = G(A317,"s-app",L[198]);
var anf_fun11981786 = G(f4111574,"visit",L[197]);
var $z17781779 = D;
var $f17841785 = function(_) {
return R.isFunction(anf_fun11981786)?anf_fun11981786.app(self4091578):R.ffi.throwNonFunApp(L[196],anf_fun11981786,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z17781779 = $f17841785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17841785,
"from":L[196]});
}
} catch($e17761777) {
if(R.isCont($e17761777)) {
var $ss17801781 = {"from":L[196],
"go":function(anf_arg11991787) {
return $Hanf_arg19051789(anf_arg11991787,anf_fun11971788,args4121576,l4101577,self4091578);
}};
$e17761777.stack[R.EXN_STACKHEIGHT++] = $ss17801781;
}
if(R.isPyretException($e17761777)) {
$e17761777.pyretStack.push(L[196]);
}
throw $e17761777;
}
var $ret17821783 = $Hanf_arg19051789($z17781779,anf_fun11971788,args4121576,l4101577,self4091578);
++R.GAS;
return $ret17821783;
});
var $z17631764 = D;
var $f17691770 = function(_) {
return R.isFunction(anf_fun11731771)?anf_fun11731771.app(anf_arg11951772,anf_arg12051773):R.ffi.throwNonFunApp(L[180],anf_fun11731771,[anf_arg11951772,anf_arg12051773]);
};
try {
if(--R.GAS > 0) {
$z17631764 = $f17691770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17691770,
"from":L[180]});
}
} catch($e17611762) {
if(R.isCont($e17611762)) {
var $ss17651766 = {"from":L[180],
"go":function(ann_DASH_check_DASH_temp11711774) {
return $Hann_DASH_check_DASH_temp19061775(ann_DASH_check_DASH_temp11711774);
}};
$e17611762.stack[R.EXN_STACKHEIGHT++] = $ss17651766;
}
if(R.isPyretException($e17611762)) {
$e17611762.pyretStack.push(L[180]);
}
throw $e17611762;
}
var $ret17671768 = $Hann_DASH_check_DASH_temp19061775($z17631764);
++R.GAS;
return $ret17671768;
};
var $Hann_DASH_check_DASH_temp19061775 = function(ann_DASH_check_DASH_temp11711774) {
return ann_DASH_check_DASH_temp11711774;
};
var $Hanf_arg19051789 = function(anf_arg11991787,anf_fun11971788,args4121576,l4101577,self4091578) {
var anf_fun12001838 = G(args4121576,"map",L[209]);
var anf_arg12031839 = R.makeFunction(function(recv_DASH_1291842) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[208],1,arguments);
}
var anf_fun12021853 = G(recv_DASH_1291842,"visit",L[208]);
var $z18451846 = D;
var $f18511852 = function(_) {
return R.isFunction(anf_fun12021853)?anf_fun12021853.app(self4091578):R.ffi.throwNonFunApp(L[208],anf_fun12021853,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z18451846 = $f18511852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18511852,
"from":L[208]});
}
} catch($e18431844) {
if(R.isCont($e18431844)) {
var $ss18471848 = {"from":L[208],
"go":function(ann_DASH_check_DASH_temp12011854) {
return $Hann_DASH_check_DASH_temp19021855(ann_DASH_check_DASH_temp12011854);
}};
$e18431844.stack[R.EXN_STACKHEIGHT++] = $ss18471848;
}
if(R.isPyretException($e18431844)) {
$e18431844.pyretStack.push(L[208]);
}
throw $e18431844;
}
var $ret18491850 = $Hann_DASH_check_DASH_temp19021855($z18451846);
++R.GAS;
return $ret18491850;
});
var $z18301831 = D;
var $f18361837 = function(_) {
return R.isFunction(anf_fun12001838)?anf_fun12001838.app(anf_arg12031839):R.ffi.throwNonFunApp(L[207],anf_fun12001838,[anf_arg12031839]);
};
try {
if(--R.GAS > 0) {
$z18301831 = $f18361837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18361837,
"from":L[207]});
}
} catch($e18281829) {
if(R.isCont($e18281829)) {
var $ss18321833 = {"from":L[207],
"go":function(anf_arg12041840) {
return $Hanf_arg19041841(anf_arg12041840,anf_arg11991787,anf_fun11971788,l4101577);
}};
$e18281829.stack[R.EXN_STACKHEIGHT++] = $ss18321833;
}
if(R.isPyretException($e18281829)) {
$e18281829.pyretStack.push(L[207]);
}
throw $e18281829;
}
var $ret18341835 = $Hanf_arg19041841($z18301831,anf_arg11991787,anf_fun11971788,l4101577);
++R.GAS;
return $ret18341835;
};
var $Hanf_arg19041841 = function(anf_arg12041840,anf_arg11991787,anf_fun11971788,l4101577) {
var $z18581859 = D;
var $f18641865 = function(_) {
return R.isFunction(anf_fun11971788)?anf_fun11971788.app(l4101577,anf_arg11991787,anf_arg12041840):R.ffi.throwNonFunApp(L[181],anf_fun11971788,[l4101577,anf_arg11991787,anf_arg12041840]);
};
try {
if(--R.GAS > 0) {
$z18581859 = $f18641865();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18641865,
"from":L[181]});
}
} catch($e18561857) {
if(R.isCont($e18561857)) {
var $ss18601861 = {"from":L[181],
"go":function(ann_DASH_check_DASH_temp11961866) {
return $Hann_DASH_check_DASH_temp19031867(ann_DASH_check_DASH_temp11961866);
}};
$e18561857.stack[R.EXN_STACKHEIGHT++] = $ss18601861;
}
if(R.isPyretException($e18561857)) {
$e18561857.pyretStack.push(L[181]);
}
throw $e18561857;
}
var $ret18621863 = $Hann_DASH_check_DASH_temp19031867($z18581859);
++R.GAS;
return $ret18621863;
};
var $Hann_DASH_check_DASH_temp19031867 = function(ann_DASH_check_DASH_temp11961866) {
return ann_DASH_check_DASH_temp11961866;
};
var $Hann_DASH_check_DASH_temp19021855 = function(ann_DASH_check_DASH_temp12011854) {
return ann_DASH_check_DASH_temp12011854;
};
var $Hcont_tail_arg18971805 = function(cont_tail_arg11921803,if_helper11751804) {
if(--R.GAS > 0) {
$z18681869 = R.isFunction(if_helper11751804)?if_helper11751804.app(cont_tail_arg11921803):R.ffi.throwNonFunApp(L[200],if_helper11751804,[cont_tail_arg11921803]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper11751804)?if_helper11751804.app(cont_tail_arg11921803):R.ffi.throwNonFunApp(L[200],if_helper11751804,[cont_tail_arg11921803]);
},
"from":L[200]});
}
++R.GAS;
return $z18681869;
};
var $Hanf_arg19011820 = function(anf_arg11821818,anf_fun11801819,args4121576,if_helper11751804,l4101577,self4091578) {
var anf_fun11831880 = G(args4121576,"map",L[212]);
var anf_arg11861881 = R.makeFunction(function(recv_DASH_1271884) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[211],1,arguments);
}
var anf_fun11851895 = G(recv_DASH_1271884,"visit",L[211]);
var $z18871888 = D;
var $f18931894 = function(_) {
return R.isFunction(anf_fun11851895)?anf_fun11851895.app(self4091578):R.ffi.throwNonFunApp(L[211],anf_fun11851895,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z18871888 = $f18931894();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18931894,
"from":L[211]});
}
} catch($e18851886) {
if(R.isCont($e18851886)) {
var $ss18891890 = {"from":L[211],
"go":function(ann_DASH_check_DASH_temp11841896) {
return $Hann_DASH_check_DASH_temp18981897(ann_DASH_check_DASH_temp11841896);
}};
$e18851886.stack[R.EXN_STACKHEIGHT++] = $ss18891890;
}
if(R.isPyretException($e18851886)) {
$e18851886.pyretStack.push(L[211]);
}
throw $e18851886;
}
var $ret18911892 = $Hann_DASH_check_DASH_temp18981897($z18871888);
++R.GAS;
return $ret18911892;
});
var $z18721873 = D;
var $f18781879 = function(_) {
return R.isFunction(anf_fun11831880)?anf_fun11831880.app(anf_arg11861881):R.ffi.throwNonFunApp(L[210],anf_fun11831880,[anf_arg11861881]);
};
try {
if(--R.GAS > 0) {
$z18721873 = $f18781879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18781879,
"from":L[210]});
}
} catch($e18701871) {
if(R.isCont($e18701871)) {
var $ss18741875 = {"from":L[210],
"go":function(anf_arg11871882) {
return $Hanf_arg19001883(anf_arg11871882,anf_arg11821818,anf_fun11801819,if_helper11751804,l4101577);
}};
$e18701871.stack[R.EXN_STACKHEIGHT++] = $ss18741875;
}
if(R.isPyretException($e18701871)) {
$e18701871.pyretStack.push(L[210]);
}
throw $e18701871;
}
var $ret18761877 = $Hanf_arg19001883($z18721873,anf_arg11821818,anf_fun11801819,if_helper11751804,l4101577);
++R.GAS;
return $ret18761877;
};
var $Hanf_arg19001883 = function(anf_arg11871882,anf_arg11821818,anf_fun11801819,if_helper11751804,l4101577) {
var $z19001901 = D;
var $f19061907 = function(_) {
return R.isFunction(anf_fun11801819)?anf_fun11801819.app(l4101577,anf_arg11821818,anf_arg11871882):R.ffi.throwNonFunApp(L[213],anf_fun11801819,[l4101577,anf_arg11821818,anf_arg11871882]);
};
try {
if(--R.GAS > 0) {
$z19001901 = $f19061907();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19061907,
"from":L[213]});
}
} catch($e18981899) {
if(R.isCont($e18981899)) {
var $ss19021903 = {"from":L[213],
"go":function(cont_tail_arg11881908) {
return $Hcont_tail_arg18991909(cont_tail_arg11881908,if_helper11751804);
}};
$e18981899.stack[R.EXN_STACKHEIGHT++] = $ss19021903;
}
if(R.isPyretException($e18981899)) {
$e18981899.pyretStack.push(L[213]);
}
throw $e18981899;
}
var $ret19041905 = $Hcont_tail_arg18991909($z19001901,if_helper11751804);
++R.GAS;
return $ret19041905;
};
var $Hcont_tail_arg18991909 = function(cont_tail_arg11881908,if_helper11751804) {
if(--R.GAS > 0) {
$z19101911 = R.isFunction(if_helper11751804)?if_helper11751804.app(cont_tail_arg11881908):R.ffi.throwNonFunApp(L[213],if_helper11751804,[cont_tail_arg11881908]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper11751804)?if_helper11751804.app(cont_tail_arg11881908):R.ffi.throwNonFunApp(L[213],if_helper11751804,[cont_tail_arg11881908]);
},
"from":L[213]});
}
++R.GAS;
return $z19101911;
};
var $Hann_DASH_check_DASH_temp18981897 = function(ann_DASH_check_DASH_temp11841896) {
return ann_DASH_check_DASH_temp11841896;
};
var $Hcases_DASH_val18961680 = function(cases_DASH_val1261679,A317,args4121576,f4111574,l4101577,self4091578) {
var anf_fun11371922 = G(cases_DASH_val1261679,"_match",L[184]);
var anf_obj11581941 = R.makeFunction(function(name4201942) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[217],1,arguments);
}
var if_DASH_1241972 = R.equiv(name4201942,("list:empty"));
var if_helper11391955 = R.makeFunction(function(if_helper_arg11401977) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[224],1,arguments);
}
var ann_DASH_check_DASH_temp11381978 = if_helper_arg11401977;
return ann_DASH_check_DASH_temp11381978;
});
var anf_if11431976 = R.isBoolean(if_DASH_1241972);
if(R.isPyretTrue(anf_if11431976)) {
if(R.isPyretTrue(if_DASH_1241972)) {
var anf_bracket11541957 = G(args4121576,"first",L[220]);
var anf_fun11551953 = G(anf_bracket11541957,"visit",L[219]);
var $z19451946 = D;
var $f19511952 = function(_) {
return R.isFunction(anf_fun11551953)?anf_fun11551953.app(self4091578):R.ffi.throwNonFunApp(L[218],anf_fun11551953,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z19451946 = $f19511952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19511952,
"from":L[218]});
}
} catch($e19431944) {
if(R.isCont($e19431944)) {
var $ss19471948 = {"from":L[218],
"go":function(cont_tail_arg11561954) {
return $Hcont_tail_arg18861956(cont_tail_arg11561954,if_helper11391955);
}};
$e19431944.stack[R.EXN_STACKHEIGHT++] = $ss19471948;
}
if(R.isPyretException($e19431944)) {
$e19431944.pyretStack.push(L[218]);
}
throw $e19431944;
}
var $ret19491950 = $Hcont_tail_arg18861956($z19451946,if_helper11391955);
++R.GAS;
return $ret19491950;
} else {
var anf_fun11441970 = G(A317,"s-app",L[223]);
var anf_fun11451968 = G(f4111574,"visit",L[222]);
var $z19601961 = D;
var $f19661967 = function(_) {
return R.isFunction(anf_fun11451968)?anf_fun11451968.app(self4091578):R.ffi.throwNonFunApp(L[221],anf_fun11451968,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z19601961 = $f19661967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19661967,
"from":L[221]});
}
} catch($e19581959) {
if(R.isCont($e19581959)) {
var $ss19621963 = {"from":L[221],
"go":function(anf_arg11461969) {
return $Hanf_arg18901971(anf_arg11461969,anf_fun11441970,args4121576,if_helper11391955,l4101577,self4091578);
}};
$e19581959.stack[R.EXN_STACKHEIGHT++] = $ss19621963;
}
if(R.isPyretException($e19581959)) {
$e19581959.pyretStack.push(L[221]);
}
throw $e19581959;
}
var $ret19641965 = $Hanf_arg18901971($z19601961,anf_fun11441970,args4121576,if_helper11391955,l4101577,self4091578);
++R.GAS;
return $ret19641965;
}
} else {
var cont_tail_arg11411975 = R.throwNonBooleanCondition(L[224],("if"),if_DASH_1241972);
if(--R.GAS > 0) {
$z19731974 = R.isFunction(if_helper11391955)?if_helper11391955.app(cont_tail_arg11411975):R.ffi.throwNonFunApp(L[224],if_helper11391955,[cont_tail_arg11411975]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper11391955)?if_helper11391955.app(cont_tail_arg11411975):R.ffi.throwNonFunApp(L[224],if_helper11391955,[cont_tail_arg11411975]);
},
"from":L[224]});
}
++R.GAS;
return $z19731974;
}
});
var anf_arg11591923 = R.makeObject({"b-prim":anf_obj11581941});
var anf_arg11691924 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[184],0,arguments);
}
var anf_fun11611939 = G(A317,"s-app",L[216]);
var anf_fun11621937 = G(f4111574,"visit",L[215]);
var $z19291930 = D;
var $f19351936 = function(_) {
return R.isFunction(anf_fun11621937)?anf_fun11621937.app(self4091578):R.ffi.throwNonFunApp(L[214],anf_fun11621937,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z19291930 = $f19351936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19351936,
"from":L[214]});
}
} catch($e19271928) {
if(R.isCont($e19271928)) {
var $ss19311932 = {"from":L[214],
"go":function(anf_arg11631938) {
return $Hanf_arg18941940(anf_arg11631938,anf_fun11611939,args4121576,l4101577,self4091578);
}};
$e19271928.stack[R.EXN_STACKHEIGHT++] = $ss19311932;
}
if(R.isPyretException($e19271928)) {
$e19271928.pyretStack.push(L[214]);
}
throw $e19271928;
}
var $ret19331934 = $Hanf_arg18941940($z19291930,anf_fun11611939,args4121576,l4101577,self4091578);
++R.GAS;
return $ret19331934;
});
var $z19141915 = D;
var $f19201921 = function(_) {
return R.isFunction(anf_fun11371922)?anf_fun11371922.app(anf_arg11591923,anf_arg11691924):R.ffi.throwNonFunApp(L[183],anf_fun11371922,[anf_arg11591923,anf_arg11691924]);
};
try {
if(--R.GAS > 0) {
$z19141915 = $f19201921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19201921,
"from":L[183]});
}
} catch($e19121913) {
if(R.isCont($e19121913)) {
var $ss19161917 = {"from":L[183],
"go":function(ann_DASH_check_DASH_temp11351925) {
return $Hann_DASH_check_DASH_temp18951926(ann_DASH_check_DASH_temp11351925);
}};
$e19121913.stack[R.EXN_STACKHEIGHT++] = $ss19161917;
}
if(R.isPyretException($e19121913)) {
$e19121913.pyretStack.push(L[183]);
}
throw $e19121913;
}
var $ret19181919 = $Hann_DASH_check_DASH_temp18951926($z19141915);
++R.GAS;
return $ret19181919;
};
var $Hann_DASH_check_DASH_temp18951926 = function(ann_DASH_check_DASH_temp11351925) {
return ann_DASH_check_DASH_temp11351925;
};
var $Hanf_arg18941940 = function(anf_arg11631938,anf_fun11611939,args4121576,l4101577,self4091578) {
var anf_fun11641989 = G(args4121576,"map",L[227]);
var anf_arg11671990 = R.makeFunction(function(recv_DASH_1251993) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[226],1,arguments);
}
var anf_fun11662004 = G(recv_DASH_1251993,"visit",L[226]);
var $z19961997 = D;
var $f20022003 = function(_) {
return R.isFunction(anf_fun11662004)?anf_fun11662004.app(self4091578):R.ffi.throwNonFunApp(L[226],anf_fun11662004,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z19961997 = $f20022003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20022003,
"from":L[226]});
}
} catch($e19941995) {
if(R.isCont($e19941995)) {
var $ss19981999 = {"from":L[226],
"go":function(ann_DASH_check_DASH_temp11652005) {
return $Hann_DASH_check_DASH_temp18912006(ann_DASH_check_DASH_temp11652005);
}};
$e19941995.stack[R.EXN_STACKHEIGHT++] = $ss19981999;
}
if(R.isPyretException($e19941995)) {
$e19941995.pyretStack.push(L[226]);
}
throw $e19941995;
}
var $ret20002001 = $Hann_DASH_check_DASH_temp18912006($z19961997);
++R.GAS;
return $ret20002001;
});
var $z19811982 = D;
var $f19871988 = function(_) {
return R.isFunction(anf_fun11641989)?anf_fun11641989.app(anf_arg11671990):R.ffi.throwNonFunApp(L[225],anf_fun11641989,[anf_arg11671990]);
};
try {
if(--R.GAS > 0) {
$z19811982 = $f19871988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19871988,
"from":L[225]});
}
} catch($e19791980) {
if(R.isCont($e19791980)) {
var $ss19831984 = {"from":L[225],
"go":function(anf_arg11681991) {
return $Hanf_arg18931992(anf_arg11681991,anf_arg11631938,anf_fun11611939,l4101577);
}};
$e19791980.stack[R.EXN_STACKHEIGHT++] = $ss19831984;
}
if(R.isPyretException($e19791980)) {
$e19791980.pyretStack.push(L[225]);
}
throw $e19791980;
}
var $ret19851986 = $Hanf_arg18931992($z19811982,anf_arg11631938,anf_fun11611939,l4101577);
++R.GAS;
return $ret19851986;
};
var $Hanf_arg18931992 = function(anf_arg11681991,anf_arg11631938,anf_fun11611939,l4101577) {
var $z20092010 = D;
var $f20152016 = function(_) {
return R.isFunction(anf_fun11611939)?anf_fun11611939.app(l4101577,anf_arg11631938,anf_arg11681991):R.ffi.throwNonFunApp(L[184],anf_fun11611939,[l4101577,anf_arg11631938,anf_arg11681991]);
};
try {
if(--R.GAS > 0) {
$z20092010 = $f20152016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20152016,
"from":L[184]});
}
} catch($e20072008) {
if(R.isCont($e20072008)) {
var $ss20112012 = {"from":L[184],
"go":function(ann_DASH_check_DASH_temp11602017) {
return $Hann_DASH_check_DASH_temp18922018(ann_DASH_check_DASH_temp11602017);
}};
$e20072008.stack[R.EXN_STACKHEIGHT++] = $ss20112012;
}
if(R.isPyretException($e20072008)) {
$e20072008.pyretStack.push(L[184]);
}
throw $e20072008;
}
var $ret20132014 = $Hann_DASH_check_DASH_temp18922018($z20092010);
++R.GAS;
return $ret20132014;
};
var $Hann_DASH_check_DASH_temp18922018 = function(ann_DASH_check_DASH_temp11602017) {
return ann_DASH_check_DASH_temp11602017;
};
var $Hann_DASH_check_DASH_temp18912006 = function(ann_DASH_check_DASH_temp11652005) {
return ann_DASH_check_DASH_temp11652005;
};
var $Hcont_tail_arg18861956 = function(cont_tail_arg11561954,if_helper11391955) {
if(--R.GAS > 0) {
$z20192020 = R.isFunction(if_helper11391955)?if_helper11391955.app(cont_tail_arg11561954):R.ffi.throwNonFunApp(L[218],if_helper11391955,[cont_tail_arg11561954]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper11391955)?if_helper11391955.app(cont_tail_arg11561954):R.ffi.throwNonFunApp(L[218],if_helper11391955,[cont_tail_arg11561954]);
},
"from":L[218]});
}
++R.GAS;
return $z20192020;
};
var $Hanf_arg18901971 = function(anf_arg11461969,anf_fun11441970,args4121576,if_helper11391955,l4101577,self4091578) {
var anf_fun11472031 = G(args4121576,"map",L[230]);
var anf_arg11502032 = R.makeFunction(function(recv_DASH_1232035) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[229],1,arguments);
}
var anf_fun11492046 = G(recv_DASH_1232035,"visit",L[229]);
var $z20382039 = D;
var $f20442045 = function(_) {
return R.isFunction(anf_fun11492046)?anf_fun11492046.app(self4091578):R.ffi.throwNonFunApp(L[229],anf_fun11492046,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z20382039 = $f20442045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20442045,
"from":L[229]});
}
} catch($e20362037) {
if(R.isCont($e20362037)) {
var $ss20402041 = {"from":L[229],
"go":function(ann_DASH_check_DASH_temp11482047) {
return $Hann_DASH_check_DASH_temp18872048(ann_DASH_check_DASH_temp11482047);
}};
$e20362037.stack[R.EXN_STACKHEIGHT++] = $ss20402041;
}
if(R.isPyretException($e20362037)) {
$e20362037.pyretStack.push(L[229]);
}
throw $e20362037;
}
var $ret20422043 = $Hann_DASH_check_DASH_temp18872048($z20382039);
++R.GAS;
return $ret20422043;
});
var $z20232024 = D;
var $f20292030 = function(_) {
return R.isFunction(anf_fun11472031)?anf_fun11472031.app(anf_arg11502032):R.ffi.throwNonFunApp(L[228],anf_fun11472031,[anf_arg11502032]);
};
try {
if(--R.GAS > 0) {
$z20232024 = $f20292030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20292030,
"from":L[228]});
}
} catch($e20212022) {
if(R.isCont($e20212022)) {
var $ss20252026 = {"from":L[228],
"go":function(anf_arg11512033) {
return $Hanf_arg18892034(anf_arg11512033,anf_arg11461969,anf_fun11441970,if_helper11391955,l4101577);
}};
$e20212022.stack[R.EXN_STACKHEIGHT++] = $ss20252026;
}
if(R.isPyretException($e20212022)) {
$e20212022.pyretStack.push(L[228]);
}
throw $e20212022;
}
var $ret20272028 = $Hanf_arg18892034($z20232024,anf_arg11461969,anf_fun11441970,if_helper11391955,l4101577);
++R.GAS;
return $ret20272028;
};
var $Hanf_arg18892034 = function(anf_arg11512033,anf_arg11461969,anf_fun11441970,if_helper11391955,l4101577) {
var $z20512052 = D;
var $f20572058 = function(_) {
return R.isFunction(anf_fun11441970)?anf_fun11441970.app(l4101577,anf_arg11461969,anf_arg11512033):R.ffi.throwNonFunApp(L[231],anf_fun11441970,[l4101577,anf_arg11461969,anf_arg11512033]);
};
try {
if(--R.GAS > 0) {
$z20512052 = $f20572058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20572058,
"from":L[231]});
}
} catch($e20492050) {
if(R.isCont($e20492050)) {
var $ss20532054 = {"from":L[231],
"go":function(cont_tail_arg11522059) {
return $Hcont_tail_arg18882060(cont_tail_arg11522059,if_helper11391955);
}};
$e20492050.stack[R.EXN_STACKHEIGHT++] = $ss20532054;
}
if(R.isPyretException($e20492050)) {
$e20492050.pyretStack.push(L[231]);
}
throw $e20492050;
}
var $ret20552056 = $Hcont_tail_arg18882060($z20512052,if_helper11391955);
++R.GAS;
return $ret20552056;
};
var $Hcont_tail_arg18882060 = function(cont_tail_arg11522059,if_helper11391955) {
if(--R.GAS > 0) {
$z20612062 = R.isFunction(if_helper11391955)?if_helper11391955.app(cont_tail_arg11522059):R.ffi.throwNonFunApp(L[231],if_helper11391955,[cont_tail_arg11522059]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper11391955)?if_helper11391955.app(cont_tail_arg11522059):R.ffi.throwNonFunApp(L[231],if_helper11391955,[cont_tail_arg11522059]);
},
"from":L[231]});
}
++R.GAS;
return $z20612062;
};
var $Hann_DASH_check_DASH_temp18872048 = function(ann_DASH_check_DASH_temp11482047) {
return ann_DASH_check_DASH_temp11482047;
};
var $Hcases_DASH_val18851696 = function(cases_DASH_val1221695,A317,_args4161683,args4121576,f4111574,l24141681,l4101577,list3192,lnk4151682,self4091578) {
var anf_fun10822073 = G(cases_DASH_val1221695,"_match",L[187]);
var anf_obj11222092 = R.makeFunction(function(n4172093) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[235],1,arguments);
}
var if_DASH_1202149 = R.equiv(n4172093,("list:link"));
var if_helper10842113 = R.makeFunction(function(if_helper_arg10852154) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[253],1,arguments);
}
var ann_DASH_check_DASH_temp10832155 = if_helper_arg10852154;
return ann_DASH_check_DASH_temp10832155;
});
var anf_if10882153 = R.isBoolean(if_DASH_1202149);
if(R.isPyretTrue(anf_if10882153)) {
if(R.isPyretTrue(if_DASH_1202149)) {
var anf_fun11062110 = G(A317,"s-app",L[245]);
var anf_fun11072111 = G(list3192,"make",L[244]);
var anf_array_val11082109 = G(_args4161683,"first",L[243]);
var anf_fun11092112 = G(A317,"s-app",L[242]);
var anf_fun11102104 = G(A317,"s-dot",L[241]);
var anf_arg11112105 = G(f4111574,"l",L[240]);
var anf_bracket11122115 = G(_args4161683,"rest",L[239]);
var anf_arg11132106 = G(anf_bracket11122115,"first",L[238]);
var anf_arg11142107 = G(f4111574,"field",L[237]);
var $z20962097 = D;
var $f21022103 = function(_) {
return R.isFunction(anf_fun11102104)?anf_fun11102104.app(anf_arg11112105,anf_arg11132106,anf_arg11142107):R.ffi.throwNonFunApp(L[236],anf_fun11102104,[anf_arg11112105,anf_arg11132106,anf_arg11142107]);
};
try {
if(--R.GAS > 0) {
$z20962097 = $f21022103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21022103,
"from":L[236]});
}
} catch($e20942095) {
if(R.isCont($e20942095)) {
var $ss20982099 = {"from":L[236],
"go":function(anf_arg11152108) {
return $Hanf_arg18742114(anf_arg11152108,anf_array_val11082109,anf_fun11062110,anf_fun11072111,anf_fun11092112,args4121576,if_helper10842113,l24141681,l4101577,lnk4151682,self4091578);
}};
$e20942095.stack[R.EXN_STACKHEIGHT++] = $ss20982099;
}
if(R.isPyretException($e20942095)) {
$e20942095.pyretStack.push(L[236]);
}
throw $e20942095;
}
var $ret21002101 = $Hanf_arg18742114($z20962097,anf_array_val11082109,anf_fun11062110,anf_fun11072111,anf_fun11092112,args4121576,if_helper10842113,l24141681,l4101577,lnk4151682,self4091578);
++R.GAS;
return $ret21002101;
} else {
var if_DASH_1192144 = R.equiv(n4172093,("list:empty"));
var anf_if10912148 = R.isBoolean(if_DASH_1192144);
if(R.isPyretTrue(anf_if10912148)) {
if(R.isPyretTrue(if_DASH_1192144)) {
var anf_bracket11022129 = G(args4121576,"first",L[248]);
var anf_fun11032126 = G(anf_bracket11022129,"visit",L[247]);
var $z21182119 = D;
var $f21242125 = function(_) {
return R.isFunction(anf_fun11032126)?anf_fun11032126.app(self4091578):R.ffi.throwNonFunApp(L[246],anf_fun11032126,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z21182119 = $f21242125();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21242125,
"from":L[246]});
}
} catch($e21162117) {
if(R.isCont($e21162117)) {
var $ss21202121 = {"from":L[246],
"go":function(cont_tail_arg11042127) {
return $Hcont_tail_arg18752128(cont_tail_arg11042127,if_helper10842113);
}};
$e21162117.stack[R.EXN_STACKHEIGHT++] = $ss21202121;
}
if(R.isPyretException($e21162117)) {
$e21162117.pyretStack.push(L[246]);
}
throw $e21162117;
}
var $ret21222123 = $Hcont_tail_arg18752128($z21182119,if_helper10842113);
++R.GAS;
return $ret21222123;
} else {
var anf_fun10922142 = G(A317,"s-app",L[251]);
var anf_fun10932140 = G(f4111574,"visit",L[250]);
var $z21322133 = D;
var $f21382139 = function(_) {
return R.isFunction(anf_fun10932140)?anf_fun10932140.app(self4091578):R.ffi.throwNonFunApp(L[249],anf_fun10932140,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z21322133 = $f21382139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21382139,
"from":L[249]});
}
} catch($e21302131) {
if(R.isCont($e21302131)) {
var $ss21342135 = {"from":L[249],
"go":function(anf_arg10942141) {
return $Hanf_arg18792143(anf_arg10942141,anf_fun10922142,args4121576,if_helper10842113,l4101577,self4091578);
}};
$e21302131.stack[R.EXN_STACKHEIGHT++] = $ss21342135;
}
if(R.isPyretException($e21302131)) {
$e21302131.pyretStack.push(L[249]);
}
throw $e21302131;
}
var $ret21362137 = $Hanf_arg18792143($z21322133,anf_fun10922142,args4121576,if_helper10842113,l4101577,self4091578);
++R.GAS;
return $ret21362137;
}
} else {
var cont_tail_arg10892147 = R.throwNonBooleanCondition(L[252],("if"),if_DASH_1192144);
if(--R.GAS > 0) {
$z21452146 = R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg10892147):R.ffi.throwNonFunApp(L[252],if_helper10842113,[cont_tail_arg10892147]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg10892147):R.ffi.throwNonFunApp(L[252],if_helper10842113,[cont_tail_arg10892147]);
},
"from":L[252]});
}
++R.GAS;
return $z21452146;
}
}
} else {
var cont_tail_arg10862152 = R.throwNonBooleanCondition(L[253],("if"),if_DASH_1202149);
if(--R.GAS > 0) {
$z21502151 = R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg10862152):R.ffi.throwNonFunApp(L[253],if_helper10842113,[cont_tail_arg10862152]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg10862152):R.ffi.throwNonFunApp(L[253],if_helper10842113,[cont_tail_arg10862152]);
},
"from":L[253]});
}
++R.GAS;
return $z21502151;
}
});
var anf_arg11232074 = R.makeObject({"b-prim":anf_obj11222092});
var anf_arg11332075 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[187],0,arguments);
}
var anf_fun11252090 = G(A317,"s-app",L[234]);
var anf_fun11262088 = G(f4111574,"visit",L[233]);
var $z20802081 = D;
var $f20862087 = function(_) {
return R.isFunction(anf_fun11262088)?anf_fun11262088.app(self4091578):R.ffi.throwNonFunApp(L[232],anf_fun11262088,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z20802081 = $f20862087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20862087,
"from":L[232]});
}
} catch($e20782079) {
if(R.isCont($e20782079)) {
var $ss20822083 = {"from":L[232],
"go":function(anf_arg11272089) {
return $Hanf_arg18832091(anf_arg11272089,anf_fun11252090,args4121576,l4101577,self4091578);
}};
$e20782079.stack[R.EXN_STACKHEIGHT++] = $ss20822083;
}
if(R.isPyretException($e20782079)) {
$e20782079.pyretStack.push(L[232]);
}
throw $e20782079;
}
var $ret20842085 = $Hanf_arg18832091($z20802081,anf_fun11252090,args4121576,l4101577,self4091578);
++R.GAS;
return $ret20842085;
});
var $z20652066 = D;
var $f20712072 = function(_) {
return R.isFunction(anf_fun10822073)?anf_fun10822073.app(anf_arg11232074,anf_arg11332075):R.ffi.throwNonFunApp(L[186],anf_fun10822073,[anf_arg11232074,anf_arg11332075]);
};
try {
if(--R.GAS > 0) {
$z20652066 = $f20712072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20712072,
"from":L[186]});
}
} catch($e20632064) {
if(R.isCont($e20632064)) {
var $ss20672068 = {"from":L[186],
"go":function(ann_DASH_check_DASH_temp10802076) {
return $Hann_DASH_check_DASH_temp18842077(ann_DASH_check_DASH_temp10802076);
}};
$e20632064.stack[R.EXN_STACKHEIGHT++] = $ss20672068;
}
if(R.isPyretException($e20632064)) {
$e20632064.pyretStack.push(L[186]);
}
throw $e20632064;
}
var $ret20692070 = $Hann_DASH_check_DASH_temp18842077($z20652066);
++R.GAS;
return $ret20692070;
};
var $Hann_DASH_check_DASH_temp18842077 = function(ann_DASH_check_DASH_temp10802076) {
return ann_DASH_check_DASH_temp10802076;
};
var $Hanf_arg18832091 = function(anf_arg11272089,anf_fun11252090,args4121576,l4101577,self4091578) {
var anf_fun11282166 = G(args4121576,"map",L[256]);
var anf_arg11312167 = R.makeFunction(function(recv_DASH_1212170) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[255],1,arguments);
}
var anf_fun11302181 = G(recv_DASH_1212170,"visit",L[255]);
var $z21732174 = D;
var $f21792180 = function(_) {
return R.isFunction(anf_fun11302181)?anf_fun11302181.app(self4091578):R.ffi.throwNonFunApp(L[255],anf_fun11302181,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z21732174 = $f21792180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21792180,
"from":L[255]});
}
} catch($e21712172) {
if(R.isCont($e21712172)) {
var $ss21752176 = {"from":L[255],
"go":function(ann_DASH_check_DASH_temp11292182) {
return $Hann_DASH_check_DASH_temp18802183(ann_DASH_check_DASH_temp11292182);
}};
$e21712172.stack[R.EXN_STACKHEIGHT++] = $ss21752176;
}
if(R.isPyretException($e21712172)) {
$e21712172.pyretStack.push(L[255]);
}
throw $e21712172;
}
var $ret21772178 = $Hann_DASH_check_DASH_temp18802183($z21732174);
++R.GAS;
return $ret21772178;
});
var $z21582159 = D;
var $f21642165 = function(_) {
return R.isFunction(anf_fun11282166)?anf_fun11282166.app(anf_arg11312167):R.ffi.throwNonFunApp(L[254],anf_fun11282166,[anf_arg11312167]);
};
try {
if(--R.GAS > 0) {
$z21582159 = $f21642165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21642165,
"from":L[254]});
}
} catch($e21562157) {
if(R.isCont($e21562157)) {
var $ss21602161 = {"from":L[254],
"go":function(anf_arg11322168) {
return $Hanf_arg18822169(anf_arg11322168,anf_arg11272089,anf_fun11252090,l4101577);
}};
$e21562157.stack[R.EXN_STACKHEIGHT++] = $ss21602161;
}
if(R.isPyretException($e21562157)) {
$e21562157.pyretStack.push(L[254]);
}
throw $e21562157;
}
var $ret21622163 = $Hanf_arg18822169($z21582159,anf_arg11272089,anf_fun11252090,l4101577);
++R.GAS;
return $ret21622163;
};
var $Hanf_arg18822169 = function(anf_arg11322168,anf_arg11272089,anf_fun11252090,l4101577) {
var $z21862187 = D;
var $f21922193 = function(_) {
return R.isFunction(anf_fun11252090)?anf_fun11252090.app(l4101577,anf_arg11272089,anf_arg11322168):R.ffi.throwNonFunApp(L[187],anf_fun11252090,[l4101577,anf_arg11272089,anf_arg11322168]);
};
try {
if(--R.GAS > 0) {
$z21862187 = $f21922193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21922193,
"from":L[187]});
}
} catch($e21842185) {
if(R.isCont($e21842185)) {
var $ss21882189 = {"from":L[187],
"go":function(ann_DASH_check_DASH_temp11242194) {
return $Hann_DASH_check_DASH_temp18812195(ann_DASH_check_DASH_temp11242194);
}};
$e21842185.stack[R.EXN_STACKHEIGHT++] = $ss21882189;
}
if(R.isPyretException($e21842185)) {
$e21842185.pyretStack.push(L[187]);
}
throw $e21842185;
}
var $ret21902191 = $Hann_DASH_check_DASH_temp18812195($z21862187);
++R.GAS;
return $ret21902191;
};
var $Hann_DASH_check_DASH_temp18812195 = function(ann_DASH_check_DASH_temp11242194) {
return ann_DASH_check_DASH_temp11242194;
};
var $Hann_DASH_check_DASH_temp18802183 = function(ann_DASH_check_DASH_temp11292182) {
return ann_DASH_check_DASH_temp11292182;
};
var $Hanf_arg18742114 = function(anf_arg11152108,anf_array_val11082109,anf_fun11062110,anf_fun11072111,anf_fun11092112,args4121576,if_helper10842113,l24141681,l4101577,lnk4151682,self4091578) {
var $z21982199 = D;
var $f22042205 = function(_) {
return R.isFunction(anf_fun11092112)?anf_fun11092112.app(l4101577,anf_arg11152108,args4121576):R.ffi.throwNonFunApp(L[257],anf_fun11092112,[l4101577,anf_arg11152108,args4121576]);
};
try {
if(--R.GAS > 0) {
$z21982199 = $f22042205();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22042205,
"from":L[257]});
}
} catch($e21962197) {
if(R.isCont($e21962197)) {
var $ss22002201 = {"from":L[257],
"go":function(anf_bracket11162206) {
return $Hanf_bracket18732207(anf_bracket11162206,anf_array_val11082109,anf_fun11062110,anf_fun11072111,if_helper10842113,l24141681,lnk4151682,self4091578);
}};
$e21962197.stack[R.EXN_STACKHEIGHT++] = $ss22002201;
}
if(R.isPyretException($e21962197)) {
$e21962197.pyretStack.push(L[257]);
}
throw $e21962197;
}
var $ret22022203 = $Hanf_bracket18732207($z21982199,anf_array_val11082109,anf_fun11062110,anf_fun11072111,if_helper10842113,l24141681,lnk4151682,self4091578);
++R.GAS;
return $ret22022203;
};
var $Hanf_bracket18732207 = function(anf_bracket11162206,anf_array_val11082109,anf_fun11062110,anf_fun11072111,if_helper10842113,l24141681,lnk4151682,self4091578) {
var anf_fun11172218 = G(anf_bracket11162206,"visit",L[259]);
var $z22102211 = D;
var $f22162217 = function(_) {
return R.isFunction(anf_fun11172218)?anf_fun11172218.app(self4091578):R.ffi.throwNonFunApp(L[258],anf_fun11172218,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z22102211 = $f22162217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22162217,
"from":L[258]});
}
} catch($e22082209) {
if(R.isCont($e22082209)) {
var $ss22122213 = {"from":L[258],
"go":function(anf_array_val11182219) {
return $Hanf_array_val18722220(anf_array_val11182219,anf_array_val11082109,anf_fun11062110,anf_fun11072111,if_helper10842113,l24141681,lnk4151682);
}};
$e22082209.stack[R.EXN_STACKHEIGHT++] = $ss22122213;
}
if(R.isPyretException($e22082209)) {
$e22082209.pyretStack.push(L[258]);
}
throw $e22082209;
}
var $ret22142215 = $Hanf_array_val18722220($z22102211,anf_array_val11082109,anf_fun11062110,anf_fun11072111,if_helper10842113,l24141681,lnk4151682);
++R.GAS;
return $ret22142215;
};
var $Hanf_array_val18722220 = function(anf_array_val11182219,anf_array_val11082109,anf_fun11062110,anf_fun11072111,if_helper10842113,l24141681,lnk4151682) {
var $z22232224 = D;
var $f22292230 = function(_) {
return R.isFunction(anf_fun11072111)?anf_fun11072111.app([anf_array_val11082109,anf_array_val11182219]):R.ffi.throwNonFunApp(L[244],anf_fun11072111,[[anf_array_val11082109,anf_array_val11182219]]);
};
try {
if(--R.GAS > 0) {
$z22232224 = $f22292230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22292230,
"from":L[244]});
}
} catch($e22212222) {
if(R.isCont($e22212222)) {
var $ss22252226 = {"from":L[244],
"go":function(anf_arg11192231) {
return $Hanf_arg18712232(anf_arg11192231,anf_fun11062110,if_helper10842113,l24141681,lnk4151682);
}};
$e22212222.stack[R.EXN_STACKHEIGHT++] = $ss22252226;
}
if(R.isPyretException($e22212222)) {
$e22212222.pyretStack.push(L[244]);
}
throw $e22212222;
}
var $ret22272228 = $Hanf_arg18712232($z22232224,anf_fun11062110,if_helper10842113,l24141681,lnk4151682);
++R.GAS;
return $ret22272228;
};
var $Hanf_arg18712232 = function(anf_arg11192231,anf_fun11062110,if_helper10842113,l24141681,lnk4151682) {
var $z22352236 = D;
var $f22412242 = function(_) {
return R.isFunction(anf_fun11062110)?anf_fun11062110.app(l24141681,lnk4151682,anf_arg11192231):R.ffi.throwNonFunApp(L[260],anf_fun11062110,[l24141681,lnk4151682,anf_arg11192231]);
};
try {
if(--R.GAS > 0) {
$z22352236 = $f22412242();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22412242,
"from":L[260]});
}
} catch($e22332234) {
if(R.isCont($e22332234)) {
var $ss22372238 = {"from":L[260],
"go":function(cont_tail_arg11202243) {
return $Hcont_tail_arg18702244(cont_tail_arg11202243,if_helper10842113);
}};
$e22332234.stack[R.EXN_STACKHEIGHT++] = $ss22372238;
}
if(R.isPyretException($e22332234)) {
$e22332234.pyretStack.push(L[260]);
}
throw $e22332234;
}
var $ret22392240 = $Hcont_tail_arg18702244($z22352236,if_helper10842113);
++R.GAS;
return $ret22392240;
};
var $Hcont_tail_arg18702244 = function(cont_tail_arg11202243,if_helper10842113) {
if(--R.GAS > 0) {
$z22452246 = R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg11202243):R.ffi.throwNonFunApp(L[260],if_helper10842113,[cont_tail_arg11202243]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg11202243):R.ffi.throwNonFunApp(L[260],if_helper10842113,[cont_tail_arg11202243]);
},
"from":L[260]});
}
++R.GAS;
return $z22452246;
};
var $Hcont_tail_arg18752128 = function(cont_tail_arg11042127,if_helper10842113) {
if(--R.GAS > 0) {
$z22472248 = R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg11042127):R.ffi.throwNonFunApp(L[246],if_helper10842113,[cont_tail_arg11042127]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg11042127):R.ffi.throwNonFunApp(L[246],if_helper10842113,[cont_tail_arg11042127]);
},
"from":L[246]});
}
++R.GAS;
return $z22472248;
};
var $Hanf_arg18792143 = function(anf_arg10942141,anf_fun10922142,args4121576,if_helper10842113,l4101577,self4091578) {
var anf_fun10952259 = G(args4121576,"map",L[263]);
var anf_arg10982260 = R.makeFunction(function(recv_DASH_1182263) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[262],1,arguments);
}
var anf_fun10972274 = G(recv_DASH_1182263,"visit",L[262]);
var $z22662267 = D;
var $f22722273 = function(_) {
return R.isFunction(anf_fun10972274)?anf_fun10972274.app(self4091578):R.ffi.throwNonFunApp(L[262],anf_fun10972274,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z22662267 = $f22722273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22722273,
"from":L[262]});
}
} catch($e22642265) {
if(R.isCont($e22642265)) {
var $ss22682269 = {"from":L[262],
"go":function(ann_DASH_check_DASH_temp10962275) {
return $Hann_DASH_check_DASH_temp18762276(ann_DASH_check_DASH_temp10962275);
}};
$e22642265.stack[R.EXN_STACKHEIGHT++] = $ss22682269;
}
if(R.isPyretException($e22642265)) {
$e22642265.pyretStack.push(L[262]);
}
throw $e22642265;
}
var $ret22702271 = $Hann_DASH_check_DASH_temp18762276($z22662267);
++R.GAS;
return $ret22702271;
});
var $z22512252 = D;
var $f22572258 = function(_) {
return R.isFunction(anf_fun10952259)?anf_fun10952259.app(anf_arg10982260):R.ffi.throwNonFunApp(L[261],anf_fun10952259,[anf_arg10982260]);
};
try {
if(--R.GAS > 0) {
$z22512252 = $f22572258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22572258,
"from":L[261]});
}
} catch($e22492250) {
if(R.isCont($e22492250)) {
var $ss22532254 = {"from":L[261],
"go":function(anf_arg10992261) {
return $Hanf_arg18782262(anf_arg10992261,anf_arg10942141,anf_fun10922142,if_helper10842113,l4101577);
}};
$e22492250.stack[R.EXN_STACKHEIGHT++] = $ss22532254;
}
if(R.isPyretException($e22492250)) {
$e22492250.pyretStack.push(L[261]);
}
throw $e22492250;
}
var $ret22552256 = $Hanf_arg18782262($z22512252,anf_arg10942141,anf_fun10922142,if_helper10842113,l4101577);
++R.GAS;
return $ret22552256;
};
var $Hanf_arg18782262 = function(anf_arg10992261,anf_arg10942141,anf_fun10922142,if_helper10842113,l4101577) {
var $z22792280 = D;
var $f22852286 = function(_) {
return R.isFunction(anf_fun10922142)?anf_fun10922142.app(l4101577,anf_arg10942141,anf_arg10992261):R.ffi.throwNonFunApp(L[264],anf_fun10922142,[l4101577,anf_arg10942141,anf_arg10992261]);
};
try {
if(--R.GAS > 0) {
$z22792280 = $f22852286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22852286,
"from":L[264]});
}
} catch($e22772278) {
if(R.isCont($e22772278)) {
var $ss22812282 = {"from":L[264],
"go":function(cont_tail_arg11002287) {
return $Hcont_tail_arg18772288(cont_tail_arg11002287,if_helper10842113);
}};
$e22772278.stack[R.EXN_STACKHEIGHT++] = $ss22812282;
}
if(R.isPyretException($e22772278)) {
$e22772278.pyretStack.push(L[264]);
}
throw $e22772278;
}
var $ret22832284 = $Hcont_tail_arg18772288($z22792280,if_helper10842113);
++R.GAS;
return $ret22832284;
};
var $Hcont_tail_arg18772288 = function(cont_tail_arg11002287,if_helper10842113) {
if(--R.GAS > 0) {
$z22892290 = R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg11002287):R.ffi.throwNonFunApp(L[264],if_helper10842113,[cont_tail_arg11002287]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10842113)?if_helper10842113.app(cont_tail_arg11002287):R.ffi.throwNonFunApp(L[264],if_helper10842113,[cont_tail_arg11002287]);
},
"from":L[264]});
}
++R.GAS;
return $z22892290;
};
var $Hann_DASH_check_DASH_temp18762276 = function(ann_DASH_check_DASH_temp10962275) {
return ann_DASH_check_DASH_temp10962275;
};
var $Hanf_arg19161711 = function(anf_arg10711709,anf_fun10691710,args4121576,if_helper10641630,l4101577,self4091578) {
var anf_fun10722301 = G(args4121576,"map",L[267]);
var anf_arg10752302 = R.makeFunction(function(recv_DASH_1142305) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[266],1,arguments);
}
var anf_fun10742316 = G(recv_DASH_1142305,"visit",L[266]);
var $z23082309 = D;
var $f23142315 = function(_) {
return R.isFunction(anf_fun10742316)?anf_fun10742316.app(self4091578):R.ffi.throwNonFunApp(L[266],anf_fun10742316,[self4091578]);
};
try {
if(--R.GAS > 0) {
$z23082309 = $f23142315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23142315,
"from":L[266]});
}
} catch($e23062307) {
if(R.isCont($e23062307)) {
var $ss23102311 = {"from":L[266],
"go":function(ann_DASH_check_DASH_temp10732317) {
return $Hann_DASH_check_DASH_temp19132318(ann_DASH_check_DASH_temp10732317);
}};
$e23062307.stack[R.EXN_STACKHEIGHT++] = $ss23102311;
}
if(R.isPyretException($e23062307)) {
$e23062307.pyretStack.push(L[266]);
}
throw $e23062307;
}
var $ret23122313 = $Hann_DASH_check_DASH_temp19132318($z23082309);
++R.GAS;
return $ret23122313;
});
var $z22932294 = D;
var $f22992300 = function(_) {
return R.isFunction(anf_fun10722301)?anf_fun10722301.app(anf_arg10752302):R.ffi.throwNonFunApp(L[265],anf_fun10722301,[anf_arg10752302]);
};
try {
if(--R.GAS > 0) {
$z22932294 = $f22992300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22992300,
"from":L[265]});
}
} catch($e22912292) {
if(R.isCont($e22912292)) {
var $ss22952296 = {"from":L[265],
"go":function(anf_arg10762303) {
return $Hanf_arg19152304(anf_arg10762303,anf_arg10711709,anf_fun10691710,if_helper10641630,l4101577);
}};
$e22912292.stack[R.EXN_STACKHEIGHT++] = $ss22952296;
}
if(R.isPyretException($e22912292)) {
$e22912292.pyretStack.push(L[265]);
}
throw $e22912292;
}
var $ret22972298 = $Hanf_arg19152304($z22932294,anf_arg10711709,anf_fun10691710,if_helper10641630,l4101577);
++R.GAS;
return $ret22972298;
};
var $Hanf_arg19152304 = function(anf_arg10762303,anf_arg10711709,anf_fun10691710,if_helper10641630,l4101577) {
var $z23212322 = D;
var $f23272328 = function(_) {
return R.isFunction(anf_fun10691710)?anf_fun10691710.app(l4101577,anf_arg10711709,anf_arg10762303):R.ffi.throwNonFunApp(L[268],anf_fun10691710,[l4101577,anf_arg10711709,anf_arg10762303]);
};
try {
if(--R.GAS > 0) {
$z23212322 = $f23272328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23272328,
"from":L[268]});
}
} catch($e23192320) {
if(R.isCont($e23192320)) {
var $ss23232324 = {"from":L[268],
"go":function(cont_tail_arg10772329) {
return $Hcont_tail_arg19142330(cont_tail_arg10772329,if_helper10641630);
}};
$e23192320.stack[R.EXN_STACKHEIGHT++] = $ss23232324;
}
if(R.isPyretException($e23192320)) {
$e23192320.pyretStack.push(L[268]);
}
throw $e23192320;
}
var $ret23252326 = $Hcont_tail_arg19142330($z23212322,if_helper10641630);
++R.GAS;
return $ret23252326;
};
var $Hcont_tail_arg19142330 = function(cont_tail_arg10772329,if_helper10641630) {
if(--R.GAS > 0) {
$z23312332 = R.isFunction(if_helper10641630)?if_helper10641630.app(cont_tail_arg10772329):R.ffi.throwNonFunApp(L[268],if_helper10641630,[cont_tail_arg10772329]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper10641630)?if_helper10641630.app(cont_tail_arg10772329):R.ffi.throwNonFunApp(L[268],if_helper10641630,[cont_tail_arg10772329]);
},
"from":L[268]});
}
++R.GAS;
return $z23312332;
};
var $Hann_DASH_check_DASH_temp19132318 = function(ann_DASH_check_DASH_temp10732317) {
return ann_DASH_check_DASH_temp10732317;
};
var $Hanf_arg18692333 = function(anf_arg10552334,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,default_DASH_env_DASH_iter_DASH_visitor13276,initial_DASH_env4072335) {
var $z23382339 = D;
var $f23442345 = function(_) {
return R.isFunction(binding_DASH_type_DASH_env_DASH_from_DASH_env12972.$var)?binding_DASH_type_DASH_env_DASH_from_DASH_env12972.$var.app(initial_DASH_env4072335):R.ffi.throwNonFunApp(L[269],binding_DASH_type_DASH_env_DASH_from_DASH_env12972.$var,[initial_DASH_env4072335]);
};
try {
if(--R.GAS > 0) {
$z23382339 = $f23442345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23442345,
"from":L[269]});
}
} catch($e23362337) {
if(R.isCont($e23362337)) {
var $ss23402341 = {"from":L[269],
"go":function(anf_arg10562346) {
return $Hanf_arg18682347(anf_arg10562346,anf_arg10552334,binding_DASH_handlers36871,default_DASH_env_DASH_iter_DASH_visitor13276);
}};
$e23362337.stack[R.EXN_STACKHEIGHT++] = $ss23402341;
}
if(R.isPyretException($e23362337)) {
$e23362337.pyretStack.push(L[269]);
}
throw $e23362337;
}
var $ret23422343 = $Hanf_arg18682347($z23382339,anf_arg10552334,binding_DASH_handlers36871,default_DASH_env_DASH_iter_DASH_visitor13276);
++R.GAS;
return $ret23422343;
};
var $Hanf_arg18682347 = function(anf_arg10562346,anf_arg10552334,binding_DASH_handlers36871,default_DASH_env_DASH_iter_DASH_visitor13276) {
var $z23502351 = D;
var $f23562357 = function(_) {
return R.isFunction(default_DASH_env_DASH_iter_DASH_visitor13276.$var)?default_DASH_env_DASH_iter_DASH_visitor13276.$var.app(anf_arg10552334,anf_arg10562346,binding_DASH_handlers36871):R.ffi.throwNonFunApp(L[270],default_DASH_env_DASH_iter_DASH_visitor13276.$var,[anf_arg10552334,anf_arg10562346,binding_DASH_handlers36871]);
};
try {
if(--R.GAS > 0) {
$z23502351 = $f23562357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23562357,
"from":L[270]});
}
} catch($e23482349) {
if(R.isCont($e23482349)) {
var $ss23522353 = {"from":L[270],
"go":function(ann_DASH_check_DASH_temp10542358) {
return $Hann_DASH_check_DASH_temp18672359(ann_DASH_check_DASH_temp10542358);
}};
$e23482349.stack[R.EXN_STACKHEIGHT++] = $ss23522353;
}
if(R.isPyretException($e23482349)) {
$e23482349.pyretStack.push(L[270]);
}
throw $e23482349;
}
var $ret23542355 = $Hann_DASH_check_DASH_temp18672359($z23502351);
++R.GAS;
return $ret23542355;
};
var $Hann_DASH_check_DASH_temp18672359 = function(ann_DASH_check_DASH_temp10542358) {
return ann_DASH_check_DASH_temp10542358;
};
var $Hanf_arg18662360 = function(anf_arg10512361,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,default_DASH_env_DASH_map_DASH_visitor13177,initial_DASH_env4062362) {
var $z23652366 = D;
var $f23712372 = function(_) {
return R.isFunction(binding_DASH_type_DASH_env_DASH_from_DASH_env12972.$var)?binding_DASH_type_DASH_env_DASH_from_DASH_env12972.$var.app(initial_DASH_env4062362):R.ffi.throwNonFunApp(L[271],binding_DASH_type_DASH_env_DASH_from_DASH_env12972.$var,[initial_DASH_env4062362]);
};
try {
if(--R.GAS > 0) {
$z23652366 = $f23712372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23712372,
"from":L[271]});
}
} catch($e23632364) {
if(R.isCont($e23632364)) {
var $ss23672368 = {"from":L[271],
"go":function(anf_arg10522373) {
return $Hanf_arg18652374(anf_arg10522373,anf_arg10512361,binding_DASH_handlers36871,default_DASH_env_DASH_map_DASH_visitor13177);
}};
$e23632364.stack[R.EXN_STACKHEIGHT++] = $ss23672368;
}
if(R.isPyretException($e23632364)) {
$e23632364.pyretStack.push(L[271]);
}
throw $e23632364;
}
var $ret23692370 = $Hanf_arg18652374($z23652366,anf_arg10512361,binding_DASH_handlers36871,default_DASH_env_DASH_map_DASH_visitor13177);
++R.GAS;
return $ret23692370;
};
var $Hanf_arg18652374 = function(anf_arg10522373,anf_arg10512361,binding_DASH_handlers36871,default_DASH_env_DASH_map_DASH_visitor13177) {
var $z23772378 = D;
var $f23832384 = function(_) {
return R.isFunction(default_DASH_env_DASH_map_DASH_visitor13177.$var)?default_DASH_env_DASH_map_DASH_visitor13177.$var.app(anf_arg10512361,anf_arg10522373,binding_DASH_handlers36871):R.ffi.throwNonFunApp(L[272],default_DASH_env_DASH_map_DASH_visitor13177.$var,[anf_arg10512361,anf_arg10522373,binding_DASH_handlers36871]);
};
try {
if(--R.GAS > 0) {
$z23772378 = $f23832384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23832384,
"from":L[272]});
}
} catch($e23752376) {
if(R.isCont($e23752376)) {
var $ss23792380 = {"from":L[272],
"go":function(ann_DASH_check_DASH_temp10502385) {
return $Hann_DASH_check_DASH_temp18642386(ann_DASH_check_DASH_temp10502385);
}};
$e23752376.stack[R.EXN_STACKHEIGHT++] = $ss23792380;
}
if(R.isPyretException($e23752376)) {
$e23752376.pyretStack.push(L[272]);
}
throw $e23752376;
}
var $ret23812382 = $Hann_DASH_check_DASH_temp18642386($z23772378);
++R.GAS;
return $ret23812382;
};
var $Hann_DASH_check_DASH_temp18642386 = function(ann_DASH_check_DASH_temp10502385) {
return ann_DASH_check_DASH_temp10502385;
};
var $Hanf_arg18632387 = function(anf_arg10462388,anf_fun10432389,b_DASH_unknown12164,b4002390,e_DASH_bind12678) {
var anf_arg10472401 = G(b4002390,"l",L[274]);
var $z23932394 = D;
var $f23992400 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg10472401,(false),b_DASH_unknown12164.$var):R.ffi.throwNonFunApp(L[273],e_DASH_bind12678.$var,[anf_arg10472401,(false),b_DASH_unknown12164.$var]);
};
try {
if(--R.GAS > 0) {
$z23932394 = $f23992400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23992400,
"from":L[273]});
}
} catch($e23912392) {
if(R.isCont($e23912392)) {
var $ss23952396 = {"from":L[273],
"go":function(anf_arg10482402) {
return $Hanf_arg18622403(anf_arg10482402,anf_arg10462388,anf_fun10432389);
}};
$e23912392.stack[R.EXN_STACKHEIGHT++] = $ss23952396;
}
if(R.isPyretException($e23912392)) {
$e23912392.pyretStack.push(L[273]);
}
throw $e23912392;
}
var $ret23972398 = $Hanf_arg18622403($z23932394,anf_arg10462388,anf_fun10432389);
++R.GAS;
return $ret23972398;
};
var $Hanf_arg18622403 = function(anf_arg10482402,anf_arg10462388,anf_fun10432389) {
var $z24062407 = D;
var $f24122413 = function(_) {
return R.isFunction(anf_fun10432389)?anf_fun10432389.app(anf_arg10462388,anf_arg10482402):R.ffi.throwNonFunApp(L[275],anf_fun10432389,[anf_arg10462388,anf_arg10482402]);
};
try {
if(--R.GAS > 0) {
$z24062407 = $f24122413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24122413,
"from":L[275]});
}
} catch($e24042405) {
if(R.isCont($e24042405)) {
var $ss24082409 = {"from":L[275],
"go":function(ann_DASH_check_DASH_temp10422414) {
return $Hann_DASH_check_DASH_temp18612415(ann_DASH_check_DASH_temp10422414);
}};
$e24042405.stack[R.EXN_STACKHEIGHT++] = $ss24082409;
}
if(R.isPyretException($e24042405)) {
$e24042405.pyretStack.push(L[275]);
}
throw $e24042405;
}
var $ret24102411 = $Hann_DASH_check_DASH_temp18612415($z24062407);
++R.GAS;
return $ret24102411;
};
var $Hann_DASH_check_DASH_temp18612415 = function(ann_DASH_check_DASH_temp10422414) {
return ann_DASH_check_DASH_temp10422414;
};
var $Hanf_arg18602416 = function(anf_arg10362417,anf_fun10322418,bind_DASH_or_DASH_unknown12867,e_DASH_bind12678,env3982419,lrb3972420) {
var anf_arg10372433 = G(lrb3972420,"l",L[278]);
var anf_arg10382431 = G(lrb3972420,"value",L[277]);
var $z24232424 = D;
var $f24292430 = function(_) {
return R.isFunction(bind_DASH_or_DASH_unknown12867.$var)?bind_DASH_or_DASH_unknown12867.$var.app(anf_arg10382431,env3982419):R.ffi.throwNonFunApp(L[276],bind_DASH_or_DASH_unknown12867.$var,[anf_arg10382431,env3982419]);
};
try {
if(--R.GAS > 0) {
$z24232424 = $f24292430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24292430,
"from":L[276]});
}
} catch($e24212422) {
if(R.isCont($e24212422)) {
var $ss24252426 = {"from":L[276],
"go":function(anf_arg10392432) {
return $Hanf_arg18592434(anf_arg10392432,anf_arg10362417,anf_arg10372433,anf_fun10322418,e_DASH_bind12678);
}};
$e24212422.stack[R.EXN_STACKHEIGHT++] = $ss24252426;
}
if(R.isPyretException($e24212422)) {
$e24212422.pyretStack.push(L[276]);
}
throw $e24212422;
}
var $ret24272428 = $Hanf_arg18592434($z24232424,anf_arg10362417,anf_arg10372433,anf_fun10322418,e_DASH_bind12678);
++R.GAS;
return $ret24272428;
};
var $Hanf_arg18592434 = function(anf_arg10392432,anf_arg10362417,anf_arg10372433,anf_fun10322418,e_DASH_bind12678) {
var $z24372438 = D;
var $f24432444 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg10372433,(false),anf_arg10392432):R.ffi.throwNonFunApp(L[279],e_DASH_bind12678.$var,[anf_arg10372433,(false),anf_arg10392432]);
};
try {
if(--R.GAS > 0) {
$z24372438 = $f24432444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24432444,
"from":L[279]});
}
} catch($e24352436) {
if(R.isCont($e24352436)) {
var $ss24392440 = {"from":L[279],
"go":function(anf_arg10402445) {
return $Hanf_arg18582446(anf_arg10402445,anf_arg10362417,anf_fun10322418);
}};
$e24352436.stack[R.EXN_STACKHEIGHT++] = $ss24392440;
}
if(R.isPyretException($e24352436)) {
$e24352436.pyretStack.push(L[279]);
}
throw $e24352436;
}
var $ret24412442 = $Hanf_arg18582446($z24372438,anf_arg10362417,anf_fun10322418);
++R.GAS;
return $ret24412442;
};
var $Hanf_arg18582446 = function(anf_arg10402445,anf_arg10362417,anf_fun10322418) {
var $z24492450 = D;
var $f24552456 = function(_) {
return R.isFunction(anf_fun10322418)?anf_fun10322418.app(anf_arg10362417,anf_arg10402445):R.ffi.throwNonFunApp(L[280],anf_fun10322418,[anf_arg10362417,anf_arg10402445]);
};
try {
if(--R.GAS > 0) {
$z24492450 = $f24552456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24552456,
"from":L[280]});
}
} catch($e24472448) {
if(R.isCont($e24472448)) {
var $ss24512452 = {"from":L[280],
"go":function(ann_DASH_check_DASH_temp10312457) {
return $Hann_DASH_check_DASH_temp18572458(ann_DASH_check_DASH_temp10312457);
}};
$e24472448.stack[R.EXN_STACKHEIGHT++] = $ss24512452;
}
if(R.isPyretException($e24472448)) {
$e24472448.pyretStack.push(L[280]);
}
throw $e24472448;
}
var $ret24532454 = $Hann_DASH_check_DASH_temp18572458($z24492450);
++R.GAS;
return $ret24532454;
};
var $Hann_DASH_check_DASH_temp18572458 = function(ann_DASH_check_DASH_temp10312457) {
return ann_DASH_check_DASH_temp10312457;
};
var $Hann_DASH_check_DASH_temp18562459 = function(ann_DASH_check_DASH_temp10102460) {
return ann_DASH_check_DASH_temp10102460;
};
var $Hanf_arg18552461 = function(anf_arg10242462,anf_fun10212463,b_DASH_unknown12164,e_DASH_bind12678,l23932464) {
var $z24672468 = D;
var $f24732474 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(l23932464,(true),b_DASH_unknown12164.$var):R.ffi.throwNonFunApp(L[281],e_DASH_bind12678.$var,[l23932464,(true),b_DASH_unknown12164.$var]);
};
try {
if(--R.GAS > 0) {
$z24672468 = $f24732474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24732474,
"from":L[281]});
}
} catch($e24652466) {
if(R.isCont($e24652466)) {
var $ss24692470 = {"from":L[281],
"go":function(anf_arg10252475) {
return $Hanf_arg18542476(anf_arg10252475,anf_arg10242462,anf_fun10212463);
}};
$e24652466.stack[R.EXN_STACKHEIGHT++] = $ss24692470;
}
if(R.isPyretException($e24652466)) {
$e24652466.pyretStack.push(L[281]);
}
throw $e24652466;
}
var $ret24712472 = $Hanf_arg18542476($z24672468,anf_arg10242462,anf_fun10212463);
++R.GAS;
return $ret24712472;
};
var $Hanf_arg18542476 = function(anf_arg10252475,anf_arg10242462,anf_fun10212463) {
var $z24792480 = D;
var $f24852486 = function(_) {
return R.isFunction(anf_fun10212463)?anf_fun10212463.app(anf_arg10242462,anf_arg10252475):R.ffi.throwNonFunApp(L[282],anf_fun10212463,[anf_arg10242462,anf_arg10252475]);
};
try {
if(--R.GAS > 0) {
$z24792480 = $f24852486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24852486,
"from":L[282]});
}
} catch($e24772478) {
if(R.isCont($e24772478)) {
var $ss24812482 = {"from":L[282],
"go":function(ann_DASH_check_DASH_temp10202487) {
return $Hann_DASH_check_DASH_temp18532488(ann_DASH_check_DASH_temp10202487);
}};
$e24772478.stack[R.EXN_STACKHEIGHT++] = $ss24812482;
}
if(R.isPyretException($e24772478)) {
$e24772478.pyretStack.push(L[282]);
}
throw $e24772478;
}
var $ret24832484 = $Hann_DASH_check_DASH_temp18532488($z24792480);
++R.GAS;
return $ret24832484;
};
var $Hann_DASH_check_DASH_temp18532488 = function(ann_DASH_check_DASH_temp10202487) {
return ann_DASH_check_DASH_temp10202487;
};
var $Hanf_arg18522489 = function(anf_arg10162490,anf_fun10132491,bind_DASH_or_DASH_unknown12867,e_DASH_bind12678,env3892492,l23902493,val3922494) {
var $z24972498 = D;
var $f25032504 = function(_) {
return R.isFunction(bind_DASH_or_DASH_unknown12867.$var)?bind_DASH_or_DASH_unknown12867.$var.app(val3922494,env3892492):R.ffi.throwNonFunApp(L[283],bind_DASH_or_DASH_unknown12867.$var,[val3922494,env3892492]);
};
try {
if(--R.GAS > 0) {
$z24972498 = $f25032504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25032504,
"from":L[283]});
}
} catch($e24952496) {
if(R.isCont($e24952496)) {
var $ss24992500 = {"from":L[283],
"go":function(anf_arg10172505) {
return $Hanf_arg18512506(anf_arg10172505,anf_arg10162490,anf_fun10132491,e_DASH_bind12678,l23902493);
}};
$e24952496.stack[R.EXN_STACKHEIGHT++] = $ss24992500;
}
if(R.isPyretException($e24952496)) {
$e24952496.pyretStack.push(L[283]);
}
throw $e24952496;
}
var $ret25012502 = $Hanf_arg18512506($z24972498,anf_arg10162490,anf_fun10132491,e_DASH_bind12678,l23902493);
++R.GAS;
return $ret25012502;
};
var $Hanf_arg18512506 = function(anf_arg10172505,anf_arg10162490,anf_fun10132491,e_DASH_bind12678,l23902493) {
var $z25092510 = D;
var $f25152516 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(l23902493,(false),anf_arg10172505):R.ffi.throwNonFunApp(L[284],e_DASH_bind12678.$var,[l23902493,(false),anf_arg10172505]);
};
try {
if(--R.GAS > 0) {
$z25092510 = $f25152516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25152516,
"from":L[284]});
}
} catch($e25072508) {
if(R.isCont($e25072508)) {
var $ss25112512 = {"from":L[284],
"go":function(anf_arg10182517) {
return $Hanf_arg18502518(anf_arg10182517,anf_arg10162490,anf_fun10132491);
}};
$e25072508.stack[R.EXN_STACKHEIGHT++] = $ss25112512;
}
if(R.isPyretException($e25072508)) {
$e25072508.pyretStack.push(L[284]);
}
throw $e25072508;
}
var $ret25132514 = $Hanf_arg18502518($z25092510,anf_arg10162490,anf_fun10132491);
++R.GAS;
return $ret25132514;
};
var $Hanf_arg18502518 = function(anf_arg10182517,anf_arg10162490,anf_fun10132491) {
var $z25212522 = D;
var $f25272528 = function(_) {
return R.isFunction(anf_fun10132491)?anf_fun10132491.app(anf_arg10162490,anf_arg10182517):R.ffi.throwNonFunApp(L[285],anf_fun10132491,[anf_arg10162490,anf_arg10182517]);
};
try {
if(--R.GAS > 0) {
$z25212522 = $f25272528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25272528,
"from":L[285]});
}
} catch($e25192520) {
if(R.isCont($e25192520)) {
var $ss25232524 = {"from":L[285],
"go":function(ann_DASH_check_DASH_temp10122529) {
return $Hann_DASH_check_DASH_temp18492530(ann_DASH_check_DASH_temp10122529);
}};
$e25192520.stack[R.EXN_STACKHEIGHT++] = $ss25232524;
}
if(R.isPyretException($e25192520)) {
$e25192520.pyretStack.push(L[285]);
}
throw $e25192520;
}
var $ret25252526 = $Hann_DASH_check_DASH_temp18492530($z25212522);
++R.GAS;
return $ret25252526;
};
var $Hann_DASH_check_DASH_temp18492530 = function(ann_DASH_check_DASH_temp10122529) {
return ann_DASH_check_DASH_temp10122529;
};
var $Hann_DASH_check_DASH_temp18482531 = function(ann_DASH_check_DASH_temp9852532) {
return ann_DASH_check_DASH_temp9852532;
};
var $Hanf_arg18472533 = function(anf_arg9972534,anf_fun9952535,b_DASH_typ11963,b_DASH_unknown12164,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538) {
var $z25412542 = D;
var $f25472548 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(l3842536,(false),b_DASH_unknown12164.$var):R.ffi.throwNonFunApp(L[286],e_DASH_bind12678.$var,[l3842536,(false),b_DASH_unknown12164.$var]);
};
try {
if(--R.GAS > 0) {
$z25412542 = $f25472548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25472548,
"from":L[286]});
}
} catch($e25392540) {
if(R.isCont($e25392540)) {
var $ss25432544 = {"from":L[286],
"go":function(anf_arg9982549) {
return $Hanf_arg18462550(anf_arg9982549,anf_arg9972534,anf_fun9952535,b_DASH_typ11963,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538);
}};
$e25392540.stack[R.EXN_STACKHEIGHT++] = $ss25432544;
}
if(R.isPyretException($e25392540)) {
$e25392540.pyretStack.push(L[286]);
}
throw $e25392540;
}
var $ret25452546 = $Hanf_arg18462550($z25412542,anf_arg9972534,anf_fun9952535,b_DASH_typ11963,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538);
++R.GAS;
return $ret25452546;
};
var $Hanf_arg18462550 = function(anf_arg9982549,anf_arg9972534,anf_fun9952535,b_DASH_typ11963,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538) {
var $z25532554 = D;
var $f25592560 = function(_) {
return R.isFunction(anf_fun9952535)?anf_fun9952535.app(anf_arg9972534,anf_arg9982549):R.ffi.throwNonFunApp(L[287],anf_fun9952535,[anf_arg9972534,anf_arg9982549]);
};
try {
if(--R.GAS > 0) {
$z25532554 = $f25592560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25592560,
"from":L[287]});
}
} catch($e25512552) {
if(R.isCont($e25512552)) {
var $ss25552556 = {"from":L[287],
"go":function(anf_obj9992561) {
return $Hanf_obj18452562(anf_obj9992561,b_DASH_typ11963,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538);
}};
$e25512552.stack[R.EXN_STACKHEIGHT++] = $ss25552556;
}
if(R.isPyretException($e25512552)) {
$e25512552.pyretStack.push(L[287]);
}
throw $e25512552;
}
var $ret25572558 = $Hanf_obj18452562($z25532554,b_DASH_typ11963,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538);
++R.GAS;
return $ret25572558;
};
var $Hanf_obj18452562 = function(anf_obj9992561,b_DASH_typ11963,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538) {
var anf_fun10002575 = G(type_DASH_env3802538,"set",L[290]);
var anf_fun10012573 = G(tname3852537,"key",L[289]);
var $z25652566 = D;
var $f25712572 = function(_) {
return R.isFunction(anf_fun10012573)?anf_fun10012573.app():R.ffi.throwNonFunApp(L[288],anf_fun10012573,[]);
};
try {
if(--R.GAS > 0) {
$z25652566 = $f25712572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25712572,
"from":L[288]});
}
} catch($e25632564) {
if(R.isCont($e25632564)) {
var $ss25672568 = {"from":L[288],
"go":function(anf_arg10022574) {
return $Hanf_arg18442576(anf_arg10022574,anf_fun10002575,anf_obj9992561,b_DASH_typ11963,e_DASH_bind12678,l3842536);
}};
$e25632564.stack[R.EXN_STACKHEIGHT++] = $ss25672568;
}
if(R.isPyretException($e25632564)) {
$e25632564.pyretStack.push(L[288]);
}
throw $e25632564;
}
var $ret25692570 = $Hanf_arg18442576($z25652566,anf_fun10002575,anf_obj9992561,b_DASH_typ11963,e_DASH_bind12678,l3842536);
++R.GAS;
return $ret25692570;
};
var $Hanf_arg18442576 = function(anf_arg10022574,anf_fun10002575,anf_obj9992561,b_DASH_typ11963,e_DASH_bind12678,l3842536) {
var $z25792580 = D;
var $f25852586 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(l3842536,(false),b_DASH_typ11963.$var):R.ffi.throwNonFunApp(L[291],e_DASH_bind12678.$var,[l3842536,(false),b_DASH_typ11963.$var]);
};
try {
if(--R.GAS > 0) {
$z25792580 = $f25852586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25852586,
"from":L[291]});
}
} catch($e25772578) {
if(R.isCont($e25772578)) {
var $ss25812582 = {"from":L[291],
"go":function(anf_arg10032587) {
return $Hanf_arg18432588(anf_arg10032587,anf_arg10022574,anf_fun10002575,anf_obj9992561);
}};
$e25772578.stack[R.EXN_STACKHEIGHT++] = $ss25812582;
}
if(R.isPyretException($e25772578)) {
$e25772578.pyretStack.push(L[291]);
}
throw $e25772578;
}
var $ret25832584 = $Hanf_arg18432588($z25792580,anf_arg10022574,anf_fun10002575,anf_obj9992561);
++R.GAS;
return $ret25832584;
};
var $Hanf_arg18432588 = function(anf_arg10032587,anf_arg10022574,anf_fun10002575,anf_obj9992561) {
var $z25912592 = D;
var $f25972598 = function(_) {
return R.isFunction(anf_fun10002575)?anf_fun10002575.app(anf_arg10022574,anf_arg10032587):R.ffi.throwNonFunApp(L[292],anf_fun10002575,[anf_arg10022574,anf_arg10032587]);
};
try {
if(--R.GAS > 0) {
$z25912592 = $f25972598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25972598,
"from":L[292]});
}
} catch($e25892590) {
if(R.isCont($e25892590)) {
var $ss25932594 = {"from":L[292],
"go":function(anf_obj10042599) {
return $Hanf_obj18422600(anf_obj10042599,anf_obj9992561);
}};
$e25892590.stack[R.EXN_STACKHEIGHT++] = $ss25932594;
}
if(R.isPyretException($e25892590)) {
$e25892590.pyretStack.push(L[292]);
}
throw $e25892590;
}
var $ret25952596 = $Hanf_obj18422600($z25912592,anf_obj9992561);
++R.GAS;
return $ret25952596;
};
var $Hanf_obj18422600 = function(anf_obj10042599,anf_obj9992561) {
var ann_DASH_check_DASH_temp9942601 = R.makeObject({"val-env":anf_obj9992561,
"type-env":anf_obj10042599});
return ann_DASH_check_DASH_temp9942601;
};
var $Hanf_arg18412602 = function(anf_arg9902603,anf_fun9882604,b_DASH_typ11963,e_DASH_bind12678,env3792605,l3812606) {
var $z26092610 = D;
var $f26152616 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(l3812606,(false),b_DASH_typ11963.$var):R.ffi.throwNonFunApp(L[293],e_DASH_bind12678.$var,[l3812606,(false),b_DASH_typ11963.$var]);
};
try {
if(--R.GAS > 0) {
$z26092610 = $f26152616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26152616,
"from":L[293]});
}
} catch($e26072608) {
if(R.isCont($e26072608)) {
var $ss26112612 = {"from":L[293],
"go":function(anf_arg9912617) {
return $Hanf_arg18402618(anf_arg9912617,anf_arg9902603,anf_fun9882604,env3792605);
}};
$e26072608.stack[R.EXN_STACKHEIGHT++] = $ss26112612;
}
if(R.isPyretException($e26072608)) {
$e26072608.pyretStack.push(L[293]);
}
throw $e26072608;
}
var $ret26132614 = $Hanf_arg18402618($z26092610,anf_arg9902603,anf_fun9882604,env3792605);
++R.GAS;
return $ret26132614;
};
var $Hanf_arg18402618 = function(anf_arg9912617,anf_arg9902603,anf_fun9882604,env3792605) {
var $z26212622 = D;
var $f26272628 = function(_) {
return R.isFunction(anf_fun9882604)?anf_fun9882604.app(anf_arg9902603,anf_arg9912617):R.ffi.throwNonFunApp(L[294],anf_fun9882604,[anf_arg9902603,anf_arg9912617]);
};
try {
if(--R.GAS > 0) {
$z26212622 = $f26272628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26272628,
"from":L[294]});
}
} catch($e26192620) {
if(R.isCont($e26192620)) {
var $ss26232624 = {"from":L[294],
"go":function(anf_obj9922629) {
return $Hanf_obj18392630(anf_obj9922629,env3792605);
}};
$e26192620.stack[R.EXN_STACKHEIGHT++] = $ss26232624;
}
if(R.isPyretException($e26192620)) {
$e26192620.pyretStack.push(L[294]);
}
throw $e26192620;
}
var $ret26252626 = $Hanf_obj18392630($z26212622,env3792605);
++R.GAS;
return $ret26252626;
};
var $Hanf_obj18392630 = function(anf_obj9922629,env3792605) {
var ann_DASH_check_DASH_temp9872631 = R.makeObject({"val-env":env3792605,
"type-env":anf_obj9922629});
return ann_DASH_check_DASH_temp9872631;
};
var $Hanf_arg18382632 = function(anf_arg9822633,anf_fun9802634,b_DASH_typ11963,e_DASH_bind12678,l3742635) {
var $z26382639 = D;
var $f26442645 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(l3742635,(false),b_DASH_typ11963.$var):R.ffi.throwNonFunApp(L[295],e_DASH_bind12678.$var,[l3742635,(false),b_DASH_typ11963.$var]);
};
try {
if(--R.GAS > 0) {
$z26382639 = $f26442645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26442645,
"from":L[295]});
}
} catch($e26362637) {
if(R.isCont($e26362637)) {
var $ss26402641 = {"from":L[295],
"go":function(anf_arg9832646) {
return $Hanf_arg18372647(anf_arg9832646,anf_arg9822633,anf_fun9802634);
}};
$e26362637.stack[R.EXN_STACKHEIGHT++] = $ss26402641;
}
if(R.isPyretException($e26362637)) {
$e26362637.pyretStack.push(L[295]);
}
throw $e26362637;
}
var $ret26422643 = $Hanf_arg18372647($z26382639,anf_arg9822633,anf_fun9802634);
++R.GAS;
return $ret26422643;
};
var $Hanf_arg18372647 = function(anf_arg9832646,anf_arg9822633,anf_fun9802634) {
var $z26502651 = D;
var $f26562657 = function(_) {
return R.isFunction(anf_fun9802634)?anf_fun9802634.app(anf_arg9822633,anf_arg9832646):R.ffi.throwNonFunApp(L[296],anf_fun9802634,[anf_arg9822633,anf_arg9832646]);
};
try {
if(--R.GAS > 0) {
$z26502651 = $f26562657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26562657,
"from":L[296]});
}
} catch($e26482649) {
if(R.isCont($e26482649)) {
var $ss26522653 = {"from":L[296],
"go":function(ann_DASH_check_DASH_temp9792658) {
return $Hann_DASH_check_DASH_temp18362659(ann_DASH_check_DASH_temp9792658);
}};
$e26482649.stack[R.EXN_STACKHEIGHT++] = $ss26522653;
}
if(R.isPyretException($e26482649)) {
$e26482649.pyretStack.push(L[296]);
}
throw $e26482649;
}
var $ret26542655 = $Hann_DASH_check_DASH_temp18362659($z26502651);
++R.GAS;
return $ret26542655;
};
var $Hann_DASH_check_DASH_temp18362659 = function(ann_DASH_check_DASH_temp9792658) {
return ann_DASH_check_DASH_temp9792658;
};
var $Hanf_arg18352660 = function(anf_arg9672661,anf_fun9642662,b_DASH_typ11963,b_DASH_unknown12164,e_DASH_bind12678,imp3702663,type_DASH_env3722664) {
var anf_arg9682675 = G(imp3702663,"l",L[298]);
var $z26672668 = D;
var $f26732674 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg9682675,(false),b_DASH_unknown12164.$var):R.ffi.throwNonFunApp(L[297],e_DASH_bind12678.$var,[anf_arg9682675,(false),b_DASH_unknown12164.$var]);
};
try {
if(--R.GAS > 0) {
$z26672668 = $f26732674();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26732674,
"from":L[297]});
}
} catch($e26652666) {
if(R.isCont($e26652666)) {
var $ss26692670 = {"from":L[297],
"go":function(anf_arg9692676) {
return $Hanf_arg18342677(anf_arg9692676,anf_arg9672661,anf_fun9642662,b_DASH_typ11963,e_DASH_bind12678,imp3702663,type_DASH_env3722664);
}};
$e26652666.stack[R.EXN_STACKHEIGHT++] = $ss26692670;
}
if(R.isPyretException($e26652666)) {
$e26652666.pyretStack.push(L[297]);
}
throw $e26652666;
}
var $ret26712672 = $Hanf_arg18342677($z26672668,anf_arg9672661,anf_fun9642662,b_DASH_typ11963,e_DASH_bind12678,imp3702663,type_DASH_env3722664);
++R.GAS;
return $ret26712672;
};
var $Hanf_arg18342677 = function(anf_arg9692676,anf_arg9672661,anf_fun9642662,b_DASH_typ11963,e_DASH_bind12678,imp3702663,type_DASH_env3722664) {
var $z26802681 = D;
var $f26862687 = function(_) {
return R.isFunction(anf_fun9642662)?anf_fun9642662.app(anf_arg9672661,anf_arg9692676):R.ffi.throwNonFunApp(L[299],anf_fun9642662,[anf_arg9672661,anf_arg9692676]);
};
try {
if(--R.GAS > 0) {
$z26802681 = $f26862687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26862687,
"from":L[299]});
}
} catch($e26782679) {
if(R.isCont($e26782679)) {
var $ss26822683 = {"from":L[299],
"go":function(anf_obj9702688) {
return $Hanf_obj18332689(anf_obj9702688,b_DASH_typ11963,e_DASH_bind12678,imp3702663,type_DASH_env3722664);
}};
$e26782679.stack[R.EXN_STACKHEIGHT++] = $ss26822683;
}
if(R.isPyretException($e26782679)) {
$e26782679.pyretStack.push(L[299]);
}
throw $e26782679;
}
var $ret26842685 = $Hanf_obj18332689($z26802681,b_DASH_typ11963,e_DASH_bind12678,imp3702663,type_DASH_env3722664);
++R.GAS;
return $ret26842685;
};
var $Hanf_obj18332689 = function(anf_obj9702688,b_DASH_typ11963,e_DASH_bind12678,imp3702663,type_DASH_env3722664) {
var anf_fun9712702 = G(type_DASH_env3722664,"set",L[303]);
var anf_bracket9722704 = G(imp3702663,"types",L[302]);
var anf_fun9732700 = G(anf_bracket9722704,"key",L[301]);
var $z26922693 = D;
var $f26982699 = function(_) {
return R.isFunction(anf_fun9732700)?anf_fun9732700.app():R.ffi.throwNonFunApp(L[300],anf_fun9732700,[]);
};
try {
if(--R.GAS > 0) {
$z26922693 = $f26982699();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26982699,
"from":L[300]});
}
} catch($e26902691) {
if(R.isCont($e26902691)) {
var $ss26942695 = {"from":L[300],
"go":function(anf_arg9742701) {
return $Hanf_arg18322703(anf_arg9742701,anf_fun9712702,anf_obj9702688,b_DASH_typ11963,e_DASH_bind12678,imp3702663);
}};
$e26902691.stack[R.EXN_STACKHEIGHT++] = $ss26942695;
}
if(R.isPyretException($e26902691)) {
$e26902691.pyretStack.push(L[300]);
}
throw $e26902691;
}
var $ret26962697 = $Hanf_arg18322703($z26922693,anf_fun9712702,anf_obj9702688,b_DASH_typ11963,e_DASH_bind12678,imp3702663);
++R.GAS;
return $ret26962697;
};
var $Hanf_arg18322703 = function(anf_arg9742701,anf_fun9712702,anf_obj9702688,b_DASH_typ11963,e_DASH_bind12678,imp3702663) {
var anf_arg9752715 = G(imp3702663,"l",L[305]);
var $z27072708 = D;
var $f27132714 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg9752715,(false),b_DASH_typ11963.$var):R.ffi.throwNonFunApp(L[304],e_DASH_bind12678.$var,[anf_arg9752715,(false),b_DASH_typ11963.$var]);
};
try {
if(--R.GAS > 0) {
$z27072708 = $f27132714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27132714,
"from":L[304]});
}
} catch($e27052706) {
if(R.isCont($e27052706)) {
var $ss27092710 = {"from":L[304],
"go":function(anf_arg9762716) {
return $Hanf_arg18312717(anf_arg9762716,anf_arg9742701,anf_fun9712702,anf_obj9702688);
}};
$e27052706.stack[R.EXN_STACKHEIGHT++] = $ss27092710;
}
if(R.isPyretException($e27052706)) {
$e27052706.pyretStack.push(L[304]);
}
throw $e27052706;
}
var $ret27112712 = $Hanf_arg18312717($z27072708,anf_arg9742701,anf_fun9712702,anf_obj9702688);
++R.GAS;
return $ret27112712;
};
var $Hanf_arg18312717 = function(anf_arg9762716,anf_arg9742701,anf_fun9712702,anf_obj9702688) {
var $z27202721 = D;
var $f27262727 = function(_) {
return R.isFunction(anf_fun9712702)?anf_fun9712702.app(anf_arg9742701,anf_arg9762716):R.ffi.throwNonFunApp(L[306],anf_fun9712702,[anf_arg9742701,anf_arg9762716]);
};
try {
if(--R.GAS > 0) {
$z27202721 = $f27262727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27262727,
"from":L[306]});
}
} catch($e27182719) {
if(R.isCont($e27182719)) {
var $ss27222723 = {"from":L[306],
"go":function(anf_obj9772728) {
return $Hanf_obj18302729(anf_obj9772728,anf_obj9702688);
}};
$e27182719.stack[R.EXN_STACKHEIGHT++] = $ss27222723;
}
if(R.isPyretException($e27182719)) {
$e27182719.pyretStack.push(L[306]);
}
throw $e27182719;
}
var $ret27242725 = $Hanf_obj18302729($z27202721,anf_obj9702688);
++R.GAS;
return $ret27242725;
};
var $Hanf_obj18302729 = function(anf_obj9772728,anf_obj9702688) {
var ann_DASH_check_DASH_temp9632730 = R.makeObject({"val-env":anf_obj9702688,
"type-env":anf_obj9772728});
return ann_DASH_check_DASH_temp9632730;
};
var $Hargs_DASH_env18292731 = function(args_DASH_env3652732,_check3642733,ann3612734,args3602735,body3632736,lists1523,self3582737) {
var anf_fun9332748 = G(lists1523,"all",L[309]);
var anf_arg9362749 = R.makeFunction(function(recv_DASH_1082752) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[308],1,arguments);
}
var anf_fun9352763 = G(recv_DASH_1082752,"visit",L[308]);
var $z27552756 = D;
var $f27612762 = function(_) {
return R.isFunction(anf_fun9352763)?anf_fun9352763.app(self3582737):R.ffi.throwNonFunApp(L[308],anf_fun9352763,[self3582737]);
};
try {
if(--R.GAS > 0) {
$z27552756 = $f27612762();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27612762,
"from":L[308]});
}
} catch($e27532754) {
if(R.isCont($e27532754)) {
var $ss27572758 = {"from":L[308],
"go":function(ann_DASH_check_DASH_temp9342764) {
return $Hann_DASH_check_DASH_temp18202765(ann_DASH_check_DASH_temp9342764);
}};
$e27532754.stack[R.EXN_STACKHEIGHT++] = $ss27572758;
}
if(R.isPyretException($e27532754)) {
$e27532754.pyretStack.push(L[308]);
}
throw $e27532754;
}
var $ret27592760 = $Hann_DASH_check_DASH_temp18202765($z27552756);
++R.GAS;
return $ret27592760;
});
var $z27402741 = D;
var $f27462747 = function(_) {
return R.isFunction(anf_fun9332748)?anf_fun9332748.app(anf_arg9362749,args3602735):R.ffi.throwNonFunApp(L[307],anf_fun9332748,[anf_arg9362749,args3602735]);
};
try {
if(--R.GAS > 0) {
$z27402741 = $f27462747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27462747,
"from":L[307]});
}
} catch($e27382739) {
if(R.isCont($e27382739)) {
var $ss27422743 = {"from":L[307],
"go":function(and_DASH_oper_DASH_1072750) {
return $Hand_DASH_oper_DASH_18282751(and_DASH_oper_DASH_1072750,_check3642733,ann3612734,args_DASH_env3652732,body3632736,self3582737);
}};
$e27382739.stack[R.EXN_STACKHEIGHT++] = $ss27422743;
}
if(R.isPyretException($e27382739)) {
$e27382739.pyretStack.push(L[307]);
}
throw $e27382739;
}
var $ret27442745 = $Hand_DASH_oper_DASH_18282751($z27402741,_check3642733,ann3612734,args_DASH_env3652732,body3632736,self3582737);
++R.GAS;
return $ret27442745;
};
var $Hand_DASH_oper_DASH_18282751 = function(and_DASH_oper_DASH_1072750,_check3642733,ann3612734,args_DASH_env3652732,body3632736,self3582737) {
var if_helper9372779 = R.makeFunction(function(if_helper_arg9382797) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[307],1,arguments);
}
var ann_DASH_check_DASH_temp9272798 = if_helper_arg9382797;
return ann_DASH_check_DASH_temp9272798;
});
var anf_if9412796 = R.isBoolean(and_DASH_oper_DASH_1072750);
if(R.isPyretTrue(anf_if9412796)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1072750)) {
var anf_fun9432776 = G(ann3612734,"visit",L[310]);
var anf_arg9442777 = self3582737.extendWith({"env":args_DASH_env3652732});
var $z27682769 = D;
var $f27742775 = function(_) {
return R.isFunction(anf_fun9432776)?anf_fun9432776.app(anf_arg9442777):R.ffi.throwNonFunApp(L[307],anf_fun9432776,[anf_arg9442777]);
};
try {
if(--R.GAS > 0) {
$z27682769 = $f27742775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27742775,
"from":L[307]});
}
} catch($e27662767) {
if(R.isCont($e27662767)) {
var $ss27702771 = {"from":L[307],
"go":function(and_DASH_oper_DASH_1092778) {
return $Hand_DASH_oper_DASH_18262780(and_DASH_oper_DASH_1092778,_check3642733,args_DASH_env3652732,body3632736,if_helper9372779,self3582737);
}};
$e27662767.stack[R.EXN_STACKHEIGHT++] = $ss27702771;
}
if(R.isPyretException($e27662767)) {
$e27662767.pyretStack.push(L[307]);
}
throw $e27662767;
}
var $ret27722773 = $Hand_DASH_oper_DASH_18262780($z27682769,_check3642733,args_DASH_env3652732,body3632736,if_helper9372779,self3582737);
++R.GAS;
return $ret27722773;
} else {
var $z27832784 = D;
var $f27892790 = function(_) {
return R.isFunction(if_helper9372779)?if_helper9372779.app((false)):R.ffi.throwNonFunApp(L[307],if_helper9372779,[(false)]);
};
try {
if(--R.GAS > 0) {
$z27832784 = $f27892790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27892790,
"from":L[307]});
}
} catch($e27812782) {
if(R.isCont($e27812782)) {
var $ss27852786 = {"from":L[307],
"go":function(cont_tail_app9422791) {
return $Hcont_tail_app18272792(cont_tail_app9422791);
}};
$e27812782.stack[R.EXN_STACKHEIGHT++] = $ss27852786;
}
if(R.isPyretException($e27812782)) {
$e27812782.pyretStack.push(L[307]);
}
throw $e27812782;
}
var $ret27872788 = $Hcont_tail_app18272792($z27832784);
++R.GAS;
return $ret27872788;
}
} else {
var cont_tail_arg9392795 = R.throwNonBooleanOp(L[311],("first"),("and"),and_DASH_oper_DASH_1072750);
if(--R.GAS > 0) {
$z27932794 = R.isFunction(if_helper9372779)?if_helper9372779.app(cont_tail_arg9392795):R.ffi.throwNonFunApp(L[311],if_helper9372779,[cont_tail_arg9392795]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper9372779)?if_helper9372779.app(cont_tail_arg9392795):R.ffi.throwNonFunApp(L[311],if_helper9372779,[cont_tail_arg9392795]);
},
"from":L[311]});
}
++R.GAS;
return $z27932794;
}
};
var $Hand_DASH_oper_DASH_18262780 = function(and_DASH_oper_DASH_1092778,_check3642733,args_DASH_env3652732,body3632736,if_helper9372779,self3582737) {
var anf_if9472828 = R.isBoolean(and_DASH_oper_DASH_1092778);
if(R.isPyretTrue(anf_if9472828)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1092778)) {
var anf_fun9492809 = G(body3632736,"visit",L[312]);
var anf_arg9502810 = self3582737.extendWith({"env":args_DASH_env3652732});
var $z28012802 = D;
var $f28072808 = function(_) {
return R.isFunction(anf_fun9492809)?anf_fun9492809.app(anf_arg9502810):R.ffi.throwNonFunApp(L[307],anf_fun9492809,[anf_arg9502810]);
};
try {
if(--R.GAS > 0) {
$z28012802 = $f28072808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28072808,
"from":L[307]});
}
} catch($e27992800) {
if(R.isCont($e27992800)) {
var $ss28032804 = {"from":L[307],
"go":function(and_DASH_oper_DASH_1102811) {
return $Hand_DASH_oper_DASH_18242812(and_DASH_oper_DASH_1102811,_check3642733,args_DASH_env3652732,if_helper9372779,self3582737);
}};
$e27992800.stack[R.EXN_STACKHEIGHT++] = $ss28032804;
}
if(R.isPyretException($e27992800)) {
$e27992800.pyretStack.push(L[307]);
}
throw $e27992800;
}
var $ret28052806 = $Hand_DASH_oper_DASH_18242812($z28012802,_check3642733,args_DASH_env3652732,if_helper9372779,self3582737);
++R.GAS;
return $ret28052806;
} else {
var $z28152816 = D;
var $f28212822 = function(_) {
return R.isFunction(if_helper9372779)?if_helper9372779.app((false)):R.ffi.throwNonFunApp(L[307],if_helper9372779,[(false)]);
};
try {
if(--R.GAS > 0) {
$z28152816 = $f28212822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28212822,
"from":L[307]});
}
} catch($e28132814) {
if(R.isCont($e28132814)) {
var $ss28172818 = {"from":L[307],
"go":function(cont_tail_app9482823) {
return $Hcont_tail_app18252824(cont_tail_app9482823);
}};
$e28132814.stack[R.EXN_STACKHEIGHT++] = $ss28172818;
}
if(R.isPyretException($e28132814)) {
$e28132814.pyretStack.push(L[307]);
}
throw $e28132814;
}
var $ret28192820 = $Hcont_tail_app18252824($z28152816);
++R.GAS;
return $ret28192820;
}
} else {
var cont_tail_arg9452827 = R.throwNonBooleanOp(L[313],("first"),("and"),and_DASH_oper_DASH_1092778);
if(--R.GAS > 0) {
$z28252826 = R.isFunction(if_helper9372779)?if_helper9372779.app(cont_tail_arg9452827):R.ffi.throwNonFunApp(L[313],if_helper9372779,[cont_tail_arg9452827]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper9372779)?if_helper9372779.app(cont_tail_arg9452827):R.ffi.throwNonFunApp(L[313],if_helper9372779,[cont_tail_arg9452827]);
},
"from":L[313]});
}
++R.GAS;
return $z28252826;
}
};
var $Hand_DASH_oper_DASH_18242812 = function(and_DASH_oper_DASH_1102811,_check3642733,args_DASH_env3652732,if_helper9372779,self3582737) {
var anf_if9532858 = R.isBoolean(and_DASH_oper_DASH_1102811);
if(R.isPyretTrue(anf_if9532858)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1102811)) {
var anf_bracket9552842 = self3582737.extendWith({"env":args_DASH_env3652732});
var anf_fun9562839 = G(anf_bracket9552842,"option",L[314]);
var $z28312832 = D;
var $f28372838 = function(_) {
return R.isFunction(anf_fun9562839)?anf_fun9562839.app(_check3642733):R.ffi.throwNonFunApp(L[307],anf_fun9562839,[_check3642733]);
};
try {
if(--R.GAS > 0) {
$z28312832 = $f28372838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28372838,
"from":L[307]});
}
} catch($e28292830) {
if(R.isCont($e28292830)) {
var $ss28332834 = {"from":L[307],
"go":function(and_DASH_oper_DASH_1112840) {
return $Hand_DASH_oper_DASH_18222841(and_DASH_oper_DASH_1112840,if_helper9372779);
}};
$e28292830.stack[R.EXN_STACKHEIGHT++] = $ss28332834;
}
if(R.isPyretException($e28292830)) {
$e28292830.pyretStack.push(L[307]);
}
throw $e28292830;
}
var $ret28352836 = $Hand_DASH_oper_DASH_18222841($z28312832,if_helper9372779);
++R.GAS;
return $ret28352836;
} else {
var $z28452846 = D;
var $f28512852 = function(_) {
return R.isFunction(if_helper9372779)?if_helper9372779.app((false)):R.ffi.throwNonFunApp(L[307],if_helper9372779,[(false)]);
};
try {
if(--R.GAS > 0) {
$z28452846 = $f28512852();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28512852,
"from":L[307]});
}
} catch($e28432844) {
if(R.isCont($e28432844)) {
var $ss28472848 = {"from":L[307],
"go":function(cont_tail_app9542853) {
return $Hcont_tail_app18232854(cont_tail_app9542853);
}};
$e28432844.stack[R.EXN_STACKHEIGHT++] = $ss28472848;
}
if(R.isPyretException($e28432844)) {
$e28432844.pyretStack.push(L[307]);
}
throw $e28432844;
}
var $ret28492850 = $Hcont_tail_app18232854($z28452846);
++R.GAS;
return $ret28492850;
}
} else {
var cont_tail_arg9512857 = R.throwNonBooleanOp(L[315],("first"),("and"),and_DASH_oper_DASH_1102811);
if(--R.GAS > 0) {
$z28552856 = R.isFunction(if_helper9372779)?if_helper9372779.app(cont_tail_arg9512857):R.ffi.throwNonFunApp(L[315],if_helper9372779,[cont_tail_arg9512857]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper9372779)?if_helper9372779.app(cont_tail_arg9512857):R.ffi.throwNonFunApp(L[315],if_helper9372779,[cont_tail_arg9512857]);
},
"from":L[315]});
}
++R.GAS;
return $z28552856;
}
};
var $Hand_DASH_oper_DASH_18222841 = function(and_DASH_oper_DASH_1112840,if_helper9372779) {
var anf_if9592874 = R.isBoolean(and_DASH_oper_DASH_1112840);
if(R.isPyretTrue(anf_if9592874)) {
var $z28612862 = D;
var $f28672868 = function(_) {
return R.isFunction(if_helper9372779)?if_helper9372779.app(and_DASH_oper_DASH_1112840):R.ffi.throwNonFunApp(L[307],if_helper9372779,[and_DASH_oper_DASH_1112840]);
};
try {
if(--R.GAS > 0) {
$z28612862 = $f28672868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28672868,
"from":L[307]});
}
} catch($e28592860) {
if(R.isCont($e28592860)) {
var $ss28632864 = {"from":L[307],
"go":function(cont_tail_app9602869) {
return $Hcont_tail_app18212870(cont_tail_app9602869);
}};
$e28592860.stack[R.EXN_STACKHEIGHT++] = $ss28632864;
}
if(R.isPyretException($e28592860)) {
$e28592860.pyretStack.push(L[307]);
}
throw $e28592860;
}
var $ret28652866 = $Hcont_tail_app18212870($z28612862);
++R.GAS;
return $ret28652866;
} else {
var cont_tail_arg9572873 = R.throwNonBooleanOp(L[316],("second"),("and"),and_DASH_oper_DASH_1112840);
if(--R.GAS > 0) {
$z28712872 = R.isFunction(if_helper9372779)?if_helper9372779.app(cont_tail_arg9572873):R.ffi.throwNonFunApp(L[316],if_helper9372779,[cont_tail_arg9572873]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper9372779)?if_helper9372779.app(cont_tail_arg9572873):R.ffi.throwNonFunApp(L[316],if_helper9372779,[cont_tail_arg9572873]);
},
"from":L[316]});
}
++R.GAS;
return $z28712872;
}
};
var $Hcont_tail_app18212870 = function(cont_tail_app9602869) {
return cont_tail_app9602869;
};
var $Hcont_tail_app18232854 = function(cont_tail_app9542853) {
return cont_tail_app9542853;
};
var $Hcont_tail_app18252824 = function(cont_tail_app9482823) {
return cont_tail_app9482823;
};
var $Hcont_tail_app18272792 = function(cont_tail_app9422791) {
return cont_tail_app9422791;
};
var $Hann_DASH_check_DASH_temp18202765 = function(ann_DASH_check_DASH_temp9342764) {
return ann_DASH_check_DASH_temp9342764;
};
var $Hann_DASH_check_DASH_temp18192875 = function(ann_DASH_check_DASH_temp9292876) {
return ann_DASH_check_DASH_temp9292876;
};
var $Hnew_DASH_type_DASH_env18182877 = function(new_DASH_type_DASH_env3542878,_check3532879,lists1523,mixins3502880,namet3482881,self3452882,shared_DASH_members3522883,variants3512884) {
var with_DASH_params3572896 = self3452882.extendWith({"type-env":new_DASH_type_DASH_env3542878});
var anf_fun8902895 = G(namet3482881,"visit",L[318]);
var $z28872888 = D;
var $f28932894 = function(_) {
return R.isFunction(anf_fun8902895)?anf_fun8902895.app(with_DASH_params3572896):R.ffi.throwNonFunApp(L[317],anf_fun8902895,[with_DASH_params3572896]);
};
try {
if(--R.GAS > 0) {
$z28872888 = $f28932894();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28932894,
"from":L[317]});
}
} catch($e28852886) {
if(R.isCont($e28852886)) {
var $ss28892890 = {"from":L[317],
"go":function(and_DASH_oper_DASH_992897) {
return $Hand_DASH_oper_DASH_18172898(and_DASH_oper_DASH_992897,_check3532879,lists1523,mixins3502880,shared_DASH_members3522883,variants3512884,with_DASH_params3572896);
}};
$e28852886.stack[R.EXN_STACKHEIGHT++] = $ss28892890;
}
if(R.isPyretException($e28852886)) {
$e28852886.pyretStack.push(L[317]);
}
throw $e28852886;
}
var $ret28912892 = $Hand_DASH_oper_DASH_18172898($z28872888,_check3532879,lists1523,mixins3502880,shared_DASH_members3522883,variants3512884,with_DASH_params3572896);
++R.GAS;
return $ret28912892;
};
var $Hand_DASH_oper_DASH_18172898 = function(and_DASH_oper_DASH_992897,_check3532879,lists1523,mixins3502880,shared_DASH_members3522883,variants3512884,with_DASH_params3572896) {
var if_helper8912912 = R.makeFunction(function(if_helper_arg8922944) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[317],1,arguments);
}
var ann_DASH_check_DASH_temp8842945 = if_helper_arg8922944;
return ann_DASH_check_DASH_temp8842945;
});
var anf_if8952943 = R.isBoolean(and_DASH_oper_DASH_992897);
if(R.isPyretTrue(anf_if8952943)) {
if(R.isPyretTrue(and_DASH_oper_DASH_992897)) {
var anf_fun8972909 = G(lists1523,"all",L[320]);
var anf_arg9002910 = R.makeFunction(function(recv_DASH_1012914) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[319],1,arguments);
}
var anf_fun8992925 = G(recv_DASH_1012914,"visit",L[319]);
var $z29172918 = D;
var $f29232924 = function(_) {
return R.isFunction(anf_fun8992925)?anf_fun8992925.app(with_DASH_params3572896):R.ffi.throwNonFunApp(L[319],anf_fun8992925,[with_DASH_params3572896]);
};
try {
if(--R.GAS > 0) {
$z29172918 = $f29232924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29232924,
"from":L[319]});
}
} catch($e29152916) {
if(R.isCont($e29152916)) {
var $ss29192920 = {"from":L[319],
"go":function(ann_DASH_check_DASH_temp8982926) {
return $Hann_DASH_check_DASH_temp18052927(ann_DASH_check_DASH_temp8982926);
}};
$e29152916.stack[R.EXN_STACKHEIGHT++] = $ss29192920;
}
if(R.isPyretException($e29152916)) {
$e29152916.pyretStack.push(L[319]);
}
throw $e29152916;
}
var $ret29212922 = $Hann_DASH_check_DASH_temp18052927($z29172918);
++R.GAS;
return $ret29212922;
});
var $z29012902 = D;
var $f29072908 = function(_) {
return R.isFunction(anf_fun8972909)?anf_fun8972909.app(anf_arg9002910,mixins3502880):R.ffi.throwNonFunApp(L[317],anf_fun8972909,[anf_arg9002910,mixins3502880]);
};
try {
if(--R.GAS > 0) {
$z29012902 = $f29072908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29072908,
"from":L[317]});
}
} catch($e28992900) {
if(R.isCont($e28992900)) {
var $ss29032904 = {"from":L[317],
"go":function(and_DASH_oper_DASH_1002911) {
return $Hand_DASH_oper_DASH_18152913(and_DASH_oper_DASH_1002911,_check3532879,if_helper8912912,lists1523,shared_DASH_members3522883,variants3512884,with_DASH_params3572896);
}};
$e28992900.stack[R.EXN_STACKHEIGHT++] = $ss29032904;
}
if(R.isPyretException($e28992900)) {
$e28992900.pyretStack.push(L[317]);
}
throw $e28992900;
}
var $ret29052906 = $Hand_DASH_oper_DASH_18152913($z29012902,_check3532879,if_helper8912912,lists1523,shared_DASH_members3522883,variants3512884,with_DASH_params3572896);
++R.GAS;
return $ret29052906;
} else {
var $z29302931 = D;
var $f29362937 = function(_) {
return R.isFunction(if_helper8912912)?if_helper8912912.app((false)):R.ffi.throwNonFunApp(L[317],if_helper8912912,[(false)]);
};
try {
if(--R.GAS > 0) {
$z29302931 = $f29362937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29362937,
"from":L[317]});
}
} catch($e29282929) {
if(R.isCont($e29282929)) {
var $ss29322933 = {"from":L[317],
"go":function(cont_tail_app8962938) {
return $Hcont_tail_app18162939(cont_tail_app8962938);
}};
$e29282929.stack[R.EXN_STACKHEIGHT++] = $ss29322933;
}
if(R.isPyretException($e29282929)) {
$e29282929.pyretStack.push(L[317]);
}
throw $e29282929;
}
var $ret29342935 = $Hcont_tail_app18162939($z29302931);
++R.GAS;
return $ret29342935;
}
} else {
var cont_tail_arg8932942 = R.throwNonBooleanOp(L[321],("first"),("and"),and_DASH_oper_DASH_992897);
if(--R.GAS > 0) {
$z29402941 = R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg8932942):R.ffi.throwNonFunApp(L[321],if_helper8912912,[cont_tail_arg8932942]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg8932942):R.ffi.throwNonFunApp(L[321],if_helper8912912,[cont_tail_arg8932942]);
},
"from":L[321]});
}
++R.GAS;
return $z29402941;
}
};
var $Hand_DASH_oper_DASH_18152913 = function(and_DASH_oper_DASH_1002911,_check3532879,if_helper8912912,lists1523,shared_DASH_members3522883,variants3512884,with_DASH_params3572896) {
var anf_if9032989 = R.isBoolean(and_DASH_oper_DASH_1002911);
if(R.isPyretTrue(anf_if9032989)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1002911)) {
var anf_fun9052956 = G(lists1523,"all",L[323]);
var anf_arg9082957 = R.makeFunction(function(recv_DASH_1032960) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[322],1,arguments);
}
var anf_fun9072971 = G(recv_DASH_1032960,"visit",L[322]);
var $z29632964 = D;
var $f29692970 = function(_) {
return R.isFunction(anf_fun9072971)?anf_fun9072971.app(with_DASH_params3572896):R.ffi.throwNonFunApp(L[322],anf_fun9072971,[with_DASH_params3572896]);
};
try {
if(--R.GAS > 0) {
$z29632964 = $f29692970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29692970,
"from":L[322]});
}
} catch($e29612962) {
if(R.isCont($e29612962)) {
var $ss29652966 = {"from":L[322],
"go":function(ann_DASH_check_DASH_temp9062972) {
return $Hann_DASH_check_DASH_temp18062973(ann_DASH_check_DASH_temp9062972);
}};
$e29612962.stack[R.EXN_STACKHEIGHT++] = $ss29652966;
}
if(R.isPyretException($e29612962)) {
$e29612962.pyretStack.push(L[322]);
}
throw $e29612962;
}
var $ret29672968 = $Hann_DASH_check_DASH_temp18062973($z29632964);
++R.GAS;
return $ret29672968;
});
var $z29482949 = D;
var $f29542955 = function(_) {
return R.isFunction(anf_fun9052956)?anf_fun9052956.app(anf_arg9082957,variants3512884):R.ffi.throwNonFunApp(L[317],anf_fun9052956,[anf_arg9082957,variants3512884]);
};
try {
if(--R.GAS > 0) {
$z29482949 = $f29542955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29542955,
"from":L[317]});
}
} catch($e29462947) {
if(R.isCont($e29462947)) {
var $ss29502951 = {"from":L[317],
"go":function(and_DASH_oper_DASH_1022958) {
return $Hand_DASH_oper_DASH_18132959(and_DASH_oper_DASH_1022958,_check3532879,if_helper8912912,lists1523,shared_DASH_members3522883,with_DASH_params3572896);
}};
$e29462947.stack[R.EXN_STACKHEIGHT++] = $ss29502951;
}
if(R.isPyretException($e29462947)) {
$e29462947.pyretStack.push(L[317]);
}
throw $e29462947;
}
var $ret29522953 = $Hand_DASH_oper_DASH_18132959($z29482949,_check3532879,if_helper8912912,lists1523,shared_DASH_members3522883,with_DASH_params3572896);
++R.GAS;
return $ret29522953;
} else {
var $z29762977 = D;
var $f29822983 = function(_) {
return R.isFunction(if_helper8912912)?if_helper8912912.app((false)):R.ffi.throwNonFunApp(L[317],if_helper8912912,[(false)]);
};
try {
if(--R.GAS > 0) {
$z29762977 = $f29822983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29822983,
"from":L[317]});
}
} catch($e29742975) {
if(R.isCont($e29742975)) {
var $ss29782979 = {"from":L[317],
"go":function(cont_tail_app9042984) {
return $Hcont_tail_app18142985(cont_tail_app9042984);
}};
$e29742975.stack[R.EXN_STACKHEIGHT++] = $ss29782979;
}
if(R.isPyretException($e29742975)) {
$e29742975.pyretStack.push(L[317]);
}
throw $e29742975;
}
var $ret29802981 = $Hcont_tail_app18142985($z29762977);
++R.GAS;
return $ret29802981;
}
} else {
var cont_tail_arg9012988 = R.throwNonBooleanOp(L[324],("first"),("and"),and_DASH_oper_DASH_1002911);
if(--R.GAS > 0) {
$z29862987 = R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg9012988):R.ffi.throwNonFunApp(L[324],if_helper8912912,[cont_tail_arg9012988]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg9012988):R.ffi.throwNonFunApp(L[324],if_helper8912912,[cont_tail_arg9012988]);
},
"from":L[324]});
}
++R.GAS;
return $z29862987;
}
};
var $Hand_DASH_oper_DASH_18132959 = function(and_DASH_oper_DASH_1022958,_check3532879,if_helper8912912,lists1523,shared_DASH_members3522883,with_DASH_params3572896) {
var anf_if9113033 = R.isBoolean(and_DASH_oper_DASH_1022958);
if(R.isPyretTrue(anf_if9113033)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1022958)) {
var anf_fun9133000 = G(lists1523,"all",L[326]);
var anf_arg9163001 = R.makeFunction(function(recv_DASH_1053004) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[325],1,arguments);
}
var anf_fun9153015 = G(recv_DASH_1053004,"visit",L[325]);
var $z30073008 = D;
var $f30133014 = function(_) {
return R.isFunction(anf_fun9153015)?anf_fun9153015.app(with_DASH_params3572896):R.ffi.throwNonFunApp(L[325],anf_fun9153015,[with_DASH_params3572896]);
};
try {
if(--R.GAS > 0) {
$z30073008 = $f30133014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30133014,
"from":L[325]});
}
} catch($e30053006) {
if(R.isCont($e30053006)) {
var $ss30093010 = {"from":L[325],
"go":function(ann_DASH_check_DASH_temp9143016) {
return $Hann_DASH_check_DASH_temp18073017(ann_DASH_check_DASH_temp9143016);
}};
$e30053006.stack[R.EXN_STACKHEIGHT++] = $ss30093010;
}
if(R.isPyretException($e30053006)) {
$e30053006.pyretStack.push(L[325]);
}
throw $e30053006;
}
var $ret30113012 = $Hann_DASH_check_DASH_temp18073017($z30073008);
++R.GAS;
return $ret30113012;
});
var $z29922993 = D;
var $f29982999 = function(_) {
return R.isFunction(anf_fun9133000)?anf_fun9133000.app(anf_arg9163001,shared_DASH_members3522883):R.ffi.throwNonFunApp(L[317],anf_fun9133000,[anf_arg9163001,shared_DASH_members3522883]);
};
try {
if(--R.GAS > 0) {
$z29922993 = $f29982999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29982999,
"from":L[317]});
}
} catch($e29902991) {
if(R.isCont($e29902991)) {
var $ss29942995 = {"from":L[317],
"go":function(and_DASH_oper_DASH_1043002) {
return $Hand_DASH_oper_DASH_18113003(and_DASH_oper_DASH_1043002,_check3532879,if_helper8912912,with_DASH_params3572896);
}};
$e29902991.stack[R.EXN_STACKHEIGHT++] = $ss29942995;
}
if(R.isPyretException($e29902991)) {
$e29902991.pyretStack.push(L[317]);
}
throw $e29902991;
}
var $ret29962997 = $Hand_DASH_oper_DASH_18113003($z29922993,_check3532879,if_helper8912912,with_DASH_params3572896);
++R.GAS;
return $ret29962997;
} else {
var $z30203021 = D;
var $f30263027 = function(_) {
return R.isFunction(if_helper8912912)?if_helper8912912.app((false)):R.ffi.throwNonFunApp(L[317],if_helper8912912,[(false)]);
};
try {
if(--R.GAS > 0) {
$z30203021 = $f30263027();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30263027,
"from":L[317]});
}
} catch($e30183019) {
if(R.isCont($e30183019)) {
var $ss30223023 = {"from":L[317],
"go":function(cont_tail_app9123028) {
return $Hcont_tail_app18123029(cont_tail_app9123028);
}};
$e30183019.stack[R.EXN_STACKHEIGHT++] = $ss30223023;
}
if(R.isPyretException($e30183019)) {
$e30183019.pyretStack.push(L[317]);
}
throw $e30183019;
}
var $ret30243025 = $Hcont_tail_app18123029($z30203021);
++R.GAS;
return $ret30243025;
}
} else {
var cont_tail_arg9093032 = R.throwNonBooleanOp(L[327],("first"),("and"),and_DASH_oper_DASH_1022958);
if(--R.GAS > 0) {
$z30303031 = R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg9093032):R.ffi.throwNonFunApp(L[327],if_helper8912912,[cont_tail_arg9093032]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg9093032):R.ffi.throwNonFunApp(L[327],if_helper8912912,[cont_tail_arg9093032]);
},
"from":L[327]});
}
++R.GAS;
return $z30303031;
}
};
var $Hand_DASH_oper_DASH_18113003 = function(and_DASH_oper_DASH_1043002,_check3532879,if_helper8912912,with_DASH_params3572896) {
var anf_if9193062 = R.isBoolean(and_DASH_oper_DASH_1043002);
if(R.isPyretTrue(anf_if9193062)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1043002)) {
var anf_fun9213044 = G(with_DASH_params3572896,"option",L[328]);
var $z30363037 = D;
var $f30423043 = function(_) {
return R.isFunction(anf_fun9213044)?anf_fun9213044.app(_check3532879):R.ffi.throwNonFunApp(L[317],anf_fun9213044,[_check3532879]);
};
try {
if(--R.GAS > 0) {
$z30363037 = $f30423043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30423043,
"from":L[317]});
}
} catch($e30343035) {
if(R.isCont($e30343035)) {
var $ss30383039 = {"from":L[317],
"go":function(and_DASH_oper_DASH_1063045) {
return $Hand_DASH_oper_DASH_18093046(and_DASH_oper_DASH_1063045,if_helper8912912);
}};
$e30343035.stack[R.EXN_STACKHEIGHT++] = $ss30383039;
}
if(R.isPyretException($e30343035)) {
$e30343035.pyretStack.push(L[317]);
}
throw $e30343035;
}
var $ret30403041 = $Hand_DASH_oper_DASH_18093046($z30363037,if_helper8912912);
++R.GAS;
return $ret30403041;
} else {
var $z30493050 = D;
var $f30553056 = function(_) {
return R.isFunction(if_helper8912912)?if_helper8912912.app((false)):R.ffi.throwNonFunApp(L[317],if_helper8912912,[(false)]);
};
try {
if(--R.GAS > 0) {
$z30493050 = $f30553056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30553056,
"from":L[317]});
}
} catch($e30473048) {
if(R.isCont($e30473048)) {
var $ss30513052 = {"from":L[317],
"go":function(cont_tail_app9203057) {
return $Hcont_tail_app18103058(cont_tail_app9203057);
}};
$e30473048.stack[R.EXN_STACKHEIGHT++] = $ss30513052;
}
if(R.isPyretException($e30473048)) {
$e30473048.pyretStack.push(L[317]);
}
throw $e30473048;
}
var $ret30533054 = $Hcont_tail_app18103058($z30493050);
++R.GAS;
return $ret30533054;
}
} else {
var cont_tail_arg9173061 = R.throwNonBooleanOp(L[329],("first"),("and"),and_DASH_oper_DASH_1043002);
if(--R.GAS > 0) {
$z30593060 = R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg9173061):R.ffi.throwNonFunApp(L[329],if_helper8912912,[cont_tail_arg9173061]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg9173061):R.ffi.throwNonFunApp(L[329],if_helper8912912,[cont_tail_arg9173061]);
},
"from":L[329]});
}
++R.GAS;
return $z30593060;
}
};
var $Hand_DASH_oper_DASH_18093046 = function(and_DASH_oper_DASH_1063045,if_helper8912912) {
var anf_if9243078 = R.isBoolean(and_DASH_oper_DASH_1063045);
if(R.isPyretTrue(anf_if9243078)) {
var $z30653066 = D;
var $f30713072 = function(_) {
return R.isFunction(if_helper8912912)?if_helper8912912.app(and_DASH_oper_DASH_1063045):R.ffi.throwNonFunApp(L[317],if_helper8912912,[and_DASH_oper_DASH_1063045]);
};
try {
if(--R.GAS > 0) {
$z30653066 = $f30713072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30713072,
"from":L[317]});
}
} catch($e30633064) {
if(R.isCont($e30633064)) {
var $ss30673068 = {"from":L[317],
"go":function(cont_tail_app9253073) {
return $Hcont_tail_app18083074(cont_tail_app9253073);
}};
$e30633064.stack[R.EXN_STACKHEIGHT++] = $ss30673068;
}
if(R.isPyretException($e30633064)) {
$e30633064.pyretStack.push(L[317]);
}
throw $e30633064;
}
var $ret30693070 = $Hcont_tail_app18083074($z30653066);
++R.GAS;
return $ret30693070;
} else {
var cont_tail_arg9223077 = R.throwNonBooleanOp(L[330],("second"),("and"),and_DASH_oper_DASH_1063045);
if(--R.GAS > 0) {
$z30753076 = R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg9223077):R.ffi.throwNonFunApp(L[330],if_helper8912912,[cont_tail_arg9223077]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8912912)?if_helper8912912.app(cont_tail_arg9223077):R.ffi.throwNonFunApp(L[330],if_helper8912912,[cont_tail_arg9223077]);
},
"from":L[330]});
}
++R.GAS;
return $z30753076;
}
};
var $Hcont_tail_app18083074 = function(cont_tail_app9253073) {
return cont_tail_app9253073;
};
var $Hcont_tail_app18103058 = function(cont_tail_app9203057) {
return cont_tail_app9203057;
};
var $Hann_DASH_check_DASH_temp18073017 = function(ann_DASH_check_DASH_temp9143016) {
return ann_DASH_check_DASH_temp9143016;
};
var $Hcont_tail_app18123029 = function(cont_tail_app9123028) {
return cont_tail_app9123028;
};
var $Hann_DASH_check_DASH_temp18062973 = function(ann_DASH_check_DASH_temp9062972) {
return ann_DASH_check_DASH_temp9062972;
};
var $Hcont_tail_app18142985 = function(cont_tail_app9042984) {
return cont_tail_app9042984;
};
var $Hann_DASH_check_DASH_temp18052927 = function(ann_DASH_check_DASH_temp8982926) {
return ann_DASH_check_DASH_temp8982926;
};
var $Hcont_tail_app18162939 = function(cont_tail_app8962938) {
return cont_tail_app8962938;
};
var $Hann_DASH_check_DASH_temp18043079 = function(ann_DASH_check_DASH_temp8863080) {
return ann_DASH_check_DASH_temp8863080;
};
var $Hnew_DASH_type_DASH_env18033081 = function(new_DASH_type_DASH_env3363082,_check3353083,ann3323084,args3313085,bind_DASH_handlers2853086,body3343087,lists1523,self3283088) {
var with_DASH_params3393102 = self3283088.extendWith({"type-env":new_DASH_type_DASH_env3363082});
var anf_fun8533099 = G(lists1523,"all",L[333]);
var anf_arg8563100 = R.makeFunction(function(recv_DASH_943104) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[332],1,arguments);
}
var anf_fun8553115 = G(recv_DASH_943104,"visit",L[332]);
var $z31073108 = D;
var $f31133114 = function(_) {
return R.isFunction(anf_fun8553115)?anf_fun8553115.app(with_DASH_params3393102):R.ffi.throwNonFunApp(L[332],anf_fun8553115,[with_DASH_params3393102]);
};
try {
if(--R.GAS > 0) {
$z31073108 = $f31133114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31133114,
"from":L[332]});
}
} catch($e31053106) {
if(R.isCont($e31053106)) {
var $ss31093110 = {"from":L[332],
"go":function(ann_DASH_check_DASH_temp8543116) {
return $Hann_DASH_check_DASH_temp17923117(ann_DASH_check_DASH_temp8543116);
}};
$e31053106.stack[R.EXN_STACKHEIGHT++] = $ss31093110;
}
if(R.isPyretException($e31053106)) {
$e31053106.pyretStack.push(L[332]);
}
throw $e31053106;
}
var $ret31113112 = $Hann_DASH_check_DASH_temp17923117($z31073108);
++R.GAS;
return $ret31113112;
});
var $z30913092 = D;
var $f30973098 = function(_) {
return R.isFunction(anf_fun8533099)?anf_fun8533099.app(anf_arg8563100,args3313085):R.ffi.throwNonFunApp(L[331],anf_fun8533099,[anf_arg8563100,args3313085]);
};
try {
if(--R.GAS > 0) {
$z30913092 = $f30973098();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30973098,
"from":L[331]});
}
} catch($e30893090) {
if(R.isCont($e30893090)) {
var $ss30933094 = {"from":L[331],
"go":function(visit_DASH_args3403101) {
return $Hvisit_DASH_args18023103(visit_DASH_args3403101,_check3353083,ann3323084,args3313085,bind_DASH_handlers2853086,body3343087,lists1523,with_DASH_params3393102);
}};
$e30893090.stack[R.EXN_STACKHEIGHT++] = $ss30933094;
}
if(R.isPyretException($e30893090)) {
$e30893090.pyretStack.push(L[331]);
}
throw $e30893090;
}
var $ret30953096 = $Hvisit_DASH_args18023103($z30913092,_check3353083,ann3323084,args3313085,bind_DASH_handlers2853086,body3343087,lists1523,with_DASH_params3393102);
++R.GAS;
return $ret30953096;
};
var $Hvisit_DASH_args18023103 = function(visit_DASH_args3403101,_check3353083,ann3323084,args3313085,bind_DASH_handlers2853086,body3343087,lists1523,with_DASH_params3393102) {
var anf_fun8573128 = G(lists1523,"fold",L[338]);
var anf_arg8603129 = R.makeFunction(function(acc3423133,arg3433134) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[336],2,arguments);
}
var anf_fun8593145 = G(bind_DASH_handlers2853086,"s-bind",L[337]);
var $z31373138 = D;
var $f31433144 = function(_) {
return R.isFunction(anf_fun8593145)?anf_fun8593145.app(arg3433134,acc3423133):R.ffi.throwNonFunApp(L[336],anf_fun8593145,[arg3433134,acc3423133]);
};
try {
if(--R.GAS > 0) {
$z31373138 = $f31433144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31433144,
"from":L[336]});
}
} catch($e31353136) {
if(R.isCont($e31353136)) {
var $ss31393140 = {"from":L[336],
"go":function(ann_DASH_check_DASH_temp8583146) {
return $Hann_DASH_check_DASH_temp17933147(ann_DASH_check_DASH_temp8583146);
}};
$e31353136.stack[R.EXN_STACKHEIGHT++] = $ss31393140;
}
if(R.isPyretException($e31353136)) {
$e31353136.pyretStack.push(L[336]);
}
throw $e31353136;
}
var $ret31413142 = $Hann_DASH_check_DASH_temp17933147($z31373138);
++R.GAS;
return $ret31413142;
});
var anf_arg8613130 = G(with_DASH_params3393102,"env",L[335]);
var $z31203121 = D;
var $f31263127 = function(_) {
return R.isFunction(anf_fun8573128)?anf_fun8573128.app(anf_arg8603129,anf_arg8613130,args3313085):R.ffi.throwNonFunApp(L[334],anf_fun8573128,[anf_arg8603129,anf_arg8613130,args3313085]);
};
try {
if(--R.GAS > 0) {
$z31203121 = $f31263127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31263127,
"from":L[334]});
}
} catch($e31183119) {
if(R.isCont($e31183119)) {
var $ss31223123 = {"from":L[334],
"go":function(args_DASH_env3413131) {
return $Hargs_DASH_env18013132(args_DASH_env3413131,_check3353083,ann3323084,body3343087,visit_DASH_args3403101,with_DASH_params3393102);
}};
$e31183119.stack[R.EXN_STACKHEIGHT++] = $ss31223123;
}
if(R.isPyretException($e31183119)) {
$e31183119.pyretStack.push(L[334]);
}
throw $e31183119;
}
var $ret31243125 = $Hargs_DASH_env18013132($z31203121,_check3353083,ann3323084,body3343087,visit_DASH_args3403101,with_DASH_params3393102);
++R.GAS;
return $ret31243125;
};
var $Hargs_DASH_env18013132 = function(args_DASH_env3413131,_check3353083,ann3323084,body3343087,visit_DASH_args3403101,with_DASH_params3393102) {
var with_DASH_args3443159 = with_DASH_params3393102.extendWith({"env":args_DASH_env3413131});
var and_DASH_oper_DASH_953175 = visit_DASH_args3403101;
var if_helper8623161 = R.makeFunction(function(if_helper_arg8633180) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[339],1,arguments);
}
var ann_DASH_check_DASH_temp8473181 = if_helper_arg8633180;
return ann_DASH_check_DASH_temp8473181;
});
var anf_if8663179 = R.isBoolean(and_DASH_oper_DASH_953175);
if(R.isPyretTrue(anf_if8663179)) {
if(R.isPyretTrue(and_DASH_oper_DASH_953175)) {
var anf_fun8683158 = G(ann3323084,"visit",L[340]);
var $z31503151 = D;
var $f31563157 = function(_) {
return R.isFunction(anf_fun8683158)?anf_fun8683158.app(with_DASH_args3443159):R.ffi.throwNonFunApp(L[339],anf_fun8683158,[with_DASH_args3443159]);
};
try {
if(--R.GAS > 0) {
$z31503151 = $f31563157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31563157,
"from":L[339]});
}
} catch($e31483149) {
if(R.isCont($e31483149)) {
var $ss31523153 = {"from":L[339],
"go":function(and_DASH_oper_DASH_963160) {
return $Hand_DASH_oper_DASH_17993162(and_DASH_oper_DASH_963160,_check3353083,body3343087,if_helper8623161,with_DASH_args3443159);
}};
$e31483149.stack[R.EXN_STACKHEIGHT++] = $ss31523153;
}
if(R.isPyretException($e31483149)) {
$e31483149.pyretStack.push(L[339]);
}
throw $e31483149;
}
var $ret31543155 = $Hand_DASH_oper_DASH_17993162($z31503151,_check3353083,body3343087,if_helper8623161,with_DASH_args3443159);
++R.GAS;
return $ret31543155;
} else {
var $z31653166 = D;
var $f31713172 = function(_) {
return R.isFunction(if_helper8623161)?if_helper8623161.app((false)):R.ffi.throwNonFunApp(L[339],if_helper8623161,[(false)]);
};
try {
if(--R.GAS > 0) {
$z31653166 = $f31713172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31713172,
"from":L[339]});
}
} catch($e31633164) {
if(R.isCont($e31633164)) {
var $ss31673168 = {"from":L[339],
"go":function(cont_tail_app8673173) {
return $Hcont_tail_app18003174(cont_tail_app8673173);
}};
$e31633164.stack[R.EXN_STACKHEIGHT++] = $ss31673168;
}
if(R.isPyretException($e31633164)) {
$e31633164.pyretStack.push(L[339]);
}
throw $e31633164;
}
var $ret31693170 = $Hcont_tail_app18003174($z31653166);
++R.GAS;
return $ret31693170;
}
} else {
var cont_tail_arg8643178 = R.throwNonBooleanOp(L[341],("first"),("and"),and_DASH_oper_DASH_953175);
if(--R.GAS > 0) {
$z31763177 = R.isFunction(if_helper8623161)?if_helper8623161.app(cont_tail_arg8643178):R.ffi.throwNonFunApp(L[341],if_helper8623161,[cont_tail_arg8643178]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8623161)?if_helper8623161.app(cont_tail_arg8643178):R.ffi.throwNonFunApp(L[341],if_helper8623161,[cont_tail_arg8643178]);
},
"from":L[341]});
}
++R.GAS;
return $z31763177;
}
};
var $Hand_DASH_oper_DASH_17993162 = function(and_DASH_oper_DASH_963160,_check3353083,body3343087,if_helper8623161,with_DASH_args3443159) {
var anf_if8713210 = R.isBoolean(and_DASH_oper_DASH_963160);
if(R.isPyretTrue(anf_if8713210)) {
if(R.isPyretTrue(and_DASH_oper_DASH_963160)) {
var anf_fun8733192 = G(body3343087,"visit",L[342]);
var $z31843185 = D;
var $f31903191 = function(_) {
return R.isFunction(anf_fun8733192)?anf_fun8733192.app(with_DASH_args3443159):R.ffi.throwNonFunApp(L[339],anf_fun8733192,[with_DASH_args3443159]);
};
try {
if(--R.GAS > 0) {
$z31843185 = $f31903191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31903191,
"from":L[339]});
}
} catch($e31823183) {
if(R.isCont($e31823183)) {
var $ss31863187 = {"from":L[339],
"go":function(and_DASH_oper_DASH_973193) {
return $Hand_DASH_oper_DASH_17973194(and_DASH_oper_DASH_973193,_check3353083,if_helper8623161,with_DASH_args3443159);
}};
$e31823183.stack[R.EXN_STACKHEIGHT++] = $ss31863187;
}
if(R.isPyretException($e31823183)) {
$e31823183.pyretStack.push(L[339]);
}
throw $e31823183;
}
var $ret31883189 = $Hand_DASH_oper_DASH_17973194($z31843185,_check3353083,if_helper8623161,with_DASH_args3443159);
++R.GAS;
return $ret31883189;
} else {
var $z31973198 = D;
var $f32033204 = function(_) {
return R.isFunction(if_helper8623161)?if_helper8623161.app((false)):R.ffi.throwNonFunApp(L[339],if_helper8623161,[(false)]);
};
try {
if(--R.GAS > 0) {
$z31973198 = $f32033204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32033204,
"from":L[339]});
}
} catch($e31953196) {
if(R.isCont($e31953196)) {
var $ss31993200 = {"from":L[339],
"go":function(cont_tail_app8723205) {
return $Hcont_tail_app17983206(cont_tail_app8723205);
}};
$e31953196.stack[R.EXN_STACKHEIGHT++] = $ss31993200;
}
if(R.isPyretException($e31953196)) {
$e31953196.pyretStack.push(L[339]);
}
throw $e31953196;
}
var $ret32013202 = $Hcont_tail_app17983206($z31973198);
++R.GAS;
return $ret32013202;
}
} else {
var cont_tail_arg8693209 = R.throwNonBooleanOp(L[343],("first"),("and"),and_DASH_oper_DASH_963160);
if(--R.GAS > 0) {
$z32073208 = R.isFunction(if_helper8623161)?if_helper8623161.app(cont_tail_arg8693209):R.ffi.throwNonFunApp(L[343],if_helper8623161,[cont_tail_arg8693209]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8623161)?if_helper8623161.app(cont_tail_arg8693209):R.ffi.throwNonFunApp(L[343],if_helper8623161,[cont_tail_arg8693209]);
},
"from":L[343]});
}
++R.GAS;
return $z32073208;
}
};
var $Hand_DASH_oper_DASH_17973194 = function(and_DASH_oper_DASH_973193,_check3353083,if_helper8623161,with_DASH_args3443159) {
var anf_if8763239 = R.isBoolean(and_DASH_oper_DASH_973193);
if(R.isPyretTrue(anf_if8763239)) {
if(R.isPyretTrue(and_DASH_oper_DASH_973193)) {
var anf_fun8783221 = G(with_DASH_args3443159,"option",L[344]);
var $z32133214 = D;
var $f32193220 = function(_) {
return R.isFunction(anf_fun8783221)?anf_fun8783221.app(_check3353083):R.ffi.throwNonFunApp(L[339],anf_fun8783221,[_check3353083]);
};
try {
if(--R.GAS > 0) {
$z32133214 = $f32193220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32193220,
"from":L[339]});
}
} catch($e32113212) {
if(R.isCont($e32113212)) {
var $ss32153216 = {"from":L[339],
"go":function(and_DASH_oper_DASH_983222) {
return $Hand_DASH_oper_DASH_17953223(and_DASH_oper_DASH_983222,if_helper8623161);
}};
$e32113212.stack[R.EXN_STACKHEIGHT++] = $ss32153216;
}
if(R.isPyretException($e32113212)) {
$e32113212.pyretStack.push(L[339]);
}
throw $e32113212;
}
var $ret32173218 = $Hand_DASH_oper_DASH_17953223($z32133214,if_helper8623161);
++R.GAS;
return $ret32173218;
} else {
var $z32263227 = D;
var $f32323233 = function(_) {
return R.isFunction(if_helper8623161)?if_helper8623161.app((false)):R.ffi.throwNonFunApp(L[339],if_helper8623161,[(false)]);
};
try {
if(--R.GAS > 0) {
$z32263227 = $f32323233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32323233,
"from":L[339]});
}
} catch($e32243225) {
if(R.isCont($e32243225)) {
var $ss32283229 = {"from":L[339],
"go":function(cont_tail_app8773234) {
return $Hcont_tail_app17963235(cont_tail_app8773234);
}};
$e32243225.stack[R.EXN_STACKHEIGHT++] = $ss32283229;
}
if(R.isPyretException($e32243225)) {
$e32243225.pyretStack.push(L[339]);
}
throw $e32243225;
}
var $ret32303231 = $Hcont_tail_app17963235($z32263227);
++R.GAS;
return $ret32303231;
}
} else {
var cont_tail_arg8743238 = R.throwNonBooleanOp(L[345],("first"),("and"),and_DASH_oper_DASH_973193);
if(--R.GAS > 0) {
$z32363237 = R.isFunction(if_helper8623161)?if_helper8623161.app(cont_tail_arg8743238):R.ffi.throwNonFunApp(L[345],if_helper8623161,[cont_tail_arg8743238]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8623161)?if_helper8623161.app(cont_tail_arg8743238):R.ffi.throwNonFunApp(L[345],if_helper8623161,[cont_tail_arg8743238]);
},
"from":L[345]});
}
++R.GAS;
return $z32363237;
}
};
var $Hand_DASH_oper_DASH_17953223 = function(and_DASH_oper_DASH_983222,if_helper8623161) {
var anf_if8813255 = R.isBoolean(and_DASH_oper_DASH_983222);
if(R.isPyretTrue(anf_if8813255)) {
var $z32423243 = D;
var $f32483249 = function(_) {
return R.isFunction(if_helper8623161)?if_helper8623161.app(and_DASH_oper_DASH_983222):R.ffi.throwNonFunApp(L[339],if_helper8623161,[and_DASH_oper_DASH_983222]);
};
try {
if(--R.GAS > 0) {
$z32423243 = $f32483249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32483249,
"from":L[339]});
}
} catch($e32403241) {
if(R.isCont($e32403241)) {
var $ss32443245 = {"from":L[339],
"go":function(cont_tail_app8823250) {
return $Hcont_tail_app17943251(cont_tail_app8823250);
}};
$e32403241.stack[R.EXN_STACKHEIGHT++] = $ss32443245;
}
if(R.isPyretException($e32403241)) {
$e32403241.pyretStack.push(L[339]);
}
throw $e32403241;
}
var $ret32463247 = $Hcont_tail_app17943251($z32423243);
++R.GAS;
return $ret32463247;
} else {
var cont_tail_arg8793254 = R.throwNonBooleanOp(L[346],("second"),("and"),and_DASH_oper_DASH_983222);
if(--R.GAS > 0) {
$z32523253 = R.isFunction(if_helper8623161)?if_helper8623161.app(cont_tail_arg8793254):R.ffi.throwNonFunApp(L[346],if_helper8623161,[cont_tail_arg8793254]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8623161)?if_helper8623161.app(cont_tail_arg8793254):R.ffi.throwNonFunApp(L[346],if_helper8623161,[cont_tail_arg8793254]);
},
"from":L[346]});
}
++R.GAS;
return $z32523253;
}
};
var $Hcont_tail_app17943251 = function(cont_tail_app8823250) {
return cont_tail_app8823250;
};
var $Hcont_tail_app17963235 = function(cont_tail_app8773234) {
return cont_tail_app8773234;
};
var $Hcont_tail_app17983206 = function(cont_tail_app8723205) {
return cont_tail_app8723205;
};
var $Hcont_tail_app18003174 = function(cont_tail_app8673173) {
return cont_tail_app8673173;
};
var $Hann_DASH_check_DASH_temp17933147 = function(ann_DASH_check_DASH_temp8583146) {
return ann_DASH_check_DASH_temp8583146;
};
var $Hann_DASH_check_DASH_temp17923117 = function(ann_DASH_check_DASH_temp8543116) {
return ann_DASH_check_DASH_temp8543116;
};
var $Hann_DASH_check_DASH_temp17913256 = function(ann_DASH_check_DASH_temp8493257) {
return ann_DASH_check_DASH_temp8493257;
};
var $Hbind_DASH_env17903258 = function(bind_DASH_env3213259,E1121,binds3193260,body3203261,lists1523,self3173262) {
var new_DASH_visitor3243276 = self3173262.extendWith({"env":bind_DASH_env3213259});
var anf_fun8203273 = G(lists1523,"fold-while",L[351]);
var anf_arg8343274 = R.makeFunction(function(acc3263278,b3273279) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[348],2,arguments);
}
var anf_fun8223290 = G(b3273279,"visit",L[350]);
var $z32823283 = D;
var $f32883289 = function(_) {
return R.isFunction(anf_fun8223290)?anf_fun8223290.app(new_DASH_visitor3243276):R.ffi.throwNonFunApp(L[349],anf_fun8223290,[new_DASH_visitor3243276]);
};
try {
if(--R.GAS > 0) {
$z32823283 = $f32883289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32883289,
"from":L[349]});
}
} catch($e32803281) {
if(R.isCont($e32803281)) {
var $ss32843285 = {"from":L[349],
"go":function(if_DASH_913291) {
return $Hif_DASH_17853292(if_DASH_913291,E1121);
}};
$e32803281.stack[R.EXN_STACKHEIGHT++] = $ss32843285;
}
if(R.isPyretException($e32803281)) {
$e32803281.pyretStack.push(L[349]);
}
throw $e32803281;
}
var $ret32863287 = $Hif_DASH_17853292($z32823283,E1121);
++R.GAS;
return $ret32863287;
});
var $z32653266 = D;
var $f32713272 = function(_) {
return R.isFunction(anf_fun8203273)?anf_fun8203273.app(anf_arg8343274,(true),binds3193260):R.ffi.throwNonFunApp(L[347],anf_fun8203273,[anf_arg8343274,(true),binds3193260]);
};
try {
if(--R.GAS > 0) {
$z32653266 = $f32713272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32713272,
"from":L[347]});
}
} catch($e32633264) {
if(R.isCont($e32633264)) {
var $ss32673268 = {"from":L[347],
"go":function(continue_DASH_binds3253275) {
return $Hcontinue_DASH_binds17893277(continue_DASH_binds3253275,body3203261,new_DASH_visitor3243276);
}};
$e32633264.stack[R.EXN_STACKHEIGHT++] = $ss32673268;
}
if(R.isPyretException($e32633264)) {
$e32633264.pyretStack.push(L[347]);
}
throw $e32633264;
}
var $ret32693270 = $Hcontinue_DASH_binds17893277($z32653266,body3203261,new_DASH_visitor3243276);
++R.GAS;
return $ret32693270;
};
var $Hcontinue_DASH_binds17893277 = function(continue_DASH_binds3253275,body3203261,new_DASH_visitor3243276) {
var and_DASH_oper_DASH_923319 = continue_DASH_binds3253275;
var if_helper8353305 = R.makeFunction(function(if_helper_arg8363324) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[352],1,arguments);
}
var ann_DASH_check_DASH_temp8143325 = if_helper_arg8363324;
return ann_DASH_check_DASH_temp8143325;
});
var anf_if8393323 = R.isBoolean(and_DASH_oper_DASH_923319);
if(R.isPyretTrue(anf_if8393323)) {
if(R.isPyretTrue(and_DASH_oper_DASH_923319)) {
var anf_fun8413303 = G(body3203261,"visit",L[353]);
var $z32953296 = D;
var $f33013302 = function(_) {
return R.isFunction(anf_fun8413303)?anf_fun8413303.app(new_DASH_visitor3243276):R.ffi.throwNonFunApp(L[352],anf_fun8413303,[new_DASH_visitor3243276]);
};
try {
if(--R.GAS > 0) {
$z32953296 = $f33013302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33013302,
"from":L[352]});
}
} catch($e32933294) {
if(R.isCont($e32933294)) {
var $ss32973298 = {"from":L[352],
"go":function(and_DASH_oper_DASH_933304) {
return $Hand_DASH_oper_DASH_17873306(and_DASH_oper_DASH_933304,if_helper8353305);
}};
$e32933294.stack[R.EXN_STACKHEIGHT++] = $ss32973298;
}
if(R.isPyretException($e32933294)) {
$e32933294.pyretStack.push(L[352]);
}
throw $e32933294;
}
var $ret32993300 = $Hand_DASH_oper_DASH_17873306($z32953296,if_helper8353305);
++R.GAS;
return $ret32993300;
} else {
var $z33093310 = D;
var $f33153316 = function(_) {
return R.isFunction(if_helper8353305)?if_helper8353305.app((false)):R.ffi.throwNonFunApp(L[352],if_helper8353305,[(false)]);
};
try {
if(--R.GAS > 0) {
$z33093310 = $f33153316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33153316,
"from":L[352]});
}
} catch($e33073308) {
if(R.isCont($e33073308)) {
var $ss33113312 = {"from":L[352],
"go":function(cont_tail_app8403317) {
return $Hcont_tail_app17883318(cont_tail_app8403317);
}};
$e33073308.stack[R.EXN_STACKHEIGHT++] = $ss33113312;
}
if(R.isPyretException($e33073308)) {
$e33073308.pyretStack.push(L[352]);
}
throw $e33073308;
}
var $ret33133314 = $Hcont_tail_app17883318($z33093310);
++R.GAS;
return $ret33133314;
}
} else {
var cont_tail_arg8373322 = R.throwNonBooleanOp(L[354],("first"),("and"),and_DASH_oper_DASH_923319);
if(--R.GAS > 0) {
$z33203321 = R.isFunction(if_helper8353305)?if_helper8353305.app(cont_tail_arg8373322):R.ffi.throwNonFunApp(L[354],if_helper8353305,[cont_tail_arg8373322]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8353305)?if_helper8353305.app(cont_tail_arg8373322):R.ffi.throwNonFunApp(L[354],if_helper8353305,[cont_tail_arg8373322]);
},
"from":L[354]});
}
++R.GAS;
return $z33203321;
}
};
var $Hand_DASH_oper_DASH_17873306 = function(and_DASH_oper_DASH_933304,if_helper8353305) {
var anf_if8443341 = R.isBoolean(and_DASH_oper_DASH_933304);
if(R.isPyretTrue(anf_if8443341)) {
var $z33283329 = D;
var $f33343335 = function(_) {
return R.isFunction(if_helper8353305)?if_helper8353305.app(and_DASH_oper_DASH_933304):R.ffi.throwNonFunApp(L[352],if_helper8353305,[and_DASH_oper_DASH_933304]);
};
try {
if(--R.GAS > 0) {
$z33283329 = $f33343335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33343335,
"from":L[352]});
}
} catch($e33263327) {
if(R.isCont($e33263327)) {
var $ss33303331 = {"from":L[352],
"go":function(cont_tail_app8453336) {
return $Hcont_tail_app17863337(cont_tail_app8453336);
}};
$e33263327.stack[R.EXN_STACKHEIGHT++] = $ss33303331;
}
if(R.isPyretException($e33263327)) {
$e33263327.pyretStack.push(L[352]);
}
throw $e33263327;
}
var $ret33323333 = $Hcont_tail_app17863337($z33283329);
++R.GAS;
return $ret33323333;
} else {
var cont_tail_arg8423340 = R.throwNonBooleanOp(L[355],("second"),("and"),and_DASH_oper_DASH_933304);
if(--R.GAS > 0) {
$z33383339 = R.isFunction(if_helper8353305)?if_helper8353305.app(cont_tail_arg8423340):R.ffi.throwNonFunApp(L[355],if_helper8353305,[cont_tail_arg8423340]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8353305)?if_helper8353305.app(cont_tail_arg8423340):R.ffi.throwNonFunApp(L[355],if_helper8353305,[cont_tail_arg8423340]);
},
"from":L[355]});
}
++R.GAS;
return $z33383339;
}
};
var $Hcont_tail_app17863337 = function(cont_tail_app8453336) {
return cont_tail_app8453336;
};
var $Hcont_tail_app17883318 = function(cont_tail_app8403317) {
return cont_tail_app8403317;
};
var $Hif_DASH_17853292 = function(if_DASH_913291,E1121) {
var if_helper8233354 = R.makeFunction(function(if_helper_arg8243373) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[349],1,arguments);
}
var ann_DASH_check_DASH_temp8213374 = if_helper_arg8243373;
return ann_DASH_check_DASH_temp8213374;
});
var anf_if8273372 = R.isBoolean(if_DASH_913291);
if(R.isPyretTrue(anf_if8273372)) {
if(R.isPyretTrue(if_DASH_913291)) {
var anf_fun8313352 = G(E1121,"left",L[357]);
var $z33443345 = D;
var $f33503351 = function(_) {
return R.isFunction(anf_fun8313352)?anf_fun8313352.app((true)):R.ffi.throwNonFunApp(L[356],anf_fun8313352,[(true)]);
};
try {
if(--R.GAS > 0) {
$z33443345 = $f33503351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33503351,
"from":L[356]});
}
} catch($e33423343) {
if(R.isCont($e33423343)) {
var $ss33463347 = {"from":L[356],
"go":function(cont_tail_arg8323353) {
return $Hcont_tail_arg17833355(cont_tail_arg8323353,if_helper8233354);
}};
$e33423343.stack[R.EXN_STACKHEIGHT++] = $ss33463347;
}
if(R.isPyretException($e33423343)) {
$e33423343.pyretStack.push(L[356]);
}
throw $e33423343;
}
var $ret33483349 = $Hcont_tail_arg17833355($z33443345,if_helper8233354);
++R.GAS;
return $ret33483349;
} else {
var anf_fun8283366 = G(E1121,"right",L[359]);
var $z33583359 = D;
var $f33643365 = function(_) {
return R.isFunction(anf_fun8283366)?anf_fun8283366.app((false)):R.ffi.throwNonFunApp(L[358],anf_fun8283366,[(false)]);
};
try {
if(--R.GAS > 0) {
$z33583359 = $f33643365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33643365,
"from":L[358]});
}
} catch($e33563357) {
if(R.isCont($e33563357)) {
var $ss33603361 = {"from":L[358],
"go":function(cont_tail_arg8293367) {
return $Hcont_tail_arg17843368(cont_tail_arg8293367,if_helper8233354);
}};
$e33563357.stack[R.EXN_STACKHEIGHT++] = $ss33603361;
}
if(R.isPyretException($e33563357)) {
$e33563357.pyretStack.push(L[358]);
}
throw $e33563357;
}
var $ret33623363 = $Hcont_tail_arg17843368($z33583359,if_helper8233354);
++R.GAS;
return $ret33623363;
}
} else {
var cont_tail_arg8253371 = R.throwNonBooleanCondition(L[349],("if"),if_DASH_913291);
if(--R.GAS > 0) {
$z33693370 = R.isFunction(if_helper8233354)?if_helper8233354.app(cont_tail_arg8253371):R.ffi.throwNonFunApp(L[349],if_helper8233354,[cont_tail_arg8253371]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8233354)?if_helper8233354.app(cont_tail_arg8253371):R.ffi.throwNonFunApp(L[349],if_helper8233354,[cont_tail_arg8253371]);
},
"from":L[349]});
}
++R.GAS;
return $z33693370;
}
};
var $Hcont_tail_arg17833355 = function(cont_tail_arg8323353,if_helper8233354) {
if(--R.GAS > 0) {
$z33753376 = R.isFunction(if_helper8233354)?if_helper8233354.app(cont_tail_arg8323353):R.ffi.throwNonFunApp(L[356],if_helper8233354,[cont_tail_arg8323353]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8233354)?if_helper8233354.app(cont_tail_arg8323353):R.ffi.throwNonFunApp(L[356],if_helper8233354,[cont_tail_arg8323353]);
},
"from":L[356]});
}
++R.GAS;
return $z33753376;
};
var $Hcont_tail_arg17843368 = function(cont_tail_arg8293367,if_helper8233354) {
if(--R.GAS > 0) {
$z33773378 = R.isFunction(if_helper8233354)?if_helper8233354.app(cont_tail_arg8293367):R.ffi.throwNonFunApp(L[358],if_helper8233354,[cont_tail_arg8293367]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8233354)?if_helper8233354.app(cont_tail_arg8293367):R.ffi.throwNonFunApp(L[358],if_helper8233354,[cont_tail_arg8293367]);
},
"from":L[358]});
}
++R.GAS;
return $z33773378;
};
var $Hann_DASH_check_DASH_temp17823379 = function(ann_DASH_check_DASH_temp8163380) {
return ann_DASH_check_DASH_temp8163380;
};
var $Hbound_DASH_env17813381 = function(bound_DASH_env3123382,body3113383,self3083384) {
var and_DASH_oper_DASH_893413 = G(bound_DASH_env3123382,"bs",L[363]);
var if_helper8003398 = R.makeFunction(function(if_helper_arg8013418) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[360],1,arguments);
}
var ann_DASH_check_DASH_temp7763419 = if_helper_arg8013418;
return ann_DASH_check_DASH_temp7763419;
});
var anf_if8043417 = R.isBoolean(and_DASH_oper_DASH_893413);
if(R.isPyretTrue(anf_if8043417)) {
if(R.isPyretTrue(and_DASH_oper_DASH_893413)) {
var anf_fun8063395 = G(body3113383,"visit",L[362]);
var anf_extend8073400 = G(bound_DASH_env3123382,"e",L[361]);
var anf_arg8083396 = self3083384.extendWith({"env":anf_extend8073400});
var $z33873388 = D;
var $f33933394 = function(_) {
return R.isFunction(anf_fun8063395)?anf_fun8063395.app(anf_arg8083396):R.ffi.throwNonFunApp(L[360],anf_fun8063395,[anf_arg8083396]);
};
try {
if(--R.GAS > 0) {
$z33873388 = $f33933394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33933394,
"from":L[360]});
}
} catch($e33853386) {
if(R.isCont($e33853386)) {
var $ss33893390 = {"from":L[360],
"go":function(and_DASH_oper_DASH_903397) {
return $Hand_DASH_oper_DASH_17793399(and_DASH_oper_DASH_903397,if_helper8003398);
}};
$e33853386.stack[R.EXN_STACKHEIGHT++] = $ss33893390;
}
if(R.isPyretException($e33853386)) {
$e33853386.pyretStack.push(L[360]);
}
throw $e33853386;
}
var $ret33913392 = $Hand_DASH_oper_DASH_17793399($z33873388,if_helper8003398);
++R.GAS;
return $ret33913392;
} else {
var $z34033404 = D;
var $f34093410 = function(_) {
return R.isFunction(if_helper8003398)?if_helper8003398.app((false)):R.ffi.throwNonFunApp(L[360],if_helper8003398,[(false)]);
};
try {
if(--R.GAS > 0) {
$z34033404 = $f34093410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34093410,
"from":L[360]});
}
} catch($e34013402) {
if(R.isCont($e34013402)) {
var $ss34053406 = {"from":L[360],
"go":function(cont_tail_app8053411) {
return $Hcont_tail_app17803412(cont_tail_app8053411);
}};
$e34013402.stack[R.EXN_STACKHEIGHT++] = $ss34053406;
}
if(R.isPyretException($e34013402)) {
$e34013402.pyretStack.push(L[360]);
}
throw $e34013402;
}
var $ret34073408 = $Hcont_tail_app17803412($z34033404);
++R.GAS;
return $ret34073408;
}
} else {
var cont_tail_arg8023416 = R.throwNonBooleanOp(L[363],("first"),("and"),and_DASH_oper_DASH_893413);
if(--R.GAS > 0) {
$z34143415 = R.isFunction(if_helper8003398)?if_helper8003398.app(cont_tail_arg8023416):R.ffi.throwNonFunApp(L[363],if_helper8003398,[cont_tail_arg8023416]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8003398)?if_helper8003398.app(cont_tail_arg8023416):R.ffi.throwNonFunApp(L[363],if_helper8003398,[cont_tail_arg8023416]);
},
"from":L[363]});
}
++R.GAS;
return $z34143415;
}
};
var $Hand_DASH_oper_DASH_17793399 = function(and_DASH_oper_DASH_903397,if_helper8003398) {
var anf_if8113435 = R.isBoolean(and_DASH_oper_DASH_903397);
if(R.isPyretTrue(anf_if8113435)) {
var $z34223423 = D;
var $f34283429 = function(_) {
return R.isFunction(if_helper8003398)?if_helper8003398.app(and_DASH_oper_DASH_903397):R.ffi.throwNonFunApp(L[360],if_helper8003398,[and_DASH_oper_DASH_903397]);
};
try {
if(--R.GAS > 0) {
$z34223423 = $f34283429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34283429,
"from":L[360]});
}
} catch($e34203421) {
if(R.isCont($e34203421)) {
var $ss34243425 = {"from":L[360],
"go":function(cont_tail_app8123430) {
return $Hcont_tail_app17783431(cont_tail_app8123430);
}};
$e34203421.stack[R.EXN_STACKHEIGHT++] = $ss34243425;
}
if(R.isPyretException($e34203421)) {
$e34203421.pyretStack.push(L[360]);
}
throw $e34203421;
}
var $ret34263427 = $Hcont_tail_app17783431($z34223423);
++R.GAS;
return $ret34263427;
} else {
var cont_tail_arg8093434 = R.throwNonBooleanOp(L[364],("second"),("and"),and_DASH_oper_DASH_903397);
if(--R.GAS > 0) {
$z34323433 = R.isFunction(if_helper8003398)?if_helper8003398.app(cont_tail_arg8093434):R.ffi.throwNonFunApp(L[364],if_helper8003398,[cont_tail_arg8093434]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper8003398)?if_helper8003398.app(cont_tail_arg8093434):R.ffi.throwNonFunApp(L[364],if_helper8003398,[cont_tail_arg8093434]);
},
"from":L[364]});
}
++R.GAS;
return $z34323433;
}
};
var $Hcont_tail_app17783431 = function(cont_tail_app8123430) {
return cont_tail_app8123430;
};
var $Hcont_tail_app17803412 = function(cont_tail_app8053411) {
return cont_tail_app8053411;
};
var $Hthis_DASH_env17773436 = function(this_DASH_env3153437,E1121,acc3133438,b3143439,self3083384) {
var anf_fun7813450 = G(b3143439,"visit",L[367]);
var anf_extend7823454 = G(acc3133438,"e",L[366]);
var anf_arg7833451 = self3083384.extendWith({"env":anf_extend7823454});
var $z34423443 = D;
var $f34483449 = function(_) {
return R.isFunction(anf_fun7813450)?anf_fun7813450.app(anf_arg7833451):R.ffi.throwNonFunApp(L[365],anf_fun7813450,[anf_arg7833451]);
};
try {
if(--R.GAS > 0) {
$z34423443 = $f34483449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34483449,
"from":L[365]});
}
} catch($e34403441) {
if(R.isCont($e34403441)) {
var $ss34443445 = {"from":L[365],
"go":function(new_DASH_bind3163452) {
return $Hnew_DASH_bind17763453(new_DASH_bind3163452,E1121,this_DASH_env3153437);
}};
$e34403441.stack[R.EXN_STACKHEIGHT++] = $ss34443445;
}
if(R.isPyretException($e34403441)) {
$e34403441.pyretStack.push(L[365]);
}
throw $e34403441;
}
var $ret34463447 = $Hnew_DASH_bind17763453($z34423443,E1121,this_DASH_env3153437);
++R.GAS;
return $ret34463447;
};
var $Hnew_DASH_bind17763453 = function(new_DASH_bind3163452,E1121,this_DASH_env3153437) {
var if_DASH_883484 = new_DASH_bind3163452;
var if_helper7843468 = R.makeFunction(function(if_helper_arg7853489) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[372],1,arguments);
}
var ann_DASH_check_DASH_temp7783490 = if_helper_arg7853489;
return ann_DASH_check_DASH_temp7783490;
});
var anf_if7883488 = R.isBoolean(if_DASH_883484);
if(R.isPyretTrue(anf_if7883488)) {
if(R.isPyretTrue(if_DASH_883484)) {
var anf_fun7933465 = G(E1121,"left",L[369]);
var anf_arg7943466 = R.makeObject({"e":this_DASH_env3153437,
"bs":(true)});
var $z34573458 = D;
var $f34633464 = function(_) {
return R.isFunction(anf_fun7933465)?anf_fun7933465.app(anf_arg7943466):R.ffi.throwNonFunApp(L[368],anf_fun7933465,[anf_arg7943466]);
};
try {
if(--R.GAS > 0) {
$z34573458 = $f34633464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34633464,
"from":L[368]});
}
} catch($e34553456) {
if(R.isCont($e34553456)) {
var $ss34593460 = {"from":L[368],
"go":function(cont_tail_arg7953467) {
return $Hcont_tail_arg17743469(cont_tail_arg7953467,if_helper7843468);
}};
$e34553456.stack[R.EXN_STACKHEIGHT++] = $ss34593460;
}
if(R.isPyretException($e34553456)) {
$e34553456.pyretStack.push(L[368]);
}
throw $e34553456;
}
var $ret34613462 = $Hcont_tail_arg17743469($z34573458,if_helper7843468);
++R.GAS;
return $ret34613462;
} else {
var anf_fun7893480 = G(E1121,"right",L[371]);
var anf_arg7903481 = R.makeObject({"e":this_DASH_env3153437,
"bs":(false)});
var $z34723473 = D;
var $f34783479 = function(_) {
return R.isFunction(anf_fun7893480)?anf_fun7893480.app(anf_arg7903481):R.ffi.throwNonFunApp(L[370],anf_fun7893480,[anf_arg7903481]);
};
try {
if(--R.GAS > 0) {
$z34723473 = $f34783479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34783479,
"from":L[370]});
}
} catch($e34703471) {
if(R.isCont($e34703471)) {
var $ss34743475 = {"from":L[370],
"go":function(cont_tail_arg7913482) {
return $Hcont_tail_arg17753483(cont_tail_arg7913482,if_helper7843468);
}};
$e34703471.stack[R.EXN_STACKHEIGHT++] = $ss34743475;
}
if(R.isPyretException($e34703471)) {
$e34703471.pyretStack.push(L[370]);
}
throw $e34703471;
}
var $ret34763477 = $Hcont_tail_arg17753483($z34723473,if_helper7843468);
++R.GAS;
return $ret34763477;
}
} else {
var cont_tail_arg7863487 = R.throwNonBooleanCondition(L[372],("if"),if_DASH_883484);
if(--R.GAS > 0) {
$z34853486 = R.isFunction(if_helper7843468)?if_helper7843468.app(cont_tail_arg7863487):R.ffi.throwNonFunApp(L[372],if_helper7843468,[cont_tail_arg7863487]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper7843468)?if_helper7843468.app(cont_tail_arg7863487):R.ffi.throwNonFunApp(L[372],if_helper7843468,[cont_tail_arg7863487]);
},
"from":L[372]});
}
++R.GAS;
return $z34853486;
}
};
var $Hcont_tail_arg17743469 = function(cont_tail_arg7953467,if_helper7843468) {
if(--R.GAS > 0) {
$z34913492 = R.isFunction(if_helper7843468)?if_helper7843468.app(cont_tail_arg7953467):R.ffi.throwNonFunApp(L[368],if_helper7843468,[cont_tail_arg7953467]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper7843468)?if_helper7843468.app(cont_tail_arg7953467):R.ffi.throwNonFunApp(L[368],if_helper7843468,[cont_tail_arg7953467]);
},
"from":L[368]});
}
++R.GAS;
return $z34913492;
};
var $Hcont_tail_arg17753483 = function(cont_tail_arg7913482,if_helper7843468) {
if(--R.GAS > 0) {
$z34933494 = R.isFunction(if_helper7843468)?if_helper7843468.app(cont_tail_arg7913482):R.ffi.throwNonFunApp(L[370],if_helper7843468,[cont_tail_arg7913482]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper7843468)?if_helper7843468.app(cont_tail_arg7913482):R.ffi.throwNonFunApp(L[370],if_helper7843468,[cont_tail_arg7913482]);
},
"from":L[370]});
}
++R.GAS;
return $z34933494;
};
var $Hbound_DASH_env17733495 = function(bound_DASH_env3023496,body3003497,self2973498) {
var and_DASH_oper_DASH_863528 = G(bound_DASH_env3023496,"bs",L[377]);
var if_helper7613512 = R.makeFunction(function(if_helper_arg7623533) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[373],1,arguments);
}
var ann_DASH_check_DASH_temp7353534 = if_helper_arg7623533;
return ann_DASH_check_DASH_temp7353534;
});
var anf_if7653532 = R.isBoolean(and_DASH_oper_DASH_863528);
if(R.isPyretTrue(anf_if7653532)) {
if(R.isPyretTrue(and_DASH_oper_DASH_863528)) {
var anf_fun7673509 = G(body3003497,"visit",L[376]);
var anf_extend7683514 = G(bound_DASH_env3023496,"val-env",L[375]);
var anf_extend7693515 = G(bound_DASH_env3023496,"type-env",L[374]);
var anf_arg7703510 = self2973498.extendWith({"env":anf_extend7683514,
"type-env":anf_extend7693515});
var $z35013502 = D;
var $f35073508 = function(_) {
return R.isFunction(anf_fun7673509)?anf_fun7673509.app(anf_arg7703510):R.ffi.throwNonFunApp(L[373],anf_fun7673509,[anf_arg7703510]);
};
try {
if(--R.GAS > 0) {
$z35013502 = $f35073508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35073508,
"from":L[373]});
}
} catch($e34993500) {
if(R.isCont($e34993500)) {
var $ss35033504 = {"from":L[373],
"go":function(and_DASH_oper_DASH_873511) {
return $Hand_DASH_oper_DASH_17713513(and_DASH_oper_DASH_873511,if_helper7613512);
}};
$e34993500.stack[R.EXN_STACKHEIGHT++] = $ss35033504;
}
if(R.isPyretException($e34993500)) {
$e34993500.pyretStack.push(L[373]);
}
throw $e34993500;
}
var $ret35053506 = $Hand_DASH_oper_DASH_17713513($z35013502,if_helper7613512);
++R.GAS;
return $ret35053506;
} else {
var $z35183519 = D;
var $f35243525 = function(_) {
return R.isFunction(if_helper7613512)?if_helper7613512.app((false)):R.ffi.throwNonFunApp(L[373],if_helper7613512,[(false)]);
};
try {
if(--R.GAS > 0) {
$z35183519 = $f35243525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35243525,
"from":L[373]});
}
} catch($e35163517) {
if(R.isCont($e35163517)) {
var $ss35203521 = {"from":L[373],
"go":function(cont_tail_app7663526) {
return $Hcont_tail_app17723527(cont_tail_app7663526);
}};
$e35163517.stack[R.EXN_STACKHEIGHT++] = $ss35203521;
}
if(R.isPyretException($e35163517)) {
$e35163517.pyretStack.push(L[373]);
}
throw $e35163517;
}
var $ret35223523 = $Hcont_tail_app17723527($z35183519);
++R.GAS;
return $ret35223523;
}
} else {
var cont_tail_arg7633531 = R.throwNonBooleanOp(L[377],("first"),("and"),and_DASH_oper_DASH_863528);
if(--R.GAS > 0) {
$z35293530 = R.isFunction(if_helper7613512)?if_helper7613512.app(cont_tail_arg7633531):R.ffi.throwNonFunApp(L[377],if_helper7613512,[cont_tail_arg7633531]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper7613512)?if_helper7613512.app(cont_tail_arg7633531):R.ffi.throwNonFunApp(L[377],if_helper7613512,[cont_tail_arg7633531]);
},
"from":L[377]});
}
++R.GAS;
return $z35293530;
}
};
var $Hand_DASH_oper_DASH_17713513 = function(and_DASH_oper_DASH_873511,if_helper7613512) {
var anf_if7733550 = R.isBoolean(and_DASH_oper_DASH_873511);
if(R.isPyretTrue(anf_if7733550)) {
var $z35373538 = D;
var $f35433544 = function(_) {
return R.isFunction(if_helper7613512)?if_helper7613512.app(and_DASH_oper_DASH_873511):R.ffi.throwNonFunApp(L[373],if_helper7613512,[and_DASH_oper_DASH_873511]);
};
try {
if(--R.GAS > 0) {
$z35373538 = $f35433544();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35433544,
"from":L[373]});
}
} catch($e35353536) {
if(R.isCont($e35353536)) {
var $ss35393540 = {"from":L[373],
"go":function(cont_tail_app7743545) {
return $Hcont_tail_app17703546(cont_tail_app7743545);
}};
$e35353536.stack[R.EXN_STACKHEIGHT++] = $ss35393540;
}
if(R.isPyretException($e35353536)) {
$e35353536.pyretStack.push(L[373]);
}
throw $e35353536;
}
var $ret35413542 = $Hcont_tail_app17703546($z35373538);
++R.GAS;
return $ret35413542;
} else {
var cont_tail_arg7713549 = R.throwNonBooleanOp(L[378],("second"),("and"),and_DASH_oper_DASH_873511);
if(--R.GAS > 0) {
$z35473548 = R.isFunction(if_helper7613512)?if_helper7613512.app(cont_tail_arg7713549):R.ffi.throwNonFunApp(L[378],if_helper7613512,[cont_tail_arg7713549]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper7613512)?if_helper7613512.app(cont_tail_arg7713549):R.ffi.throwNonFunApp(L[378],if_helper7613512,[cont_tail_arg7713549]);
},
"from":L[378]});
}
++R.GAS;
return $z35473548;
}
};
var $Hcont_tail_app17703546 = function(cont_tail_app7743545) {
return cont_tail_app7743545;
};
var $Hcont_tail_app17723527 = function(cont_tail_app7663526) {
return cont_tail_app7663526;
};
var $Hupdated17693551 = function(updated3053552,E1121,b3043553,self2973498) {
var anf_extend7433568 = G(updated3053552,"val-env",L[382]);
var anf_extend7443569 = G(updated3053552,"type-env",L[381]);
var visit_DASH_envs3063565 = self2973498.extendWith({"env":anf_extend7433568,
"type-env":anf_extend7443569});
var anf_fun7453564 = G(b3043553,"visit",L[380]);
var $z35563557 = D;
var $f35623563 = function(_) {
return R.isFunction(anf_fun7453564)?anf_fun7453564.app(visit_DASH_envs3063565):R.ffi.throwNonFunApp(L[379],anf_fun7453564,[visit_DASH_envs3063565]);
};
try {
if(--R.GAS > 0) {
$z35563557 = $f35623563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35623563,
"from":L[379]});
}
} catch($e35543555) {
if(R.isCont($e35543555)) {
var $ss35583559 = {"from":L[379],
"go":function(new_DASH_bind3073566) {
return $Hnew_DASH_bind17683567(new_DASH_bind3073566,E1121,updated3053552);
}};
$e35543555.stack[R.EXN_STACKHEIGHT++] = $ss35583559;
}
if(R.isPyretException($e35543555)) {
$e35543555.pyretStack.push(L[379]);
}
throw $e35543555;
}
var $ret35603561 = $Hnew_DASH_bind17683567($z35563557,E1121,updated3053552);
++R.GAS;
return $ret35603561;
};
var $Hnew_DASH_bind17683567 = function(new_DASH_bind3073566,E1121,updated3053552) {
var if_DASH_853599 = new_DASH_bind3073566;
var if_helper7463583 = R.makeFunction(function(if_helper_arg7473604) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[387],1,arguments);
}
var ann_DASH_check_DASH_temp7393605 = if_helper_arg7473604;
return ann_DASH_check_DASH_temp7393605;
});
var anf_if7503603 = R.isBoolean(if_DASH_853599);
if(R.isPyretTrue(anf_if7503603)) {
if(R.isPyretTrue(if_DASH_853599)) {
var anf_fun7553580 = G(E1121,"left",L[384]);
var anf_arg7563581 = updated3053552.extendWith({"bs":(true)});
var $z35723573 = D;
var $f35783579 = function(_) {
return R.isFunction(anf_fun7553580)?anf_fun7553580.app(anf_arg7563581):R.ffi.throwNonFunApp(L[383],anf_fun7553580,[anf_arg7563581]);
};
try {
if(--R.GAS > 0) {
$z35723573 = $f35783579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35783579,
"from":L[383]});
}
} catch($e35703571) {
if(R.isCont($e35703571)) {
var $ss35743575 = {"from":L[383],
"go":function(cont_tail_arg7573582) {
return $Hcont_tail_arg17663584(cont_tail_arg7573582,if_helper7463583);
}};
$e35703571.stack[R.EXN_STACKHEIGHT++] = $ss35743575;
}
if(R.isPyretException($e35703571)) {
$e35703571.pyretStack.push(L[383]);
}
throw $e35703571;
}
var $ret35763577 = $Hcont_tail_arg17663584($z35723573,if_helper7463583);
++R.GAS;
return $ret35763577;
} else {
var anf_fun7513595 = G(E1121,"right",L[386]);
var anf_arg7523596 = updated3053552.extendWith({"bs":(false)});
var $z35873588 = D;
var $f35933594 = function(_) {
return R.isFunction(anf_fun7513595)?anf_fun7513595.app(anf_arg7523596):R.ffi.throwNonFunApp(L[385],anf_fun7513595,[anf_arg7523596]);
};
try {
if(--R.GAS > 0) {
$z35873588 = $f35933594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35933594,
"from":L[385]});
}
} catch($e35853586) {
if(R.isCont($e35853586)) {
var $ss35893590 = {"from":L[385],
"go":function(cont_tail_arg7533597) {
return $Hcont_tail_arg17673598(cont_tail_arg7533597,if_helper7463583);
}};
$e35853586.stack[R.EXN_STACKHEIGHT++] = $ss35893590;
}
if(R.isPyretException($e35853586)) {
$e35853586.pyretStack.push(L[385]);
}
throw $e35853586;
}
var $ret35913592 = $Hcont_tail_arg17673598($z35873588,if_helper7463583);
++R.GAS;
return $ret35913592;
}
} else {
var cont_tail_arg7483602 = R.throwNonBooleanCondition(L[387],("if"),if_DASH_853599);
if(--R.GAS > 0) {
$z36003601 = R.isFunction(if_helper7463583)?if_helper7463583.app(cont_tail_arg7483602):R.ffi.throwNonFunApp(L[387],if_helper7463583,[cont_tail_arg7483602]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper7463583)?if_helper7463583.app(cont_tail_arg7483602):R.ffi.throwNonFunApp(L[387],if_helper7463583,[cont_tail_arg7483602]);
},
"from":L[387]});
}
++R.GAS;
return $z36003601;
}
};
var $Hcont_tail_arg17663584 = function(cont_tail_arg7573582,if_helper7463583) {
if(--R.GAS > 0) {
$z36063607 = R.isFunction(if_helper7463583)?if_helper7463583.app(cont_tail_arg7573582):R.ffi.throwNonFunApp(L[383],if_helper7463583,[cont_tail_arg7573582]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper7463583)?if_helper7463583.app(cont_tail_arg7573582):R.ffi.throwNonFunApp(L[383],if_helper7463583,[cont_tail_arg7573582]);
},
"from":L[383]});
}
++R.GAS;
return $z36063607;
};
var $Hcont_tail_arg17673598 = function(cont_tail_arg7533597,if_helper7463583) {
if(--R.GAS > 0) {
$z36083609 = R.isFunction(if_helper7463583)?if_helper7463583.app(cont_tail_arg7533597):R.ffi.throwNonFunApp(L[385],if_helper7463583,[cont_tail_arg7533597]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper7463583)?if_helper7463583.app(cont_tail_arg7533597):R.ffi.throwNonFunApp(L[385],if_helper7463583,[cont_tail_arg7533597]);
},
"from":L[385]});
}
++R.GAS;
return $z36083609;
};
var $Hand_DASH_oper_DASH_17653610 = function(and_DASH_oper_DASH_803611,_provide_DASH_types2893612,bind_DASH_handlers2853086,body2913613,fold593614,imports2903615,lists1523,self2863616) {
var if_helper6953629 = R.makeFunction(function(if_helper_arg6963647) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[388],1,arguments);
}
var if_DASH_793694 = if_helper_arg6963647;
var if_helper6973661 = R.makeFunction(function(if_helper_arg6983699) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[388],1,arguments);
}
var ann_DASH_check_DASH_temp6933700 = if_helper_arg6983699;
return ann_DASH_check_DASH_temp6933700;
});
var anf_if7013698 = R.isBoolean(if_DASH_793694);
if(R.isPyretTrue(anf_if7013698)) {
if(R.isPyretTrue(if_DASH_793694)) {
var anf_obj7033680 = G(self2863616,"env",L[397]);
var anf_obj7043681 = G(self2863616,"type-env",L[396]);
var new_DASH_envs2923659 = R.makeObject({"val-env":anf_obj7033680,
"type-env":anf_obj7043681});
var anf_arg7093658 = R.makeFunction(function(acc2943663,i2953664) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[392],2,arguments);
}
var anf_fun7063675 = G(bind_DASH_handlers2853086,"s-header",L[395]);
var anf_arg7073676 = G(acc2943663,"val-env",L[394]);
var anf_arg7083677 = G(acc2943663,"type-env",L[393]);
var $z36673668 = D;
var $f36733674 = function(_) {
return R.isFunction(anf_fun7063675)?anf_fun7063675.app(i2953664,anf_arg7073676,anf_arg7083677):R.ffi.throwNonFunApp(L[392],anf_fun7063675,[i2953664,anf_arg7073676,anf_arg7083677]);
};
try {
if(--R.GAS > 0) {
$z36673668 = $f36733674();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36733674,
"from":L[392]});
}
} catch($e36653666) {
if(R.isCont($e36653666)) {
var $ss36693670 = {"from":L[392],
"go":function(ann_DASH_check_DASH_temp7053678) {
return $Hann_DASH_check_DASH_temp17543679(ann_DASH_check_DASH_temp7053678);
}};
$e36653666.stack[R.EXN_STACKHEIGHT++] = $ss36693670;
}
if(R.isPyretException($e36653666)) {
$e36653666.pyretStack.push(L[392]);
}
throw $e36653666;
}
var $ret36713672 = $Hann_DASH_check_DASH_temp17543679($z36673668);
++R.GAS;
return $ret36713672;
});
var $z36503651 = D;
var $f36563657 = function(_) {
return R.isFunction(fold593614)?fold593614.app(anf_arg7093658,new_DASH_envs2923659,imports2903615):R.ffi.throwNonFunApp(L[391],fold593614,[anf_arg7093658,new_DASH_envs2923659,imports2903615]);
};
try {
if(--R.GAS > 0) {
$z36503651 = $f36563657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36563657,
"from":L[391]});
}
} catch($e36483649) {
if(R.isCont($e36483649)) {
var $ss36523653 = {"from":L[391],
"go":function(imported_DASH_envs2933660) {
return $Himported_DASH_envs17603662(imported_DASH_envs2933660,body2913613,if_helper6973661,imports2903615,lists1523,self2863616);
}};
$e36483649.stack[R.EXN_STACKHEIGHT++] = $ss36523653;
}
if(R.isPyretException($e36483649)) {
$e36483649.pyretStack.push(L[391]);
}
throw $e36483649;
}
var $ret36543655 = $Himported_DASH_envs17603662($z36503651,body2913613,if_helper6973661,imports2903615,lists1523,self2863616);
++R.GAS;
return $ret36543655;
} else {
var $z36843685 = D;
var $f36903691 = function(_) {
return R.isFunction(if_helper6973661)?if_helper6973661.app((false)):R.ffi.throwNonFunApp(L[398],if_helper6973661,[(false)]);
};
try {
if(--R.GAS > 0) {
$z36843685 = $f36903691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36903691,
"from":L[398]});
}
} catch($e36823683) {
if(R.isCont($e36823683)) {
var $ss36863687 = {"from":L[398],
"go":function(cont_tail_app7023692) {
return $Hcont_tail_app17613693(cont_tail_app7023692);
}};
$e36823683.stack[R.EXN_STACKHEIGHT++] = $ss36863687;
}
if(R.isPyretException($e36823683)) {
$e36823683.pyretStack.push(L[398]);
}
throw $e36823683;
}
var $ret36883689 = $Hcont_tail_app17613693($z36843685);
++R.GAS;
return $ret36883689;
}
} else {
var cont_tail_arg6993697 = R.throwNonBooleanCondition(L[388],("if"),if_DASH_793694);
if(--R.GAS > 0) {
$z36953696 = R.isFunction(if_helper6973661)?if_helper6973661.app(cont_tail_arg6993697):R.ffi.throwNonFunApp(L[388],if_helper6973661,[cont_tail_arg6993697]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper6973661)?if_helper6973661.app(cont_tail_arg6993697):R.ffi.throwNonFunApp(L[388],if_helper6973661,[cont_tail_arg6993697]);
},
"from":L[388]});
}
++R.GAS;
return $z36953696;
}
});
var anf_if7273646 = R.isBoolean(and_DASH_oper_DASH_803611);
if(R.isPyretTrue(anf_if7273646)) {
if(R.isPyretTrue(and_DASH_oper_DASH_803611)) {
var anf_fun7293627 = G(_provide_DASH_types2893612,"visit",L[389]);
var $z36193620 = D;
var $f36253626 = function(_) {
return R.isFunction(anf_fun7293627)?anf_fun7293627.app(self2863616):R.ffi.throwNonFunApp(L[388],anf_fun7293627,[self2863616]);
};
try {
if(--R.GAS > 0) {
$z36193620 = $f36253626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36253626,
"from":L[388]});
}
} catch($e36173618) {
if(R.isCont($e36173618)) {
var $ss36213622 = {"from":L[388],
"go":function(and_DASH_oper_DASH_813628) {
return $Hand_DASH_oper_DASH_17633630(and_DASH_oper_DASH_813628,if_helper6953629);
}};
$e36173618.stack[R.EXN_STACKHEIGHT++] = $ss36213622;
}
if(R.isPyretException($e36173618)) {
$e36173618.pyretStack.push(L[388]);
}
throw $e36173618;
}
var $ret36233624 = $Hand_DASH_oper_DASH_17633630($z36193620,if_helper6953629);
++R.GAS;
return $ret36233624;
} else {
var $z36333634 = D;
var $f36393640 = function(_) {
return R.isFunction(if_helper6953629)?if_helper6953629.app((false)):R.ffi.throwNonFunApp(L[388],if_helper6953629,[(false)]);
};
try {
if(--R.GAS > 0) {
$z36333634 = $f36393640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36393640,
"from":L[388]});
}
} catch($e36313632) {
if(R.isCont($e36313632)) {
var $ss36353636 = {"from":L[388],
"go":function(cont_tail_app7283641) {
return $Hcont_tail_app17643642(cont_tail_app7283641);
}};
$e36313632.stack[R.EXN_STACKHEIGHT++] = $ss36353636;
}
if(R.isPyretException($e36313632)) {
$e36313632.pyretStack.push(L[388]);
}
throw $e36313632;
}
var $ret36373638 = $Hcont_tail_app17643642($z36333634);
++R.GAS;
return $ret36373638;
}
} else {
var cont_tail_arg7253645 = R.throwNonBooleanOp(L[390],("first"),("and"),and_DASH_oper_DASH_803611);
if(--R.GAS > 0) {
$z36433644 = R.isFunction(if_helper6953629)?if_helper6953629.app(cont_tail_arg7253645):R.ffi.throwNonFunApp(L[390],if_helper6953629,[cont_tail_arg7253645]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper6953629)?if_helper6953629.app(cont_tail_arg7253645):R.ffi.throwNonFunApp(L[390],if_helper6953629,[cont_tail_arg7253645]);
},
"from":L[390]});
}
++R.GAS;
return $z36433644;
}
};
var $Hand_DASH_oper_DASH_17633630 = function(and_DASH_oper_DASH_813628,if_helper6953629) {
var anf_if7323716 = R.isBoolean(and_DASH_oper_DASH_813628);
if(R.isPyretTrue(anf_if7323716)) {
var $z37033704 = D;
var $f37093710 = function(_) {
return R.isFunction(if_helper6953629)?if_helper6953629.app(and_DASH_oper_DASH_813628):R.ffi.throwNonFunApp(L[388],if_helper6953629,[and_DASH_oper_DASH_813628]);
};
try {
if(--R.GAS > 0) {
$z37033704 = $f37093710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37093710,
"from":L[388]});
}
} catch($e37013702) {
if(R.isCont($e37013702)) {
var $ss37053706 = {"from":L[388],
"go":function(cont_tail_app7333711) {
return $Hcont_tail_app17623712(cont_tail_app7333711);
}};
$e37013702.stack[R.EXN_STACKHEIGHT++] = $ss37053706;
}
if(R.isPyretException($e37013702)) {
$e37013702.pyretStack.push(L[388]);
}
throw $e37013702;
}
var $ret37073708 = $Hcont_tail_app17623712($z37033704);
++R.GAS;
return $ret37073708;
} else {
var cont_tail_arg7303715 = R.throwNonBooleanOp(L[399],("second"),("and"),and_DASH_oper_DASH_813628);
if(--R.GAS > 0) {
$z37133714 = R.isFunction(if_helper6953629)?if_helper6953629.app(cont_tail_arg7303715):R.ffi.throwNonFunApp(L[399],if_helper6953629,[cont_tail_arg7303715]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper6953629)?if_helper6953629.app(cont_tail_arg7303715):R.ffi.throwNonFunApp(L[399],if_helper6953629,[cont_tail_arg7303715]);
},
"from":L[399]});
}
++R.GAS;
return $z37133714;
}
};
var $Hcont_tail_app17623712 = function(cont_tail_app7333711) {
return cont_tail_app7333711;
};
var $Hcont_tail_app17643642 = function(cont_tail_app7283641) {
return cont_tail_app7283641;
};
var $Himported_DASH_envs17603662 = function(imported_DASH_envs2933660,body2913613,if_helper6973661,imports2903615,lists1523,self2863616) {
var anf_extend7103746 = G(imported_DASH_envs2933660,"val-env",L[404]);
var anf_extend7113747 = G(imported_DASH_envs2933660,"type-env",L[403]);
var new_DASH_visitor2963730 = self2863616.extendWith({"env":anf_extend7103746,
"type-env":anf_extend7113747});
var anf_fun7123727 = G(lists1523,"all",L[402]);
var anf_arg7153728 = R.makeFunction(function(recv_DASH_833732) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[401],1,arguments);
}
var anf_fun7143743 = G(recv_DASH_833732,"visit",L[401]);
var $z37353736 = D;
var $f37413742 = function(_) {
return R.isFunction(anf_fun7143743)?anf_fun7143743.app(new_DASH_visitor2963730):R.ffi.throwNonFunApp(L[401],anf_fun7143743,[new_DASH_visitor2963730]);
};
try {
if(--R.GAS > 0) {
$z37353736 = $f37413742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37413742,
"from":L[401]});
}
} catch($e37333734) {
if(R.isCont($e37333734)) {
var $ss37373738 = {"from":L[401],
"go":function(ann_DASH_check_DASH_temp7133744) {
return $Hann_DASH_check_DASH_temp17553745(ann_DASH_check_DASH_temp7133744);
}};
$e37333734.stack[R.EXN_STACKHEIGHT++] = $ss37373738;
}
if(R.isPyretException($e37333734)) {
$e37333734.pyretStack.push(L[401]);
}
throw $e37333734;
}
var $ret37393740 = $Hann_DASH_check_DASH_temp17553745($z37353736);
++R.GAS;
return $ret37393740;
});
var $z37193720 = D;
var $f37253726 = function(_) {
return R.isFunction(anf_fun7123727)?anf_fun7123727.app(anf_arg7153728,imports2903615):R.ffi.throwNonFunApp(L[400],anf_fun7123727,[anf_arg7153728,imports2903615]);
};
try {
if(--R.GAS > 0) {
$z37193720 = $f37253726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37253726,
"from":L[400]});
}
} catch($e37173718) {
if(R.isCont($e37173718)) {
var $ss37213722 = {"from":L[400],
"go":function(and_DASH_oper_DASH_823729) {
return $Hand_DASH_oper_DASH_17593731(and_DASH_oper_DASH_823729,body2913613,if_helper6973661,new_DASH_visitor2963730);
}};
$e37173718.stack[R.EXN_STACKHEIGHT++] = $ss37213722;
}
if(R.isPyretException($e37173718)) {
$e37173718.pyretStack.push(L[400]);
}
throw $e37173718;
}
var $ret37233724 = $Hand_DASH_oper_DASH_17593731($z37193720,body2913613,if_helper6973661,new_DASH_visitor2963730);
++R.GAS;
return $ret37233724;
};
var $Hand_DASH_oper_DASH_17593731 = function(and_DASH_oper_DASH_823729,body2913613,if_helper6973661,new_DASH_visitor2963730) {
var anf_if7183776 = R.isBoolean(and_DASH_oper_DASH_823729);
if(R.isPyretTrue(anf_if7183776)) {
if(R.isPyretTrue(and_DASH_oper_DASH_823729)) {
var anf_fun7203758 = G(body2913613,"visit",L[405]);
var $z37503751 = D;
var $f37563757 = function(_) {
return R.isFunction(anf_fun7203758)?anf_fun7203758.app(new_DASH_visitor2963730):R.ffi.throwNonFunApp(L[400],anf_fun7203758,[new_DASH_visitor2963730]);
};
try {
if(--R.GAS > 0) {
$z37503751 = $f37563757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37563757,
"from":L[400]});
}
} catch($e37483749) {
if(R.isCont($e37483749)) {
var $ss37523753 = {"from":L[400],
"go":function(and_DASH_oper_DASH_843759) {
return $Hand_DASH_oper_DASH_17573760(and_DASH_oper_DASH_843759,if_helper6973661);
}};
$e37483749.stack[R.EXN_STACKHEIGHT++] = $ss37523753;
}
if(R.isPyretException($e37483749)) {
$e37483749.pyretStack.push(L[400]);
}
throw $e37483749;
}
var $ret37543755 = $Hand_DASH_oper_DASH_17573760($z37503751,if_helper6973661);
++R.GAS;
return $ret37543755;
} else {
var $z37633764 = D;
var $f37693770 = function(_) {
return R.isFunction(if_helper6973661)?if_helper6973661.app((false)):R.ffi.throwNonFunApp(L[400],if_helper6973661,[(false)]);
};
try {
if(--R.GAS > 0) {
$z37633764 = $f37693770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37693770,
"from":L[400]});
}
} catch($e37613762) {
if(R.isCont($e37613762)) {
var $ss37653766 = {"from":L[400],
"go":function(cont_tail_app7193771) {
return $Hcont_tail_app17583772(cont_tail_app7193771);
}};
$e37613762.stack[R.EXN_STACKHEIGHT++] = $ss37653766;
}
if(R.isPyretException($e37613762)) {
$e37613762.pyretStack.push(L[400]);
}
throw $e37613762;
}
var $ret37673768 = $Hcont_tail_app17583772($z37633764);
++R.GAS;
return $ret37673768;
}
} else {
var cont_tail_arg7163775 = R.throwNonBooleanOp(L[406],("first"),("and"),and_DASH_oper_DASH_823729);
if(--R.GAS > 0) {
$z37733774 = R.isFunction(if_helper6973661)?if_helper6973661.app(cont_tail_arg7163775):R.ffi.throwNonFunApp(L[406],if_helper6973661,[cont_tail_arg7163775]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper6973661)?if_helper6973661.app(cont_tail_arg7163775):R.ffi.throwNonFunApp(L[406],if_helper6973661,[cont_tail_arg7163775]);
},
"from":L[406]});
}
++R.GAS;
return $z37733774;
}
};
var $Hand_DASH_oper_DASH_17573760 = function(and_DASH_oper_DASH_843759,if_helper6973661) {
var anf_if7233792 = R.isBoolean(and_DASH_oper_DASH_843759);
if(R.isPyretTrue(anf_if7233792)) {
var $z37793780 = D;
var $f37853786 = function(_) {
return R.isFunction(if_helper6973661)?if_helper6973661.app(and_DASH_oper_DASH_843759):R.ffi.throwNonFunApp(L[400],if_helper6973661,[and_DASH_oper_DASH_843759]);
};
try {
if(--R.GAS > 0) {
$z37793780 = $f37853786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37853786,
"from":L[400]});
}
} catch($e37773778) {
if(R.isCont($e37773778)) {
var $ss37813782 = {"from":L[400],
"go":function(cont_tail_app7243787) {
return $Hcont_tail_app17563788(cont_tail_app7243787);
}};
$e37773778.stack[R.EXN_STACKHEIGHT++] = $ss37813782;
}
if(R.isPyretException($e37773778)) {
$e37773778.pyretStack.push(L[400]);
}
throw $e37773778;
}
var $ret37833784 = $Hcont_tail_app17563788($z37793780);
++R.GAS;
return $ret37833784;
} else {
var cont_tail_arg7213791 = R.throwNonBooleanOp(L[407],("second"),("and"),and_DASH_oper_DASH_843759);
if(--R.GAS > 0) {
$z37893790 = R.isFunction(if_helper6973661)?if_helper6973661.app(cont_tail_arg7213791):R.ffi.throwNonFunApp(L[407],if_helper6973661,[cont_tail_arg7213791]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper6973661)?if_helper6973661.app(cont_tail_arg7213791):R.ffi.throwNonFunApp(L[407],if_helper6973661,[cont_tail_arg7213791]);
},
"from":L[407]});
}
++R.GAS;
return $z37893790;
}
};
var $Hcont_tail_app17563788 = function(cont_tail_app7243787) {
return cont_tail_app7243787;
};
var $Hcont_tail_app17583772 = function(cont_tail_app7193771) {
return cont_tail_app7193771;
};
var $Hann_DASH_check_DASH_temp17553745 = function(ann_DASH_check_DASH_temp7133744) {
return ann_DASH_check_DASH_temp7133744;
};
var $Hann_DASH_check_DASH_temp17543679 = function(ann_DASH_check_DASH_temp7053678) {
return ann_DASH_check_DASH_temp7053678;
};
var $Hcont_tail_app17613693 = function(cont_tail_app7023692) {
return cont_tail_app7023692;
};
var $Hnew_DASH_args17533793 = function(new_DASH_args2753794,A317,_check2743795,ann2713796,bind_DASH_handlers1883797,body2733798,doc2723799,l2693800,lists1523,self2683801) {
var anf_fun6763812 = G(lists1523,"fold",L[412]);
var anf_arg6793813 = R.makeFunction(function(acc2773817,arg2783818) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[410],2,arguments);
}
var anf_fun6783829 = G(bind_DASH_handlers1883797,"s-bind",L[411]);
var $z38213822 = D;
var $f38273828 = function(_) {
return R.isFunction(anf_fun6783829)?anf_fun6783829.app(arg2783818,acc2773817):R.ffi.throwNonFunApp(L[410],anf_fun6783829,[arg2783818,acc2773817]);
};
try {
if(--R.GAS > 0) {
$z38213822 = $f38273828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38273828,
"from":L[410]});
}
} catch($e38193820) {
if(R.isCont($e38193820)) {
var $ss38233824 = {"from":L[410],
"go":function(ann_DASH_check_DASH_temp6773830) {
return $Hann_DASH_check_DASH_temp17473831(ann_DASH_check_DASH_temp6773830);
}};
$e38193820.stack[R.EXN_STACKHEIGHT++] = $ss38233824;
}
if(R.isPyretException($e38193820)) {
$e38193820.pyretStack.push(L[410]);
}
throw $e38193820;
}
var $ret38253826 = $Hann_DASH_check_DASH_temp17473831($z38213822);
++R.GAS;
return $ret38253826;
});
var anf_arg6803814 = G(self2683801,"env",L[409]);
var $z38043805 = D;
var $f38103811 = function(_) {
return R.isFunction(anf_fun6763812)?anf_fun6763812.app(anf_arg6793813,anf_arg6803814,new_DASH_args2753794):R.ffi.throwNonFunApp(L[408],anf_fun6763812,[anf_arg6793813,anf_arg6803814,new_DASH_args2753794]);
};
try {
if(--R.GAS > 0) {
$z38043805 = $f38103811();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38103811,
"from":L[408]});
}
} catch($e38023803) {
if(R.isCont($e38023803)) {
var $ss38063807 = {"from":L[408],
"go":function(args_DASH_env2763815) {
return $Hargs_DASH_env17523816(args_DASH_env2763815,A317,_check2743795,ann2713796,body2733798,doc2723799,l2693800,new_DASH_args2753794,self2683801);
}};
$e38023803.stack[R.EXN_STACKHEIGHT++] = $ss38063807;
}
if(R.isPyretException($e38023803)) {
$e38023803.pyretStack.push(L[408]);
}
throw $e38023803;
}
var $ret38083809 = $Hargs_DASH_env17523816($z38043805,A317,_check2743795,ann2713796,body2733798,doc2723799,l2693800,new_DASH_args2753794,self2683801);
++R.GAS;
return $ret38083809;
};
var $Hargs_DASH_env17523816 = function(args_DASH_env2763815,A317,_check2743795,ann2713796,body2733798,doc2723799,l2693800,new_DASH_args2753794,self2683801) {
var anf_fun6813842 = G(body2733798,"visit",L[414]);
var anf_arg6823843 = self2683801.extendWith({"env":args_DASH_env2763815});
var $z38343835 = D;
var $f38403841 = function(_) {
return R.isFunction(anf_fun6813842)?anf_fun6813842.app(anf_arg6823843):R.ffi.throwNonFunApp(L[413],anf_fun6813842,[anf_arg6823843]);
};
try {
if(--R.GAS > 0) {
$z38343835 = $f38403841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38403841,
"from":L[413]});
}
} catch($e38323833) {
if(R.isCont($e38323833)) {
var $ss38363837 = {"from":L[413],
"go":function(new_DASH_body2793844) {
return $Hnew_DASH_body17513845(new_DASH_body2793844,A317,_check2743795,ann2713796,args_DASH_env2763815,doc2723799,l2693800,new_DASH_args2753794,self2683801);
}};
$e38323833.stack[R.EXN_STACKHEIGHT++] = $ss38363837;
}
if(R.isPyretException($e38323833)) {
$e38323833.pyretStack.push(L[413]);
}
throw $e38323833;
}
var $ret38383839 = $Hnew_DASH_body17513845($z38343835,A317,_check2743795,ann2713796,args_DASH_env2763815,doc2723799,l2693800,new_DASH_args2753794,self2683801);
++R.GAS;
return $ret38383839;
};
var $Hnew_DASH_body17513845 = function(new_DASH_body2793844,A317,_check2743795,ann2713796,args_DASH_env2763815,doc2723799,l2693800,new_DASH_args2753794,self2683801) {
var anf_bracket6833859 = self2683801.extendWith({"env":args_DASH_env2763815});
var anf_fun6843856 = G(anf_bracket6833859,"option",L[416]);
var $z38483849 = D;
var $f38543855 = function(_) {
return R.isFunction(anf_fun6843856)?anf_fun6843856.app(_check2743795):R.ffi.throwNonFunApp(L[415],anf_fun6843856,[_check2743795]);
};
try {
if(--R.GAS > 0) {
$z38483849 = $f38543855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38543855,
"from":L[415]});
}
} catch($e38463847) {
if(R.isCont($e38463847)) {
var $ss38503851 = {"from":L[415],
"go":function(new_DASH_check2803857) {
return $Hnew_DASH_check17503858(new_DASH_check2803857,A317,ann2713796,args_DASH_env2763815,doc2723799,l2693800,new_DASH_args2753794,new_DASH_body2793844,self2683801);
}};
$e38463847.stack[R.EXN_STACKHEIGHT++] = $ss38503851;
}
if(R.isPyretException($e38463847)) {
$e38463847.pyretStack.push(L[415]);
}
throw $e38463847;
}
var $ret38523853 = $Hnew_DASH_check17503858($z38483849,A317,ann2713796,args_DASH_env2763815,doc2723799,l2693800,new_DASH_args2753794,new_DASH_body2793844,self2683801);
++R.GAS;
return $ret38523853;
};
var $Hnew_DASH_check17503858 = function(new_DASH_check2803857,A317,ann2713796,args_DASH_env2763815,doc2723799,l2693800,new_DASH_args2753794,new_DASH_body2793844,self2683801) {
var anf_fun6853873 = G(A317,"s-method",L[419]);
var anf_fun6863870 = G(ann2713796,"visit",L[418]);
var anf_arg6873871 = self2683801.extendWith({"env":args_DASH_env2763815});
var $z38623863 = D;
var $f38683869 = function(_) {
return R.isFunction(anf_fun6863870)?anf_fun6863870.app(anf_arg6873871):R.ffi.throwNonFunApp(L[417],anf_fun6863870,[anf_arg6873871]);
};
try {
if(--R.GAS > 0) {
$z38623863 = $f38683869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38683869,
"from":L[417]});
}
} catch($e38603861) {
if(R.isCont($e38603861)) {
var $ss38643865 = {"from":L[417],
"go":function(anf_arg6883872) {
return $Hanf_arg17493874(anf_arg6883872,anf_fun6853873,doc2723799,l2693800,new_DASH_args2753794,new_DASH_body2793844,new_DASH_check2803857);
}};
$e38603861.stack[R.EXN_STACKHEIGHT++] = $ss38643865;
}
if(R.isPyretException($e38603861)) {
$e38603861.pyretStack.push(L[417]);
}
throw $e38603861;
}
var $ret38663867 = $Hanf_arg17493874($z38623863,anf_fun6853873,doc2723799,l2693800,new_DASH_args2753794,new_DASH_body2793844,new_DASH_check2803857);
++R.GAS;
return $ret38663867;
};
var $Hanf_arg17493874 = function(anf_arg6883872,anf_fun6853873,doc2723799,l2693800,new_DASH_args2753794,new_DASH_body2793844,new_DASH_check2803857) {
var $z38773878 = D;
var $f38833884 = function(_) {
return R.isFunction(anf_fun6853873)?anf_fun6853873.app(l2693800,new_DASH_args2753794,anf_arg6883872,doc2723799,new_DASH_body2793844,new_DASH_check2803857):R.ffi.throwNonFunApp(L[420],anf_fun6853873,[l2693800,new_DASH_args2753794,anf_arg6883872,doc2723799,new_DASH_body2793844,new_DASH_check2803857]);
};
try {
if(--R.GAS > 0) {
$z38773878 = $f38833884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38833884,
"from":L[420]});
}
} catch($e38753876) {
if(R.isCont($e38753876)) {
var $ss38793880 = {"from":L[420],
"go":function(ann_DASH_check_DASH_temp6713885) {
return $Hann_DASH_check_DASH_temp17483886(ann_DASH_check_DASH_temp6713885);
}};
$e38753876.stack[R.EXN_STACKHEIGHT++] = $ss38793880;
}
if(R.isPyretException($e38753876)) {
$e38753876.pyretStack.push(L[420]);
}
throw $e38753876;
}
var $ret38813882 = $Hann_DASH_check_DASH_temp17483886($z38773878);
++R.GAS;
return $ret38813882;
};
var $Hann_DASH_check_DASH_temp17483886 = function(ann_DASH_check_DASH_temp6713885) {
return ann_DASH_check_DASH_temp6713885;
};
var $Hann_DASH_check_DASH_temp17473831 = function(ann_DASH_check_DASH_temp6773830) {
return ann_DASH_check_DASH_temp6773830;
};
var $Hann_DASH_check_DASH_temp17463887 = function(ann_DASH_check_DASH_temp6733888) {
return ann_DASH_check_DASH_temp6733888;
};
var $Hnew_DASH_type_DASH_env17453889 = function(new_DASH_type_DASH_env2643890,A317,_check2633891,l2563892,mixins2603893,name2573894,namet2583895,params2593896,self2553897,shared_DASH_members2623898,variants2613899) {
var with_DASH_params2673911 = self2553897.extendWith({"type-env":new_DASH_type_DASH_env2643890});
var anf_fun6503913 = G(A317,"s-data-expr",L[423]);
var anf_fun6513910 = G(namet2583895,"visit",L[422]);
var $z39023903 = D;
var $f39083909 = function(_) {
return R.isFunction(anf_fun6513910)?anf_fun6513910.app(with_DASH_params2673911):R.ffi.throwNonFunApp(L[421],anf_fun6513910,[with_DASH_params2673911]);
};
try {
if(--R.GAS > 0) {
$z39023903 = $f39083909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39083909,
"from":L[421]});
}
} catch($e39003901) {
if(R.isCont($e39003901)) {
var $ss39043905 = {"from":L[421],
"go":function(anf_arg6523912) {
return $Hanf_arg17443914(anf_arg6523912,_check2633891,anf_fun6503913,l2563892,mixins2603893,name2573894,params2593896,shared_DASH_members2623898,variants2613899,with_DASH_params2673911);
}};
$e39003901.stack[R.EXN_STACKHEIGHT++] = $ss39043905;
}
if(R.isPyretException($e39003901)) {
$e39003901.pyretStack.push(L[421]);
}
throw $e39003901;
}
var $ret39063907 = $Hanf_arg17443914($z39023903,_check2633891,anf_fun6503913,l2563892,mixins2603893,name2573894,params2593896,shared_DASH_members2623898,variants2613899,with_DASH_params2673911);
++R.GAS;
return $ret39063907;
};
var $Hanf_arg17443914 = function(anf_arg6523912,_check2633891,anf_fun6503913,l2563892,mixins2603893,name2573894,params2593896,shared_DASH_members2623898,variants2613899,with_DASH_params2673911) {
var anf_fun6533925 = G(mixins2603893,"map",L[426]);
var anf_arg6563926 = R.makeFunction(function(recv_DASH_753929) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[425],1,arguments);
}
var anf_fun6553940 = G(recv_DASH_753929,"visit",L[425]);
var $z39323933 = D;
var $f39383939 = function(_) {
return R.isFunction(anf_fun6553940)?anf_fun6553940.app(with_DASH_params2673911):R.ffi.throwNonFunApp(L[425],anf_fun6553940,[with_DASH_params2673911]);
};
try {
if(--R.GAS > 0) {
$z39323933 = $f39383939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39383939,
"from":L[425]});
}
} catch($e39303931) {
if(R.isCont($e39303931)) {
var $ss39343935 = {"from":L[425],
"go":function(ann_DASH_check_DASH_temp6543941) {
return $Hann_DASH_check_DASH_temp17363942(ann_DASH_check_DASH_temp6543941);
}};
$e39303931.stack[R.EXN_STACKHEIGHT++] = $ss39343935;
}
if(R.isPyretException($e39303931)) {
$e39303931.pyretStack.push(L[425]);
}
throw $e39303931;
}
var $ret39363937 = $Hann_DASH_check_DASH_temp17363942($z39323933);
++R.GAS;
return $ret39363937;
});
var $z39173918 = D;
var $f39233924 = function(_) {
return R.isFunction(anf_fun6533925)?anf_fun6533925.app(anf_arg6563926):R.ffi.throwNonFunApp(L[424],anf_fun6533925,[anf_arg6563926]);
};
try {
if(--R.GAS > 0) {
$z39173918 = $f39233924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39233924,
"from":L[424]});
}
} catch($e39153916) {
if(R.isCont($e39153916)) {
var $ss39193920 = {"from":L[424],
"go":function(anf_arg6573927) {
return $Hanf_arg17433928(anf_arg6573927,_check2633891,anf_arg6523912,anf_fun6503913,l2563892,name2573894,params2593896,shared_DASH_members2623898,variants2613899,with_DASH_params2673911);
}};
$e39153916.stack[R.EXN_STACKHEIGHT++] = $ss39193920;
}
if(R.isPyretException($e39153916)) {
$e39153916.pyretStack.push(L[424]);
}
throw $e39153916;
}
var $ret39213922 = $Hanf_arg17433928($z39173918,_check2633891,anf_arg6523912,anf_fun6503913,l2563892,name2573894,params2593896,shared_DASH_members2623898,variants2613899,with_DASH_params2673911);
++R.GAS;
return $ret39213922;
};
var $Hanf_arg17433928 = function(anf_arg6573927,_check2633891,anf_arg6523912,anf_fun6503913,l2563892,name2573894,params2593896,shared_DASH_members2623898,variants2613899,with_DASH_params2673911) {
var anf_fun6583953 = G(variants2613899,"map",L[429]);
var anf_arg6613954 = R.makeFunction(function(recv_DASH_763957) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[428],1,arguments);
}
var anf_fun6603968 = G(recv_DASH_763957,"visit",L[428]);
var $z39603961 = D;
var $f39663967 = function(_) {
return R.isFunction(anf_fun6603968)?anf_fun6603968.app(with_DASH_params2673911):R.ffi.throwNonFunApp(L[428],anf_fun6603968,[with_DASH_params2673911]);
};
try {
if(--R.GAS > 0) {
$z39603961 = $f39663967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39663967,
"from":L[428]});
}
} catch($e39583959) {
if(R.isCont($e39583959)) {
var $ss39623963 = {"from":L[428],
"go":function(ann_DASH_check_DASH_temp6593969) {
return $Hann_DASH_check_DASH_temp17373970(ann_DASH_check_DASH_temp6593969);
}};
$e39583959.stack[R.EXN_STACKHEIGHT++] = $ss39623963;
}
if(R.isPyretException($e39583959)) {
$e39583959.pyretStack.push(L[428]);
}
throw $e39583959;
}
var $ret39643965 = $Hann_DASH_check_DASH_temp17373970($z39603961);
++R.GAS;
return $ret39643965;
});
var $z39453946 = D;
var $f39513952 = function(_) {
return R.isFunction(anf_fun6583953)?anf_fun6583953.app(anf_arg6613954):R.ffi.throwNonFunApp(L[427],anf_fun6583953,[anf_arg6613954]);
};
try {
if(--R.GAS > 0) {
$z39453946 = $f39513952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39513952,
"from":L[427]});
}
} catch($e39433944) {
if(R.isCont($e39433944)) {
var $ss39473948 = {"from":L[427],
"go":function(anf_arg6623955) {
return $Hanf_arg17423956(anf_arg6623955,_check2633891,anf_arg6523912,anf_arg6573927,anf_fun6503913,l2563892,name2573894,params2593896,shared_DASH_members2623898,with_DASH_params2673911);
}};
$e39433944.stack[R.EXN_STACKHEIGHT++] = $ss39473948;
}
if(R.isPyretException($e39433944)) {
$e39433944.pyretStack.push(L[427]);
}
throw $e39433944;
}
var $ret39493950 = $Hanf_arg17423956($z39453946,_check2633891,anf_arg6523912,anf_arg6573927,anf_fun6503913,l2563892,name2573894,params2593896,shared_DASH_members2623898,with_DASH_params2673911);
++R.GAS;
return $ret39493950;
};
var $Hanf_arg17423956 = function(anf_arg6623955,_check2633891,anf_arg6523912,anf_arg6573927,anf_fun6503913,l2563892,name2573894,params2593896,shared_DASH_members2623898,with_DASH_params2673911) {
var anf_fun6633981 = G(shared_DASH_members2623898,"map",L[432]);
var anf_arg6663982 = R.makeFunction(function(recv_DASH_773985) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[431],1,arguments);
}
var anf_fun6653996 = G(recv_DASH_773985,"visit",L[431]);
var $z39883989 = D;
var $f39943995 = function(_) {
return R.isFunction(anf_fun6653996)?anf_fun6653996.app(with_DASH_params2673911):R.ffi.throwNonFunApp(L[431],anf_fun6653996,[with_DASH_params2673911]);
};
try {
if(--R.GAS > 0) {
$z39883989 = $f39943995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39943995,
"from":L[431]});
}
} catch($e39863987) {
if(R.isCont($e39863987)) {
var $ss39903991 = {"from":L[431],
"go":function(ann_DASH_check_DASH_temp6643997) {
return $Hann_DASH_check_DASH_temp17383998(ann_DASH_check_DASH_temp6643997);
}};
$e39863987.stack[R.EXN_STACKHEIGHT++] = $ss39903991;
}
if(R.isPyretException($e39863987)) {
$e39863987.pyretStack.push(L[431]);
}
throw $e39863987;
}
var $ret39923993 = $Hann_DASH_check_DASH_temp17383998($z39883989);
++R.GAS;
return $ret39923993;
});
var $z39733974 = D;
var $f39793980 = function(_) {
return R.isFunction(anf_fun6633981)?anf_fun6633981.app(anf_arg6663982):R.ffi.throwNonFunApp(L[430],anf_fun6633981,[anf_arg6663982]);
};
try {
if(--R.GAS > 0) {
$z39733974 = $f39793980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39793980,
"from":L[430]});
}
} catch($e39713972) {
if(R.isCont($e39713972)) {
var $ss39753976 = {"from":L[430],
"go":function(anf_arg6673983) {
return $Hanf_arg17413984(anf_arg6673983,_check2633891,anf_arg6523912,anf_arg6573927,anf_arg6623955,anf_fun6503913,l2563892,name2573894,params2593896,with_DASH_params2673911);
}};
$e39713972.stack[R.EXN_STACKHEIGHT++] = $ss39753976;
}
if(R.isPyretException($e39713972)) {
$e39713972.pyretStack.push(L[430]);
}
throw $e39713972;
}
var $ret39773978 = $Hanf_arg17413984($z39733974,_check2633891,anf_arg6523912,anf_arg6573927,anf_arg6623955,anf_fun6503913,l2563892,name2573894,params2593896,with_DASH_params2673911);
++R.GAS;
return $ret39773978;
};
var $Hanf_arg17413984 = function(anf_arg6673983,_check2633891,anf_arg6523912,anf_arg6573927,anf_arg6623955,anf_fun6503913,l2563892,name2573894,params2593896,with_DASH_params2673911) {
var anf_fun6684009 = G(with_DASH_params2673911,"option",L[434]);
var $z40014002 = D;
var $f40074008 = function(_) {
return R.isFunction(anf_fun6684009)?anf_fun6684009.app(_check2633891):R.ffi.throwNonFunApp(L[433],anf_fun6684009,[_check2633891]);
};
try {
if(--R.GAS > 0) {
$z40014002 = $f40074008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40074008,
"from":L[433]});
}
} catch($e39994000) {
if(R.isCont($e39994000)) {
var $ss40034004 = {"from":L[433],
"go":function(anf_arg6694010) {
return $Hanf_arg17404011(anf_arg6694010,anf_arg6523912,anf_arg6573927,anf_arg6623955,anf_arg6673983,anf_fun6503913,l2563892,name2573894,params2593896);
}};
$e39994000.stack[R.EXN_STACKHEIGHT++] = $ss40034004;
}
if(R.isPyretException($e39994000)) {
$e39994000.pyretStack.push(L[433]);
}
throw $e39994000;
}
var $ret40054006 = $Hanf_arg17404011($z40014002,anf_arg6523912,anf_arg6573927,anf_arg6623955,anf_arg6673983,anf_fun6503913,l2563892,name2573894,params2593896);
++R.GAS;
return $ret40054006;
};
var $Hanf_arg17404011 = function(anf_arg6694010,anf_arg6523912,anf_arg6573927,anf_arg6623955,anf_arg6673983,anf_fun6503913,l2563892,name2573894,params2593896) {
var $z40144015 = D;
var $f40204021 = function(_) {
return R.isFunction(anf_fun6503913)?anf_fun6503913.app(l2563892,name2573894,anf_arg6523912,params2593896,anf_arg6573927,anf_arg6623955,anf_arg6673983,anf_arg6694010):R.ffi.throwNonFunApp(L[435],anf_fun6503913,[l2563892,name2573894,anf_arg6523912,params2593896,anf_arg6573927,anf_arg6623955,anf_arg6673983,anf_arg6694010]);
};
try {
if(--R.GAS > 0) {
$z40144015 = $f40204021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40204021,
"from":L[435]});
}
} catch($e40124013) {
if(R.isCont($e40124013)) {
var $ss40164017 = {"from":L[435],
"go":function(ann_DASH_check_DASH_temp6444022) {
return $Hann_DASH_check_DASH_temp17394023(ann_DASH_check_DASH_temp6444022);
}};
$e40124013.stack[R.EXN_STACKHEIGHT++] = $ss40164017;
}
if(R.isPyretException($e40124013)) {
$e40124013.pyretStack.push(L[435]);
}
throw $e40124013;
}
var $ret40184019 = $Hann_DASH_check_DASH_temp17394023($z40144015);
++R.GAS;
return $ret40184019;
};
var $Hann_DASH_check_DASH_temp17394023 = function(ann_DASH_check_DASH_temp6444022) {
return ann_DASH_check_DASH_temp6444022;
};
var $Hann_DASH_check_DASH_temp17383998 = function(ann_DASH_check_DASH_temp6643997) {
return ann_DASH_check_DASH_temp6643997;
};
var $Hann_DASH_check_DASH_temp17373970 = function(ann_DASH_check_DASH_temp6593969) {
return ann_DASH_check_DASH_temp6593969;
};
var $Hann_DASH_check_DASH_temp17363942 = function(ann_DASH_check_DASH_temp6543941) {
return ann_DASH_check_DASH_temp6543941;
};
var $Hann_DASH_check_DASH_temp17354024 = function(ann_DASH_check_DASH_temp6464025) {
return ann_DASH_check_DASH_temp6464025;
};
var $Hnew_DASH_type_DASH_env17344026 = function(new_DASH_type_DASH_env2444027,A317,_check2434028,ann2404029,args2394030,bind_DASH_handlers1883797,body2424031,doc2414032,l2374033,lists1523,params2384034,self2364035) {
var with_DASH_params2474049 = self2364035.extendWith({"type-env":new_DASH_type_DASH_env2444027});
var anf_fun6294046 = G(args2394030,"map",L[438]);
var anf_arg6324047 = R.makeFunction(function(recv_DASH_744051) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[437],1,arguments);
}
var anf_fun6314062 = G(recv_DASH_744051,"visit",L[437]);
var $z40544055 = D;
var $f40604061 = function(_) {
return R.isFunction(anf_fun6314062)?anf_fun6314062.app(with_DASH_params2474049):R.ffi.throwNonFunApp(L[437],anf_fun6314062,[with_DASH_params2474049]);
};
try {
if(--R.GAS > 0) {
$z40544055 = $f40604061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40604061,
"from":L[437]});
}
} catch($e40524053) {
if(R.isCont($e40524053)) {
var $ss40564057 = {"from":L[437],
"go":function(ann_DASH_check_DASH_temp6304063) {
return $Hann_DASH_check_DASH_temp17264064(ann_DASH_check_DASH_temp6304063);
}};
$e40524053.stack[R.EXN_STACKHEIGHT++] = $ss40564057;
}
if(R.isPyretException($e40524053)) {
$e40524053.pyretStack.push(L[437]);
}
throw $e40524053;
}
var $ret40584059 = $Hann_DASH_check_DASH_temp17264064($z40544055);
++R.GAS;
return $ret40584059;
});
var $z40384039 = D;
var $f40444045 = function(_) {
return R.isFunction(anf_fun6294046)?anf_fun6294046.app(anf_arg6324047):R.ffi.throwNonFunApp(L[436],anf_fun6294046,[anf_arg6324047]);
};
try {
if(--R.GAS > 0) {
$z40384039 = $f40444045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40444045,
"from":L[436]});
}
} catch($e40364037) {
if(R.isCont($e40364037)) {
var $ss40404041 = {"from":L[436],
"go":function(new_DASH_args2484048) {
return $Hnew_DASH_args17334050(new_DASH_args2484048,A317,_check2434028,ann2404029,args2394030,bind_DASH_handlers1883797,body2424031,doc2414032,l2374033,lists1523,params2384034,with_DASH_params2474049);
}};
$e40364037.stack[R.EXN_STACKHEIGHT++] = $ss40404041;
}
if(R.isPyretException($e40364037)) {
$e40364037.pyretStack.push(L[436]);
}
throw $e40364037;
}
var $ret40424043 = $Hnew_DASH_args17334050($z40384039,A317,_check2434028,ann2404029,args2394030,bind_DASH_handlers1883797,body2424031,doc2414032,l2374033,lists1523,params2384034,with_DASH_params2474049);
++R.GAS;
return $ret40424043;
};
var $Hnew_DASH_args17334050 = function(new_DASH_args2484048,A317,_check2434028,ann2404029,args2394030,bind_DASH_handlers1883797,body2424031,doc2414032,l2374033,lists1523,params2384034,with_DASH_params2474049) {
var anf_fun6334075 = G(lists1523,"fold",L[443]);
var anf_arg6364076 = R.makeFunction(function(acc2504080,new_DASH_arg2514081) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[441],2,arguments);
}
var anf_fun6354092 = G(bind_DASH_handlers1883797,"s-bind",L[442]);
var $z40844085 = D;
var $f40904091 = function(_) {
return R.isFunction(anf_fun6354092)?anf_fun6354092.app(new_DASH_arg2514081,acc2504080):R.ffi.throwNonFunApp(L[441],anf_fun6354092,[new_DASH_arg2514081,acc2504080]);
};
try {
if(--R.GAS > 0) {
$z40844085 = $f40904091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40904091,
"from":L[441]});
}
} catch($e40824083) {
if(R.isCont($e40824083)) {
var $ss40864087 = {"from":L[441],
"go":function(ann_DASH_check_DASH_temp6344093) {
return $Hann_DASH_check_DASH_temp17274094(ann_DASH_check_DASH_temp6344093);
}};
$e40824083.stack[R.EXN_STACKHEIGHT++] = $ss40864087;
}
if(R.isPyretException($e40824083)) {
$e40824083.pyretStack.push(L[441]);
}
throw $e40824083;
}
var $ret40884089 = $Hann_DASH_check_DASH_temp17274094($z40844085);
++R.GAS;
return $ret40884089;
});
var anf_arg6374077 = G(with_DASH_params2474049,"env",L[440]);
var $z40674068 = D;
var $f40734074 = function(_) {
return R.isFunction(anf_fun6334075)?anf_fun6334075.app(anf_arg6364076,anf_arg6374077,args2394030):R.ffi.throwNonFunApp(L[439],anf_fun6334075,[anf_arg6364076,anf_arg6374077,args2394030]);
};
try {
if(--R.GAS > 0) {
$z40674068 = $f40734074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40734074,
"from":L[439]});
}
} catch($e40654066) {
if(R.isCont($e40654066)) {
var $ss40694070 = {"from":L[439],
"go":function(args_DASH_env2494078) {
return $Hargs_DASH_env17324079(args_DASH_env2494078,A317,_check2434028,ann2404029,body2424031,doc2414032,l2374033,new_DASH_args2484048,params2384034,with_DASH_params2474049);
}};
$e40654066.stack[R.EXN_STACKHEIGHT++] = $ss40694070;
}
if(R.isPyretException($e40654066)) {
$e40654066.pyretStack.push(L[439]);
}
throw $e40654066;
}
var $ret40714072 = $Hargs_DASH_env17324079($z40674068,A317,_check2434028,ann2404029,body2424031,doc2414032,l2374033,new_DASH_args2484048,params2384034,with_DASH_params2474049);
++R.GAS;
return $ret40714072;
};
var $Hargs_DASH_env17324079 = function(args_DASH_env2494078,A317,_check2434028,ann2404029,body2424031,doc2414032,l2374033,new_DASH_args2484048,params2384034,with_DASH_params2474049) {
var with_DASH_args2524106 = with_DASH_params2474049.extendWith({"env":args_DASH_env2494078});
var anf_fun6384105 = G(body2424031,"visit",L[445]);
var $z40974098 = D;
var $f41034104 = function(_) {
return R.isFunction(anf_fun6384105)?anf_fun6384105.app(with_DASH_args2524106):R.ffi.throwNonFunApp(L[444],anf_fun6384105,[with_DASH_args2524106]);
};
try {
if(--R.GAS > 0) {
$z40974098 = $f41034104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41034104,
"from":L[444]});
}
} catch($e40954096) {
if(R.isCont($e40954096)) {
var $ss40994100 = {"from":L[444],
"go":function(new_DASH_body2534107) {
return $Hnew_DASH_body17314108(new_DASH_body2534107,A317,_check2434028,ann2404029,doc2414032,l2374033,new_DASH_args2484048,params2384034,with_DASH_args2524106);
}};
$e40954096.stack[R.EXN_STACKHEIGHT++] = $ss40994100;
}
if(R.isPyretException($e40954096)) {
$e40954096.pyretStack.push(L[444]);
}
throw $e40954096;
}
var $ret41014102 = $Hnew_DASH_body17314108($z40974098,A317,_check2434028,ann2404029,doc2414032,l2374033,new_DASH_args2484048,params2384034,with_DASH_args2524106);
++R.GAS;
return $ret41014102;
};
var $Hnew_DASH_body17314108 = function(new_DASH_body2534107,A317,_check2434028,ann2404029,doc2414032,l2374033,new_DASH_args2484048,params2384034,with_DASH_args2524106) {
var anf_fun6394119 = G(with_DASH_args2524106,"option",L[447]);
var $z41114112 = D;
var $f41174118 = function(_) {
return R.isFunction(anf_fun6394119)?anf_fun6394119.app(_check2434028):R.ffi.throwNonFunApp(L[446],anf_fun6394119,[_check2434028]);
};
try {
if(--R.GAS > 0) {
$z41114112 = $f41174118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41174118,
"from":L[446]});
}
} catch($e41094110) {
if(R.isCont($e41094110)) {
var $ss41134114 = {"from":L[446],
"go":function(new_DASH_check2544120) {
return $Hnew_DASH_check17304121(new_DASH_check2544120,A317,ann2404029,doc2414032,l2374033,new_DASH_args2484048,new_DASH_body2534107,params2384034,with_DASH_args2524106);
}};
$e41094110.stack[R.EXN_STACKHEIGHT++] = $ss41134114;
}
if(R.isPyretException($e41094110)) {
$e41094110.pyretStack.push(L[446]);
}
throw $e41094110;
}
var $ret41154116 = $Hnew_DASH_check17304121($z41114112,A317,ann2404029,doc2414032,l2374033,new_DASH_args2484048,new_DASH_body2534107,params2384034,with_DASH_args2524106);
++R.GAS;
return $ret41154116;
};
var $Hnew_DASH_check17304121 = function(new_DASH_check2544120,A317,ann2404029,doc2414032,l2374033,new_DASH_args2484048,new_DASH_body2534107,params2384034,with_DASH_args2524106) {
var anf_fun6404134 = G(A317,"s-lam",L[450]);
var anf_fun6414132 = G(ann2404029,"visit",L[449]);
var $z41244125 = D;
var $f41304131 = function(_) {
return R.isFunction(anf_fun6414132)?anf_fun6414132.app(with_DASH_args2524106):R.ffi.throwNonFunApp(L[448],anf_fun6414132,[with_DASH_args2524106]);
};
try {
if(--R.GAS > 0) {
$z41244125 = $f41304131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41304131,
"from":L[448]});
}
} catch($e41224123) {
if(R.isCont($e41224123)) {
var $ss41264127 = {"from":L[448],
"go":function(anf_arg6424133) {
return $Hanf_arg17294135(anf_arg6424133,anf_fun6404134,doc2414032,l2374033,new_DASH_args2484048,new_DASH_body2534107,new_DASH_check2544120,params2384034);
}};
$e41224123.stack[R.EXN_STACKHEIGHT++] = $ss41264127;
}
if(R.isPyretException($e41224123)) {
$e41224123.pyretStack.push(L[448]);
}
throw $e41224123;
}
var $ret41284129 = $Hanf_arg17294135($z41244125,anf_fun6404134,doc2414032,l2374033,new_DASH_args2484048,new_DASH_body2534107,new_DASH_check2544120,params2384034);
++R.GAS;
return $ret41284129;
};
var $Hanf_arg17294135 = function(anf_arg6424133,anf_fun6404134,doc2414032,l2374033,new_DASH_args2484048,new_DASH_body2534107,new_DASH_check2544120,params2384034) {
var $z41384139 = D;
var $f41444145 = function(_) {
return R.isFunction(anf_fun6404134)?anf_fun6404134.app(l2374033,params2384034,new_DASH_args2484048,anf_arg6424133,doc2414032,new_DASH_body2534107,new_DASH_check2544120):R.ffi.throwNonFunApp(L[451],anf_fun6404134,[l2374033,params2384034,new_DASH_args2484048,anf_arg6424133,doc2414032,new_DASH_body2534107,new_DASH_check2544120]);
};
try {
if(--R.GAS > 0) {
$z41384139 = $f41444145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41444145,
"from":L[451]});
}
} catch($e41364137) {
if(R.isCont($e41364137)) {
var $ss41404141 = {"from":L[451],
"go":function(ann_DASH_check_DASH_temp6234146) {
return $Hann_DASH_check_DASH_temp17284147(ann_DASH_check_DASH_temp6234146);
}};
$e41364137.stack[R.EXN_STACKHEIGHT++] = $ss41404141;
}
if(R.isPyretException($e41364137)) {
$e41364137.pyretStack.push(L[451]);
}
throw $e41364137;
}
var $ret41424143 = $Hann_DASH_check_DASH_temp17284147($z41384139);
++R.GAS;
return $ret41424143;
};
var $Hann_DASH_check_DASH_temp17284147 = function(ann_DASH_check_DASH_temp6234146) {
return ann_DASH_check_DASH_temp6234146;
};
var $Hann_DASH_check_DASH_temp17274094 = function(ann_DASH_check_DASH_temp6344093) {
return ann_DASH_check_DASH_temp6344093;
};
var $Hann_DASH_check_DASH_temp17264064 = function(ann_DASH_check_DASH_temp6304063) {
return ann_DASH_check_DASH_temp6304063;
};
var $Hann_DASH_check_DASH_temp17254148 = function(ann_DASH_check_DASH_temp6254149) {
return ann_DASH_check_DASH_temp6254149;
};
var $Hbind_DASH_env17244150 = function(bind_DASH_env2304151,A317,binds2284152,body2294153,l2274154,self2264155) {
var new_DASH_visitor2334169 = self2264155.extendWith({"env":bind_DASH_env2304151});
var anf_fun6164166 = G(binds2284152,"map",L[454]);
var anf_arg6194167 = R.makeFunction(function(recv_DASH_734171) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[453],1,arguments);
}
var anf_fun6184182 = G(recv_DASH_734171,"visit",L[453]);
var $z41744175 = D;
var $f41804181 = function(_) {
return R.isFunction(anf_fun6184182)?anf_fun6184182.app(new_DASH_visitor2334169):R.ffi.throwNonFunApp(L[453],anf_fun6184182,[new_DASH_visitor2334169]);
};
try {
if(--R.GAS > 0) {
$z41744175 = $f41804181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41804181,
"from":L[453]});
}
} catch($e41724173) {
if(R.isCont($e41724173)) {
var $ss41764177 = {"from":L[453],
"go":function(ann_DASH_check_DASH_temp6174183) {
return $Hann_DASH_check_DASH_temp17204184(ann_DASH_check_DASH_temp6174183);
}};
$e41724173.stack[R.EXN_STACKHEIGHT++] = $ss41764177;
}
if(R.isPyretException($e41724173)) {
$e41724173.pyretStack.push(L[453]);
}
throw $e41724173;
}
var $ret41784179 = $Hann_DASH_check_DASH_temp17204184($z41744175);
++R.GAS;
return $ret41784179;
});
var $z41584159 = D;
var $f41644165 = function(_) {
return R.isFunction(anf_fun6164166)?anf_fun6164166.app(anf_arg6194167):R.ffi.throwNonFunApp(L[452],anf_fun6164166,[anf_arg6194167]);
};
try {
if(--R.GAS > 0) {
$z41584159 = $f41644165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41644165,
"from":L[452]});
}
} catch($e41564157) {
if(R.isCont($e41564157)) {
var $ss41604161 = {"from":L[452],
"go":function(visit_DASH_binds2344168) {
return $Hvisit_DASH_binds17234170(visit_DASH_binds2344168,A317,body2294153,l2274154,new_DASH_visitor2334169);
}};
$e41564157.stack[R.EXN_STACKHEIGHT++] = $ss41604161;
}
if(R.isPyretException($e41564157)) {
$e41564157.pyretStack.push(L[452]);
}
throw $e41564157;
}
var $ret41624163 = $Hvisit_DASH_binds17234170($z41584159,A317,body2294153,l2274154,new_DASH_visitor2334169);
++R.GAS;
return $ret41624163;
};
var $Hvisit_DASH_binds17234170 = function(visit_DASH_binds2344168,A317,body2294153,l2274154,new_DASH_visitor2334169) {
var anf_fun6204195 = G(body2294153,"visit",L[456]);
var $z41874188 = D;
var $f41934194 = function(_) {
return R.isFunction(anf_fun6204195)?anf_fun6204195.app(new_DASH_visitor2334169):R.ffi.throwNonFunApp(L[455],anf_fun6204195,[new_DASH_visitor2334169]);
};
try {
if(--R.GAS > 0) {
$z41874188 = $f41934194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41934194,
"from":L[455]});
}
} catch($e41854186) {
if(R.isCont($e41854186)) {
var $ss41894190 = {"from":L[455],
"go":function(visit_DASH_body2354196) {
return $Hvisit_DASH_body17224197(visit_DASH_body2354196,A317,l2274154,visit_DASH_binds2344168);
}};
$e41854186.stack[R.EXN_STACKHEIGHT++] = $ss41894190;
}
if(R.isPyretException($e41854186)) {
$e41854186.pyretStack.push(L[455]);
}
throw $e41854186;
}
var $ret41914192 = $Hvisit_DASH_body17224197($z41874188,A317,l2274154,visit_DASH_binds2344168);
++R.GAS;
return $ret41914192;
};
var $Hvisit_DASH_body17224197 = function(visit_DASH_body2354196,A317,l2274154,visit_DASH_binds2344168) {
var anf_fun6214208 = G(A317,"s-letrec",L[458]);
var $z42004201 = D;
var $f42064207 = function(_) {
return R.isFunction(anf_fun6214208)?anf_fun6214208.app(l2274154,visit_DASH_binds2344168,visit_DASH_body2354196):R.ffi.throwNonFunApp(L[457],anf_fun6214208,[l2274154,visit_DASH_binds2344168,visit_DASH_body2354196]);
};
try {
if(--R.GAS > 0) {
$z42004201 = $f42064207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42064207,
"from":L[457]});
}
} catch($e41984199) {
if(R.isCont($e41984199)) {
var $ss42024203 = {"from":L[457],
"go":function(ann_DASH_check_DASH_temp6114209) {
return $Hann_DASH_check_DASH_temp17214210(ann_DASH_check_DASH_temp6114209);
}};
$e41984199.stack[R.EXN_STACKHEIGHT++] = $ss42024203;
}
if(R.isPyretException($e41984199)) {
$e41984199.pyretStack.push(L[457]);
}
throw $e41984199;
}
var $ret42044205 = $Hann_DASH_check_DASH_temp17214210($z42004201);
++R.GAS;
return $ret42044205;
};
var $Hann_DASH_check_DASH_temp17214210 = function(ann_DASH_check_DASH_temp6114209) {
return ann_DASH_check_DASH_temp6114209;
};
var $Hann_DASH_check_DASH_temp17204184 = function(ann_DASH_check_DASH_temp6174183) {
return ann_DASH_check_DASH_temp6174183;
};
var $Hann_DASH_check_DASH_temp17194211 = function(ann_DASH_check_DASH_temp6124212) {
return ann_DASH_check_DASH_temp6124212;
};
var $Hanf_obj17184213 = function(anf_obj6024214,A317,anf_arg5994215,anf_obj6004216,binds2174217,body2184218,fold593614,l2164219,self2154220) {
var anf_arg6034231 = R.makeObject({"e":anf_obj6004216,
"bs":anf_obj6024214});
var $z42234224 = D;
var $f42294230 = function(_) {
return R.isFunction(fold593614)?fold593614.app(anf_arg5994215,anf_arg6034231,binds2174217):R.ffi.throwNonFunApp(L[459],fold593614,[anf_arg5994215,anf_arg6034231,binds2174217]);
};
try {
if(--R.GAS > 0) {
$z42234224 = $f42294230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42294230,
"from":L[459]});
}
} catch($e42214222) {
if(R.isCont($e42214222)) {
var $ss42254226 = {"from":L[459],
"go":function(bound_DASH_env2194232) {
return $Hbound_DASH_env17174233(bound_DASH_env2194232,A317,body2184218,l2164219,self2154220);
}};
$e42214222.stack[R.EXN_STACKHEIGHT++] = $ss42254226;
}
if(R.isPyretException($e42214222)) {
$e42214222.pyretStack.push(L[459]);
}
throw $e42214222;
}
var $ret42274228 = $Hbound_DASH_env17174233($z42234224,A317,body2184218,l2164219,self2154220);
++R.GAS;
return $ret42274228;
};
var $Hbound_DASH_env17174233 = function(bound_DASH_env2194232,A317,body2184218,l2164219,self2154220) {
var anf_bracket6044247 = G(bound_DASH_env2194232,"bs",L[462]);
var anf_fun6054244 = G(anf_bracket6044247,"reverse",L[461]);
var $z42364237 = D;
var $f42424243 = function(_) {
return R.isFunction(anf_fun6054244)?anf_fun6054244.app():R.ffi.throwNonFunApp(L[460],anf_fun6054244,[]);
};
try {
if(--R.GAS > 0) {
$z42364237 = $f42424243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42424243,
"from":L[460]});
}
} catch($e42344235) {
if(R.isCont($e42344235)) {
var $ss42384239 = {"from":L[460],
"go":function(visit_DASH_binds2244245) {
return $Hvisit_DASH_binds17164246(visit_DASH_binds2244245,A317,body2184218,bound_DASH_env2194232,l2164219,self2154220);
}};
$e42344235.stack[R.EXN_STACKHEIGHT++] = $ss42384239;
}
if(R.isPyretException($e42344235)) {
$e42344235.pyretStack.push(L[460]);
}
throw $e42344235;
}
var $ret42404241 = $Hvisit_DASH_binds17164246($z42364237,A317,body2184218,bound_DASH_env2194232,l2164219,self2154220);
++R.GAS;
return $ret42404241;
};
var $Hvisit_DASH_binds17164246 = function(visit_DASH_binds2244245,A317,body2184218,bound_DASH_env2194232,l2164219,self2154220) {
var anf_fun6064258 = G(body2184218,"visit",L[465]);
var anf_extend6074262 = G(bound_DASH_env2194232,"e",L[464]);
var anf_arg6084259 = self2154220.extendWith({"env":anf_extend6074262});
var $z42504251 = D;
var $f42564257 = function(_) {
return R.isFunction(anf_fun6064258)?anf_fun6064258.app(anf_arg6084259):R.ffi.throwNonFunApp(L[463],anf_fun6064258,[anf_arg6084259]);
};
try {
if(--R.GAS > 0) {
$z42504251 = $f42564257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42564257,
"from":L[463]});
}
} catch($e42484249) {
if(R.isCont($e42484249)) {
var $ss42524253 = {"from":L[463],
"go":function(visit_DASH_body2254260) {
return $Hvisit_DASH_body17154261(visit_DASH_body2254260,A317,l2164219,visit_DASH_binds2244245);
}};
$e42484249.stack[R.EXN_STACKHEIGHT++] = $ss42524253;
}
if(R.isPyretException($e42484249)) {
$e42484249.pyretStack.push(L[463]);
}
throw $e42484249;
}
var $ret42544255 = $Hvisit_DASH_body17154261($z42504251,A317,l2164219,visit_DASH_binds2244245);
++R.GAS;
return $ret42544255;
};
var $Hvisit_DASH_body17154261 = function(visit_DASH_body2254260,A317,l2164219,visit_DASH_binds2244245) {
var anf_fun6094273 = G(A317,"s-let-expr",L[467]);
var $z42654266 = D;
var $f42714272 = function(_) {
return R.isFunction(anf_fun6094273)?anf_fun6094273.app(l2164219,visit_DASH_binds2244245,visit_DASH_body2254260):R.ffi.throwNonFunApp(L[466],anf_fun6094273,[l2164219,visit_DASH_binds2244245,visit_DASH_body2254260]);
};
try {
if(--R.GAS > 0) {
$z42654266 = $f42714272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42714272,
"from":L[466]});
}
} catch($e42634264) {
if(R.isCont($e42634264)) {
var $ss42674268 = {"from":L[466],
"go":function(ann_DASH_check_DASH_temp5904274) {
return $Hann_DASH_check_DASH_temp17144275(ann_DASH_check_DASH_temp5904274);
}};
$e42634264.stack[R.EXN_STACKHEIGHT++] = $ss42674268;
}
if(R.isPyretException($e42634264)) {
$e42634264.pyretStack.push(L[466]);
}
throw $e42634264;
}
var $ret42694270 = $Hann_DASH_check_DASH_temp17144275($z42654266);
++R.GAS;
return $ret42694270;
};
var $Hann_DASH_check_DASH_temp17144275 = function(ann_DASH_check_DASH_temp5904274) {
return ann_DASH_check_DASH_temp5904274;
};
var $Hnew_DASH_bind17134276 = function(new_DASH_bind2224277,acc2204278,bind_DASH_handlers1883797,link35745) {
var anf_fun5954289 = G(bind_DASH_handlers1883797,"s-let-bind",L[470]);
var anf_arg5964290 = G(acc2204278,"e",L[469]);
var $z42814282 = D;
var $f42874288 = function(_) {
return R.isFunction(anf_fun5954289)?anf_fun5954289.app(new_DASH_bind2224277,anf_arg5964290):R.ffi.throwNonFunApp(L[468],anf_fun5954289,[new_DASH_bind2224277,anf_arg5964290]);
};
try {
if(--R.GAS > 0) {
$z42814282 = $f42874288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42874288,
"from":L[468]});
}
} catch($e42794280) {
if(R.isCont($e42794280)) {
var $ss42834284 = {"from":L[468],
"go":function(this_DASH_env2234291) {
return $Hthis_DASH_env17124292(this_DASH_env2234291,acc2204278,link35745,new_DASH_bind2224277);
}};
$e42794280.stack[R.EXN_STACKHEIGHT++] = $ss42834284;
}
if(R.isPyretException($e42794280)) {
$e42794280.pyretStack.push(L[468]);
}
throw $e42794280;
}
var $ret42854286 = $Hthis_DASH_env17124292($z42814282,acc2204278,link35745,new_DASH_bind2224277);
++R.GAS;
return $ret42854286;
};
var $Hthis_DASH_env17124292 = function(this_DASH_env2234291,acc2204278,link35745,new_DASH_bind2224277) {
var anf_arg5974303 = G(acc2204278,"bs",L[472]);
var $z42954296 = D;
var $f43014302 = function(_) {
return R.isFunction(link35745)?link35745.app(new_DASH_bind2224277,anf_arg5974303):R.ffi.throwNonFunApp(L[471],link35745,[new_DASH_bind2224277,anf_arg5974303]);
};
try {
if(--R.GAS > 0) {
$z42954296 = $f43014302();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43014302,
"from":L[471]});
}
} catch($e42934294) {
if(R.isCont($e42934294)) {
var $ss42974298 = {"from":L[471],
"go":function(anf_obj5984304) {
return $Hanf_obj17114305(anf_obj5984304,this_DASH_env2234291);
}};
$e42934294.stack[R.EXN_STACKHEIGHT++] = $ss42974298;
}
if(R.isPyretException($e42934294)) {
$e42934294.pyretStack.push(L[471]);
}
throw $e42934294;
}
var $ret42994300 = $Hanf_obj17114305($z42954296,this_DASH_env2234291);
++R.GAS;
return $ret42994300;
};
var $Hanf_obj17114305 = function(anf_obj5984304,this_DASH_env2234291) {
var ann_DASH_check_DASH_temp5914306 = R.makeObject({"e":this_DASH_env2234291,
"bs":anf_obj5984304});
return ann_DASH_check_DASH_temp5914306;
};
var $Hanf_extend17104307 = function(anf_extend5804308,A317,anf_arg5784309,anf_fun5684310,binds2064311,body2074312,l2054313,new_DASH_envs2084314,self2044315) {
var anf_arg5814326 = new_DASH_envs2084314.extendWith({"bs":anf_extend5804308});
var $z43184319 = D;
var $f43244325 = function(_) {
return R.isFunction(anf_fun5684310)?anf_fun5684310.app(anf_arg5784309,anf_arg5814326,binds2064311):R.ffi.throwNonFunApp(L[473],anf_fun5684310,[anf_arg5784309,anf_arg5814326,binds2064311]);
};
try {
if(--R.GAS > 0) {
$z43184319 = $f43244325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43244325,
"from":L[473]});
}
} catch($e43164317) {
if(R.isCont($e43164317)) {
var $ss43204321 = {"from":L[473],
"go":function(bound_DASH_env2094327) {
return $Hbound_DASH_env17094328(bound_DASH_env2094327,A317,body2074312,l2054313,self2044315);
}};
$e43164317.stack[R.EXN_STACKHEIGHT++] = $ss43204321;
}
if(R.isPyretException($e43164317)) {
$e43164317.pyretStack.push(L[473]);
}
throw $e43164317;
}
var $ret43224323 = $Hbound_DASH_env17094328($z43184319,A317,body2074312,l2054313,self2044315);
++R.GAS;
return $ret43224323;
};
var $Hbound_DASH_env17094328 = function(bound_DASH_env2094327,A317,body2074312,l2054313,self2044315) {
var anf_fun5824343 = G(A317,"s-type-let-expr",L[479]);
var anf_arg5834342 = G(bound_DASH_env2094327,"bs",L[478]);
var anf_fun5844339 = G(body2074312,"visit",L[477]);
var anf_extend5854345 = G(bound_DASH_env2094327,"val-env",L[476]);
var anf_extend5864346 = G(bound_DASH_env2094327,"type-env",L[475]);
var anf_arg5874340 = self2044315.extendWith({"env":anf_extend5854345,
"type-env":anf_extend5864346});
var $z43314332 = D;
var $f43374338 = function(_) {
return R.isFunction(anf_fun5844339)?anf_fun5844339.app(anf_arg5874340):R.ffi.throwNonFunApp(L[474],anf_fun5844339,[anf_arg5874340]);
};
try {
if(--R.GAS > 0) {
$z43314332 = $f43374338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43374338,
"from":L[474]});
}
} catch($e43294330) {
if(R.isCont($e43294330)) {
var $ss43334334 = {"from":L[474],
"go":function(anf_arg5884341) {
return $Hanf_arg17084344(anf_arg5884341,anf_arg5834342,anf_fun5824343,l2054313);
}};
$e43294330.stack[R.EXN_STACKHEIGHT++] = $ss43334334;
}
if(R.isPyretException($e43294330)) {
$e43294330.pyretStack.push(L[474]);
}
throw $e43294330;
}
var $ret43354336 = $Hanf_arg17084344($z43314332,anf_arg5834342,anf_fun5824343,l2054313);
++R.GAS;
return $ret43354336;
};
var $Hanf_arg17084344 = function(anf_arg5884341,anf_arg5834342,anf_fun5824343,l2054313) {
var $z43494350 = D;
var $f43554356 = function(_) {
return R.isFunction(anf_fun5824343)?anf_fun5824343.app(l2054313,anf_arg5834342,anf_arg5884341):R.ffi.throwNonFunApp(L[480],anf_fun5824343,[l2054313,anf_arg5834342,anf_arg5884341]);
};
try {
if(--R.GAS > 0) {
$z43494350 = $f43554356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43554356,
"from":L[480]});
}
} catch($e43474348) {
if(R.isCont($e43474348)) {
var $ss43514352 = {"from":L[480],
"go":function(ann_DASH_check_DASH_temp5654357) {
return $Hann_DASH_check_DASH_temp17074358(ann_DASH_check_DASH_temp5654357);
}};
$e43474348.stack[R.EXN_STACKHEIGHT++] = $ss43514352;
}
if(R.isPyretException($e43474348)) {
$e43474348.pyretStack.push(L[480]);
}
throw $e43474348;
}
var $ret43534354 = $Hann_DASH_check_DASH_temp17074358($z43494350);
++R.GAS;
return $ret43534354;
};
var $Hann_DASH_check_DASH_temp17074358 = function(ann_DASH_check_DASH_temp5654357) {
return ann_DASH_check_DASH_temp5654357;
};
var $Hupdated17064359 = function(updated2124360,acc2104361,b2114362,link35745,self2044315) {
var anf_extend5734377 = G(updated2124360,"val-env",L[484]);
var anf_extend5744378 = G(updated2124360,"type-env",L[483]);
var visit_DASH_envs2134374 = self2044315.extendWith({"env":anf_extend5734377,
"type-env":anf_extend5744378});
var anf_fun5754373 = G(b2114362,"visit",L[482]);
var $z43654366 = D;
var $f43714372 = function(_) {
return R.isFunction(anf_fun5754373)?anf_fun5754373.app(visit_DASH_envs2134374):R.ffi.throwNonFunApp(L[481],anf_fun5754373,[visit_DASH_envs2134374]);
};
try {
if(--R.GAS > 0) {
$z43654366 = $f43714372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43714372,
"from":L[481]});
}
} catch($e43634364) {
if(R.isCont($e43634364)) {
var $ss43674368 = {"from":L[481],
"go":function(new_DASH_bind2144375) {
return $Hnew_DASH_bind17054376(new_DASH_bind2144375,acc2104361,link35745,updated2124360);
}};
$e43634364.stack[R.EXN_STACKHEIGHT++] = $ss43674368;
}
if(R.isPyretException($e43634364)) {
$e43634364.pyretStack.push(L[481]);
}
throw $e43634364;
}
var $ret43694370 = $Hnew_DASH_bind17054376($z43654366,acc2104361,link35745,updated2124360);
++R.GAS;
return $ret43694370;
};
var $Hnew_DASH_bind17054376 = function(new_DASH_bind2144375,acc2104361,link35745,updated2124360) {
var anf_arg5764389 = G(acc2104361,"bs",L[486]);
var $z43814382 = D;
var $f43874388 = function(_) {
return R.isFunction(link35745)?link35745.app(new_DASH_bind2144375,anf_arg5764389):R.ffi.throwNonFunApp(L[485],link35745,[new_DASH_bind2144375,anf_arg5764389]);
};
try {
if(--R.GAS > 0) {
$z43814382 = $f43874388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43874388,
"from":L[485]});
}
} catch($e43794380) {
if(R.isCont($e43794380)) {
var $ss43834384 = {"from":L[485],
"go":function(anf_extend5774390) {
return $Hanf_extend17044391(anf_extend5774390,updated2124360);
}};
$e43794380.stack[R.EXN_STACKHEIGHT++] = $ss43834384;
}
if(R.isPyretException($e43794380)) {
$e43794380.pyretStack.push(L[485]);
}
throw $e43794380;
}
var $ret43854386 = $Hanf_extend17044391($z43814382,updated2124360);
++R.GAS;
return $ret43854386;
};
var $Hanf_extend17044391 = function(anf_extend5774390,updated2124360) {
var ann_DASH_check_DASH_temp5694392 = updated2124360.extendWith({"bs":anf_extend5774390});
return ann_DASH_check_DASH_temp5694392;
};
var $Hvisit_DASH_provide17034393 = function(visit_DASH_provide1954394,A317,_provide_DASH_types1924395,bind_DASH_handlers1883797,body1944396,fold593614,imports1934397,l1904398,map434399,self1894400) {
var anf_fun5484411 = G(_provide_DASH_types1924395,"visit",L[488]);
var $z44034404 = D;
var $f44094410 = function(_) {
return R.isFunction(anf_fun5484411)?anf_fun5484411.app(self1894400):R.ffi.throwNonFunApp(L[487],anf_fun5484411,[self1894400]);
};
try {
if(--R.GAS > 0) {
$z44034404 = $f44094410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44094410,
"from":L[487]});
}
} catch($e44014402) {
if(R.isCont($e44014402)) {
var $ss44054406 = {"from":L[487],
"go":function(visit_DASH_provide_DASH_types1964412) {
return $Hvisit_DASH_provide_DASH_types17024413(visit_DASH_provide_DASH_types1964412,A317,bind_DASH_handlers1883797,body1944396,fold593614,imports1934397,l1904398,map434399,self1894400,visit_DASH_provide1954394);
}};
$e44014402.stack[R.EXN_STACKHEIGHT++] = $ss44054406;
}
if(R.isPyretException($e44014402)) {
$e44014402.pyretStack.push(L[487]);
}
throw $e44014402;
}
var $ret44074408 = $Hvisit_DASH_provide_DASH_types17024413($z44034404,A317,bind_DASH_handlers1883797,body1944396,fold593614,imports1934397,l1904398,map434399,self1894400,visit_DASH_provide1954394);
++R.GAS;
return $ret44074408;
};
var $Hvisit_DASH_provide_DASH_types17024413 = function(visit_DASH_provide_DASH_types1964412,A317,bind_DASH_handlers1883797,body1944396,fold593614,imports1934397,l1904398,map434399,self1894400,visit_DASH_provide1954394) {
var anf_arg5514424 = R.makeFunction(function(i1984427) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[490],1,arguments);
}
var anf_fun5504438 = G(i1984427,"visit",L[491]);
var $z44304431 = D;
var $f44364437 = function(_) {
return R.isFunction(anf_fun5504438)?anf_fun5504438.app(self1894400):R.ffi.throwNonFunApp(L[490],anf_fun5504438,[self1894400]);
};
try {
if(--R.GAS > 0) {
$z44304431 = $f44364437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44364437,
"from":L[490]});
}
} catch($e44284429) {
if(R.isCont($e44284429)) {
var $ss44324433 = {"from":L[490],
"go":function(ann_DASH_check_DASH_temp5494439) {
return $Hann_DASH_check_DASH_temp16964440(ann_DASH_check_DASH_temp5494439);
}};
$e44284429.stack[R.EXN_STACKHEIGHT++] = $ss44324433;
}
if(R.isPyretException($e44284429)) {
$e44284429.pyretStack.push(L[490]);
}
throw $e44284429;
}
var $ret44344435 = $Hann_DASH_check_DASH_temp16964440($z44304431);
++R.GAS;
return $ret44344435;
});
var $z44164417 = D;
var $f44224423 = function(_) {
return R.isFunction(map434399)?map434399.app(anf_arg5514424,imports1934397):R.ffi.throwNonFunApp(L[489],map434399,[anf_arg5514424,imports1934397]);
};
try {
if(--R.GAS > 0) {
$z44164417 = $f44224423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44224423,
"from":L[489]});
}
} catch($e44144415) {
if(R.isCont($e44144415)) {
var $ss44184419 = {"from":L[489],
"go":function(visit_DASH_imports1974425) {
return $Hvisit_DASH_imports17014426(visit_DASH_imports1974425,A317,bind_DASH_handlers1883797,body1944396,fold593614,l1904398,self1894400,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394);
}};
$e44144415.stack[R.EXN_STACKHEIGHT++] = $ss44184419;
}
if(R.isPyretException($e44144415)) {
$e44144415.pyretStack.push(L[489]);
}
throw $e44144415;
}
var $ret44204421 = $Hvisit_DASH_imports17014426($z44164417,A317,bind_DASH_handlers1883797,body1944396,fold593614,l1904398,self1894400,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394);
++R.GAS;
return $ret44204421;
};
var $Hvisit_DASH_imports17014426 = function(visit_DASH_imports1974425,A317,bind_DASH_handlers1883797,body1944396,fold593614,l1904398,self1894400,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394) {
var anf_obj5524472 = G(self1894400,"env",L[498]);
var anf_obj5534473 = G(self1894400,"type-env",L[497]);
var new_DASH_envs1994452 = R.makeObject({"val-env":anf_obj5524472,
"type-env":anf_obj5534473});
var anf_arg5584451 = R.makeFunction(function(acc2014455,i2024456) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[493],2,arguments);
}
var anf_fun5554467 = G(bind_DASH_handlers1883797,"s-header",L[496]);
var anf_arg5564468 = G(acc2014455,"val-env",L[495]);
var anf_arg5574469 = G(acc2014455,"type-env",L[494]);
var $z44594460 = D;
var $f44654466 = function(_) {
return R.isFunction(anf_fun5554467)?anf_fun5554467.app(i2024456,anf_arg5564468,anf_arg5574469):R.ffi.throwNonFunApp(L[493],anf_fun5554467,[i2024456,anf_arg5564468,anf_arg5574469]);
};
try {
if(--R.GAS > 0) {
$z44594460 = $f44654466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44654466,
"from":L[493]});
}
} catch($e44574458) {
if(R.isCont($e44574458)) {
var $ss44614462 = {"from":L[493],
"go":function(ann_DASH_check_DASH_temp5544470) {
return $Hann_DASH_check_DASH_temp16974471(ann_DASH_check_DASH_temp5544470);
}};
$e44574458.stack[R.EXN_STACKHEIGHT++] = $ss44614462;
}
if(R.isPyretException($e44574458)) {
$e44574458.pyretStack.push(L[493]);
}
throw $e44574458;
}
var $ret44634464 = $Hann_DASH_check_DASH_temp16974471($z44594460);
++R.GAS;
return $ret44634464;
});
var $z44434444 = D;
var $f44494450 = function(_) {
return R.isFunction(fold593614)?fold593614.app(anf_arg5584451,new_DASH_envs1994452,visit_DASH_imports1974425):R.ffi.throwNonFunApp(L[492],fold593614,[anf_arg5584451,new_DASH_envs1994452,visit_DASH_imports1974425]);
};
try {
if(--R.GAS > 0) {
$z44434444 = $f44494450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44494450,
"from":L[492]});
}
} catch($e44414442) {
if(R.isCont($e44414442)) {
var $ss44454446 = {"from":L[492],
"go":function(imported_DASH_envs2004453) {
return $Himported_DASH_envs17004454(imported_DASH_envs2004453,A317,body1944396,l1904398,self1894400,visit_DASH_imports1974425,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394);
}};
$e44414442.stack[R.EXN_STACKHEIGHT++] = $ss44454446;
}
if(R.isPyretException($e44414442)) {
$e44414442.pyretStack.push(L[492]);
}
throw $e44414442;
}
var $ret44474448 = $Himported_DASH_envs17004454($z44434444,A317,body1944396,l1904398,self1894400,visit_DASH_imports1974425,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394);
++R.GAS;
return $ret44474448;
};
var $Himported_DASH_envs17004454 = function(imported_DASH_envs2004453,A317,body1944396,l1904398,self1894400,visit_DASH_imports1974425,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394) {
var anf_fun5594484 = G(body1944396,"visit",L[502]);
var anf_extend5604488 = G(imported_DASH_envs2004453,"val-env",L[501]);
var anf_extend5614489 = G(imported_DASH_envs2004453,"type-env",L[500]);
var anf_arg5624485 = self1894400.extendWith({"env":anf_extend5604488,
"type-env":anf_extend5614489});
var $z44764477 = D;
var $f44824483 = function(_) {
return R.isFunction(anf_fun5594484)?anf_fun5594484.app(anf_arg5624485):R.ffi.throwNonFunApp(L[499],anf_fun5594484,[anf_arg5624485]);
};
try {
if(--R.GAS > 0) {
$z44764477 = $f44824483();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44824483,
"from":L[499]});
}
} catch($e44744475) {
if(R.isCont($e44744475)) {
var $ss44784479 = {"from":L[499],
"go":function(visit_DASH_body2034486) {
return $Hvisit_DASH_body16994487(visit_DASH_body2034486,A317,l1904398,visit_DASH_imports1974425,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394);
}};
$e44744475.stack[R.EXN_STACKHEIGHT++] = $ss44784479;
}
if(R.isPyretException($e44744475)) {
$e44744475.pyretStack.push(L[499]);
}
throw $e44744475;
}
var $ret44804481 = $Hvisit_DASH_body16994487($z44764477,A317,l1904398,visit_DASH_imports1974425,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394);
++R.GAS;
return $ret44804481;
};
var $Hvisit_DASH_body16994487 = function(visit_DASH_body2034486,A317,l1904398,visit_DASH_imports1974425,visit_DASH_provide_DASH_types1964412,visit_DASH_provide1954394) {
var anf_fun5634500 = G(A317,"s-program",L[504]);
var $z44924493 = D;
var $f44984499 = function(_) {
return R.isFunction(anf_fun5634500)?anf_fun5634500.app(l1904398,visit_DASH_provide1954394,visit_DASH_provide_DASH_types1964412,visit_DASH_imports1974425,visit_DASH_body2034486):R.ffi.throwNonFunApp(L[503],anf_fun5634500,[l1904398,visit_DASH_provide1954394,visit_DASH_provide_DASH_types1964412,visit_DASH_imports1974425,visit_DASH_body2034486]);
};
try {
if(--R.GAS > 0) {
$z44924493 = $f44984499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44984499,
"from":L[503]});
}
} catch($e44904491) {
if(R.isCont($e44904491)) {
var $ss44944495 = {"from":L[503],
"go":function(ann_DASH_check_DASH_temp5464501) {
return $Hann_DASH_check_DASH_temp16984502(ann_DASH_check_DASH_temp5464501);
}};
$e44904491.stack[R.EXN_STACKHEIGHT++] = $ss44944495;
}
if(R.isPyretException($e44904491)) {
$e44904491.pyretStack.push(L[503]);
}
throw $e44904491;
}
var $ret44964497 = $Hann_DASH_check_DASH_temp16984502($z44924493);
++R.GAS;
return $ret44964497;
};
var $Hann_DASH_check_DASH_temp16984502 = function(ann_DASH_check_DASH_temp5464501) {
return ann_DASH_check_DASH_temp5464501;
};
var $Hann_DASH_check_DASH_temp16974471 = function(ann_DASH_check_DASH_temp5544470) {
return ann_DASH_check_DASH_temp5544470;
};
var $Hann_DASH_check_DASH_temp16964440 = function(ann_DASH_check_DASH_temp5494439) {
return ann_DASH_check_DASH_temp5494439;
};
var $Hanf_arg16954503 = function(anf_arg5414504,anf_arg5394505,anf_fun4964506,initial_DASH_env1754507) {
var anf_arg5424518 = G(initial_DASH_env1754507,"bindings",L[506]);
var $z45104511 = D;
var $f45164517 = function(_) {
return R.isFunction(anf_fun4964506)?anf_fun4964506.app(anf_arg5394505,anf_arg5414504,anf_arg5424518):R.ffi.throwNonFunApp(L[505],anf_fun4964506,[anf_arg5394505,anf_arg5414504,anf_arg5424518]);
};
try {
if(--R.GAS > 0) {
$z45104511 = $f45164517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45164517,
"from":L[505]});
}
} catch($e45084509) {
if(R.isCont($e45084509)) {
var $ss45124513 = {"from":L[505],
"go":function(ann_DASH_check_DASH_temp4954519) {
return $Hann_DASH_check_DASH_temp16944520(ann_DASH_check_DASH_temp4954519);
}};
$e45084509.stack[R.EXN_STACKHEIGHT++] = $ss45124513;
}
if(R.isPyretException($e45084509)) {
$e45084509.pyretStack.push(L[505]);
}
throw $e45084509;
}
var $ret45144515 = $Hann_DASH_check_DASH_temp16944520($z45104511);
++R.GAS;
return $ret45144515;
};
var $Hann_DASH_check_DASH_temp16944520 = function(ann_DASH_check_DASH_temp4954519) {
return ann_DASH_check_DASH_temp4954519;
};
var $Hann_DASH_check_DASH_temp16934521 = function(ann_DASH_check_DASH_temp4974522) {
return ann_DASH_check_DASH_temp4974522;
};
var $Hanf_bracket16924523 = function(anf_bracket5294524,A317,anf_fun5274525,b_DASH_prim11162,e_DASH_bind12678,name1834526) {
var anf_fun5304537 = G(anf_bracket5294524,"key",L[508]);
var $z45294530 = D;
var $f45354536 = function(_) {
return R.isFunction(anf_fun5304537)?anf_fun5304537.app():R.ffi.throwNonFunApp(L[507],anf_fun5304537,[]);
};
try {
if(--R.GAS > 0) {
$z45294530 = $f45354536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45354536,
"from":L[507]});
}
} catch($e45274528) {
if(R.isCont($e45274528)) {
var $ss45314532 = {"from":L[507],
"go":function(anf_arg5314538) {
return $Hanf_arg16914539(anf_arg5314538,A317,anf_fun5274525,b_DASH_prim11162,e_DASH_bind12678,name1834526);
}};
$e45274528.stack[R.EXN_STACKHEIGHT++] = $ss45314532;
}
if(R.isPyretException($e45274528)) {
$e45274528.pyretStack.push(L[507]);
}
throw $e45274528;
}
var $ret45334534 = $Hanf_arg16914539($z45294530,A317,anf_fun5274525,b_DASH_prim11162,e_DASH_bind12678,name1834526);
++R.GAS;
return $ret45334534;
};
var $Hanf_arg16914539 = function(anf_arg5314538,A317,anf_fun5274525,b_DASH_prim11162,e_DASH_bind12678,name1834526) {
var anf_arg5324551 = G(A317,"dummy-loc",L[510]);
var $z45424543 = D;
var $f45484549 = function(_) {
return R.isFunction(b_DASH_prim11162.$var)?b_DASH_prim11162.$var.app(name1834526):R.ffi.throwNonFunApp(L[509],b_DASH_prim11162.$var,[name1834526]);
};
try {
if(--R.GAS > 0) {
$z45424543 = $f45484549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45484549,
"from":L[509]});
}
} catch($e45404541) {
if(R.isCont($e45404541)) {
var $ss45444545 = {"from":L[509],
"go":function(anf_arg5334550) {
return $Hanf_arg16904552(anf_arg5334550,anf_arg5314538,anf_arg5324551,anf_fun5274525,e_DASH_bind12678);
}};
$e45404541.stack[R.EXN_STACKHEIGHT++] = $ss45444545;
}
if(R.isPyretException($e45404541)) {
$e45404541.pyretStack.push(L[509]);
}
throw $e45404541;
}
var $ret45464547 = $Hanf_arg16904552($z45424543,anf_arg5314538,anf_arg5324551,anf_fun5274525,e_DASH_bind12678);
++R.GAS;
return $ret45464547;
};
var $Hanf_arg16904552 = function(anf_arg5334550,anf_arg5314538,anf_arg5324551,anf_fun5274525,e_DASH_bind12678) {
var $z45554556 = D;
var $f45614562 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg5324551,(false),anf_arg5334550):R.ffi.throwNonFunApp(L[511],e_DASH_bind12678.$var,[anf_arg5324551,(false),anf_arg5334550]);
};
try {
if(--R.GAS > 0) {
$z45554556 = $f45614562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45614562,
"from":L[511]});
}
} catch($e45534554) {
if(R.isCont($e45534554)) {
var $ss45574558 = {"from":L[511],
"go":function(anf_arg5344563) {
return $Hanf_arg16894564(anf_arg5344563,anf_arg5314538,anf_fun5274525);
}};
$e45534554.stack[R.EXN_STACKHEIGHT++] = $ss45574558;
}
if(R.isPyretException($e45534554)) {
$e45534554.pyretStack.push(L[511]);
}
throw $e45534554;
}
var $ret45594560 = $Hanf_arg16894564($z45554556,anf_arg5314538,anf_fun5274525);
++R.GAS;
return $ret45594560;
};
var $Hanf_arg16894564 = function(anf_arg5344563,anf_arg5314538,anf_fun5274525) {
var $z45674568 = D;
var $f45734574 = function(_) {
return R.isFunction(anf_fun5274525)?anf_fun5274525.app(anf_arg5314538,anf_arg5344563):R.ffi.throwNonFunApp(L[512],anf_fun5274525,[anf_arg5314538,anf_arg5344563]);
};
try {
if(--R.GAS > 0) {
$z45674568 = $f45734574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45734574,
"from":L[512]});
}
} catch($e45654566) {
if(R.isCont($e45654566)) {
var $ss45694570 = {"from":L[512],
"go":function(ann_DASH_check_DASH_temp5264575) {
return $Hann_DASH_check_DASH_temp16884576(ann_DASH_check_DASH_temp5264575);
}};
$e45654566.stack[R.EXN_STACKHEIGHT++] = $ss45694570;
}
if(R.isPyretException($e45654566)) {
$e45654566.pyretStack.push(L[512]);
}
throw $e45654566;
}
var $ret45714572 = $Hann_DASH_check_DASH_temp16884576($z45674568);
++R.GAS;
return $ret45714572;
};
var $Hann_DASH_check_DASH_temp16884576 = function(ann_DASH_check_DASH_temp5264575) {
return ann_DASH_check_DASH_temp5264575;
};
var $Hanf_arg16874577 = function(anf_arg5154578,A317,acc1764579,anf_arg5134580,anf_fun5004581,b_DASH_dict11359,e_DASH_bind12678,ids1794582,name1784583) {
var $z45864587 = D;
var $f45924593 = function(_) {
return R.isFunction(anf_fun5004581)?anf_fun5004581.app(anf_arg5134580,anf_arg5154578,ids1794582):R.ffi.throwNonFunApp(L[513],anf_fun5004581,[anf_arg5134580,anf_arg5154578,ids1794582]);
};
try {
if(--R.GAS > 0) {
$z45864587 = $f45924593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45924593,
"from":L[513]});
}
} catch($e45844585) {
if(R.isCont($e45844585)) {
var $ss45884589 = {"from":L[513],
"go":function(mod1804594) {
return $Hmod16864595(mod1804594,A317,acc1764579,b_DASH_dict11359,e_DASH_bind12678,name1784583);
}};
$e45844585.stack[R.EXN_STACKHEIGHT++] = $ss45884589;
}
if(R.isPyretException($e45844585)) {
$e45844585.pyretStack.push(L[513]);
}
throw $e45844585;
}
var $ret45904591 = $Hmod16864595($z45864587,A317,acc1764579,b_DASH_dict11359,e_DASH_bind12678,name1784583);
++R.GAS;
return $ret45904591;
};
var $Hmod16864595 = function(mod1804594,A317,acc1764579,b_DASH_dict11359,e_DASH_bind12678,name1784583) {
var anf_fun5164609 = G(acc1764579,"set",L[517]);
var anf_fun5174606 = G(A317,"s-name",L[516]);
var anf_arg5184607 = G(A317,"dummy-loc",L[515]);
var $z45984599 = D;
var $f46044605 = function(_) {
return R.isFunction(anf_fun5174606)?anf_fun5174606.app(anf_arg5184607,name1784583):R.ffi.throwNonFunApp(L[514],anf_fun5174606,[anf_arg5184607,name1784583]);
};
try {
if(--R.GAS > 0) {
$z45984599 = $f46044605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46044605,
"from":L[514]});
}
} catch($e45964597) {
if(R.isCont($e45964597)) {
var $ss46004601 = {"from":L[514],
"go":function(anf_bracket5194608) {
return $Hanf_bracket16854610(anf_bracket5194608,A317,anf_fun5164609,b_DASH_dict11359,e_DASH_bind12678,mod1804594);
}};
$e45964597.stack[R.EXN_STACKHEIGHT++] = $ss46004601;
}
if(R.isPyretException($e45964597)) {
$e45964597.pyretStack.push(L[514]);
}
throw $e45964597;
}
var $ret46024603 = $Hanf_bracket16854610($z45984599,A317,anf_fun5164609,b_DASH_dict11359,e_DASH_bind12678,mod1804594);
++R.GAS;
return $ret46024603;
};
var $Hanf_bracket16854610 = function(anf_bracket5194608,A317,anf_fun5164609,b_DASH_dict11359,e_DASH_bind12678,mod1804594) {
var anf_fun5204621 = G(anf_bracket5194608,"key",L[519]);
var $z46134614 = D;
var $f46194620 = function(_) {
return R.isFunction(anf_fun5204621)?anf_fun5204621.app():R.ffi.throwNonFunApp(L[518],anf_fun5204621,[]);
};
try {
if(--R.GAS > 0) {
$z46134614 = $f46194620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46194620,
"from":L[518]});
}
} catch($e46114612) {
if(R.isCont($e46114612)) {
var $ss46154616 = {"from":L[518],
"go":function(anf_arg5214622) {
return $Hanf_arg16844623(anf_arg5214622,A317,anf_fun5164609,b_DASH_dict11359,e_DASH_bind12678,mod1804594);
}};
$e46114612.stack[R.EXN_STACKHEIGHT++] = $ss46154616;
}
if(R.isPyretException($e46114612)) {
$e46114612.pyretStack.push(L[518]);
}
throw $e46114612;
}
var $ret46174618 = $Hanf_arg16844623($z46134614,A317,anf_fun5164609,b_DASH_dict11359,e_DASH_bind12678,mod1804594);
++R.GAS;
return $ret46174618;
};
var $Hanf_arg16844623 = function(anf_arg5214622,A317,anf_fun5164609,b_DASH_dict11359,e_DASH_bind12678,mod1804594) {
var anf_arg5224635 = G(A317,"dummy-loc",L[521]);
var $z46264627 = D;
var $f46324633 = function(_) {
return R.isFunction(b_DASH_dict11359.$var)?b_DASH_dict11359.$var.app(mod1804594):R.ffi.throwNonFunApp(L[520],b_DASH_dict11359.$var,[mod1804594]);
};
try {
if(--R.GAS > 0) {
$z46264627 = $f46324633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46324633,
"from":L[520]});
}
} catch($e46244625) {
if(R.isCont($e46244625)) {
var $ss46284629 = {"from":L[520],
"go":function(anf_arg5234634) {
return $Hanf_arg16834636(anf_arg5234634,anf_arg5214622,anf_arg5224635,anf_fun5164609,e_DASH_bind12678);
}};
$e46244625.stack[R.EXN_STACKHEIGHT++] = $ss46284629;
}
if(R.isPyretException($e46244625)) {
$e46244625.pyretStack.push(L[520]);
}
throw $e46244625;
}
var $ret46304631 = $Hanf_arg16834636($z46264627,anf_arg5214622,anf_arg5224635,anf_fun5164609,e_DASH_bind12678);
++R.GAS;
return $ret46304631;
};
var $Hanf_arg16834636 = function(anf_arg5234634,anf_arg5214622,anf_arg5224635,anf_fun5164609,e_DASH_bind12678) {
var $z46394640 = D;
var $f46454646 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg5224635,(false),anf_arg5234634):R.ffi.throwNonFunApp(L[522],e_DASH_bind12678.$var,[anf_arg5224635,(false),anf_arg5234634]);
};
try {
if(--R.GAS > 0) {
$z46394640 = $f46454646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46454646,
"from":L[522]});
}
} catch($e46374638) {
if(R.isCont($e46374638)) {
var $ss46414642 = {"from":L[522],
"go":function(anf_arg5244647) {
return $Hanf_arg16824648(anf_arg5244647,anf_arg5214622,anf_fun5164609);
}};
$e46374638.stack[R.EXN_STACKHEIGHT++] = $ss46414642;
}
if(R.isPyretException($e46374638)) {
$e46374638.pyretStack.push(L[522]);
}
throw $e46374638;
}
var $ret46434644 = $Hanf_arg16824648($z46394640,anf_arg5214622,anf_fun5164609);
++R.GAS;
return $ret46434644;
};
var $Hanf_arg16824648 = function(anf_arg5244647,anf_arg5214622,anf_fun5164609) {
var $z46514652 = D;
var $f46574658 = function(_) {
return R.isFunction(anf_fun5164609)?anf_fun5164609.app(anf_arg5214622,anf_arg5244647):R.ffi.throwNonFunApp(L[523],anf_fun5164609,[anf_arg5214622,anf_arg5244647]);
};
try {
if(--R.GAS > 0) {
$z46514652 = $f46574658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46574658,
"from":L[523]});
}
} catch($e46494650) {
if(R.isCont($e46494650)) {
var $ss46534654 = {"from":L[523],
"go":function(ann_DASH_check_DASH_temp4994659) {
return $Hann_DASH_check_DASH_temp16814660(ann_DASH_check_DASH_temp4994659);
}};
$e46494650.stack[R.EXN_STACKHEIGHT++] = $ss46534654;
}
if(R.isPyretException($e46494650)) {
$e46494650.pyretStack.push(L[523]);
}
throw $e46494650;
}
var $ret46554656 = $Hann_DASH_check_DASH_temp16814660($z46514652);
++R.GAS;
return $ret46554656;
};
var $Hann_DASH_check_DASH_temp16814660 = function(ann_DASH_check_DASH_temp4994659) {
return ann_DASH_check_DASH_temp4994659;
};
var $Hanf_bracket16804661 = function(anf_bracket5054662,A317,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,name1784583,_plus7) {
var anf_fun5064675 = G(anf_bracket5054662,"key",L[525]);
var $z46674668 = D;
var $f46734674 = function(_) {
return R.isFunction(anf_fun5064675)?anf_fun5064675.app():R.ffi.throwNonFunApp(L[524],anf_fun5064675,[]);
};
try {
if(--R.GAS > 0) {
$z46674668 = $f46734674();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46734674,
"from":L[524]});
}
} catch($e46654666) {
if(R.isCont($e46654666)) {
var $ss46694670 = {"from":L[524],
"go":function(anf_arg5074676) {
return $Hanf_arg16794677(anf_arg5074676,A317,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,name1784583,_plus7);
}};
$e46654666.stack[R.EXN_STACKHEIGHT++] = $ss46694670;
}
if(R.isPyretException($e46654666)) {
$e46654666.pyretStack.push(L[524]);
}
throw $e46654666;
}
var $ret46714672 = $Hanf_arg16794677($z46674668,A317,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,name1784583,_plus7);
++R.GAS;
return $ret46714672;
};
var $Hanf_arg16794677 = function(anf_arg5074676,A317,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,name1784583,_plus7) {
var anf_arg5084689 = G(A317,"dummy-loc",L[527]);
var $z46804681 = D;
var $f46864687 = function(_) {
return R.isFunction(_plus7)?_plus7.app(name1784583,(":")):R.ffi.throwNonFunApp(L[526],_plus7,[name1784583,(":")]);
};
try {
if(--R.GAS > 0) {
$z46804681 = $f46864687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46864687,
"from":L[526]});
}
} catch($e46784679) {
if(R.isCont($e46784679)) {
var $ss46824683 = {"from":L[526],
"go":function(anf_arg5094688) {
return $Hanf_arg16784690(anf_arg5094688,anf_arg5074676,anf_arg5084689,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,_plus7);
}};
$e46784679.stack[R.EXN_STACKHEIGHT++] = $ss46824683;
}
if(R.isPyretException($e46784679)) {
$e46784679.pyretStack.push(L[526]);
}
throw $e46784679;
}
var $ret46844685 = $Hanf_arg16784690($z46804681,anf_arg5074676,anf_arg5084689,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,_plus7);
++R.GAS;
return $ret46844685;
};
var $Hanf_arg16784690 = function(anf_arg5094688,anf_arg5074676,anf_arg5084689,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,_plus7) {
var $z46934694 = D;
var $f46994700 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg5094688,b1824664):R.ffi.throwNonFunApp(L[526],_plus7,[anf_arg5094688,b1824664]);
};
try {
if(--R.GAS > 0) {
$z46934694 = $f46994700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46994700,
"from":L[526]});
}
} catch($e46914692) {
if(R.isCont($e46914692)) {
var $ss46954696 = {"from":L[526],
"go":function(anf_arg5104701) {
return $Hanf_arg16774702(anf_arg5104701,anf_arg5074676,anf_arg5084689,anf_fun5024663,b_DASH_prim11162,e_DASH_bind12678);
}};
$e46914692.stack[R.EXN_STACKHEIGHT++] = $ss46954696;
}
if(R.isPyretException($e46914692)) {
$e46914692.pyretStack.push(L[526]);
}
throw $e46914692;
}
var $ret46974698 = $Hanf_arg16774702($z46934694,anf_arg5074676,anf_arg5084689,anf_fun5024663,b_DASH_prim11162,e_DASH_bind12678);
++R.GAS;
return $ret46974698;
};
var $Hanf_arg16774702 = function(anf_arg5104701,anf_arg5074676,anf_arg5084689,anf_fun5024663,b_DASH_prim11162,e_DASH_bind12678) {
var $z47054706 = D;
var $f47114712 = function(_) {
return R.isFunction(b_DASH_prim11162.$var)?b_DASH_prim11162.$var.app(anf_arg5104701):R.ffi.throwNonFunApp(L[528],b_DASH_prim11162.$var,[anf_arg5104701]);
};
try {
if(--R.GAS > 0) {
$z47054706 = $f47114712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47114712,
"from":L[528]});
}
} catch($e47034704) {
if(R.isCont($e47034704)) {
var $ss47074708 = {"from":L[528],
"go":function(anf_arg5114713) {
return $Hanf_arg16764714(anf_arg5114713,anf_arg5074676,anf_arg5084689,anf_fun5024663,e_DASH_bind12678);
}};
$e47034704.stack[R.EXN_STACKHEIGHT++] = $ss47074708;
}
if(R.isPyretException($e47034704)) {
$e47034704.pyretStack.push(L[528]);
}
throw $e47034704;
}
var $ret47094710 = $Hanf_arg16764714($z47054706,anf_arg5074676,anf_arg5084689,anf_fun5024663,e_DASH_bind12678);
++R.GAS;
return $ret47094710;
};
var $Hanf_arg16764714 = function(anf_arg5114713,anf_arg5074676,anf_arg5084689,anf_fun5024663,e_DASH_bind12678) {
var $z47174718 = D;
var $f47234724 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg5084689,(false),anf_arg5114713):R.ffi.throwNonFunApp(L[529],e_DASH_bind12678.$var,[anf_arg5084689,(false),anf_arg5114713]);
};
try {
if(--R.GAS > 0) {
$z47174718 = $f47234724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47234724,
"from":L[529]});
}
} catch($e47154716) {
if(R.isCont($e47154716)) {
var $ss47194720 = {"from":L[529],
"go":function(anf_arg5124725) {
return $Hanf_arg16754726(anf_arg5124725,anf_arg5074676,anf_fun5024663);
}};
$e47154716.stack[R.EXN_STACKHEIGHT++] = $ss47194720;
}
if(R.isPyretException($e47154716)) {
$e47154716.pyretStack.push(L[529]);
}
throw $e47154716;
}
var $ret47214722 = $Hanf_arg16754726($z47174718,anf_arg5074676,anf_fun5024663);
++R.GAS;
return $ret47214722;
};
var $Hanf_arg16754726 = function(anf_arg5124725,anf_arg5074676,anf_fun5024663) {
var $z47294730 = D;
var $f47354736 = function(_) {
return R.isFunction(anf_fun5024663)?anf_fun5024663.app(anf_arg5074676,anf_arg5124725):R.ffi.throwNonFunApp(L[530],anf_fun5024663,[anf_arg5074676,anf_arg5124725]);
};
try {
if(--R.GAS > 0) {
$z47294730 = $f47354736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47354736,
"from":L[530]});
}
} catch($e47274728) {
if(R.isCont($e47274728)) {
var $ss47314732 = {"from":L[530],
"go":function(ann_DASH_check_DASH_temp5014737) {
return $Hann_DASH_check_DASH_temp16744738(ann_DASH_check_DASH_temp5014737);
}};
$e47274728.stack[R.EXN_STACKHEIGHT++] = $ss47314732;
}
if(R.isPyretException($e47274728)) {
$e47274728.pyretStack.push(L[530]);
}
throw $e47274728;
}
var $ret47334734 = $Hann_DASH_check_DASH_temp16744738($z47294730);
++R.GAS;
return $ret47334734;
};
var $Hann_DASH_check_DASH_temp16744738 = function(ann_DASH_check_DASH_temp5014737) {
return ann_DASH_check_DASH_temp5014737;
};
var $Hanf_arg16734739 = function(anf_arg4924740,anf_arg4904741,anf_fun4514742,initial_DASH_env1664743) {
var anf_arg4934754 = G(initial_DASH_env1664743,"types",L[532]);
var $z47464747 = D;
var $f47524753 = function(_) {
return R.isFunction(anf_fun4514742)?anf_fun4514742.app(anf_arg4904741,anf_arg4924740,anf_arg4934754):R.ffi.throwNonFunApp(L[531],anf_fun4514742,[anf_arg4904741,anf_arg4924740,anf_arg4934754]);
};
try {
if(--R.GAS > 0) {
$z47464747 = $f47524753();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47524753,
"from":L[531]});
}
} catch($e47444745) {
if(R.isCont($e47444745)) {
var $ss47484749 = {"from":L[531],
"go":function(ann_DASH_check_DASH_temp4504755) {
return $Hann_DASH_check_DASH_temp16724756(ann_DASH_check_DASH_temp4504755);
}};
$e47444745.stack[R.EXN_STACKHEIGHT++] = $ss47484749;
}
if(R.isPyretException($e47444745)) {
$e47444745.pyretStack.push(L[531]);
}
throw $e47444745;
}
var $ret47504751 = $Hann_DASH_check_DASH_temp16724756($z47464747);
++R.GAS;
return $ret47504751;
};
var $Hann_DASH_check_DASH_temp16724756 = function(ann_DASH_check_DASH_temp4504755) {
return ann_DASH_check_DASH_temp4504755;
};
var $Hann_DASH_check_DASH_temp16714757 = function(ann_DASH_check_DASH_temp4524758) {
return ann_DASH_check_DASH_temp4524758;
};
var $Hanf_bracket16704759 = function(anf_bracket4814760,A317,anf_fun4794761,b_DASH_typ11963,e_DASH_bind12678) {
var anf_fun4824772 = G(anf_bracket4814760,"key",L[534]);
var $z47644765 = D;
var $f47704771 = function(_) {
return R.isFunction(anf_fun4824772)?anf_fun4824772.app():R.ffi.throwNonFunApp(L[533],anf_fun4824772,[]);
};
try {
if(--R.GAS > 0) {
$z47644765 = $f47704771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47704771,
"from":L[533]});
}
} catch($e47624763) {
if(R.isCont($e47624763)) {
var $ss47664767 = {"from":L[533],
"go":function(anf_arg4834773) {
return $Hanf_arg16694774(anf_arg4834773,A317,anf_fun4794761,b_DASH_typ11963,e_DASH_bind12678);
}};
$e47624763.stack[R.EXN_STACKHEIGHT++] = $ss47664767;
}
if(R.isPyretException($e47624763)) {
$e47624763.pyretStack.push(L[533]);
}
throw $e47624763;
}
var $ret47684769 = $Hanf_arg16694774($z47644765,A317,anf_fun4794761,b_DASH_typ11963,e_DASH_bind12678);
++R.GAS;
return $ret47684769;
};
var $Hanf_arg16694774 = function(anf_arg4834773,A317,anf_fun4794761,b_DASH_typ11963,e_DASH_bind12678) {
var anf_arg4844785 = G(A317,"dummy-loc",L[536]);
var $z47774778 = D;
var $f47834784 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg4844785,(false),b_DASH_typ11963.$var):R.ffi.throwNonFunApp(L[535],e_DASH_bind12678.$var,[anf_arg4844785,(false),b_DASH_typ11963.$var]);
};
try {
if(--R.GAS > 0) {
$z47774778 = $f47834784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47834784,
"from":L[535]});
}
} catch($e47754776) {
if(R.isCont($e47754776)) {
var $ss47794780 = {"from":L[535],
"go":function(anf_arg4854786) {
return $Hanf_arg16684787(anf_arg4854786,anf_arg4834773,anf_fun4794761);
}};
$e47754776.stack[R.EXN_STACKHEIGHT++] = $ss47794780;
}
if(R.isPyretException($e47754776)) {
$e47754776.pyretStack.push(L[535]);
}
throw $e47754776;
}
var $ret47814782 = $Hanf_arg16684787($z47774778,anf_arg4834773,anf_fun4794761);
++R.GAS;
return $ret47814782;
};
var $Hanf_arg16684787 = function(anf_arg4854786,anf_arg4834773,anf_fun4794761) {
var $z47904791 = D;
var $f47964797 = function(_) {
return R.isFunction(anf_fun4794761)?anf_fun4794761.app(anf_arg4834773,anf_arg4854786):R.ffi.throwNonFunApp(L[537],anf_fun4794761,[anf_arg4834773,anf_arg4854786]);
};
try {
if(--R.GAS > 0) {
$z47904791 = $f47964797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47964797,
"from":L[537]});
}
} catch($e47884789) {
if(R.isCont($e47884789)) {
var $ss47924793 = {"from":L[537],
"go":function(ann_DASH_check_DASH_temp4784798) {
return $Hann_DASH_check_DASH_temp16674799(ann_DASH_check_DASH_temp4784798);
}};
$e47884789.stack[R.EXN_STACKHEIGHT++] = $ss47924793;
}
if(R.isPyretException($e47884789)) {
$e47884789.pyretStack.push(L[537]);
}
throw $e47884789;
}
var $ret47944795 = $Hann_DASH_check_DASH_temp16674799($z47904791);
++R.GAS;
return $ret47944795;
};
var $Hann_DASH_check_DASH_temp16674799 = function(ann_DASH_check_DASH_temp4784798) {
return ann_DASH_check_DASH_temp4784798;
};
var $Hanf_arg16664800 = function(anf_arg4674801,A317,acc1674802,anf_arg4654803,anf_fun4554804,b_DASH_dict11359,e_DASH_bind12678,ids1704805,name1694806) {
var $z48094810 = D;
var $f48154816 = function(_) {
return R.isFunction(anf_fun4554804)?anf_fun4554804.app(anf_arg4654803,anf_arg4674801,ids1704805):R.ffi.throwNonFunApp(L[538],anf_fun4554804,[anf_arg4654803,anf_arg4674801,ids1704805]);
};
try {
if(--R.GAS > 0) {
$z48094810 = $f48154816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48154816,
"from":L[538]});
}
} catch($e48074808) {
if(R.isCont($e48074808)) {
var $ss48114812 = {"from":L[538],
"go":function(mod1714817) {
return $Hmod16654818(mod1714817,A317,acc1674802,b_DASH_dict11359,e_DASH_bind12678,name1694806);
}};
$e48074808.stack[R.EXN_STACKHEIGHT++] = $ss48114812;
}
if(R.isPyretException($e48074808)) {
$e48074808.pyretStack.push(L[538]);
}
throw $e48074808;
}
var $ret48134814 = $Hmod16654818($z48094810,A317,acc1674802,b_DASH_dict11359,e_DASH_bind12678,name1694806);
++R.GAS;
return $ret48134814;
};
var $Hmod16654818 = function(mod1714817,A317,acc1674802,b_DASH_dict11359,e_DASH_bind12678,name1694806) {
var anf_fun4684832 = G(acc1674802,"set",L[542]);
var anf_fun4694829 = G(A317,"s-name",L[541]);
var anf_arg4704830 = G(A317,"dummy-loc",L[540]);
var $z48214822 = D;
var $f48274828 = function(_) {
return R.isFunction(anf_fun4694829)?anf_fun4694829.app(anf_arg4704830,name1694806):R.ffi.throwNonFunApp(L[539],anf_fun4694829,[anf_arg4704830,name1694806]);
};
try {
if(--R.GAS > 0) {
$z48214822 = $f48274828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48274828,
"from":L[539]});
}
} catch($e48194820) {
if(R.isCont($e48194820)) {
var $ss48234824 = {"from":L[539],
"go":function(anf_bracket4714831) {
return $Hanf_bracket16644833(anf_bracket4714831,A317,anf_fun4684832,b_DASH_dict11359,e_DASH_bind12678,mod1714817);
}};
$e48194820.stack[R.EXN_STACKHEIGHT++] = $ss48234824;
}
if(R.isPyretException($e48194820)) {
$e48194820.pyretStack.push(L[539]);
}
throw $e48194820;
}
var $ret48254826 = $Hanf_bracket16644833($z48214822,A317,anf_fun4684832,b_DASH_dict11359,e_DASH_bind12678,mod1714817);
++R.GAS;
return $ret48254826;
};
var $Hanf_bracket16644833 = function(anf_bracket4714831,A317,anf_fun4684832,b_DASH_dict11359,e_DASH_bind12678,mod1714817) {
var anf_fun4724844 = G(anf_bracket4714831,"key",L[544]);
var $z48364837 = D;
var $f48424843 = function(_) {
return R.isFunction(anf_fun4724844)?anf_fun4724844.app():R.ffi.throwNonFunApp(L[543],anf_fun4724844,[]);
};
try {
if(--R.GAS > 0) {
$z48364837 = $f48424843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48424843,
"from":L[543]});
}
} catch($e48344835) {
if(R.isCont($e48344835)) {
var $ss48384839 = {"from":L[543],
"go":function(anf_arg4734845) {
return $Hanf_arg16634846(anf_arg4734845,A317,anf_fun4684832,b_DASH_dict11359,e_DASH_bind12678,mod1714817);
}};
$e48344835.stack[R.EXN_STACKHEIGHT++] = $ss48384839;
}
if(R.isPyretException($e48344835)) {
$e48344835.pyretStack.push(L[543]);
}
throw $e48344835;
}
var $ret48404841 = $Hanf_arg16634846($z48364837,A317,anf_fun4684832,b_DASH_dict11359,e_DASH_bind12678,mod1714817);
++R.GAS;
return $ret48404841;
};
var $Hanf_arg16634846 = function(anf_arg4734845,A317,anf_fun4684832,b_DASH_dict11359,e_DASH_bind12678,mod1714817) {
var anf_arg4744858 = G(A317,"dummy-loc",L[546]);
var $z48494850 = D;
var $f48554856 = function(_) {
return R.isFunction(b_DASH_dict11359.$var)?b_DASH_dict11359.$var.app(mod1714817):R.ffi.throwNonFunApp(L[545],b_DASH_dict11359.$var,[mod1714817]);
};
try {
if(--R.GAS > 0) {
$z48494850 = $f48554856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48554856,
"from":L[545]});
}
} catch($e48474848) {
if(R.isCont($e48474848)) {
var $ss48514852 = {"from":L[545],
"go":function(anf_arg4754857) {
return $Hanf_arg16624859(anf_arg4754857,anf_arg4734845,anf_arg4744858,anf_fun4684832,e_DASH_bind12678);
}};
$e48474848.stack[R.EXN_STACKHEIGHT++] = $ss48514852;
}
if(R.isPyretException($e48474848)) {
$e48474848.pyretStack.push(L[545]);
}
throw $e48474848;
}
var $ret48534854 = $Hanf_arg16624859($z48494850,anf_arg4734845,anf_arg4744858,anf_fun4684832,e_DASH_bind12678);
++R.GAS;
return $ret48534854;
};
var $Hanf_arg16624859 = function(anf_arg4754857,anf_arg4734845,anf_arg4744858,anf_fun4684832,e_DASH_bind12678) {
var $z48624863 = D;
var $f48684869 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg4744858,(false),anf_arg4754857):R.ffi.throwNonFunApp(L[547],e_DASH_bind12678.$var,[anf_arg4744858,(false),anf_arg4754857]);
};
try {
if(--R.GAS > 0) {
$z48624863 = $f48684869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48684869,
"from":L[547]});
}
} catch($e48604861) {
if(R.isCont($e48604861)) {
var $ss48644865 = {"from":L[547],
"go":function(anf_arg4764870) {
return $Hanf_arg16614871(anf_arg4764870,anf_arg4734845,anf_fun4684832);
}};
$e48604861.stack[R.EXN_STACKHEIGHT++] = $ss48644865;
}
if(R.isPyretException($e48604861)) {
$e48604861.pyretStack.push(L[547]);
}
throw $e48604861;
}
var $ret48664867 = $Hanf_arg16614871($z48624863,anf_arg4734845,anf_fun4684832);
++R.GAS;
return $ret48664867;
};
var $Hanf_arg16614871 = function(anf_arg4764870,anf_arg4734845,anf_fun4684832) {
var $z48744875 = D;
var $f48804881 = function(_) {
return R.isFunction(anf_fun4684832)?anf_fun4684832.app(anf_arg4734845,anf_arg4764870):R.ffi.throwNonFunApp(L[548],anf_fun4684832,[anf_arg4734845,anf_arg4764870]);
};
try {
if(--R.GAS > 0) {
$z48744875 = $f48804881();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48804881,
"from":L[548]});
}
} catch($e48724873) {
if(R.isCont($e48724873)) {
var $ss48764877 = {"from":L[548],
"go":function(ann_DASH_check_DASH_temp4544882) {
return $Hann_DASH_check_DASH_temp16604883(ann_DASH_check_DASH_temp4544882);
}};
$e48724873.stack[R.EXN_STACKHEIGHT++] = $ss48764877;
}
if(R.isPyretException($e48724873)) {
$e48724873.pyretStack.push(L[548]);
}
throw $e48724873;
}
var $ret48784879 = $Hann_DASH_check_DASH_temp16604883($z48744875);
++R.GAS;
return $ret48784879;
};
var $Hann_DASH_check_DASH_temp16604883 = function(ann_DASH_check_DASH_temp4544882) {
return ann_DASH_check_DASH_temp4544882;
};
var $Hanf_bracket16594884 = function(anf_bracket4604885,A317,anf_fun4574886,b_DASH_typ11963,e_DASH_bind12678) {
var anf_fun4614897 = G(anf_bracket4604885,"key",L[550]);
var $z48894890 = D;
var $f48954896 = function(_) {
return R.isFunction(anf_fun4614897)?anf_fun4614897.app():R.ffi.throwNonFunApp(L[549],anf_fun4614897,[]);
};
try {
if(--R.GAS > 0) {
$z48894890 = $f48954896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48954896,
"from":L[549]});
}
} catch($e48874888) {
if(R.isCont($e48874888)) {
var $ss48914892 = {"from":L[549],
"go":function(anf_arg4624898) {
return $Hanf_arg16584899(anf_arg4624898,A317,anf_fun4574886,b_DASH_typ11963,e_DASH_bind12678);
}};
$e48874888.stack[R.EXN_STACKHEIGHT++] = $ss48914892;
}
if(R.isPyretException($e48874888)) {
$e48874888.pyretStack.push(L[549]);
}
throw $e48874888;
}
var $ret48934894 = $Hanf_arg16584899($z48894890,A317,anf_fun4574886,b_DASH_typ11963,e_DASH_bind12678);
++R.GAS;
return $ret48934894;
};
var $Hanf_arg16584899 = function(anf_arg4624898,A317,anf_fun4574886,b_DASH_typ11963,e_DASH_bind12678) {
var anf_arg4634910 = G(A317,"dummy-loc",L[552]);
var $z49024903 = D;
var $f49084909 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg4634910,(false),b_DASH_typ11963.$var):R.ffi.throwNonFunApp(L[551],e_DASH_bind12678.$var,[anf_arg4634910,(false),b_DASH_typ11963.$var]);
};
try {
if(--R.GAS > 0) {
$z49024903 = $f49084909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49084909,
"from":L[551]});
}
} catch($e49004901) {
if(R.isCont($e49004901)) {
var $ss49044905 = {"from":L[551],
"go":function(anf_arg4644911) {
return $Hanf_arg16574912(anf_arg4644911,anf_arg4624898,anf_fun4574886);
}};
$e49004901.stack[R.EXN_STACKHEIGHT++] = $ss49044905;
}
if(R.isPyretException($e49004901)) {
$e49004901.pyretStack.push(L[551]);
}
throw $e49004901;
}
var $ret49064907 = $Hanf_arg16574912($z49024903,anf_arg4624898,anf_fun4574886);
++R.GAS;
return $ret49064907;
};
var $Hanf_arg16574912 = function(anf_arg4644911,anf_arg4624898,anf_fun4574886) {
var $z49154916 = D;
var $f49214922 = function(_) {
return R.isFunction(anf_fun4574886)?anf_fun4574886.app(anf_arg4624898,anf_arg4644911):R.ffi.throwNonFunApp(L[553],anf_fun4574886,[anf_arg4624898,anf_arg4644911]);
};
try {
if(--R.GAS > 0) {
$z49154916 = $f49214922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49214922,
"from":L[553]});
}
} catch($e49134914) {
if(R.isCont($e49134914)) {
var $ss49174918 = {"from":L[553],
"go":function(ann_DASH_check_DASH_temp4564923) {
return $Hann_DASH_check_DASH_temp16564924(ann_DASH_check_DASH_temp4564923);
}};
$e49134914.stack[R.EXN_STACKHEIGHT++] = $ss49174918;
}
if(R.isPyretException($e49134914)) {
$e49134914.pyretStack.push(L[553]);
}
throw $e49134914;
}
var $ret49194920 = $Hann_DASH_check_DASH_temp16564924($z49154916);
++R.GAS;
return $ret49194920;
};
var $Hann_DASH_check_DASH_temp16564924 = function(ann_DASH_check_DASH_temp4564923) {
return ann_DASH_check_DASH_temp4564923;
};
var $Hcases_DASH_val16554925 = function(cases_DASH_val704926,BindingInfo7255,b_DASH_unknown12164,e1634927,is_DASH_e_DASH_bind12590,_plus7,not9,nothing10,print_DASH_error11,string_DASH_substring12,torepr13) {
var anf_fun4304938 = G(cases_DASH_val704926,"_match",L[555]);
var anf_obj4324944 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[558],0,arguments);
}
var ann_DASH_check_DASH_temp4314959 = b_DASH_unknown12164.$var;
return ann_DASH_check_DASH_temp4314959;
});
var anf_obj4454945 = R.makeFunction(function(b1654946) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[556],1,arguments);
}
var $z49494950 = D;
var $f49554956 = function(_) {
return R.isFunction(is_DASH_e_DASH_bind12590.$var)?is_DASH_e_DASH_bind12590.$var.app(b1654946):R.ffi.throwNonFunApp(L[557],is_DASH_e_DASH_bind12590.$var,[b1654946]);
};
try {
if(--R.GAS > 0) {
$z49494950 = $f49554956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49554956,
"from":L[557]});
}
} catch($e49474948) {
if(R.isCont($e49474948)) {
var $ss49514952 = {"from":L[557],
"go":function(anf_arg4344957) {
return $Hanf_arg16534958(anf_arg4344957,b1654946,e1634927,_plus7,not9,nothing10,print_DASH_error11,string_DASH_substring12,torepr13);
}};
$e49474948.stack[R.EXN_STACKHEIGHT++] = $ss49514952;
}
if(R.isPyretException($e49474948)) {
$e49474948.pyretStack.push(L[557]);
}
throw $e49474948;
}
var $ret49534954 = $Hanf_arg16534958($z49494950,b1654946,e1634927,_plus7,not9,nothing10,print_DASH_error11,string_DASH_substring12,torepr13);
++R.GAS;
return $ret49534954;
});
var anf_arg4464939 = R.makeObject({"none":anf_obj4324944,
"some":anf_obj4454945});
var anf_arg4484940 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[555],0,arguments);
}
var ann_DASH_check_DASH_temp4474943 = R.throwNoBranchesMatched(L[555],("cases"));
return ann_DASH_check_DASH_temp4474943;
});
var $z49304931 = D;
var $f49364937 = function(_) {
return R.isFunction(anf_fun4304938)?anf_fun4304938.app(anf_arg4464939,anf_arg4484940):R.ffi.throwNonFunApp(L[554],anf_fun4304938,[anf_arg4464939,anf_arg4484940]);
};
try {
if(--R.GAS > 0) {
$z49304931 = $f49364937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49364937,
"from":L[554]});
}
} catch($e49284929) {
if(R.isCont($e49284929)) {
var $ss49324933 = {"from":L[554],
"go":function(ann_DASH_check_DASH_temp4294941) {
return $Hann_DASH_check_DASH_temp16544942(ann_DASH_check_DASH_temp4294941,BindingInfo7255);
}};
$e49284929.stack[R.EXN_STACKHEIGHT++] = $ss49324933;
}
if(R.isPyretException($e49284929)) {
$e49284929.pyretStack.push(L[554]);
}
throw $e49284929;
}
var $ret49344935 = $Hann_DASH_check_DASH_temp16544942($z49304931,BindingInfo7255);
++R.GAS;
return $ret49344935;
};
var $Hann_DASH_check_DASH_temp16544942 = function(ann_DASH_check_DASH_temp4294941,BindingInfo7255) {
return ann_DASH_check_DASH_temp4294941;
};
var $Hanf_arg16534958 = function(anf_arg4344957,b1654946,e1634927,_plus7,not9,nothing10,print_DASH_error11,string_DASH_substring12,torepr13) {
var $z49624963 = D;
var $f49684969 = function(_) {
return R.isFunction(not9)?not9.app(anf_arg4344957):R.ffi.throwNonFunApp(L[559],not9,[anf_arg4344957]);
};
try {
if(--R.GAS > 0) {
$z49624963 = $f49684969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49684969,
"from":L[559]});
}
} catch($e49604961) {
if(R.isCont($e49604961)) {
var $ss49644965 = {"from":L[559],
"go":function(when_DASH_694970) {
return $Hwhen_DASH_16524971(when_DASH_694970,b1654946,e1634927,_plus7,nothing10,print_DASH_error11,string_DASH_substring12,torepr13);
}};
$e49604961.stack[R.EXN_STACKHEIGHT++] = $ss49644965;
}
if(R.isPyretException($e49604961)) {
$e49604961.pyretStack.push(L[559]);
}
throw $e49604961;
}
var $ret49664967 = $Hwhen_DASH_16524971($z49624963,b1654946,e1634927,_plus7,nothing10,print_DASH_error11,string_DASH_substring12,torepr13);
++R.GAS;
return $ret49664967;
};
var $Hwhen_DASH_16524971 = function(when_DASH_694970,b1654946,e1634927,_plus7,nothing10,print_DASH_error11,string_DASH_substring12,torepr13) {
var if_helper4354983 = R.makeFunction(function(if_helper_arg4365001) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[559],1,arguments);
}
if_helper_arg4365001;
var ann_DASH_check_DASH_temp4335002 = G(b1654946,"info",L[562]);
return ann_DASH_check_DASH_temp4335002;
});
var anf_if4395000 = R.isBoolean(when_DASH_694970);
if(R.isPyretTrue(anf_if4395000)) {
if(R.isPyretTrue(when_DASH_694970)) {
var $z49744975 = D;
var $f49804981 = function(_) {
return R.isFunction(torepr13)?torepr13.app(e1634927):R.ffi.throwNonFunApp(L[560],torepr13,[e1634927]);
};
try {
if(--R.GAS > 0) {
$z49744975 = $f49804981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49804981,
"from":L[560]});
}
} catch($e49724973) {
if(R.isCont($e49724973)) {
var $ss49764977 = {"from":L[560],
"go":function(anf_arg4414982) {
return $Hanf_arg16504984(anf_arg4414982,b1654946,if_helper4354983,_plus7,nothing10,print_DASH_error11,string_DASH_substring12);
}};
$e49724973.stack[R.EXN_STACKHEIGHT++] = $ss49764977;
}
if(R.isPyretException($e49724973)) {
$e49724973.pyretStack.push(L[560]);
}
throw $e49724973;
}
var $ret49784979 = $Hanf_arg16504984($z49744975,b1654946,if_helper4354983,_plus7,nothing10,print_DASH_error11,string_DASH_substring12);
++R.GAS;
return $ret49784979;
} else {
var $z49874988 = D;
var $f49934994 = function(_) {
return R.isFunction(if_helper4354983)?if_helper4354983.app(nothing10):R.ffi.throwNonFunApp(L[559],if_helper4354983,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z49874988 = $f49934994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49934994,
"from":L[559]});
}
} catch($e49854986) {
if(R.isCont($e49854986)) {
var $ss49894990 = {"from":L[559],
"go":function(cont_tail_app4404995) {
return $Hcont_tail_app16514996(cont_tail_app4404995);
}};
$e49854986.stack[R.EXN_STACKHEIGHT++] = $ss49894990;
}
if(R.isPyretException($e49854986)) {
$e49854986.pyretStack.push(L[559]);
}
throw $e49854986;
}
var $ret49914992 = $Hcont_tail_app16514996($z49874988);
++R.GAS;
return $ret49914992;
}
} else {
var cont_tail_arg4374999 = R.throwNonBooleanCondition(L[561],("when"),when_DASH_694970);
if(--R.GAS > 0) {
$z49974998 = R.isFunction(if_helper4354983)?if_helper4354983.app(cont_tail_arg4374999):R.ffi.throwNonFunApp(L[561],if_helper4354983,[cont_tail_arg4374999]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper4354983)?if_helper4354983.app(cont_tail_arg4374999):R.ffi.throwNonFunApp(L[561],if_helper4354983,[cont_tail_arg4374999]);
},
"from":L[561]});
}
++R.GAS;
return $z49974998;
}
};
var $Hanf_arg16504984 = function(anf_arg4414982,b1654946,if_helper4354983,_plus7,nothing10,print_DASH_error11,string_DASH_substring12) {
var $z50055006 = D;
var $f50115012 = function(_) {
return R.isFunction(string_DASH_substring12)?string_DASH_substring12.app(anf_arg4414982,(0),(100)):R.ffi.throwNonFunApp(L[563],string_DASH_substring12,[anf_arg4414982,(0),(100)]);
};
try {
if(--R.GAS > 0) {
$z50055006 = $f50115012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50115012,
"from":L[563]});
}
} catch($e50035004) {
if(R.isCont($e50035004)) {
var $ss50075008 = {"from":L[563],
"go":function(anf_arg4425013) {
return $Hanf_arg16495014(anf_arg4425013,b1654946,if_helper4354983,_plus7,nothing10,print_DASH_error11);
}};
$e50035004.stack[R.EXN_STACKHEIGHT++] = $ss50075008;
}
if(R.isPyretException($e50035004)) {
$e50035004.pyretStack.push(L[563]);
}
throw $e50035004;
}
var $ret50095010 = $Hanf_arg16495014($z50055006,b1654946,if_helper4354983,_plus7,nothing10,print_DASH_error11);
++R.GAS;
return $ret50095010;
};
var $Hanf_arg16495014 = function(anf_arg4425013,b1654946,if_helper4354983,_plus7,nothing10,print_DASH_error11) {
var $z50175018 = D;
var $f50235024 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("b isn't a binding for expr "),anf_arg4425013):R.ffi.throwNonFunApp(L[564],_plus7,[("b isn't a binding for expr "),anf_arg4425013]);
};
try {
if(--R.GAS > 0) {
$z50175018 = $f50235024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50235024,
"from":L[564]});
}
} catch($e50155016) {
if(R.isCont($e50155016)) {
var $ss50195020 = {"from":L[564],
"go":function(anf_arg4435025) {
return $Hanf_arg16485026(anf_arg4435025,b1654946,if_helper4354983,nothing10,print_DASH_error11);
}};
$e50155016.stack[R.EXN_STACKHEIGHT++] = $ss50195020;
}
if(R.isPyretException($e50155016)) {
$e50155016.pyretStack.push(L[564]);
}
throw $e50155016;
}
var $ret50215022 = $Hanf_arg16485026($z50175018,b1654946,if_helper4354983,nothing10,print_DASH_error11);
++R.GAS;
return $ret50215022;
};
var $Hanf_arg16485026 = function(anf_arg4435025,b1654946,if_helper4354983,nothing10,print_DASH_error11) {
var $z50295030 = D;
var $f50355036 = function(_) {
return R.isFunction(print_DASH_error11)?print_DASH_error11.app(anf_arg4435025):R.ffi.throwNonFunApp(L[565],print_DASH_error11,[anf_arg4435025]);
};
try {
if(--R.GAS > 0) {
$z50295030 = $f50355036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50355036,
"from":L[565]});
}
} catch($e50275028) {
if(R.isCont($e50275028)) {
var $ss50315032 = {"from":L[565],
"go":function(anf_begin_app_dropped16435037) {
return $Hanf_begin_app_dropped16475038(anf_begin_app_dropped16435037,b1654946,if_helper4354983,nothing10,print_DASH_error11);
}};
$e50275028.stack[R.EXN_STACKHEIGHT++] = $ss50315032;
}
if(R.isPyretException($e50275028)) {
$e50275028.pyretStack.push(L[565]);
}
throw $e50275028;
}
var $ret50335034 = $Hanf_begin_app_dropped16475038($z50295030,b1654946,if_helper4354983,nothing10,print_DASH_error11);
++R.GAS;
return $ret50335034;
};
var $Hanf_begin_app_dropped16475038 = function(anf_begin_app_dropped16435037,b1654946,if_helper4354983,nothing10,print_DASH_error11) {
var $z50415042 = D;
var $f50475048 = function(_) {
return R.isFunction(print_DASH_error11)?print_DASH_error11.app(b1654946):R.ffi.throwNonFunApp(L[566],print_DASH_error11,[b1654946]);
};
try {
if(--R.GAS > 0) {
$z50415042 = $f50475048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50475048,
"from":L[566]});
}
} catch($e50395040) {
if(R.isCont($e50395040)) {
var $ss50435044 = {"from":L[566],
"go":function(anf_begin_app_dropped16445049) {
return $Hanf_begin_app_dropped16465050(anf_begin_app_dropped16445049,if_helper4354983,nothing10);
}};
$e50395040.stack[R.EXN_STACKHEIGHT++] = $ss50435044;
}
if(R.isPyretException($e50395040)) {
$e50395040.pyretStack.push(L[566]);
}
throw $e50395040;
}
var $ret50455046 = $Hanf_begin_app_dropped16465050($z50415042,if_helper4354983,nothing10);
++R.GAS;
return $ret50455046;
};
var $Hanf_begin_app_dropped16465050 = function(anf_begin_app_dropped16445049,if_helper4354983,nothing10) {
var $z50535054 = D;
var $f50595060 = function(_) {
return R.isFunction(if_helper4354983)?if_helper4354983.app(nothing10):R.ffi.throwNonFunApp(L[559],if_helper4354983,[nothing10]);
};
try {
if(--R.GAS > 0) {
$z50535054 = $f50595060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50595060,
"from":L[559]});
}
} catch($e50515052) {
if(R.isCont($e50515052)) {
var $ss50555056 = {"from":L[559],
"go":function(cont_tail_app4445061) {
return $Hcont_tail_app16455062(cont_tail_app4445061);
}};
$e50515052.stack[R.EXN_STACKHEIGHT++] = $ss50555056;
}
if(R.isPyretException($e50515052)) {
$e50515052.pyretStack.push(L[559]);
}
throw $e50515052;
}
var $ret50575058 = $Hcont_tail_app16455062($z50535054);
++R.GAS;
return $ret50575058;
};
var $Hcont_tail_app16455062 = function(cont_tail_app4445061) {
return cont_tail_app4445061;
};
var $Hcont_tail_app16514996 = function(cont_tail_app4404995) {
return cont_tail_app4404995;
};
var $Hann_DASH_check_DASH_temp16425063 = function(ann_DASH_check_DASH_temp3295064,Binding7453,Option245065) {
return ann_DASH_check_DASH_temp3295064;
};
var $Hanf_arg16415066 = function(anf_arg4255067,anf_arg4245068,e_DASH_bind12678,some685069) {
var $z50725073 = D;
var $f50785079 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg4245068,(false),anf_arg4255067):R.ffi.throwNonFunApp(L[567],e_DASH_bind12678.$var,[anf_arg4245068,(false),anf_arg4255067]);
};
try {
if(--R.GAS > 0) {
$z50725073 = $f50785079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50785079,
"from":L[567]});
}
} catch($e50705071) {
if(R.isCont($e50705071)) {
var $ss50745075 = {"from":L[567],
"go":function(anf_arg4265080) {
return $Hanf_arg16405081(anf_arg4265080,some685069);
}};
$e50705071.stack[R.EXN_STACKHEIGHT++] = $ss50745075;
}
if(R.isPyretException($e50705071)) {
$e50705071.pyretStack.push(L[567]);
}
throw $e50705071;
}
var $ret50765077 = $Hanf_arg16405081($z50725073,some685069);
++R.GAS;
return $ret50765077;
};
var $Hanf_arg16405081 = function(anf_arg4265080,some685069) {
var $z50845085 = D;
var $f50905091 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg4265080):R.ffi.throwNonFunApp(L[568],some685069,[anf_arg4265080]);
};
try {
if(--R.GAS > 0) {
$z50845085 = $f50905091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50905091,
"from":L[568]});
}
} catch($e50825083) {
if(R.isCont($e50825083)) {
var $ss50865087 = {"from":L[568],
"go":function(ann_DASH_check_DASH_temp4235092) {
return $Hann_DASH_check_DASH_temp16395093(ann_DASH_check_DASH_temp4235092);
}};
$e50825083.stack[R.EXN_STACKHEIGHT++] = $ss50865087;
}
if(R.isPyretException($e50825083)) {
$e50825083.pyretStack.push(L[568]);
}
throw $e50825083;
}
var $ret50885089 = $Hann_DASH_check_DASH_temp16395093($z50845085);
++R.GAS;
return $ret50885089;
};
var $Hann_DASH_check_DASH_temp16395093 = function(ann_DASH_check_DASH_temp4235092) {
return ann_DASH_check_DASH_temp4235092;
};
var $Hanf_arg16385094 = function(anf_arg4085095,anf_fun4065096,env1495097,name1615098,none675099,some685069) {
var $z51025103 = D;
var $f51085109 = function(_) {
return R.isFunction(anf_fun4065096)?anf_fun4065096.app(anf_arg4085095):R.ffi.throwNonFunApp(L[569],anf_fun4065096,[anf_arg4085095]);
};
try {
if(--R.GAS > 0) {
$z51025103 = $f51085109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51085109,
"from":L[569]});
}
} catch($e51005101) {
if(R.isCont($e51005101)) {
var $ss51045105 = {"from":L[569],
"go":function(if_DASH_675110) {
return $Hif_DASH_16375111(if_DASH_675110,env1495097,name1615098,none675099,some685069);
}};
$e51005101.stack[R.EXN_STACKHEIGHT++] = $ss51045105;
}
if(R.isPyretException($e51005101)) {
$e51005101.pyretStack.push(L[569]);
}
throw $e51005101;
}
var $ret51065107 = $Hif_DASH_16375111($z51025103,env1495097,name1615098,none675099,some685069);
++R.GAS;
return $ret51065107;
};
var $Hif_DASH_16375111 = function(if_DASH_675110,env1495097,name1615098,none675099,some685069) {
var if_helper4095125 = R.makeFunction(function(if_helper_arg4105143) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[569],1,arguments);
}
var ann_DASH_check_DASH_temp4055144 = if_helper_arg4105143;
return ann_DASH_check_DASH_temp4055144;
});
var anf_if4135142 = R.isBoolean(if_DASH_675110);
if(R.isPyretTrue(anf_if4135142)) {
if(R.isPyretTrue(if_DASH_675110)) {
var anf_fun4155124 = G(env1495097,"get",L[572]);
var anf_fun4165122 = G(name1615098,"key",L[571]);
var $z51145115 = D;
var $f51205121 = function(_) {
return R.isFunction(anf_fun4165122)?anf_fun4165122.app():R.ffi.throwNonFunApp(L[570],anf_fun4165122,[]);
};
try {
if(--R.GAS > 0) {
$z51145115 = $f51205121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51205121,
"from":L[570]});
}
} catch($e51125113) {
if(R.isCont($e51125113)) {
var $ss51165117 = {"from":L[570],
"go":function(anf_arg4175123) {
return $Hanf_arg16355126(anf_arg4175123,anf_fun4155124,if_helper4095125,some685069);
}};
$e51125113.stack[R.EXN_STACKHEIGHT++] = $ss51165117;
}
if(R.isPyretException($e51125113)) {
$e51125113.pyretStack.push(L[570]);
}
throw $e51125113;
}
var $ret51185119 = $Hanf_arg16355126($z51145115,anf_fun4155124,if_helper4095125,some685069);
++R.GAS;
return $ret51185119;
} else {
var $z51295130 = D;
var $f51355136 = function(_) {
return R.isFunction(if_helper4095125)?if_helper4095125.app(none675099):R.ffi.throwNonFunApp(L[573],if_helper4095125,[none675099]);
};
try {
if(--R.GAS > 0) {
$z51295130 = $f51355136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51355136,
"from":L[573]});
}
} catch($e51275128) {
if(R.isCont($e51275128)) {
var $ss51315132 = {"from":L[573],
"go":function(cont_tail_app4145137) {
return $Hcont_tail_app16365138(cont_tail_app4145137);
}};
$e51275128.stack[R.EXN_STACKHEIGHT++] = $ss51315132;
}
if(R.isPyretException($e51275128)) {
$e51275128.pyretStack.push(L[573]);
}
throw $e51275128;
}
var $ret51335134 = $Hcont_tail_app16365138($z51295130);
++R.GAS;
return $ret51335134;
}
} else {
var cont_tail_arg4115141 = R.throwNonBooleanCondition(L[569],("if"),if_DASH_675110);
if(--R.GAS > 0) {
$z51395140 = R.isFunction(if_helper4095125)?if_helper4095125.app(cont_tail_arg4115141):R.ffi.throwNonFunApp(L[569],if_helper4095125,[cont_tail_arg4115141]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper4095125)?if_helper4095125.app(cont_tail_arg4115141):R.ffi.throwNonFunApp(L[569],if_helper4095125,[cont_tail_arg4115141]);
},
"from":L[569]});
}
++R.GAS;
return $z51395140;
}
};
var $Hanf_arg16355126 = function(anf_arg4175123,anf_fun4155124,if_helper4095125,some685069) {
var $z51475148 = D;
var $f51535154 = function(_) {
return R.isFunction(anf_fun4155124)?anf_fun4155124.app(anf_arg4175123):R.ffi.throwNonFunApp(L[574],anf_fun4155124,[anf_arg4175123]);
};
try {
if(--R.GAS > 0) {
$z51475148 = $f51535154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51535154,
"from":L[574]});
}
} catch($e51455146) {
if(R.isCont($e51455146)) {
var $ss51495150 = {"from":L[574],
"go":function(anf_arg4185155) {
return $Hanf_arg16345156(anf_arg4185155,if_helper4095125,some685069);
}};
$e51455146.stack[R.EXN_STACKHEIGHT++] = $ss51495150;
}
if(R.isPyretException($e51455146)) {
$e51455146.pyretStack.push(L[574]);
}
throw $e51455146;
}
var $ret51515152 = $Hanf_arg16345156($z51475148,if_helper4095125,some685069);
++R.GAS;
return $ret51515152;
};
var $Hanf_arg16345156 = function(anf_arg4185155,if_helper4095125,some685069) {
var $z51595160 = D;
var $f51655166 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg4185155):R.ffi.throwNonFunApp(L[575],some685069,[anf_arg4185155]);
};
try {
if(--R.GAS > 0) {
$z51595160 = $f51655166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51655166,
"from":L[575]});
}
} catch($e51575158) {
if(R.isCont($e51575158)) {
var $ss51615162 = {"from":L[575],
"go":function(cont_tail_arg4195167) {
return $Hcont_tail_arg16335168(cont_tail_arg4195167,if_helper4095125);
}};
$e51575158.stack[R.EXN_STACKHEIGHT++] = $ss51615162;
}
if(R.isPyretException($e51575158)) {
$e51575158.pyretStack.push(L[575]);
}
throw $e51575158;
}
var $ret51635164 = $Hcont_tail_arg16335168($z51595160,if_helper4095125);
++R.GAS;
return $ret51635164;
};
var $Hcont_tail_arg16335168 = function(cont_tail_arg4195167,if_helper4095125) {
if(--R.GAS > 0) {
$z51695170 = R.isFunction(if_helper4095125)?if_helper4095125.app(cont_tail_arg4195167):R.ffi.throwNonFunApp(L[575],if_helper4095125,[cont_tail_arg4195167]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper4095125)?if_helper4095125.app(cont_tail_arg4195167):R.ffi.throwNonFunApp(L[575],if_helper4095125,[cont_tail_arg4195167]);
},
"from":L[575]});
}
++R.GAS;
return $z51695170;
};
var $Hcont_tail_app16365138 = function(cont_tail_app4145137) {
return cont_tail_app4145137;
};
var $Hanf_arg16325171 = function(anf_arg3915172,anf_fun3895173,env1495097,name1595174,none675099,some685069) {
var $z51775178 = D;
var $f51835184 = function(_) {
return R.isFunction(anf_fun3895173)?anf_fun3895173.app(anf_arg3915172):R.ffi.throwNonFunApp(L[576],anf_fun3895173,[anf_arg3915172]);
};
try {
if(--R.GAS > 0) {
$z51775178 = $f51835184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51835184,
"from":L[576]});
}
} catch($e51755176) {
if(R.isCont($e51755176)) {
var $ss51795180 = {"from":L[576],
"go":function(if_DASH_665185) {
return $Hif_DASH_16315186(if_DASH_665185,env1495097,name1595174,none675099,some685069);
}};
$e51755176.stack[R.EXN_STACKHEIGHT++] = $ss51795180;
}
if(R.isPyretException($e51755176)) {
$e51755176.pyretStack.push(L[576]);
}
throw $e51755176;
}
var $ret51815182 = $Hif_DASH_16315186($z51775178,env1495097,name1595174,none675099,some685069);
++R.GAS;
return $ret51815182;
};
var $Hif_DASH_16315186 = function(if_DASH_665185,env1495097,name1595174,none675099,some685069) {
var if_helper3925200 = R.makeFunction(function(if_helper_arg3935218) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[576],1,arguments);
}
var ann_DASH_check_DASH_temp3885219 = if_helper_arg3935218;
return ann_DASH_check_DASH_temp3885219;
});
var anf_if3965217 = R.isBoolean(if_DASH_665185);
if(R.isPyretTrue(anf_if3965217)) {
if(R.isPyretTrue(if_DASH_665185)) {
var anf_fun3985199 = G(env1495097,"get",L[579]);
var anf_fun3995197 = G(name1595174,"key",L[578]);
var $z51895190 = D;
var $f51955196 = function(_) {
return R.isFunction(anf_fun3995197)?anf_fun3995197.app():R.ffi.throwNonFunApp(L[577],anf_fun3995197,[]);
};
try {
if(--R.GAS > 0) {
$z51895190 = $f51955196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51955196,
"from":L[577]});
}
} catch($e51875188) {
if(R.isCont($e51875188)) {
var $ss51915192 = {"from":L[577],
"go":function(anf_arg4005198) {
return $Hanf_arg16295201(anf_arg4005198,anf_fun3985199,if_helper3925200,some685069);
}};
$e51875188.stack[R.EXN_STACKHEIGHT++] = $ss51915192;
}
if(R.isPyretException($e51875188)) {
$e51875188.pyretStack.push(L[577]);
}
throw $e51875188;
}
var $ret51935194 = $Hanf_arg16295201($z51895190,anf_fun3985199,if_helper3925200,some685069);
++R.GAS;
return $ret51935194;
} else {
var $z52045205 = D;
var $f52105211 = function(_) {
return R.isFunction(if_helper3925200)?if_helper3925200.app(none675099):R.ffi.throwNonFunApp(L[580],if_helper3925200,[none675099]);
};
try {
if(--R.GAS > 0) {
$z52045205 = $f52105211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52105211,
"from":L[580]});
}
} catch($e52025203) {
if(R.isCont($e52025203)) {
var $ss52065207 = {"from":L[580],
"go":function(cont_tail_app3975212) {
return $Hcont_tail_app16305213(cont_tail_app3975212);
}};
$e52025203.stack[R.EXN_STACKHEIGHT++] = $ss52065207;
}
if(R.isPyretException($e52025203)) {
$e52025203.pyretStack.push(L[580]);
}
throw $e52025203;
}
var $ret52085209 = $Hcont_tail_app16305213($z52045205);
++R.GAS;
return $ret52085209;
}
} else {
var cont_tail_arg3945216 = R.throwNonBooleanCondition(L[576],("if"),if_DASH_665185);
if(--R.GAS > 0) {
$z52145215 = R.isFunction(if_helper3925200)?if_helper3925200.app(cont_tail_arg3945216):R.ffi.throwNonFunApp(L[576],if_helper3925200,[cont_tail_arg3945216]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper3925200)?if_helper3925200.app(cont_tail_arg3945216):R.ffi.throwNonFunApp(L[576],if_helper3925200,[cont_tail_arg3945216]);
},
"from":L[576]});
}
++R.GAS;
return $z52145215;
}
};
var $Hanf_arg16295201 = function(anf_arg4005198,anf_fun3985199,if_helper3925200,some685069) {
var $z52225223 = D;
var $f52285229 = function(_) {
return R.isFunction(anf_fun3985199)?anf_fun3985199.app(anf_arg4005198):R.ffi.throwNonFunApp(L[581],anf_fun3985199,[anf_arg4005198]);
};
try {
if(--R.GAS > 0) {
$z52225223 = $f52285229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52285229,
"from":L[581]});
}
} catch($e52205221) {
if(R.isCont($e52205221)) {
var $ss52245225 = {"from":L[581],
"go":function(anf_arg4015230) {
return $Hanf_arg16285231(anf_arg4015230,if_helper3925200,some685069);
}};
$e52205221.stack[R.EXN_STACKHEIGHT++] = $ss52245225;
}
if(R.isPyretException($e52205221)) {
$e52205221.pyretStack.push(L[581]);
}
throw $e52205221;
}
var $ret52265227 = $Hanf_arg16285231($z52225223,if_helper3925200,some685069);
++R.GAS;
return $ret52265227;
};
var $Hanf_arg16285231 = function(anf_arg4015230,if_helper3925200,some685069) {
var $z52345235 = D;
var $f52405241 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg4015230):R.ffi.throwNonFunApp(L[582],some685069,[anf_arg4015230]);
};
try {
if(--R.GAS > 0) {
$z52345235 = $f52405241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52405241,
"from":L[582]});
}
} catch($e52325233) {
if(R.isCont($e52325233)) {
var $ss52365237 = {"from":L[582],
"go":function(cont_tail_arg4025242) {
return $Hcont_tail_arg16275243(cont_tail_arg4025242,if_helper3925200);
}};
$e52325233.stack[R.EXN_STACKHEIGHT++] = $ss52365237;
}
if(R.isPyretException($e52325233)) {
$e52325233.pyretStack.push(L[582]);
}
throw $e52325233;
}
var $ret52385239 = $Hcont_tail_arg16275243($z52345235,if_helper3925200);
++R.GAS;
return $ret52385239;
};
var $Hcont_tail_arg16275243 = function(cont_tail_arg4025242,if_helper3925200) {
if(--R.GAS > 0) {
$z52445245 = R.isFunction(if_helper3925200)?if_helper3925200.app(cont_tail_arg4025242):R.ffi.throwNonFunApp(L[582],if_helper3925200,[cont_tail_arg4025242]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper3925200)?if_helper3925200.app(cont_tail_arg4025242):R.ffi.throwNonFunApp(L[582],if_helper3925200,[cont_tail_arg4025242]);
},
"from":L[582]});
}
++R.GAS;
return $z52445245;
};
var $Hcont_tail_app16305213 = function(cont_tail_app3975212) {
return cont_tail_app3975212;
};
var $Hanf_arg16265246 = function(anf_arg3745247,anf_fun3725248,env1495097,name1575249,none675099,some685069) {
var $z52525253 = D;
var $f52585259 = function(_) {
return R.isFunction(anf_fun3725248)?anf_fun3725248.app(anf_arg3745247):R.ffi.throwNonFunApp(L[583],anf_fun3725248,[anf_arg3745247]);
};
try {
if(--R.GAS > 0) {
$z52525253 = $f52585259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52585259,
"from":L[583]});
}
} catch($e52505251) {
if(R.isCont($e52505251)) {
var $ss52545255 = {"from":L[583],
"go":function(if_DASH_655260) {
return $Hif_DASH_16255261(if_DASH_655260,env1495097,name1575249,none675099,some685069);
}};
$e52505251.stack[R.EXN_STACKHEIGHT++] = $ss52545255;
}
if(R.isPyretException($e52505251)) {
$e52505251.pyretStack.push(L[583]);
}
throw $e52505251;
}
var $ret52565257 = $Hif_DASH_16255261($z52525253,env1495097,name1575249,none675099,some685069);
++R.GAS;
return $ret52565257;
};
var $Hif_DASH_16255261 = function(if_DASH_655260,env1495097,name1575249,none675099,some685069) {
var if_helper3755275 = R.makeFunction(function(if_helper_arg3765293) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[583],1,arguments);
}
var ann_DASH_check_DASH_temp3715294 = if_helper_arg3765293;
return ann_DASH_check_DASH_temp3715294;
});
var anf_if3795292 = R.isBoolean(if_DASH_655260);
if(R.isPyretTrue(anf_if3795292)) {
if(R.isPyretTrue(if_DASH_655260)) {
var anf_fun3815274 = G(env1495097,"get",L[586]);
var anf_fun3825272 = G(name1575249,"key",L[585]);
var $z52645265 = D;
var $f52705271 = function(_) {
return R.isFunction(anf_fun3825272)?anf_fun3825272.app():R.ffi.throwNonFunApp(L[584],anf_fun3825272,[]);
};
try {
if(--R.GAS > 0) {
$z52645265 = $f52705271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52705271,
"from":L[584]});
}
} catch($e52625263) {
if(R.isCont($e52625263)) {
var $ss52665267 = {"from":L[584],
"go":function(anf_arg3835273) {
return $Hanf_arg16235276(anf_arg3835273,anf_fun3815274,if_helper3755275,some685069);
}};
$e52625263.stack[R.EXN_STACKHEIGHT++] = $ss52665267;
}
if(R.isPyretException($e52625263)) {
$e52625263.pyretStack.push(L[584]);
}
throw $e52625263;
}
var $ret52685269 = $Hanf_arg16235276($z52645265,anf_fun3815274,if_helper3755275,some685069);
++R.GAS;
return $ret52685269;
} else {
var $z52795280 = D;
var $f52855286 = function(_) {
return R.isFunction(if_helper3755275)?if_helper3755275.app(none675099):R.ffi.throwNonFunApp(L[587],if_helper3755275,[none675099]);
};
try {
if(--R.GAS > 0) {
$z52795280 = $f52855286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52855286,
"from":L[587]});
}
} catch($e52775278) {
if(R.isCont($e52775278)) {
var $ss52815282 = {"from":L[587],
"go":function(cont_tail_app3805287) {
return $Hcont_tail_app16245288(cont_tail_app3805287);
}};
$e52775278.stack[R.EXN_STACKHEIGHT++] = $ss52815282;
}
if(R.isPyretException($e52775278)) {
$e52775278.pyretStack.push(L[587]);
}
throw $e52775278;
}
var $ret52835284 = $Hcont_tail_app16245288($z52795280);
++R.GAS;
return $ret52835284;
}
} else {
var cont_tail_arg3775291 = R.throwNonBooleanCondition(L[583],("if"),if_DASH_655260);
if(--R.GAS > 0) {
$z52895290 = R.isFunction(if_helper3755275)?if_helper3755275.app(cont_tail_arg3775291):R.ffi.throwNonFunApp(L[583],if_helper3755275,[cont_tail_arg3775291]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper3755275)?if_helper3755275.app(cont_tail_arg3775291):R.ffi.throwNonFunApp(L[583],if_helper3755275,[cont_tail_arg3775291]);
},
"from":L[583]});
}
++R.GAS;
return $z52895290;
}
};
var $Hanf_arg16235276 = function(anf_arg3835273,anf_fun3815274,if_helper3755275,some685069) {
var $z52975298 = D;
var $f53035304 = function(_) {
return R.isFunction(anf_fun3815274)?anf_fun3815274.app(anf_arg3835273):R.ffi.throwNonFunApp(L[588],anf_fun3815274,[anf_arg3835273]);
};
try {
if(--R.GAS > 0) {
$z52975298 = $f53035304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53035304,
"from":L[588]});
}
} catch($e52955296) {
if(R.isCont($e52955296)) {
var $ss52995300 = {"from":L[588],
"go":function(anf_arg3845305) {
return $Hanf_arg16225306(anf_arg3845305,if_helper3755275,some685069);
}};
$e52955296.stack[R.EXN_STACKHEIGHT++] = $ss52995300;
}
if(R.isPyretException($e52955296)) {
$e52955296.pyretStack.push(L[588]);
}
throw $e52955296;
}
var $ret53015302 = $Hanf_arg16225306($z52975298,if_helper3755275,some685069);
++R.GAS;
return $ret53015302;
};
var $Hanf_arg16225306 = function(anf_arg3845305,if_helper3755275,some685069) {
var $z53095310 = D;
var $f53155316 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg3845305):R.ffi.throwNonFunApp(L[589],some685069,[anf_arg3845305]);
};
try {
if(--R.GAS > 0) {
$z53095310 = $f53155316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53155316,
"from":L[589]});
}
} catch($e53075308) {
if(R.isCont($e53075308)) {
var $ss53115312 = {"from":L[589],
"go":function(cont_tail_arg3855317) {
return $Hcont_tail_arg16215318(cont_tail_arg3855317,if_helper3755275);
}};
$e53075308.stack[R.EXN_STACKHEIGHT++] = $ss53115312;
}
if(R.isPyretException($e53075308)) {
$e53075308.pyretStack.push(L[589]);
}
throw $e53075308;
}
var $ret53135314 = $Hcont_tail_arg16215318($z53095310,if_helper3755275);
++R.GAS;
return $ret53135314;
};
var $Hcont_tail_arg16215318 = function(cont_tail_arg3855317,if_helper3755275) {
if(--R.GAS > 0) {
$z53195320 = R.isFunction(if_helper3755275)?if_helper3755275.app(cont_tail_arg3855317):R.ffi.throwNonFunApp(L[589],if_helper3755275,[cont_tail_arg3855317]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper3755275)?if_helper3755275.app(cont_tail_arg3855317):R.ffi.throwNonFunApp(L[589],if_helper3755275,[cont_tail_arg3855317]);
},
"from":L[589]});
}
++R.GAS;
return $z53195320;
};
var $Hcont_tail_app16245288 = function(cont_tail_app3805287) {
return cont_tail_app3805287;
};
var $Hcases_DASH_val16205321 = function(cases_DASH_val645322,A317,b_DASH_dot11760,e_DASH_bind12678,name1525323,none675099,some685069) {
var anf_fun3325334 = G(cases_DASH_val645322,"_match",L[591]);
var anf_obj3645340 = R.makeFunction(function(eb1535343) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[593],1,arguments);
}
var b1545369 = G(eb1535343,"info",L[601]);
var cases_DASH_val635389 = b1545369;
var anf_fun3345354 = G(cases_DASH_val635389,"_match",L[594]);
var anf_obj3575373 = R.makeFunction(function(dict1555374) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[597],1,arguments);
}
var anf_fun3365387 = G(dict1555374,"has-key",L[600]);
var anf_fun3375385 = G(name1525323,"key",L[599]);
var $z53775378 = D;
var $f53835384 = function(_) {
return R.isFunction(anf_fun3375385)?anf_fun3375385.app():R.ffi.throwNonFunApp(L[598],anf_fun3375385,[]);
};
try {
if(--R.GAS > 0) {
$z53775378 = $f53835384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53835384,
"from":L[598]});
}
} catch($e53755376) {
if(R.isCont($e53755376)) {
var $ss53795380 = {"from":L[598],
"go":function(anf_arg3385386) {
return $Hanf_arg16145388(anf_arg3385386,A317,anf_fun3365387,b_DASH_dot11760,b1545369,dict1555374,e_DASH_bind12678,name1525323,some685069);
}};
$e53755376.stack[R.EXN_STACKHEIGHT++] = $ss53795380;
}
if(R.isPyretException($e53755376)) {
$e53755376.pyretStack.push(L[598]);
}
throw $e53755376;
}
var $ret53815382 = $Hanf_arg16145388($z53775378,A317,anf_fun3365387,b_DASH_dot11760,b1545369,dict1555374,e_DASH_bind12678,name1525323,some685069);
++R.GAS;
return $ret53815382;
});
var anf_arg3585355 = R.makeObject({"b-dict":anf_obj3575373});
var anf_arg3635356 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[594],0,arguments);
}
var anf_arg3605371 = G(A317,"dummy-loc",L[596]);
var $z53615362 = D;
var $f53675368 = function(_) {
return R.isFunction(b_DASH_dot11760.$var)?b_DASH_dot11760.$var.app(b1545369,name1525323):R.ffi.throwNonFunApp(L[595],b_DASH_dot11760.$var,[b1545369,name1525323]);
};
try {
if(--R.GAS > 0) {
$z53615362 = $f53675368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53675368,
"from":L[595]});
}
} catch($e53595360) {
if(R.isCont($e53595360)) {
var $ss53635364 = {"from":L[595],
"go":function(anf_arg3615370) {
return $Hanf_arg16175372(anf_arg3615370,anf_arg3605371,e_DASH_bind12678,some685069);
}};
$e53595360.stack[R.EXN_STACKHEIGHT++] = $ss53635364;
}
if(R.isPyretException($e53595360)) {
$e53595360.pyretStack.push(L[595]);
}
throw $e53595360;
}
var $ret53655366 = $Hanf_arg16175372($z53615362,anf_arg3605371,e_DASH_bind12678,some685069);
++R.GAS;
return $ret53655366;
});
var $z53465347 = D;
var $f53525353 = function(_) {
return R.isFunction(anf_fun3345354)?anf_fun3345354.app(anf_arg3585355,anf_arg3635356):R.ffi.throwNonFunApp(L[593],anf_fun3345354,[anf_arg3585355,anf_arg3635356]);
};
try {
if(--R.GAS > 0) {
$z53465347 = $f53525353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53525353,
"from":L[593]});
}
} catch($e53445345) {
if(R.isCont($e53445345)) {
var $ss53485349 = {"from":L[593],
"go":function(ann_DASH_check_DASH_temp3335357) {
return $Hann_DASH_check_DASH_temp16185358(ann_DASH_check_DASH_temp3335357);
}};
$e53445345.stack[R.EXN_STACKHEIGHT++] = $ss53485349;
}
if(R.isPyretException($e53445345)) {
$e53445345.pyretStack.push(L[593]);
}
throw $e53445345;
}
var $ret53505351 = $Hann_DASH_check_DASH_temp16185358($z53465347);
++R.GAS;
return $ret53505351;
});
var anf_obj3665341 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[592],0,arguments);
}
var ann_DASH_check_DASH_temp3655342 = none675099;
return ann_DASH_check_DASH_temp3655342;
});
var anf_arg3675335 = R.makeObject({"some":anf_obj3645340,
"none":anf_obj3665341});
var anf_arg3695336 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[591],0,arguments);
}
var ann_DASH_check_DASH_temp3685339 = R.throwNoBranchesMatched(L[591],("cases"));
return ann_DASH_check_DASH_temp3685339;
});
var $z53265327 = D;
var $f53325333 = function(_) {
return R.isFunction(anf_fun3325334)?anf_fun3325334.app(anf_arg3675335,anf_arg3695336):R.ffi.throwNonFunApp(L[590],anf_fun3325334,[anf_arg3675335,anf_arg3695336]);
};
try {
if(--R.GAS > 0) {
$z53265327 = $f53325333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53325333,
"from":L[590]});
}
} catch($e53245325) {
if(R.isCont($e53245325)) {
var $ss53285329 = {"from":L[590],
"go":function(ann_DASH_check_DASH_temp3315337) {
return $Hann_DASH_check_DASH_temp16195338(ann_DASH_check_DASH_temp3315337);
}};
$e53245325.stack[R.EXN_STACKHEIGHT++] = $ss53285329;
}
if(R.isPyretException($e53245325)) {
$e53245325.pyretStack.push(L[590]);
}
throw $e53245325;
}
var $ret53305331 = $Hann_DASH_check_DASH_temp16195338($z53265327);
++R.GAS;
return $ret53305331;
};
var $Hann_DASH_check_DASH_temp16195338 = function(ann_DASH_check_DASH_temp3315337) {
return ann_DASH_check_DASH_temp3315337;
};
var $Hann_DASH_check_DASH_temp16185358 = function(ann_DASH_check_DASH_temp3335357) {
return ann_DASH_check_DASH_temp3335357;
};
var $Hanf_arg16175372 = function(anf_arg3615370,anf_arg3605371,e_DASH_bind12678,some685069) {
var $z53925393 = D;
var $f53985399 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg3605371,(false),anf_arg3615370):R.ffi.throwNonFunApp(L[602],e_DASH_bind12678.$var,[anf_arg3605371,(false),anf_arg3615370]);
};
try {
if(--R.GAS > 0) {
$z53925393 = $f53985399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53985399,
"from":L[602]});
}
} catch($e53905391) {
if(R.isCont($e53905391)) {
var $ss53945395 = {"from":L[602],
"go":function(anf_arg3625400) {
return $Hanf_arg16165401(anf_arg3625400,some685069);
}};
$e53905391.stack[R.EXN_STACKHEIGHT++] = $ss53945395;
}
if(R.isPyretException($e53905391)) {
$e53905391.pyretStack.push(L[602]);
}
throw $e53905391;
}
var $ret53965397 = $Hanf_arg16165401($z53925393,some685069);
++R.GAS;
return $ret53965397;
};
var $Hanf_arg16165401 = function(anf_arg3625400,some685069) {
var $z54045405 = D;
var $f54105411 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg3625400):R.ffi.throwNonFunApp(L[594],some685069,[anf_arg3625400]);
};
try {
if(--R.GAS > 0) {
$z54045405 = $f54105411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54105411,
"from":L[594]});
}
} catch($e54025403) {
if(R.isCont($e54025403)) {
var $ss54065407 = {"from":L[594],
"go":function(ann_DASH_check_DASH_temp3595412) {
return $Hann_DASH_check_DASH_temp16155413(ann_DASH_check_DASH_temp3595412);
}};
$e54025403.stack[R.EXN_STACKHEIGHT++] = $ss54065407;
}
if(R.isPyretException($e54025403)) {
$e54025403.pyretStack.push(L[594]);
}
throw $e54025403;
}
var $ret54085409 = $Hann_DASH_check_DASH_temp16155413($z54045405);
++R.GAS;
return $ret54085409;
};
var $Hann_DASH_check_DASH_temp16155413 = function(ann_DASH_check_DASH_temp3595412) {
return ann_DASH_check_DASH_temp3595412;
};
var $Hanf_arg16145388 = function(anf_arg3385386,A317,anf_fun3365387,b_DASH_dot11760,b1545369,dict1555374,e_DASH_bind12678,name1525323,some685069) {
var $z54165417 = D;
var $f54225423 = function(_) {
return R.isFunction(anf_fun3365387)?anf_fun3365387.app(anf_arg3385386):R.ffi.throwNonFunApp(L[603],anf_fun3365387,[anf_arg3385386]);
};
try {
if(--R.GAS > 0) {
$z54165417 = $f54225423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54225423,
"from":L[603]});
}
} catch($e54145415) {
if(R.isCont($e54145415)) {
var $ss54185419 = {"from":L[603],
"go":function(if_DASH_625424) {
return $Hif_DASH_16135425(if_DASH_625424,A317,b_DASH_dot11760,b1545369,dict1555374,e_DASH_bind12678,name1525323,some685069);
}};
$e54145415.stack[R.EXN_STACKHEIGHT++] = $ss54185419;
}
if(R.isPyretException($e54145415)) {
$e54145415.pyretStack.push(L[603]);
}
throw $e54145415;
}
var $ret54205421 = $Hif_DASH_16135425($z54165417,A317,b_DASH_dot11760,b1545369,dict1555374,e_DASH_bind12678,name1525323,some685069);
++R.GAS;
return $ret54205421;
};
var $Hif_DASH_16135425 = function(if_DASH_625424,A317,b_DASH_dot11760,b1545369,dict1555374,e_DASH_bind12678,name1525323,some685069) {
var if_helper3395440 = R.makeFunction(function(if_helper_arg3405459) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[603],1,arguments);
}
var ann_DASH_check_DASH_temp3355460 = if_helper_arg3405459;
return ann_DASH_check_DASH_temp3355460;
});
var anf_if3435458 = R.isBoolean(if_DASH_625424);
if(R.isPyretTrue(anf_if3435458)) {
if(R.isPyretTrue(if_DASH_625424)) {
var anf_arg3495438 = G(A317,"dummy-loc",L[607]);
var anf_fun3505439 = G(dict1555374,"get",L[606]);
var anf_fun3515436 = G(name1525323,"key",L[605]);
var $z54285429 = D;
var $f54345435 = function(_) {
return R.isFunction(anf_fun3515436)?anf_fun3515436.app():R.ffi.throwNonFunApp(L[604],anf_fun3515436,[]);
};
try {
if(--R.GAS > 0) {
$z54285429 = $f54345435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54345435,
"from":L[604]});
}
} catch($e54265427) {
if(R.isCont($e54265427)) {
var $ss54305431 = {"from":L[604],
"go":function(anf_arg3525437) {
return $Hanf_arg16095441(anf_arg3525437,anf_arg3495438,anf_fun3505439,e_DASH_bind12678,if_helper3395440,some685069);
}};
$e54265427.stack[R.EXN_STACKHEIGHT++] = $ss54305431;
}
if(R.isPyretException($e54265427)) {
$e54265427.pyretStack.push(L[604]);
}
throw $e54265427;
}
var $ret54325433 = $Hanf_arg16095441($z54285429,anf_arg3495438,anf_fun3505439,e_DASH_bind12678,if_helper3395440,some685069);
++R.GAS;
return $ret54325433;
} else {
var anf_arg3445453 = G(A317,"dummy-loc",L[609]);
var $z54445445 = D;
var $f54505451 = function(_) {
return R.isFunction(b_DASH_dot11760.$var)?b_DASH_dot11760.$var.app(b1545369,name1525323):R.ffi.throwNonFunApp(L[608],b_DASH_dot11760.$var,[b1545369,name1525323]);
};
try {
if(--R.GAS > 0) {
$z54445445 = $f54505451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54505451,
"from":L[608]});
}
} catch($e54425443) {
if(R.isCont($e54425443)) {
var $ss54465447 = {"from":L[608],
"go":function(anf_arg3455452) {
return $Hanf_arg16125454(anf_arg3455452,anf_arg3445453,e_DASH_bind12678,if_helper3395440,some685069);
}};
$e54425443.stack[R.EXN_STACKHEIGHT++] = $ss54465447;
}
if(R.isPyretException($e54425443)) {
$e54425443.pyretStack.push(L[608]);
}
throw $e54425443;
}
var $ret54485449 = $Hanf_arg16125454($z54445445,anf_arg3445453,e_DASH_bind12678,if_helper3395440,some685069);
++R.GAS;
return $ret54485449;
}
} else {
var cont_tail_arg3415457 = R.throwNonBooleanCondition(L[603],("if"),if_DASH_625424);
if(--R.GAS > 0) {
$z54555456 = R.isFunction(if_helper3395440)?if_helper3395440.app(cont_tail_arg3415457):R.ffi.throwNonFunApp(L[603],if_helper3395440,[cont_tail_arg3415457]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper3395440)?if_helper3395440.app(cont_tail_arg3415457):R.ffi.throwNonFunApp(L[603],if_helper3395440,[cont_tail_arg3415457]);
},
"from":L[603]});
}
++R.GAS;
return $z54555456;
}
};
var $Hanf_arg16095441 = function(anf_arg3525437,anf_arg3495438,anf_fun3505439,e_DASH_bind12678,if_helper3395440,some685069) {
var $z54635464 = D;
var $f54695470 = function(_) {
return R.isFunction(anf_fun3505439)?anf_fun3505439.app(anf_arg3525437):R.ffi.throwNonFunApp(L[610],anf_fun3505439,[anf_arg3525437]);
};
try {
if(--R.GAS > 0) {
$z54635464 = $f54695470();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54695470,
"from":L[610]});
}
} catch($e54615462) {
if(R.isCont($e54615462)) {
var $ss54655466 = {"from":L[610],
"go":function(anf_arg3535471) {
return $Hanf_arg16085472(anf_arg3535471,anf_arg3495438,e_DASH_bind12678,if_helper3395440,some685069);
}};
$e54615462.stack[R.EXN_STACKHEIGHT++] = $ss54655466;
}
if(R.isPyretException($e54615462)) {
$e54615462.pyretStack.push(L[610]);
}
throw $e54615462;
}
var $ret54675468 = $Hanf_arg16085472($z54635464,anf_arg3495438,e_DASH_bind12678,if_helper3395440,some685069);
++R.GAS;
return $ret54675468;
};
var $Hanf_arg16085472 = function(anf_arg3535471,anf_arg3495438,e_DASH_bind12678,if_helper3395440,some685069) {
var $z54755476 = D;
var $f54815482 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg3495438,(false),anf_arg3535471):R.ffi.throwNonFunApp(L[611],e_DASH_bind12678.$var,[anf_arg3495438,(false),anf_arg3535471]);
};
try {
if(--R.GAS > 0) {
$z54755476 = $f54815482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54815482,
"from":L[611]});
}
} catch($e54735474) {
if(R.isCont($e54735474)) {
var $ss54775478 = {"from":L[611],
"go":function(anf_arg3545483) {
return $Hanf_arg16075484(anf_arg3545483,if_helper3395440,some685069);
}};
$e54735474.stack[R.EXN_STACKHEIGHT++] = $ss54775478;
}
if(R.isPyretException($e54735474)) {
$e54735474.pyretStack.push(L[611]);
}
throw $e54735474;
}
var $ret54795480 = $Hanf_arg16075484($z54755476,if_helper3395440,some685069);
++R.GAS;
return $ret54795480;
};
var $Hanf_arg16075484 = function(anf_arg3545483,if_helper3395440,some685069) {
var $z54875488 = D;
var $f54935494 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg3545483):R.ffi.throwNonFunApp(L[612],some685069,[anf_arg3545483]);
};
try {
if(--R.GAS > 0) {
$z54875488 = $f54935494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54935494,
"from":L[612]});
}
} catch($e54855486) {
if(R.isCont($e54855486)) {
var $ss54895490 = {"from":L[612],
"go":function(cont_tail_arg3555495) {
return $Hcont_tail_arg16065496(cont_tail_arg3555495,if_helper3395440);
}};
$e54855486.stack[R.EXN_STACKHEIGHT++] = $ss54895490;
}
if(R.isPyretException($e54855486)) {
$e54855486.pyretStack.push(L[612]);
}
throw $e54855486;
}
var $ret54915492 = $Hcont_tail_arg16065496($z54875488,if_helper3395440);
++R.GAS;
return $ret54915492;
};
var $Hcont_tail_arg16065496 = function(cont_tail_arg3555495,if_helper3395440) {
if(--R.GAS > 0) {
$z54975498 = R.isFunction(if_helper3395440)?if_helper3395440.app(cont_tail_arg3555495):R.ffi.throwNonFunApp(L[612],if_helper3395440,[cont_tail_arg3555495]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper3395440)?if_helper3395440.app(cont_tail_arg3555495):R.ffi.throwNonFunApp(L[612],if_helper3395440,[cont_tail_arg3555495]);
},
"from":L[612]});
}
++R.GAS;
return $z54975498;
};
var $Hanf_arg16125454 = function(anf_arg3455452,anf_arg3445453,e_DASH_bind12678,if_helper3395440,some685069) {
var $z55015502 = D;
var $f55075508 = function(_) {
return R.isFunction(e_DASH_bind12678.$var)?e_DASH_bind12678.$var.app(anf_arg3445453,(false),anf_arg3455452):R.ffi.throwNonFunApp(L[613],e_DASH_bind12678.$var,[anf_arg3445453,(false),anf_arg3455452]);
};
try {
if(--R.GAS > 0) {
$z55015502 = $f55075508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55075508,
"from":L[613]});
}
} catch($e54995500) {
if(R.isCont($e54995500)) {
var $ss55035504 = {"from":L[613],
"go":function(anf_arg3465509) {
return $Hanf_arg16115510(anf_arg3465509,if_helper3395440,some685069);
}};
$e54995500.stack[R.EXN_STACKHEIGHT++] = $ss55035504;
}
if(R.isPyretException($e54995500)) {
$e54995500.pyretStack.push(L[613]);
}
throw $e54995500;
}
var $ret55055506 = $Hanf_arg16115510($z55015502,if_helper3395440,some685069);
++R.GAS;
return $ret55055506;
};
var $Hanf_arg16115510 = function(anf_arg3465509,if_helper3395440,some685069) {
var $z55135514 = D;
var $f55195520 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg3465509):R.ffi.throwNonFunApp(L[614],some685069,[anf_arg3465509]);
};
try {
if(--R.GAS > 0) {
$z55135514 = $f55195520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55195520,
"from":L[614]});
}
} catch($e55115512) {
if(R.isCont($e55115512)) {
var $ss55155516 = {"from":L[614],
"go":function(cont_tail_arg3475521) {
return $Hcont_tail_arg16105522(cont_tail_arg3475521,if_helper3395440);
}};
$e55115512.stack[R.EXN_STACKHEIGHT++] = $ss55155516;
}
if(R.isPyretException($e55115512)) {
$e55115512.pyretStack.push(L[614]);
}
throw $e55115512;
}
var $ret55175518 = $Hcont_tail_arg16105522($z55135514,if_helper3395440);
++R.GAS;
return $ret55175518;
};
var $Hcont_tail_arg16105522 = function(cont_tail_arg3475521,if_helper3395440) {
if(--R.GAS > 0) {
$z55235524 = R.isFunction(if_helper3395440)?if_helper3395440.app(cont_tail_arg3475521):R.ffi.throwNonFunApp(L[614],if_helper3395440,[cont_tail_arg3475521]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper3395440)?if_helper3395440.app(cont_tail_arg3475521):R.ffi.throwNonFunApp(L[614],if_helper3395440,[cont_tail_arg3475521]);
},
"from":L[614]});
}
++R.GAS;
return $z55235524;
};
var $Hanf_arg16055525 = function(anf_arg3125526,self605527,_plus7,torepr13) {
var anf_arg3135538 = G(self605527,"mut",L[615]);
var $z55305531 = D;
var $f55365537 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg3135538):R.ffi.throwNonFunApp(L[615],torepr13,[anf_arg3135538]);
};
try {
if(--R.GAS > 0) {
$z55305531 = $f55365537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55365537,
"from":L[615]});
}
} catch($e55285529) {
if(R.isCont($e55285529)) {
var $ss55325533 = {"from":L[615],
"go":function(anf_arg3145539) {
return $Hanf_arg16045540(anf_arg3145539,anf_arg3125526,self605527,_plus7,torepr13);
}};
$e55285529.stack[R.EXN_STACKHEIGHT++] = $ss55325533;
}
if(R.isPyretException($e55285529)) {
$e55285529.pyretStack.push(L[615]);
}
throw $e55285529;
}
var $ret55345535 = $Hanf_arg16045540($z55305531,anf_arg3125526,self605527,_plus7,torepr13);
++R.GAS;
return $ret55345535;
};
var $Hanf_arg16045540 = function(anf_arg3145539,anf_arg3125526,self605527,_plus7,torepr13) {
var $z55435544 = D;
var $f55495550 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg3145539):R.ffi.throwNonFunApp(L[615],_plus7,[(", "),anf_arg3145539]);
};
try {
if(--R.GAS > 0) {
$z55435544 = $f55495550();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55495550,
"from":L[615]});
}
} catch($e55415542) {
if(R.isCont($e55415542)) {
var $ss55455546 = {"from":L[615],
"go":function(anf_arg3155551) {
return $Hanf_arg16035552(anf_arg3155551,anf_arg3125526,self605527,_plus7,torepr13);
}};
$e55415542.stack[R.EXN_STACKHEIGHT++] = $ss55455546;
}
if(R.isPyretException($e55415542)) {
$e55415542.pyretStack.push(L[615]);
}
throw $e55415542;
}
var $ret55475548 = $Hanf_arg16035552($z55435544,anf_arg3125526,self605527,_plus7,torepr13);
++R.GAS;
return $ret55475548;
};
var $Hanf_arg16035552 = function(anf_arg3155551,anf_arg3125526,self605527,_plus7,torepr13) {
var $z55555556 = D;
var $f55615562 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg3125526,anf_arg3155551):R.ffi.throwNonFunApp(L[615],_plus7,[anf_arg3125526,anf_arg3155551]);
};
try {
if(--R.GAS > 0) {
$z55555556 = $f55615562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55615562,
"from":L[615]});
}
} catch($e55535554) {
if(R.isCont($e55535554)) {
var $ss55575558 = {"from":L[615],
"go":function(anf_arg3165563) {
return $Hanf_arg16025564(anf_arg3165563,self605527,_plus7,torepr13);
}};
$e55535554.stack[R.EXN_STACKHEIGHT++] = $ss55575558;
}
if(R.isPyretException($e55535554)) {
$e55535554.pyretStack.push(L[615]);
}
throw $e55535554;
}
var $ret55595560 = $Hanf_arg16025564($z55555556,self605527,_plus7,torepr13);
++R.GAS;
return $ret55595560;
};
var $Hanf_arg16025564 = function(anf_arg3165563,self605527,_plus7,torepr13) {
var anf_arg3175575 = G(self605527,"info",L[615]);
var $z55675568 = D;
var $f55735574 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg3175575):R.ffi.throwNonFunApp(L[615],torepr13,[anf_arg3175575]);
};
try {
if(--R.GAS > 0) {
$z55675568 = $f55735574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55735574,
"from":L[615]});
}
} catch($e55655566) {
if(R.isCont($e55655566)) {
var $ss55695570 = {"from":L[615],
"go":function(anf_arg3185576) {
return $Hanf_arg16015577(anf_arg3185576,anf_arg3165563,_plus7);
}};
$e55655566.stack[R.EXN_STACKHEIGHT++] = $ss55695570;
}
if(R.isPyretException($e55655566)) {
$e55655566.pyretStack.push(L[615]);
}
throw $e55655566;
}
var $ret55715572 = $Hanf_arg16015577($z55675568,anf_arg3165563,_plus7);
++R.GAS;
return $ret55715572;
};
var $Hanf_arg16015577 = function(anf_arg3185576,anf_arg3165563,_plus7) {
var $z55805581 = D;
var $f55865587 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg3185576):R.ffi.throwNonFunApp(L[615],_plus7,[(", "),anf_arg3185576]);
};
try {
if(--R.GAS > 0) {
$z55805581 = $f55865587();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55865587,
"from":L[615]});
}
} catch($e55785579) {
if(R.isCont($e55785579)) {
var $ss55825583 = {"from":L[615],
"go":function(anf_arg3195588) {
return $Hanf_arg16005589(anf_arg3195588,anf_arg3165563,_plus7);
}};
$e55785579.stack[R.EXN_STACKHEIGHT++] = $ss55825583;
}
if(R.isPyretException($e55785579)) {
$e55785579.pyretStack.push(L[615]);
}
throw $e55785579;
}
var $ret55845585 = $Hanf_arg16005589($z55805581,anf_arg3165563,_plus7);
++R.GAS;
return $ret55845585;
};
var $Hanf_arg16005589 = function(anf_arg3195588,anf_arg3165563,_plus7) {
var $z55925593 = D;
var $f55985599 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg3165563,anf_arg3195588):R.ffi.throwNonFunApp(L[615],_plus7,[anf_arg3165563,anf_arg3195588]);
};
try {
if(--R.GAS > 0) {
$z55925593 = $f55985599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55985599,
"from":L[615]});
}
} catch($e55905591) {
if(R.isCont($e55905591)) {
var $ss55945595 = {"from":L[615],
"go":function(anf_arg3205600) {
return $Hanf_arg15995601(anf_arg3205600,_plus7);
}};
$e55905591.stack[R.EXN_STACKHEIGHT++] = $ss55945595;
}
if(R.isPyretException($e55905591)) {
$e55905591.pyretStack.push(L[615]);
}
throw $e55905591;
}
var $ret55965597 = $Hanf_arg15995601($z55925593,_plus7);
++R.GAS;
return $ret55965597;
};
var $Hanf_arg15995601 = function(anf_arg3205600,_plus7) {
var $z56045605 = D;
var $f56105611 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg3205600,(")")):R.ffi.throwNonFunApp(L[615],_plus7,[anf_arg3205600,(")")]);
};
try {
if(--R.GAS > 0) {
$z56045605 = $f56105611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56105611,
"from":L[615]});
}
} catch($e56025603) {
if(R.isCont($e56025603)) {
var $ss56065607 = {"from":L[615],
"go":function(anf_arg3215612) {
return $Hanf_arg15985613(anf_arg3215612,_plus7);
}};
$e56025603.stack[R.EXN_STACKHEIGHT++] = $ss56065607;
}
if(R.isPyretException($e56025603)) {
$e56025603.pyretStack.push(L[615]);
}
throw $e56025603;
}
var $ret56085609 = $Hanf_arg15985613($z56045605,_plus7);
++R.GAS;
return $ret56085609;
};
var $Hanf_arg15985613 = function(anf_arg3215612,_plus7) {
var $z56165617 = D;
var $f56225623 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg3215612):R.ffi.throwNonFunApp(L[615],_plus7,[("("),anf_arg3215612]);
};
try {
if(--R.GAS > 0) {
$z56165617 = $f56225623();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56225623,
"from":L[615]});
}
} catch($e56145615) {
if(R.isCont($e56145615)) {
var $ss56185619 = {"from":L[615],
"go":function(anf_arg3225624) {
return $Hanf_arg15975625(anf_arg3225624,_plus7);
}};
$e56145615.stack[R.EXN_STACKHEIGHT++] = $ss56185619;
}
if(R.isPyretException($e56145615)) {
$e56145615.pyretStack.push(L[615]);
}
throw $e56145615;
}
var $ret56205621 = $Hanf_arg15975625($z56165617,_plus7);
++R.GAS;
return $ret56205621;
};
var $Hanf_arg15975625 = function(anf_arg3225624,_plus7) {
var $z56285629 = D;
var $f56345635 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("e-bind"),anf_arg3225624):R.ffi.throwNonFunApp(L[615],_plus7,[("e-bind"),anf_arg3225624]);
};
try {
if(--R.GAS > 0) {
$z56285629 = $f56345635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56345635,
"from":L[615]});
}
} catch($e56265627) {
if(R.isCont($e56265627)) {
var $ss56305631 = {"from":L[615],
"go":function(ann_DASH_check_DASH_temp3105636) {
return $Hann_DASH_check_DASH_temp15965637(ann_DASH_check_DASH_temp3105636);
}};
$e56265627.stack[R.EXN_STACKHEIGHT++] = $ss56305631;
}
if(R.isPyretException($e56265627)) {
$e56265627.pyretStack.push(L[615]);
}
throw $e56265627;
}
var $ret56325633 = $Hann_DASH_check_DASH_temp15965637($z56285629);
++R.GAS;
return $ret56325633;
};
var $Hann_DASH_check_DASH_temp15965637 = function(ann_DASH_check_DASH_temp3105636) {
return ann_DASH_check_DASH_temp3105636;
};
var $Hcont_tail_arg15945638 = function(cont_tail_arg3075639,if_helper2975640) {
if(--R.GAS > 0) {
$z56415642 = R.isFunction(if_helper2975640)?if_helper2975640.app(cont_tail_arg3075639):R.ffi.throwNonFunApp(L[615],if_helper2975640,[cont_tail_arg3075639]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2975640)?if_helper2975640.app(cont_tail_arg3075639):R.ffi.throwNonFunApp(L[615],if_helper2975640,[cont_tail_arg3075639]);
},
"from":L[615]});
}
++R.GAS;
return $z56415642;
};
var $Hcont_tail_arg15955643 = function(cont_tail_arg3025644,if_helper2975640) {
if(--R.GAS > 0) {
$z56455646 = R.isFunction(if_helper2975640)?if_helper2975640.app(cont_tail_arg3025644):R.ffi.throwNonFunApp(L[615],if_helper2975640,[cont_tail_arg3025644]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2975640)?if_helper2975640.app(cont_tail_arg3025644):R.ffi.throwNonFunApp(L[615],if_helper2975640,[cont_tail_arg3025644]);
},
"from":L[615]});
}
++R.GAS;
return $z56455646;
};
var $Hcont_tail_arg15925647 = function(cont_tail_arg2765648,if_helper2695649) {
if(--R.GAS > 0) {
$z56505651 = R.isFunction(if_helper2695649)?if_helper2695649.app(cont_tail_arg2765648):R.ffi.throwNonFunApp(L[616],if_helper2695649,[cont_tail_arg2765648]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2695649)?if_helper2695649.app(cont_tail_arg2765648):R.ffi.throwNonFunApp(L[616],if_helper2695649,[cont_tail_arg2765648]);
},
"from":L[616]});
}
++R.GAS;
return $z56505651;
};
var $Hcont_tail_arg15935652 = function(cont_tail_arg2745653,if_helper2695649) {
if(--R.GAS > 0) {
$z56545655 = R.isFunction(if_helper2695649)?if_helper2695649.app(cont_tail_arg2745653):R.ffi.throwNonFunApp(L[616],if_helper2695649,[cont_tail_arg2745653]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2695649)?if_helper2695649.app(cont_tail_arg2745653):R.ffi.throwNonFunApp(L[616],if_helper2695649,[cont_tail_arg2745653]);
},
"from":L[616]});
}
++R.GAS;
return $z56545655;
};
var $Hcont_tail_arg15905656 = function(cont_tail_arg2635657,if_helper2565658) {
if(--R.GAS > 0) {
$z56595660 = R.isFunction(if_helper2565658)?if_helper2565658.app(cont_tail_arg2635657):R.ffi.throwNonFunApp(L[617],if_helper2565658,[cont_tail_arg2635657]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2565658)?if_helper2565658.app(cont_tail_arg2635657):R.ffi.throwNonFunApp(L[617],if_helper2565658,[cont_tail_arg2635657]);
},
"from":L[617]});
}
++R.GAS;
return $z56595660;
};
var $Hcont_tail_arg15915661 = function(cont_tail_arg2615662,if_helper2565658) {
if(--R.GAS > 0) {
$z56635664 = R.isFunction(if_helper2565658)?if_helper2565658.app(cont_tail_arg2615662):R.ffi.throwNonFunApp(L[617],if_helper2565658,[cont_tail_arg2615662]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2565658)?if_helper2565658.app(cont_tail_arg2615662):R.ffi.throwNonFunApp(L[617],if_helper2565658,[cont_tail_arg2615662]);
},
"from":L[617]});
}
++R.GAS;
return $z56635664;
};
var $Hanf_arg15895665 = function(anf_arg2475666,self425667,_plus7,torepr13) {
var anf_arg2485678 = G(self425667,"name",L[618]);
var $z56705671 = D;
var $f56765677 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg2485678):R.ffi.throwNonFunApp(L[618],torepr13,[anf_arg2485678]);
};
try {
if(--R.GAS > 0) {
$z56705671 = $f56765677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56765677,
"from":L[618]});
}
} catch($e56685669) {
if(R.isCont($e56685669)) {
var $ss56725673 = {"from":L[618],
"go":function(anf_arg2495679) {
return $Hanf_arg15885680(anf_arg2495679,anf_arg2475666,_plus7);
}};
$e56685669.stack[R.EXN_STACKHEIGHT++] = $ss56725673;
}
if(R.isPyretException($e56685669)) {
$e56685669.pyretStack.push(L[618]);
}
throw $e56685669;
}
var $ret56745675 = $Hanf_arg15885680($z56705671,anf_arg2475666,_plus7);
++R.GAS;
return $ret56745675;
};
var $Hanf_arg15885680 = function(anf_arg2495679,anf_arg2475666,_plus7) {
var $z56835684 = D;
var $f56895690 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg2495679):R.ffi.throwNonFunApp(L[618],_plus7,[(", "),anf_arg2495679]);
};
try {
if(--R.GAS > 0) {
$z56835684 = $f56895690();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56895690,
"from":L[618]});
}
} catch($e56815682) {
if(R.isCont($e56815682)) {
var $ss56855686 = {"from":L[618],
"go":function(anf_arg2505691) {
return $Hanf_arg15875692(anf_arg2505691,anf_arg2475666,_plus7);
}};
$e56815682.stack[R.EXN_STACKHEIGHT++] = $ss56855686;
}
if(R.isPyretException($e56815682)) {
$e56815682.pyretStack.push(L[618]);
}
throw $e56815682;
}
var $ret56875688 = $Hanf_arg15875692($z56835684,anf_arg2475666,_plus7);
++R.GAS;
return $ret56875688;
};
var $Hanf_arg15875692 = function(anf_arg2505691,anf_arg2475666,_plus7) {
var $z56955696 = D;
var $f57015702 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg2475666,anf_arg2505691):R.ffi.throwNonFunApp(L[618],_plus7,[anf_arg2475666,anf_arg2505691]);
};
try {
if(--R.GAS > 0) {
$z56955696 = $f57015702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57015702,
"from":L[618]});
}
} catch($e56935694) {
if(R.isCont($e56935694)) {
var $ss56975698 = {"from":L[618],
"go":function(anf_arg2515703) {
return $Hanf_arg15865704(anf_arg2515703,_plus7);
}};
$e56935694.stack[R.EXN_STACKHEIGHT++] = $ss56975698;
}
if(R.isPyretException($e56935694)) {
$e56935694.pyretStack.push(L[618]);
}
throw $e56935694;
}
var $ret56995700 = $Hanf_arg15865704($z56955696,_plus7);
++R.GAS;
return $ret56995700;
};
var $Hanf_arg15865704 = function(anf_arg2515703,_plus7) {
var $z57075708 = D;
var $f57135714 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg2515703,(")")):R.ffi.throwNonFunApp(L[618],_plus7,[anf_arg2515703,(")")]);
};
try {
if(--R.GAS > 0) {
$z57075708 = $f57135714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57135714,
"from":L[618]});
}
} catch($e57055706) {
if(R.isCont($e57055706)) {
var $ss57095710 = {"from":L[618],
"go":function(anf_arg2525715) {
return $Hanf_arg15855716(anf_arg2525715,_plus7);
}};
$e57055706.stack[R.EXN_STACKHEIGHT++] = $ss57095710;
}
if(R.isPyretException($e57055706)) {
$e57055706.pyretStack.push(L[618]);
}
throw $e57055706;
}
var $ret57115712 = $Hanf_arg15855716($z57075708,_plus7);
++R.GAS;
return $ret57115712;
};
var $Hanf_arg15855716 = function(anf_arg2525715,_plus7) {
var $z57195720 = D;
var $f57255726 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg2525715):R.ffi.throwNonFunApp(L[618],_plus7,[("("),anf_arg2525715]);
};
try {
if(--R.GAS > 0) {
$z57195720 = $f57255726();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57255726,
"from":L[618]});
}
} catch($e57175718) {
if(R.isCont($e57175718)) {
var $ss57215722 = {"from":L[618],
"go":function(anf_arg2535727) {
return $Hanf_arg15845728(anf_arg2535727,_plus7);
}};
$e57175718.stack[R.EXN_STACKHEIGHT++] = $ss57215722;
}
if(R.isPyretException($e57175718)) {
$e57175718.pyretStack.push(L[618]);
}
throw $e57175718;
}
var $ret57235724 = $Hanf_arg15845728($z57195720,_plus7);
++R.GAS;
return $ret57235724;
};
var $Hanf_arg15845728 = function(anf_arg2535727,_plus7) {
var $z57315732 = D;
var $f57375738 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("b-dot"),anf_arg2535727):R.ffi.throwNonFunApp(L[618],_plus7,[("b-dot"),anf_arg2535727]);
};
try {
if(--R.GAS > 0) {
$z57315732 = $f57375738();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57375738,
"from":L[618]});
}
} catch($e57295730) {
if(R.isCont($e57295730)) {
var $ss57335734 = {"from":L[618],
"go":function(ann_DASH_check_DASH_temp2455739) {
return $Hann_DASH_check_DASH_temp15835740(ann_DASH_check_DASH_temp2455739);
}};
$e57295730.stack[R.EXN_STACKHEIGHT++] = $ss57335734;
}
if(R.isPyretException($e57295730)) {
$e57295730.pyretStack.push(L[618]);
}
throw $e57295730;
}
var $ret57355736 = $Hann_DASH_check_DASH_temp15835740($z57315732);
++R.GAS;
return $ret57355736;
};
var $Hann_DASH_check_DASH_temp15835740 = function(ann_DASH_check_DASH_temp2455739) {
return ann_DASH_check_DASH_temp2455739;
};
var $Hcont_tail_arg15815741 = function(cont_tail_arg2425742,if_helper2335743) {
if(--R.GAS > 0) {
$z57445745 = R.isFunction(if_helper2335743)?if_helper2335743.app(cont_tail_arg2425742):R.ffi.throwNonFunApp(L[618],if_helper2335743,[cont_tail_arg2425742]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2335743)?if_helper2335743.app(cont_tail_arg2425742):R.ffi.throwNonFunApp(L[618],if_helper2335743,[cont_tail_arg2425742]);
},
"from":L[618]});
}
++R.GAS;
return $z57445745;
};
var $Hcont_tail_arg15825746 = function(cont_tail_arg2385747,if_helper2335743) {
if(--R.GAS > 0) {
$z57485749 = R.isFunction(if_helper2335743)?if_helper2335743.app(cont_tail_arg2385747):R.ffi.throwNonFunApp(L[618],if_helper2335743,[cont_tail_arg2385747]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2335743)?if_helper2335743.app(cont_tail_arg2385747):R.ffi.throwNonFunApp(L[618],if_helper2335743,[cont_tail_arg2385747]);
},
"from":L[618]});
}
++R.GAS;
return $z57485749;
};
var $Hanf_arg15805750 = function(anf_arg2285751,_plus7) {
var $z57545755 = D;
var $f57605761 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg2285751,(")")):R.ffi.throwNonFunApp(L[619],_plus7,[anf_arg2285751,(")")]);
};
try {
if(--R.GAS > 0) {
$z57545755 = $f57605761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57605761,
"from":L[619]});
}
} catch($e57525753) {
if(R.isCont($e57525753)) {
var $ss57565757 = {"from":L[619],
"go":function(anf_arg2295762) {
return $Hanf_arg15795763(anf_arg2295762,_plus7);
}};
$e57525753.stack[R.EXN_STACKHEIGHT++] = $ss57565757;
}
if(R.isPyretException($e57525753)) {
$e57525753.pyretStack.push(L[619]);
}
throw $e57525753;
}
var $ret57585759 = $Hanf_arg15795763($z57545755,_plus7);
++R.GAS;
return $ret57585759;
};
var $Hanf_arg15795763 = function(anf_arg2295762,_plus7) {
var $z57665767 = D;
var $f57725773 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg2295762):R.ffi.throwNonFunApp(L[619],_plus7,[("("),anf_arg2295762]);
};
try {
if(--R.GAS > 0) {
$z57665767 = $f57725773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57725773,
"from":L[619]});
}
} catch($e57645765) {
if(R.isCont($e57645765)) {
var $ss57685769 = {"from":L[619],
"go":function(anf_arg2305774) {
return $Hanf_arg15785775(anf_arg2305774,_plus7);
}};
$e57645765.stack[R.EXN_STACKHEIGHT++] = $ss57685769;
}
if(R.isPyretException($e57645765)) {
$e57645765.pyretStack.push(L[619]);
}
throw $e57645765;
}
var $ret57705771 = $Hanf_arg15785775($z57665767,_plus7);
++R.GAS;
return $ret57705771;
};
var $Hanf_arg15785775 = function(anf_arg2305774,_plus7) {
var $z57785779 = D;
var $f57845785 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("b-exp"),anf_arg2305774):R.ffi.throwNonFunApp(L[619],_plus7,[("b-exp"),anf_arg2305774]);
};
try {
if(--R.GAS > 0) {
$z57785779 = $f57845785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57845785,
"from":L[619]});
}
} catch($e57765777) {
if(R.isCont($e57765777)) {
var $ss57805781 = {"from":L[619],
"go":function(ann_DASH_check_DASH_temp2265786) {
return $Hann_DASH_check_DASH_temp15775787(ann_DASH_check_DASH_temp2265786);
}};
$e57765777.stack[R.EXN_STACKHEIGHT++] = $ss57805781;
}
if(R.isPyretException($e57765777)) {
$e57765777.pyretStack.push(L[619]);
}
throw $e57765777;
}
var $ret57825783 = $Hann_DASH_check_DASH_temp15775787($z57785779);
++R.GAS;
return $ret57825783;
};
var $Hann_DASH_check_DASH_temp15775787 = function(ann_DASH_check_DASH_temp2265786) {
return ann_DASH_check_DASH_temp2265786;
};
var $Hcont_tail_arg15755788 = function(cont_tail_arg2235789,if_helper2155790) {
if(--R.GAS > 0) {
$z57915792 = R.isFunction(if_helper2155790)?if_helper2155790.app(cont_tail_arg2235789):R.ffi.throwNonFunApp(L[619],if_helper2155790,[cont_tail_arg2235789]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2155790)?if_helper2155790.app(cont_tail_arg2235789):R.ffi.throwNonFunApp(L[619],if_helper2155790,[cont_tail_arg2235789]);
},
"from":L[619]});
}
++R.GAS;
return $z57915792;
};
var $Hcont_tail_arg15765793 = function(cont_tail_arg2205794,if_helper2155790) {
if(--R.GAS > 0) {
$z57955796 = R.isFunction(if_helper2155790)?if_helper2155790.app(cont_tail_arg2205794):R.ffi.throwNonFunApp(L[619],if_helper2155790,[cont_tail_arg2205794]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2155790)?if_helper2155790.app(cont_tail_arg2205794):R.ffi.throwNonFunApp(L[619],if_helper2155790,[cont_tail_arg2205794]);
},
"from":L[619]});
}
++R.GAS;
return $z57955796;
};
var $Hanf_arg15745797 = function(anf_arg2105798,_plus7) {
var $z58015802 = D;
var $f58075808 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg2105798,(")")):R.ffi.throwNonFunApp(L[620],_plus7,[anf_arg2105798,(")")]);
};
try {
if(--R.GAS > 0) {
$z58015802 = $f58075808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58075808,
"from":L[620]});
}
} catch($e57995800) {
if(R.isCont($e57995800)) {
var $ss58035804 = {"from":L[620],
"go":function(anf_arg2115809) {
return $Hanf_arg15735810(anf_arg2115809,_plus7);
}};
$e57995800.stack[R.EXN_STACKHEIGHT++] = $ss58035804;
}
if(R.isPyretException($e57995800)) {
$e57995800.pyretStack.push(L[620]);
}
throw $e57995800;
}
var $ret58055806 = $Hanf_arg15735810($z58015802,_plus7);
++R.GAS;
return $ret58055806;
};
var $Hanf_arg15735810 = function(anf_arg2115809,_plus7) {
var $z58135814 = D;
var $f58195820 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg2115809):R.ffi.throwNonFunApp(L[620],_plus7,[("("),anf_arg2115809]);
};
try {
if(--R.GAS > 0) {
$z58135814 = $f58195820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58195820,
"from":L[620]});
}
} catch($e58115812) {
if(R.isCont($e58115812)) {
var $ss58155816 = {"from":L[620],
"go":function(anf_arg2125821) {
return $Hanf_arg15725822(anf_arg2125821,_plus7);
}};
$e58115812.stack[R.EXN_STACKHEIGHT++] = $ss58155816;
}
if(R.isPyretException($e58115812)) {
$e58115812.pyretStack.push(L[620]);
}
throw $e58115812;
}
var $ret58175818 = $Hanf_arg15725822($z58135814,_plus7);
++R.GAS;
return $ret58175818;
};
var $Hanf_arg15725822 = function(anf_arg2125821,_plus7) {
var $z58255826 = D;
var $f58315832 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("b-dict"),anf_arg2125821):R.ffi.throwNonFunApp(L[620],_plus7,[("b-dict"),anf_arg2125821]);
};
try {
if(--R.GAS > 0) {
$z58255826 = $f58315832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58315832,
"from":L[620]});
}
} catch($e58235824) {
if(R.isCont($e58235824)) {
var $ss58275828 = {"from":L[620],
"go":function(ann_DASH_check_DASH_temp2085833) {
return $Hann_DASH_check_DASH_temp15715834(ann_DASH_check_DASH_temp2085833);
}};
$e58235824.stack[R.EXN_STACKHEIGHT++] = $ss58275828;
}
if(R.isPyretException($e58235824)) {
$e58235824.pyretStack.push(L[620]);
}
throw $e58235824;
}
var $ret58295830 = $Hann_DASH_check_DASH_temp15715834($z58255826);
++R.GAS;
return $ret58295830;
};
var $Hann_DASH_check_DASH_temp15715834 = function(ann_DASH_check_DASH_temp2085833) {
return ann_DASH_check_DASH_temp2085833;
};
var $Hcont_tail_arg15695835 = function(cont_tail_arg2055836,if_helper1975837) {
if(--R.GAS > 0) {
$z58385839 = R.isFunction(if_helper1975837)?if_helper1975837.app(cont_tail_arg2055836):R.ffi.throwNonFunApp(L[620],if_helper1975837,[cont_tail_arg2055836]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1975837)?if_helper1975837.app(cont_tail_arg2055836):R.ffi.throwNonFunApp(L[620],if_helper1975837,[cont_tail_arg2055836]);
},
"from":L[620]});
}
++R.GAS;
return $z58385839;
};
var $Hcont_tail_arg15705840 = function(cont_tail_arg2025841,if_helper1975837) {
if(--R.GAS > 0) {
$z58425843 = R.isFunction(if_helper1975837)?if_helper1975837.app(cont_tail_arg2025841):R.ffi.throwNonFunApp(L[620],if_helper1975837,[cont_tail_arg2025841]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1975837)?if_helper1975837.app(cont_tail_arg2025841):R.ffi.throwNonFunApp(L[620],if_helper1975837,[cont_tail_arg2025841]);
},
"from":L[620]});
}
++R.GAS;
return $z58425843;
};
var $Hanf_arg15685844 = function(anf_arg1925845,_plus7) {
var $z58485849 = D;
var $f58545855 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg1925845,(")")):R.ffi.throwNonFunApp(L[621],_plus7,[anf_arg1925845,(")")]);
};
try {
if(--R.GAS > 0) {
$z58485849 = $f58545855();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58545855,
"from":L[621]});
}
} catch($e58465847) {
if(R.isCont($e58465847)) {
var $ss58505851 = {"from":L[621],
"go":function(anf_arg1935856) {
return $Hanf_arg15675857(anf_arg1935856,_plus7);
}};
$e58465847.stack[R.EXN_STACKHEIGHT++] = $ss58505851;
}
if(R.isPyretException($e58465847)) {
$e58465847.pyretStack.push(L[621]);
}
throw $e58465847;
}
var $ret58525853 = $Hanf_arg15675857($z58485849,_plus7);
++R.GAS;
return $ret58525853;
};
var $Hanf_arg15675857 = function(anf_arg1935856,_plus7) {
var $z58605861 = D;
var $f58665867 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg1935856):R.ffi.throwNonFunApp(L[621],_plus7,[("("),anf_arg1935856]);
};
try {
if(--R.GAS > 0) {
$z58605861 = $f58665867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58665867,
"from":L[621]});
}
} catch($e58585859) {
if(R.isCont($e58585859)) {
var $ss58625863 = {"from":L[621],
"go":function(anf_arg1945868) {
return $Hanf_arg15665869(anf_arg1945868,_plus7);
}};
$e58585859.stack[R.EXN_STACKHEIGHT++] = $ss58625863;
}
if(R.isPyretException($e58585859)) {
$e58585859.pyretStack.push(L[621]);
}
throw $e58585859;
}
var $ret58645865 = $Hanf_arg15665869($z58605861,_plus7);
++R.GAS;
return $ret58645865;
};
var $Hanf_arg15665869 = function(anf_arg1945868,_plus7) {
var $z58725873 = D;
var $f58785879 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("b-prim"),anf_arg1945868):R.ffi.throwNonFunApp(L[621],_plus7,[("b-prim"),anf_arg1945868]);
};
try {
if(--R.GAS > 0) {
$z58725873 = $f58785879();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58785879,
"from":L[621]});
}
} catch($e58705871) {
if(R.isCont($e58705871)) {
var $ss58745875 = {"from":L[621],
"go":function(ann_DASH_check_DASH_temp1905880) {
return $Hann_DASH_check_DASH_temp15655881(ann_DASH_check_DASH_temp1905880);
}};
$e58705871.stack[R.EXN_STACKHEIGHT++] = $ss58745875;
}
if(R.isPyretException($e58705871)) {
$e58705871.pyretStack.push(L[621]);
}
throw $e58705871;
}
var $ret58765877 = $Hann_DASH_check_DASH_temp15655881($z58725873);
++R.GAS;
return $ret58765877;
};
var $Hann_DASH_check_DASH_temp15655881 = function(ann_DASH_check_DASH_temp1905880) {
return ann_DASH_check_DASH_temp1905880;
};
var $Hcont_tail_arg15635882 = function(cont_tail_arg1875883,if_helper1795884) {
if(--R.GAS > 0) {
$z58855886 = R.isFunction(if_helper1795884)?if_helper1795884.app(cont_tail_arg1875883):R.ffi.throwNonFunApp(L[621],if_helper1795884,[cont_tail_arg1875883]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1795884)?if_helper1795884.app(cont_tail_arg1875883):R.ffi.throwNonFunApp(L[621],if_helper1795884,[cont_tail_arg1875883]);
},
"from":L[621]});
}
++R.GAS;
return $z58855886;
};
var $Hcont_tail_arg15645887 = function(cont_tail_arg1845888,if_helper1795884) {
if(--R.GAS > 0) {
$z58895890 = R.isFunction(if_helper1795884)?if_helper1795884.app(cont_tail_arg1845888):R.ffi.throwNonFunApp(L[621],if_helper1795884,[cont_tail_arg1845888]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1795884)?if_helper1795884.app(cont_tail_arg1845888):R.ffi.throwNonFunApp(L[621],if_helper1795884,[cont_tail_arg1845888]);
},
"from":L[621]});
}
++R.GAS;
return $z58895890;
};
var $Hanf_begin_app_dropped15625891 = function(anf_begin_app_dropped15615892,count1345893) {
var ann_DASH_check_DASH_temp1565894 = count1345893.$var;
return ann_DASH_check_DASH_temp1565894;
};
var $Hanf_assign15605895 = function(anf_assign1595896,args1395897,count1345893,f1385898,self1365899) {
count1345893.$var = anf_assign1595896;
var anf_fun1605910 = G(f1385898,"visit",L[623]);
var $z59025903 = D;
var $f59085909 = function(_) {
return R.isFunction(anf_fun1605910)?anf_fun1605910.app(self1365899):R.ffi.throwNonFunApp(L[622],anf_fun1605910,[self1365899]);
};
try {
if(--R.GAS > 0) {
$z59025903 = $f59085909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59085909,
"from":L[622]});
}
} catch($e59005901) {
if(R.isCont($e59005901)) {
var $ss59045905 = {"from":L[622],
"go":function(and_DASH_oper_DASH_175911) {
return $Hand_DASH_oper_DASH_15595912(and_DASH_oper_DASH_175911,args1395897,self1365899);
}};
$e59005901.stack[R.EXN_STACKHEIGHT++] = $ss59045905;
}
if(R.isPyretException($e59005901)) {
$e59005901.pyretStack.push(L[622]);
}
throw $e59005901;
}
var $ret59065907 = $Hand_DASH_oper_DASH_15595912($z59025903,args1395897,self1365899);
++R.GAS;
return $ret59065907;
};
var $Hand_DASH_oper_DASH_15595912 = function(and_DASH_oper_DASH_175911,args1395897,self1365899) {
var if_helper1615926 = R.makeFunction(function(if_helper_arg1625958) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[622],1,arguments);
}
var ann_DASH_check_DASH_temp1585959 = if_helper_arg1625958;
return ann_DASH_check_DASH_temp1585959;
});
var anf_if1655957 = R.isBoolean(and_DASH_oper_DASH_175911);
if(R.isPyretTrue(anf_if1655957)) {
if(R.isPyretTrue(and_DASH_oper_DASH_175911)) {
var anf_fun1675923 = G(args1395897,"map",L[625]);
var anf_arg1705924 = R.makeFunction(function(recv_DASH_195928) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[624],1,arguments);
}
var anf_fun1695939 = G(recv_DASH_195928,"visit",L[624]);
var $z59315932 = D;
var $f59375938 = function(_) {
return R.isFunction(anf_fun1695939)?anf_fun1695939.app(self1365899):R.ffi.throwNonFunApp(L[624],anf_fun1695939,[self1365899]);
};
try {
if(--R.GAS > 0) {
$z59315932 = $f59375938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59375938,
"from":L[624]});
}
} catch($e59295930) {
if(R.isCont($e59295930)) {
var $ss59335934 = {"from":L[624],
"go":function(ann_DASH_check_DASH_temp1685940) {
return $Hann_DASH_check_DASH_temp15555941(ann_DASH_check_DASH_temp1685940);
}};
$e59295930.stack[R.EXN_STACKHEIGHT++] = $ss59335934;
}
if(R.isPyretException($e59295930)) {
$e59295930.pyretStack.push(L[624]);
}
throw $e59295930;
}
var $ret59355936 = $Hann_DASH_check_DASH_temp15555941($z59315932);
++R.GAS;
return $ret59355936;
});
var $z59155916 = D;
var $f59215922 = function(_) {
return R.isFunction(anf_fun1675923)?anf_fun1675923.app(anf_arg1705924):R.ffi.throwNonFunApp(L[622],anf_fun1675923,[anf_arg1705924]);
};
try {
if(--R.GAS > 0) {
$z59155916 = $f59215922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59215922,
"from":L[622]});
}
} catch($e59135914) {
if(R.isCont($e59135914)) {
var $ss59175918 = {"from":L[622],
"go":function(and_DASH_oper_DASH_185925) {
return $Hand_DASH_oper_DASH_15575927(and_DASH_oper_DASH_185925,if_helper1615926);
}};
$e59135914.stack[R.EXN_STACKHEIGHT++] = $ss59175918;
}
if(R.isPyretException($e59135914)) {
$e59135914.pyretStack.push(L[622]);
}
throw $e59135914;
}
var $ret59195920 = $Hand_DASH_oper_DASH_15575927($z59155916,if_helper1615926);
++R.GAS;
return $ret59195920;
} else {
var $z59445945 = D;
var $f59505951 = function(_) {
return R.isFunction(if_helper1615926)?if_helper1615926.app((false)):R.ffi.throwNonFunApp(L[622],if_helper1615926,[(false)]);
};
try {
if(--R.GAS > 0) {
$z59445945 = $f59505951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59505951,
"from":L[622]});
}
} catch($e59425943) {
if(R.isCont($e59425943)) {
var $ss59465947 = {"from":L[622],
"go":function(cont_tail_app1665952) {
return $Hcont_tail_app15585953(cont_tail_app1665952);
}};
$e59425943.stack[R.EXN_STACKHEIGHT++] = $ss59465947;
}
if(R.isPyretException($e59425943)) {
$e59425943.pyretStack.push(L[622]);
}
throw $e59425943;
}
var $ret59485949 = $Hcont_tail_app15585953($z59445945);
++R.GAS;
return $ret59485949;
}
} else {
var cont_tail_arg1635956 = R.throwNonBooleanOp(L[626],("first"),("and"),and_DASH_oper_DASH_175911);
if(--R.GAS > 0) {
$z59545955 = R.isFunction(if_helper1615926)?if_helper1615926.app(cont_tail_arg1635956):R.ffi.throwNonFunApp(L[626],if_helper1615926,[cont_tail_arg1635956]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1615926)?if_helper1615926.app(cont_tail_arg1635956):R.ffi.throwNonFunApp(L[626],if_helper1615926,[cont_tail_arg1635956]);
},
"from":L[626]});
}
++R.GAS;
return $z59545955;
}
};
var $Hand_DASH_oper_DASH_15575927 = function(and_DASH_oper_DASH_185925,if_helper1615926) {
var anf_if1735975 = R.isBoolean(and_DASH_oper_DASH_185925);
if(R.isPyretTrue(anf_if1735975)) {
var $z59625963 = D;
var $f59685969 = function(_) {
return R.isFunction(if_helper1615926)?if_helper1615926.app(and_DASH_oper_DASH_185925):R.ffi.throwNonFunApp(L[622],if_helper1615926,[and_DASH_oper_DASH_185925]);
};
try {
if(--R.GAS > 0) {
$z59625963 = $f59685969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59685969,
"from":L[622]});
}
} catch($e59605961) {
if(R.isCont($e59605961)) {
var $ss59645965 = {"from":L[622],
"go":function(cont_tail_app1745970) {
return $Hcont_tail_app15565971(cont_tail_app1745970);
}};
$e59605961.stack[R.EXN_STACKHEIGHT++] = $ss59645965;
}
if(R.isPyretException($e59605961)) {
$e59605961.pyretStack.push(L[622]);
}
throw $e59605961;
}
var $ret59665967 = $Hcont_tail_app15565971($z59625963);
++R.GAS;
return $ret59665967;
} else {
var cont_tail_arg1715974 = R.throwNonBooleanOp(L[627],("second"),("and"),and_DASH_oper_DASH_185925);
if(--R.GAS > 0) {
$z59725973 = R.isFunction(if_helper1615926)?if_helper1615926.app(cont_tail_arg1715974):R.ffi.throwNonFunApp(L[627],if_helper1615926,[cont_tail_arg1715974]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1615926)?if_helper1615926.app(cont_tail_arg1715974):R.ffi.throwNonFunApp(L[627],if_helper1615926,[cont_tail_arg1715974]);
},
"from":L[627]});
}
++R.GAS;
return $z59725973;
}
};
var $Hcont_tail_app15565971 = function(cont_tail_app1745970) {
return cont_tail_app1745970;
};
var $Hann_DASH_check_DASH_temp15555941 = function(ann_DASH_check_DASH_temp1685940) {
return ann_DASH_check_DASH_temp1685940;
};
var $Hcont_tail_app15585953 = function(cont_tail_app1665952) {
return cont_tail_app1665952;
};
var $Hanf_arg15545976 = function(anf_arg1515977,A317,anf_arg1495978,fold593614,l995979,stmts1005980) {
var $z59835984 = D;
var $f59895990 = function(_) {
return R.isFunction(fold593614)?fold593614.app(anf_arg1495978,anf_arg1515977,stmts1005980):R.ffi.throwNonFunApp(L[628],fold593614,[anf_arg1495978,anf_arg1515977,stmts1005980]);
};
try {
if(--R.GAS > 0) {
$z59835984 = $f59895990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59895990,
"from":L[628]});
}
} catch($e59815982) {
if(R.isCont($e59815982)) {
var $ss59855986 = {"from":L[628],
"go":function(merged_DASH_stmts1015991) {
return $Hmerged_DASH_stmts15535992(merged_DASH_stmts1015991,A317,l995979);
}};
$e59815982.stack[R.EXN_STACKHEIGHT++] = $ss59855986;
}
if(R.isPyretException($e59815982)) {
$e59815982.pyretStack.push(L[628]);
}
throw $e59815982;
}
var $ret59875988 = $Hmerged_DASH_stmts15535992($z59835984,A317,l995979);
++R.GAS;
return $ret59875988;
};
var $Hmerged_DASH_stmts15535992 = function(merged_DASH_stmts1015991,A317,l995979) {
var anf_fun1526005 = G(A317,"s-block",L[631]);
var anf_fun1536003 = G(merged_DASH_stmts1015991,"reverse",L[630]);
var $z59955996 = D;
var $f60016002 = function(_) {
return R.isFunction(anf_fun1536003)?anf_fun1536003.app():R.ffi.throwNonFunApp(L[629],anf_fun1536003,[]);
};
try {
if(--R.GAS > 0) {
$z59955996 = $f60016002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60016002,
"from":L[629]});
}
} catch($e59935994) {
if(R.isCont($e59935994)) {
var $ss59975998 = {"from":L[629],
"go":function(anf_arg1546004) {
return $Hanf_arg15526006(anf_arg1546004,anf_fun1526005,l995979);
}};
$e59935994.stack[R.EXN_STACKHEIGHT++] = $ss59975998;
}
if(R.isPyretException($e59935994)) {
$e59935994.pyretStack.push(L[629]);
}
throw $e59935994;
}
var $ret59996000 = $Hanf_arg15526006($z59955996,anf_fun1526005,l995979);
++R.GAS;
return $ret59996000;
};
var $Hanf_arg15526006 = function(anf_arg1546004,anf_fun1526005,l995979) {
var $z60096010 = D;
var $f60156016 = function(_) {
return R.isFunction(anf_fun1526005)?anf_fun1526005.app(l995979,anf_arg1546004):R.ffi.throwNonFunApp(L[632],anf_fun1526005,[l995979,anf_arg1546004]);
};
try {
if(--R.GAS > 0) {
$z60096010 = $f60156016();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60156016,
"from":L[632]});
}
} catch($e60076008) {
if(R.isCont($e60076008)) {
var $ss60116012 = {"from":L[632],
"go":function(ann_DASH_check_DASH_temp1366017) {
return $Hann_DASH_check_DASH_temp15516018(ann_DASH_check_DASH_temp1366017);
}};
$e60076008.stack[R.EXN_STACKHEIGHT++] = $ss60116012;
}
if(R.isPyretException($e60076008)) {
$e60076008.pyretStack.push(L[632]);
}
throw $e60076008;
}
var $ret60136014 = $Hann_DASH_check_DASH_temp15516018($z60096010);
++R.GAS;
return $ret60136014;
};
var $Hann_DASH_check_DASH_temp15516018 = function(ann_DASH_check_DASH_temp1366017) {
return ann_DASH_check_DASH_temp1366017;
};
var $Hcases_DASH_val15506019 = function(cases_DASH_val166020,list3192,new_DASH_stmts1026021,s1036022,_plus7) {
var anf_fun1396033 = G(cases_DASH_val166020,"_match",L[634]);
var anf_obj1436051 = R.makeFunction(function(l21046052,stmts21056053) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[636],2,arguments);
}
var anf_fun1416064 = G(stmts21056053,"reverse",L[638]);
var $z60566057 = D;
var $f60626063 = function(_) {
return R.isFunction(anf_fun1416064)?anf_fun1416064.app():R.ffi.throwNonFunApp(L[637],anf_fun1416064,[]);
};
try {
if(--R.GAS > 0) {
$z60566057 = $f60626063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60626063,
"from":L[637]});
}
} catch($e60546055) {
if(R.isCont($e60546055)) {
var $ss60586059 = {"from":L[637],
"go":function(anf_arg1426065) {
return $Hanf_arg15466066(anf_arg1426065,new_DASH_stmts1026021,_plus7);
}};
$e60546055.stack[R.EXN_STACKHEIGHT++] = $ss60586059;
}
if(R.isPyretException($e60546055)) {
$e60546055.pyretStack.push(L[637]);
}
throw $e60546055;
}
var $ret60606061 = $Hanf_arg15466066($z60566057,new_DASH_stmts1026021,_plus7);
++R.GAS;
return $ret60606061;
});
var anf_arg1446034 = R.makeObject({"s-block":anf_obj1436051});
var anf_arg1486035 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[634],0,arguments);
}
var anf_fun1466048 = G(list3192,"make",L[635]);
var $z60406041 = D;
var $f60466047 = function(_) {
return R.isFunction(anf_fun1466048)?anf_fun1466048.app([s1036022]):R.ffi.throwNonFunApp(L[635],anf_fun1466048,[[s1036022]]);
};
try {
if(--R.GAS > 0) {
$z60406041 = $f60466047();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60466047,
"from":L[635]});
}
} catch($e60386039) {
if(R.isCont($e60386039)) {
var $ss60426043 = {"from":L[635],
"go":function(anf_arg1476049) {
return $Hanf_arg15486050(anf_arg1476049,new_DASH_stmts1026021,_plus7);
}};
$e60386039.stack[R.EXN_STACKHEIGHT++] = $ss60426043;
}
if(R.isPyretException($e60386039)) {
$e60386039.pyretStack.push(L[635]);
}
throw $e60386039;
}
var $ret60446045 = $Hanf_arg15486050($z60406041,new_DASH_stmts1026021,_plus7);
++R.GAS;
return $ret60446045;
});
var $z60256026 = D;
var $f60316032 = function(_) {
return R.isFunction(anf_fun1396033)?anf_fun1396033.app(anf_arg1446034,anf_arg1486035):R.ffi.throwNonFunApp(L[633],anf_fun1396033,[anf_arg1446034,anf_arg1486035]);
};
try {
if(--R.GAS > 0) {
$z60256026 = $f60316032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60316032,
"from":L[633]});
}
} catch($e60236024) {
if(R.isCont($e60236024)) {
var $ss60276028 = {"from":L[633],
"go":function(ann_DASH_check_DASH_temp1376036) {
return $Hann_DASH_check_DASH_temp15496037(ann_DASH_check_DASH_temp1376036);
}};
$e60236024.stack[R.EXN_STACKHEIGHT++] = $ss60276028;
}
if(R.isPyretException($e60236024)) {
$e60236024.pyretStack.push(L[633]);
}
throw $e60236024;
}
var $ret60296030 = $Hann_DASH_check_DASH_temp15496037($z60256026);
++R.GAS;
return $ret60296030;
};
var $Hann_DASH_check_DASH_temp15496037 = function(ann_DASH_check_DASH_temp1376036) {
return ann_DASH_check_DASH_temp1376036;
};
var $Hanf_arg15486050 = function(anf_arg1476049,new_DASH_stmts1026021,_plus7) {
var $z60696070 = D;
var $f60756076 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg1476049,new_DASH_stmts1026021):R.ffi.throwNonFunApp(L[634],_plus7,[anf_arg1476049,new_DASH_stmts1026021]);
};
try {
if(--R.GAS > 0) {
$z60696070 = $f60756076();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60756076,
"from":L[634]});
}
} catch($e60676068) {
if(R.isCont($e60676068)) {
var $ss60716072 = {"from":L[634],
"go":function(ann_DASH_check_DASH_temp1456077) {
return $Hann_DASH_check_DASH_temp15476078(ann_DASH_check_DASH_temp1456077);
}};
$e60676068.stack[R.EXN_STACKHEIGHT++] = $ss60716072;
}
if(R.isPyretException($e60676068)) {
$e60676068.pyretStack.push(L[634]);
}
throw $e60676068;
}
var $ret60736074 = $Hann_DASH_check_DASH_temp15476078($z60696070);
++R.GAS;
return $ret60736074;
};
var $Hann_DASH_check_DASH_temp15476078 = function(ann_DASH_check_DASH_temp1456077) {
return ann_DASH_check_DASH_temp1456077;
};
var $Hanf_arg15466066 = function(anf_arg1426065,new_DASH_stmts1026021,_plus7) {
var $z60816082 = D;
var $f60876088 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg1426065,new_DASH_stmts1026021):R.ffi.throwNonFunApp(L[636],_plus7,[anf_arg1426065,new_DASH_stmts1026021]);
};
try {
if(--R.GAS > 0) {
$z60816082 = $f60876088();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60876088,
"from":L[636]});
}
} catch($e60796080) {
if(R.isCont($e60796080)) {
var $ss60836084 = {"from":L[636],
"go":function(ann_DASH_check_DASH_temp1406089) {
return $Hann_DASH_check_DASH_temp15456090(ann_DASH_check_DASH_temp1406089);
}};
$e60796080.stack[R.EXN_STACKHEIGHT++] = $ss60836084;
}
if(R.isPyretException($e60796080)) {
$e60796080.pyretStack.push(L[636]);
}
throw $e60796080;
}
var $ret60856086 = $Hann_DASH_check_DASH_temp15456090($z60816082);
++R.GAS;
return $ret60856086;
};
var $Hann_DASH_check_DASH_temp15456090 = function(ann_DASH_check_DASH_temp1406089) {
return ann_DASH_check_DASH_temp1406089;
};
var $Hanf_arg15446091 = function(anf_arg1166092,A317,l956093,self946094,stmts966095) {
var if_DASH_156140 = R.equiv(anf_arg1166092,(1));
var if_helper1176108 = R.makeFunction(function(if_helper_arg1186145) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[646],1,arguments);
}
var ann_DASH_check_DASH_temp1146146 = if_helper_arg1186145;
return ann_DASH_check_DASH_temp1146146;
});
var anf_if1216144 = R.isBoolean(if_DASH_156140);
if(R.isPyretTrue(anf_if1216144)) {
if(R.isPyretTrue(if_DASH_156140)) {
var anf_bracket1306110 = G(stmts966095,"first",L[641]);
var anf_fun1316106 = G(anf_bracket1306110,"visit",L[640]);
var $z60986099 = D;
var $f61046105 = function(_) {
return R.isFunction(anf_fun1316106)?anf_fun1316106.app(self946094):R.ffi.throwNonFunApp(L[639],anf_fun1316106,[self946094]);
};
try {
if(--R.GAS > 0) {
$z60986099 = $f61046105();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61046105,
"from":L[639]});
}
} catch($e60966097) {
if(R.isCont($e60966097)) {
var $ss61006101 = {"from":L[639],
"go":function(cont_tail_arg1326107) {
return $Hcont_tail_arg15406109(cont_tail_arg1326107,if_helper1176108);
}};
$e60966097.stack[R.EXN_STACKHEIGHT++] = $ss61006101;
}
if(R.isPyretException($e60966097)) {
$e60966097.pyretStack.push(L[639]);
}
throw $e60966097;
}
var $ret61026103 = $Hcont_tail_arg15406109($z60986099,if_helper1176108);
++R.GAS;
return $ret61026103;
} else {
var anf_fun1226124 = G(A317,"s-block",L[645]);
var anf_fun1236121 = G(stmts966095,"map",L[644]);
var anf_arg1266122 = R.makeFunction(function(recv_DASH_146126) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[643],1,arguments);
}
var anf_fun1256137 = G(recv_DASH_146126,"visit",L[643]);
var $z61296130 = D;
var $f61356136 = function(_) {
return R.isFunction(anf_fun1256137)?anf_fun1256137.app(self946094):R.ffi.throwNonFunApp(L[643],anf_fun1256137,[self946094]);
};
try {
if(--R.GAS > 0) {
$z61296130 = $f61356136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61356136,
"from":L[643]});
}
} catch($e61276128) {
if(R.isCont($e61276128)) {
var $ss61316132 = {"from":L[643],
"go":function(ann_DASH_check_DASH_temp1246138) {
return $Hann_DASH_check_DASH_temp15416139(ann_DASH_check_DASH_temp1246138);
}};
$e61276128.stack[R.EXN_STACKHEIGHT++] = $ss61316132;
}
if(R.isPyretException($e61276128)) {
$e61276128.pyretStack.push(L[643]);
}
throw $e61276128;
}
var $ret61336134 = $Hann_DASH_check_DASH_temp15416139($z61296130);
++R.GAS;
return $ret61336134;
});
var $z61136114 = D;
var $f61196120 = function(_) {
return R.isFunction(anf_fun1236121)?anf_fun1236121.app(anf_arg1266122):R.ffi.throwNonFunApp(L[642],anf_fun1236121,[anf_arg1266122]);
};
try {
if(--R.GAS > 0) {
$z61136114 = $f61196120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61196120,
"from":L[642]});
}
} catch($e61116112) {
if(R.isCont($e61116112)) {
var $ss61156116 = {"from":L[642],
"go":function(anf_arg1276123) {
return $Hanf_arg15436125(anf_arg1276123,anf_fun1226124,if_helper1176108,l956093);
}};
$e61116112.stack[R.EXN_STACKHEIGHT++] = $ss61156116;
}
if(R.isPyretException($e61116112)) {
$e61116112.pyretStack.push(L[642]);
}
throw $e61116112;
}
var $ret61176118 = $Hanf_arg15436125($z61136114,anf_fun1226124,if_helper1176108,l956093);
++R.GAS;
return $ret61176118;
}
} else {
var cont_tail_arg1196143 = R.throwNonBooleanCondition(L[646],("if"),if_DASH_156140);
if(--R.GAS > 0) {
$z61416142 = R.isFunction(if_helper1176108)?if_helper1176108.app(cont_tail_arg1196143):R.ffi.throwNonFunApp(L[646],if_helper1176108,[cont_tail_arg1196143]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1176108)?if_helper1176108.app(cont_tail_arg1196143):R.ffi.throwNonFunApp(L[646],if_helper1176108,[cont_tail_arg1196143]);
},
"from":L[646]});
}
++R.GAS;
return $z61416142;
}
};
var $Hcont_tail_arg15406109 = function(cont_tail_arg1326107,if_helper1176108) {
if(--R.GAS > 0) {
$z61476148 = R.isFunction(if_helper1176108)?if_helper1176108.app(cont_tail_arg1326107):R.ffi.throwNonFunApp(L[639],if_helper1176108,[cont_tail_arg1326107]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1176108)?if_helper1176108.app(cont_tail_arg1326107):R.ffi.throwNonFunApp(L[639],if_helper1176108,[cont_tail_arg1326107]);
},
"from":L[639]});
}
++R.GAS;
return $z61476148;
};
var $Hanf_arg15436125 = function(anf_arg1276123,anf_fun1226124,if_helper1176108,l956093) {
var $z61516152 = D;
var $f61576158 = function(_) {
return R.isFunction(anf_fun1226124)?anf_fun1226124.app(l956093,anf_arg1276123):R.ffi.throwNonFunApp(L[647],anf_fun1226124,[l956093,anf_arg1276123]);
};
try {
if(--R.GAS > 0) {
$z61516152 = $f61576158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61576158,
"from":L[647]});
}
} catch($e61496150) {
if(R.isCont($e61496150)) {
var $ss61536154 = {"from":L[647],
"go":function(cont_tail_arg1286159) {
return $Hcont_tail_arg15426160(cont_tail_arg1286159,if_helper1176108);
}};
$e61496150.stack[R.EXN_STACKHEIGHT++] = $ss61536154;
}
if(R.isPyretException($e61496150)) {
$e61496150.pyretStack.push(L[647]);
}
throw $e61496150;
}
var $ret61556156 = $Hcont_tail_arg15426160($z61516152,if_helper1176108);
++R.GAS;
return $ret61556156;
};
var $Hcont_tail_arg15426160 = function(cont_tail_arg1286159,if_helper1176108) {
if(--R.GAS > 0) {
$z61616162 = R.isFunction(if_helper1176108)?if_helper1176108.app(cont_tail_arg1286159):R.ffi.throwNonFunApp(L[647],if_helper1176108,[cont_tail_arg1286159]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1176108)?if_helper1176108.app(cont_tail_arg1286159):R.ffi.throwNonFunApp(L[647],if_helper1176108,[cont_tail_arg1286159]);
},
"from":L[647]});
}
++R.GAS;
return $z61616162;
};
var $Hann_DASH_check_DASH_temp15416139 = function(ann_DASH_check_DASH_temp1246138) {
return ann_DASH_check_DASH_temp1246138;
};
var $Hann_DASH_check_DASH_temp15396163 = function(ann_DASH_check_DASH_temp616164,A428,Option245065) {
return ann_DASH_check_DASH_temp616164;
};
var $Hann_DASH_check_DASH_temp15386165 = function(ann_DASH_check_DASH_temp636166) {
return ann_DASH_check_DASH_temp636166;
};
var $Hann_DASH_check_DASH_temp15376167 = function(ann_DASH_check_DASH_temp656168) {
return ann_DASH_check_DASH_temp656168;
};
var $Hlast_DASH_stmt15366169 = function(last_DASH_stmt926170,A317,_provide_DASH_types856171,_provide846172,imports866173,l1836174,l2886175,list3192,none675099,ok_DASH_last7795,some685069,stmts896176,_plus7) {
var $z61796180 = D;
var $f61856186 = function(_) {
return R.isFunction(ok_DASH_last7795.$var)?ok_DASH_last7795.$var.app(last_DASH_stmt926170):R.ffi.throwNonFunApp(L[648],ok_DASH_last7795.$var,[last_DASH_stmt926170]);
};
try {
if(--R.GAS > 0) {
$z61796180 = $f61856186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61856186,
"from":L[648]});
}
} catch($e61776178) {
if(R.isCont($e61776178)) {
var $ss61816182 = {"from":L[648],
"go":function(if_DASH_106187) {
return $Hif_DASH_15356188(if_DASH_106187,A317,_provide_DASH_types856171,_provide846172,imports866173,l1836174,l2886175,list3192,none675099,some685069,stmts896176,_plus7);
}};
$e61776178.stack[R.EXN_STACKHEIGHT++] = $ss61816182;
}
if(R.isPyretException($e61776178)) {
$e61776178.pyretStack.push(L[648]);
}
throw $e61776178;
}
var $ret61836184 = $Hif_DASH_15356188($z61796180,A317,_provide_DASH_types856171,_provide846172,imports866173,l1836174,l2886175,list3192,none675099,some685069,stmts896176,_plus7);
++R.GAS;
return $ret61836184;
};
var $Hif_DASH_15356188 = function(if_DASH_106187,A317,_provide_DASH_types856171,_provide846172,imports866173,l1836174,l2886175,list3192,none675099,some685069,stmts896176,_plus7) {
var if_helper816199 = R.makeFunction(function(if_helper_arg826223) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[648],1,arguments);
}
var ann_DASH_check_DASH_temp796224 = if_helper_arg826223;
return ann_DASH_check_DASH_temp796224;
});
var anf_if856222 = R.isBoolean(if_DASH_106187);
if(R.isPyretTrue(anf_if856222)) {
if(R.isPyretTrue(if_DASH_106187)) {
var $z61916192 = D;
var $f61976198 = function(_) {
return R.isFunction(if_helper816199)?if_helper816199.app(none675099):R.ffi.throwNonFunApp(L[649],if_helper816199,[none675099]);
};
try {
if(--R.GAS > 0) {
$z61916192 = $f61976198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61976198,
"from":L[649]});
}
} catch($e61896190) {
if(R.isCont($e61896190)) {
var $ss61936194 = {"from":L[649],
"go":function(cont_tail_app996200) {
return $Hcont_tail_app15276201(cont_tail_app996200);
}};
$e61896190.stack[R.EXN_STACKHEIGHT++] = $ss61936194;
}
if(R.isPyretException($e61896190)) {
$e61896190.pyretStack.push(L[649]);
}
throw $e61896190;
}
var $ret61956196 = $Hcont_tail_app15276201($z61916192);
++R.GAS;
return $ret61956196;
} else {
var anf_fun866214 = G(A317,"s-program",L[655]);
var anf_fun876215 = G(A317,"s-block",L[654]);
var anf_fun886216 = G(list3192,"make",L[653]);
var anf_fun896217 = G(A317,"s-id",L[652]);
var anf_fun906212 = G(A317,"s-name",L[651]);
var $z62046205 = D;
var $f62106211 = function(_) {
return R.isFunction(anf_fun906212)?anf_fun906212.app(l2886175,("nothing")):R.ffi.throwNonFunApp(L[650],anf_fun906212,[l2886175,("nothing")]);
};
try {
if(--R.GAS > 0) {
$z62046205 = $f62106211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62106211,
"from":L[650]});
}
} catch($e62026203) {
if(R.isCont($e62026203)) {
var $ss62066207 = {"from":L[650],
"go":function(anf_arg916213) {
return $Hanf_arg15346218(anf_arg916213,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,anf_fun886216,anf_fun896217,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7);
}};
$e62026203.stack[R.EXN_STACKHEIGHT++] = $ss62066207;
}
if(R.isPyretException($e62026203)) {
$e62026203.pyretStack.push(L[650]);
}
throw $e62026203;
}
var $ret62086209 = $Hanf_arg15346218($z62046205,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,anf_fun886216,anf_fun896217,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7);
++R.GAS;
return $ret62086209;
}
} else {
var cont_tail_arg836221 = R.throwNonBooleanCondition(L[648],("if"),if_DASH_106187);
if(--R.GAS > 0) {
$z62196220 = R.isFunction(if_helper816199)?if_helper816199.app(cont_tail_arg836221):R.ffi.throwNonFunApp(L[648],if_helper816199,[cont_tail_arg836221]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper816199)?if_helper816199.app(cont_tail_arg836221):R.ffi.throwNonFunApp(L[648],if_helper816199,[cont_tail_arg836221]);
},
"from":L[648]});
}
++R.GAS;
return $z62196220;
}
};
var $Hcont_tail_app15276201 = function(cont_tail_app996200) {
return cont_tail_app996200;
};
var $Hanf_arg15346218 = function(anf_arg916213,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,anf_fun886216,anf_fun896217,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7) {
var $z62276228 = D;
var $f62336234 = function(_) {
return R.isFunction(anf_fun896217)?anf_fun896217.app(l2886175,anf_arg916213):R.ffi.throwNonFunApp(L[656],anf_fun896217,[l2886175,anf_arg916213]);
};
try {
if(--R.GAS > 0) {
$z62276228 = $f62336234();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62336234,
"from":L[656]});
}
} catch($e62256226) {
if(R.isCont($e62256226)) {
var $ss62296230 = {"from":L[656],
"go":function(anf_array_val926235) {
return $Hanf_array_val15336236(anf_array_val926235,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,anf_fun886216,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7);
}};
$e62256226.stack[R.EXN_STACKHEIGHT++] = $ss62296230;
}
if(R.isPyretException($e62256226)) {
$e62256226.pyretStack.push(L[656]);
}
throw $e62256226;
}
var $ret62316232 = $Hanf_array_val15336236($z62276228,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,anf_fun886216,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7);
++R.GAS;
return $ret62316232;
};
var $Hanf_array_val15336236 = function(anf_array_val926235,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,anf_fun886216,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7) {
var $z62396240 = D;
var $f62456246 = function(_) {
return R.isFunction(anf_fun886216)?anf_fun886216.app([anf_array_val926235]):R.ffi.throwNonFunApp(L[653],anf_fun886216,[[anf_array_val926235]]);
};
try {
if(--R.GAS > 0) {
$z62396240 = $f62456246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62456246,
"from":L[653]});
}
} catch($e62376238) {
if(R.isCont($e62376238)) {
var $ss62416242 = {"from":L[653],
"go":function(anf_arg936247) {
return $Hanf_arg15326248(anf_arg936247,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7);
}};
$e62376238.stack[R.EXN_STACKHEIGHT++] = $ss62416242;
}
if(R.isPyretException($e62376238)) {
$e62376238.pyretStack.push(L[653]);
}
throw $e62376238;
}
var $ret62436244 = $Hanf_arg15326248($z62396240,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7);
++R.GAS;
return $ret62436244;
};
var $Hanf_arg15326248 = function(anf_arg936247,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,if_helper816199,imports866173,l1836174,l2886175,some685069,stmts896176,_plus7) {
var $z62516252 = D;
var $f62576258 = function(_) {
return R.isFunction(_plus7)?_plus7.app(stmts896176,anf_arg936247):R.ffi.throwNonFunApp(L[657],_plus7,[stmts896176,anf_arg936247]);
};
try {
if(--R.GAS > 0) {
$z62516252 = $f62576258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62576258,
"from":L[657]});
}
} catch($e62496250) {
if(R.isCont($e62496250)) {
var $ss62536254 = {"from":L[657],
"go":function(anf_arg946259) {
return $Hanf_arg15316260(anf_arg946259,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,if_helper816199,imports866173,l1836174,l2886175,some685069);
}};
$e62496250.stack[R.EXN_STACKHEIGHT++] = $ss62536254;
}
if(R.isPyretException($e62496250)) {
$e62496250.pyretStack.push(L[657]);
}
throw $e62496250;
}
var $ret62556256 = $Hanf_arg15316260($z62516252,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,if_helper816199,imports866173,l1836174,l2886175,some685069);
++R.GAS;
return $ret62556256;
};
var $Hanf_arg15316260 = function(anf_arg946259,_provide_DASH_types856171,_provide846172,anf_fun866214,anf_fun876215,if_helper816199,imports866173,l1836174,l2886175,some685069) {
var $z62636264 = D;
var $f62696270 = function(_) {
return R.isFunction(anf_fun876215)?anf_fun876215.app(l2886175,anf_arg946259):R.ffi.throwNonFunApp(L[658],anf_fun876215,[l2886175,anf_arg946259]);
};
try {
if(--R.GAS > 0) {
$z62636264 = $f62696270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62696270,
"from":L[658]});
}
} catch($e62616262) {
if(R.isCont($e62616262)) {
var $ss62656266 = {"from":L[658],
"go":function(anf_arg956271) {
return $Hanf_arg15306272(anf_arg956271,_provide_DASH_types856171,_provide846172,anf_fun866214,if_helper816199,imports866173,l1836174,some685069);
}};
$e62616262.stack[R.EXN_STACKHEIGHT++] = $ss62656266;
}
if(R.isPyretException($e62616262)) {
$e62616262.pyretStack.push(L[658]);
}
throw $e62616262;
}
var $ret62676268 = $Hanf_arg15306272($z62636264,_provide_DASH_types856171,_provide846172,anf_fun866214,if_helper816199,imports866173,l1836174,some685069);
++R.GAS;
return $ret62676268;
};
var $Hanf_arg15306272 = function(anf_arg956271,_provide_DASH_types856171,_provide846172,anf_fun866214,if_helper816199,imports866173,l1836174,some685069) {
var $z62756276 = D;
var $f62816282 = function(_) {
return R.isFunction(anf_fun866214)?anf_fun866214.app(l1836174,_provide846172,_provide_DASH_types856171,imports866173,anf_arg956271):R.ffi.throwNonFunApp(L[659],anf_fun866214,[l1836174,_provide846172,_provide_DASH_types856171,imports866173,anf_arg956271]);
};
try {
if(--R.GAS > 0) {
$z62756276 = $f62816282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62816282,
"from":L[659]});
}
} catch($e62736274) {
if(R.isCont($e62736274)) {
var $ss62776278 = {"from":L[659],
"go":function(anf_arg966283) {
return $Hanf_arg15296284(anf_arg966283,if_helper816199,some685069);
}};
$e62736274.stack[R.EXN_STACKHEIGHT++] = $ss62776278;
}
if(R.isPyretException($e62736274)) {
$e62736274.pyretStack.push(L[659]);
}
throw $e62736274;
}
var $ret62796280 = $Hanf_arg15296284($z62756276,if_helper816199,some685069);
++R.GAS;
return $ret62796280;
};
var $Hanf_arg15296284 = function(anf_arg966283,if_helper816199,some685069) {
var $z62876288 = D;
var $f62936294 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg966283):R.ffi.throwNonFunApp(L[660],some685069,[anf_arg966283]);
};
try {
if(--R.GAS > 0) {
$z62876288 = $f62936294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62936294,
"from":L[660]});
}
} catch($e62856286) {
if(R.isCont($e62856286)) {
var $ss62896290 = {"from":L[660],
"go":function(cont_tail_arg976295) {
return $Hcont_tail_arg15286296(cont_tail_arg976295,if_helper816199);
}};
$e62856286.stack[R.EXN_STACKHEIGHT++] = $ss62896290;
}
if(R.isPyretException($e62856286)) {
$e62856286.pyretStack.push(L[660]);
}
throw $e62856286;
}
var $ret62916292 = $Hcont_tail_arg15286296($z62876288,if_helper816199);
++R.GAS;
return $ret62916292;
};
var $Hcont_tail_arg15286296 = function(cont_tail_arg976295,if_helper816199) {
if(--R.GAS > 0) {
$z62976298 = R.isFunction(if_helper816199)?if_helper816199.app(cont_tail_arg976295):R.ffi.throwNonFunApp(L[660],if_helper816199,[cont_tail_arg976295]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper816199)?if_helper816199.app(cont_tail_arg976295):R.ffi.throwNonFunApp(L[660],if_helper816199,[cont_tail_arg976295]);
},
"from":L[660]});
}
++R.GAS;
return $z62976298;
};
var $Hanf_arg15266299 = function(anf_arg736300,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,anf_fun706303,anf_fun716304,imports866173,l1836174,l2886175,some685069) {
var $z63076308 = D;
var $f63136314 = function(_) {
return R.isFunction(anf_fun716304)?anf_fun716304.app(l2886175,anf_arg736300):R.ffi.throwNonFunApp(L[661],anf_fun716304,[l2886175,anf_arg736300]);
};
try {
if(--R.GAS > 0) {
$z63076308 = $f63136314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63136314,
"from":L[661]});
}
} catch($e63056306) {
if(R.isCont($e63056306)) {
var $ss63096310 = {"from":L[661],
"go":function(anf_array_val746315) {
return $Hanf_array_val15256316(anf_array_val746315,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,anf_fun706303,imports866173,l1836174,l2886175,some685069);
}};
$e63056306.stack[R.EXN_STACKHEIGHT++] = $ss63096310;
}
if(R.isPyretException($e63056306)) {
$e63056306.pyretStack.push(L[661]);
}
throw $e63056306;
}
var $ret63116312 = $Hanf_array_val15256316($z63076308,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,anf_fun706303,imports866173,l1836174,l2886175,some685069);
++R.GAS;
return $ret63116312;
};
var $Hanf_array_val15256316 = function(anf_array_val746315,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,anf_fun706303,imports866173,l1836174,l2886175,some685069) {
var $z63196320 = D;
var $f63256326 = function(_) {
return R.isFunction(anf_fun706303)?anf_fun706303.app([anf_array_val746315]):R.ffi.throwNonFunApp(L[662],anf_fun706303,[[anf_array_val746315]]);
};
try {
if(--R.GAS > 0) {
$z63196320 = $f63256326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63256326,
"from":L[662]});
}
} catch($e63176318) {
if(R.isCont($e63176318)) {
var $ss63216322 = {"from":L[662],
"go":function(anf_arg756327) {
return $Hanf_arg15246328(anf_arg756327,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,imports866173,l1836174,l2886175,some685069);
}};
$e63176318.stack[R.EXN_STACKHEIGHT++] = $ss63216322;
}
if(R.isPyretException($e63176318)) {
$e63176318.pyretStack.push(L[662]);
}
throw $e63176318;
}
var $ret63236324 = $Hanf_arg15246328($z63196320,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,imports866173,l1836174,l2886175,some685069);
++R.GAS;
return $ret63236324;
};
var $Hanf_arg15246328 = function(anf_arg756327,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,imports866173,l1836174,l2886175,some685069) {
var $z63316332 = D;
var $f63376338 = function(_) {
return R.isFunction(anf_fun696302)?anf_fun696302.app(l2886175,anf_arg756327):R.ffi.throwNonFunApp(L[663],anf_fun696302,[l2886175,anf_arg756327]);
};
try {
if(--R.GAS > 0) {
$z63316332 = $f63376338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63376338,
"from":L[663]});
}
} catch($e63296330) {
if(R.isCont($e63296330)) {
var $ss63336334 = {"from":L[663],
"go":function(anf_arg766339) {
return $Hanf_arg15236340(anf_arg766339,_provide_DASH_types856171,_provide846172,anf_fun686301,imports866173,l1836174,some685069);
}};
$e63296330.stack[R.EXN_STACKHEIGHT++] = $ss63336334;
}
if(R.isPyretException($e63296330)) {
$e63296330.pyretStack.push(L[663]);
}
throw $e63296330;
}
var $ret63356336 = $Hanf_arg15236340($z63316332,_provide_DASH_types856171,_provide846172,anf_fun686301,imports866173,l1836174,some685069);
++R.GAS;
return $ret63356336;
};
var $Hanf_arg15236340 = function(anf_arg766339,_provide_DASH_types856171,_provide846172,anf_fun686301,imports866173,l1836174,some685069) {
var $z63436344 = D;
var $f63496350 = function(_) {
return R.isFunction(anf_fun686301)?anf_fun686301.app(l1836174,_provide846172,_provide_DASH_types856171,imports866173,anf_arg766339):R.ffi.throwNonFunApp(L[664],anf_fun686301,[l1836174,_provide846172,_provide_DASH_types856171,imports866173,anf_arg766339]);
};
try {
if(--R.GAS > 0) {
$z63436344 = $f63496350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63496350,
"from":L[664]});
}
} catch($e63416342) {
if(R.isCont($e63416342)) {
var $ss63456346 = {"from":L[664],
"go":function(anf_arg776351) {
return $Hanf_arg15226352(anf_arg776351,some685069);
}};
$e63416342.stack[R.EXN_STACKHEIGHT++] = $ss63456346;
}
if(R.isPyretException($e63416342)) {
$e63416342.pyretStack.push(L[664]);
}
throw $e63416342;
}
var $ret63476348 = $Hanf_arg15226352($z63436344,some685069);
++R.GAS;
return $ret63476348;
};
var $Hanf_arg15226352 = function(anf_arg776351,some685069) {
var $z63556356 = D;
var $f63616362 = function(_) {
return R.isFunction(some685069)?some685069.app(anf_arg776351):R.ffi.throwNonFunApp(L[665],some685069,[anf_arg776351]);
};
try {
if(--R.GAS > 0) {
$z63556356 = $f63616362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63616362,
"from":L[665]});
}
} catch($e63536354) {
if(R.isCont($e63536354)) {
var $ss63576358 = {"from":L[665],
"go":function(ann_DASH_check_DASH_temp676363) {
return $Hann_DASH_check_DASH_temp15216364(ann_DASH_check_DASH_temp676363);
}};
$e63536354.stack[R.EXN_STACKHEIGHT++] = $ss63576358;
}
if(R.isPyretException($e63536354)) {
$e63536354.pyretStack.push(L[665]);
}
throw $e63536354;
}
var $ret63596360 = $Hann_DASH_check_DASH_temp15216364($z63556356);
++R.GAS;
return $ret63596360;
};
var $Hann_DASH_check_DASH_temp15216364 = function(ann_DASH_check_DASH_temp676363) {
return ann_DASH_check_DASH_temp676363;
};
var $Hanf_arg15206365 = function(anf_arg556366,anf_fun516367,anf_fun526368,anf_fun536369,l816370,list3192) {
var $z63736374 = D;
var $f63796380 = function(_) {
return R.isFunction(anf_fun536369)?anf_fun536369.app(l816370,anf_arg556366):R.ffi.throwNonFunApp(L[666],anf_fun536369,[l816370,anf_arg556366]);
};
try {
if(--R.GAS > 0) {
$z63736374 = $f63796380();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63796380,
"from":L[666]});
}
} catch($e63716372) {
if(R.isCont($e63716372)) {
var $ss63756376 = {"from":L[666],
"go":function(anf_arg566381) {
return $Hanf_arg15196382(anf_arg566381,anf_fun516367,anf_fun526368,l816370,list3192);
}};
$e63716372.stack[R.EXN_STACKHEIGHT++] = $ss63756376;
}
if(R.isPyretException($e63716372)) {
$e63716372.pyretStack.push(L[666]);
}
throw $e63716372;
}
var $ret63776378 = $Hanf_arg15196382($z63736374,anf_fun516367,anf_fun526368,l816370,list3192);
++R.GAS;
return $ret63776378;
};
var $Hanf_arg15196382 = function(anf_arg566381,anf_fun516367,anf_fun526368,l816370,list3192) {
var $z63856386 = D;
var $f63916392 = function(_) {
return R.isFunction(anf_fun526368)?anf_fun526368.app(l816370,anf_arg566381,("current-checker")):R.ffi.throwNonFunApp(L[667],anf_fun526368,[l816370,anf_arg566381,("current-checker")]);
};
try {
if(--R.GAS > 0) {
$z63856386 = $f63916392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63916392,
"from":L[667]});
}
} catch($e63836384) {
if(R.isCont($e63836384)) {
var $ss63876388 = {"from":L[667],
"go":function(anf_arg576393) {
return $Hanf_arg15186394(anf_arg576393,anf_fun516367,l816370,list3192);
}};
$e63836384.stack[R.EXN_STACKHEIGHT++] = $ss63876388;
}
if(R.isPyretException($e63836384)) {
$e63836384.pyretStack.push(L[667]);
}
throw $e63836384;
}
var $ret63896390 = $Hanf_arg15186394($z63856386,anf_fun516367,l816370,list3192);
++R.GAS;
return $ret63896390;
};
var $Hanf_arg15186394 = function(anf_arg576393,anf_fun516367,l816370,list3192) {
var anf_fun586405 = G(list3192,"make",L[668]);
var $z63976398 = D;
var $f64036404 = function(_) {
return R.isFunction(anf_fun586405)?anf_fun586405.app([]):R.ffi.throwNonFunApp(L[668],anf_fun586405,[[]]);
};
try {
if(--R.GAS > 0) {
$z63976398 = $f64036404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64036404,
"from":L[668]});
}
} catch($e63956396) {
if(R.isCont($e63956396)) {
var $ss63996400 = {"from":L[668],
"go":function(anf_arg596406) {
return $Hanf_arg15176407(anf_arg596406,anf_arg576393,anf_fun516367,l816370);
}};
$e63956396.stack[R.EXN_STACKHEIGHT++] = $ss63996400;
}
if(R.isPyretException($e63956396)) {
$e63956396.pyretStack.push(L[668]);
}
throw $e63956396;
}
var $ret64016402 = $Hanf_arg15176407($z63976398,anf_arg576393,anf_fun516367,l816370);
++R.GAS;
return $ret64016402;
};
var $Hanf_arg15176407 = function(anf_arg596406,anf_arg576393,anf_fun516367,l816370) {
var $z64106411 = D;
var $f64166417 = function(_) {
return R.isFunction(anf_fun516367)?anf_fun516367.app(l816370,anf_arg576393,anf_arg596406):R.ffi.throwNonFunApp(L[669],anf_fun516367,[l816370,anf_arg576393,anf_arg596406]);
};
try {
if(--R.GAS > 0) {
$z64106411 = $f64166417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64166417,
"from":L[669]});
}
} catch($e64086409) {
if(R.isCont($e64086409)) {
var $ss64126413 = {"from":L[669],
"go":function(ann_DASH_check_DASH_temp506418) {
return $Hann_DASH_check_DASH_temp15166419(ann_DASH_check_DASH_temp506418);
}};
$e64086409.stack[R.EXN_STACKHEIGHT++] = $ss64126413;
}
if(R.isPyretException($e64086409)) {
$e64086409.pyretStack.push(L[669]);
}
throw $e64086409;
}
var $ret64146415 = $Hann_DASH_check_DASH_temp15166419($z64106411);
++R.GAS;
return $ret64146415;
};
var $Hann_DASH_check_DASH_temp15166419 = function(ann_DASH_check_DASH_temp506418) {
return ann_DASH_check_DASH_temp506418;
};
var $Hor_DASH_oper_DASH_15156420 = function(or_DASH_oper_DASH_16421,A317,stmt806422,not9) {
var if_helper36433 = R.makeFunction(function(if_helper_arg46453) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[670],1,arguments);
}
var $z64566457 = D;
var $f64626463 = function(_) {
return R.isFunction(not9)?not9.app(if_helper_arg46453):R.ffi.throwNonFunApp(L[673],not9,[if_helper_arg46453]);
};
try {
if(--R.GAS > 0) {
$z64566457 = $f64626463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64626463,
"from":L[673]});
}
} catch($e64546455) {
if(R.isCont($e64546455)) {
var $ss64586459 = {"from":L[673],
"go":function(ann_DASH_check_DASH_temp16464) {
return $Hann_DASH_check_DASH_temp14976465(ann_DASH_check_DASH_temp16464);
}};
$e64546455.stack[R.EXN_STACKHEIGHT++] = $ss64586459;
}
if(R.isPyretException($e64546455)) {
$e64546455.pyretStack.push(L[673]);
}
throw $e64546455;
}
var $ret64606461 = $Hann_DASH_check_DASH_temp14976465($z64566457);
++R.GAS;
return $ret64606461;
});
var anf_if76452 = R.isBoolean(or_DASH_oper_DASH_16421);
if(R.isPyretTrue(anf_if76452)) {
if(R.isPyretTrue(or_DASH_oper_DASH_16421)) {
var $z64256426 = D;
var $f64316432 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app((true)):R.ffi.throwNonFunApp(L[670],if_helper36433,[(true)]);
};
try {
if(--R.GAS > 0) {
$z64256426 = $f64316432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64316432,
"from":L[670]});
}
} catch($e64236424) {
if(R.isCont($e64236424)) {
var $ss64276428 = {"from":L[670],
"go":function(cont_tail_app486434) {
return $Hcont_tail_app14986435(cont_tail_app486434);
}};
$e64236424.stack[R.EXN_STACKHEIGHT++] = $ss64276428;
}
if(R.isPyretException($e64236424)) {
$e64236424.pyretStack.push(L[670]);
}
throw $e64236424;
}
var $ret64296430 = $Hcont_tail_app14986435($z64256426);
++R.GAS;
return $ret64296430;
} else {
var anf_fun86446 = G(A317,"is-s-var",L[671]);
var $z64386439 = D;
var $f64446445 = function(_) {
return R.isFunction(anf_fun86446)?anf_fun86446.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun86446,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z64386439 = $f64446445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64446445,
"from":L[670]});
}
} catch($e64366437) {
if(R.isCont($e64366437)) {
var $ss64406441 = {"from":L[670],
"go":function(or_DASH_oper_DASH_26447) {
return $Hor_DASH_oper_DASH_15146448(or_DASH_oper_DASH_26447,A317,if_helper36433,stmt806422);
}};
$e64366437.stack[R.EXN_STACKHEIGHT++] = $ss64406441;
}
if(R.isPyretException($e64366437)) {
$e64366437.pyretStack.push(L[670]);
}
throw $e64366437;
}
var $ret64426443 = $Hor_DASH_oper_DASH_15146448($z64386439,A317,if_helper36433,stmt806422);
++R.GAS;
return $ret64426443;
}
} else {
var cont_tail_arg56451 = R.throwNonBooleanOp(L[672],("first"),("or"),or_DASH_oper_DASH_16421);
if(--R.GAS > 0) {
$z64496450 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg56451):R.ffi.throwNonFunApp(L[672],if_helper36433,[cont_tail_arg56451]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg56451):R.ffi.throwNonFunApp(L[672],if_helper36433,[cont_tail_arg56451]);
},
"from":L[672]});
}
++R.GAS;
return $z64496450;
}
};
var $Hcont_tail_app14986435 = function(cont_tail_app486434) {
return cont_tail_app486434;
};
var $Hor_DASH_oper_DASH_15146448 = function(or_DASH_oper_DASH_26447,A317,if_helper36433,stmt806422) {
var anf_if116494 = R.isBoolean(or_DASH_oper_DASH_26447);
if(R.isPyretTrue(anf_if116494)) {
if(R.isPyretTrue(or_DASH_oper_DASH_26447)) {
var $z64686469 = D;
var $f64746475 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app((true)):R.ffi.throwNonFunApp(L[670],if_helper36433,[(true)]);
};
try {
if(--R.GAS > 0) {
$z64686469 = $f64746475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64746475,
"from":L[670]});
}
} catch($e64666467) {
if(R.isCont($e64666467)) {
var $ss64706471 = {"from":L[670],
"go":function(cont_tail_app476476) {
return $Hcont_tail_app14996477(cont_tail_app476476);
}};
$e64666467.stack[R.EXN_STACKHEIGHT++] = $ss64706471;
}
if(R.isPyretException($e64666467)) {
$e64666467.pyretStack.push(L[670]);
}
throw $e64666467;
}
var $ret64726473 = $Hcont_tail_app14996477($z64686469);
++R.GAS;
return $ret64726473;
} else {
var anf_fun126488 = G(A317,"is-s-fun",L[674]);
var $z64806481 = D;
var $f64866487 = function(_) {
return R.isFunction(anf_fun126488)?anf_fun126488.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun126488,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z64806481 = $f64866487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64866487,
"from":L[670]});
}
} catch($e64786479) {
if(R.isCont($e64786479)) {
var $ss64826483 = {"from":L[670],
"go":function(or_DASH_oper_DASH_36489) {
return $Hor_DASH_oper_DASH_15136490(or_DASH_oper_DASH_36489,A317,if_helper36433,stmt806422);
}};
$e64786479.stack[R.EXN_STACKHEIGHT++] = $ss64826483;
}
if(R.isPyretException($e64786479)) {
$e64786479.pyretStack.push(L[670]);
}
throw $e64786479;
}
var $ret64846485 = $Hor_DASH_oper_DASH_15136490($z64806481,A317,if_helper36433,stmt806422);
++R.GAS;
return $ret64846485;
}
} else {
var cont_tail_arg96493 = R.throwNonBooleanOp(L[675],("first"),("or"),or_DASH_oper_DASH_26447);
if(--R.GAS > 0) {
$z64916492 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg96493):R.ffi.throwNonFunApp(L[675],if_helper36433,[cont_tail_arg96493]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg96493):R.ffi.throwNonFunApp(L[675],if_helper36433,[cont_tail_arg96493]);
},
"from":L[675]});
}
++R.GAS;
return $z64916492;
}
};
var $Hcont_tail_app14996477 = function(cont_tail_app476476) {
return cont_tail_app476476;
};
var $Hor_DASH_oper_DASH_15136490 = function(or_DASH_oper_DASH_36489,A317,if_helper36433,stmt806422) {
var anf_if156523 = R.isBoolean(or_DASH_oper_DASH_36489);
if(R.isPyretTrue(anf_if156523)) {
if(R.isPyretTrue(or_DASH_oper_DASH_36489)) {
var $z64976498 = D;
var $f65036504 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app((true)):R.ffi.throwNonFunApp(L[670],if_helper36433,[(true)]);
};
try {
if(--R.GAS > 0) {
$z64976498 = $f65036504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65036504,
"from":L[670]});
}
} catch($e64956496) {
if(R.isCont($e64956496)) {
var $ss64996500 = {"from":L[670],
"go":function(cont_tail_app466505) {
return $Hcont_tail_app15006506(cont_tail_app466505);
}};
$e64956496.stack[R.EXN_STACKHEIGHT++] = $ss64996500;
}
if(R.isPyretException($e64956496)) {
$e64956496.pyretStack.push(L[670]);
}
throw $e64956496;
}
var $ret65016502 = $Hcont_tail_app15006506($z64976498);
++R.GAS;
return $ret65016502;
} else {
var anf_fun166517 = G(A317,"is-s-data",L[676]);
var $z65096510 = D;
var $f65156516 = function(_) {
return R.isFunction(anf_fun166517)?anf_fun166517.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun166517,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z65096510 = $f65156516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65156516,
"from":L[670]});
}
} catch($e65076508) {
if(R.isCont($e65076508)) {
var $ss65116512 = {"from":L[670],
"go":function(or_DASH_oper_DASH_46518) {
return $Hor_DASH_oper_DASH_15126519(or_DASH_oper_DASH_46518,A317,if_helper36433,stmt806422);
}};
$e65076508.stack[R.EXN_STACKHEIGHT++] = $ss65116512;
}
if(R.isPyretException($e65076508)) {
$e65076508.pyretStack.push(L[670]);
}
throw $e65076508;
}
var $ret65136514 = $Hor_DASH_oper_DASH_15126519($z65096510,A317,if_helper36433,stmt806422);
++R.GAS;
return $ret65136514;
}
} else {
var cont_tail_arg136522 = R.throwNonBooleanOp(L[677],("first"),("or"),or_DASH_oper_DASH_36489);
if(--R.GAS > 0) {
$z65206521 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg136522):R.ffi.throwNonFunApp(L[677],if_helper36433,[cont_tail_arg136522]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg136522):R.ffi.throwNonFunApp(L[677],if_helper36433,[cont_tail_arg136522]);
},
"from":L[677]});
}
++R.GAS;
return $z65206521;
}
};
var $Hcont_tail_app15006506 = function(cont_tail_app466505) {
return cont_tail_app466505;
};
var $Hor_DASH_oper_DASH_15126519 = function(or_DASH_oper_DASH_46518,A317,if_helper36433,stmt806422) {
var anf_if196552 = R.isBoolean(or_DASH_oper_DASH_46518);
if(R.isPyretTrue(anf_if196552)) {
if(R.isPyretTrue(or_DASH_oper_DASH_46518)) {
var $z65266527 = D;
var $f65326533 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app((true)):R.ffi.throwNonFunApp(L[670],if_helper36433,[(true)]);
};
try {
if(--R.GAS > 0) {
$z65266527 = $f65326533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65326533,
"from":L[670]});
}
} catch($e65246525) {
if(R.isCont($e65246525)) {
var $ss65286529 = {"from":L[670],
"go":function(cont_tail_app456534) {
return $Hcont_tail_app15016535(cont_tail_app456534);
}};
$e65246525.stack[R.EXN_STACKHEIGHT++] = $ss65286529;
}
if(R.isPyretException($e65246525)) {
$e65246525.pyretStack.push(L[670]);
}
throw $e65246525;
}
var $ret65306531 = $Hcont_tail_app15016535($z65266527);
++R.GAS;
return $ret65306531;
} else {
var anf_fun206546 = G(A317,"is-s-graph",L[678]);
var $z65386539 = D;
var $f65446545 = function(_) {
return R.isFunction(anf_fun206546)?anf_fun206546.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun206546,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z65386539 = $f65446545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65446545,
"from":L[670]});
}
} catch($e65366537) {
if(R.isCont($e65366537)) {
var $ss65406541 = {"from":L[670],
"go":function(or_DASH_oper_DASH_56547) {
return $Hor_DASH_oper_DASH_15116548(or_DASH_oper_DASH_56547,A317,if_helper36433,stmt806422);
}};
$e65366537.stack[R.EXN_STACKHEIGHT++] = $ss65406541;
}
if(R.isPyretException($e65366537)) {
$e65366537.pyretStack.push(L[670]);
}
throw $e65366537;
}
var $ret65426543 = $Hor_DASH_oper_DASH_15116548($z65386539,A317,if_helper36433,stmt806422);
++R.GAS;
return $ret65426543;
}
} else {
var cont_tail_arg176551 = R.throwNonBooleanOp(L[679],("first"),("or"),or_DASH_oper_DASH_46518);
if(--R.GAS > 0) {
$z65496550 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg176551):R.ffi.throwNonFunApp(L[679],if_helper36433,[cont_tail_arg176551]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg176551):R.ffi.throwNonFunApp(L[679],if_helper36433,[cont_tail_arg176551]);
},
"from":L[679]});
}
++R.GAS;
return $z65496550;
}
};
var $Hcont_tail_app15016535 = function(cont_tail_app456534) {
return cont_tail_app456534;
};
var $Hor_DASH_oper_DASH_15116548 = function(or_DASH_oper_DASH_56547,A317,if_helper36433,stmt806422) {
var anf_if236581 = R.isBoolean(or_DASH_oper_DASH_56547);
if(R.isPyretTrue(anf_if236581)) {
if(R.isPyretTrue(or_DASH_oper_DASH_56547)) {
var $z65556556 = D;
var $f65616562 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app((true)):R.ffi.throwNonFunApp(L[670],if_helper36433,[(true)]);
};
try {
if(--R.GAS > 0) {
$z65556556 = $f65616562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65616562,
"from":L[670]});
}
} catch($e65536554) {
if(R.isCont($e65536554)) {
var $ss65576558 = {"from":L[670],
"go":function(cont_tail_app446563) {
return $Hcont_tail_app15026564(cont_tail_app446563);
}};
$e65536554.stack[R.EXN_STACKHEIGHT++] = $ss65576558;
}
if(R.isPyretException($e65536554)) {
$e65536554.pyretStack.push(L[670]);
}
throw $e65536554;
}
var $ret65596560 = $Hcont_tail_app15026564($z65556556);
++R.GAS;
return $ret65596560;
} else {
var anf_fun246575 = G(A317,"is-s-contract",L[680]);
var $z65676568 = D;
var $f65736574 = function(_) {
return R.isFunction(anf_fun246575)?anf_fun246575.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun246575,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z65676568 = $f65736574();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65736574,
"from":L[670]});
}
} catch($e65656566) {
if(R.isCont($e65656566)) {
var $ss65696570 = {"from":L[670],
"go":function(or_DASH_oper_DASH_66576) {
return $Hor_DASH_oper_DASH_15106577(or_DASH_oper_DASH_66576,A317,if_helper36433,stmt806422);
}};
$e65656566.stack[R.EXN_STACKHEIGHT++] = $ss65696570;
}
if(R.isPyretException($e65656566)) {
$e65656566.pyretStack.push(L[670]);
}
throw $e65656566;
}
var $ret65716572 = $Hor_DASH_oper_DASH_15106577($z65676568,A317,if_helper36433,stmt806422);
++R.GAS;
return $ret65716572;
}
} else {
var cont_tail_arg216580 = R.throwNonBooleanOp(L[681],("first"),("or"),or_DASH_oper_DASH_56547);
if(--R.GAS > 0) {
$z65786579 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg216580):R.ffi.throwNonFunApp(L[681],if_helper36433,[cont_tail_arg216580]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg216580):R.ffi.throwNonFunApp(L[681],if_helper36433,[cont_tail_arg216580]);
},
"from":L[681]});
}
++R.GAS;
return $z65786579;
}
};
var $Hcont_tail_app15026564 = function(cont_tail_app446563) {
return cont_tail_app446563;
};
var $Hor_DASH_oper_DASH_15106577 = function(or_DASH_oper_DASH_66576,A317,if_helper36433,stmt806422) {
var anf_if276610 = R.isBoolean(or_DASH_oper_DASH_66576);
if(R.isPyretTrue(anf_if276610)) {
if(R.isPyretTrue(or_DASH_oper_DASH_66576)) {
var $z65846585 = D;
var $f65906591 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app((true)):R.ffi.throwNonFunApp(L[670],if_helper36433,[(true)]);
};
try {
if(--R.GAS > 0) {
$z65846585 = $f65906591();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65906591,
"from":L[670]});
}
} catch($e65826583) {
if(R.isCont($e65826583)) {
var $ss65866587 = {"from":L[670],
"go":function(cont_tail_app436592) {
return $Hcont_tail_app15036593(cont_tail_app436592);
}};
$e65826583.stack[R.EXN_STACKHEIGHT++] = $ss65866587;
}
if(R.isPyretException($e65826583)) {
$e65826583.pyretStack.push(L[670]);
}
throw $e65826583;
}
var $ret65886589 = $Hcont_tail_app15036593($z65846585);
++R.GAS;
return $ret65886589;
} else {
var anf_fun286604 = G(A317,"is-s-check",L[682]);
var $z65966597 = D;
var $f66026603 = function(_) {
return R.isFunction(anf_fun286604)?anf_fun286604.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun286604,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z65966597 = $f66026603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66026603,
"from":L[670]});
}
} catch($e65946595) {
if(R.isCont($e65946595)) {
var $ss65986599 = {"from":L[670],
"go":function(or_DASH_oper_DASH_76605) {
return $Hor_DASH_oper_DASH_15096606(or_DASH_oper_DASH_76605,A317,if_helper36433,stmt806422);
}};
$e65946595.stack[R.EXN_STACKHEIGHT++] = $ss65986599;
}
if(R.isPyretException($e65946595)) {
$e65946595.pyretStack.push(L[670]);
}
throw $e65946595;
}
var $ret66006601 = $Hor_DASH_oper_DASH_15096606($z65966597,A317,if_helper36433,stmt806422);
++R.GAS;
return $ret66006601;
}
} else {
var cont_tail_arg256609 = R.throwNonBooleanOp(L[683],("first"),("or"),or_DASH_oper_DASH_66576);
if(--R.GAS > 0) {
$z66076608 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg256609):R.ffi.throwNonFunApp(L[683],if_helper36433,[cont_tail_arg256609]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg256609):R.ffi.throwNonFunApp(L[683],if_helper36433,[cont_tail_arg256609]);
},
"from":L[683]});
}
++R.GAS;
return $z66076608;
}
};
var $Hcont_tail_app15036593 = function(cont_tail_app436592) {
return cont_tail_app436592;
};
var $Hor_DASH_oper_DASH_15096606 = function(or_DASH_oper_DASH_76605,A317,if_helper36433,stmt806422) {
var anf_if316639 = R.isBoolean(or_DASH_oper_DASH_76605);
if(R.isPyretTrue(anf_if316639)) {
if(R.isPyretTrue(or_DASH_oper_DASH_76605)) {
var $z66136614 = D;
var $f66196620 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app((true)):R.ffi.throwNonFunApp(L[670],if_helper36433,[(true)]);
};
try {
if(--R.GAS > 0) {
$z66136614 = $f66196620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66196620,
"from":L[670]});
}
} catch($e66116612) {
if(R.isCont($e66116612)) {
var $ss66156616 = {"from":L[670],
"go":function(cont_tail_app426621) {
return $Hcont_tail_app15046622(cont_tail_app426621);
}};
$e66116612.stack[R.EXN_STACKHEIGHT++] = $ss66156616;
}
if(R.isPyretException($e66116612)) {
$e66116612.pyretStack.push(L[670]);
}
throw $e66116612;
}
var $ret66176618 = $Hcont_tail_app15046622($z66136614);
++R.GAS;
return $ret66176618;
} else {
var anf_fun326633 = G(A317,"is-s-type",L[684]);
var $z66256626 = D;
var $f66316632 = function(_) {
return R.isFunction(anf_fun326633)?anf_fun326633.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun326633,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z66256626 = $f66316632();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66316632,
"from":L[670]});
}
} catch($e66236624) {
if(R.isCont($e66236624)) {
var $ss66276628 = {"from":L[670],
"go":function(or_DASH_oper_DASH_86634) {
return $Hor_DASH_oper_DASH_15086635(or_DASH_oper_DASH_86634,A317,if_helper36433,stmt806422);
}};
$e66236624.stack[R.EXN_STACKHEIGHT++] = $ss66276628;
}
if(R.isPyretException($e66236624)) {
$e66236624.pyretStack.push(L[670]);
}
throw $e66236624;
}
var $ret66296630 = $Hor_DASH_oper_DASH_15086635($z66256626,A317,if_helper36433,stmt806422);
++R.GAS;
return $ret66296630;
}
} else {
var cont_tail_arg296638 = R.throwNonBooleanOp(L[685],("first"),("or"),or_DASH_oper_DASH_76605);
if(--R.GAS > 0) {
$z66366637 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg296638):R.ffi.throwNonFunApp(L[685],if_helper36433,[cont_tail_arg296638]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg296638):R.ffi.throwNonFunApp(L[685],if_helper36433,[cont_tail_arg296638]);
},
"from":L[685]});
}
++R.GAS;
return $z66366637;
}
};
var $Hcont_tail_app15046622 = function(cont_tail_app426621) {
return cont_tail_app426621;
};
var $Hor_DASH_oper_DASH_15086635 = function(or_DASH_oper_DASH_86634,A317,if_helper36433,stmt806422) {
var anf_if356668 = R.isBoolean(or_DASH_oper_DASH_86634);
if(R.isPyretTrue(anf_if356668)) {
if(R.isPyretTrue(or_DASH_oper_DASH_86634)) {
var $z66426643 = D;
var $f66486649 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app((true)):R.ffi.throwNonFunApp(L[670],if_helper36433,[(true)]);
};
try {
if(--R.GAS > 0) {
$z66426643 = $f66486649();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66486649,
"from":L[670]});
}
} catch($e66406641) {
if(R.isCont($e66406641)) {
var $ss66446645 = {"from":L[670],
"go":function(cont_tail_app416650) {
return $Hcont_tail_app15056651(cont_tail_app416650);
}};
$e66406641.stack[R.EXN_STACKHEIGHT++] = $ss66446645;
}
if(R.isPyretException($e66406641)) {
$e66406641.pyretStack.push(L[670]);
}
throw $e66406641;
}
var $ret66466647 = $Hcont_tail_app15056651($z66426643);
++R.GAS;
return $ret66466647;
} else {
var anf_fun366662 = G(A317,"is-s-newtype",L[686]);
var $z66546655 = D;
var $f66606661 = function(_) {
return R.isFunction(anf_fun366662)?anf_fun366662.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun366662,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z66546655 = $f66606661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66606661,
"from":L[670]});
}
} catch($e66526653) {
if(R.isCont($e66526653)) {
var $ss66566657 = {"from":L[670],
"go":function(or_DASH_oper_DASH_96663) {
return $Hor_DASH_oper_DASH_15076664(or_DASH_oper_DASH_96663,if_helper36433);
}};
$e66526653.stack[R.EXN_STACKHEIGHT++] = $ss66566657;
}
if(R.isPyretException($e66526653)) {
$e66526653.pyretStack.push(L[670]);
}
throw $e66526653;
}
var $ret66586659 = $Hor_DASH_oper_DASH_15076664($z66546655,if_helper36433);
++R.GAS;
return $ret66586659;
}
} else {
var cont_tail_arg336667 = R.throwNonBooleanOp(L[687],("first"),("or"),or_DASH_oper_DASH_86634);
if(--R.GAS > 0) {
$z66656666 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg336667):R.ffi.throwNonFunApp(L[687],if_helper36433,[cont_tail_arg336667]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg336667):R.ffi.throwNonFunApp(L[687],if_helper36433,[cont_tail_arg336667]);
},
"from":L[687]});
}
++R.GAS;
return $z66656666;
}
};
var $Hcont_tail_app15056651 = function(cont_tail_app416650) {
return cont_tail_app416650;
};
var $Hor_DASH_oper_DASH_15076664 = function(or_DASH_oper_DASH_96663,if_helper36433) {
var anf_if396684 = R.isBoolean(or_DASH_oper_DASH_96663);
if(R.isPyretTrue(anf_if396684)) {
var $z66716672 = D;
var $f66776678 = function(_) {
return R.isFunction(if_helper36433)?if_helper36433.app(or_DASH_oper_DASH_96663):R.ffi.throwNonFunApp(L[670],if_helper36433,[or_DASH_oper_DASH_96663]);
};
try {
if(--R.GAS > 0) {
$z66716672 = $f66776678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66776678,
"from":L[670]});
}
} catch($e66696670) {
if(R.isCont($e66696670)) {
var $ss66736674 = {"from":L[670],
"go":function(cont_tail_app406679) {
return $Hcont_tail_app15066680(cont_tail_app406679);
}};
$e66696670.stack[R.EXN_STACKHEIGHT++] = $ss66736674;
}
if(R.isPyretException($e66696670)) {
$e66696670.pyretStack.push(L[670]);
}
throw $e66696670;
}
var $ret66756676 = $Hcont_tail_app15066680($z66716672);
++R.GAS;
return $ret66756676;
} else {
var cont_tail_arg376683 = R.throwNonBooleanOp(L[688],("second"),("or"),or_DASH_oper_DASH_96663);
if(--R.GAS > 0) {
$z66816682 = R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg376683):R.ffi.throwNonFunApp(L[688],if_helper36433,[cont_tail_arg376683]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper36433)?if_helper36433.app(cont_tail_arg376683):R.ffi.throwNonFunApp(L[688],if_helper36433,[cont_tail_arg376683]);
},
"from":L[688]});
}
++R.GAS;
return $z66816682;
}
};
var $Hcont_tail_app15066680 = function(cont_tail_app406679) {
return cont_tail_app406679;
};
var $Hann_DASH_check_DASH_temp14976465 = function(ann_DASH_check_DASH_temp16464) {
return ann_DASH_check_DASH_temp16464;
};
return R.loadModulesNew(NAMESPACE,[$SL11639,$A31740,$PP51841,$CS71942,$SD92043,$E112144,$arrays132245,$lists152346,$option172447,$error192548,$sets212649],function($SL11639,$A31740,$PP51841,$CS71942,$SD92043,$E112144,$arrays132245,$lists152346,$option172447,$error192548,$sets212649) {
var SL116 = R.getField($SL11639,"values");
var A317 = R.getField($A31740,"values");
var PP518 = R.getField($PP51841,"values");
var CS719 = R.getField($CS71942,"values");
var SD920 = R.getField($SD92043,"values");
var E1121 = R.getField($E112144,"values");
var arrays1322 = R.getField($arrays132245,"values");
var lists1523 = R.getField($lists152346,"values");
var option1724 = R.getField($option172447,"values");
var error1925 = R.getField($error192548,"values");
var sets2126 = R.getField($sets212649,"values");
var SL227 = R.getField($SL11639,"types");
var A428 = R.getField($A31740,"types");
var PP629 = R.getField($PP51841,"types");
var CS830 = R.getField($CS71942,"types");
var SD1031 = R.getField($SD92043,"types");
var E1232 = R.getField($E112144,"types");
var arrays1433 = R.getField($arrays132245,"types");
var lists1634 = R.getField($lists152346,"types");
var option1835 = R.getField($option172447,"types");
var error2036 = R.getField($error192548,"types");
var sets2237 = R.getField($sets212649,"types");
return R.safeCall(function() {
var List236685 = R.getDotAnn(L[689],"lists",lists1634,"List");
var Option245065 = R.getDotAnn(L[689],"option",option1835,"Option");
var Array256686 = R.getDotAnn(L[689],"arrays",arrays1433,"Array");
var Set266687 = R.getDotAnn(L[689],"sets",sets2237,"Set");
var array278145 = G(arrays1322,"array",L[689]);
var build_DASH_array288144 = G(arrays1322,"build-array",L[689]);
var array_DASH_from_DASH_list298143 = G(arrays1322,"array-from-list",L[689]);
var is_DASH_array308142 = G(arrays1322,"is-array",L[689]);
var list3192 = G(lists1523,"list",L[689]);
var is_DASH_empty328141 = G(lists1523,"is-empty",L[689]);
var is_DASH_link338140 = G(lists1523,"is-link",L[689]);
var empty348139 = G(lists1523,"empty",L[689]);
var link35745 = G(lists1523,"link",L[689]);
var range3696 = G(lists1523,"range",L[689]);
var repeat378138 = G(lists1523,"repeat",L[689]);
var filter388137 = G(lists1523,"filter",L[689]);
var partition398136 = G(lists1523,"partition",L[689]);
var split_DASH_at408135 = G(lists1523,"split-at",L[689]);
var any418134 = G(lists1523,"any",L[689]);
var find428133 = G(lists1523,"find",L[689]);
var map434399 = G(lists1523,"map",L[689]);
var map24493 = G(lists1523,"map2",L[689]);
var map3458132 = G(lists1523,"map3",L[689]);
var map4468131 = G(lists1523,"map4",L[689]);
var map_n478130 = G(lists1523,"map_n",L[689]);
var map2_n488129 = G(lists1523,"map2_n",L[689]);
var map3_n498128 = G(lists1523,"map3_n",L[689]);
var map4_n508127 = G(lists1523,"map4_n",L[689]);
var each518126 = G(lists1523,"each",L[689]);
var each2528125 = G(lists1523,"each2",L[689]);
var each3538124 = G(lists1523,"each3",L[689]);
var each4548123 = G(lists1523,"each4",L[689]);
var each_n558122 = G(lists1523,"each_n",L[689]);
var each2_n568121 = G(lists1523,"each2_n",L[689]);
var each3_n578120 = G(lists1523,"each3_n",L[689]);
var each4_n588119 = G(lists1523,"each4_n",L[689]);
var fold593614 = G(lists1523,"fold",L[689]);
var fold26080 = G(lists1523,"fold2",L[689]);
var fold3618118 = G(lists1523,"fold3",L[689]);
var fold4628117 = G(lists1523,"fold4",L[689]);
var index638116 = G(lists1523,"index",L[689]);
var Option648115 = G(option1724,"Option",L[689]);
var is_DASH_none65744 = G(option1724,"is-none",L[689]);
var is_DASH_some668114 = G(option1724,"is-some",L[689]);
var none675099 = G(option1724,"none",L[689]);
var some685069 = G(option1724,"some",L[689]);
var set698113 = G(sets2126,"set",L[689]);
var tree_DASH_set708112 = G(sets2126,"tree-set",L[689]);
var list_DASH_set718111 = G(sets2126,"list-set",L[689]);
var BindingInfoT2736688 = R.namedBrander("BindingInfo");
var BindingInfo7255 = R.makeBranderAnn(BindingInfoT2736688,"BindingInfo");
var BindingT3756689 = R.namedBrander("Binding");
var Binding7453 = R.makeBranderAnn(BindingT3756689,"Binding");
var Loc7656 = R.getDotAnn(L[690],"SL",SL227,"Srcloc");
var ok_DASH_last7795 = {"$var":D,
"$name":"ok-last"};
var checkers7874 = {"$var":D,
"$name":"checkers"};
var append_DASH_nothing_DASH_if_DASH_necessary7958 = {"$var":D,
"$name":"append-nothing-if-necessary"};
var anf_assign496690 = R.makeFunction(function(stmt806422) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[673],1,arguments);
}
var anf_fun28110 = G(A317,"is-s-let",L[951]);
var $z81028103 = D;
var $f81088109 = function(_) {
return R.isFunction(anf_fun28110)?anf_fun28110.app(stmt806422):R.ffi.throwNonFunApp(L[670],anf_fun28110,[stmt806422]);
};
try {
if(--R.GAS > 0) {
$z81028103 = $f81088109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81088109,
"from":L[670]});
}
} catch($e81008101) {
if(R.isCont($e81008101)) {
var $ss81048105 = {"from":L[670],
"go":function(or_DASH_oper_DASH_16421) {
return $Hor_DASH_oper_DASH_15156420(or_DASH_oper_DASH_16421,A317,stmt806422,not9);
}};
$e81008101.stack[R.EXN_STACKHEIGHT++] = $ss81048105;
}
if(R.isPyretException($e81008101)) {
$e81008101.pyretStack.push(L[670]);
}
throw $e81008101;
}
var $ret81068107 = $Hor_DASH_oper_DASH_15156420($z81028103,A317,stmt806422,not9);
++R.GAS;
return $ret81068107;
});
ok_DASH_last7795.$var = anf_assign496690;
var anf_assign606691 = R.makeFunction(function(l816370) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[669],1,arguments);
}
var anf_fun516367 = G(A317,"s-app",L[950]);
var anf_fun526368 = G(A317,"s-dot",L[949]);
var anf_fun536369 = G(A317,"s-id",L[948]);
var anf_fun548099 = G(A317,"s-name",L[947]);
var $z80918092 = D;
var $f80978098 = function(_) {
return R.isFunction(anf_fun548099)?anf_fun548099.app(l816370,("builtins")):R.ffi.throwNonFunApp(L[946],anf_fun548099,[l816370,("builtins")]);
};
try {
if(--R.GAS > 0) {
$z80918092 = $f80978098();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80978098,
"from":L[946]});
}
} catch($e80898090) {
if(R.isCont($e80898090)) {
var $ss80938094 = {"from":L[946],
"go":function(anf_arg556366) {
return $Hanf_arg15206365(anf_arg556366,anf_fun516367,anf_fun526368,anf_fun536369,l816370,list3192);
}};
$e80898090.stack[R.EXN_STACKHEIGHT++] = $ss80938094;
}
if(R.isPyretException($e80898090)) {
$e80898090.pyretStack.push(L[946]);
}
throw $e80898090;
}
var $ret80958096 = $Hanf_arg15206365($z80918092,anf_fun516367,anf_fun526368,anf_fun536369,l816370,list3192);
++R.GAS;
return $ret80958096;
});
checkers7874.$var = anf_assign606691;
var anf_assign1126692 = R.makeFunction(function(prog828014) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[931],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[945],"A",A428,"Program")],[prog828014],[L[945]],function() {
var cases_DASH_val138088 = prog828014;
var anf_fun628025 = G(cases_DASH_val138088,"_match",L[932]);
var anf_obj1088029 = R.makeFunction(function(l1836174,_provide846172,_provide_DASH_types856171,imports866173,body878030) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[933],5,arguments);
}
var cases_DASH_val128087 = body878030;
var anf_fun648041 = G(cases_DASH_val128087,"_match",L[934]);
var anf_obj1048045 = R.makeFunction(function(l2886175,stmts896176) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[935],2,arguments);
}
var cases_DASH_val118086 = stmts896176;
var anf_fun668056 = G(cases_DASH_val118086,"_match",L[936]);
var anf_obj788060 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[665],0,arguments);
}
var anf_fun686301 = G(A317,"s-program",L[944]);
var anf_fun696302 = G(A317,"s-block",L[943]);
var anf_fun706303 = G(list3192,"make",L[662]);
var anf_fun716304 = G(A317,"s-id",L[942]);
var anf_fun728085 = G(A317,"s-name",L[941]);
var $z80778078 = D;
var $f80838084 = function(_) {
return R.isFunction(anf_fun728085)?anf_fun728085.app(l2886175,("nothing")):R.ffi.throwNonFunApp(L[940],anf_fun728085,[l2886175,("nothing")]);
};
try {
if(--R.GAS > 0) {
$z80778078 = $f80838084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80838084,
"from":L[940]});
}
} catch($e80758076) {
if(R.isCont($e80758076)) {
var $ss80798080 = {"from":L[940],
"go":function(anf_arg736300) {
return $Hanf_arg15266299(anf_arg736300,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,anf_fun706303,anf_fun716304,imports866173,l1836174,l2886175,some685069);
}};
$e80758076.stack[R.EXN_STACKHEIGHT++] = $ss80798080;
}
if(R.isPyretException($e80758076)) {
$e80758076.pyretStack.push(L[940]);
}
throw $e80758076;
}
var $ret80818082 = $Hanf_arg15266299($z80778078,_provide_DASH_types856171,_provide846172,anf_fun686301,anf_fun696302,anf_fun706303,anf_fun716304,imports866173,l1836174,l2886175,some685069);
++R.GAS;
return $ret80818082;
});
var anf_obj1008061 = R.makeFunction(function($underscore908062,$underscore918063) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[937],2,arguments);
}
var anf_fun808074 = G(stmts896176,"last",L[939]);
var $z80668067 = D;
var $f80728073 = function(_) {
return R.isFunction(anf_fun808074)?anf_fun808074.app():R.ffi.throwNonFunApp(L[938],anf_fun808074,[]);
};
try {
if(--R.GAS > 0) {
$z80668067 = $f80728073();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80728073,
"from":L[938]});
}
} catch($e80648065) {
if(R.isCont($e80648065)) {
var $ss80688069 = {"from":L[938],
"go":function(last_DASH_stmt926170) {
return $Hlast_DASH_stmt15366169(last_DASH_stmt926170,A317,_provide_DASH_types856171,_provide846172,imports866173,l1836174,l2886175,list3192,none675099,ok_DASH_last7795,some685069,stmts896176,_plus7);
}};
$e80648065.stack[R.EXN_STACKHEIGHT++] = $ss80688069;
}
if(R.isPyretException($e80648065)) {
$e80648065.pyretStack.push(L[938]);
}
throw $e80648065;
}
var $ret80708071 = $Hlast_DASH_stmt15366169($z80668067,A317,_provide_DASH_types856171,_provide846172,imports866173,l1836174,l2886175,list3192,none675099,ok_DASH_last7795,some685069,stmts896176,_plus7);
++R.GAS;
return $ret80708071;
});
var anf_arg1018057 = R.makeObject({"empty":anf_obj788060,
"link":anf_obj1008061});
var anf_arg1038058 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[936],0,arguments);
}
var ann_DASH_check_DASH_temp1028059 = R.throwNoBranchesMatched(L[936],("cases"));
return ann_DASH_check_DASH_temp1028059;
});
var $z80488049 = D;
var $f80548055 = function(_) {
return R.isFunction(anf_fun668056)?anf_fun668056.app(anf_arg1018057,anf_arg1038058):R.ffi.throwNonFunApp(L[935],anf_fun668056,[anf_arg1018057,anf_arg1038058]);
};
try {
if(--R.GAS > 0) {
$z80488049 = $f80548055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80548055,
"from":L[935]});
}
} catch($e80468047) {
if(R.isCont($e80468047)) {
var $ss80508051 = {"from":L[935],
"go":function(ann_DASH_check_DASH_temp656168) {
return $Hann_DASH_check_DASH_temp15376167(ann_DASH_check_DASH_temp656168);
}};
$e80468047.stack[R.EXN_STACKHEIGHT++] = $ss80508051;
}
if(R.isPyretException($e80468047)) {
$e80468047.pyretStack.push(L[935]);
}
throw $e80468047;
}
var $ret80528053 = $Hann_DASH_check_DASH_temp15376167($z80488049);
++R.GAS;
return $ret80528053;
});
var anf_arg1058042 = R.makeObject({"s-block":anf_obj1048045});
var anf_arg1078043 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[934],0,arguments);
}
var ann_DASH_check_DASH_temp1068044 = none675099;
return ann_DASH_check_DASH_temp1068044;
});
var $z80338034 = D;
var $f80398040 = function(_) {
return R.isFunction(anf_fun648041)?anf_fun648041.app(anf_arg1058042,anf_arg1078043):R.ffi.throwNonFunApp(L[933],anf_fun648041,[anf_arg1058042,anf_arg1078043]);
};
try {
if(--R.GAS > 0) {
$z80338034 = $f80398040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80398040,
"from":L[933]});
}
} catch($e80318032) {
if(R.isCont($e80318032)) {
var $ss80358036 = {"from":L[933],
"go":function(ann_DASH_check_DASH_temp636166) {
return $Hann_DASH_check_DASH_temp15386165(ann_DASH_check_DASH_temp636166);
}};
$e80318032.stack[R.EXN_STACKHEIGHT++] = $ss80358036;
}
if(R.isPyretException($e80318032)) {
$e80318032.pyretStack.push(L[933]);
}
throw $e80318032;
}
var $ret80378038 = $Hann_DASH_check_DASH_temp15386165($z80338034);
++R.GAS;
return $ret80378038;
});
var anf_arg1098026 = R.makeObject({"s-program":anf_obj1088029});
var anf_arg1118027 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[932],0,arguments);
}
var ann_DASH_check_DASH_temp1108028 = R.throwNoBranchesMatched(L[932],("cases"));
return ann_DASH_check_DASH_temp1108028;
});
var $z80178018 = D;
var $f80238024 = function(_) {
return R.isFunction(anf_fun628025)?anf_fun628025.app(anf_arg1098026,anf_arg1118027):R.ffi.throwNonFunApp(L[931],anf_fun628025,[anf_arg1098026,anf_arg1118027]);
};
try {
if(--R.GAS > 0) {
$z80178018 = $f80238024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80238024,
"from":L[931]});
}
} catch($e80158016) {
if(R.isCont($e80158016)) {
var $ss80198020 = {"from":L[931],
"go":function(ann_DASH_check_DASH_temp616164) {
return $Hann_DASH_check_DASH_temp15396163(ann_DASH_check_DASH_temp616164,A428,Option245065);
}};
$e80158016.stack[R.EXN_STACKHEIGHT++] = $ss80198020;
}
if(R.isPyretException($e80158016)) {
$e80158016.pyretStack.push(L[931]);
}
throw $e80158016;
}
var $ret80218022 = $Hann_DASH_check_DASH_temp15396163($z80178018,A428,Option245065);
++R.GAS;
return $ret80218022;
});
});
append_DASH_nothing_DASH_if_DASH_necessary7958.$var = anf_assign1126692;
var anf_extend1138001 = G(A317,"default-map-visitor",L[930]);
var anf_extend1348002 = R.makeMethod(function(self946094) {
return function(l956093,stmts966095) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[929],2,arguments);
}
var anf_fun1158013 = G(stmts966095,"length",L[928]);
var $z80058006 = D;
var $f80118012 = function(_) {
return R.isFunction(anf_fun1158013)?anf_fun1158013.app():R.ffi.throwNonFunApp(L[927],anf_fun1158013,[]);
};
try {
if(--R.GAS > 0) {
$z80058006 = $f80118012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80118012,
"from":L[927]});
}
} catch($e80038004) {
if(R.isCont($e80038004)) {
var $ss80078008 = {"from":L[927],
"go":function(anf_arg1166092) {
return $Hanf_arg15446091(anf_arg1166092,A317,l956093,self946094,stmts966095);
}};
$e80038004.stack[R.EXN_STACKHEIGHT++] = $ss80078008;
}
if(R.isPyretException($e80038004)) {
$e80038004.pyretStack.push(L[927]);
}
throw $e80038004;
}
var $ret80098010 = $Hanf_arg15446091($z80058006,A317,l956093,self946094,stmts966095);
++R.GAS;
return $ret80098010;
};
},{"length":3});
var flatten_DASH_single_DASH_blocks9379 = anf_extend1138001.extendWith({"s-block":anf_extend1348002});
nothing10;
var anf_extend1357976 = G(A317,"default-map-visitor",L[926]);
var anf_extend1557977 = R.makeMethod(function(self988000) {
return function(l995979,stmts1005980) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[632],2,arguments);
}
var anf_arg1495978 = R.makeFunction(function(new_DASH_stmts1026021,s1036022) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[633],2,arguments);
}
var anf_fun1387999 = G(s1036022,"visit",L[925]);
var $z79917992 = D;
var $f79977998 = function(_) {
return R.isFunction(anf_fun1387999)?anf_fun1387999.app(self988000):R.ffi.throwNonFunApp(L[634],anf_fun1387999,[self988000]);
};
try {
if(--R.GAS > 0) {
$z79917992 = $f79977998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79977998,
"from":L[634]});
}
} catch($e79897990) {
if(R.isCont($e79897990)) {
var $ss79937994 = {"from":L[634],
"go":function(cases_DASH_val166020) {
return $Hcases_DASH_val15506019(cases_DASH_val166020,list3192,new_DASH_stmts1026021,s1036022,_plus7);
}};
$e79897990.stack[R.EXN_STACKHEIGHT++] = $ss79937994;
}
if(R.isPyretException($e79897990)) {
$e79897990.pyretStack.push(L[634]);
}
throw $e79897990;
}
var $ret79957996 = $Hcases_DASH_val15506019($z79917992,list3192,new_DASH_stmts1026021,s1036022,_plus7);
++R.GAS;
return $ret79957996;
});
var anf_fun1507988 = G(list3192,"make",L[924]);
var $z79807981 = D;
var $f79867987 = function(_) {
return R.isFunction(anf_fun1507988)?anf_fun1507988.app([]):R.ffi.throwNonFunApp(L[924],anf_fun1507988,[[]]);
};
try {
if(--R.GAS > 0) {
$z79807981 = $f79867987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79867987,
"from":L[924]});
}
} catch($e79787979) {
if(R.isCont($e79787979)) {
var $ss79827983 = {"from":L[924],
"go":function(anf_arg1515977) {
return $Hanf_arg15545976(anf_arg1515977,A317,anf_arg1495978,fold593614,l995979,stmts1005980);
}};
$e79787979.stack[R.EXN_STACKHEIGHT++] = $ss79827983;
}
if(R.isPyretException($e79787979)) {
$e79787979.pyretStack.push(L[924]);
}
throw $e79787979;
}
var $ret79847985 = $Hanf_arg15545976($z79807981,A317,anf_arg1495978,fold593614,l995979,stmts1005980);
++R.GAS;
return $ret79847985;
};
},{"length":3});
var merge_DASH_nested_DASH_blocks9794 = anf_extend1357976.extendWith({"s-block":anf_extend1557977});
var count_DASH_apps10675 = {"$var":D,
"$name":"count-apps"};
var BindingInfo41076694 = {"$var":D,
"$name":"BindingInfo4"};
var BindingInfo10854 = {"$var":D,
"$name":"BindingInfo"};
var is_DASH_BindingInfo10983 = {"$var":D,
"$name":"is-BindingInfo"};
var is_DASH_b_DASH_prim11087 = {"$var":D,
"$name":"is-b-prim"};
var b_DASH_prim11162 = {"$var":D,
"$name":"b-prim"};
var is_DASH_b_DASH_dict11284 = {"$var":D,
"$name":"is-b-dict"};
var b_DASH_dict11359 = {"$var":D,
"$name":"b-dict"};
var is_DASH_b_DASH_exp11486 = {"$var":D,
"$name":"is-b-exp"};
var b_DASH_exp11561 = {"$var":D,
"$name":"b-exp"};
var is_DASH_b_DASH_dot11685 = {"$var":D,
"$name":"is-b-dot"};
var b_DASH_dot11760 = {"$var":D,
"$name":"b-dot"};
var is_DASH_b_DASH_typ11888 = {"$var":D,
"$name":"is-b-typ"};
var b_DASH_typ11963 = {"$var":D,
"$name":"b-typ"};
var is_DASH_b_DASH_unknown12089 = {"$var":D,
"$name":"is-b-unknown"};
var b_DASH_unknown12164 = {"$var":D,
"$name":"b-unknown"};
var Binding51226710 = {"$var":D,
"$name":"Binding5"};
var Binding12352 = {"$var":D,
"$name":"Binding"};
var is_DASH_Binding12482 = {"$var":D,
"$name":"is-Binding"};
var is_DASH_e_DASH_bind12590 = {"$var":D,
"$name":"is-e-bind"};
var e_DASH_bind12678 = {"$var":D,
"$name":"e-bind"};
var bind_DASH_exp12766 = {"$var":D,
"$name":"bind-exp"};
var bind_DASH_or_DASH_unknown12867 = {"$var":D,
"$name":"bind-or-unknown"};
var binding_DASH_type_DASH_env_DASH_from_DASH_env12972 = {"$var":D,
"$name":"binding-type-env-from-env"};
var binding_DASH_env_DASH_from_DASH_env13068 = {"$var":D,
"$name":"binding-env-from-env"};
var default_DASH_env_DASH_map_DASH_visitor13177 = {"$var":D,
"$name":"default-env-map-visitor"};
var default_DASH_env_DASH_iter_DASH_visitor13276 = {"$var":D,
"$name":"default-env-iter-visitor"};
var anf_assign1776693 = R.makeFunction(function(expr1337950) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[918],1,arguments);
}
var count1345893 = {"$var":(0),
"$name":"count"};
var anf_extend1577963 = G(A317,"default-iter-visitor",L[923]);
var anf_extend1757964 = R.makeMethod(function(self1365899) {
return function(l1377975,f1385898,args1395897) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[922],3,arguments);
}
var $z79677968 = D;
var $f79737974 = function(_) {
return R.isFunction(_plus7)?_plus7.app(count1345893.$var,(1)):R.ffi.throwNonFunApp(L[921],_plus7,[count1345893.$var,(1)]);
};
try {
if(--R.GAS > 0) {
$z79677968 = $f79737974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79737974,
"from":L[921]});
}
} catch($e79657966) {
if(R.isCont($e79657966)) {
var $ss79697970 = {"from":L[921],
"go":function(anf_assign1595896) {
return $Hanf_assign15605895(anf_assign1595896,args1395897,count1345893,f1385898,self1365899);
}};
$e79657966.stack[R.EXN_STACKHEIGHT++] = $ss79697970;
}
if(R.isPyretException($e79657966)) {
$e79657966.pyretStack.push(L[921]);
}
throw $e79657966;
}
var $ret79717972 = $Hanf_assign15605895($z79677968,args1395897,count1345893,f1385898,self1365899);
++R.GAS;
return $ret79717972;
};
},{"length":4});
var visitor1357962 = anf_extend1577963.extendWith({"s-app":anf_extend1757964});
var anf_fun1767961 = G(expr1337950,"visit",L[920]);
var $z79537954 = D;
var $f79597960 = function(_) {
return R.isFunction(anf_fun1767961)?anf_fun1767961.app(visitor1357962):R.ffi.throwNonFunApp(L[919],anf_fun1767961,[visitor1357962]);
};
try {
if(--R.GAS > 0) {
$z79537954 = $f79597960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79597960,
"from":L[919]});
}
} catch($e79517952) {
if(R.isCont($e79517952)) {
var $ss79557956 = {"from":L[919],
"go":function(anf_begin_app_dropped15615892) {
return $Hanf_begin_app_dropped15625891(anf_begin_app_dropped15615892,count1345893);
}};
$e79517952.stack[R.EXN_STACKHEIGHT++] = $ss79557956;
}
if(R.isPyretException($e79517952)) {
$e79517952.pyretStack.push(L[919]);
}
throw $e79517952;
}
var $ret79577958 = $Hanf_begin_app_dropped15625891($z79537954,count1345893);
++R.GAS;
return $ret79577958;
});
count_DASH_apps10675.$var = anf_assign1776693;
var anf_variant_member1897666 = R.makeMethod(function(self217930) {
return function(cases_DASH_funs227931,else_DASH_clause237942) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[621],2,arguments);
}
var if_DASH_257943 = R.hasField(cases_DASH_funs227931,("b-prim"));
var if_helper1795884 = R.makeFunction(function(if_helper_arg1807948) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[621],1,arguments);
}
var ann_DASH_check_DASH_temp1787949 = if_helper_arg1807948;
return ann_DASH_check_DASH_temp1787949;
});
var anf_if1837947 = R.isBoolean(if_DASH_257943);
if(R.isPyretTrue(anf_if1837947)) {
if(R.isPyretTrue(if_DASH_257943)) {
var call_DASH_b_DASH_prim207928 = G(cases_DASH_funs227931,"b-prim",L[621]);
var anf_arg1867929 = G(self217930,"name",L[917]);
var $z79207921 = D;
var $f79267927 = function(_) {
return R.isFunction(call_DASH_b_DASH_prim207928)?call_DASH_b_DASH_prim207928.app(anf_arg1867929):R.ffi.throwNonFunApp(L[621],call_DASH_b_DASH_prim207928,[anf_arg1867929]);
};
try {
if(--R.GAS > 0) {
$z79207921 = $f79267927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79267927,
"from":L[621]});
}
} catch($e79187919) {
if(R.isCont($e79187919)) {
var $ss79227923 = {"from":L[621],
"go":function(cont_tail_arg1875883) {
return $Hcont_tail_arg15635882(cont_tail_arg1875883,if_helper1795884);
}};
$e79187919.stack[R.EXN_STACKHEIGHT++] = $ss79227923;
}
if(R.isPyretException($e79187919)) {
$e79187919.pyretStack.push(L[621]);
}
throw $e79187919;
}
var $ret79247925 = $Hcont_tail_arg15635882($z79207921,if_helper1795884);
++R.GAS;
return $ret79247925;
} else {
var $z79347935 = D;
var $f79407941 = function(_) {
return R.isFunction(else_DASH_clause237942)?else_DASH_clause237942.app():R.ffi.throwNonFunApp(L[621],else_DASH_clause237942,[]);
};
try {
if(--R.GAS > 0) {
$z79347935 = $f79407941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79407941,
"from":L[621]});
}
} catch($e79327933) {
if(R.isCont($e79327933)) {
var $ss79367937 = {"from":L[621],
"go":function(cont_tail_arg1845888) {
return $Hcont_tail_arg15645887(cont_tail_arg1845888,if_helper1795884);
}};
$e79327933.stack[R.EXN_STACKHEIGHT++] = $ss79367937;
}
if(R.isPyretException($e79327933)) {
$e79327933.pyretStack.push(L[621]);
}
throw $e79327933;
}
var $ret79387939 = $Hcont_tail_arg15645887($z79347935,if_helper1795884);
++R.GAS;
return $ret79387939;
}
} else {
var cont_tail_arg1817946 = R.throwNonBooleanCondition(L[621],("if"),if_DASH_257943);
if(--R.GAS > 0) {
$z79447945 = R.isFunction(if_helper1795884)?if_helper1795884.app(cont_tail_arg1817946):R.ffi.throwNonFunApp(L[621],if_helper1795884,[cont_tail_arg1817946]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1795884)?if_helper1795884.app(cont_tail_arg1817946):R.ffi.throwNonFunApp(L[621],if_helper1795884,[cont_tail_arg1817946]);
},
"from":L[621]});
}
++R.GAS;
return $z79447945;
}
};
},{"length":3});
var anf_variant_member1957667 = R.makeMethod(function(self247917) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[621],0,arguments);
}
var anf_arg1917916 = G(self247917,"name",L[621]);
var $z79087909 = D;
var $f79147915 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg1917916):R.ffi.throwNonFunApp(L[621],torepr13,[anf_arg1917916]);
};
try {
if(--R.GAS > 0) {
$z79087909 = $f79147915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79147915,
"from":L[621]});
}
} catch($e79067907) {
if(R.isCont($e79067907)) {
var $ss79107911 = {"from":L[621],
"go":function(anf_arg1925845) {
return $Hanf_arg15685844(anf_arg1925845,_plus7);
}};
$e79067907.stack[R.EXN_STACKHEIGHT++] = $ss79107911;
}
if(R.isPyretException($e79067907)) {
$e79067907.pyretStack.push(L[621]);
}
throw $e79067907;
}
var $ret79127913 = $Hanf_arg15685844($z79087909,_plus7);
++R.GAS;
return $ret79127913;
};
},{"length":1});
var anf_variant_member2077674 = R.makeMethod(function(self277886) {
return function(cases_DASH_funs287887,else_DASH_clause297898) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[620],2,arguments);
}
var if_DASH_317899 = R.hasField(cases_DASH_funs287887,("b-dict"));
var if_helper1975837 = R.makeFunction(function(if_helper_arg1987904) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[620],1,arguments);
}
var ann_DASH_check_DASH_temp1967905 = if_helper_arg1987904;
return ann_DASH_check_DASH_temp1967905;
});
var anf_if2017903 = R.isBoolean(if_DASH_317899);
if(R.isPyretTrue(anf_if2017903)) {
if(R.isPyretTrue(if_DASH_317899)) {
var call_DASH_b_DASH_dict267884 = G(cases_DASH_funs287887,"b-dict",L[620]);
var anf_arg2047885 = G(self277886,"dict",L[916]);
var $z78767877 = D;
var $f78827883 = function(_) {
return R.isFunction(call_DASH_b_DASH_dict267884)?call_DASH_b_DASH_dict267884.app(anf_arg2047885):R.ffi.throwNonFunApp(L[620],call_DASH_b_DASH_dict267884,[anf_arg2047885]);
};
try {
if(--R.GAS > 0) {
$z78767877 = $f78827883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78827883,
"from":L[620]});
}
} catch($e78747875) {
if(R.isCont($e78747875)) {
var $ss78787879 = {"from":L[620],
"go":function(cont_tail_arg2055836) {
return $Hcont_tail_arg15695835(cont_tail_arg2055836,if_helper1975837);
}};
$e78747875.stack[R.EXN_STACKHEIGHT++] = $ss78787879;
}
if(R.isPyretException($e78747875)) {
$e78747875.pyretStack.push(L[620]);
}
throw $e78747875;
}
var $ret78807881 = $Hcont_tail_arg15695835($z78767877,if_helper1975837);
++R.GAS;
return $ret78807881;
} else {
var $z78907891 = D;
var $f78967897 = function(_) {
return R.isFunction(else_DASH_clause297898)?else_DASH_clause297898.app():R.ffi.throwNonFunApp(L[620],else_DASH_clause297898,[]);
};
try {
if(--R.GAS > 0) {
$z78907891 = $f78967897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78967897,
"from":L[620]});
}
} catch($e78887889) {
if(R.isCont($e78887889)) {
var $ss78927893 = {"from":L[620],
"go":function(cont_tail_arg2025841) {
return $Hcont_tail_arg15705840(cont_tail_arg2025841,if_helper1975837);
}};
$e78887889.stack[R.EXN_STACKHEIGHT++] = $ss78927893;
}
if(R.isPyretException($e78887889)) {
$e78887889.pyretStack.push(L[620]);
}
throw $e78887889;
}
var $ret78947895 = $Hcont_tail_arg15705840($z78907891,if_helper1975837);
++R.GAS;
return $ret78947895;
}
} else {
var cont_tail_arg1997902 = R.throwNonBooleanCondition(L[620],("if"),if_DASH_317899);
if(--R.GAS > 0) {
$z79007901 = R.isFunction(if_helper1975837)?if_helper1975837.app(cont_tail_arg1997902):R.ffi.throwNonFunApp(L[620],if_helper1975837,[cont_tail_arg1997902]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper1975837)?if_helper1975837.app(cont_tail_arg1997902):R.ffi.throwNonFunApp(L[620],if_helper1975837,[cont_tail_arg1997902]);
},
"from":L[620]});
}
++R.GAS;
return $z79007901;
}
};
},{"length":3});
var anf_variant_member2137675 = R.makeMethod(function(self307873) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[620],0,arguments);
}
var anf_arg2097872 = G(self307873,"dict",L[620]);
var $z78647865 = D;
var $f78707871 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg2097872):R.ffi.throwNonFunApp(L[620],torepr13,[anf_arg2097872]);
};
try {
if(--R.GAS > 0) {
$z78647865 = $f78707871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78707871,
"from":L[620]});
}
} catch($e78627863) {
if(R.isCont($e78627863)) {
var $ss78667867 = {"from":L[620],
"go":function(anf_arg2105798) {
return $Hanf_arg15745797(anf_arg2105798,_plus7);
}};
$e78627863.stack[R.EXN_STACKHEIGHT++] = $ss78667867;
}
if(R.isPyretException($e78627863)) {
$e78627863.pyretStack.push(L[620]);
}
throw $e78627863;
}
var $ret78687869 = $Hanf_arg15745797($z78647865,_plus7);
++R.GAS;
return $ret78687869;
};
},{"length":1});
var anf_variant_member2257682 = R.makeMethod(function(self337842) {
return function(cases_DASH_funs347843,else_DASH_clause357854) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[619],2,arguments);
}
var if_DASH_377855 = R.hasField(cases_DASH_funs347843,("b-exp"));
var if_helper2155790 = R.makeFunction(function(if_helper_arg2167860) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[619],1,arguments);
}
var ann_DASH_check_DASH_temp2147861 = if_helper_arg2167860;
return ann_DASH_check_DASH_temp2147861;
});
var anf_if2197859 = R.isBoolean(if_DASH_377855);
if(R.isPyretTrue(anf_if2197859)) {
if(R.isPyretTrue(if_DASH_377855)) {
var call_DASH_b_DASH_exp327840 = G(cases_DASH_funs347843,"b-exp",L[619]);
var anf_arg2227841 = G(self337842,"exp",L[915]);
var $z78327833 = D;
var $f78387839 = function(_) {
return R.isFunction(call_DASH_b_DASH_exp327840)?call_DASH_b_DASH_exp327840.app(anf_arg2227841):R.ffi.throwNonFunApp(L[619],call_DASH_b_DASH_exp327840,[anf_arg2227841]);
};
try {
if(--R.GAS > 0) {
$z78327833 = $f78387839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78387839,
"from":L[619]});
}
} catch($e78307831) {
if(R.isCont($e78307831)) {
var $ss78347835 = {"from":L[619],
"go":function(cont_tail_arg2235789) {
return $Hcont_tail_arg15755788(cont_tail_arg2235789,if_helper2155790);
}};
$e78307831.stack[R.EXN_STACKHEIGHT++] = $ss78347835;
}
if(R.isPyretException($e78307831)) {
$e78307831.pyretStack.push(L[619]);
}
throw $e78307831;
}
var $ret78367837 = $Hcont_tail_arg15755788($z78327833,if_helper2155790);
++R.GAS;
return $ret78367837;
} else {
var $z78467847 = D;
var $f78527853 = function(_) {
return R.isFunction(else_DASH_clause357854)?else_DASH_clause357854.app():R.ffi.throwNonFunApp(L[619],else_DASH_clause357854,[]);
};
try {
if(--R.GAS > 0) {
$z78467847 = $f78527853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78527853,
"from":L[619]});
}
} catch($e78447845) {
if(R.isCont($e78447845)) {
var $ss78487849 = {"from":L[619],
"go":function(cont_tail_arg2205794) {
return $Hcont_tail_arg15765793(cont_tail_arg2205794,if_helper2155790);
}};
$e78447845.stack[R.EXN_STACKHEIGHT++] = $ss78487849;
}
if(R.isPyretException($e78447845)) {
$e78447845.pyretStack.push(L[619]);
}
throw $e78447845;
}
var $ret78507851 = $Hcont_tail_arg15765793($z78467847,if_helper2155790);
++R.GAS;
return $ret78507851;
}
} else {
var cont_tail_arg2177858 = R.throwNonBooleanCondition(L[619],("if"),if_DASH_377855);
if(--R.GAS > 0) {
$z78567857 = R.isFunction(if_helper2155790)?if_helper2155790.app(cont_tail_arg2177858):R.ffi.throwNonFunApp(L[619],if_helper2155790,[cont_tail_arg2177858]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2155790)?if_helper2155790.app(cont_tail_arg2177858):R.ffi.throwNonFunApp(L[619],if_helper2155790,[cont_tail_arg2177858]);
},
"from":L[619]});
}
++R.GAS;
return $z78567857;
}
};
},{"length":3});
var anf_variant_member2317683 = R.makeMethod(function(self367829) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[619],0,arguments);
}
var anf_arg2277828 = G(self367829,"exp",L[619]);
var $z78207821 = D;
var $f78267827 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg2277828):R.ffi.throwNonFunApp(L[619],torepr13,[anf_arg2277828]);
};
try {
if(--R.GAS > 0) {
$z78207821 = $f78267827();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78267827,
"from":L[619]});
}
} catch($e78187819) {
if(R.isCont($e78187819)) {
var $ss78227823 = {"from":L[619],
"go":function(anf_arg2285751) {
return $Hanf_arg15805750(anf_arg2285751,_plus7);
}};
$e78187819.stack[R.EXN_STACKHEIGHT++] = $ss78227823;
}
if(R.isPyretException($e78187819)) {
$e78187819.pyretStack.push(L[619]);
}
throw $e78187819;
}
var $ret78247825 = $Hanf_arg15805750($z78207821,_plus7);
++R.GAS;
return $ret78247825;
};
},{"length":1});
var anf_variant_member2447690 = R.makeMethod(function(self397798) {
return function(cases_DASH_funs407799,else_DASH_clause417810) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[618],2,arguments);
}
var if_DASH_437811 = R.hasField(cases_DASH_funs407799,("b-dot"));
var if_helper2335743 = R.makeFunction(function(if_helper_arg2347816) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[618],1,arguments);
}
var ann_DASH_check_DASH_temp2327817 = if_helper_arg2347816;
return ann_DASH_check_DASH_temp2327817;
});
var anf_if2377815 = R.isBoolean(if_DASH_437811);
if(R.isPyretTrue(anf_if2377815)) {
if(R.isPyretTrue(if_DASH_437811)) {
var call_DASH_b_DASH_dot387795 = G(cases_DASH_funs407799,"b-dot",L[618]);
var anf_arg2407796 = G(self397798,"base",L[914]);
var anf_arg2417797 = G(self397798,"name",L[913]);
var $z77877788 = D;
var $f77937794 = function(_) {
return R.isFunction(call_DASH_b_DASH_dot387795)?call_DASH_b_DASH_dot387795.app(anf_arg2407796,anf_arg2417797):R.ffi.throwNonFunApp(L[618],call_DASH_b_DASH_dot387795,[anf_arg2407796,anf_arg2417797]);
};
try {
if(--R.GAS > 0) {
$z77877788 = $f77937794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77937794,
"from":L[618]});
}
} catch($e77857786) {
if(R.isCont($e77857786)) {
var $ss77897790 = {"from":L[618],
"go":function(cont_tail_arg2425742) {
return $Hcont_tail_arg15815741(cont_tail_arg2425742,if_helper2335743);
}};
$e77857786.stack[R.EXN_STACKHEIGHT++] = $ss77897790;
}
if(R.isPyretException($e77857786)) {
$e77857786.pyretStack.push(L[618]);
}
throw $e77857786;
}
var $ret77917792 = $Hcont_tail_arg15815741($z77877788,if_helper2335743);
++R.GAS;
return $ret77917792;
} else {
var $z78027803 = D;
var $f78087809 = function(_) {
return R.isFunction(else_DASH_clause417810)?else_DASH_clause417810.app():R.ffi.throwNonFunApp(L[618],else_DASH_clause417810,[]);
};
try {
if(--R.GAS > 0) {
$z78027803 = $f78087809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78087809,
"from":L[618]});
}
} catch($e78007801) {
if(R.isCont($e78007801)) {
var $ss78047805 = {"from":L[618],
"go":function(cont_tail_arg2385747) {
return $Hcont_tail_arg15825746(cont_tail_arg2385747,if_helper2335743);
}};
$e78007801.stack[R.EXN_STACKHEIGHT++] = $ss78047805;
}
if(R.isPyretException($e78007801)) {
$e78007801.pyretStack.push(L[618]);
}
throw $e78007801;
}
var $ret78067807 = $Hcont_tail_arg15825746($z78027803,if_helper2335743);
++R.GAS;
return $ret78067807;
}
} else {
var cont_tail_arg2357814 = R.throwNonBooleanCondition(L[618],("if"),if_DASH_437811);
if(--R.GAS > 0) {
$z78127813 = R.isFunction(if_helper2335743)?if_helper2335743.app(cont_tail_arg2357814):R.ffi.throwNonFunApp(L[618],if_helper2335743,[cont_tail_arg2357814]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2335743)?if_helper2335743.app(cont_tail_arg2357814):R.ffi.throwNonFunApp(L[618],if_helper2335743,[cont_tail_arg2357814]);
},
"from":L[618]});
}
++R.GAS;
return $z78127813;
}
};
},{"length":3});
var anf_variant_member2547691 = R.makeMethod(function(self425667) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[618],0,arguments);
}
var anf_arg2467784 = G(self425667,"base",L[618]);
var $z77767777 = D;
var $f77827783 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg2467784):R.ffi.throwNonFunApp(L[618],torepr13,[anf_arg2467784]);
};
try {
if(--R.GAS > 0) {
$z77767777 = $f77827783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77827783,
"from":L[618]});
}
} catch($e77747775) {
if(R.isCont($e77747775)) {
var $ss77787779 = {"from":L[618],
"go":function(anf_arg2475666) {
return $Hanf_arg15895665(anf_arg2475666,self425667,_plus7,torepr13);
}};
$e77747775.stack[R.EXN_STACKHEIGHT++] = $ss77787779;
}
if(R.isPyretException($e77747775)) {
$e77747775.pyretStack.push(L[618]);
}
throw $e77747775;
}
var $ret77807781 = $Hanf_arg15895665($z77767777,self425667,_plus7,torepr13);
++R.GAS;
return $ret77807781;
};
},{"length":1});
var anf_singleton_variant_member2657699 = R.makeMethod(function(self457773) {
return function(cases_DASH_funs467754,else_DASH_clause477765) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[617],2,arguments);
}
var if_DASH_497766 = R.hasField(cases_DASH_funs467754,("b-typ"));
var if_helper2565658 = R.makeFunction(function(if_helper_arg2577771) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[617],1,arguments);
}
var ann_DASH_check_DASH_temp2557772 = if_helper_arg2577771;
return ann_DASH_check_DASH_temp2557772;
});
var anf_if2607770 = R.isBoolean(if_DASH_497766);
if(R.isPyretTrue(anf_if2607770)) {
if(R.isPyretTrue(if_DASH_497766)) {
var call_DASH_b_DASH_typ447753 = G(cases_DASH_funs467754,"b-typ",L[617]);
var $z77457746 = D;
var $f77517752 = function(_) {
return R.isFunction(call_DASH_b_DASH_typ447753)?call_DASH_b_DASH_typ447753.app():R.ffi.throwNonFunApp(L[617],call_DASH_b_DASH_typ447753,[]);
};
try {
if(--R.GAS > 0) {
$z77457746 = $f77517752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77517752,
"from":L[617]});
}
} catch($e77437744) {
if(R.isCont($e77437744)) {
var $ss77477748 = {"from":L[617],
"go":function(cont_tail_arg2635657) {
return $Hcont_tail_arg15905656(cont_tail_arg2635657,if_helper2565658);
}};
$e77437744.stack[R.EXN_STACKHEIGHT++] = $ss77477748;
}
if(R.isPyretException($e77437744)) {
$e77437744.pyretStack.push(L[617]);
}
throw $e77437744;
}
var $ret77497750 = $Hcont_tail_arg15905656($z77457746,if_helper2565658);
++R.GAS;
return $ret77497750;
} else {
var $z77577758 = D;
var $f77637764 = function(_) {
return R.isFunction(else_DASH_clause477765)?else_DASH_clause477765.app():R.ffi.throwNonFunApp(L[617],else_DASH_clause477765,[]);
};
try {
if(--R.GAS > 0) {
$z77577758 = $f77637764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77637764,
"from":L[617]});
}
} catch($e77557756) {
if(R.isCont($e77557756)) {
var $ss77597760 = {"from":L[617],
"go":function(cont_tail_arg2615662) {
return $Hcont_tail_arg15915661(cont_tail_arg2615662,if_helper2565658);
}};
$e77557756.stack[R.EXN_STACKHEIGHT++] = $ss77597760;
}
if(R.isPyretException($e77557756)) {
$e77557756.pyretStack.push(L[617]);
}
throw $e77557756;
}
var $ret77617762 = $Hcont_tail_arg15915661($z77577758,if_helper2565658);
++R.GAS;
return $ret77617762;
}
} else {
var cont_tail_arg2587769 = R.throwNonBooleanCondition(L[617],("if"),if_DASH_497766);
if(--R.GAS > 0) {
$z77677768 = R.isFunction(if_helper2565658)?if_helper2565658.app(cont_tail_arg2587769):R.ffi.throwNonFunApp(L[617],if_helper2565658,[cont_tail_arg2587769]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2565658)?if_helper2565658.app(cont_tail_arg2587769):R.ffi.throwNonFunApp(L[617],if_helper2565658,[cont_tail_arg2587769]);
},
"from":L[617]});
}
++R.GAS;
return $z77677768;
}
};
},{"length":3});
var anf_singleton_variant_member2677700 = R.makeMethod(function(self487742) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[617],0,arguments);
}
var ann_DASH_check_DASH_temp2667741 = ("b-typ");
return ann_DASH_check_DASH_temp2667741;
};
},{"length":1});
var anf_singleton_variant_member2787706 = R.makeMethod(function(self517740) {
return function(cases_DASH_funs527721,else_DASH_clause537732) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[616],2,arguments);
}
var if_DASH_557733 = R.hasField(cases_DASH_funs527721,("b-unknown"));
var if_helper2695649 = R.makeFunction(function(if_helper_arg2707738) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[616],1,arguments);
}
var ann_DASH_check_DASH_temp2687739 = if_helper_arg2707738;
return ann_DASH_check_DASH_temp2687739;
});
var anf_if2737737 = R.isBoolean(if_DASH_557733);
if(R.isPyretTrue(anf_if2737737)) {
if(R.isPyretTrue(if_DASH_557733)) {
var call_DASH_b_DASH_unknown507720 = G(cases_DASH_funs527721,"b-unknown",L[616]);
var $z77127713 = D;
var $f77187719 = function(_) {
return R.isFunction(call_DASH_b_DASH_unknown507720)?call_DASH_b_DASH_unknown507720.app():R.ffi.throwNonFunApp(L[616],call_DASH_b_DASH_unknown507720,[]);
};
try {
if(--R.GAS > 0) {
$z77127713 = $f77187719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77187719,
"from":L[616]});
}
} catch($e77107711) {
if(R.isCont($e77107711)) {
var $ss77147715 = {"from":L[616],
"go":function(cont_tail_arg2765648) {
return $Hcont_tail_arg15925647(cont_tail_arg2765648,if_helper2695649);
}};
$e77107711.stack[R.EXN_STACKHEIGHT++] = $ss77147715;
}
if(R.isPyretException($e77107711)) {
$e77107711.pyretStack.push(L[616]);
}
throw $e77107711;
}
var $ret77167717 = $Hcont_tail_arg15925647($z77127713,if_helper2695649);
++R.GAS;
return $ret77167717;
} else {
var $z77247725 = D;
var $f77307731 = function(_) {
return R.isFunction(else_DASH_clause537732)?else_DASH_clause537732.app():R.ffi.throwNonFunApp(L[616],else_DASH_clause537732,[]);
};
try {
if(--R.GAS > 0) {
$z77247725 = $f77307731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77307731,
"from":L[616]});
}
} catch($e77227723) {
if(R.isCont($e77227723)) {
var $ss77267727 = {"from":L[616],
"go":function(cont_tail_arg2745653) {
return $Hcont_tail_arg15935652(cont_tail_arg2745653,if_helper2695649);
}};
$e77227723.stack[R.EXN_STACKHEIGHT++] = $ss77267727;
}
if(R.isPyretException($e77227723)) {
$e77227723.pyretStack.push(L[616]);
}
throw $e77227723;
}
var $ret77287729 = $Hcont_tail_arg15935652($z77247725,if_helper2695649);
++R.GAS;
return $ret77287729;
}
} else {
var cont_tail_arg2717736 = R.throwNonBooleanCondition(L[616],("if"),if_DASH_557733);
if(--R.GAS > 0) {
$z77347735 = R.isFunction(if_helper2695649)?if_helper2695649.app(cont_tail_arg2717736):R.ffi.throwNonFunApp(L[616],if_helper2695649,[cont_tail_arg2717736]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2695649)?if_helper2695649.app(cont_tail_arg2717736):R.ffi.throwNonFunApp(L[616],if_helper2695649,[cont_tail_arg2717736]);
},
"from":L[616]});
}
++R.GAS;
return $z77347735;
}
};
},{"length":3});
var anf_singleton_variant_member2807707 = R.makeMethod(function(self547709) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[616],0,arguments);
}
var ann_DASH_check_DASH_temp2797708 = ("b-unknown");
return ann_DASH_check_DASH_temp2797708;
};
},{"length":1});
var anf_assign2816695 = (function() {
var $b_DASH_prim_DASH_base76617662 = {"_match":anf_variant_member1897666,
"_torepr":anf_variant_member1957667};
var $b_DASH_prim_DASH_brands76647665 = {"$brand-b-prim7663":true};
$b_DASH_prim_DASH_brands76647665[BindingInfoT2736688._brand] = true
var $b_DASH_dict_DASH_base76697670 = {"_match":anf_variant_member2077674,
"_torepr":anf_variant_member2137675};
var $b_DASH_dict_DASH_brands76727673 = {"$brand-b-dict7671":true};
$b_DASH_dict_DASH_brands76727673[BindingInfoT2736688._brand] = true
var $b_DASH_exp_DASH_base76777678 = {"_match":anf_variant_member2257682,
"_torepr":anf_variant_member2317683};
var $b_DASH_exp_DASH_brands76807681 = {"$brand-b-exp7679":true};
$b_DASH_exp_DASH_brands76807681[BindingInfoT2736688._brand] = true
var $b_DASH_dot_DASH_base76857686 = {"_match":anf_variant_member2447690,
"_torepr":anf_variant_member2547691};
var $b_DASH_dot_DASH_brands76887689 = {"$brand-b-dot7687":true};
$b_DASH_dot_DASH_brands76887689[BindingInfoT2736688._brand] = true
var $b_DASH_typ_DASH_base76947695 = {"_match":anf_singleton_variant_member2657699,
"_torepr":anf_singleton_variant_member2677700};
var $b_DASH_typ_DASH_brands76977698 = {"$brand-b-typ7696":true};
$b_DASH_typ_DASH_brands76977698[BindingInfoT2736688._brand] = true
var $b_DASH_unknown_DASH_base77017702 = {"_match":anf_singleton_variant_member2787706,
"_torepr":anf_singleton_variant_member2807707};
var $b_DASH_unknown_DASH_brands77047705 = {"$brand-b-unknown7703":true};
$b_DASH_unknown_DASH_brands77047705[BindingInfoT2736688._brand] = true
return R.makeObject({"BindingInfo":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[23],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,BindingInfoT2736688._brand));
}),
"is-b-prim":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[621],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-b-prim7663"));
}),
"b-prim":R.makeFunction(function(name1407668) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[904],1,arguments);
}
return R.checkAnnArgs([$type$String15],[name1407668],[L[905]],function() {
var dict = R.create($b_DASH_prim_DASH_base76617662);
dict["name"] = name1407668
return R.makeBrandedObject(dict,$b_DASH_prim_DASH_brands76647665);
});
}),
"is-b-dict":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[620],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-b-dict7671"));
}),
"b-dict":R.makeFunction(function(dict1417676) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[906],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[907],"SD",SD1031,"StringDict")],[dict1417676],[L[907]],function() {
var dict = R.create($b_DASH_dict_DASH_base76697670);
dict["dict"] = dict1417676
return R.makeBrandedObject(dict,$b_DASH_dict_DASH_brands76727673);
});
}),
"is-b-exp":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[619],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-b-exp7679"));
}),
"b-exp":R.makeFunction(function(exp1427684) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[908],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[909],"A",A428,"Expr")],[exp1427684],[L[909]],function() {
var dict = R.create($b_DASH_exp_DASH_base76777678);
dict["exp"] = exp1427684
return R.makeBrandedObject(dict,$b_DASH_exp_DASH_brands76807681);
});
}),
"is-b-dot":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[618],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-b-dot7687"));
}),
"b-dot":R.makeFunction(function(base1437692,name1447693) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[910],2,arguments);
}
return R.checkAnnArgs([BindingInfo7255,$type$String15],[base1437692,name1447693],[L[911],L[912]],function() {
var dict = R.create($b_DASH_dot_DASH_base76857686);
dict["base"] = base1437692
dict["name"] = name1447693
return R.makeBrandedObject(dict,$b_DASH_dot_DASH_brands76887689);
});
}),
"is-b-typ":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[617],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-b-typ7696"));
}),
"b-typ":R.makeBrandedObject($b_DASH_typ_DASH_base76947695,$b_DASH_typ_DASH_brands76977698),
"is-b-unknown":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[616],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-b-unknown7703"));
}),
"b-unknown":R.makeBrandedObject($b_DASH_unknown_DASH_base77017702,$b_DASH_unknown_DASH_brands77047705)});
})();
BindingInfo41076694.$var = anf_assign2816695;
var anf_assign2826696 = G(BindingInfo41076694.$var,"BindingInfo",L[23]);
BindingInfo10854.$var = anf_assign2826696;
var anf_assign2836697 = G(BindingInfo41076694.$var,"BindingInfo",L[23]);
is_DASH_BindingInfo10983.$var = anf_assign2836697;
var anf_assign2846698 = G(BindingInfo41076694.$var,"is-b-prim",L[621]);
is_DASH_b_DASH_prim11087.$var = anf_assign2846698;
var anf_assign2856699 = G(BindingInfo41076694.$var,"b-prim",L[621]);
b_DASH_prim11162.$var = anf_assign2856699;
var anf_assign2866700 = G(BindingInfo41076694.$var,"is-b-dict",L[620]);
is_DASH_b_DASH_dict11284.$var = anf_assign2866700;
var anf_assign2876701 = G(BindingInfo41076694.$var,"b-dict",L[620]);
b_DASH_dict11359.$var = anf_assign2876701;
var anf_assign2886702 = G(BindingInfo41076694.$var,"is-b-exp",L[619]);
is_DASH_b_DASH_exp11486.$var = anf_assign2886702;
var anf_assign2896703 = G(BindingInfo41076694.$var,"b-exp",L[619]);
b_DASH_exp11561.$var = anf_assign2896703;
var anf_assign2906704 = G(BindingInfo41076694.$var,"is-b-dot",L[618]);
is_DASH_b_DASH_dot11685.$var = anf_assign2906704;
var anf_assign2916705 = G(BindingInfo41076694.$var,"b-dot",L[618]);
b_DASH_dot11760.$var = anf_assign2916705;
var anf_assign2926706 = G(BindingInfo41076694.$var,"is-b-typ",L[617]);
is_DASH_b_DASH_typ11888.$var = anf_assign2926706;
var anf_assign2936707 = G(BindingInfo41076694.$var,"b-typ",L[617]);
b_DASH_typ11963.$var = anf_assign2936707;
var anf_assign2946708 = G(BindingInfo41076694.$var,"is-b-unknown",L[616]);
is_DASH_b_DASH_unknown12089.$var = anf_assign2946708;
var anf_assign2956709 = G(BindingInfo41076694.$var,"b-unknown",L[616]);
b_DASH_unknown12164.$var = anf_assign2956709;
var anf_variant_member3097611 = R.makeMethod(function(self577641) {
return function(cases_DASH_funs587642,else_DASH_clause597653) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[615],2,arguments);
}
var if_DASH_617654 = R.hasField(cases_DASH_funs587642,("e-bind"));
var if_helper2975640 = R.makeFunction(function(if_helper_arg2987659) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[615],1,arguments);
}
var ann_DASH_check_DASH_temp2967660 = if_helper_arg2987659;
return ann_DASH_check_DASH_temp2967660;
});
var anf_if3017658 = R.isBoolean(if_DASH_617654);
if(R.isPyretTrue(anf_if3017658)) {
if(R.isPyretTrue(if_DASH_617654)) {
var call_DASH_e_DASH_bind567637 = G(cases_DASH_funs587642,"e-bind",L[615]);
var anf_arg3047638 = G(self577641,"loc",L[903]);
var anf_arg3057639 = G(self577641,"mut",L[902]);
var anf_arg3067640 = G(self577641,"info",L[901]);
var $z76297630 = D;
var $f76357636 = function(_) {
return R.isFunction(call_DASH_e_DASH_bind567637)?call_DASH_e_DASH_bind567637.app(anf_arg3047638,anf_arg3057639,anf_arg3067640):R.ffi.throwNonFunApp(L[615],call_DASH_e_DASH_bind567637,[anf_arg3047638,anf_arg3057639,anf_arg3067640]);
};
try {
if(--R.GAS > 0) {
$z76297630 = $f76357636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76357636,
"from":L[615]});
}
} catch($e76277628) {
if(R.isCont($e76277628)) {
var $ss76317632 = {"from":L[615],
"go":function(cont_tail_arg3075639) {
return $Hcont_tail_arg15945638(cont_tail_arg3075639,if_helper2975640);
}};
$e76277628.stack[R.EXN_STACKHEIGHT++] = $ss76317632;
}
if(R.isPyretException($e76277628)) {
$e76277628.pyretStack.push(L[615]);
}
throw $e76277628;
}
var $ret76337634 = $Hcont_tail_arg15945638($z76297630,if_helper2975640);
++R.GAS;
return $ret76337634;
} else {
var $z76457646 = D;
var $f76517652 = function(_) {
return R.isFunction(else_DASH_clause597653)?else_DASH_clause597653.app():R.ffi.throwNonFunApp(L[615],else_DASH_clause597653,[]);
};
try {
if(--R.GAS > 0) {
$z76457646 = $f76517652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76517652,
"from":L[615]});
}
} catch($e76437644) {
if(R.isCont($e76437644)) {
var $ss76477648 = {"from":L[615],
"go":function(cont_tail_arg3025644) {
return $Hcont_tail_arg15955643(cont_tail_arg3025644,if_helper2975640);
}};
$e76437644.stack[R.EXN_STACKHEIGHT++] = $ss76477648;
}
if(R.isPyretException($e76437644)) {
$e76437644.pyretStack.push(L[615]);
}
throw $e76437644;
}
var $ret76497650 = $Hcont_tail_arg15955643($z76457646,if_helper2975640);
++R.GAS;
return $ret76497650;
}
} else {
var cont_tail_arg2997657 = R.throwNonBooleanCondition(L[615],("if"),if_DASH_617654);
if(--R.GAS > 0) {
$z76557656 = R.isFunction(if_helper2975640)?if_helper2975640.app(cont_tail_arg2997657):R.ffi.throwNonFunApp(L[615],if_helper2975640,[cont_tail_arg2997657]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored675) {
return R.isFunction(if_helper2975640)?if_helper2975640.app(cont_tail_arg2997657):R.ffi.throwNonFunApp(L[615],if_helper2975640,[cont_tail_arg2997657]);
},
"from":L[615]});
}
++R.GAS;
return $z76557656;
}
};
},{"length":3});
var anf_variant_member3237612 = R.makeMethod(function(self605527) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[615],0,arguments);
}
var anf_arg3117626 = G(self605527,"loc",L[615]);
var $z76187619 = D;
var $f76247625 = function(_) {
return R.isFunction(torepr13)?torepr13.app(anf_arg3117626):R.ffi.throwNonFunApp(L[615],torepr13,[anf_arg3117626]);
};
try {
if(--R.GAS > 0) {
$z76187619 = $f76247625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76247625,
"from":L[615]});
}
} catch($e76167617) {
if(R.isCont($e76167617)) {
var $ss76207621 = {"from":L[615],
"go":function(anf_arg3125526) {
return $Hanf_arg16055525(anf_arg3125526,self605527,_plus7,torepr13);
}};
$e76167617.stack[R.EXN_STACKHEIGHT++] = $ss76207621;
}
if(R.isPyretException($e76167617)) {
$e76167617.pyretStack.push(L[615]);
}
throw $e76167617;
}
var $ret76227623 = $Hanf_arg16055525($z76187619,self605527,_plus7,torepr13);
++R.GAS;
return $ret76227623;
};
},{"length":1});
var anf_assign3246711 = (function() {
var $e_DASH_bind_DASH_base76067607 = {"_match":anf_variant_member3097611,
"_torepr":anf_variant_member3237612};
var $e_DASH_bind_DASH_brands76097610 = {"$brand-e-bind7608":true};
$e_DASH_bind_DASH_brands76097610[BindingT3756689._brand] = true
return R.makeObject({"Binding":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[896],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,BindingT3756689._brand));
}),
"is-e-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[615],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-e-bind7608"));
}),
"e-bind":R.makeFunction(function(loc1457613,mut1467614,info1477615) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[897],3,arguments);
}
return R.checkAnnArgs([Loc7656,$type$Boolean14,BindingInfo7255],[loc1457613,mut1467614,info1477615],[L[898],L[899],L[900]],function() {
var dict = R.create($e_DASH_bind_DASH_base76067607);
dict["loc"] = loc1457613
dict["mut"] = mut1467614
dict["info"] = info1477615
return R.makeBrandedObject(dict,$e_DASH_bind_DASH_brands76097610);
});
})});
})();
Binding51226710.$var = anf_assign3246711;
var anf_assign3256712 = G(Binding51226710.$var,"Binding",L[896]);
Binding12352.$var = anf_assign3256712;
var anf_assign3266713 = G(Binding51226710.$var,"Binding",L[896]);
is_DASH_Binding12482.$var = anf_assign3266713;
var anf_assign3276714 = G(Binding51226710.$var,"is-e-bind",L[615]);
is_DASH_e_DASH_bind12590.$var = anf_assign3276714;
var anf_assign3286715 = G(Binding51226710.$var,"e-bind",L[615]);
e_DASH_bind12678.$var = anf_assign3286715;
var anf_assign4286716 = R.makeFunction(function(e1487528,env1495097) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[880],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[895],"A",A428,"Expr")],[e1487528],[L[895]],function() {
var cases_DASH_val687605 = e1487528;
var anf_fun3307539 = G(cases_DASH_val687605,"_match",L[568]);
var anf_obj3707552 = R.makeFunction(function(l1507593,o1517594,name1525323) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[590],3,arguments);
}
var $z75977598 = D;
var $f76037604 = function(_) {
return R.isFunction(bind_DASH_exp12766.$var)?bind_DASH_exp12766.$var.app(o1517594,env1495097):R.ffi.throwNonFunApp(L[591],bind_DASH_exp12766.$var,[o1517594,env1495097]);
};
try {
if(--R.GAS > 0) {
$z75977598 = $f76037604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76037604,
"from":L[591]});
}
} catch($e75957596) {
if(R.isCont($e75957596)) {
var $ss75997600 = {"from":L[591],
"go":function(cases_DASH_val645322) {
return $Hcases_DASH_val16205321(cases_DASH_val645322,A317,b_DASH_dot11760,e_DASH_bind12678,name1525323,none675099,some685069);
}};
$e75957596.stack[R.EXN_STACKHEIGHT++] = $ss75997600;
}
if(R.isPyretException($e75957596)) {
$e75957596.pyretStack.push(L[591]);
}
throw $e75957596;
}
var $ret76017602 = $Hcases_DASH_val16205321($z75977598,A317,b_DASH_dot11760,e_DASH_bind12678,name1525323,none675099,some685069);
++R.GAS;
return $ret76017602;
});
var anf_obj3877553 = R.makeFunction(function($underscore1567581,name1575249) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[891],2,arguments);
}
var anf_fun3725248 = G(env1495097,"has-key",L[894]);
var anf_fun3737592 = G(name1575249,"key",L[893]);
var $z75847585 = D;
var $f75907591 = function(_) {
return R.isFunction(anf_fun3737592)?anf_fun3737592.app():R.ffi.throwNonFunApp(L[892],anf_fun3737592,[]);
};
try {
if(--R.GAS > 0) {
$z75847585 = $f75907591();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75907591,
"from":L[892]});
}
} catch($e75827583) {
if(R.isCont($e75827583)) {
var $ss75867587 = {"from":L[892],
"go":function(anf_arg3745247) {
return $Hanf_arg16265246(anf_arg3745247,anf_fun3725248,env1495097,name1575249,none675099,some685069);
}};
$e75827583.stack[R.EXN_STACKHEIGHT++] = $ss75867587;
}
if(R.isPyretException($e75827583)) {
$e75827583.pyretStack.push(L[892]);
}
throw $e75827583;
}
var $ret75887589 = $Hanf_arg16265246($z75847585,anf_fun3725248,env1495097,name1575249,none675099,some685069);
++R.GAS;
return $ret75887589;
});
var anf_obj4047554 = R.makeFunction(function($underscore1587569,name1595174) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[887],2,arguments);
}
var anf_fun3895173 = G(env1495097,"has-key",L[890]);
var anf_fun3907580 = G(name1595174,"key",L[889]);
var $z75727573 = D;
var $f75787579 = function(_) {
return R.isFunction(anf_fun3907580)?anf_fun3907580.app():R.ffi.throwNonFunApp(L[888],anf_fun3907580,[]);
};
try {
if(--R.GAS > 0) {
$z75727573 = $f75787579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75787579,
"from":L[888]});
}
} catch($e75707571) {
if(R.isCont($e75707571)) {
var $ss75747575 = {"from":L[888],
"go":function(anf_arg3915172) {
return $Hanf_arg16325171(anf_arg3915172,anf_fun3895173,env1495097,name1595174,none675099,some685069);
}};
$e75707571.stack[R.EXN_STACKHEIGHT++] = $ss75747575;
}
if(R.isPyretException($e75707571)) {
$e75707571.pyretStack.push(L[888]);
}
throw $e75707571;
}
var $ret75767577 = $Hanf_arg16325171($z75727573,anf_fun3895173,env1495097,name1595174,none675099,some685069);
++R.GAS;
return $ret75767577;
});
var anf_obj4217555 = R.makeFunction(function($underscore1607556,name1615098,$underscore1627557) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[883],3,arguments);
}
var anf_fun4065096 = G(env1495097,"has-key",L[886]);
var anf_fun4077568 = G(name1615098,"key",L[885]);
var $z75607561 = D;
var $f75667567 = function(_) {
return R.isFunction(anf_fun4077568)?anf_fun4077568.app():R.ffi.throwNonFunApp(L[884],anf_fun4077568,[]);
};
try {
if(--R.GAS > 0) {
$z75607561 = $f75667567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75667567,
"from":L[884]});
}
} catch($e75587559) {
if(R.isCont($e75587559)) {
var $ss75627563 = {"from":L[884],
"go":function(anf_arg4085095) {
return $Hanf_arg16385094(anf_arg4085095,anf_fun4065096,env1495097,name1615098,none675099,some685069);
}};
$e75587559.stack[R.EXN_STACKHEIGHT++] = $ss75627563;
}
if(R.isPyretException($e75587559)) {
$e75587559.pyretStack.push(L[884]);
}
throw $e75587559;
}
var $ret75647565 = $Hanf_arg16385094($z75607561,anf_fun4065096,env1495097,name1615098,none675099,some685069);
++R.GAS;
return $ret75647565;
});
var anf_arg4227540 = R.makeObject({"s-dot":anf_obj3707552,
"s-id":anf_obj3877553,
"s-id-var":anf_obj4047554,
"s-id-letrec":anf_obj4217555});
var anf_arg4277541 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[568],0,arguments);
}
var anf_arg4245068 = G(A317,"dummy-loc",L[882]);
var $z75447545 = D;
var $f75507551 = function(_) {
return R.isFunction(b_DASH_exp11561.$var)?b_DASH_exp11561.$var.app(e1487528):R.ffi.throwNonFunApp(L[881],b_DASH_exp11561.$var,[e1487528]);
};
try {
if(--R.GAS > 0) {
$z75447545 = $f75507551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75507551,
"from":L[881]});
}
} catch($e75427543) {
if(R.isCont($e75427543)) {
var $ss75467547 = {"from":L[881],
"go":function(anf_arg4255067) {
return $Hanf_arg16415066(anf_arg4255067,anf_arg4245068,e_DASH_bind12678,some685069);
}};
$e75427543.stack[R.EXN_STACKHEIGHT++] = $ss75467547;
}
if(R.isPyretException($e75427543)) {
$e75427543.pyretStack.push(L[881]);
}
throw $e75427543;
}
var $ret75487549 = $Hanf_arg16415066($z75447545,anf_arg4245068,e_DASH_bind12678,some685069);
++R.GAS;
return $ret75487549;
});
var $z75317532 = D;
var $f75377538 = function(_) {
return R.isFunction(anf_fun3307539)?anf_fun3307539.app(anf_arg4227540,anf_arg4277541):R.ffi.throwNonFunApp(L[880],anf_fun3307539,[anf_arg4227540,anf_arg4277541]);
};
try {
if(--R.GAS > 0) {
$z75317532 = $f75377538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75377538,
"from":L[880]});
}
} catch($e75297530) {
if(R.isCont($e75297530)) {
var $ss75337534 = {"from":L[880],
"go":function(ann_DASH_check_DASH_temp3295064) {
return $Hann_DASH_check_DASH_temp16425063(ann_DASH_check_DASH_temp3295064,Binding7453,Option245065);
}};
$e75297530.stack[R.EXN_STACKHEIGHT++] = $ss75337534;
}
if(R.isPyretException($e75297530)) {
$e75297530.pyretStack.push(L[880]);
}
throw $e75297530;
}
var $ret75357536 = $Hann_DASH_check_DASH_temp16425063($z75317532,Binding7453,Option245065);
++R.GAS;
return $ret75357536;
});
});
bind_DASH_exp12766.$var = anf_assign4286716;
var anf_assign4496717 = R.makeFunction(function(e1634927,env1647517) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[554],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[879],"A",A428,"Expr")],[e1634927],[L[879]],function() {
var $z75207521 = D;
var $f75267527 = function(_) {
return R.isFunction(bind_DASH_exp12766.$var)?bind_DASH_exp12766.$var.app(e1634927,env1647517):R.ffi.throwNonFunApp(L[555],bind_DASH_exp12766.$var,[e1634927,env1647517]);
};
try {
if(--R.GAS > 0) {
$z75207521 = $f75267527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75267527,
"from":L[555]});
}
} catch($e75187519) {
if(R.isCont($e75187519)) {
var $ss75227523 = {"from":L[555],
"go":function(cases_DASH_val704926) {
return $Hcases_DASH_val16554925(cases_DASH_val704926,BindingInfo7255,b_DASH_unknown12164,e1634927,is_DASH_e_DASH_bind12590,_plus7,not9,nothing10,print_DASH_error11,string_DASH_substring12,torepr13);
}};
$e75187519.stack[R.EXN_STACKHEIGHT++] = $ss75227523;
}
if(R.isPyretException($e75187519)) {
$e75187519.pyretStack.push(L[555]);
}
throw $e75187519;
}
var $ret75247525 = $Hcases_DASH_val16554925($z75207521,BindingInfo7255,b_DASH_unknown12164,e1634927,is_DASH_e_DASH_bind12590,_plus7,not9,nothing10,print_DASH_error11,string_DASH_substring12,torepr13);
++R.GAS;
return $ret75247525;
});
});
bind_DASH_or_DASH_unknown12867.$var = anf_assign4496717;
var anf_assign4946718 = R.makeFunction(function(initial_DASH_env1664743) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[531],1,arguments);
}
var anf_fun4514742 = G(lists1523,"fold",L[878]);
var anf_arg4904741 = R.makeFunction(function(acc1674802,binding1687462) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[866],2,arguments);
}
var cases_DASH_val717516 = binding1687462;
var anf_fun4537473 = G(cases_DASH_val717516,"_match",L[867]);
var anf_obj4777477 = R.makeFunction(function(name1694806,ids1704805) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[548],2,arguments);
}
var anf_fun4554804 = G(lists1523,"fold",L[877]);
var anf_arg4654803 = R.makeFunction(function(m1727502,b1737503) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[553],2,arguments);
}
var anf_fun4574886 = G(m1727502,"set",L[876]);
var anf_fun4587514 = G(A317,"s-name",L[875]);
var anf_arg4597515 = G(A317,"dummy-loc",L[874]);
var $z75067507 = D;
var $f75127513 = function(_) {
return R.isFunction(anf_fun4587514)?anf_fun4587514.app(anf_arg4597515,b1737503):R.ffi.throwNonFunApp(L[873],anf_fun4587514,[anf_arg4597515,b1737503]);
};
try {
if(--R.GAS > 0) {
$z75067507 = $f75127513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75127513,
"from":L[873]});
}
} catch($e75047505) {
if(R.isCont($e75047505)) {
var $ss75087509 = {"from":L[873],
"go":function(anf_bracket4604885) {
return $Hanf_bracket16594884(anf_bracket4604885,A317,anf_fun4574886,b_DASH_typ11963,e_DASH_bind12678);
}};
$e75047505.stack[R.EXN_STACKHEIGHT++] = $ss75087509;
}
if(R.isPyretException($e75047505)) {
$e75047505.pyretStack.push(L[873]);
}
throw $e75047505;
}
var $ret75107511 = $Hanf_bracket16594884($z75067507,A317,anf_fun4574886,b_DASH_typ11963,e_DASH_bind12678);
++R.GAS;
return $ret75107511;
});
var anf_fun4667501 = G(SD920,"immutable-string-dict",L[872]);
var $z74937494 = D;
var $f74997500 = function(_) {
return R.isFunction(anf_fun4667501)?anf_fun4667501.app():R.ffi.throwNonFunApp(L[871],anf_fun4667501,[]);
};
try {
if(--R.GAS > 0) {
$z74937494 = $f74997500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74997500,
"from":L[871]});
}
} catch($e74917492) {
if(R.isCont($e74917492)) {
var $ss74957496 = {"from":L[871],
"go":function(anf_arg4674801) {
return $Hanf_arg16664800(anf_arg4674801,A317,acc1674802,anf_arg4654803,anf_fun4554804,b_DASH_dict11359,e_DASH_bind12678,ids1704805,name1694806);
}};
$e74917492.stack[R.EXN_STACKHEIGHT++] = $ss74957496;
}
if(R.isPyretException($e74917492)) {
$e74917492.pyretStack.push(L[871]);
}
throw $e74917492;
}
var $ret74977498 = $Hanf_arg16664800($z74937494,A317,acc1674802,anf_arg4654803,anf_fun4554804,b_DASH_dict11359,e_DASH_bind12678,ids1704805,name1694806);
++R.GAS;
return $ret74977498;
});
var anf_obj4867478 = R.makeFunction(function(name1747479) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[537],1,arguments);
}
var anf_fun4794761 = G(acc1674802,"set",L[870]);
var anf_fun4807490 = G(A317,"s-type-global",L[869]);
var $z74827483 = D;
var $f74887489 = function(_) {
return R.isFunction(anf_fun4807490)?anf_fun4807490.app(name1747479):R.ffi.throwNonFunApp(L[868],anf_fun4807490,[name1747479]);
};
try {
if(--R.GAS > 0) {
$z74827483 = $f74887489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74887489,
"from":L[868]});
}
} catch($e74807481) {
if(R.isCont($e74807481)) {
var $ss74847485 = {"from":L[868],
"go":function(anf_bracket4814760) {
return $Hanf_bracket16704759(anf_bracket4814760,A317,anf_fun4794761,b_DASH_typ11963,e_DASH_bind12678);
}};
$e74807481.stack[R.EXN_STACKHEIGHT++] = $ss74847485;
}
if(R.isPyretException($e74807481)) {
$e74807481.pyretStack.push(L[868]);
}
throw $e74807481;
}
var $ret74867487 = $Hanf_bracket16704759($z74827483,A317,anf_fun4794761,b_DASH_typ11963,e_DASH_bind12678);
++R.GAS;
return $ret74867487;
});
var anf_arg4877474 = R.makeObject({"type-module-bindings":anf_obj4777477,
"type-id":anf_obj4867478});
var anf_arg4897475 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[867],0,arguments);
}
var ann_DASH_check_DASH_temp4887476 = R.throwNoBranchesMatched(L[867],("cases"));
return ann_DASH_check_DASH_temp4887476;
});
var $z74657466 = D;
var $f74717472 = function(_) {
return R.isFunction(anf_fun4537473)?anf_fun4537473.app(anf_arg4877474,anf_arg4897475):R.ffi.throwNonFunApp(L[866],anf_fun4537473,[anf_arg4877474,anf_arg4897475]);
};
try {
if(--R.GAS > 0) {
$z74657466 = $f74717472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74717472,
"from":L[866]});
}
} catch($e74637464) {
if(R.isCont($e74637464)) {
var $ss74677468 = {"from":L[866],
"go":function(ann_DASH_check_DASH_temp4524758) {
return $Hann_DASH_check_DASH_temp16714757(ann_DASH_check_DASH_temp4524758);
}};
$e74637464.stack[R.EXN_STACKHEIGHT++] = $ss74677468;
}
if(R.isPyretException($e74637464)) {
$e74637464.pyretStack.push(L[866]);
}
throw $e74637464;
}
var $ret74697470 = $Hann_DASH_check_DASH_temp16714757($z74657466);
++R.GAS;
return $ret74697470;
});
var anf_fun4917461 = G(SD920,"immutable-string-dict",L[865]);
var $z74537454 = D;
var $f74597460 = function(_) {
return R.isFunction(anf_fun4917461)?anf_fun4917461.app():R.ffi.throwNonFunApp(L[864],anf_fun4917461,[]);
};
try {
if(--R.GAS > 0) {
$z74537454 = $f74597460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74597460,
"from":L[864]});
}
} catch($e74517452) {
if(R.isCont($e74517452)) {
var $ss74557456 = {"from":L[864],
"go":function(anf_arg4924740) {
return $Hanf_arg16734739(anf_arg4924740,anf_arg4904741,anf_fun4514742,initial_DASH_env1664743);
}};
$e74517452.stack[R.EXN_STACKHEIGHT++] = $ss74557456;
}
if(R.isPyretException($e74517452)) {
$e74517452.pyretStack.push(L[864]);
}
throw $e74517452;
}
var $ret74577458 = $Hanf_arg16734739($z74537454,anf_arg4904741,anf_fun4514742,initial_DASH_env1664743);
++R.GAS;
return $ret74577458;
});
binding_DASH_type_DASH_env_DASH_from_DASH_env12972.$var = anf_assign4946718;
var anf_assign5436719 = R.makeFunction(function(initial_DASH_env1754507) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[505],1,arguments);
}
var anf_fun4964506 = G(lists1523,"fold",L[863]);
var anf_arg5394505 = R.makeFunction(function(acc1764579,binding1777398) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[851],2,arguments);
}
var cases_DASH_val727450 = binding1777398;
var anf_fun4987409 = G(cases_DASH_val727450,"_match",L[852]);
var anf_obj5257413 = R.makeFunction(function(name1784583,ids1794582) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[523],2,arguments);
}
var anf_fun5004581 = G(lists1523,"fold",L[862]);
var anf_arg5134580 = R.makeFunction(function(m1817437,b1824664) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[530],2,arguments);
}
var anf_fun5024663 = G(m1817437,"set",L[861]);
var anf_fun5037448 = G(A317,"s-name",L[860]);
var anf_arg5047449 = G(A317,"dummy-loc",L[859]);
var $z74407441 = D;
var $f74467447 = function(_) {
return R.isFunction(anf_fun5037448)?anf_fun5037448.app(anf_arg5047449,b1824664):R.ffi.throwNonFunApp(L[858],anf_fun5037448,[anf_arg5047449,b1824664]);
};
try {
if(--R.GAS > 0) {
$z74407441 = $f74467447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74467447,
"from":L[858]});
}
} catch($e74387439) {
if(R.isCont($e74387439)) {
var $ss74427443 = {"from":L[858],
"go":function(anf_bracket5054662) {
return $Hanf_bracket16804661(anf_bracket5054662,A317,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,name1784583,_plus7);
}};
$e74387439.stack[R.EXN_STACKHEIGHT++] = $ss74427443;
}
if(R.isPyretException($e74387439)) {
$e74387439.pyretStack.push(L[858]);
}
throw $e74387439;
}
var $ret74447445 = $Hanf_bracket16804661($z74407441,A317,anf_fun5024663,b_DASH_prim11162,b1824664,e_DASH_bind12678,name1784583,_plus7);
++R.GAS;
return $ret74447445;
});
var anf_fun5147436 = G(SD920,"immutable-string-dict",L[857]);
var $z74287429 = D;
var $f74347435 = function(_) {
return R.isFunction(anf_fun5147436)?anf_fun5147436.app():R.ffi.throwNonFunApp(L[856],anf_fun5147436,[]);
};
try {
if(--R.GAS > 0) {
$z74287429 = $f74347435();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74347435,
"from":L[856]});
}
} catch($e74267427) {
if(R.isCont($e74267427)) {
var $ss74307431 = {"from":L[856],
"go":function(anf_arg5154578) {
return $Hanf_arg16874577(anf_arg5154578,A317,acc1764579,anf_arg5134580,anf_fun5004581,b_DASH_dict11359,e_DASH_bind12678,ids1794582,name1784583);
}};
$e74267427.stack[R.EXN_STACKHEIGHT++] = $ss74307431;
}
if(R.isPyretException($e74267427)) {
$e74267427.pyretStack.push(L[856]);
}
throw $e74267427;
}
var $ret74327433 = $Hanf_arg16874577($z74287429,A317,acc1764579,anf_arg5134580,anf_fun5004581,b_DASH_dict11359,e_DASH_bind12678,ids1794582,name1784583);
++R.GAS;
return $ret74327433;
});
var anf_obj5357414 = R.makeFunction(function(name1834526) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[512],1,arguments);
}
var anf_fun5274525 = G(acc1764579,"set",L[855]);
var anf_fun5287425 = G(A317,"s-global",L[854]);
var $z74177418 = D;
var $f74237424 = function(_) {
return R.isFunction(anf_fun5287425)?anf_fun5287425.app(name1834526):R.ffi.throwNonFunApp(L[853],anf_fun5287425,[name1834526]);
};
try {
if(--R.GAS > 0) {
$z74177418 = $f74237424();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74237424,
"from":L[853]});
}
} catch($e74157416) {
if(R.isCont($e74157416)) {
var $ss74197420 = {"from":L[853],
"go":function(anf_bracket5294524) {
return $Hanf_bracket16924523(anf_bracket5294524,A317,anf_fun5274525,b_DASH_prim11162,e_DASH_bind12678,name1834526);
}};
$e74157416.stack[R.EXN_STACKHEIGHT++] = $ss74197420;
}
if(R.isPyretException($e74157416)) {
$e74157416.pyretStack.push(L[853]);
}
throw $e74157416;
}
var $ret74217422 = $Hanf_bracket16924523($z74177418,A317,anf_fun5274525,b_DASH_prim11162,e_DASH_bind12678,name1834526);
++R.GAS;
return $ret74217422;
});
var anf_arg5367410 = R.makeObject({"module-bindings":anf_obj5257413,
"builtin-id":anf_obj5357414});
var anf_arg5387411 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[852],0,arguments);
}
var ann_DASH_check_DASH_temp5377412 = R.throwNoBranchesMatched(L[852],("cases"));
return ann_DASH_check_DASH_temp5377412;
});
var $z74017402 = D;
var $f74077408 = function(_) {
return R.isFunction(anf_fun4987409)?anf_fun4987409.app(anf_arg5367410,anf_arg5387411):R.ffi.throwNonFunApp(L[851],anf_fun4987409,[anf_arg5367410,anf_arg5387411]);
};
try {
if(--R.GAS > 0) {
$z74017402 = $f74077408();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74077408,
"from":L[851]});
}
} catch($e73997400) {
if(R.isCont($e73997400)) {
var $ss74037404 = {"from":L[851],
"go":function(ann_DASH_check_DASH_temp4974522) {
return $Hann_DASH_check_DASH_temp16934521(ann_DASH_check_DASH_temp4974522);
}};
$e73997400.stack[R.EXN_STACKHEIGHT++] = $ss74037404;
}
if(R.isPyretException($e73997400)) {
$e73997400.pyretStack.push(L[851]);
}
throw $e73997400;
}
var $ret74057406 = $Hann_DASH_check_DASH_temp16934521($z74017402);
++R.GAS;
return $ret74057406;
});
var anf_fun5407397 = G(SD920,"immutable-string-dict",L[850]);
var $z73897390 = D;
var $f73957396 = function(_) {
return R.isFunction(anf_fun5407397)?anf_fun5407397.app():R.ffi.throwNonFunApp(L[849],anf_fun5407397,[]);
};
try {
if(--R.GAS > 0) {
$z73897390 = $f73957396();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73957396,
"from":L[849]});
}
} catch($e73877388) {
if(R.isCont($e73877388)) {
var $ss73917392 = {"from":L[849],
"go":function(anf_arg5414504) {
return $Hanf_arg16954503(anf_arg5414504,anf_arg5394505,anf_fun4964506,initial_DASH_env1754507);
}};
$e73877388.stack[R.EXN_STACKHEIGHT++] = $ss73917392;
}
if(R.isPyretException($e73877388)) {
$e73877388.pyretStack.push(L[849]);
}
throw $e73877388;
}
var $ret73937394 = $Hanf_arg16954503($z73897390,anf_arg5394505,anf_fun4964506,initial_DASH_env1754507);
++R.GAS;
return $ret73937394;
});
binding_DASH_env_DASH_from_DASH_env13068.$var = anf_assign5436719;
var anf_assign6906720 = R.makeFunction(function(initial_DASH_env1867211,initial_DASH_type_DASH_env1877212,bind_DASH_handlers1883797) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[806],3,arguments);
}
return R.checkAnnArgs([R.makeRecordAnn(["s-letrec-bind","s-let-bind","s-bind","s-header","s-type-let-bind","s-param-bind"],[L[842],L[843],L[844],L[845],L[846],L[847]],{"s-letrec-bind":R.Function,
"s-let-bind":R.Function,
"s-bind":R.Function,
"s-header":R.Function,
"s-type-let-bind":R.Function,
"s-param-bind":R.Function})],[bind_DASH_handlers1883797],[L[848]],function() {
var anf_extend5457214 = G(A317,"default-map-visitor",L[841]);
var anf_extend5647215 = R.makeMethod(function(self1894400) {
return function(l1904398,_provide1917386,_provide_DASH_types1924395,imports1934397,body1944396) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[503],5,arguments);
}
var anf_fun5477385 = G(_provide1917386,"visit",L[840]);
var $z73777378 = D;
var $f73837384 = function(_) {
return R.isFunction(anf_fun5477385)?anf_fun5477385.app(self1894400):R.ffi.throwNonFunApp(L[839],anf_fun5477385,[self1894400]);
};
try {
if(--R.GAS > 0) {
$z73777378 = $f73837384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73837384,
"from":L[839]});
}
} catch($e73757376) {
if(R.isCont($e73757376)) {
var $ss73797380 = {"from":L[839],
"go":function(visit_DASH_provide1954394) {
return $Hvisit_DASH_provide17034393(visit_DASH_provide1954394,A317,_provide_DASH_types1924395,bind_DASH_handlers1883797,body1944396,fold593614,imports1934397,l1904398,map434399,self1894400);
}};
$e73757376.stack[R.EXN_STACKHEIGHT++] = $ss73797380;
}
if(R.isPyretException($e73757376)) {
$e73757376.pyretStack.push(L[839]);
}
throw $e73757376;
}
var $ret73817382 = $Hvisit_DASH_provide17034393($z73777378,A317,_provide_DASH_types1924395,bind_DASH_handlers1883797,body1944396,fold593614,imports1934397,l1904398,map434399,self1894400);
++R.GAS;
return $ret73817382;
};
},{"length":6});
var anf_extend5897216 = R.makeMethod(function(self2044315) {
return function(l2054313,binds2064311,body2074312) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[480],3,arguments);
}
var anf_obj5667373 = G(self2044315,"env",L[838]);
var anf_obj5677374 = G(self2044315,"type-env",L[837]);
var new_DASH_envs2084314 = R.makeObject({"val-env":anf_obj5667373,
"type-env":anf_obj5677374});
var anf_fun5684310 = G(lists1523,"fold",L[836]);
var anf_arg5784309 = R.makeFunction(function(acc2104361,b2114362) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[831],2,arguments);
}
var anf_fun5707370 = G(bind_DASH_handlers1883797,"s-type-let-bind",L[835]);
var anf_arg5717371 = G(acc2104361,"val-env",L[834]);
var anf_arg5727372 = G(acc2104361,"type-env",L[833]);
var $z73627363 = D;
var $f73687369 = function(_) {
return R.isFunction(anf_fun5707370)?anf_fun5707370.app(b2114362,anf_arg5717371,anf_arg5727372):R.ffi.throwNonFunApp(L[832],anf_fun5707370,[b2114362,anf_arg5717371,anf_arg5727372]);
};
try {
if(--R.GAS > 0) {
$z73627363 = $f73687369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73687369,
"from":L[832]});
}
} catch($e73607361) {
if(R.isCont($e73607361)) {
var $ss73647365 = {"from":L[832],
"go":function(updated2124360) {
return $Hupdated17064359(updated2124360,acc2104361,b2114362,link35745,self2044315);
}};
$e73607361.stack[R.EXN_STACKHEIGHT++] = $ss73647365;
}
if(R.isPyretException($e73607361)) {
$e73607361.pyretStack.push(L[832]);
}
throw $e73607361;
}
var $ret73667367 = $Hupdated17064359($z73627363,acc2104361,b2114362,link35745,self2044315);
++R.GAS;
return $ret73667367;
});
var anf_fun5797359 = G(list3192,"make",L[830]);
var $z73517352 = D;
var $f73577358 = function(_) {
return R.isFunction(anf_fun5797359)?anf_fun5797359.app([]):R.ffi.throwNonFunApp(L[830],anf_fun5797359,[[]]);
};
try {
if(--R.GAS > 0) {
$z73517352 = $f73577358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73577358,
"from":L[830]});
}
} catch($e73497350) {
if(R.isCont($e73497350)) {
var $ss73537354 = {"from":L[830],
"go":function(anf_extend5804308) {
return $Hanf_extend17104307(anf_extend5804308,A317,anf_arg5784309,anf_fun5684310,binds2064311,body2074312,l2054313,new_DASH_envs2084314,self2044315);
}};
$e73497350.stack[R.EXN_STACKHEIGHT++] = $ss73537354;
}
if(R.isPyretException($e73497350)) {
$e73497350.pyretStack.push(L[830]);
}
throw $e73497350;
}
var $ret73557356 = $Hanf_extend17104307($z73517352,A317,anf_arg5784309,anf_fun5684310,binds2064311,body2074312,l2054313,new_DASH_envs2084314,self2044315);
++R.GAS;
return $ret73557356;
};
},{"length":4});
var anf_extend6107217 = R.makeMethod(function(self2154220) {
return function(l2164219,binds2174217,body2184218) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[466],3,arguments);
}
var anf_arg5994215 = R.makeFunction(function(acc2204278,b2217335) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[826],2,arguments);
}
var anf_fun5927346 = G(b2217335,"visit",L[829]);
var anf_extend5937348 = G(acc2204278,"e",L[828]);
var anf_arg5947347 = self2154220.extendWith({"env":anf_extend5937348});
var $z73387339 = D;
var $f73447345 = function(_) {
return R.isFunction(anf_fun5927346)?anf_fun5927346.app(anf_arg5947347):R.ffi.throwNonFunApp(L[827],anf_fun5927346,[anf_arg5947347]);
};
try {
if(--R.GAS > 0) {
$z73387339 = $f73447345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73447345,
"from":L[827]});
}
} catch($e73367337) {
if(R.isCont($e73367337)) {
var $ss73407341 = {"from":L[827],
"go":function(new_DASH_bind2224277) {
return $Hnew_DASH_bind17134276(new_DASH_bind2224277,acc2204278,bind_DASH_handlers1883797,link35745);
}};
$e73367337.stack[R.EXN_STACKHEIGHT++] = $ss73407341;
}
if(R.isPyretException($e73367337)) {
$e73367337.pyretStack.push(L[827]);
}
throw $e73367337;
}
var $ret73427343 = $Hnew_DASH_bind17134276($z73387339,acc2204278,bind_DASH_handlers1883797,link35745);
++R.GAS;
return $ret73427343;
});
var anf_obj6004216 = G(self2154220,"env",L[825]);
var anf_fun6017334 = G(list3192,"make",L[824]);
var $z73267327 = D;
var $f73327333 = function(_) {
return R.isFunction(anf_fun6017334)?anf_fun6017334.app([]):R.ffi.throwNonFunApp(L[824],anf_fun6017334,[[]]);
};
try {
if(--R.GAS > 0) {
$z73267327 = $f73327333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73327333,
"from":L[824]});
}
} catch($e73247325) {
if(R.isCont($e73247325)) {
var $ss73287329 = {"from":L[824],
"go":function(anf_obj6024214) {
return $Hanf_obj17184213(anf_obj6024214,A317,anf_arg5994215,anf_obj6004216,binds2174217,body2184218,fold593614,l2164219,self2154220);
}};
$e73247325.stack[R.EXN_STACKHEIGHT++] = $ss73287329;
}
if(R.isPyretException($e73247325)) {
$e73247325.pyretStack.push(L[824]);
}
throw $e73247325;
}
var $ret73307331 = $Hanf_obj17184213($z73267327,A317,anf_arg5994215,anf_obj6004216,binds2174217,body2184218,fold593614,l2164219,self2154220);
++R.GAS;
return $ret73307331;
};
},{"length":4});
var anf_extend6227218 = R.makeMethod(function(self2264155) {
return function(l2274154,binds2284152,body2294153) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[457],3,arguments);
}
var anf_arg6147309 = R.makeFunction(function(acc2317311,b2327312) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[822],2,arguments);
}
var anf_fun6137323 = G(bind_DASH_handlers1883797,"s-letrec-bind",L[823]);
var $z73157316 = D;
var $f73217322 = function(_) {
return R.isFunction(anf_fun6137323)?anf_fun6137323.app(b2327312,acc2317311):R.ffi.throwNonFunApp(L[822],anf_fun6137323,[b2327312,acc2317311]);
};
try {
if(--R.GAS > 0) {
$z73157316 = $f73217322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73217322,
"from":L[822]});
}
} catch($e73137314) {
if(R.isCont($e73137314)) {
var $ss73177318 = {"from":L[822],
"go":function(ann_DASH_check_DASH_temp6124212) {
return $Hann_DASH_check_DASH_temp17194211(ann_DASH_check_DASH_temp6124212);
}};
$e73137314.stack[R.EXN_STACKHEIGHT++] = $ss73177318;
}
if(R.isPyretException($e73137314)) {
$e73137314.pyretStack.push(L[822]);
}
throw $e73137314;
}
var $ret73197320 = $Hann_DASH_check_DASH_temp17194211($z73157316);
++R.GAS;
return $ret73197320;
});
var anf_arg6157310 = G(self2264155,"env",L[821]);
var $z73017302 = D;
var $f73077308 = function(_) {
return R.isFunction(fold593614)?fold593614.app(anf_arg6147309,anf_arg6157310,binds2284152):R.ffi.throwNonFunApp(L[820],fold593614,[anf_arg6147309,anf_arg6157310,binds2284152]);
};
try {
if(--R.GAS > 0) {
$z73017302 = $f73077308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73077308,
"from":L[820]});
}
} catch($e72997300) {
if(R.isCont($e72997300)) {
var $ss73037304 = {"from":L[820],
"go":function(bind_DASH_env2304151) {
return $Hbind_DASH_env17244150(bind_DASH_env2304151,A317,binds2284152,body2294153,l2274154,self2264155);
}};
$e72997300.stack[R.EXN_STACKHEIGHT++] = $ss73037304;
}
if(R.isPyretException($e72997300)) {
$e72997300.pyretStack.push(L[820]);
}
throw $e72997300;
}
var $ret73057306 = $Hbind_DASH_env17244150($z73017302,A317,binds2284152,body2294153,l2274154,self2264155);
++R.GAS;
return $ret73057306;
};
},{"length":4});
var anf_extend6437219 = R.makeMethod(function(self2364035) {
return function(l2374033,params2384034,args2394030,ann2404029,doc2414032,body2424031,_check2434028) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[451],7,arguments);
}
var anf_fun6247283 = G(lists1523,"fold",L[819]);
var anf_arg6277284 = R.makeFunction(function(acc2457286,param2467287) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[817],2,arguments);
}
var anf_fun6267298 = G(bind_DASH_handlers1883797,"s-param-bind",L[818]);
var $z72907291 = D;
var $f72967297 = function(_) {
return R.isFunction(anf_fun6267298)?anf_fun6267298.app(l2374033,param2467287,acc2457286):R.ffi.throwNonFunApp(L[817],anf_fun6267298,[l2374033,param2467287,acc2457286]);
};
try {
if(--R.GAS > 0) {
$z72907291 = $f72967297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72967297,
"from":L[817]});
}
} catch($e72887289) {
if(R.isCont($e72887289)) {
var $ss72927293 = {"from":L[817],
"go":function(ann_DASH_check_DASH_temp6254149) {
return $Hann_DASH_check_DASH_temp17254148(ann_DASH_check_DASH_temp6254149);
}};
$e72887289.stack[R.EXN_STACKHEIGHT++] = $ss72927293;
}
if(R.isPyretException($e72887289)) {
$e72887289.pyretStack.push(L[817]);
}
throw $e72887289;
}
var $ret72947295 = $Hann_DASH_check_DASH_temp17254148($z72907291);
++R.GAS;
return $ret72947295;
});
var anf_arg6287285 = G(self2364035,"type-env",L[816]);
var $z72757276 = D;
var $f72817282 = function(_) {
return R.isFunction(anf_fun6247283)?anf_fun6247283.app(anf_arg6277284,anf_arg6287285,params2384034):R.ffi.throwNonFunApp(L[815],anf_fun6247283,[anf_arg6277284,anf_arg6287285,params2384034]);
};
try {
if(--R.GAS > 0) {
$z72757276 = $f72817282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72817282,
"from":L[815]});
}
} catch($e72737274) {
if(R.isCont($e72737274)) {
var $ss72777278 = {"from":L[815],
"go":function(new_DASH_type_DASH_env2444027) {
return $Hnew_DASH_type_DASH_env17344026(new_DASH_type_DASH_env2444027,A317,_check2434028,ann2404029,args2394030,bind_DASH_handlers1883797,body2424031,doc2414032,l2374033,lists1523,params2384034,self2364035);
}};
$e72737274.stack[R.EXN_STACKHEIGHT++] = $ss72777278;
}
if(R.isPyretException($e72737274)) {
$e72737274.pyretStack.push(L[815]);
}
throw $e72737274;
}
var $ret72797280 = $Hnew_DASH_type_DASH_env17344026($z72757276,A317,_check2434028,ann2404029,args2394030,bind_DASH_handlers1883797,body2424031,doc2414032,l2374033,lists1523,params2384034,self2364035);
++R.GAS;
return $ret72797280;
};
},{"length":8});
var anf_extend6707220 = R.makeMethod(function(self2553897) {
return function(l2563892,name2573894,namet2583895,params2593896,mixins2603893,variants2613899,shared_DASH_members2623898,_check2633891) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[435],8,arguments);
}
var anf_fun6457257 = G(lists1523,"fold",L[814]);
var anf_arg6487258 = R.makeFunction(function(acc2657260,param2667261) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[812],2,arguments);
}
var anf_fun6477272 = G(bind_DASH_handlers1883797,"s-param-bind",L[813]);
var $z72647265 = D;
var $f72707271 = function(_) {
return R.isFunction(anf_fun6477272)?anf_fun6477272.app(l2563892,param2667261,acc2657260):R.ffi.throwNonFunApp(L[812],anf_fun6477272,[l2563892,param2667261,acc2657260]);
};
try {
if(--R.GAS > 0) {
$z72647265 = $f72707271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72707271,
"from":L[812]});
}
} catch($e72627263) {
if(R.isCont($e72627263)) {
var $ss72667267 = {"from":L[812],
"go":function(ann_DASH_check_DASH_temp6464025) {
return $Hann_DASH_check_DASH_temp17354024(ann_DASH_check_DASH_temp6464025);
}};
$e72627263.stack[R.EXN_STACKHEIGHT++] = $ss72667267;
}
if(R.isPyretException($e72627263)) {
$e72627263.pyretStack.push(L[812]);
}
throw $e72627263;
}
var $ret72687269 = $Hann_DASH_check_DASH_temp17354024($z72647265);
++R.GAS;
return $ret72687269;
});
var anf_arg6497259 = G(self2553897,"type-env",L[811]);
var $z72497250 = D;
var $f72557256 = function(_) {
return R.isFunction(anf_fun6457257)?anf_fun6457257.app(anf_arg6487258,anf_arg6497259,params2593896):R.ffi.throwNonFunApp(L[810],anf_fun6457257,[anf_arg6487258,anf_arg6497259,params2593896]);
};
try {
if(--R.GAS > 0) {
$z72497250 = $f72557256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72557256,
"from":L[810]});
}
} catch($e72477248) {
if(R.isCont($e72477248)) {
var $ss72517252 = {"from":L[810],
"go":function(new_DASH_type_DASH_env2643890) {
return $Hnew_DASH_type_DASH_env17453889(new_DASH_type_DASH_env2643890,A317,_check2633891,l2563892,mixins2603893,name2573894,namet2583895,params2593896,self2553897,shared_DASH_members2623898,variants2613899);
}};
$e72477248.stack[R.EXN_STACKHEIGHT++] = $ss72517252;
}
if(R.isPyretException($e72477248)) {
$e72477248.pyretStack.push(L[810]);
}
throw $e72477248;
}
var $ret72537254 = $Hnew_DASH_type_DASH_env17453889($z72497250,A317,_check2633891,l2563892,mixins2603893,name2573894,namet2583895,params2593896,self2553897,shared_DASH_members2623898,variants2613899);
++R.GAS;
return $ret72537254;
};
},{"length":9});
var anf_extend6897221 = R.makeMethod(function(self2683801) {
return function(l2693800,args2707246,ann2713796,doc2723799,body2733798,_check2743795) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[420],6,arguments);
}
var anf_fun6727232 = G(args2707246,"map",L[809]);
var anf_arg6757233 = R.makeFunction(function(recv_DASH_787234) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[808],1,arguments);
}
var anf_fun6747245 = G(recv_DASH_787234,"visit",L[808]);
var $z72377238 = D;
var $f72437244 = function(_) {
return R.isFunction(anf_fun6747245)?anf_fun6747245.app(self2683801):R.ffi.throwNonFunApp(L[808],anf_fun6747245,[self2683801]);
};
try {
if(--R.GAS > 0) {
$z72377238 = $f72437244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72437244,
"from":L[808]});
}
} catch($e72357236) {
if(R.isCont($e72357236)) {
var $ss72397240 = {"from":L[808],
"go":function(ann_DASH_check_DASH_temp6733888) {
return $Hann_DASH_check_DASH_temp17463887(ann_DASH_check_DASH_temp6733888);
}};
$e72357236.stack[R.EXN_STACKHEIGHT++] = $ss72397240;
}
if(R.isPyretException($e72357236)) {
$e72357236.pyretStack.push(L[808]);
}
throw $e72357236;
}
var $ret72417242 = $Hann_DASH_check_DASH_temp17463887($z72377238);
++R.GAS;
return $ret72417242;
});
var $z72247225 = D;
var $f72307231 = function(_) {
return R.isFunction(anf_fun6727232)?anf_fun6727232.app(anf_arg6757233):R.ffi.throwNonFunApp(L[807],anf_fun6727232,[anf_arg6757233]);
};
try {
if(--R.GAS > 0) {
$z72247225 = $f72307231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72307231,
"from":L[807]});
}
} catch($e72227223) {
if(R.isCont($e72227223)) {
var $ss72267227 = {"from":L[807],
"go":function(new_DASH_args2753794) {
return $Hnew_DASH_args17533793(new_DASH_args2753794,A317,_check2743795,ann2713796,bind_DASH_handlers1883797,body2733798,doc2723799,l2693800,lists1523,self2683801);
}};
$e72227223.stack[R.EXN_STACKHEIGHT++] = $ss72267227;
}
if(R.isPyretException($e72227223)) {
$e72227223.pyretStack.push(L[807]);
}
throw $e72227223;
}
var $ret72287229 = $Hnew_DASH_args17533793($z72247225,A317,_check2743795,ann2713796,bind_DASH_handlers1883797,body2733798,doc2723799,l2693800,lists1523,self2683801);
++R.GAS;
return $ret72287229;
};
},{"length":7});
var ann_DASH_check_DASH_temp5447213 = anf_extend5457214.extendWith({"env":initial_DASH_env1867211,
"type-env":initial_DASH_type_DASH_env1877212,
"s-program":anf_extend5647215,
"s-type-let-expr":anf_extend5897216,
"s-let-expr":anf_extend6107217,
"s-letrec":anf_extend6227218,
"s-lam":anf_extend6437219,
"s-data-expr":anf_extend6707220,
"s-method":anf_extend6897221});
return ann_DASH_check_DASH_temp5447213;
});
});
default_DASH_env_DASH_map_DASH_visitor13177.$var = anf_assign6906720;
var anf_assign9626721 = R.makeFunction(function(initial_DASH_env2837014,initial_DASH_type_DASH_env2847015,bind_DASH_handlers2853086) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[753],3,arguments);
}
return R.checkAnnArgs([R.makeRecordAnn(["s-letrec-bind","s-let-bind","s-bind","s-header","s-type-let-bind","s-param-bind"],[L[799],L[800],L[801],L[802],L[803],L[804]],{"s-letrec-bind":R.Function,
"s-let-bind":R.Function,
"s-bind":R.Function,
"s-header":R.Function,
"s-type-let-bind":R.Function,
"s-param-bind":R.Function})],[bind_DASH_handlers2853086],[L[805]],function() {
var anf_extend6927017 = G(A317,"default-iter-visitor",L[798]);
var anf_extend7347018 = R.makeMethod(function(self2863616) {
return function(l2877210,_provide2887209,_provide_DASH_types2893612,imports2903615,body2913613) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[797],5,arguments);
}
var anf_fun6947208 = G(_provide2887209,"visit",L[796]);
var $z72007201 = D;
var $f72067207 = function(_) {
return R.isFunction(anf_fun6947208)?anf_fun6947208.app(self2863616):R.ffi.throwNonFunApp(L[388],anf_fun6947208,[self2863616]);
};
try {
if(--R.GAS > 0) {
$z72007201 = $f72067207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72067207,
"from":L[388]});
}
} catch($e71987199) {
if(R.isCont($e71987199)) {
var $ss72027203 = {"from":L[388],
"go":function(and_DASH_oper_DASH_803611) {
return $Hand_DASH_oper_DASH_17653610(and_DASH_oper_DASH_803611,_provide_DASH_types2893612,bind_DASH_handlers2853086,body2913613,fold593614,imports2903615,lists1523,self2863616);
}};
$e71987199.stack[R.EXN_STACKHEIGHT++] = $ss72027203;
}
if(R.isPyretException($e71987199)) {
$e71987199.pyretStack.push(L[388]);
}
throw $e71987199;
}
var $ret72047205 = $Hand_DASH_oper_DASH_17653610($z72007201,_provide_DASH_types2893612,bind_DASH_handlers2853086,body2913613,fold593614,imports2903615,lists1523,self2863616);
++R.GAS;
return $ret72047205;
};
},{"length":6});
var anf_extend7757019 = R.makeMethod(function(self2973498) {
return function(l2987197,binds2997179,body3003497) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[795],3,arguments);
}
var anf_obj7367195 = G(self2973498,"env",L[794]);
var anf_obj7377196 = G(self2973498,"type-env",L[793]);
var new_DASH_envs3017180 = R.makeObject({"val-env":anf_obj7367195,
"type-env":anf_obj7377196});
var anf_fun7387176 = G(lists1523,"fold-while",L[792]);
var anf_arg7597177 = R.makeFunction(function(acc3037181,b3043553) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[787],2,arguments);
}
var anf_fun7407192 = G(bind_DASH_handlers2853086,"s-type-let-bind",L[791]);
var anf_arg7417193 = G(acc3037181,"val-env",L[790]);
var anf_arg7427194 = G(acc3037181,"type-env",L[789]);
var $z71847185 = D;
var $f71907191 = function(_) {
return R.isFunction(anf_fun7407192)?anf_fun7407192.app(b3043553,anf_arg7417193,anf_arg7427194):R.ffi.throwNonFunApp(L[788],anf_fun7407192,[b3043553,anf_arg7417193,anf_arg7427194]);
};
try {
if(--R.GAS > 0) {
$z71847185 = $f71907191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71907191,
"from":L[788]});
}
} catch($e71827183) {
if(R.isCont($e71827183)) {
var $ss71867187 = {"from":L[788],
"go":function(updated3053552) {
return $Hupdated17693551(updated3053552,E1121,b3043553,self2973498);
}};
$e71827183.stack[R.EXN_STACKHEIGHT++] = $ss71867187;
}
if(R.isPyretException($e71827183)) {
$e71827183.pyretStack.push(L[788]);
}
throw $e71827183;
}
var $ret71887189 = $Hupdated17693551($z71847185,E1121,b3043553,self2973498);
++R.GAS;
return $ret71887189;
});
var anf_arg7607178 = new_DASH_envs3017180.extendWith({"bs":(true)});
var $z71687169 = D;
var $f71747175 = function(_) {
return R.isFunction(anf_fun7387176)?anf_fun7387176.app(anf_arg7597177,anf_arg7607178,binds2997179):R.ffi.throwNonFunApp(L[786],anf_fun7387176,[anf_arg7597177,anf_arg7607178,binds2997179]);
};
try {
if(--R.GAS > 0) {
$z71687169 = $f71747175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71747175,
"from":L[786]});
}
} catch($e71667167) {
if(R.isCont($e71667167)) {
var $ss71707171 = {"from":L[786],
"go":function(bound_DASH_env3023496) {
return $Hbound_DASH_env17733495(bound_DASH_env3023496,body3003497,self2973498);
}};
$e71667167.stack[R.EXN_STACKHEIGHT++] = $ss71707171;
}
if(R.isPyretException($e71667167)) {
$e71667167.pyretStack.push(L[786]);
}
throw $e71667167;
}
var $ret71727173 = $Hbound_DASH_env17733495($z71687169,body3003497,self2973498);
++R.GAS;
return $ret71727173;
};
},{"length":4});
var anf_extend8137020 = R.makeMethod(function(self3083384) {
return function(l3097165,binds3107151,body3113383) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[785],3,arguments);
}
var anf_fun7777148 = G(lists1523,"fold-while",L[784]);
var anf_arg7977149 = R.makeFunction(function(acc3133438,b3143439) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[780],2,arguments);
}
var anf_fun7797163 = G(bind_DASH_handlers2853086,"s-let-bind",L[783]);
var anf_arg7807164 = G(acc3133438,"e",L[782]);
var $z71557156 = D;
var $f71617162 = function(_) {
return R.isFunction(anf_fun7797163)?anf_fun7797163.app(b3143439,anf_arg7807164):R.ffi.throwNonFunApp(L[781],anf_fun7797163,[b3143439,anf_arg7807164]);
};
try {
if(--R.GAS > 0) {
$z71557156 = $f71617162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71617162,
"from":L[781]});
}
} catch($e71537154) {
if(R.isCont($e71537154)) {
var $ss71577158 = {"from":L[781],
"go":function(this_DASH_env3153437) {
return $Hthis_DASH_env17773436(this_DASH_env3153437,E1121,acc3133438,b3143439,self3083384);
}};
$e71537154.stack[R.EXN_STACKHEIGHT++] = $ss71577158;
}
if(R.isPyretException($e71537154)) {
$e71537154.pyretStack.push(L[781]);
}
throw $e71537154;
}
var $ret71597160 = $Hthis_DASH_env17773436($z71557156,E1121,acc3133438,b3143439,self3083384);
++R.GAS;
return $ret71597160;
});
var anf_obj7987152 = G(self3083384,"env",L[779]);
var anf_arg7997150 = R.makeObject({"e":anf_obj7987152,
"bs":(true)});
var $z71407141 = D;
var $f71467147 = function(_) {
return R.isFunction(anf_fun7777148)?anf_fun7777148.app(anf_arg7977149,anf_arg7997150,binds3107151):R.ffi.throwNonFunApp(L[778],anf_fun7777148,[anf_arg7977149,anf_arg7997150,binds3107151]);
};
try {
if(--R.GAS > 0) {
$z71407141 = $f71467147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71467147,
"from":L[778]});
}
} catch($e71387139) {
if(R.isCont($e71387139)) {
var $ss71427143 = {"from":L[778],
"go":function(bound_DASH_env3123382) {
return $Hbound_DASH_env17813381(bound_DASH_env3123382,body3113383,self3083384);
}};
$e71387139.stack[R.EXN_STACKHEIGHT++] = $ss71427143;
}
if(R.isPyretException($e71387139)) {
$e71387139.pyretStack.push(L[778]);
}
throw $e71387139;
}
var $ret71447145 = $Hbound_DASH_env17813381($z71407141,body3113383,self3083384);
++R.GAS;
return $ret71447145;
};
},{"length":4});
var anf_extend8467021 = R.makeMethod(function(self3173262) {
return function(l3187137,binds3193260,body3203261) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[777],3,arguments);
}
var anf_fun8157121 = G(lists1523,"fold",L[776]);
var anf_arg8187122 = R.makeFunction(function(acc3227124,b3237125) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[774],2,arguments);
}
var anf_fun8177136 = G(bind_DASH_handlers2853086,"s-letrec-bind",L[775]);
var $z71287129 = D;
var $f71347135 = function(_) {
return R.isFunction(anf_fun8177136)?anf_fun8177136.app(b3237125,acc3227124):R.ffi.throwNonFunApp(L[774],anf_fun8177136,[b3237125,acc3227124]);
};
try {
if(--R.GAS > 0) {
$z71287129 = $f71347135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71347135,
"from":L[774]});
}
} catch($e71267127) {
if(R.isCont($e71267127)) {
var $ss71307131 = {"from":L[774],
"go":function(ann_DASH_check_DASH_temp8163380) {
return $Hann_DASH_check_DASH_temp17823379(ann_DASH_check_DASH_temp8163380);
}};
$e71267127.stack[R.EXN_STACKHEIGHT++] = $ss71307131;
}
if(R.isPyretException($e71267127)) {
$e71267127.pyretStack.push(L[774]);
}
throw $e71267127;
}
var $ret71327133 = $Hann_DASH_check_DASH_temp17823379($z71287129);
++R.GAS;
return $ret71327133;
});
var anf_arg8197123 = G(self3173262,"env",L[773]);
var $z71137114 = D;
var $f71197120 = function(_) {
return R.isFunction(anf_fun8157121)?anf_fun8157121.app(anf_arg8187122,anf_arg8197123,binds3193260):R.ffi.throwNonFunApp(L[772],anf_fun8157121,[anf_arg8187122,anf_arg8197123,binds3193260]);
};
try {
if(--R.GAS > 0) {
$z71137114 = $f71197120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71197120,
"from":L[772]});
}
} catch($e71117112) {
if(R.isCont($e71117112)) {
var $ss71157116 = {"from":L[772],
"go":function(bind_DASH_env3213259) {
return $Hbind_DASH_env17903258(bind_DASH_env3213259,E1121,binds3193260,body3203261,lists1523,self3173262);
}};
$e71117112.stack[R.EXN_STACKHEIGHT++] = $ss71157116;
}
if(R.isPyretException($e71117112)) {
$e71117112.pyretStack.push(L[772]);
}
throw $e71117112;
}
var $ret71177118 = $Hbind_DASH_env17903258($z71137114,E1121,binds3193260,body3203261,lists1523,self3173262);
++R.GAS;
return $ret71177118;
};
},{"length":4});
var anf_extend8837022 = R.makeMethod(function(self3283088) {
return function(l3297109,params3307095,args3313085,ann3323084,doc3337110,body3343087,_check3353083) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[771],7,arguments);
}
var anf_fun8487092 = G(lists1523,"fold",L[770]);
var anf_arg8517093 = R.makeFunction(function(acc3377096,param3387097) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[768],2,arguments);
}
var anf_fun8507108 = G(bind_DASH_handlers2853086,"s-param-bind",L[769]);
var $z71007101 = D;
var $f71067107 = function(_) {
return R.isFunction(anf_fun8507108)?anf_fun8507108.app(l3297109,param3387097,acc3377096):R.ffi.throwNonFunApp(L[768],anf_fun8507108,[l3297109,param3387097,acc3377096]);
};
try {
if(--R.GAS > 0) {
$z71007101 = $f71067107();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71067107,
"from":L[768]});
}
} catch($e70987099) {
if(R.isCont($e70987099)) {
var $ss71027103 = {"from":L[768],
"go":function(ann_DASH_check_DASH_temp8493257) {
return $Hann_DASH_check_DASH_temp17913256(ann_DASH_check_DASH_temp8493257);
}};
$e70987099.stack[R.EXN_STACKHEIGHT++] = $ss71027103;
}
if(R.isPyretException($e70987099)) {
$e70987099.pyretStack.push(L[768]);
}
throw $e70987099;
}
var $ret71047105 = $Hann_DASH_check_DASH_temp17913256($z71007101);
++R.GAS;
return $ret71047105;
});
var anf_arg8527094 = G(self3283088,"type-env",L[767]);
var $z70847085 = D;
var $f70907091 = function(_) {
return R.isFunction(anf_fun8487092)?anf_fun8487092.app(anf_arg8517093,anf_arg8527094,params3307095):R.ffi.throwNonFunApp(L[766],anf_fun8487092,[anf_arg8517093,anf_arg8527094,params3307095]);
};
try {
if(--R.GAS > 0) {
$z70847085 = $f70907091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70907091,
"from":L[766]});
}
} catch($e70827083) {
if(R.isCont($e70827083)) {
var $ss70867087 = {"from":L[766],
"go":function(new_DASH_type_DASH_env3363082) {
return $Hnew_DASH_type_DASH_env18033081(new_DASH_type_DASH_env3363082,_check3353083,ann3323084,args3313085,bind_DASH_handlers2853086,body3343087,lists1523,self3283088);
}};
$e70827083.stack[R.EXN_STACKHEIGHT++] = $ss70867087;
}
if(R.isPyretException($e70827083)) {
$e70827083.pyretStack.push(L[766]);
}
throw $e70827083;
}
var $ret70887089 = $Hnew_DASH_type_DASH_env18033081($z70847085,_check3353083,ann3323084,args3313085,bind_DASH_handlers2853086,body3343087,lists1523,self3283088);
++R.GAS;
return $ret70887089;
};
},{"length":8});
var anf_extend9267023 = R.makeMethod(function(self3452882) {
return function(l3467080,name3477081,namet3482881,params3497066,mixins3502880,variants3512884,shared_DASH_members3522883,_check3532879) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[765],8,arguments);
}
var anf_fun8857063 = G(lists1523,"fold",L[764]);
var anf_arg8887064 = R.makeFunction(function(acc3557067,param3567068) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[762],2,arguments);
}
var anf_fun8877079 = G(bind_DASH_handlers2853086,"s-param-bind",L[763]);
var $z70717072 = D;
var $f70777078 = function(_) {
return R.isFunction(anf_fun8877079)?anf_fun8877079.app(l3467080,param3567068,acc3557067):R.ffi.throwNonFunApp(L[762],anf_fun8877079,[l3467080,param3567068,acc3557067]);
};
try {
if(--R.GAS > 0) {
$z70717072 = $f70777078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70777078,
"from":L[762]});
}
} catch($e70697070) {
if(R.isCont($e70697070)) {
var $ss70737074 = {"from":L[762],
"go":function(ann_DASH_check_DASH_temp8863080) {
return $Hann_DASH_check_DASH_temp18043079(ann_DASH_check_DASH_temp8863080);
}};
$e70697070.stack[R.EXN_STACKHEIGHT++] = $ss70737074;
}
if(R.isPyretException($e70697070)) {
$e70697070.pyretStack.push(L[762]);
}
throw $e70697070;
}
var $ret70757076 = $Hann_DASH_check_DASH_temp18043079($z70717072);
++R.GAS;
return $ret70757076;
});
var anf_arg8897065 = G(self3452882,"type-env",L[761]);
var $z70557056 = D;
var $f70617062 = function(_) {
return R.isFunction(anf_fun8857063)?anf_fun8857063.app(anf_arg8887064,anf_arg8897065,params3497066):R.ffi.throwNonFunApp(L[760],anf_fun8857063,[anf_arg8887064,anf_arg8897065,params3497066]);
};
try {
if(--R.GAS > 0) {
$z70557056 = $f70617062();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70617062,
"from":L[760]});
}
} catch($e70537054) {
if(R.isCont($e70537054)) {
var $ss70577058 = {"from":L[760],
"go":function(new_DASH_type_DASH_env3542878) {
return $Hnew_DASH_type_DASH_env18182877(new_DASH_type_DASH_env3542878,_check3532879,lists1523,mixins3502880,namet3482881,self3452882,shared_DASH_members3522883,variants3512884);
}};
$e70537054.stack[R.EXN_STACKHEIGHT++] = $ss70577058;
}
if(R.isPyretException($e70537054)) {
$e70537054.pyretStack.push(L[760]);
}
throw $e70537054;
}
var $ret70597060 = $Hnew_DASH_type_DASH_env18182877($z70557056,_check3532879,lists1523,mixins3502880,namet3482881,self3452882,shared_DASH_members3522883,variants3512884);
++R.GAS;
return $ret70597060;
};
},{"length":9});
var anf_extend9617024 = R.makeMethod(function(self3582737) {
return function(l3597051,args3602735,ann3612734,doc3627052,body3632736,_check3642733) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[759],6,arguments);
}
var anf_fun9287035 = G(lists1523,"fold",L[758]);
var anf_arg9317036 = R.makeFunction(function(acc3667038,arg3677039) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[756],2,arguments);
}
var anf_fun9307050 = G(bind_DASH_handlers2853086,"s-bind",L[757]);
var $z70427043 = D;
var $f70487049 = function(_) {
return R.isFunction(anf_fun9307050)?anf_fun9307050.app(arg3677039,acc3667038):R.ffi.throwNonFunApp(L[756],anf_fun9307050,[arg3677039,acc3667038]);
};
try {
if(--R.GAS > 0) {
$z70427043 = $f70487049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70487049,
"from":L[756]});
}
} catch($e70407041) {
if(R.isCont($e70407041)) {
var $ss70447045 = {"from":L[756],
"go":function(ann_DASH_check_DASH_temp9292876) {
return $Hann_DASH_check_DASH_temp18192875(ann_DASH_check_DASH_temp9292876);
}};
$e70407041.stack[R.EXN_STACKHEIGHT++] = $ss70447045;
}
if(R.isPyretException($e70407041)) {
$e70407041.pyretStack.push(L[756]);
}
throw $e70407041;
}
var $ret70467047 = $Hann_DASH_check_DASH_temp18192875($z70427043);
++R.GAS;
return $ret70467047;
});
var anf_arg9327037 = G(self3582737,"env",L[755]);
var $z70277028 = D;
var $f70337034 = function(_) {
return R.isFunction(anf_fun9287035)?anf_fun9287035.app(anf_arg9317036,anf_arg9327037,args3602735):R.ffi.throwNonFunApp(L[754],anf_fun9287035,[anf_arg9317036,anf_arg9327037,args3602735]);
};
try {
if(--R.GAS > 0) {
$z70277028 = $f70337034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70337034,
"from":L[754]});
}
} catch($e70257026) {
if(R.isCont($e70257026)) {
var $ss70297030 = {"from":L[754],
"go":function(args_DASH_env3652732) {
return $Hargs_DASH_env18292731(args_DASH_env3652732,_check3642733,ann3612734,args3602735,body3632736,lists1523,self3582737);
}};
$e70257026.stack[R.EXN_STACKHEIGHT++] = $ss70297030;
}
if(R.isPyretException($e70257026)) {
$e70257026.pyretStack.push(L[754]);
}
throw $e70257026;
}
var $ret70317032 = $Hargs_DASH_env18292731($z70277028,_check3642733,ann3612734,args3602735,body3632736,lists1523,self3582737);
++R.GAS;
return $ret70317032;
};
},{"length":7});
var ann_DASH_check_DASH_temp6917016 = anf_extend6927017.extendWith({"env":initial_DASH_env2837014,
"type-env":initial_DASH_type_DASH_env2847015,
"s-program":anf_extend7347018,
"s-type-let-expr":anf_extend7757019,
"s-let-expr":anf_extend8137020,
"s-letrec":anf_extend8467021,
"s-lam":anf_extend8837022,
"s-data-expr":anf_extend9267023,
"s-method":anf_extend9617024});
return ann_DASH_check_DASH_temp6917016;
});
});
default_DASH_env_DASH_iter_DASH_visitor13276.$var = anf_assign9626721;
var anf_obj9786862 = R.makeMethod(function($underscore3697013) {
return function(imp3702663,env3717012,type_DASH_env3722664) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[752],3,arguments);
}
var anf_fun9642662 = G(env3717012,"set",L[751]);
var anf_bracket9657011 = G(imp3702663,"name",L[750]);
var anf_fun9667010 = G(anf_bracket9657011,"key",L[749]);
var $z70027003 = D;
var $f70087009 = function(_) {
return R.isFunction(anf_fun9667010)?anf_fun9667010.app():R.ffi.throwNonFunApp(L[748],anf_fun9667010,[]);
};
try {
if(--R.GAS > 0) {
$z70027003 = $f70087009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70087009,
"from":L[748]});
}
} catch($e70007001) {
if(R.isCont($e70007001)) {
var $ss70047005 = {"from":L[748],
"go":function(anf_arg9672661) {
return $Hanf_arg18352660(anf_arg9672661,anf_fun9642662,b_DASH_typ11963,b_DASH_unknown12164,e_DASH_bind12678,imp3702663,type_DASH_env3722664);
}};
$e70007001.stack[R.EXN_STACKHEIGHT++] = $ss70047005;
}
if(R.isPyretException($e70007001)) {
$e70007001.pyretStack.push(L[748]);
}
throw $e70007001;
}
var $ret70067007 = $Hanf_arg18352660($z70027003,anf_fun9642662,b_DASH_typ11963,b_DASH_unknown12164,e_DASH_bind12678,imp3702663,type_DASH_env3722664);
++R.GAS;
return $ret70067007;
};
},{"length":4});
var anf_obj9846863 = R.makeMethod(function($underscore3736999) {
return function(l3742635,param3756997,type_DASH_env3766998) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[296],3,arguments);
}
var anf_fun9802634 = G(type_DASH_env3766998,"set",L[747]);
var anf_fun9816996 = G(param3756997,"key",L[746]);
var $z69886989 = D;
var $f69946995 = function(_) {
return R.isFunction(anf_fun9816996)?anf_fun9816996.app():R.ffi.throwNonFunApp(L[745],anf_fun9816996,[]);
};
try {
if(--R.GAS > 0) {
$z69886989 = $f69946995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69946995,
"from":L[745]});
}
} catch($e69866987) {
if(R.isCont($e69866987)) {
var $ss69906991 = {"from":L[745],
"go":function(anf_arg9822633) {
return $Hanf_arg18382632(anf_arg9822633,anf_fun9802634,b_DASH_typ11963,e_DASH_bind12678,l3742635);
}};
$e69866987.stack[R.EXN_STACKHEIGHT++] = $ss69906991;
}
if(R.isPyretException($e69866987)) {
$e69866987.pyretStack.push(L[745]);
}
throw $e69866987;
}
var $ret69926993 = $Hanf_arg18382632($z69886989,anf_fun9802634,b_DASH_typ11963,e_DASH_bind12678,l3742635);
++R.GAS;
return $ret69926993;
};
},{"length":4});
var anf_obj10096864 = R.makeMethod(function($underscore3776985) {
return function(tlb3786984,env3792605,type_DASH_env3802538) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[735],3,arguments);
}
var cases_DASH_val1126983 = tlb3786984;
var anf_fun9866952 = G(cases_DASH_val1126983,"_match",L[736]);
var anf_obj9936956 = R.makeFunction(function(l3812606,name3826970,ann3836971) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[741],3,arguments);
}
var anf_fun9882604 = G(type_DASH_env3802538,"set",L[744]);
var anf_fun9896982 = G(name3826970,"key",L[743]);
var $z69746975 = D;
var $f69806981 = function(_) {
return R.isFunction(anf_fun9896982)?anf_fun9896982.app():R.ffi.throwNonFunApp(L[742],anf_fun9896982,[]);
};
try {
if(--R.GAS > 0) {
$z69746975 = $f69806981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69806981,
"from":L[742]});
}
} catch($e69726973) {
if(R.isCont($e69726973)) {
var $ss69766977 = {"from":L[742],
"go":function(anf_arg9902603) {
return $Hanf_arg18412602(anf_arg9902603,anf_fun9882604,b_DASH_typ11963,e_DASH_bind12678,env3792605,l3812606);
}};
$e69726973.stack[R.EXN_STACKHEIGHT++] = $ss69766977;
}
if(R.isPyretException($e69726973)) {
$e69726973.pyretStack.push(L[742]);
}
throw $e69726973;
}
var $ret69786979 = $Hanf_arg18412602($z69746975,anf_fun9882604,b_DASH_typ11963,e_DASH_bind12678,env3792605,l3812606);
++R.GAS;
return $ret69786979;
});
var anf_obj10056957 = R.makeFunction(function(l3842536,tname3852537,bname3866958) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[737],3,arguments);
}
var anf_fun9952535 = G(env3792605,"set",L[740]);
var anf_fun9966969 = G(bname3866958,"key",L[739]);
var $z69616962 = D;
var $f69676968 = function(_) {
return R.isFunction(anf_fun9966969)?anf_fun9966969.app():R.ffi.throwNonFunApp(L[738],anf_fun9966969,[]);
};
try {
if(--R.GAS > 0) {
$z69616962 = $f69676968();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69676968,
"from":L[738]});
}
} catch($e69596960) {
if(R.isCont($e69596960)) {
var $ss69636964 = {"from":L[738],
"go":function(anf_arg9972534) {
return $Hanf_arg18472533(anf_arg9972534,anf_fun9952535,b_DASH_typ11963,b_DASH_unknown12164,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538);
}};
$e69596960.stack[R.EXN_STACKHEIGHT++] = $ss69636964;
}
if(R.isPyretException($e69596960)) {
$e69596960.pyretStack.push(L[738]);
}
throw $e69596960;
}
var $ret69656966 = $Hanf_arg18472533($z69616962,anf_fun9952535,b_DASH_typ11963,b_DASH_unknown12164,e_DASH_bind12678,l3842536,tname3852537,type_DASH_env3802538);
++R.GAS;
return $ret69656966;
});
var anf_arg10066953 = R.makeObject({"s-type-bind":anf_obj9936956,
"s-newtype-bind":anf_obj10056957});
var anf_arg10086954 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[736],0,arguments);
}
var ann_DASH_check_DASH_temp10076955 = R.throwNoBranchesMatched(L[736],("cases"));
return ann_DASH_check_DASH_temp10076955;
});
var $z69446945 = D;
var $f69506951 = function(_) {
return R.isFunction(anf_fun9866952)?anf_fun9866952.app(anf_arg10066953,anf_arg10086954):R.ffi.throwNonFunApp(L[735],anf_fun9866952,[anf_arg10066953,anf_arg10086954]);
};
try {
if(--R.GAS > 0) {
$z69446945 = $f69506951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69506951,
"from":L[735]});
}
} catch($e69426943) {
if(R.isCont($e69426943)) {
var $ss69466947 = {"from":L[735],
"go":function(ann_DASH_check_DASH_temp9852532) {
return $Hann_DASH_check_DASH_temp18482531(ann_DASH_check_DASH_temp9852532);
}};
$e69426943.stack[R.EXN_STACKHEIGHT++] = $ss69466947;
}
if(R.isPyretException($e69426943)) {
$e69426943.pyretStack.push(L[735]);
}
throw $e69426943;
}
var $ret69486949 = $Hann_DASH_check_DASH_temp18482531($z69446945);
++R.GAS;
return $ret69486949;
};
},{"length":4});
var anf_obj10306865 = R.makeMethod(function($underscore3876941) {
return function(lb3886940,env3892492) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[725],2,arguments);
}
var cases_DASH_val1136939 = lb3886940;
var anf_fun10116906 = G(cases_DASH_val1136939,"_match",L[726]);
var anf_obj10196910 = R.makeFunction(function(l23902493,bind3916926,val3922494) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[285],3,arguments);
}
var anf_fun10132491 = G(env3892492,"set",L[734]);
var anf_bracket10146938 = G(bind3916926,"id",L[733]);
var anf_fun10156937 = G(anf_bracket10146938,"key",L[732]);
var $z69296930 = D;
var $f69356936 = function(_) {
return R.isFunction(anf_fun10156937)?anf_fun10156937.app():R.ffi.throwNonFunApp(L[731],anf_fun10156937,[]);
};
try {
if(--R.GAS > 0) {
$z69296930 = $f69356936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69356936,
"from":L[731]});
}
} catch($e69276928) {
if(R.isCont($e69276928)) {
var $ss69316932 = {"from":L[731],
"go":function(anf_arg10162490) {
return $Hanf_arg18522489(anf_arg10162490,anf_fun10132491,bind_DASH_or_DASH_unknown12867,e_DASH_bind12678,env3892492,l23902493,val3922494);
}};
$e69276928.stack[R.EXN_STACKHEIGHT++] = $ss69316932;
}
if(R.isPyretException($e69276928)) {
$e69276928.pyretStack.push(L[731]);
}
throw $e69276928;
}
var $ret69336934 = $Hanf_arg18522489($z69296930,anf_fun10132491,bind_DASH_or_DASH_unknown12867,e_DASH_bind12678,env3892492,l23902493,val3922494);
++R.GAS;
return $ret69336934;
});
var anf_obj10266911 = R.makeFunction(function(l23932464,bind3946912,val3956913) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[282],3,arguments);
}
var anf_fun10212463 = G(env3892492,"set",L[730]);
var anf_bracket10226925 = G(bind3946912,"id",L[729]);
var anf_fun10236924 = G(anf_bracket10226925,"key",L[728]);
var $z69166917 = D;
var $f69226923 = function(_) {
return R.isFunction(anf_fun10236924)?anf_fun10236924.app():R.ffi.throwNonFunApp(L[727],anf_fun10236924,[]);
};
try {
if(--R.GAS > 0) {
$z69166917 = $f69226923();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69226923,
"from":L[727]});
}
} catch($e69146915) {
if(R.isCont($e69146915)) {
var $ss69186919 = {"from":L[727],
"go":function(anf_arg10242462) {
return $Hanf_arg18552461(anf_arg10242462,anf_fun10212463,b_DASH_unknown12164,e_DASH_bind12678,l23932464);
}};
$e69146915.stack[R.EXN_STACKHEIGHT++] = $ss69186919;
}
if(R.isPyretException($e69146915)) {
$e69146915.pyretStack.push(L[727]);
}
throw $e69146915;
}
var $ret69206921 = $Hanf_arg18552461($z69166917,anf_fun10212463,b_DASH_unknown12164,e_DASH_bind12678,l23932464);
++R.GAS;
return $ret69206921;
});
var anf_arg10276907 = R.makeObject({"s-let-bind":anf_obj10196910,
"s-var-bind":anf_obj10266911});
var anf_arg10296908 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[726],0,arguments);
}
var ann_DASH_check_DASH_temp10286909 = R.throwNoBranchesMatched(L[726],("cases"));
return ann_DASH_check_DASH_temp10286909;
});
var $z68986899 = D;
var $f69046905 = function(_) {
return R.isFunction(anf_fun10116906)?anf_fun10116906.app(anf_arg10276907,anf_arg10296908):R.ffi.throwNonFunApp(L[725],anf_fun10116906,[anf_arg10276907,anf_arg10296908]);
};
try {
if(--R.GAS > 0) {
$z68986899 = $f69046905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69046905,
"from":L[725]});
}
} catch($e68966897) {
if(R.isCont($e68966897)) {
var $ss69006901 = {"from":L[725],
"go":function(ann_DASH_check_DASH_temp10102460) {
return $Hann_DASH_check_DASH_temp18562459(ann_DASH_check_DASH_temp10102460);
}};
$e68966897.stack[R.EXN_STACKHEIGHT++] = $ss69006901;
}
if(R.isPyretException($e68966897)) {
$e68966897.pyretStack.push(L[725]);
}
throw $e68966897;
}
var $ret69026903 = $Hann_DASH_check_DASH_temp18562459($z68986899);
++R.GAS;
return $ret69026903;
};
},{"length":3});
var anf_obj10416866 = R.makeMethod(function($underscore3966895) {
return function(lrb3972420,env3982419) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[280],2,arguments);
}
var anf_fun10322418 = G(env3982419,"set",L[724]);
var anf_bracket10336894 = G(lrb3972420,"b",L[723]);
var anf_bracket10346893 = G(anf_bracket10336894,"id",L[722]);
var anf_fun10356892 = G(anf_bracket10346893,"key",L[721]);
var $z68846885 = D;
var $f68906891 = function(_) {
return R.isFunction(anf_fun10356892)?anf_fun10356892.app():R.ffi.throwNonFunApp(L[720],anf_fun10356892,[]);
};
try {
if(--R.GAS > 0) {
$z68846885 = $f68906891();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68906891,
"from":L[720]});
}
} catch($e68826883) {
if(R.isCont($e68826883)) {
var $ss68866887 = {"from":L[720],
"go":function(anf_arg10362417) {
return $Hanf_arg18602416(anf_arg10362417,anf_fun10322418,bind_DASH_or_DASH_unknown12867,e_DASH_bind12678,env3982419,lrb3972420);
}};
$e68826883.stack[R.EXN_STACKHEIGHT++] = $ss68866887;
}
if(R.isPyretException($e68826883)) {
$e68826883.pyretStack.push(L[720]);
}
throw $e68826883;
}
var $ret68886889 = $Hanf_arg18602416($z68846885,anf_fun10322418,bind_DASH_or_DASH_unknown12867,e_DASH_bind12678,env3982419,lrb3972420);
++R.GAS;
return $ret68886889;
};
},{"length":3});
var anf_obj10496867 = R.makeMethod(function($underscore3996881) {
return function(b4002390,env4016880) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[275],2,arguments);
}
var anf_fun10432389 = G(env4016880,"set",L[719]);
var anf_bracket10446879 = G(b4002390,"id",L[718]);
var anf_fun10456878 = G(anf_bracket10446879,"key",L[717]);
var $z68706871 = D;
var $f68766877 = function(_) {
return R.isFunction(anf_fun10456878)?anf_fun10456878.app():R.ffi.throwNonFunApp(L[716],anf_fun10456878,[]);
};
try {
if(--R.GAS > 0) {
$z68706871 = $f68766877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68766877,
"from":L[716]});
}
} catch($e68686869) {
if(R.isCont($e68686869)) {
var $ss68726873 = {"from":L[716],
"go":function(anf_arg10462388) {
return $Hanf_arg18632387(anf_arg10462388,anf_fun10432389,b_DASH_unknown12164,b4002390,e_DASH_bind12678);
}};
$e68686869.stack[R.EXN_STACKHEIGHT++] = $ss68726873;
}
if(R.isPyretException($e68686869)) {
$e68686869.pyretStack.push(L[716]);
}
throw $e68686869;
}
var $ret68746875 = $Hanf_arg18632387($z68706871,anf_fun10432389,b_DASH_unknown12164,b4002390,e_DASH_bind12678);
++R.GAS;
return $ret68746875;
};
},{"length":3});
var binding_DASH_handlers36871 = R.makeObject({"s-header":anf_obj9786862,
"s-param-bind":anf_obj9846863,
"s-type-let-bind":anf_obj10096864,
"s-let-bind":anf_obj10306865,
"s-letrec-bind":anf_obj10416866,
"s-bind":anf_obj10496867});
var binding_DASH_env_DASH_map_DASH_visitor40270 = {"$var":D,
"$name":"binding-env-map-visitor"};
var binding_DASH_env_DASH_iter_DASH_visitor40369 = {"$var":D,
"$name":"binding-env-iter-visitor"};
var link_DASH_list_DASH_visitor40491 = {"$var":D,
"$name":"link-list-visitor"};
var bad_DASH_assignments40565 = {"$var":D,
"$name":"bad-assignments"};
var anf_assign10536722 = R.makeFunction(function(initial_DASH_env4062362) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[272],1,arguments);
}
var $z68546855 = D;
var $f68606861 = function(_) {
return R.isFunction(binding_DASH_env_DASH_from_DASH_env13068.$var)?binding_DASH_env_DASH_from_DASH_env13068.$var.app(initial_DASH_env4062362):R.ffi.throwNonFunApp(L[715],binding_DASH_env_DASH_from_DASH_env13068.$var,[initial_DASH_env4062362]);
};
try {
if(--R.GAS > 0) {
$z68546855 = $f68606861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68606861,
"from":L[715]});
}
} catch($e68526853) {
if(R.isCont($e68526853)) {
var $ss68566857 = {"from":L[715],
"go":function(anf_arg10512361) {
return $Hanf_arg18662360(anf_arg10512361,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,default_DASH_env_DASH_map_DASH_visitor13177,initial_DASH_env4062362);
}};
$e68526853.stack[R.EXN_STACKHEIGHT++] = $ss68566857;
}
if(R.isPyretException($e68526853)) {
$e68526853.pyretStack.push(L[715]);
}
throw $e68526853;
}
var $ret68586859 = $Hanf_arg18662360($z68546855,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,default_DASH_env_DASH_map_DASH_visitor13177,initial_DASH_env4062362);
++R.GAS;
return $ret68586859;
});
binding_DASH_env_DASH_map_DASH_visitor40270.$var = anf_assign10536722;
var anf_assign10576723 = R.makeFunction(function(initial_DASH_env4072335) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[270],1,arguments);
}
var $z68446845 = D;
var $f68506851 = function(_) {
return R.isFunction(binding_DASH_env_DASH_from_DASH_env13068.$var)?binding_DASH_env_DASH_from_DASH_env13068.$var.app(initial_DASH_env4072335):R.ffi.throwNonFunApp(L[714],binding_DASH_env_DASH_from_DASH_env13068.$var,[initial_DASH_env4072335]);
};
try {
if(--R.GAS > 0) {
$z68446845 = $f68506851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68506851,
"from":L[714]});
}
} catch($e68426843) {
if(R.isCont($e68426843)) {
var $ss68466847 = {"from":L[714],
"go":function(anf_arg10552334) {
return $Hanf_arg18692333(anf_arg10552334,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,default_DASH_env_DASH_iter_DASH_visitor13276,initial_DASH_env4072335);
}};
$e68426843.stack[R.EXN_STACKHEIGHT++] = $ss68466847;
}
if(R.isPyretException($e68426843)) {
$e68426843.pyretStack.push(L[714]);
}
throw $e68426843;
}
var $ret68486849 = $Hanf_arg18692333($z68446845,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,default_DASH_env_DASH_iter_DASH_visitor13276,initial_DASH_env4072335);
++R.GAS;
return $ret68486849;
});
binding_DASH_env_DASH_iter_DASH_visitor40369.$var = anf_assign10576723;
var anf_assign12306724 = R.makeFunction(function(initial_DASH_env4086831) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[712],1,arguments);
}
var $z68346835 = D;
var $f68406841 = function(_) {
return R.isFunction(binding_DASH_env_DASH_map_DASH_visitor40270.$var)?binding_DASH_env_DASH_map_DASH_visitor40270.$var.app(initial_DASH_env4086831):R.ffi.throwNonFunApp(L[713],binding_DASH_env_DASH_map_DASH_visitor40270.$var,[initial_DASH_env4086831]);
};
try {
if(--R.GAS > 0) {
$z68346835 = $f68406841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68406841,
"from":L[713]});
}
} catch($e68326833) {
if(R.isCont($e68326833)) {
var $ss68366837 = {"from":L[713],
"go":function(anf_extend10591560) {
return $Hanf_extend19201559(anf_extend10591560,A317,bind_DASH_or_DASH_unknown12867,list3192);
}};
$e68326833.stack[R.EXN_STACKHEIGHT++] = $ss68366837;
}
if(R.isPyretException($e68326833)) {
$e68326833.pyretStack.push(L[713]);
}
throw $e68326833;
}
var $ret68386839 = $Hanf_extend19201559($z68346835,A317,bind_DASH_or_DASH_unknown12867,list3192);
++R.GAS;
return $ret68386839;
});
link_DASH_list_DASH_visitor40491.$var = anf_assign12306724;
var anf_assign12686725 = R.makeFunction(function(initial_DASH_env4251353,ast4261352) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[709],2,arguments);
}
var anf_fun12326830 = G(list3192,"make",L[711]);
var $z68226823 = D;
var $f68286829 = function(_) {
return R.isFunction(anf_fun12326830)?anf_fun12326830.app([]):R.ffi.throwNonFunApp(L[710],anf_fun12326830,[[]]);
};
try {
if(--R.GAS > 0) {
$z68226823 = $f68286829();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68286829,
"from":L[710]});
}
} catch($e68206821) {
if(R.isCont($e68206821)) {
var $ss68246825 = {"from":L[710],
"go":function(var_DASH_bind19211351) {
return $Hvar_DASH_bind19391350(var_DASH_bind19211351,A317,CS719,ast4261352,bind_DASH_exp12766,binding_DASH_env_DASH_iter_DASH_visitor40369,initial_DASH_env4251353,link35745,not9,nothing10);
}};
$e68206821.stack[R.EXN_STACKHEIGHT++] = $ss68246825;
}
if(R.isPyretException($e68206821)) {
$e68206821.pyretStack.push(L[710]);
}
throw $e68206821;
}
var $ret68266827 = $Hvar_DASH_bind19391350($z68226823,A317,CS719,ast4261352,bind_DASH_exp12766,binding_DASH_env_DASH_iter_DASH_visitor40369,initial_DASH_env4251353,link35745,not9,nothing10);
++R.GAS;
return $ret68266827;
});
bad_DASH_assignments40565.$var = anf_assign12686725;
var anf_extend12696762 = G(A317,"default-map-visitor",L[708]);
var anf_extend12936763 = R.makeMethod(function(self4361275) {
return function(loc4371274,f4386788,exps4391273) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[698],3,arguments);
}
var cases_DASH_val1376819 = f4386788;
var anf_fun12716774 = G(cases_DASH_val1376819,"_match",L[144]);
var anf_obj12816789 = R.makeFunction(function(l4401319,$underscore4416790,args4426791,$underscore4436792,$underscore4446793,body4451318,$underscore4466794) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[145],7,arguments);
}
var anf_fun12736805 = G(lists1523,"map2",L[707]);
var anf_arg12796806 = R.makeFunction(function(arg4481337,exp4496807) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[147],2,arguments);
}
var anf_fun12751336 = G(A317,"s-let-bind",L[706]);
var anf_arg12761335 = G(arg4481337,"l",L[705]);
var anf_fun12776818 = G(exp4496807,"visit",L[704]);
var $z68106811 = D;
var $f68166817 = function(_) {
return R.isFunction(anf_fun12776818)?anf_fun12776818.app(self4361275):R.ffi.throwNonFunApp(L[703],anf_fun12776818,[self4361275]);
};
try {
if(--R.GAS > 0) {
$z68106811 = $f68166817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68166817,
"from":L[703]});
}
} catch($e68086809) {
if(R.isCont($e68086809)) {
var $ss68126813 = {"from":L[703],
"go":function(anf_arg12781334) {
return $Hanf_arg19411333(anf_arg12781334,anf_arg12761335,anf_fun12751336,arg4481337);
}};
$e68086809.stack[R.EXN_STACKHEIGHT++] = $ss68126813;
}
if(R.isPyretException($e68086809)) {
$e68086809.pyretStack.push(L[703]);
}
throw $e68086809;
}
var $ret68146815 = $Hanf_arg19411333($z68106811,anf_arg12761335,anf_fun12751336,arg4481337);
++R.GAS;
return $ret68146815;
});
var $z67976798 = D;
var $f68036804 = function(_) {
return R.isFunction(anf_fun12736805)?anf_fun12736805.app(anf_arg12796806,args4426791,exps4391273):R.ffi.throwNonFunApp(L[702],anf_fun12736805,[anf_arg12796806,args4426791,exps4391273]);
};
try {
if(--R.GAS > 0) {
$z67976798 = $f68036804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68036804,
"from":L[702]});
}
} catch($e67956796) {
if(R.isCont($e67956796)) {
var $ss67996800 = {"from":L[702],
"go":function(let_DASH_binds4471317) {
return $Hlet_DASH_binds19431316(let_DASH_binds4471317,A317,body4451318,l4401319);
}};
$e67956796.stack[R.EXN_STACKHEIGHT++] = $ss67996800;
}
if(R.isPyretException($e67956796)) {
$e67956796.pyretStack.push(L[702]);
}
throw $e67956796;
}
var $ret68016802 = $Hlet_DASH_binds19431316($z67976798,A317,body4451318,l4401319);
++R.GAS;
return $ret68016802;
});
var anf_arg12826775 = R.makeObject({"s-lam":anf_obj12816789});
var anf_arg12926776 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[144],0,arguments);
}
var anf_fun12841272 = G(A317,"s-app",L[701]);
var anf_fun12856787 = G(f4386788,"visit",L[700]);
var $z67796780 = D;
var $f67856786 = function(_) {
return R.isFunction(anf_fun12856787)?anf_fun12856787.app(self4361275):R.ffi.throwNonFunApp(L[699],anf_fun12856787,[self4361275]);
};
try {
if(--R.GAS > 0) {
$z67796780 = $f67856786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67856786,
"from":L[699]});
}
} catch($e67776778) {
if(R.isCont($e67776778)) {
var $ss67816782 = {"from":L[699],
"go":function(anf_arg12861271) {
return $Hanf_arg19471270(anf_arg12861271,anf_fun12841272,exps4391273,loc4371274,self4361275);
}};
$e67776778.stack[R.EXN_STACKHEIGHT++] = $ss67816782;
}
if(R.isPyretException($e67776778)) {
$e67776778.pyretStack.push(L[699]);
}
throw $e67776778;
}
var $ret67836784 = $Hanf_arg19471270($z67796780,anf_fun12841272,exps4391273,loc4371274,self4361275);
++R.GAS;
return $ret67836784;
});
var $z67666767 = D;
var $f67726773 = function(_) {
return R.isFunction(anf_fun12716774)?anf_fun12716774.app(anf_arg12826775,anf_arg12926776):R.ffi.throwNonFunApp(L[698],anf_fun12716774,[anf_arg12826775,anf_arg12926776]);
};
try {
if(--R.GAS > 0) {
$z67666767 = $f67726773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67726773,
"from":L[698]});
}
} catch($e67646765) {
if(R.isCont($e67646765)) {
var $ss67686769 = {"from":L[698],
"go":function(ann_DASH_check_DASH_temp12701269) {
return $Hann_DASH_check_DASH_temp19481268(ann_DASH_check_DASH_temp12701269);
}};
$e67646765.stack[R.EXN_STACKHEIGHT++] = $ss67686769;
}
if(R.isPyretException($e67646765)) {
$e67646765.pyretStack.push(L[698]);
}
throw $e67646765;
}
var $ret67706771 = $Hann_DASH_check_DASH_temp19481268($z67666767);
++R.GAS;
return $ret67706771;
};
},{"length":4});
var inline_DASH_lams43581 = anf_extend12696762.extendWith({"s-app":anf_extend12936763});
var check_DASH_unbound45073 = {"$var":D,
"$name":"check-unbound"};
var value_DASH_delays_DASH_exec_DASH_of45197 = {"$var":D,
"$name":"value-delays-exec-of"};
var anf_assign13756726 = R.makeFunction(function(initial_DASH_env452743,ast453742) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[15],2,arguments);
}
var anf_fun12956761 = G(list3192,"make",L[697]);
var $z67536754 = D;
var $f67596760 = function(_) {
return R.isFunction(anf_fun12956761)?anf_fun12956761.app([]):R.ffi.throwNonFunApp(L[696],anf_fun12956761,[[]]);
};
try {
if(--R.GAS > 0) {
$z67536754 = $f67596760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67596760,
"from":L[696]});
}
} catch($e67516752) {
if(R.isCont($e67516752)) {
var $ss67556756 = {"from":L[696],
"go":function(var_DASH_bind1949741) {
return $Hvar_DASH_bind1995740(var_DASH_bind1949741,A317,CS719,ast453742,bind_DASH_exp12766,binding_DASH_env_DASH_iter_DASH_visitor40369,initial_DASH_env452743,is_DASH_none65744,link35745,not9,nothing10);
}};
$e67516752.stack[R.EXN_STACKHEIGHT++] = $ss67556756;
}
if(R.isPyretException($e67516752)) {
$e67516752.pyretStack.push(L[696]);
}
throw $e67516752;
}
var $ret67576758 = $Hvar_DASH_bind1995740($z67536754,A317,CS719,ast453742,bind_DASH_exp12766,binding_DASH_env_DASH_iter_DASH_visitor40369,initial_DASH_env452743,is_DASH_none65744,link35745,not9,nothing10);
++R.GAS;
return $ret67576758;
});
check_DASH_unbound45073.$var = anf_assign13756726;
var anf_assign13896727 = R.makeFunction(function(name4846739,expr485691) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[694],2,arguments);
}
var anf_fun13776750 = G(A317,"is-s-lam",L[695]);
var $z67426743 = D;
var $f67486749 = function(_) {
return R.isFunction(anf_fun13776750)?anf_fun13776750.app(expr485691):R.ffi.throwNonFunApp(L[76],anf_fun13776750,[expr485691]);
};
try {
if(--R.GAS > 0) {
$z67426743 = $f67486749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67486749,
"from":L[76]});
}
} catch($e67406741) {
if(R.isCont($e67406741)) {
var $ss67446745 = {"from":L[76],
"go":function(or_DASH_oper_DASH_142690) {
return $Hor_DASH_oper_DASH_1999689(or_DASH_oper_DASH_142690,A317,expr485691);
}};
$e67406741.stack[R.EXN_STACKHEIGHT++] = $ss67446745;
}
if(R.isPyretException($e67406741)) {
$e67406741.pyretStack.push(L[76]);
}
throw $e67406741;
}
var $ret67466747 = $Hor_DASH_oper_DASH_1999689($z67426743,A317,expr485691);
++R.GAS;
return $ret67466747;
});
value_DASH_delays_DASH_exec_DASH_of45197.$var = anf_assign13896727;
var anf_extend139057 = G(A317,"default-map-visitor",L[693]);
var anf_fun13916738 = G(SD920,"immutable-string-dict",L[692]);
var $z67306731 = D;
var $f67366737 = function(_) {
return R.isFunction(anf_fun13916738)?anf_fun13916738.app():R.ffi.throwNonFunApp(L[691],anf_fun13916738,[]);
};
try {
if(--R.GAS > 0) {
$z67306731 = $f67366737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67366737,
"from":L[691]});
}
} catch($e67286729) {
if(R.isCont($e67286729)) {
var $ss67326733 = {"from":L[691],
"go":function(anf_extend139251) {
return $Hanf_extend204250(anf_extend139251,A317,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,CS719,Loc7656,PP518,anf_extend139057,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,fold26080,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,link_DASH_list_DASH_visitor40491,list3192,map24493,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,range3696,value_DASH_delays_DASH_exec_DASH_of45197,_lessthan6,builtins8,nothing10);
}};
$e67286729.stack[R.EXN_STACKHEIGHT++] = $ss67326733;
}
if(R.isPyretException($e67286729)) {
$e67286729.pyretStack.push(L[691]);
}
throw $e67286729;
}
var $ret67346735 = $Hanf_extend204250($z67306731,A317,Binding12352,Binding7453,BindingInfo10854,BindingInfo7255,CS719,Loc7656,PP518,anf_extend139057,append_DASH_nothing_DASH_if_DASH_necessary7958,b_DASH_dict11359,b_DASH_dot11760,b_DASH_exp11561,b_DASH_prim11162,b_DASH_typ11963,b_DASH_unknown12164,bad_DASH_assignments40565,bind_DASH_exp12766,bind_DASH_or_DASH_unknown12867,binding_DASH_env_DASH_from_DASH_env13068,binding_DASH_env_DASH_iter_DASH_visitor40369,binding_DASH_env_DASH_map_DASH_visitor40270,binding_DASH_handlers36871,binding_DASH_type_DASH_env_DASH_from_DASH_env12972,check_DASH_unbound45073,checkers7874,count_DASH_apps10675,default_DASH_env_DASH_iter_DASH_visitor13276,default_DASH_env_DASH_map_DASH_visitor13177,e_DASH_bind12678,flatten_DASH_single_DASH_blocks9379,fold26080,inline_DASH_lams43581,is_DASH_Binding12482,is_DASH_BindingInfo10983,is_DASH_b_DASH_dict11284,is_DASH_b_DASH_dot11685,is_DASH_b_DASH_exp11486,is_DASH_b_DASH_prim11087,is_DASH_b_DASH_typ11888,is_DASH_b_DASH_unknown12089,is_DASH_e_DASH_bind12590,link_DASH_list_DASH_visitor40491,list3192,map24493,merge_DASH_nested_DASH_blocks9794,ok_DASH_last7795,range3696,value_DASH_delays_DASH_exec_DASH_of45197,_lessthan6,builtins8,nothing10);
++R.GAS;
return $ret67346735;
},function(moduleVal) {
R.modules["$src/arr/compiler/ast-util.arr38"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/desugar-check.arr',["trove/ast",
"trove/srcloc",
"compiler/gensym.arr",
"compiler/ast-util.arr",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($A11130,$SL31231,$G51332,$U71433,$arrays91534,$lists111635,$option131736,$error151837,$sets171938) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/desugar-check.arr29"]) {
return R.modules["$src/arr/compiler/desugar-check.arr29"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/desugar-check.arr";
var D = R.undefined;
var L = [[M,10,0,146,12,3,228],
[M,132,2,4310,134,5,4398],
[M,105,4,3332,105,39,3367],
[M,105,25,3353,105,38,3366],
[M,105,15,3343,105,24,3352],
[M,106,4,3372,106,56,3424],
[M,107,7,3432,107,34,3459],
[M,107,36,3461,107,58,3483],
[M,107,36,3461,107,45,3470],
[M,108,4,3488,108,52,3536],
[M,108,32,3516,108,52,3536],
[M,110,30,3577,110,64,3611],
[M,110,30,3577,110,41,3588],
[M,110,18,3565,110,26,3573],
[M,108,12,3496,108,30,3514],
[M,110,6,3553,110,65,3612],
[M,111,6,3619,111,33,3646],
[M,111,18,3631,111,31,3644],
[M,114,24,3701,114,41,3718],
[M,114,24,3701,114,39,3716],
[M,114,10,3687,114,23,3700],
[M,112,6,3653,112,15,3662],
[M,114,24,3701,114,46,3723],
[M,114,10,3687,114,46,3723],
[M,116,25,3771,116,65,3811],
[M,116,55,3801,116,64,3810],
[M,116,25,3771,116,33,3779],
[M,116,14,3760,116,21,3767],
[M,115,12,3738,119,13,3905],
[M,116,14,3760,116,84,3830],
[M,118,14,3871,118,34,3891],
[M,118,14,3871,118,20,3877],
[M,114,10,3687,119,13,3905],
[M,112,6,3653,120,9,3915],
[M,97,2,3127,99,5,3215],
[M,93,23,2989,93,81,3047],
[M,93,32,2998,93,80,3046],
[M,93,66,3032,93,75,3041],
[M,93,42,3008,93,50,3016],
[M,93,23,2989,93,31,2997],
[M,92,0,2937,94,3,3079],
[M,93,83,3049,93,92,3058],
[M,84,28,2693,84,41,2706],
[M,84,28,2693,84,38,2703],
[M,84,17,2682,84,24,2689],
[M,84,6,2671,84,13,2678],
[M,83,15,2657,89,5,2930],
[M,83,2,2644,83,11,2653],
[M,84,17,2682,84,56,2721],
[M,85,10,2741,85,30,2761],
[M,85,21,2752,85,29,2760],
[M,85,10,2741,85,17,2748],
[M,84,58,2723,88,9,2923],
[M,87,59,2882,87,78,2901],
[M,87,59,2882,87,67,2890],
[M,87,49,2872,87,55,2878],
[M,87,27,2850,87,47,2870],
[M,87,10,2833,87,23,2846],
[M,87,49,2872,87,79,2902],
[M,87,10,2833,87,90,2913],
[M,84,6,2671,88,10,2924],
[M,70,0,2125,90,3,2935],
[M,74,20,2267,74,28,2275],
[M,74,8,2255,74,48,2295],
[M,76,31,2355,76,50,2374],
[M,76,31,2355,76,38,2362],
[M,76,12,2336,76,26,2350],
[M,75,20,2316,79,11,2586],
[M,75,8,2304,75,15,2311],
[M,76,52,2376,76,69,2393],
[M,76,52,2376,76,59,2383],
[M,76,12,2336,76,70,2394],
[M,77,31,2427,77,49,2445],
[M,77,31,2427,77,38,2434],
[M,77,12,2408,77,26,2422],
[M,77,12,2408,77,61,2457],
[M,78,31,2490,78,54,2513],
[M,78,31,2490,78,38,2497],
[M,78,12,2471,78,26,2485],
[M,78,94,2553,78,112,2571],
[M,78,94,2553,78,104,2563],
[M,78,87,2546,78,113,2572],
[M,78,56,2515,78,68,2527],
[M,78,56,2515,78,114,2573],
[M,78,12,2471,78,115,2574],
[M,73,6,2215,79,12,2587],
[M,42,0,1212,68,3,2123],
[M,63,39,2012,63,70,2043],
[M,63,39,2012,63,49,2022],
[M,63,13,1986,63,71,2044],
[M,56,5,1717,63,77,2050],
[M,60,29,1907,60,57,1935],
[M,58,10,1811,60,57,1935],
[M,53,28,1620,53,77,1669],
[M,53,10,1602,53,83,1675],
[M,48,28,1423,48,77,1472],
[M,48,10,1405,48,83,1478],
[M,26,21,653,26,41,673],
[M,27,33,707,27,60,734],
[M,29,17,782,29,62,827],
[M,31,21,866,31,55,900],
[M,31,21,866,31,35,880],
[M,31,10,855,31,17,862],
[M,30,8,837,35,9,1101],
[M,31,21,866,31,66,911],
[M,31,21,866,31,64,909],
[M,31,21,866,31,77,922],
[M,31,21,866,31,73,918],
[M,31,21,866,31,92,937],
[M,31,21,866,31,86,931],
[M,31,10,855,31,93,938],
[M,32,21,961,32,29,969],
[M,32,10,950,32,17,957],
[M,32,31,971,32,39,979],
[M,32,10,950,32,67,1007],
[M,32,41,981,32,50,990],
[M,34,47,1073,34,63,1089],
[M,34,47,1073,34,57,1083],
[M,34,40,1066,34,64,1090],
[M,34,10,1036,34,22,1048],
[M,34,10,1036,34,65,1091],
[M,29,6,771,35,10,1102],
[M,37,12,1125,37,81,1194],
[M,37,71,1184,37,80,1193],
[M,37,6,1119,37,81,1194],
[M,18,17,365,18,53,401],
[M,20,21,440,20,55,474],
[M,20,21,440,20,35,454],
[M,20,10,429,20,17,436],
[M,19,8,411,24,9,622],
[M,20,21,440,20,66,485],
[M,20,21,440,20,64,483],
[M,20,21,440,20,77,496],
[M,20,21,440,20,73,492],
[M,20,21,440,20,92,511],
[M,20,21,440,20,86,505],
[M,20,10,429,20,93,512],
[M,23,47,594,23,63,610],
[M,23,47,594,23,57,604],
[M,23,40,587,23,64,611],
[M,23,10,557,23,22,569],
[M,23,10,557,23,65,612],
[M,17,4,323,25,7,631],
[M,11,2,164,11,62,224],
[M,3,0,13,151,3,4834],
[M,149,0,4770,151,3,4834],
[M,150,2,4801,150,12,4811],
[M,137,0,4402,147,3,4768],
[M,146,2,4739,146,12,4749],
[M,133,14,4369,133,36,4391],
[M,133,14,4369,133,22,4377],
[M,133,4,4359,133,10,4365],
[M,129,2,4201,131,5,4306],
[M,130,4,4254,130,11,4261],
[M,126,2,4054,128,5,4197],
[M,127,4,4126,127,12,4134],
[M,123,2,3933,125,5,4050],
[M,124,4,3992,124,11,3999],
[M,104,4,3290,104,41,3327],
[M,103,2,3261,122,5,3929],
[M,102,16,3235,102,37,3256],
[M,98,14,3186,98,36,3208],
[M,98,14,3186,98,22,3194],
[M,98,4,3176,98,10,3182],
[M,96,20,3101,96,41,3122],
[M,93,13,2979,93,21,2987],
[M,93,2,2968,93,9,2975],
[M,82,2,2604,82,39,2641],
[M,82,13,2615,82,23,2625],
[M,71,2,2162,81,5,2601],
[M,72,4,2189,80,7,2595],
[M,74,33,2280,74,41,2288],
[M,67,25,2110,67,33,2118],
[M,67,2,2087,67,13,2098],
[M,44,2,1266,66,5,2084],
[M,45,4,1296,65,7,2078],
[M,57,8,1768,62,11,1972],
[M,57,21,1781,62,11,1972],
[M,61,10,1946,61,24,1960],
[M,59,34,1855,59,56,1877],
[M,51,6,1521,55,11,1711],
[M,52,8,1570,55,11,1711],
[M,54,10,1686,54,23,1699],
[M,53,48,1640,53,76,1668],
[M,53,48,1640,53,55,1647],
[M,46,6,1322,50,11,1514],
[M,47,8,1373,50,11,1514],
[M,49,10,1489,49,23,1502],
[M,48,48,1443,48,76,1471],
[M,48,48,1443,48,55,1450],
[M,29,28,793,29,41,806],
[M,29,28,793,29,38,803],
[M,29,17,782,29,24,789],
[M,29,6,771,29,13,778],
[M,28,12,747,28,29,764],
[M,27,12,686,27,32,706],
[M,26,7,639,26,20,652],
[M,18,28,376,18,41,389],
[M,18,28,376,18,38,386],
[M,18,17,365,18,24,372],
[M,18,6,354,18,13,361],
[M,16,2,279,39,5,1208],
[M,15,22,253,15,43,274],
[M,11,4,166,11,62,224],
[M,11,20,182,11,29,191],
[M,11,55,217,11,61,223],
[M,11,39,201,11,45,207],
[M,11,47,209,11,61,223],
[M,11,31,193,11,45,207],
[M,11,15,177,11,29,191]];
var _minus3 = NAMESPACE.get("_minus");
var _plus4 = NAMESPACE.get("_plus");
var builtins5 = NAMESPACE.get("builtins");
var nothing6 = NAMESPACE.get("nothing");
var raise7 = NAMESPACE.get("raise");
var torepr8 = NAMESPACE.get("torepr");
var tostring9 = NAMESPACE.get("tostring");
var $type$String10 = NAMESPACE.get("$type$String");
var $Hanf_bracket43339 = function(anf_bracket30640,CheckInfo6841,provides30442,nothing6) {
var anf_fun30753 = G(anf_bracket30640,"results",L[0]);
var $z4546 = D;
var $f5152 = function(_) {
return R.isFunction(anf_fun30753)?anf_fun30753.app():R.ffi.throwNonFunApp(L[0],anf_fun30753,[]);
};
try {
if(--R.GAS > 0) {
$z4546 = $f5152();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5152,
"from":L[0]});
}
} catch($e4344) {
if(R.isCont($e4344)) {
var $ss4748 = {"from":L[0],
"go":function(checks30854) {
return $Hchecks43255(checks30854,CheckInfo6841,provides30442,nothing6);
}};
$e4344.stack[R.EXN_STACKHEIGHT++] = $ss4748;
}
if(R.isPyretException($e4344)) {
$e4344.pyretStack.push(L[0]);
}
throw $e4344;
}
var $ret4950 = $Hchecks43255($z4546,CheckInfo6841,provides30442,nothing6);
++R.GAS;
return $ret4950;
};
var $Hchecks43255 = function(checks30854,CheckInfo6841,provides30442,nothing6) {
return R.makeObject({"answer":nothing6,
"provide-plus-types":R.makeObject({"values":provides30442,
"types":{"CheckInfo":CheckInfo6841}}),
"checks":checks30854});
};
var $Hann_DASH_check_DASH_temp43156 = function(ann_DASH_check_DASH_temp30157) {
return ann_DASH_check_DASH_temp30157;
};
var $Hann_DASH_check_DASH_temp43058 = function(ann_DASH_check_DASH_temp29859) {
return ann_DASH_check_DASH_temp29859;
};
var $Hanf_arg42960 = function(anf_arg29661,anf_fun29462,l17163) {
var $z6667 = D;
var $f7273 = function(_) {
return R.isFunction(anf_fun29462)?anf_fun29462.app(l17163,anf_arg29661):R.ffi.throwNonFunApp(L[1],anf_fun29462,[l17163,anf_arg29661]);
};
try {
if(--R.GAS > 0) {
$z6667 = $f7273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7273,
"from":L[1]});
}
} catch($e6465) {
if(R.isCont($e6465)) {
var $ss6869 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp29374) {
return $Hann_DASH_check_DASH_temp42875(ann_DASH_check_DASH_temp29374);
}};
$e6465.stack[R.EXN_STACKHEIGHT++] = $ss6869;
}
if(R.isPyretException($e6465)) {
$e6465.pyretStack.push(L[1]);
}
throw $e6465;
}
var $ret7071 = $Hann_DASH_check_DASH_temp42875($z6667);
++R.GAS;
return $ret7071;
};
var $Hann_DASH_check_DASH_temp42875 = function(ann_DASH_check_DASH_temp29374) {
return ann_DASH_check_DASH_temp29374;
};
var $Hann_DASH_check_DASH_temp42776 = function(ann_DASH_check_DASH_temp29077) {
return ann_DASH_check_DASH_temp29077;
};
var $Hann_DASH_check_DASH_temp42678 = function(ann_DASH_check_DASH_temp28779) {
return ann_DASH_check_DASH_temp28779;
};
var $Hann_DASH_check_DASH_temp42580 = function(ann_DASH_check_DASH_temp28481) {
return ann_DASH_check_DASH_temp28481;
};
var $Hchecks_DASH_to_DASH_perform42482 = function(checks_DASH_to_DASH_perform14083,A111,G513,create_DASH_check_DASH_block8784,is_DASH_empty2885,l13886,list2787,self13788,stmts13989,_minus3,_plus4,raise7) {
var anf_fun244100 = G(stmts13989,"map",L[4]);
var anf_arg247101 = R.makeFunction(function(recv_DASH_15104) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
var anf_fun246115 = G(recv_DASH_15104,"visit",L[3]);
var $z107108 = D;
var $f113114 = function(_) {
return R.isFunction(anf_fun246115)?anf_fun246115.app(self13788):R.ffi.throwNonFunApp(L[3],anf_fun246115,[self13788]);
};
try {
if(--R.GAS > 0) {
$z107108 = $f113114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f113114,
"from":L[3]});
}
} catch($e105106) {
if(R.isCont($e105106)) {
var $ss109110 = {"from":L[3],
"go":function(ann_DASH_check_DASH_temp245116) {
return $Hann_DASH_check_DASH_temp405117(ann_DASH_check_DASH_temp245116);
}};
$e105106.stack[R.EXN_STACKHEIGHT++] = $ss109110;
}
if(R.isPyretException($e105106)) {
$e105106.pyretStack.push(L[3]);
}
throw $e105106;
}
var $ret111112 = $Hann_DASH_check_DASH_temp405117($z107108);
++R.GAS;
return $ret111112;
});
var $z9293 = D;
var $f9899 = function(_) {
return R.isFunction(anf_fun244100)?anf_fun244100.app(anf_arg247101):R.ffi.throwNonFunApp(L[2],anf_fun244100,[anf_arg247101]);
};
try {
if(--R.GAS > 0) {
$z9293 = $f9899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9899,
"from":L[2]});
}
} catch($e9091) {
if(R.isCont($e9091)) {
var $ss9495 = {"from":L[2],
"go":function(ds_DASH_stmts141102) {
return $Hds_DASH_stmts423103(ds_DASH_stmts141102,A111,G513,checks_DASH_to_DASH_perform14083,create_DASH_check_DASH_block8784,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7);
}};
$e9091.stack[R.EXN_STACKHEIGHT++] = $ss9495;
}
if(R.isPyretException($e9091)) {
$e9091.pyretStack.push(L[2]);
}
throw $e9091;
}
var $ret9697 = $Hds_DASH_stmts423103($z9293,A111,G513,checks_DASH_to_DASH_perform14083,create_DASH_check_DASH_block8784,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7);
++R.GAS;
return $ret9697;
};
var $Hds_DASH_stmts423103 = function(ds_DASH_stmts141102,A111,G513,checks_DASH_to_DASH_perform14083,create_DASH_check_DASH_block8784,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7) {
var $z120121 = D;
var $f126127 = function(_) {
return R.isFunction(create_DASH_check_DASH_block8784.$var)?create_DASH_check_DASH_block8784.$var.app(l13886,checks_DASH_to_DASH_perform14083):R.ffi.throwNonFunApp(L[5],create_DASH_check_DASH_block8784.$var,[l13886,checks_DASH_to_DASH_perform14083]);
};
try {
if(--R.GAS > 0) {
$z120121 = $f126127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f126127,
"from":L[5]});
}
} catch($e118119) {
if(R.isCont($e118119)) {
var $ss122123 = {"from":L[5],
"go":function(do_DASH_checks142128) {
return $Hdo_DASH_checks422129(do_DASH_checks142128,A111,G513,checks_DASH_to_DASH_perform14083,ds_DASH_stmts141102,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7);
}};
$e118119.stack[R.EXN_STACKHEIGHT++] = $ss122123;
}
if(R.isPyretException($e118119)) {
$e118119.pyretStack.push(L[5]);
}
throw $e118119;
}
var $ret124125 = $Hdo_DASH_checks422129($z120121,A111,G513,checks_DASH_to_DASH_perform14083,ds_DASH_stmts141102,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7);
++R.GAS;
return $ret124125;
};
var $Hdo_DASH_checks422129 = function(do_DASH_checks142128,A111,G513,checks_DASH_to_DASH_perform14083,ds_DASH_stmts141102,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7) {
var $z132133 = D;
var $f138139 = function(_) {
return R.isFunction(is_DASH_empty2885)?is_DASH_empty2885.app(checks_DASH_to_DASH_perform14083):R.ffi.throwNonFunApp(L[6],is_DASH_empty2885,[checks_DASH_to_DASH_perform14083]);
};
try {
if(--R.GAS > 0) {
$z132133 = $f138139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f138139,
"from":L[6]});
}
} catch($e130131) {
if(R.isCont($e130131)) {
var $ss134135 = {"from":L[6],
"go":function(if_DASH_17140) {
return $Hif_DASH_421141(if_DASH_17140,A111,G513,do_DASH_checks142128,ds_DASH_stmts141102,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7);
}};
$e130131.stack[R.EXN_STACKHEIGHT++] = $ss134135;
}
if(R.isPyretException($e130131)) {
$e130131.pyretStack.push(L[6]);
}
throw $e130131;
}
var $ret136137 = $Hif_DASH_421141($z132133,A111,G513,do_DASH_checks142128,ds_DASH_stmts141102,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7);
++R.GAS;
return $ret136137;
};
var $Hif_DASH_421141 = function(if_DASH_17140,A111,G513,do_DASH_checks142128,ds_DASH_stmts141102,is_DASH_empty2885,l13886,list2787,_minus3,_plus4,raise7) {
var if_helper248154 = R.makeFunction(function(if_helper_arg249173) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
var ann_DASH_check_DASH_temp243174 = if_helper_arg249173;
return ann_DASH_check_DASH_temp243174;
});
var anf_if252172 = R.isBoolean(if_DASH_17140);
if(R.isPyretTrue(anf_if252172)) {
if(R.isPyretTrue(if_DASH_17140)) {
var anf_fun280152 = G(A111,"s-block",L[8]);
var $z144145 = D;
var $f150151 = function(_) {
return R.isFunction(anf_fun280152)?anf_fun280152.app(l13886,ds_DASH_stmts141102):R.ffi.throwNonFunApp(L[7],anf_fun280152,[l13886,ds_DASH_stmts141102]);
};
try {
if(--R.GAS > 0) {
$z144145 = $f150151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f150151,
"from":L[7]});
}
} catch($e142143) {
if(R.isCont($e142143)) {
var $ss146147 = {"from":L[7],
"go":function(cont_tail_arg281153) {
return $Hcont_tail_arg406155(cont_tail_arg281153,if_helper248154);
}};
$e142143.stack[R.EXN_STACKHEIGHT++] = $ss146147;
}
if(R.isPyretException($e142143)) {
$e142143.pyretStack.push(L[7]);
}
throw $e142143;
}
var $ret148149 = $Hcont_tail_arg406155($z144145,if_helper248154);
++R.GAS;
return $ret148149;
} else {
var $z158159 = D;
var $f164165 = function(_) {
return R.isFunction(is_DASH_empty2885)?is_DASH_empty2885.app(ds_DASH_stmts141102):R.ffi.throwNonFunApp(L[9],is_DASH_empty2885,[ds_DASH_stmts141102]);
};
try {
if(--R.GAS > 0) {
$z158159 = $f164165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f164165,
"from":L[9]});
}
} catch($e156157) {
if(R.isCont($e156157)) {
var $ss160161 = {"from":L[9],
"go":function(if_DASH_16166) {
return $Hif_DASH_420167(if_DASH_16166,A111,G513,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4,raise7);
}};
$e156157.stack[R.EXN_STACKHEIGHT++] = $ss160161;
}
if(R.isPyretException($e156157)) {
$e156157.pyretStack.push(L[9]);
}
throw $e156157;
}
var $ret162163 = $Hif_DASH_420167($z158159,A111,G513,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4,raise7);
++R.GAS;
return $ret162163;
}
} else {
var cont_tail_arg250170 = R.throwNonBooleanCondition(L[6],("if"),if_DASH_17140);
if(--R.GAS > 0) {
$z168169 = R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg250170):R.ffi.throwNonFunApp(L[6],if_helper248154,[cont_tail_arg250170]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg250170):R.ffi.throwNonFunApp(L[6],if_helper248154,[cont_tail_arg250170]);
},
"from":L[6]});
}
++R.GAS;
return $z168169;
}
};
var $Hcont_tail_arg406155 = function(cont_tail_arg281153,if_helper248154) {
if(--R.GAS > 0) {
$z175176 = R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg281153):R.ffi.throwNonFunApp(L[7],if_helper248154,[cont_tail_arg281153]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg281153):R.ffi.throwNonFunApp(L[7],if_helper248154,[cont_tail_arg281153]);
},
"from":L[7]});
}
++R.GAS;
return $z175176;
};
var $Hif_DASH_420167 = function(if_DASH_16166,A111,G513,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4,raise7) {
var anf_if255206 = R.isBoolean(if_DASH_16166);
if(R.isPyretTrue(anf_if255206)) {
if(R.isPyretTrue(if_DASH_16166)) {
var $z179180 = D;
var $f185186 = function(_) {
return R.isFunction(raise7)?raise7.app(("Empty block")):R.ffi.throwNonFunApp(L[10],raise7,[("Empty block")]);
};
try {
if(--R.GAS > 0) {
$z179180 = $f185186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f185186,
"from":L[10]});
}
} catch($e177178) {
if(R.isCont($e177178)) {
var $ss181182 = {"from":L[10],
"go":function(cont_tail_arg278187) {
return $Hcont_tail_arg407188(cont_tail_arg278187,if_helper248154);
}};
$e177178.stack[R.EXN_STACKHEIGHT++] = $ss181182;
}
if(R.isPyretException($e177178)) {
$e177178.pyretStack.push(L[10]);
}
throw $e177178;
}
var $ret183184 = $Hcont_tail_arg407188($z179180,if_helper248154);
++R.GAS;
return $ret183184;
} else {
var anf_fun256201 = G(A111,"s-name",L[13]);
var anf_fun257199 = G(G513,"make-name",L[12]);
var $z191192 = D;
var $f197198 = function(_) {
return R.isFunction(anf_fun257199)?anf_fun257199.app(("result-after-checks")):R.ffi.throwNonFunApp(L[11],anf_fun257199,[("result-after-checks")]);
};
try {
if(--R.GAS > 0) {
$z191192 = $f197198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f197198,
"from":L[11]});
}
} catch($e189190) {
if(R.isCont($e189190)) {
var $ss193194 = {"from":L[11],
"go":function(anf_arg258200) {
return $Hanf_arg419202(anf_arg258200,A111,anf_fun256201,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4);
}};
$e189190.stack[R.EXN_STACKHEIGHT++] = $ss193194;
}
if(R.isPyretException($e189190)) {
$e189190.pyretStack.push(L[11]);
}
throw $e189190;
}
var $ret195196 = $Hanf_arg419202($z191192,A111,anf_fun256201,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4);
++R.GAS;
return $ret195196;
}
} else {
var cont_tail_arg253205 = R.throwNonBooleanCondition(L[14],("if"),if_DASH_16166);
if(--R.GAS > 0) {
$z203204 = R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg253205):R.ffi.throwNonFunApp(L[14],if_helper248154,[cont_tail_arg253205]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg253205):R.ffi.throwNonFunApp(L[14],if_helper248154,[cont_tail_arg253205]);
},
"from":L[14]});
}
++R.GAS;
return $z203204;
}
};
var $Hcont_tail_arg407188 = function(cont_tail_arg278187,if_helper248154) {
if(--R.GAS > 0) {
$z207208 = R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg278187):R.ffi.throwNonFunApp(L[10],if_helper248154,[cont_tail_arg278187]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg278187):R.ffi.throwNonFunApp(L[10],if_helper248154,[cont_tail_arg278187]);
},
"from":L[10]});
}
++R.GAS;
return $z207208;
};
var $Hanf_arg419202 = function(anf_arg258200,A111,anf_fun256201,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4) {
var $z211212 = D;
var $f217218 = function(_) {
return R.isFunction(anf_fun256201)?anf_fun256201.app(l13886,anf_arg258200):R.ffi.throwNonFunApp(L[15],anf_fun256201,[l13886,anf_arg258200]);
};
try {
if(--R.GAS > 0) {
$z211212 = $f217218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f217218,
"from":L[15]});
}
} catch($e209210) {
if(R.isCont($e209210)) {
var $ss213214 = {"from":L[15],
"go":function(id_DASH_result143219) {
return $Hid_DASH_result418220(id_DASH_result143219,A111,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4);
}};
$e209210.stack[R.EXN_STACKHEIGHT++] = $ss213214;
}
if(R.isPyretException($e209210)) {
$e209210.pyretStack.push(L[15]);
}
throw $e209210;
}
var $ret215216 = $Hid_DASH_result418220($z211212,A111,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4);
++R.GAS;
return $ret215216;
};
var $Hid_DASH_result418220 = function(id_DASH_result143219,A111,do_DASH_checks142128,ds_DASH_stmts141102,if_helper248154,l13886,list2787,_minus3,_plus4) {
var anf_fun259231 = G(ds_DASH_stmts141102,"last",L[17]);
var $z223224 = D;
var $f229230 = function(_) {
return R.isFunction(anf_fun259231)?anf_fun259231.app():R.ffi.throwNonFunApp(L[16],anf_fun259231,[]);
};
try {
if(--R.GAS > 0) {
$z223224 = $f229230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f229230,
"from":L[16]});
}
} catch($e221222) {
if(R.isCont($e221222)) {
var $ss225226 = {"from":L[16],
"go":function(last_DASH_expr144232) {
return $Hlast_DASH_expr417233(last_DASH_expr144232,A111,do_DASH_checks142128,ds_DASH_stmts141102,id_DASH_result143219,if_helper248154,l13886,list2787,_minus3,_plus4);
}};
$e221222.stack[R.EXN_STACKHEIGHT++] = $ss225226;
}
if(R.isPyretException($e221222)) {
$e221222.pyretStack.push(L[16]);
}
throw $e221222;
}
var $ret227228 = $Hlast_DASH_expr417233($z223224,A111,do_DASH_checks142128,ds_DASH_stmts141102,id_DASH_result143219,if_helper248154,l13886,list2787,_minus3,_plus4);
++R.GAS;
return $ret227228;
};
var $Hlast_DASH_expr417233 = function(last_DASH_expr144232,A111,do_DASH_checks142128,ds_DASH_stmts141102,id_DASH_result143219,if_helper248154,l13886,list2787,_minus3,_plus4) {
var anf_fun260246 = G(A111,"s-block",L[21]);
var anf_fun261247 = G(ds_DASH_stmts141102,"take",L[20]);
var anf_fun262244 = G(ds_DASH_stmts141102,"length",L[19]);
var $z236237 = D;
var $f242243 = function(_) {
return R.isFunction(anf_fun262244)?anf_fun262244.app():R.ffi.throwNonFunApp(L[18],anf_fun262244,[]);
};
try {
if(--R.GAS > 0) {
$z236237 = $f242243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f242243,
"from":L[18]});
}
} catch($e234235) {
if(R.isCont($e234235)) {
var $ss238239 = {"from":L[18],
"go":function(anf_arg263245) {
return $Hanf_arg416248(anf_arg263245,A111,anf_fun260246,anf_fun261247,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_minus3,_plus4);
}};
$e234235.stack[R.EXN_STACKHEIGHT++] = $ss238239;
}
if(R.isPyretException($e234235)) {
$e234235.pyretStack.push(L[18]);
}
throw $e234235;
}
var $ret240241 = $Hanf_arg416248($z236237,A111,anf_fun260246,anf_fun261247,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_minus3,_plus4);
++R.GAS;
return $ret240241;
};
var $Hanf_arg416248 = function(anf_arg263245,A111,anf_fun260246,anf_fun261247,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_minus3,_plus4) {
var $z251252 = D;
var $f257258 = function(_) {
return R.isFunction(_minus3)?_minus3.app(anf_arg263245,(1)):R.ffi.throwNonFunApp(L[22],_minus3,[anf_arg263245,(1)]);
};
try {
if(--R.GAS > 0) {
$z251252 = $f257258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f257258,
"from":L[22]});
}
} catch($e249250) {
if(R.isCont($e249250)) {
var $ss253254 = {"from":L[22],
"go":function(anf_arg264259) {
return $Hanf_arg415260(anf_arg264259,A111,anf_fun260246,anf_fun261247,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_plus4);
}};
$e249250.stack[R.EXN_STACKHEIGHT++] = $ss253254;
}
if(R.isPyretException($e249250)) {
$e249250.pyretStack.push(L[22]);
}
throw $e249250;
}
var $ret255256 = $Hanf_arg415260($z251252,A111,anf_fun260246,anf_fun261247,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_plus4);
++R.GAS;
return $ret255256;
};
var $Hanf_arg415260 = function(anf_arg264259,A111,anf_fun260246,anf_fun261247,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_plus4) {
var $z263264 = D;
var $f269270 = function(_) {
return R.isFunction(anf_fun261247)?anf_fun261247.app(anf_arg264259):R.ffi.throwNonFunApp(L[23],anf_fun261247,[anf_arg264259]);
};
try {
if(--R.GAS > 0) {
$z263264 = $f269270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f269270,
"from":L[23]});
}
} catch($e261262) {
if(R.isCont($e261262)) {
var $ss265266 = {"from":L[23],
"go":function(anf_arg265271) {
return $Hanf_arg414272(anf_arg265271,A111,anf_fun260246,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_plus4);
}};
$e261262.stack[R.EXN_STACKHEIGHT++] = $ss265266;
}
if(R.isPyretException($e261262)) {
$e261262.pyretStack.push(L[23]);
}
throw $e261262;
}
var $ret267268 = $Hanf_arg414272($z263264,A111,anf_fun260246,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_plus4);
++R.GAS;
return $ret267268;
};
var $Hanf_arg414272 = function(anf_arg265271,A111,anf_fun260246,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,list2787,_plus4) {
var anf_fun266286 = G(list2787,"make",L[28]);
var anf_fun267287 = G(A111,"s-let",L[27]);
var anf_fun268283 = G(A111,"s-bind",L[26]);
var anf_arg269284 = G(A111,"a-blank",L[25]);
var $z275276 = D;
var $f281282 = function(_) {
return R.isFunction(anf_fun268283)?anf_fun268283.app(l13886,(false),id_DASH_result143219,anf_arg269284):R.ffi.throwNonFunApp(L[24],anf_fun268283,[l13886,(false),id_DASH_result143219,anf_arg269284]);
};
try {
if(--R.GAS > 0) {
$z275276 = $f281282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f281282,
"from":L[24]});
}
} catch($e273274) {
if(R.isCont($e273274)) {
var $ss277278 = {"from":L[24],
"go":function(anf_arg270285) {
return $Hanf_arg413288(anf_arg270285,A111,anf_arg265271,anf_fun260246,anf_fun266286,anf_fun267287,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,_plus4);
}};
$e273274.stack[R.EXN_STACKHEIGHT++] = $ss277278;
}
if(R.isPyretException($e273274)) {
$e273274.pyretStack.push(L[24]);
}
throw $e273274;
}
var $ret279280 = $Hanf_arg413288($z275276,A111,anf_arg265271,anf_fun260246,anf_fun266286,anf_fun267287,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,_plus4);
++R.GAS;
return $ret279280;
};
var $Hanf_arg413288 = function(anf_arg270285,A111,anf_arg265271,anf_fun260246,anf_fun266286,anf_fun267287,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,last_DASH_expr144232,_plus4) {
var $z291292 = D;
var $f297298 = function(_) {
return R.isFunction(anf_fun267287)?anf_fun267287.app(l13886,anf_arg270285,last_DASH_expr144232,(false)):R.ffi.throwNonFunApp(L[29],anf_fun267287,[l13886,anf_arg270285,last_DASH_expr144232,(false)]);
};
try {
if(--R.GAS > 0) {
$z291292 = $f297298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f297298,
"from":L[29]});
}
} catch($e289290) {
if(R.isCont($e289290)) {
var $ss293294 = {"from":L[29],
"go":function(anf_array_val271299) {
return $Hanf_array_val412300(anf_array_val271299,A111,anf_arg265271,anf_fun260246,anf_fun266286,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,_plus4);
}};
$e289290.stack[R.EXN_STACKHEIGHT++] = $ss293294;
}
if(R.isPyretException($e289290)) {
$e289290.pyretStack.push(L[29]);
}
throw $e289290;
}
var $ret295296 = $Hanf_array_val412300($z291292,A111,anf_arg265271,anf_fun260246,anf_fun266286,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,_plus4);
++R.GAS;
return $ret295296;
};
var $Hanf_array_val412300 = function(anf_array_val271299,A111,anf_arg265271,anf_fun260246,anf_fun266286,do_DASH_checks142128,id_DASH_result143219,if_helper248154,l13886,_plus4) {
var anf_fun272311 = G(A111,"s-id",L[31]);
var $z303304 = D;
var $f309310 = function(_) {
return R.isFunction(anf_fun272311)?anf_fun272311.app(l13886,id_DASH_result143219):R.ffi.throwNonFunApp(L[30],anf_fun272311,[l13886,id_DASH_result143219]);
};
try {
if(--R.GAS > 0) {
$z303304 = $f309310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f309310,
"from":L[30]});
}
} catch($e301302) {
if(R.isCont($e301302)) {
var $ss305306 = {"from":L[30],
"go":function(anf_array_val273312) {
return $Hanf_array_val411313(anf_array_val273312,anf_arg265271,anf_array_val271299,anf_fun260246,anf_fun266286,do_DASH_checks142128,if_helper248154,l13886,_plus4);
}};
$e301302.stack[R.EXN_STACKHEIGHT++] = $ss305306;
}
if(R.isPyretException($e301302)) {
$e301302.pyretStack.push(L[30]);
}
throw $e301302;
}
var $ret307308 = $Hanf_array_val411313($z303304,anf_arg265271,anf_array_val271299,anf_fun260246,anf_fun266286,do_DASH_checks142128,if_helper248154,l13886,_plus4);
++R.GAS;
return $ret307308;
};
var $Hanf_array_val411313 = function(anf_array_val273312,anf_arg265271,anf_array_val271299,anf_fun260246,anf_fun266286,do_DASH_checks142128,if_helper248154,l13886,_plus4) {
var $z316317 = D;
var $f322323 = function(_) {
return R.isFunction(anf_fun266286)?anf_fun266286.app([anf_array_val271299,do_DASH_checks142128,anf_array_val273312]):R.ffi.throwNonFunApp(L[28],anf_fun266286,[[anf_array_val271299,do_DASH_checks142128,anf_array_val273312]]);
};
try {
if(--R.GAS > 0) {
$z316317 = $f322323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f322323,
"from":L[28]});
}
} catch($e314315) {
if(R.isCont($e314315)) {
var $ss318319 = {"from":L[28],
"go":function(anf_arg274324) {
return $Hanf_arg410325(anf_arg274324,anf_arg265271,anf_fun260246,if_helper248154,l13886,_plus4);
}};
$e314315.stack[R.EXN_STACKHEIGHT++] = $ss318319;
}
if(R.isPyretException($e314315)) {
$e314315.pyretStack.push(L[28]);
}
throw $e314315;
}
var $ret320321 = $Hanf_arg410325($z316317,anf_arg265271,anf_fun260246,if_helper248154,l13886,_plus4);
++R.GAS;
return $ret320321;
};
var $Hanf_arg410325 = function(anf_arg274324,anf_arg265271,anf_fun260246,if_helper248154,l13886,_plus4) {
var $z328329 = D;
var $f334335 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg265271,anf_arg274324):R.ffi.throwNonFunApp(L[32],_plus4,[anf_arg265271,anf_arg274324]);
};
try {
if(--R.GAS > 0) {
$z328329 = $f334335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f334335,
"from":L[32]});
}
} catch($e326327) {
if(R.isCont($e326327)) {
var $ss330331 = {"from":L[32],
"go":function(anf_arg275336) {
return $Hanf_arg409337(anf_arg275336,anf_fun260246,if_helper248154,l13886);
}};
$e326327.stack[R.EXN_STACKHEIGHT++] = $ss330331;
}
if(R.isPyretException($e326327)) {
$e326327.pyretStack.push(L[32]);
}
throw $e326327;
}
var $ret332333 = $Hanf_arg409337($z328329,anf_fun260246,if_helper248154,l13886);
++R.GAS;
return $ret332333;
};
var $Hanf_arg409337 = function(anf_arg275336,anf_fun260246,if_helper248154,l13886) {
var $z340341 = D;
var $f346347 = function(_) {
return R.isFunction(anf_fun260246)?anf_fun260246.app(l13886,anf_arg275336):R.ffi.throwNonFunApp(L[33],anf_fun260246,[l13886,anf_arg275336]);
};
try {
if(--R.GAS > 0) {
$z340341 = $f346347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f346347,
"from":L[33]});
}
} catch($e338339) {
if(R.isCont($e338339)) {
var $ss342343 = {"from":L[33],
"go":function(cont_tail_arg276348) {
return $Hcont_tail_arg408349(cont_tail_arg276348,if_helper248154);
}};
$e338339.stack[R.EXN_STACKHEIGHT++] = $ss342343;
}
if(R.isPyretException($e338339)) {
$e338339.pyretStack.push(L[33]);
}
throw $e338339;
}
var $ret344345 = $Hcont_tail_arg408349($z340341,if_helper248154);
++R.GAS;
return $ret344345;
};
var $Hcont_tail_arg408349 = function(cont_tail_arg276348,if_helper248154) {
if(--R.GAS > 0) {
$z350351 = R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg276348):R.ffi.throwNonFunApp(L[33],if_helper248154,[cont_tail_arg276348]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper248154)?if_helper248154.app(cont_tail_arg276348):R.ffi.throwNonFunApp(L[33],if_helper248154,[cont_tail_arg276348]);
},
"from":L[33]});
}
++R.GAS;
return $z350351;
};
var $Hann_DASH_check_DASH_temp405117 = function(ann_DASH_check_DASH_temp245116) {
return ann_DASH_check_DASH_temp245116;
};
var $Hanf_arg404352 = function(anf_arg240353,anf_fun238354,l132355) {
var $z358359 = D;
var $f364365 = function(_) {
return R.isFunction(anf_fun238354)?anf_fun238354.app(l132355,anf_arg240353):R.ffi.throwNonFunApp(L[34],anf_fun238354,[l132355,anf_arg240353]);
};
try {
if(--R.GAS > 0) {
$z358359 = $f364365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f364365,
"from":L[34]});
}
} catch($e356357) {
if(R.isCont($e356357)) {
var $ss360361 = {"from":L[34],
"go":function(ann_DASH_check_DASH_temp237366) {
return $Hann_DASH_check_DASH_temp403367(ann_DASH_check_DASH_temp237366);
}};
$e356357.stack[R.EXN_STACKHEIGHT++] = $ss360361;
}
if(R.isPyretException($e356357)) {
$e356357.pyretStack.push(L[34]);
}
throw $e356357;
}
var $ret362363 = $Hann_DASH_check_DASH_temp403367($z358359);
++R.GAS;
return $ret362363;
};
var $Hann_DASH_check_DASH_temp403367 = function(ann_DASH_check_DASH_temp237366) {
return ann_DASH_check_DASH_temp237366;
};
var $Hanf_arg402368 = function(anf_arg227369,A111,anf_fun225370,args127371,body128372,l126373,none63374) {
var anf_fun228385 = G(args127371,"map",L[39]);
var anf_arg232386 = R.makeFunction(function(sym129389) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[36],1,arguments);
}
var anf_fun230400 = G(A111,"s-bind",L[38]);
var anf_arg231401 = G(A111,"a-blank",L[37]);
var $z392393 = D;
var $f398399 = function(_) {
return R.isFunction(anf_fun230400)?anf_fun230400.app(l126373,(false),sym129389,anf_arg231401):R.ffi.throwNonFunApp(L[36],anf_fun230400,[l126373,(false),sym129389,anf_arg231401]);
};
try {
if(--R.GAS > 0) {
$z392393 = $f398399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f398399,
"from":L[36]});
}
} catch($e390391) {
if(R.isCont($e390391)) {
var $ss394395 = {"from":L[36],
"go":function(ann_DASH_check_DASH_temp229402) {
return $Hann_DASH_check_DASH_temp399403(ann_DASH_check_DASH_temp229402);
}};
$e390391.stack[R.EXN_STACKHEIGHT++] = $ss394395;
}
if(R.isPyretException($e390391)) {
$e390391.pyretStack.push(L[36]);
}
throw $e390391;
}
var $ret396397 = $Hann_DASH_check_DASH_temp399403($z392393);
++R.GAS;
return $ret396397;
});
var $z377378 = D;
var $f383384 = function(_) {
return R.isFunction(anf_fun228385)?anf_fun228385.app(anf_arg232386):R.ffi.throwNonFunApp(L[35],anf_fun228385,[anf_arg232386]);
};
try {
if(--R.GAS > 0) {
$z377378 = $f383384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f383384,
"from":L[35]});
}
} catch($e375376) {
if(R.isCont($e375376)) {
var $ss379380 = {"from":L[35],
"go":function(anf_arg233387) {
return $Hanf_arg401388(anf_arg233387,A111,anf_arg227369,anf_fun225370,body128372,l126373,none63374);
}};
$e375376.stack[R.EXN_STACKHEIGHT++] = $ss379380;
}
if(R.isPyretException($e375376)) {
$e375376.pyretStack.push(L[35]);
}
throw $e375376;
}
var $ret381382 = $Hanf_arg401388($z377378,A111,anf_arg227369,anf_fun225370,body128372,l126373,none63374);
++R.GAS;
return $ret381382;
};
var $Hanf_arg401388 = function(anf_arg233387,A111,anf_arg227369,anf_fun225370,body128372,l126373,none63374) {
var anf_arg234414 = G(A111,"a-blank",L[41]);
var $z406407 = D;
var $f412413 = function(_) {
return R.isFunction(anf_fun225370)?anf_fun225370.app(l126373,anf_arg227369,anf_arg233387,anf_arg234414,(""),body128372,none63374):R.ffi.throwNonFunApp(L[40],anf_fun225370,[l126373,anf_arg227369,anf_arg233387,anf_arg234414,(""),body128372,none63374]);
};
try {
if(--R.GAS > 0) {
$z406407 = $f412413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f412413,
"from":L[40]});
}
} catch($e404405) {
if(R.isCont($e404405)) {
var $ss408409 = {"from":L[40],
"go":function(ann_DASH_check_DASH_temp224415) {
return $Hann_DASH_check_DASH_temp400416(ann_DASH_check_DASH_temp224415);
}};
$e404405.stack[R.EXN_STACKHEIGHT++] = $ss408409;
}
if(R.isPyretException($e404405)) {
$e404405.pyretStack.push(L[40]);
}
throw $e404405;
}
var $ret410411 = $Hann_DASH_check_DASH_temp400416($z406407);
++R.GAS;
return $ret410411;
};
var $Hann_DASH_check_DASH_temp400416 = function(ann_DASH_check_DASH_temp224415) {
return ann_DASH_check_DASH_temp224415;
};
var $Hann_DASH_check_DASH_temp399403 = function(ann_DASH_check_DASH_temp229402) {
return ann_DASH_check_DASH_temp229402;
};
var $Hcheckers398417 = function(checkers125418,A111,U714,l117419,list2787) {
var anf_fun202432 = G(A111,"s-block",L[47]);
var anf_fun203433 = G(list2787,"make",L[46]);
var anf_fun204434 = G(A111,"s-app",L[45]);
var anf_fun205435 = G(A111,"s-dot",L[44]);
var anf_fun206430 = G(U714,"checkers",L[43]);
var $z422423 = D;
var $f428429 = function(_) {
return R.isFunction(anf_fun206430)?anf_fun206430.app(l117419):R.ffi.throwNonFunApp(L[42],anf_fun206430,[l117419]);
};
try {
if(--R.GAS > 0) {
$z422423 = $f428429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f428429,
"from":L[42]});
}
} catch($e420421) {
if(R.isCont($e420421)) {
var $ss424425 = {"from":L[42],
"go":function(anf_arg207431) {
return $Hanf_arg397436(anf_arg207431,A111,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun205435,checkers125418,l117419,list2787);
}};
$e420421.stack[R.EXN_STACKHEIGHT++] = $ss424425;
}
if(R.isPyretException($e420421)) {
$e420421.pyretStack.push(L[42]);
}
throw $e420421;
}
var $ret426427 = $Hanf_arg397436($z422423,A111,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun205435,checkers125418,l117419,list2787);
++R.GAS;
return $ret426427;
};
var $Hanf_arg397436 = function(anf_arg207431,A111,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun205435,checkers125418,l117419,list2787) {
var $z439440 = D;
var $f445446 = function(_) {
return R.isFunction(anf_fun205435)?anf_fun205435.app(l117419,anf_arg207431,("run-checks")):R.ffi.throwNonFunApp(L[48],anf_fun205435,[l117419,anf_arg207431,("run-checks")]);
};
try {
if(--R.GAS > 0) {
$z439440 = $f445446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f445446,
"from":L[48]});
}
} catch($e437438) {
if(R.isCont($e437438)) {
var $ss441442 = {"from":L[48],
"go":function(anf_arg208447) {
return $Hanf_arg396448(anf_arg208447,A111,anf_fun202432,anf_fun203433,anf_fun204434,checkers125418,l117419,list2787);
}};
$e437438.stack[R.EXN_STACKHEIGHT++] = $ss441442;
}
if(R.isPyretException($e437438)) {
$e437438.pyretStack.push(L[48]);
}
throw $e437438;
}
var $ret443444 = $Hanf_arg396448($z439440,A111,anf_fun202432,anf_fun203433,anf_fun204434,checkers125418,l117419,list2787);
++R.GAS;
return $ret443444;
};
var $Hanf_arg396448 = function(anf_arg208447,A111,anf_fun202432,anf_fun203433,anf_fun204434,checkers125418,l117419,list2787) {
var anf_fun209462 = G(list2787,"make",L[52]);
var anf_fun210459 = G(A111,"s-str",L[51]);
var anf_arg211460 = G(l117419,"source",L[50]);
var $z451452 = D;
var $f457458 = function(_) {
return R.isFunction(anf_fun210459)?anf_fun210459.app(l117419,anf_arg211460):R.ffi.throwNonFunApp(L[49],anf_fun210459,[l117419,anf_arg211460]);
};
try {
if(--R.GAS > 0) {
$z451452 = $f457458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f457458,
"from":L[49]});
}
} catch($e449450) {
if(R.isCont($e449450)) {
var $ss453454 = {"from":L[49],
"go":function(anf_array_val212461) {
return $Hanf_array_val395463(anf_array_val212461,A111,anf_arg208447,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,checkers125418,l117419);
}};
$e449450.stack[R.EXN_STACKHEIGHT++] = $ss453454;
}
if(R.isPyretException($e449450)) {
$e449450.pyretStack.push(L[49]);
}
throw $e449450;
}
var $ret455456 = $Hanf_array_val395463($z451452,A111,anf_arg208447,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,checkers125418,l117419);
++R.GAS;
return $ret455456;
};
var $Hanf_array_val395463 = function(anf_array_val212461,A111,anf_arg208447,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,checkers125418,l117419) {
var anf_fun213477 = G(A111,"s-construct",L[57]);
var anf_arg214476 = G(A111,"s-construct-normal",L[56]);
var anf_fun215478 = G(A111,"s-id",L[55]);
var anf_fun216474 = G(A111,"s-name",L[54]);
var $z466467 = D;
var $f472473 = function(_) {
return R.isFunction(anf_fun216474)?anf_fun216474.app(l117419,("list")):R.ffi.throwNonFunApp(L[53],anf_fun216474,[l117419,("list")]);
};
try {
if(--R.GAS > 0) {
$z466467 = $f472473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f472473,
"from":L[53]});
}
} catch($e464465) {
if(R.isCont($e464465)) {
var $ss468469 = {"from":L[53],
"go":function(anf_arg217475) {
return $Hanf_arg394479(anf_arg217475,anf_arg208447,anf_arg214476,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,anf_fun213477,anf_fun215478,checkers125418,l117419);
}};
$e464465.stack[R.EXN_STACKHEIGHT++] = $ss468469;
}
if(R.isPyretException($e464465)) {
$e464465.pyretStack.push(L[53]);
}
throw $e464465;
}
var $ret470471 = $Hanf_arg394479($z466467,anf_arg208447,anf_arg214476,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,anf_fun213477,anf_fun215478,checkers125418,l117419);
++R.GAS;
return $ret470471;
};
var $Hanf_arg394479 = function(anf_arg217475,anf_arg208447,anf_arg214476,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,anf_fun213477,anf_fun215478,checkers125418,l117419) {
var $z482483 = D;
var $f488489 = function(_) {
return R.isFunction(anf_fun215478)?anf_fun215478.app(l117419,anf_arg217475):R.ffi.throwNonFunApp(L[58],anf_fun215478,[l117419,anf_arg217475]);
};
try {
if(--R.GAS > 0) {
$z482483 = $f488489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f488489,
"from":L[58]});
}
} catch($e480481) {
if(R.isCont($e480481)) {
var $ss484485 = {"from":L[58],
"go":function(anf_arg218490) {
return $Hanf_arg393491(anf_arg218490,anf_arg208447,anf_arg214476,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,anf_fun213477,checkers125418,l117419);
}};
$e480481.stack[R.EXN_STACKHEIGHT++] = $ss484485;
}
if(R.isPyretException($e480481)) {
$e480481.pyretStack.push(L[58]);
}
throw $e480481;
}
var $ret486487 = $Hanf_arg393491($z482483,anf_arg208447,anf_arg214476,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,anf_fun213477,checkers125418,l117419);
++R.GAS;
return $ret486487;
};
var $Hanf_arg393491 = function(anf_arg218490,anf_arg208447,anf_arg214476,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,anf_fun213477,checkers125418,l117419) {
var $z494495 = D;
var $f500501 = function(_) {
return R.isFunction(anf_fun213477)?anf_fun213477.app(l117419,anf_arg214476,anf_arg218490,checkers125418):R.ffi.throwNonFunApp(L[59],anf_fun213477,[l117419,anf_arg214476,anf_arg218490,checkers125418]);
};
try {
if(--R.GAS > 0) {
$z494495 = $f500501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f500501,
"from":L[59]});
}
} catch($e492493) {
if(R.isCont($e492493)) {
var $ss496497 = {"from":L[59],
"go":function(anf_array_val219502) {
return $Hanf_array_val392503(anf_array_val219502,anf_arg208447,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,l117419);
}};
$e492493.stack[R.EXN_STACKHEIGHT++] = $ss496497;
}
if(R.isPyretException($e492493)) {
$e492493.pyretStack.push(L[59]);
}
throw $e492493;
}
var $ret498499 = $Hanf_array_val392503($z494495,anf_arg208447,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,l117419);
++R.GAS;
return $ret498499;
};
var $Hanf_array_val392503 = function(anf_array_val219502,anf_arg208447,anf_array_val212461,anf_fun202432,anf_fun203433,anf_fun204434,anf_fun209462,l117419) {
var $z506507 = D;
var $f512513 = function(_) {
return R.isFunction(anf_fun209462)?anf_fun209462.app([anf_array_val212461,anf_array_val219502]):R.ffi.throwNonFunApp(L[52],anf_fun209462,[[anf_array_val212461,anf_array_val219502]]);
};
try {
if(--R.GAS > 0) {
$z506507 = $f512513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f512513,
"from":L[52]});
}
} catch($e504505) {
if(R.isCont($e504505)) {
var $ss508509 = {"from":L[52],
"go":function(anf_arg220514) {
return $Hanf_arg391515(anf_arg220514,anf_arg208447,anf_fun202432,anf_fun203433,anf_fun204434,l117419);
}};
$e504505.stack[R.EXN_STACKHEIGHT++] = $ss508509;
}
if(R.isPyretException($e504505)) {
$e504505.pyretStack.push(L[52]);
}
throw $e504505;
}
var $ret510511 = $Hanf_arg391515($z506507,anf_arg208447,anf_fun202432,anf_fun203433,anf_fun204434,l117419);
++R.GAS;
return $ret510511;
};
var $Hanf_arg391515 = function(anf_arg220514,anf_arg208447,anf_fun202432,anf_fun203433,anf_fun204434,l117419) {
var $z518519 = D;
var $f524525 = function(_) {
return R.isFunction(anf_fun204434)?anf_fun204434.app(l117419,anf_arg208447,anf_arg220514):R.ffi.throwNonFunApp(L[60],anf_fun204434,[l117419,anf_arg208447,anf_arg220514]);
};
try {
if(--R.GAS > 0) {
$z518519 = $f524525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f524525,
"from":L[60]});
}
} catch($e516517) {
if(R.isCont($e516517)) {
var $ss520521 = {"from":L[60],
"go":function(anf_array_val221526) {
return $Hanf_array_val390527(anf_array_val221526,anf_fun202432,anf_fun203433,l117419);
}};
$e516517.stack[R.EXN_STACKHEIGHT++] = $ss520521;
}
if(R.isPyretException($e516517)) {
$e516517.pyretStack.push(L[60]);
}
throw $e516517;
}
var $ret522523 = $Hanf_array_val390527($z518519,anf_fun202432,anf_fun203433,l117419);
++R.GAS;
return $ret522523;
};
var $Hanf_array_val390527 = function(anf_array_val221526,anf_fun202432,anf_fun203433,l117419) {
var $z530531 = D;
var $f536537 = function(_) {
return R.isFunction(anf_fun203433)?anf_fun203433.app([anf_array_val221526]):R.ffi.throwNonFunApp(L[46],anf_fun203433,[[anf_array_val221526]]);
};
try {
if(--R.GAS > 0) {
$z530531 = $f536537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f536537,
"from":L[46]});
}
} catch($e528529) {
if(R.isCont($e528529)) {
var $ss532533 = {"from":L[46],
"go":function(anf_arg222538) {
return $Hanf_arg389539(anf_arg222538,anf_fun202432,l117419);
}};
$e528529.stack[R.EXN_STACKHEIGHT++] = $ss532533;
}
if(R.isPyretException($e528529)) {
$e528529.pyretStack.push(L[46]);
}
throw $e528529;
}
var $ret534535 = $Hanf_arg389539($z530531,anf_fun202432,l117419);
++R.GAS;
return $ret534535;
};
var $Hanf_arg389539 = function(anf_arg222538,anf_fun202432,l117419) {
var $z542543 = D;
var $f548549 = function(_) {
return R.isFunction(anf_fun202432)?anf_fun202432.app(l117419,anf_arg222538):R.ffi.throwNonFunApp(L[61],anf_fun202432,[l117419,anf_arg222538]);
};
try {
if(--R.GAS > 0) {
$z542543 = $f548549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f548549,
"from":L[61]});
}
} catch($e540541) {
if(R.isCont($e540541)) {
var $ss544545 = {"from":L[61],
"go":function(ann_DASH_check_DASH_temp167550) {
return $Hann_DASH_check_DASH_temp388551(ann_DASH_check_DASH_temp167550);
}};
$e540541.stack[R.EXN_STACKHEIGHT++] = $ss544545;
}
if(R.isPyretException($e540541)) {
$e540541.pyretStack.push(L[61]);
}
throw $e540541;
}
var $ret546547 = $Hann_DASH_check_DASH_temp388551($z542543);
++R.GAS;
return $ret546547;
};
var $Hann_DASH_check_DASH_temp388551 = function(ann_DASH_check_DASH_temp167550) {
return ann_DASH_check_DASH_temp167550;
};
var $Hann_DASH_check_DASH_temp387552 = function(ann_DASH_check_DASH_temp168553) {
return ann_DASH_check_DASH_temp168553;
};
var $Hanf_arg386554 = function(anf_arg172555,A111,body123556,l2121557,list2787,make_DASH_lam88558,name122559) {
var $z562563 = D;
var $f568569 = function(_) {
return R.isFunction(make_DASH_lam88558.$var === D?U(L[62],"make-lam"):make_DASH_lam88558.$var)?make_DASH_lam88558.$var === D?U(L[62],"make-lam"):make_DASH_lam88558.$var.app(l2121557,anf_arg172555,body123556):R.ffi.throwNonFunApp(L[63],make_DASH_lam88558.$var === D?U(L[62],"make-lam"):make_DASH_lam88558.$var,[l2121557,anf_arg172555,body123556]);
};
try {
if(--R.GAS > 0) {
$z562563 = $f568569();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f568569,
"from":L[63]});
}
} catch($e560561) {
if(R.isCont($e560561)) {
var $ss564565 = {"from":L[63],
"go":function(check_DASH_fun124570) {
return $Hcheck_DASH_fun385571(check_DASH_fun124570,A111,l2121557,list2787,name122559);
}};
$e560561.stack[R.EXN_STACKHEIGHT++] = $ss564565;
}
if(R.isPyretException($e560561)) {
$e560561.pyretStack.push(L[63]);
}
throw $e560561;
}
var $ret566567 = $Hcheck_DASH_fun385571($z562563,A111,l2121557,list2787,name122559);
++R.GAS;
return $ret566567;
};
var $Hcheck_DASH_fun385571 = function(check_DASH_fun124570,A111,l2121557,list2787,name122559) {
var anf_fun173584 = G(A111,"s-obj",L[68]);
var anf_fun174585 = G(list2787,"make",L[67]);
var anf_fun175586 = G(A111,"s-data-field",L[66]);
var anf_fun176582 = G(A111,"s-str",L[65]);
var $z574575 = D;
var $f580581 = function(_) {
return R.isFunction(anf_fun176582)?anf_fun176582.app(l2121557,("name")):R.ffi.throwNonFunApp(L[64],anf_fun176582,[l2121557,("name")]);
};
try {
if(--R.GAS > 0) {
$z574575 = $f580581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f580581,
"from":L[64]});
}
} catch($e572573) {
if(R.isCont($e572573)) {
var $ss576577 = {"from":L[64],
"go":function(anf_arg177583) {
return $Hanf_arg384587(anf_arg177583,A111,anf_fun173584,anf_fun174585,anf_fun175586,check_DASH_fun124570,l2121557,list2787,name122559);
}};
$e572573.stack[R.EXN_STACKHEIGHT++] = $ss576577;
}
if(R.isPyretException($e572573)) {
$e572573.pyretStack.push(L[64]);
}
throw $e572573;
}
var $ret578579 = $Hanf_arg384587($z574575,A111,anf_fun173584,anf_fun174585,anf_fun175586,check_DASH_fun124570,l2121557,list2787,name122559);
++R.GAS;
return $ret578579;
};
var $Hanf_arg384587 = function(anf_arg177583,A111,anf_fun173584,anf_fun174585,anf_fun175586,check_DASH_fun124570,l2121557,list2787,name122559) {
var anf_fun178598 = G(A111,"s-str",L[70]);
var $z590591 = D;
var $f596597 = function(_) {
return R.isFunction(anf_fun178598)?anf_fun178598.app(l2121557,name122559):R.ffi.throwNonFunApp(L[69],anf_fun178598,[l2121557,name122559]);
};
try {
if(--R.GAS > 0) {
$z590591 = $f596597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f596597,
"from":L[69]});
}
} catch($e588589) {
if(R.isCont($e588589)) {
var $ss592593 = {"from":L[69],
"go":function(anf_arg179599) {
return $Hanf_arg383600(anf_arg179599,A111,anf_arg177583,anf_fun173584,anf_fun174585,anf_fun175586,check_DASH_fun124570,l2121557,list2787);
}};
$e588589.stack[R.EXN_STACKHEIGHT++] = $ss592593;
}
if(R.isPyretException($e588589)) {
$e588589.pyretStack.push(L[69]);
}
throw $e588589;
}
var $ret594595 = $Hanf_arg383600($z590591,A111,anf_arg177583,anf_fun173584,anf_fun174585,anf_fun175586,check_DASH_fun124570,l2121557,list2787);
++R.GAS;
return $ret594595;
};
var $Hanf_arg383600 = function(anf_arg179599,A111,anf_arg177583,anf_fun173584,anf_fun174585,anf_fun175586,check_DASH_fun124570,l2121557,list2787) {
var $z603604 = D;
var $f609610 = function(_) {
return R.isFunction(anf_fun175586)?anf_fun175586.app(l2121557,anf_arg177583,anf_arg179599):R.ffi.throwNonFunApp(L[71],anf_fun175586,[l2121557,anf_arg177583,anf_arg179599]);
};
try {
if(--R.GAS > 0) {
$z603604 = $f609610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f609610,
"from":L[71]});
}
} catch($e601602) {
if(R.isCont($e601602)) {
var $ss605606 = {"from":L[71],
"go":function(anf_array_val180611) {
return $Hanf_array_val382612(anf_array_val180611,A111,anf_fun173584,anf_fun174585,check_DASH_fun124570,l2121557,list2787);
}};
$e601602.stack[R.EXN_STACKHEIGHT++] = $ss605606;
}
if(R.isPyretException($e601602)) {
$e601602.pyretStack.push(L[71]);
}
throw $e601602;
}
var $ret607608 = $Hanf_array_val382612($z603604,A111,anf_fun173584,anf_fun174585,check_DASH_fun124570,l2121557,list2787);
++R.GAS;
return $ret607608;
};
var $Hanf_array_val382612 = function(anf_array_val180611,A111,anf_fun173584,anf_fun174585,check_DASH_fun124570,l2121557,list2787) {
var anf_fun181625 = G(A111,"s-data-field",L[74]);
var anf_fun182623 = G(A111,"s-str",L[73]);
var $z615616 = D;
var $f621622 = function(_) {
return R.isFunction(anf_fun182623)?anf_fun182623.app(l2121557,("run")):R.ffi.throwNonFunApp(L[72],anf_fun182623,[l2121557,("run")]);
};
try {
if(--R.GAS > 0) {
$z615616 = $f621622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f621622,
"from":L[72]});
}
} catch($e613614) {
if(R.isCont($e613614)) {
var $ss617618 = {"from":L[72],
"go":function(anf_arg183624) {
return $Hanf_arg381626(anf_arg183624,A111,anf_array_val180611,anf_fun173584,anf_fun174585,anf_fun181625,check_DASH_fun124570,l2121557,list2787);
}};
$e613614.stack[R.EXN_STACKHEIGHT++] = $ss617618;
}
if(R.isPyretException($e613614)) {
$e613614.pyretStack.push(L[72]);
}
throw $e613614;
}
var $ret619620 = $Hanf_arg381626($z615616,A111,anf_array_val180611,anf_fun173584,anf_fun174585,anf_fun181625,check_DASH_fun124570,l2121557,list2787);
++R.GAS;
return $ret619620;
};
var $Hanf_arg381626 = function(anf_arg183624,A111,anf_array_val180611,anf_fun173584,anf_fun174585,anf_fun181625,check_DASH_fun124570,l2121557,list2787) {
var $z629630 = D;
var $f635636 = function(_) {
return R.isFunction(anf_fun181625)?anf_fun181625.app(l2121557,anf_arg183624,check_DASH_fun124570):R.ffi.throwNonFunApp(L[75],anf_fun181625,[l2121557,anf_arg183624,check_DASH_fun124570]);
};
try {
if(--R.GAS > 0) {
$z629630 = $f635636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f635636,
"from":L[75]});
}
} catch($e627628) {
if(R.isCont($e627628)) {
var $ss631632 = {"from":L[75],
"go":function(anf_array_val184637) {
return $Hanf_array_val380638(anf_array_val184637,A111,anf_array_val180611,anf_fun173584,anf_fun174585,l2121557,list2787);
}};
$e627628.stack[R.EXN_STACKHEIGHT++] = $ss631632;
}
if(R.isPyretException($e627628)) {
$e627628.pyretStack.push(L[75]);
}
throw $e627628;
}
var $ret633634 = $Hanf_array_val380638($z629630,A111,anf_array_val180611,anf_fun173584,anf_fun174585,l2121557,list2787);
++R.GAS;
return $ret633634;
};
var $Hanf_array_val380638 = function(anf_array_val184637,A111,anf_array_val180611,anf_fun173584,anf_fun174585,l2121557,list2787) {
var anf_fun185651 = G(A111,"s-data-field",L[78]);
var anf_fun186649 = G(A111,"s-str",L[77]);
var $z641642 = D;
var $f647648 = function(_) {
return R.isFunction(anf_fun186649)?anf_fun186649.app(l2121557,("location")):R.ffi.throwNonFunApp(L[76],anf_fun186649,[l2121557,("location")]);
};
try {
if(--R.GAS > 0) {
$z641642 = $f647648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f647648,
"from":L[76]});
}
} catch($e639640) {
if(R.isCont($e639640)) {
var $ss643644 = {"from":L[76],
"go":function(anf_arg187650) {
return $Hanf_arg379652(anf_arg187650,A111,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,l2121557,list2787);
}};
$e639640.stack[R.EXN_STACKHEIGHT++] = $ss643644;
}
if(R.isPyretException($e639640)) {
$e639640.pyretStack.push(L[76]);
}
throw $e639640;
}
var $ret645646 = $Hanf_arg379652($z641642,A111,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,l2121557,list2787);
++R.GAS;
return $ret645646;
};
var $Hanf_arg379652 = function(anf_arg187650,A111,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,l2121557,list2787) {
var anf_fun188665 = G(A111,"s-prim-app",L[82]);
var anf_fun189666 = G(list2787,"make",L[81]);
var anf_fun190663 = G(A111,"s-srcloc",L[80]);
var $z655656 = D;
var $f661662 = function(_) {
return R.isFunction(anf_fun190663)?anf_fun190663.app(l2121557,l2121557):R.ffi.throwNonFunApp(L[79],anf_fun190663,[l2121557,l2121557]);
};
try {
if(--R.GAS > 0) {
$z655656 = $f661662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f661662,
"from":L[79]});
}
} catch($e653654) {
if(R.isCont($e653654)) {
var $ss657658 = {"from":L[79],
"go":function(anf_array_val191664) {
return $Hanf_array_val378667(anf_array_val191664,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,anf_fun188665,anf_fun189666,l2121557);
}};
$e653654.stack[R.EXN_STACKHEIGHT++] = $ss657658;
}
if(R.isPyretException($e653654)) {
$e653654.pyretStack.push(L[79]);
}
throw $e653654;
}
var $ret659660 = $Hanf_array_val378667($z655656,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,anf_fun188665,anf_fun189666,l2121557);
++R.GAS;
return $ret659660;
};
var $Hanf_array_val378667 = function(anf_array_val191664,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,anf_fun188665,anf_fun189666,l2121557) {
var $z670671 = D;
var $f676677 = function(_) {
return R.isFunction(anf_fun189666)?anf_fun189666.app([anf_array_val191664]):R.ffi.throwNonFunApp(L[81],anf_fun189666,[[anf_array_val191664]]);
};
try {
if(--R.GAS > 0) {
$z670671 = $f676677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f676677,
"from":L[81]});
}
} catch($e668669) {
if(R.isCont($e668669)) {
var $ss672673 = {"from":L[81],
"go":function(anf_arg192678) {
return $Hanf_arg377679(anf_arg192678,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,anf_fun188665,l2121557);
}};
$e668669.stack[R.EXN_STACKHEIGHT++] = $ss672673;
}
if(R.isPyretException($e668669)) {
$e668669.pyretStack.push(L[81]);
}
throw $e668669;
}
var $ret674675 = $Hanf_arg377679($z670671,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,anf_fun188665,l2121557);
++R.GAS;
return $ret674675;
};
var $Hanf_arg377679 = function(anf_arg192678,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,anf_fun188665,l2121557) {
var $z682683 = D;
var $f688689 = function(_) {
return R.isFunction(anf_fun188665)?anf_fun188665.app(l2121557,("makeSrcloc"),anf_arg192678):R.ffi.throwNonFunApp(L[83],anf_fun188665,[l2121557,("makeSrcloc"),anf_arg192678]);
};
try {
if(--R.GAS > 0) {
$z682683 = $f688689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f688689,
"from":L[83]});
}
} catch($e680681) {
if(R.isCont($e680681)) {
var $ss684685 = {"from":L[83],
"go":function(anf_arg193690) {
return $Hanf_arg376691(anf_arg193690,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,l2121557);
}};
$e680681.stack[R.EXN_STACKHEIGHT++] = $ss684685;
}
if(R.isPyretException($e680681)) {
$e680681.pyretStack.push(L[83]);
}
throw $e680681;
}
var $ret686687 = $Hanf_arg376691($z682683,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,l2121557);
++R.GAS;
return $ret686687;
};
var $Hanf_arg376691 = function(anf_arg193690,anf_arg187650,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,anf_fun185651,l2121557) {
var $z694695 = D;
var $f700701 = function(_) {
return R.isFunction(anf_fun185651)?anf_fun185651.app(l2121557,anf_arg187650,anf_arg193690):R.ffi.throwNonFunApp(L[84],anf_fun185651,[l2121557,anf_arg187650,anf_arg193690]);
};
try {
if(--R.GAS > 0) {
$z694695 = $f700701();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f700701,
"from":L[84]});
}
} catch($e692693) {
if(R.isCont($e692693)) {
var $ss696697 = {"from":L[84],
"go":function(anf_array_val194702) {
return $Hanf_array_val375703(anf_array_val194702,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,l2121557);
}};
$e692693.stack[R.EXN_STACKHEIGHT++] = $ss696697;
}
if(R.isPyretException($e692693)) {
$e692693.pyretStack.push(L[84]);
}
throw $e692693;
}
var $ret698699 = $Hanf_array_val375703($z694695,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,l2121557);
++R.GAS;
return $ret698699;
};
var $Hanf_array_val375703 = function(anf_array_val194702,anf_array_val180611,anf_array_val184637,anf_fun173584,anf_fun174585,l2121557) {
var $z706707 = D;
var $f712713 = function(_) {
return R.isFunction(anf_fun174585)?anf_fun174585.app([anf_array_val180611,anf_array_val184637,anf_array_val194702]):R.ffi.throwNonFunApp(L[67],anf_fun174585,[[anf_array_val180611,anf_array_val184637,anf_array_val194702]]);
};
try {
if(--R.GAS > 0) {
$z706707 = $f712713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f712713,
"from":L[67]});
}
} catch($e704705) {
if(R.isCont($e704705)) {
var $ss708709 = {"from":L[67],
"go":function(anf_arg195714) {
return $Hanf_arg374715(anf_arg195714,anf_fun173584,l2121557);
}};
$e704705.stack[R.EXN_STACKHEIGHT++] = $ss708709;
}
if(R.isPyretException($e704705)) {
$e704705.pyretStack.push(L[67]);
}
throw $e704705;
}
var $ret710711 = $Hanf_arg374715($z706707,anf_fun173584,l2121557);
++R.GAS;
return $ret710711;
};
var $Hanf_arg374715 = function(anf_arg195714,anf_fun173584,l2121557) {
var $z718719 = D;
var $f724725 = function(_) {
return R.isFunction(anf_fun173584)?anf_fun173584.app(l2121557,anf_arg195714):R.ffi.throwNonFunApp(L[85],anf_fun173584,[l2121557,anf_arg195714]);
};
try {
if(--R.GAS > 0) {
$z718719 = $f724725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f724725,
"from":L[85]});
}
} catch($e716717) {
if(R.isCont($e716717)) {
var $ss720721 = {"from":L[85],
"go":function(ann_DASH_check_DASH_temp170726) {
return $Hann_DASH_check_DASH_temp373727(ann_DASH_check_DASH_temp170726);
}};
$e716717.stack[R.EXN_STACKHEIGHT++] = $ss720721;
}
if(R.isPyretException($e716717)) {
$e716717.pyretStack.push(L[85]);
}
throw $e716717;
}
var $ret722723 = $Hann_DASH_check_DASH_temp373727($z718719);
++R.GAS;
return $ret722723;
};
var $Hann_DASH_check_DASH_temp373727 = function(ann_DASH_check_DASH_temp170726) {
return ann_DASH_check_DASH_temp170726;
};
var $Hanf_arg372728 = function(anf_arg165729,add_DASH_check91730,anf_fun163731) {
var $z734735 = D;
var $f740741 = function(_) {
return R.isFunction(anf_fun163731)?anf_fun163731.app(add_DASH_check91730.$var,anf_arg165729):R.ffi.throwNonFunApp(L[86],anf_fun163731,[add_DASH_check91730.$var,anf_arg165729]);
};
try {
if(--R.GAS > 0) {
$z734735 = $f740741();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f740741,
"from":L[86]});
}
} catch($e732733) {
if(R.isCont($e732733)) {
var $ss736737 = {"from":L[86],
"go":function(ann_DASH_check_DASH_temp115742) {
return $Hann_DASH_check_DASH_temp371743(ann_DASH_check_DASH_temp115742);
}};
$e732733.stack[R.EXN_STACKHEIGHT++] = $ss736737;
}
if(R.isPyretException($e732733)) {
$e732733.pyretStack.push(L[86]);
}
throw $e732733;
}
var $ret738739 = $Hann_DASH_check_DASH_temp371743($z734735);
++R.GAS;
return $ret738739;
};
var $Hann_DASH_check_DASH_temp371743 = function(ann_DASH_check_DASH_temp115742) {
return ann_DASH_check_DASH_temp115742;
};
var $Hann_DASH_check_DASH_temp370744 = function(ann_DASH_check_DASH_temp116745) {
return ann_DASH_check_DASH_temp116745;
};
var $Hcheck_DASH_name369746 = function(check_DASH_name115747,body113748,check_DASH_info74749,check_DASH_stmts_DASH_visitor78750,l111751,link31752,lst93753) {
var anf_fun155764 = G(body113748,"visit",L[88]);
var $z756757 = D;
var $f762763 = function(_) {
return R.isFunction(anf_fun155764)?anf_fun155764.app(check_DASH_stmts_DASH_visitor78750):R.ffi.throwNonFunApp(L[87],anf_fun155764,[check_DASH_stmts_DASH_visitor78750]);
};
try {
if(--R.GAS > 0) {
$z756757 = $f762763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f762763,
"from":L[87]});
}
} catch($e754755) {
if(R.isCont($e754755)) {
var $ss758759 = {"from":L[87],
"go":function(anf_arg156765) {
return $Hanf_arg368766(anf_arg156765,check_DASH_info74749,check_DASH_name115747,l111751,link31752,lst93753);
}};
$e754755.stack[R.EXN_STACKHEIGHT++] = $ss758759;
}
if(R.isPyretException($e754755)) {
$e754755.pyretStack.push(L[87]);
}
throw $e754755;
}
var $ret760761 = $Hanf_arg368766($z756757,check_DASH_info74749,check_DASH_name115747,l111751,link31752,lst93753);
++R.GAS;
return $ret760761;
};
var $Hanf_arg368766 = function(anf_arg156765,check_DASH_info74749,check_DASH_name115747,l111751,link31752,lst93753) {
var $z769770 = D;
var $f775776 = function(_) {
return R.isFunction(check_DASH_info74749.$var)?check_DASH_info74749.$var.app(l111751,check_DASH_name115747,anf_arg156765):R.ffi.throwNonFunApp(L[89],check_DASH_info74749.$var,[l111751,check_DASH_name115747,anf_arg156765]);
};
try {
if(--R.GAS > 0) {
$z769770 = $f775776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f775776,
"from":L[89]});
}
} catch($e767768) {
if(R.isCont($e767768)) {
var $ss771772 = {"from":L[89],
"go":function(anf_arg157777) {
return $Hanf_arg367778(anf_arg157777,link31752,lst93753);
}};
$e767768.stack[R.EXN_STACKHEIGHT++] = $ss771772;
}
if(R.isPyretException($e767768)) {
$e767768.pyretStack.push(L[89]);
}
throw $e767768;
}
var $ret773774 = $Hanf_arg367778($z769770,link31752,lst93753);
++R.GAS;
return $ret773774;
};
var $Hanf_arg367778 = function(anf_arg157777,link31752,lst93753) {
var $z781782 = D;
var $f787788 = function(_) {
return R.isFunction(link31752)?link31752.app(anf_arg157777,lst93753):R.ffi.throwNonFunApp(L[90],link31752,[anf_arg157777,lst93753]);
};
try {
if(--R.GAS > 0) {
$z781782 = $f787788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f787788,
"from":L[90]});
}
} catch($e779780) {
if(R.isCont($e779780)) {
var $ss783784 = {"from":L[90],
"go":function(ann_DASH_check_DASH_temp144789) {
return $Hann_DASH_check_DASH_temp366790(ann_DASH_check_DASH_temp144789);
}};
$e779780.stack[R.EXN_STACKHEIGHT++] = $ss783784;
}
if(R.isPyretException($e779780)) {
$e779780.pyretStack.push(L[90]);
}
throw $e779780;
}
var $ret785786 = $Hann_DASH_check_DASH_temp366790($z781782);
++R.GAS;
return $ret785786;
};
var $Hann_DASH_check_DASH_temp366790 = function(ann_DASH_check_DASH_temp144789) {
return ann_DASH_check_DASH_temp144789;
};
var $Hanf_assign365791 = function(anf_assign147792,standalone_DASH_counter90793,_plus4,tostring9) {
standalone_DASH_counter90793.$var = anf_assign147792;
var $z796797 = D;
var $f802803 = function(_) {
return R.isFunction(tostring9)?tostring9.app(standalone_DASH_counter90793.$var):R.ffi.throwNonFunApp(L[91],tostring9,[standalone_DASH_counter90793.$var]);
};
try {
if(--R.GAS > 0) {
$z796797 = $f802803();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f802803,
"from":L[91]});
}
} catch($e794795) {
if(R.isCont($e794795)) {
var $ss798799 = {"from":L[91],
"go":function(anf_arg148804) {
return $Hanf_arg364805(anf_arg148804,_plus4);
}};
$e794795.stack[R.EXN_STACKHEIGHT++] = $ss798799;
}
if(R.isPyretException($e794795)) {
$e794795.pyretStack.push(L[91]);
}
throw $e794795;
}
var $ret800801 = $Hanf_arg364805($z796797,_plus4);
++R.GAS;
return $ret800801;
};
var $Hanf_arg364805 = function(anf_arg148804,_plus4) {
var $z808809 = D;
var $f814815 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("check-block-"),anf_arg148804):R.ffi.throwNonFunApp(L[92],_plus4,[("check-block-"),anf_arg148804]);
};
try {
if(--R.GAS > 0) {
$z808809 = $f814815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f814815,
"from":L[92]});
}
} catch($e806807) {
if(R.isCont($e806807)) {
var $ss810811 = {"from":L[92],
"go":function(ann_DASH_check_DASH_temp146816) {
return $Hann_DASH_check_DASH_temp363817(ann_DASH_check_DASH_temp146816);
}};
$e806807.stack[R.EXN_STACKHEIGHT++] = $ss810811;
}
if(R.isPyretException($e806807)) {
$e806807.pyretStack.push(L[92]);
}
throw $e806807;
}
var $ret812813 = $Hann_DASH_check_DASH_temp363817($z808809);
++R.GAS;
return $ret812813;
};
var $Hann_DASH_check_DASH_temp363817 = function(ann_DASH_check_DASH_temp146816) {
return ann_DASH_check_DASH_temp146816;
};
var $Hann_DASH_check_DASH_temp362818 = function(ann_DASH_check_DASH_temp131819) {
return ann_DASH_check_DASH_temp131819;
};
var $Hanf_arg361820 = function(anf_arg135821,check_DASH_info74749,l103822,link31752,lst93753,name104823) {
var $z826827 = D;
var $f832833 = function(_) {
return R.isFunction(check_DASH_info74749.$var)?check_DASH_info74749.$var.app(l103822,name104823,anf_arg135821):R.ffi.throwNonFunApp(L[93],check_DASH_info74749.$var,[l103822,name104823,anf_arg135821]);
};
try {
if(--R.GAS > 0) {
$z826827 = $f832833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f832833,
"from":L[93]});
}
} catch($e824825) {
if(R.isCont($e824825)) {
var $ss828829 = {"from":L[93],
"go":function(anf_arg136834) {
return $Hanf_arg360835(anf_arg136834,link31752,lst93753);
}};
$e824825.stack[R.EXN_STACKHEIGHT++] = $ss828829;
}
if(R.isPyretException($e824825)) {
$e824825.pyretStack.push(L[93]);
}
throw $e824825;
}
var $ret830831 = $Hanf_arg360835($z826827,link31752,lst93753);
++R.GAS;
return $ret830831;
};
var $Hanf_arg360835 = function(anf_arg136834,link31752,lst93753) {
var $z838839 = D;
var $f844845 = function(_) {
return R.isFunction(link31752)?link31752.app(anf_arg136834,lst93753):R.ffi.throwNonFunApp(L[94],link31752,[anf_arg136834,lst93753]);
};
try {
if(--R.GAS > 0) {
$z838839 = $f844845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f844845,
"from":L[94]});
}
} catch($e836837) {
if(R.isCont($e836837)) {
var $ss840841 = {"from":L[94],
"go":function(ann_DASH_check_DASH_temp133846) {
return $Hann_DASH_check_DASH_temp359847(ann_DASH_check_DASH_temp133846);
}};
$e836837.stack[R.EXN_STACKHEIGHT++] = $ss840841;
}
if(R.isPyretException($e836837)) {
$e836837.pyretStack.push(L[94]);
}
throw $e836837;
}
var $ret842843 = $Hann_DASH_check_DASH_temp359847($z838839);
++R.GAS;
return $ret842843;
};
var $Hann_DASH_check_DASH_temp359847 = function(ann_DASH_check_DASH_temp133846) {
return ann_DASH_check_DASH_temp133846;
};
var $Hann_DASH_check_DASH_temp358848 = function(ann_DASH_check_DASH_temp118849) {
return ann_DASH_check_DASH_temp118849;
};
var $Hanf_arg357850 = function(anf_arg122851,check_DASH_info74749,l94852,link31752,lst93753,name95853) {
var $z856857 = D;
var $f862863 = function(_) {
return R.isFunction(check_DASH_info74749.$var)?check_DASH_info74749.$var.app(l94852,name95853,anf_arg122851):R.ffi.throwNonFunApp(L[95],check_DASH_info74749.$var,[l94852,name95853,anf_arg122851]);
};
try {
if(--R.GAS > 0) {
$z856857 = $f862863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f862863,
"from":L[95]});
}
} catch($e854855) {
if(R.isCont($e854855)) {
var $ss858859 = {"from":L[95],
"go":function(anf_arg123864) {
return $Hanf_arg356865(anf_arg123864,link31752,lst93753);
}};
$e854855.stack[R.EXN_STACKHEIGHT++] = $ss858859;
}
if(R.isPyretException($e854855)) {
$e854855.pyretStack.push(L[95]);
}
throw $e854855;
}
var $ret860861 = $Hanf_arg356865($z856857,link31752,lst93753);
++R.GAS;
return $ret860861;
};
var $Hanf_arg356865 = function(anf_arg123864,link31752,lst93753) {
var $z868869 = D;
var $f874875 = function(_) {
return R.isFunction(link31752)?link31752.app(anf_arg123864,lst93753):R.ffi.throwNonFunApp(L[96],link31752,[anf_arg123864,lst93753]);
};
try {
if(--R.GAS > 0) {
$z868869 = $f874875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f874875,
"from":L[96]});
}
} catch($e866867) {
if(R.isCont($e866867)) {
var $ss870871 = {"from":L[96],
"go":function(ann_DASH_check_DASH_temp120876) {
return $Hann_DASH_check_DASH_temp355877(ann_DASH_check_DASH_temp120876);
}};
$e866867.stack[R.EXN_STACKHEIGHT++] = $ss870871;
}
if(R.isPyretException($e866867)) {
$e866867.pyretStack.push(L[96]);
}
throw $e866867;
}
var $ret872873 = $Hann_DASH_check_DASH_temp355877($z868869);
++R.GAS;
return $ret872873;
};
var $Hann_DASH_check_DASH_temp355877 = function(ann_DASH_check_DASH_temp120876) {
return ann_DASH_check_DASH_temp120876;
};
var $Hcont_tail_arg333878 = function(cont_tail_arg112879,if_helper61880) {
if(--R.GAS > 0) {
$z881882 = R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg112879):R.ffi.throwNonFunApp(L[97],if_helper61880,[cont_tail_arg112879]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg112879):R.ffi.throwNonFunApp(L[97],if_helper61880,[cont_tail_arg112879]);
},
"from":L[97]});
}
++R.GAS;
return $z881882;
};
var $Hcont_tail_arg334883 = function(cont_tail_arg110884,if_helper61880) {
if(--R.GAS > 0) {
$z885886 = R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg110884):R.ffi.throwNonFunApp(L[98],if_helper61880,[cont_tail_arg110884]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg110884):R.ffi.throwNonFunApp(L[98],if_helper61880,[cont_tail_arg110884]);
},
"from":L[98]});
}
++R.GAS;
return $z885886;
};
var $Hanf_arg349887 = function(anf_arg81888,A111,anf_fun78889,anf_fun79890,if_helper61880,l80891,left82892,list2787,none63374,op81893,right83894) {
var $z897898 = D;
var $f903904 = function(_) {
return R.isFunction(anf_fun79890)?anf_fun79890.app(l80891,anf_arg81888,("check-raises-str")):R.ffi.throwNonFunApp(L[99],anf_fun79890,[l80891,anf_arg81888,("check-raises-str")]);
};
try {
if(--R.GAS > 0) {
$z897898 = $f903904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f903904,
"from":L[99]});
}
} catch($e895896) {
if(R.isCont($e895896)) {
var $ss899900 = {"from":L[99],
"go":function(anf_arg82905) {
return $Hanf_arg348906(anf_arg82905,A111,anf_fun78889,if_helper61880,l80891,left82892,list2787,none63374,op81893,right83894);
}};
$e895896.stack[R.EXN_STACKHEIGHT++] = $ss899900;
}
if(R.isPyretException($e895896)) {
$e895896.pyretStack.push(L[99]);
}
throw $e895896;
}
var $ret901902 = $Hanf_arg348906($z897898,A111,anf_fun78889,if_helper61880,l80891,left82892,list2787,none63374,op81893,right83894);
++R.GAS;
return $ret901902;
};
var $Hanf_arg348906 = function(anf_arg82905,A111,anf_fun78889,if_helper61880,l80891,left82892,list2787,none63374,op81893,right83894) {
var anf_fun83919 = G(list2787,"make",L[103]);
var anf_fun84920 = G(A111,"s-str",L[102]);
var anf_fun85917 = G(A111,"s-check-test",L[101]);
var $z909910 = D;
var $f915916 = function(_) {
return R.isFunction(anf_fun85917)?anf_fun85917.app(l80891,op81893,left82892,right83894):R.ffi.throwNonFunApp(L[100],anf_fun85917,[l80891,op81893,left82892,right83894]);
};
try {
if(--R.GAS > 0) {
$z909910 = $f915916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f915916,
"from":L[100]});
}
} catch($e907908) {
if(R.isCont($e907908)) {
var $ss911912 = {"from":L[100],
"go":function(anf_bracket86918) {
return $Hanf_bracket347921(anf_bracket86918,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894);
}};
$e907908.stack[R.EXN_STACKHEIGHT++] = $ss911912;
}
if(R.isPyretException($e907908)) {
$e907908.pyretStack.push(L[100]);
}
throw $e907908;
}
var $ret913914 = $Hanf_bracket347921($z909910,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894);
++R.GAS;
return $ret913914;
};
var $Hanf_bracket347921 = function(anf_bracket86918,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894) {
var anf_fun87932 = G(anf_bracket86918,"tosource",L[105]);
var $z924925 = D;
var $f930931 = function(_) {
return R.isFunction(anf_fun87932)?anf_fun87932.app():R.ffi.throwNonFunApp(L[104],anf_fun87932,[]);
};
try {
if(--R.GAS > 0) {
$z924925 = $f930931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f930931,
"from":L[104]});
}
} catch($e922923) {
if(R.isCont($e922923)) {
var $ss926927 = {"from":L[104],
"go":function(anf_bracket88933) {
return $Hanf_bracket346934(anf_bracket88933,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894);
}};
$e922923.stack[R.EXN_STACKHEIGHT++] = $ss926927;
}
if(R.isPyretException($e922923)) {
$e922923.pyretStack.push(L[104]);
}
throw $e922923;
}
var $ret928929 = $Hanf_bracket346934($z924925,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894);
++R.GAS;
return $ret928929;
};
var $Hanf_bracket346934 = function(anf_bracket88933,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894) {
var anf_fun89945 = G(anf_bracket88933,"pretty",L[107]);
var $z937938 = D;
var $f943944 = function(_) {
return R.isFunction(anf_fun89945)?anf_fun89945.app((80)):R.ffi.throwNonFunApp(L[106],anf_fun89945,[(80)]);
};
try {
if(--R.GAS > 0) {
$z937938 = $f943944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f943944,
"from":L[106]});
}
} catch($e935936) {
if(R.isCont($e935936)) {
var $ss939940 = {"from":L[106],
"go":function(anf_bracket90946) {
return $Hanf_bracket345947(anf_bracket90946,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894);
}};
$e935936.stack[R.EXN_STACKHEIGHT++] = $ss939940;
}
if(R.isPyretException($e935936)) {
$e935936.pyretStack.push(L[106]);
}
throw $e935936;
}
var $ret941942 = $Hanf_bracket345947($z937938,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894);
++R.GAS;
return $ret941942;
};
var $Hanf_bracket345947 = function(anf_bracket90946,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894) {
var anf_fun91958 = G(anf_bracket90946,"join-str",L[109]);
var $z950951 = D;
var $f956957 = function(_) {
return R.isFunction(anf_fun91958)?anf_fun91958.app(("\n")):R.ffi.throwNonFunApp(L[108],anf_fun91958,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z950951 = $f956957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f956957,
"from":L[108]});
}
} catch($e948949) {
if(R.isCont($e948949)) {
var $ss952953 = {"from":L[108],
"go":function(anf_arg92959) {
return $Hanf_arg344960(anf_arg92959,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894);
}};
$e948949.stack[R.EXN_STACKHEIGHT++] = $ss952953;
}
if(R.isPyretException($e948949)) {
$e948949.pyretStack.push(L[108]);
}
throw $e948949;
}
var $ret954955 = $Hanf_arg344960($z950951,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894);
++R.GAS;
return $ret954955;
};
var $Hanf_arg344960 = function(anf_arg92959,A111,anf_arg82905,anf_fun78889,anf_fun83919,anf_fun84920,if_helper61880,l80891,left82892,list2787,none63374,right83894) {
var $z963964 = D;
var $f969970 = function(_) {
return R.isFunction(anf_fun84920)?anf_fun84920.app(l80891,anf_arg92959):R.ffi.throwNonFunApp(L[110],anf_fun84920,[l80891,anf_arg92959]);
};
try {
if(--R.GAS > 0) {
$z963964 = $f969970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f969970,
"from":L[110]});
}
} catch($e961962) {
if(R.isCont($e961962)) {
var $ss965966 = {"from":L[110],
"go":function(anf_array_val93971) {
return $Hanf_array_val343972(anf_array_val93971,A111,anf_arg82905,anf_fun78889,anf_fun83919,if_helper61880,l80891,left82892,list2787,none63374,right83894);
}};
$e961962.stack[R.EXN_STACKHEIGHT++] = $ss965966;
}
if(R.isPyretException($e961962)) {
$e961962.pyretStack.push(L[110]);
}
throw $e961962;
}
var $ret967968 = $Hanf_array_val343972($z963964,A111,anf_arg82905,anf_fun78889,anf_fun83919,if_helper61880,l80891,left82892,list2787,none63374,right83894);
++R.GAS;
return $ret967968;
};
var $Hanf_array_val343972 = function(anf_array_val93971,A111,anf_arg82905,anf_fun78889,anf_fun83919,if_helper61880,l80891,left82892,list2787,none63374,right83894) {
var anf_fun94985 = G(A111,"s-lam",L[112]);
var anf_fun95983 = G(list2787,"make",L[111]);
var $z975976 = D;
var $f981982 = function(_) {
return R.isFunction(anf_fun95983)?anf_fun95983.app([]):R.ffi.throwNonFunApp(L[111],anf_fun95983,[[]]);
};
try {
if(--R.GAS > 0) {
$z975976 = $f981982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f981982,
"from":L[111]});
}
} catch($e973974) {
if(R.isCont($e973974)) {
var $ss977978 = {"from":L[111],
"go":function(anf_arg96984) {
return $Hanf_arg342986(anf_arg96984,A111,anf_arg82905,anf_array_val93971,anf_fun78889,anf_fun83919,anf_fun94985,if_helper61880,l80891,left82892,list2787,none63374,right83894);
}};
$e973974.stack[R.EXN_STACKHEIGHT++] = $ss977978;
}
if(R.isPyretException($e973974)) {
$e973974.pyretStack.push(L[111]);
}
throw $e973974;
}
var $ret979980 = $Hanf_arg342986($z975976,A111,anf_arg82905,anf_array_val93971,anf_fun78889,anf_fun83919,anf_fun94985,if_helper61880,l80891,left82892,list2787,none63374,right83894);
++R.GAS;
return $ret979980;
};
var $Hanf_arg342986 = function(anf_arg96984,A111,anf_arg82905,anf_array_val93971,anf_fun78889,anf_fun83919,anf_fun94985,if_helper61880,l80891,left82892,list2787,none63374,right83894) {
var anf_fun97997 = G(list2787,"make",L[113]);
var $z989990 = D;
var $f995996 = function(_) {
return R.isFunction(anf_fun97997)?anf_fun97997.app([]):R.ffi.throwNonFunApp(L[113],anf_fun97997,[[]]);
};
try {
if(--R.GAS > 0) {
$z989990 = $f995996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f995996,
"from":L[113]});
}
} catch($e987988) {
if(R.isCont($e987988)) {
var $ss991992 = {"from":L[113],
"go":function(anf_arg98998) {
return $Hanf_arg341999(anf_arg98998,A111,anf_arg82905,anf_arg96984,anf_array_val93971,anf_fun78889,anf_fun83919,anf_fun94985,if_helper61880,l80891,left82892,list2787,none63374,right83894);
}};
$e987988.stack[R.EXN_STACKHEIGHT++] = $ss991992;
}
if(R.isPyretException($e987988)) {
$e987988.pyretStack.push(L[113]);
}
throw $e987988;
}
var $ret993994 = $Hanf_arg341999($z989990,A111,anf_arg82905,anf_arg96984,anf_array_val93971,anf_fun78889,anf_fun83919,anf_fun94985,if_helper61880,l80891,left82892,list2787,none63374,right83894);
++R.GAS;
return $ret993994;
};
var $Hanf_arg341999 = function(anf_arg98998,A111,anf_arg82905,anf_arg96984,anf_array_val93971,anf_fun78889,anf_fun83919,anf_fun94985,if_helper61880,l80891,left82892,list2787,none63374,right83894) {
var anf_arg991010 = G(A111,"a-blank",L[115]);
var $z10021003 = D;
var $f10081009 = function(_) {
return R.isFunction(anf_fun94985)?anf_fun94985.app(l80891,anf_arg96984,anf_arg98998,anf_arg991010,(""),left82892,none63374):R.ffi.throwNonFunApp(L[114],anf_fun94985,[l80891,anf_arg96984,anf_arg98998,anf_arg991010,(""),left82892,none63374]);
};
try {
if(--R.GAS > 0) {
$z10021003 = $f10081009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10081009,
"from":L[114]});
}
} catch($e10001001) {
if(R.isCont($e10001001)) {
var $ss10041005 = {"from":L[114],
"go":function(anf_array_val1001011) {
return $Hanf_array_val3401012(anf_array_val1001011,A111,anf_arg82905,anf_array_val93971,anf_fun78889,anf_fun83919,if_helper61880,l80891,list2787,right83894);
}};
$e10001001.stack[R.EXN_STACKHEIGHT++] = $ss10041005;
}
if(R.isPyretException($e10001001)) {
$e10001001.pyretStack.push(L[114]);
}
throw $e10001001;
}
var $ret10061007 = $Hanf_array_val3401012($z10021003,A111,anf_arg82905,anf_array_val93971,anf_fun78889,anf_fun83919,if_helper61880,l80891,list2787,right83894);
++R.GAS;
return $ret10061007;
};
var $Hanf_array_val3401012 = function(anf_array_val1001011,A111,anf_arg82905,anf_array_val93971,anf_fun78889,anf_fun83919,if_helper61880,l80891,list2787,right83894) {
var anf_fun1011025 = G(A111,"s-prim-app",L[119]);
var anf_fun1021026 = G(list2787,"make",L[118]);
var anf_fun1031023 = G(A111,"s-srcloc",L[117]);
var $z10151016 = D;
var $f10211022 = function(_) {
return R.isFunction(anf_fun1031023)?anf_fun1031023.app(l80891,l80891):R.ffi.throwNonFunApp(L[116],anf_fun1031023,[l80891,l80891]);
};
try {
if(--R.GAS > 0) {
$z10151016 = $f10211022();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10211022,
"from":L[116]});
}
} catch($e10131014) {
if(R.isCont($e10131014)) {
var $ss10171018 = {"from":L[116],
"go":function(anf_array_val1041024) {
return $Hanf_array_val3391027(anf_array_val1041024,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun1011025,anf_fun1021026,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894);
}};
$e10131014.stack[R.EXN_STACKHEIGHT++] = $ss10171018;
}
if(R.isPyretException($e10131014)) {
$e10131014.pyretStack.push(L[116]);
}
throw $e10131014;
}
var $ret10191020 = $Hanf_array_val3391027($z10151016,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun1011025,anf_fun1021026,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894);
++R.GAS;
return $ret10191020;
};
var $Hanf_array_val3391027 = function(anf_array_val1041024,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun1011025,anf_fun1021026,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894) {
var $z10301031 = D;
var $f10361037 = function(_) {
return R.isFunction(anf_fun1021026)?anf_fun1021026.app([anf_array_val1041024]):R.ffi.throwNonFunApp(L[118],anf_fun1021026,[[anf_array_val1041024]]);
};
try {
if(--R.GAS > 0) {
$z10301031 = $f10361037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10361037,
"from":L[118]});
}
} catch($e10281029) {
if(R.isCont($e10281029)) {
var $ss10321033 = {"from":L[118],
"go":function(anf_arg1051038) {
return $Hanf_arg3381039(anf_arg1051038,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun1011025,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894);
}};
$e10281029.stack[R.EXN_STACKHEIGHT++] = $ss10321033;
}
if(R.isPyretException($e10281029)) {
$e10281029.pyretStack.push(L[118]);
}
throw $e10281029;
}
var $ret10341035 = $Hanf_arg3381039($z10301031,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun1011025,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894);
++R.GAS;
return $ret10341035;
};
var $Hanf_arg3381039 = function(anf_arg1051038,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun1011025,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894) {
var $z10421043 = D;
var $f10481049 = function(_) {
return R.isFunction(anf_fun1011025)?anf_fun1011025.app(l80891,("makeSrcloc"),anf_arg1051038):R.ffi.throwNonFunApp(L[120],anf_fun1011025,[l80891,("makeSrcloc"),anf_arg1051038]);
};
try {
if(--R.GAS > 0) {
$z10421043 = $f10481049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10481049,
"from":L[120]});
}
} catch($e10401041) {
if(R.isCont($e10401041)) {
var $ss10441045 = {"from":L[120],
"go":function(anf_array_val1061050) {
return $Hanf_array_val3371051(anf_array_val1061050,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894);
}};
$e10401041.stack[R.EXN_STACKHEIGHT++] = $ss10441045;
}
if(R.isPyretException($e10401041)) {
$e10401041.pyretStack.push(L[120]);
}
throw $e10401041;
}
var $ret10461047 = $Hanf_array_val3371051($z10421043,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894);
++R.GAS;
return $ret10461047;
};
var $Hanf_array_val3371051 = function(anf_array_val1061050,anf_arg82905,anf_array_val1001011,anf_array_val93971,anf_fun78889,anf_fun83919,if_helper61880,l80891,right83894) {
var $z10541055 = D;
var $f10601061 = function(_) {
return R.isFunction(anf_fun83919)?anf_fun83919.app([anf_array_val93971,anf_array_val1001011,right83894,anf_array_val1061050]):R.ffi.throwNonFunApp(L[103],anf_fun83919,[[anf_array_val93971,anf_array_val1001011,right83894,anf_array_val1061050]]);
};
try {
if(--R.GAS > 0) {
$z10541055 = $f10601061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10601061,
"from":L[103]});
}
} catch($e10521053) {
if(R.isCont($e10521053)) {
var $ss10561057 = {"from":L[103],
"go":function(anf_arg1071062) {
return $Hanf_arg3361063(anf_arg1071062,anf_arg82905,anf_fun78889,if_helper61880,l80891);
}};
$e10521053.stack[R.EXN_STACKHEIGHT++] = $ss10561057;
}
if(R.isPyretException($e10521053)) {
$e10521053.pyretStack.push(L[103]);
}
throw $e10521053;
}
var $ret10581059 = $Hanf_arg3361063($z10541055,anf_arg82905,anf_fun78889,if_helper61880,l80891);
++R.GAS;
return $ret10581059;
};
var $Hanf_arg3361063 = function(anf_arg1071062,anf_arg82905,anf_fun78889,if_helper61880,l80891) {
var $z10661067 = D;
var $f10721073 = function(_) {
return R.isFunction(anf_fun78889)?anf_fun78889.app(l80891,anf_arg82905,anf_arg1071062):R.ffi.throwNonFunApp(L[121],anf_fun78889,[l80891,anf_arg82905,anf_arg1071062]);
};
try {
if(--R.GAS > 0) {
$z10661067 = $f10721073();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10721073,
"from":L[121]});
}
} catch($e10641065) {
if(R.isCont($e10641065)) {
var $ss10681069 = {"from":L[121],
"go":function(cont_tail_arg1081074) {
return $Hcont_tail_arg3351075(cont_tail_arg1081074,if_helper61880);
}};
$e10641065.stack[R.EXN_STACKHEIGHT++] = $ss10681069;
}
if(R.isPyretException($e10641065)) {
$e10641065.pyretStack.push(L[121]);
}
throw $e10641065;
}
var $ret10701071 = $Hcont_tail_arg3351075($z10661067,if_helper61880);
++R.GAS;
return $ret10701071;
};
var $Hcont_tail_arg3351075 = function(cont_tail_arg1081074,if_helper61880) {
if(--R.GAS > 0) {
$z10761077 = R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg1081074):R.ffi.throwNonFunApp(L[121],if_helper61880,[cont_tail_arg1081074]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg1081074):R.ffi.throwNonFunApp(L[121],if_helper61880,[cont_tail_arg1081074]);
},
"from":L[121]});
}
++R.GAS;
return $z10761077;
};
var $Hanf_arg3541078 = function(anf_arg721079,if_helper61880,l80891,_plus4,raise7,torepr8) {
var $z10821083 = D;
var $f10881089 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg721079,(" not yet implemented at ")):R.ffi.throwNonFunApp(L[122],_plus4,[anf_arg721079,(" not yet implemented at ")]);
};
try {
if(--R.GAS > 0) {
$z10821083 = $f10881089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10881089,
"from":L[122]});
}
} catch($e10801081) {
if(R.isCont($e10801081)) {
var $ss10841085 = {"from":L[122],
"go":function(anf_arg731090) {
return $Hanf_arg3531091(anf_arg731090,if_helper61880,l80891,_plus4,raise7,torepr8);
}};
$e10801081.stack[R.EXN_STACKHEIGHT++] = $ss10841085;
}
if(R.isPyretException($e10801081)) {
$e10801081.pyretStack.push(L[122]);
}
throw $e10801081;
}
var $ret10861087 = $Hanf_arg3531091($z10821083,if_helper61880,l80891,_plus4,raise7,torepr8);
++R.GAS;
return $ret10861087;
};
var $Hanf_arg3531091 = function(anf_arg731090,if_helper61880,l80891,_plus4,raise7,torepr8) {
var $z10941095 = D;
var $f11001101 = function(_) {
return R.isFunction(torepr8)?torepr8.app(l80891):R.ffi.throwNonFunApp(L[123],torepr8,[l80891]);
};
try {
if(--R.GAS > 0) {
$z10941095 = $f11001101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11001101,
"from":L[123]});
}
} catch($e10921093) {
if(R.isCont($e10921093)) {
var $ss10961097 = {"from":L[123],
"go":function(anf_arg741102) {
return $Hanf_arg3521103(anf_arg741102,anf_arg731090,if_helper61880,_plus4,raise7);
}};
$e10921093.stack[R.EXN_STACKHEIGHT++] = $ss10961097;
}
if(R.isPyretException($e10921093)) {
$e10921093.pyretStack.push(L[123]);
}
throw $e10921093;
}
var $ret10981099 = $Hanf_arg3521103($z10941095,anf_arg731090,if_helper61880,_plus4,raise7);
++R.GAS;
return $ret10981099;
};
var $Hanf_arg3521103 = function(anf_arg741102,anf_arg731090,if_helper61880,_plus4,raise7) {
var $z11061107 = D;
var $f11121113 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg731090,anf_arg741102):R.ffi.throwNonFunApp(L[122],_plus4,[anf_arg731090,anf_arg741102]);
};
try {
if(--R.GAS > 0) {
$z11061107 = $f11121113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11121113,
"from":L[122]});
}
} catch($e11041105) {
if(R.isCont($e11041105)) {
var $ss11081109 = {"from":L[122],
"go":function(anf_arg751114) {
return $Hanf_arg3511115(anf_arg751114,if_helper61880,raise7);
}};
$e11041105.stack[R.EXN_STACKHEIGHT++] = $ss11081109;
}
if(R.isPyretException($e11041105)) {
$e11041105.pyretStack.push(L[122]);
}
throw $e11041105;
}
var $ret11101111 = $Hanf_arg3511115($z11061107,if_helper61880,raise7);
++R.GAS;
return $ret11101111;
};
var $Hanf_arg3511115 = function(anf_arg751114,if_helper61880,raise7) {
var $z11181119 = D;
var $f11241125 = function(_) {
return R.isFunction(raise7)?raise7.app(anf_arg751114):R.ffi.throwNonFunApp(L[124],raise7,[anf_arg751114]);
};
try {
if(--R.GAS > 0) {
$z11181119 = $f11241125();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11241125,
"from":L[124]});
}
} catch($e11161117) {
if(R.isCont($e11161117)) {
var $ss11201121 = {"from":L[124],
"go":function(cont_tail_arg761126) {
return $Hcont_tail_arg3501127(cont_tail_arg761126,if_helper61880);
}};
$e11161117.stack[R.EXN_STACKHEIGHT++] = $ss11201121;
}
if(R.isPyretException($e11161117)) {
$e11161117.pyretStack.push(L[124]);
}
throw $e11161117;
}
var $ret11221123 = $Hcont_tail_arg3501127($z11181119,if_helper61880);
++R.GAS;
return $ret11221123;
};
var $Hcont_tail_arg3501127 = function(cont_tail_arg761126,if_helper61880) {
if(--R.GAS > 0) {
$z11281129 = R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg761126):R.ffi.throwNonFunApp(L[124],if_helper61880,[cont_tail_arg761126]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg761126):R.ffi.throwNonFunApp(L[124],if_helper61880,[cont_tail_arg761126]);
},
"from":L[124]});
}
++R.GAS;
return $z11281129;
};
var $Hanf_arg3321130 = function(anf_arg401131,A111,anf_fun371132,anf_fun381133,fieldname851134,l80891,left82892,list2787,op81893,right83894) {
var $z11371138 = D;
var $f11431144 = function(_) {
return R.isFunction(anf_fun381133)?anf_fun381133.app(l80891,anf_arg401131,fieldname851134):R.ffi.throwNonFunApp(L[125],anf_fun381133,[l80891,anf_arg401131,fieldname851134]);
};
try {
if(--R.GAS > 0) {
$z11371138 = $f11431144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11431144,
"from":L[125]});
}
} catch($e11351136) {
if(R.isCont($e11351136)) {
var $ss11391140 = {"from":L[125],
"go":function(anf_arg411145) {
return $Hanf_arg3311146(anf_arg411145,A111,anf_fun371132,l80891,left82892,list2787,op81893,right83894);
}};
$e11351136.stack[R.EXN_STACKHEIGHT++] = $ss11391140;
}
if(R.isPyretException($e11351136)) {
$e11351136.pyretStack.push(L[125]);
}
throw $e11351136;
}
var $ret11411142 = $Hanf_arg3311146($z11371138,A111,anf_fun371132,l80891,left82892,list2787,op81893,right83894);
++R.GAS;
return $ret11411142;
};
var $Hanf_arg3311146 = function(anf_arg411145,A111,anf_fun371132,l80891,left82892,list2787,op81893,right83894) {
var anf_fun421159 = G(list2787,"make",L[129]);
var anf_fun431160 = G(A111,"s-str",L[128]);
var anf_fun441157 = G(A111,"s-check-test",L[127]);
var $z11491150 = D;
var $f11551156 = function(_) {
return R.isFunction(anf_fun441157)?anf_fun441157.app(l80891,op81893,left82892,right83894):R.ffi.throwNonFunApp(L[126],anf_fun441157,[l80891,op81893,left82892,right83894]);
};
try {
if(--R.GAS > 0) {
$z11491150 = $f11551156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11551156,
"from":L[126]});
}
} catch($e11471148) {
if(R.isCont($e11471148)) {
var $ss11511152 = {"from":L[126],
"go":function(anf_bracket451158) {
return $Hanf_bracket3301161(anf_bracket451158,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894);
}};
$e11471148.stack[R.EXN_STACKHEIGHT++] = $ss11511152;
}
if(R.isPyretException($e11471148)) {
$e11471148.pyretStack.push(L[126]);
}
throw $e11471148;
}
var $ret11531154 = $Hanf_bracket3301161($z11491150,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894);
++R.GAS;
return $ret11531154;
};
var $Hanf_bracket3301161 = function(anf_bracket451158,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894) {
var anf_fun461172 = G(anf_bracket451158,"tosource",L[131]);
var $z11641165 = D;
var $f11701171 = function(_) {
return R.isFunction(anf_fun461172)?anf_fun461172.app():R.ffi.throwNonFunApp(L[130],anf_fun461172,[]);
};
try {
if(--R.GAS > 0) {
$z11641165 = $f11701171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11701171,
"from":L[130]});
}
} catch($e11621163) {
if(R.isCont($e11621163)) {
var $ss11661167 = {"from":L[130],
"go":function(anf_bracket471173) {
return $Hanf_bracket3291174(anf_bracket471173,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894);
}};
$e11621163.stack[R.EXN_STACKHEIGHT++] = $ss11661167;
}
if(R.isPyretException($e11621163)) {
$e11621163.pyretStack.push(L[130]);
}
throw $e11621163;
}
var $ret11681169 = $Hanf_bracket3291174($z11641165,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894);
++R.GAS;
return $ret11681169;
};
var $Hanf_bracket3291174 = function(anf_bracket471173,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894) {
var anf_fun481185 = G(anf_bracket471173,"pretty",L[133]);
var $z11771178 = D;
var $f11831184 = function(_) {
return R.isFunction(anf_fun481185)?anf_fun481185.app((80)):R.ffi.throwNonFunApp(L[132],anf_fun481185,[(80)]);
};
try {
if(--R.GAS > 0) {
$z11771178 = $f11831184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11831184,
"from":L[132]});
}
} catch($e11751176) {
if(R.isCont($e11751176)) {
var $ss11791180 = {"from":L[132],
"go":function(anf_bracket491186) {
return $Hanf_bracket3281187(anf_bracket491186,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894);
}};
$e11751176.stack[R.EXN_STACKHEIGHT++] = $ss11791180;
}
if(R.isPyretException($e11751176)) {
$e11751176.pyretStack.push(L[132]);
}
throw $e11751176;
}
var $ret11811182 = $Hanf_bracket3281187($z11771178,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894);
++R.GAS;
return $ret11811182;
};
var $Hanf_bracket3281187 = function(anf_bracket491186,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894) {
var anf_fun501198 = G(anf_bracket491186,"join-str",L[135]);
var $z11901191 = D;
var $f11961197 = function(_) {
return R.isFunction(anf_fun501198)?anf_fun501198.app(("\n")):R.ffi.throwNonFunApp(L[134],anf_fun501198,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z11901191 = $f11961197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11961197,
"from":L[134]});
}
} catch($e11881189) {
if(R.isCont($e11881189)) {
var $ss11921193 = {"from":L[134],
"go":function(anf_arg511199) {
return $Hanf_arg3271200(anf_arg511199,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894);
}};
$e11881189.stack[R.EXN_STACKHEIGHT++] = $ss11921193;
}
if(R.isPyretException($e11881189)) {
$e11881189.pyretStack.push(L[134]);
}
throw $e11881189;
}
var $ret11941195 = $Hanf_arg3271200($z11901191,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894);
++R.GAS;
return $ret11941195;
};
var $Hanf_arg3271200 = function(anf_arg511199,A111,anf_arg411145,anf_fun371132,anf_fun421159,anf_fun431160,l80891,left82892,list2787,right83894) {
var $z12031204 = D;
var $f12091210 = function(_) {
return R.isFunction(anf_fun431160)?anf_fun431160.app(l80891,anf_arg511199):R.ffi.throwNonFunApp(L[136],anf_fun431160,[l80891,anf_arg511199]);
};
try {
if(--R.GAS > 0) {
$z12031204 = $f12091210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12091210,
"from":L[136]});
}
} catch($e12011202) {
if(R.isCont($e12011202)) {
var $ss12051206 = {"from":L[136],
"go":function(anf_array_val521211) {
return $Hanf_array_val3261212(anf_array_val521211,A111,anf_arg411145,anf_fun371132,anf_fun421159,l80891,left82892,list2787,right83894);
}};
$e12011202.stack[R.EXN_STACKHEIGHT++] = $ss12051206;
}
if(R.isPyretException($e12011202)) {
$e12011202.pyretStack.push(L[136]);
}
throw $e12011202;
}
var $ret12071208 = $Hanf_array_val3261212($z12031204,A111,anf_arg411145,anf_fun371132,anf_fun421159,l80891,left82892,list2787,right83894);
++R.GAS;
return $ret12071208;
};
var $Hanf_array_val3261212 = function(anf_array_val521211,A111,anf_arg411145,anf_fun371132,anf_fun421159,l80891,left82892,list2787,right83894) {
var anf_fun531225 = G(A111,"s-prim-app",L[140]);
var anf_fun541226 = G(list2787,"make",L[139]);
var anf_fun551223 = G(A111,"s-srcloc",L[138]);
var $z12151216 = D;
var $f12211222 = function(_) {
return R.isFunction(anf_fun551223)?anf_fun551223.app(l80891,l80891):R.ffi.throwNonFunApp(L[137],anf_fun551223,[l80891,l80891]);
};
try {
if(--R.GAS > 0) {
$z12151216 = $f12211222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12211222,
"from":L[137]});
}
} catch($e12131214) {
if(R.isCont($e12131214)) {
var $ss12171218 = {"from":L[137],
"go":function(anf_array_val561224) {
return $Hanf_array_val3251227(anf_array_val561224,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,anf_fun531225,anf_fun541226,l80891,left82892,right83894);
}};
$e12131214.stack[R.EXN_STACKHEIGHT++] = $ss12171218;
}
if(R.isPyretException($e12131214)) {
$e12131214.pyretStack.push(L[137]);
}
throw $e12131214;
}
var $ret12191220 = $Hanf_array_val3251227($z12151216,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,anf_fun531225,anf_fun541226,l80891,left82892,right83894);
++R.GAS;
return $ret12191220;
};
var $Hanf_array_val3251227 = function(anf_array_val561224,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,anf_fun531225,anf_fun541226,l80891,left82892,right83894) {
var $z12301231 = D;
var $f12361237 = function(_) {
return R.isFunction(anf_fun541226)?anf_fun541226.app([anf_array_val561224]):R.ffi.throwNonFunApp(L[139],anf_fun541226,[[anf_array_val561224]]);
};
try {
if(--R.GAS > 0) {
$z12301231 = $f12361237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12361237,
"from":L[139]});
}
} catch($e12281229) {
if(R.isCont($e12281229)) {
var $ss12321233 = {"from":L[139],
"go":function(anf_arg571238) {
return $Hanf_arg3241239(anf_arg571238,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,anf_fun531225,l80891,left82892,right83894);
}};
$e12281229.stack[R.EXN_STACKHEIGHT++] = $ss12321233;
}
if(R.isPyretException($e12281229)) {
$e12281229.pyretStack.push(L[139]);
}
throw $e12281229;
}
var $ret12341235 = $Hanf_arg3241239($z12301231,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,anf_fun531225,l80891,left82892,right83894);
++R.GAS;
return $ret12341235;
};
var $Hanf_arg3241239 = function(anf_arg571238,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,anf_fun531225,l80891,left82892,right83894) {
var $z12421243 = D;
var $f12481249 = function(_) {
return R.isFunction(anf_fun531225)?anf_fun531225.app(l80891,("makeSrcloc"),anf_arg571238):R.ffi.throwNonFunApp(L[141],anf_fun531225,[l80891,("makeSrcloc"),anf_arg571238]);
};
try {
if(--R.GAS > 0) {
$z12421243 = $f12481249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12481249,
"from":L[141]});
}
} catch($e12401241) {
if(R.isCont($e12401241)) {
var $ss12441245 = {"from":L[141],
"go":function(anf_array_val581250) {
return $Hanf_array_val3231251(anf_array_val581250,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,l80891,left82892,right83894);
}};
$e12401241.stack[R.EXN_STACKHEIGHT++] = $ss12441245;
}
if(R.isPyretException($e12401241)) {
$e12401241.pyretStack.push(L[141]);
}
throw $e12401241;
}
var $ret12461247 = $Hanf_array_val3231251($z12421243,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,l80891,left82892,right83894);
++R.GAS;
return $ret12461247;
};
var $Hanf_array_val3231251 = function(anf_array_val581250,anf_arg411145,anf_array_val521211,anf_fun371132,anf_fun421159,l80891,left82892,right83894) {
var $z12541255 = D;
var $f12601261 = function(_) {
return R.isFunction(anf_fun421159)?anf_fun421159.app([anf_array_val521211,left82892,right83894,anf_array_val581250]):R.ffi.throwNonFunApp(L[129],anf_fun421159,[[anf_array_val521211,left82892,right83894,anf_array_val581250]]);
};
try {
if(--R.GAS > 0) {
$z12541255 = $f12601261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12601261,
"from":L[129]});
}
} catch($e12521253) {
if(R.isCont($e12521253)) {
var $ss12561257 = {"from":L[129],
"go":function(anf_arg591262) {
return $Hanf_arg3221263(anf_arg591262,anf_arg411145,anf_fun371132,l80891);
}};
$e12521253.stack[R.EXN_STACKHEIGHT++] = $ss12561257;
}
if(R.isPyretException($e12521253)) {
$e12521253.pyretStack.push(L[129]);
}
throw $e12521253;
}
var $ret12581259 = $Hanf_arg3221263($z12541255,anf_arg411145,anf_fun371132,l80891);
++R.GAS;
return $ret12581259;
};
var $Hanf_arg3221263 = function(anf_arg591262,anf_arg411145,anf_fun371132,l80891) {
var $z12661267 = D;
var $f12721273 = function(_) {
return R.isFunction(anf_fun371132)?anf_fun371132.app(l80891,anf_arg411145,anf_arg591262):R.ffi.throwNonFunApp(L[142],anf_fun371132,[l80891,anf_arg411145,anf_arg591262]);
};
try {
if(--R.GAS > 0) {
$z12661267 = $f12721273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12721273,
"from":L[142]});
}
} catch($e12641265) {
if(R.isCont($e12641265)) {
var $ss12681269 = {"from":L[142],
"go":function(ann_DASH_check_DASH_temp361274) {
return $Hann_DASH_check_DASH_temp3211275(ann_DASH_check_DASH_temp361274);
}};
$e12641265.stack[R.EXN_STACKHEIGHT++] = $ss12681269;
}
if(R.isPyretException($e12641265)) {
$e12641265.pyretStack.push(L[142]);
}
throw $e12641265;
}
var $ret12701271 = $Hann_DASH_check_DASH_temp3211275($z12661267);
++R.GAS;
return $ret12701271;
};
var $Hann_DASH_check_DASH_temp3211275 = function(ann_DASH_check_DASH_temp361274) {
return ann_DASH_check_DASH_temp361274;
};
var $Hanf_arg3201276 = function(anf_arg171277,self51278,_plus4,torepr8) {
var anf_arg181289 = G(self51278,"name",L[143]);
var $z12811282 = D;
var $f12871288 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg181289):R.ffi.throwNonFunApp(L[143],torepr8,[anf_arg181289]);
};
try {
if(--R.GAS > 0) {
$z12811282 = $f12871288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12871288,
"from":L[143]});
}
} catch($e12791280) {
if(R.isCont($e12791280)) {
var $ss12831284 = {"from":L[143],
"go":function(anf_arg191290) {
return $Hanf_arg3191291(anf_arg191290,anf_arg171277,self51278,_plus4,torepr8);
}};
$e12791280.stack[R.EXN_STACKHEIGHT++] = $ss12831284;
}
if(R.isPyretException($e12791280)) {
$e12791280.pyretStack.push(L[143]);
}
throw $e12791280;
}
var $ret12851286 = $Hanf_arg3191291($z12811282,anf_arg171277,self51278,_plus4,torepr8);
++R.GAS;
return $ret12851286;
};
var $Hanf_arg3191291 = function(anf_arg191290,anf_arg171277,self51278,_plus4,torepr8) {
var $z12941295 = D;
var $f13001301 = function(_) {
return R.isFunction(_plus4)?_plus4.app((", "),anf_arg191290):R.ffi.throwNonFunApp(L[143],_plus4,[(", "),anf_arg191290]);
};
try {
if(--R.GAS > 0) {
$z12941295 = $f13001301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13001301,
"from":L[143]});
}
} catch($e12921293) {
if(R.isCont($e12921293)) {
var $ss12961297 = {"from":L[143],
"go":function(anf_arg201302) {
return $Hanf_arg3181303(anf_arg201302,anf_arg171277,self51278,_plus4,torepr8);
}};
$e12921293.stack[R.EXN_STACKHEIGHT++] = $ss12961297;
}
if(R.isPyretException($e12921293)) {
$e12921293.pyretStack.push(L[143]);
}
throw $e12921293;
}
var $ret12981299 = $Hanf_arg3181303($z12941295,anf_arg171277,self51278,_plus4,torepr8);
++R.GAS;
return $ret12981299;
};
var $Hanf_arg3181303 = function(anf_arg201302,anf_arg171277,self51278,_plus4,torepr8) {
var $z13061307 = D;
var $f13121313 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg171277,anf_arg201302):R.ffi.throwNonFunApp(L[143],_plus4,[anf_arg171277,anf_arg201302]);
};
try {
if(--R.GAS > 0) {
$z13061307 = $f13121313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13121313,
"from":L[143]});
}
} catch($e13041305) {
if(R.isCont($e13041305)) {
var $ss13081309 = {"from":L[143],
"go":function(anf_arg211314) {
return $Hanf_arg3171315(anf_arg211314,self51278,_plus4,torepr8);
}};
$e13041305.stack[R.EXN_STACKHEIGHT++] = $ss13081309;
}
if(R.isPyretException($e13041305)) {
$e13041305.pyretStack.push(L[143]);
}
throw $e13041305;
}
var $ret13101311 = $Hanf_arg3171315($z13061307,self51278,_plus4,torepr8);
++R.GAS;
return $ret13101311;
};
var $Hanf_arg3171315 = function(anf_arg211314,self51278,_plus4,torepr8) {
var anf_arg221326 = G(self51278,"body",L[143]);
var $z13181319 = D;
var $f13241325 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg221326):R.ffi.throwNonFunApp(L[143],torepr8,[anf_arg221326]);
};
try {
if(--R.GAS > 0) {
$z13181319 = $f13241325();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13241325,
"from":L[143]});
}
} catch($e13161317) {
if(R.isCont($e13161317)) {
var $ss13201321 = {"from":L[143],
"go":function(anf_arg231327) {
return $Hanf_arg3161328(anf_arg231327,anf_arg211314,_plus4);
}};
$e13161317.stack[R.EXN_STACKHEIGHT++] = $ss13201321;
}
if(R.isPyretException($e13161317)) {
$e13161317.pyretStack.push(L[143]);
}
throw $e13161317;
}
var $ret13221323 = $Hanf_arg3161328($z13181319,anf_arg211314,_plus4);
++R.GAS;
return $ret13221323;
};
var $Hanf_arg3161328 = function(anf_arg231327,anf_arg211314,_plus4) {
var $z13311332 = D;
var $f13371338 = function(_) {
return R.isFunction(_plus4)?_plus4.app((", "),anf_arg231327):R.ffi.throwNonFunApp(L[143],_plus4,[(", "),anf_arg231327]);
};
try {
if(--R.GAS > 0) {
$z13311332 = $f13371338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13371338,
"from":L[143]});
}
} catch($e13291330) {
if(R.isCont($e13291330)) {
var $ss13331334 = {"from":L[143],
"go":function(anf_arg241339) {
return $Hanf_arg3151340(anf_arg241339,anf_arg211314,_plus4);
}};
$e13291330.stack[R.EXN_STACKHEIGHT++] = $ss13331334;
}
if(R.isPyretException($e13291330)) {
$e13291330.pyretStack.push(L[143]);
}
throw $e13291330;
}
var $ret13351336 = $Hanf_arg3151340($z13311332,anf_arg211314,_plus4);
++R.GAS;
return $ret13351336;
};
var $Hanf_arg3151340 = function(anf_arg241339,anf_arg211314,_plus4) {
var $z13431344 = D;
var $f13491350 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg211314,anf_arg241339):R.ffi.throwNonFunApp(L[143],_plus4,[anf_arg211314,anf_arg241339]);
};
try {
if(--R.GAS > 0) {
$z13431344 = $f13491350();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13491350,
"from":L[143]});
}
} catch($e13411342) {
if(R.isCont($e13411342)) {
var $ss13451346 = {"from":L[143],
"go":function(anf_arg251351) {
return $Hanf_arg3141352(anf_arg251351,_plus4);
}};
$e13411342.stack[R.EXN_STACKHEIGHT++] = $ss13451346;
}
if(R.isPyretException($e13411342)) {
$e13411342.pyretStack.push(L[143]);
}
throw $e13411342;
}
var $ret13471348 = $Hanf_arg3141352($z13431344,_plus4);
++R.GAS;
return $ret13471348;
};
var $Hanf_arg3141352 = function(anf_arg251351,_plus4) {
var $z13551356 = D;
var $f13611362 = function(_) {
return R.isFunction(_plus4)?_plus4.app(anf_arg251351,(")")):R.ffi.throwNonFunApp(L[143],_plus4,[anf_arg251351,(")")]);
};
try {
if(--R.GAS > 0) {
$z13551356 = $f13611362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13611362,
"from":L[143]});
}
} catch($e13531354) {
if(R.isCont($e13531354)) {
var $ss13571358 = {"from":L[143],
"go":function(anf_arg261363) {
return $Hanf_arg3131364(anf_arg261363,_plus4);
}};
$e13531354.stack[R.EXN_STACKHEIGHT++] = $ss13571358;
}
if(R.isPyretException($e13531354)) {
$e13531354.pyretStack.push(L[143]);
}
throw $e13531354;
}
var $ret13591360 = $Hanf_arg3131364($z13551356,_plus4);
++R.GAS;
return $ret13591360;
};
var $Hanf_arg3131364 = function(anf_arg261363,_plus4) {
var $z13671368 = D;
var $f13731374 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("("),anf_arg261363):R.ffi.throwNonFunApp(L[143],_plus4,[("("),anf_arg261363]);
};
try {
if(--R.GAS > 0) {
$z13671368 = $f13731374();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13731374,
"from":L[143]});
}
} catch($e13651366) {
if(R.isCont($e13651366)) {
var $ss13691370 = {"from":L[143],
"go":function(anf_arg271375) {
return $Hanf_arg3121376(anf_arg271375,_plus4);
}};
$e13651366.stack[R.EXN_STACKHEIGHT++] = $ss13691370;
}
if(R.isPyretException($e13651366)) {
$e13651366.pyretStack.push(L[143]);
}
throw $e13651366;
}
var $ret13711372 = $Hanf_arg3121376($z13671368,_plus4);
++R.GAS;
return $ret13711372;
};
var $Hanf_arg3121376 = function(anf_arg271375,_plus4) {
var $z13791380 = D;
var $f13851386 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("check-info"),anf_arg271375):R.ffi.throwNonFunApp(L[143],_plus4,[("check-info"),anf_arg271375]);
};
try {
if(--R.GAS > 0) {
$z13791380 = $f13851386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13851386,
"from":L[143]});
}
} catch($e13771378) {
if(R.isCont($e13771378)) {
var $ss13811382 = {"from":L[143],
"go":function(ann_DASH_check_DASH_temp151387) {
return $Hann_DASH_check_DASH_temp3111388(ann_DASH_check_DASH_temp151387);
}};
$e13771378.stack[R.EXN_STACKHEIGHT++] = $ss13811382;
}
if(R.isPyretException($e13771378)) {
$e13771378.pyretStack.push(L[143]);
}
throw $e13771378;
}
var $ret13831384 = $Hann_DASH_check_DASH_temp3111388($z13791380);
++R.GAS;
return $ret13831384;
};
var $Hann_DASH_check_DASH_temp3111388 = function(ann_DASH_check_DASH_temp151387) {
return ann_DASH_check_DASH_temp151387;
};
var $Hcont_tail_arg3091389 = function(cont_tail_arg121390,if_helper21391) {
if(--R.GAS > 0) {
$z13921393 = R.isFunction(if_helper21391)?if_helper21391.app(cont_tail_arg121390):R.ffi.throwNonFunApp(L[143],if_helper21391,[cont_tail_arg121390]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper21391)?if_helper21391.app(cont_tail_arg121390):R.ffi.throwNonFunApp(L[143],if_helper21391,[cont_tail_arg121390]);
},
"from":L[143]});
}
++R.GAS;
return $z13921393;
};
var $Hcont_tail_arg3101394 = function(cont_tail_arg71395,if_helper21391) {
if(--R.GAS > 0) {
$z13961397 = R.isFunction(if_helper21391)?if_helper21391.app(cont_tail_arg71395):R.ffi.throwNonFunApp(L[143],if_helper21391,[cont_tail_arg71395]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper21391)?if_helper21391.app(cont_tail_arg71395):R.ffi.throwNonFunApp(L[143],if_helper21391,[cont_tail_arg71395]);
},
"from":L[143]});
}
++R.GAS;
return $z13961397;
};
return R.loadModulesNew(NAMESPACE,[$A11130,$SL31231,$G51332,$U71433,$arrays91534,$lists111635,$option131736,$error151837,$sets171938],function($A11130,$SL31231,$G51332,$U71433,$arrays91534,$lists111635,$option131736,$error151837,$sets171938) {
var A111 = R.getField($A11130,"values");
var SL312 = R.getField($SL31231,"values");
var G513 = R.getField($G51332,"values");
var U714 = R.getField($U71433,"values");
var arrays915 = R.getField($arrays91534,"values");
var lists1116 = R.getField($lists111635,"values");
var option1317 = R.getField($option131736,"values");
var error1518 = R.getField($error151837,"values");
var sets1719 = R.getField($sets171938,"values");
var A220 = R.getField($A11130,"types");
var SL421 = R.getField($SL31231,"types");
var G622 = R.getField($G51332,"types");
var U823 = R.getField($U71433,"types");
var arrays1024 = R.getField($arrays91534,"types");
var lists1225 = R.getField($lists111635,"types");
var option1426 = R.getField($option131736,"types");
var error1627 = R.getField($error151837,"types");
var sets1828 = R.getField($sets171938,"types");
return R.safeCall(function() {
var List191398 = R.getDotAnn(L[144],"lists",lists1225,"List");
var Option201399 = R.getDotAnn(L[144],"option",option1426,"Option");
var Array211400 = R.getDotAnn(L[144],"arrays",arrays1024,"Array");
var Set221401 = R.getDotAnn(L[144],"sets",sets1828,"Set");
var array231919 = G(arrays915,"array",L[144]);
var build_DASH_array241918 = G(arrays915,"build-array",L[144]);
var array_DASH_from_DASH_list251917 = G(arrays915,"array-from-list",L[144]);
var is_DASH_array261916 = G(arrays915,"is-array",L[144]);
var list2787 = G(lists1116,"list",L[144]);
var is_DASH_empty2885 = G(lists1116,"is-empty",L[144]);
var is_DASH_link291915 = G(lists1116,"is-link",L[144]);
var empty301914 = G(lists1116,"empty",L[144]);
var link31752 = G(lists1116,"link",L[144]);
var range321913 = G(lists1116,"range",L[144]);
var repeat331912 = G(lists1116,"repeat",L[144]);
var filter341911 = G(lists1116,"filter",L[144]);
var partition351910 = G(lists1116,"partition",L[144]);
var split_DASH_at361909 = G(lists1116,"split-at",L[144]);
var any371908 = G(lists1116,"any",L[144]);
var find381907 = G(lists1116,"find",L[144]);
var map391906 = G(lists1116,"map",L[144]);
var map2401905 = G(lists1116,"map2",L[144]);
var map3411904 = G(lists1116,"map3",L[144]);
var map4421903 = G(lists1116,"map4",L[144]);
var map_n431902 = G(lists1116,"map_n",L[144]);
var map2_n441901 = G(lists1116,"map2_n",L[144]);
var map3_n451900 = G(lists1116,"map3_n",L[144]);
var map4_n461899 = G(lists1116,"map4_n",L[144]);
var each471898 = G(lists1116,"each",L[144]);
var each2481897 = G(lists1116,"each2",L[144]);
var each3491896 = G(lists1116,"each3",L[144]);
var each4501895 = G(lists1116,"each4",L[144]);
var each_n511894 = G(lists1116,"each_n",L[144]);
var each2_n521893 = G(lists1116,"each2_n",L[144]);
var each3_n531892 = G(lists1116,"each3_n",L[144]);
var each4_n541891 = G(lists1116,"each4_n",L[144]);
var fold551890 = G(lists1116,"fold",L[144]);
var fold2561889 = G(lists1116,"fold2",L[144]);
var fold3571888 = G(lists1116,"fold3",L[144]);
var fold4581887 = G(lists1116,"fold4",L[144]);
var index591886 = G(lists1116,"index",L[144]);
var Option601885 = G(option1317,"Option",L[144]);
var is_DASH_none611884 = G(option1317,"is-none",L[144]);
var is_DASH_some621883 = G(option1317,"is-some",L[144]);
var none63374 = G(option1317,"none",L[144]);
var some641882 = G(option1317,"some",L[144]);
var set651881 = G(sets1719,"set",L[144]);
var tree_DASH_set661880 = G(sets1719,"tree-set",L[144]);
var list_DASH_set671879 = G(sets1719,"list-set",L[144]);
var CheckInfoT1691402 = R.namedBrander("CheckInfo");
var CheckInfo6841 = R.makeBranderAnn(CheckInfoT1691402,"CheckInfo");
var CheckInfo2701403 = {"$var":D,
"$name":"CheckInfo2"};
var CheckInfo711405 = {"$var":D,
"$name":"CheckInfo"};
var is_DASH_CheckInfo721407 = {"$var":D,
"$name":"is-CheckInfo"};
var is_DASH_check_DASH_info731409 = {"$var":D,
"$name":"is-check-info"};
var check_DASH_info74749 = {"$var":D,
"$name":"check-info"};
var anf_variant_member141829 = R.makeMethod(function(self21859) {
return function(cases_DASH_funs31860,else_DASH_clause41871) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[143],2,arguments);
}
var if_DASH_61872 = R.hasField(cases_DASH_funs31860,("check-info"));
var if_helper21391 = R.makeFunction(function(if_helper_arg31877) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[143],1,arguments);
}
var ann_DASH_check_DASH_temp11878 = if_helper_arg31877;
return ann_DASH_check_DASH_temp11878;
});
var anf_if61876 = R.isBoolean(if_DASH_61872);
if(R.isPyretTrue(anf_if61876)) {
if(R.isPyretTrue(if_DASH_61872)) {
var call_DASH_check_DASH_info11855 = G(cases_DASH_funs31860,"check-info",L[143]);
var anf_arg91856 = G(self21859,"l",L[209]);
var anf_arg101857 = G(self21859,"name",L[208]);
var anf_arg111858 = G(self21859,"body",L[207]);
var $z18471848 = D;
var $f18531854 = function(_) {
return R.isFunction(call_DASH_check_DASH_info11855)?call_DASH_check_DASH_info11855.app(anf_arg91856,anf_arg101857,anf_arg111858):R.ffi.throwNonFunApp(L[143],call_DASH_check_DASH_info11855,[anf_arg91856,anf_arg101857,anf_arg111858]);
};
try {
if(--R.GAS > 0) {
$z18471848 = $f18531854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18531854,
"from":L[143]});
}
} catch($e18451846) {
if(R.isCont($e18451846)) {
var $ss18491850 = {"from":L[143],
"go":function(cont_tail_arg121390) {
return $Hcont_tail_arg3091389(cont_tail_arg121390,if_helper21391);
}};
$e18451846.stack[R.EXN_STACKHEIGHT++] = $ss18491850;
}
if(R.isPyretException($e18451846)) {
$e18451846.pyretStack.push(L[143]);
}
throw $e18451846;
}
var $ret18511852 = $Hcont_tail_arg3091389($z18471848,if_helper21391);
++R.GAS;
return $ret18511852;
} else {
var $z18631864 = D;
var $f18691870 = function(_) {
return R.isFunction(else_DASH_clause41871)?else_DASH_clause41871.app():R.ffi.throwNonFunApp(L[143],else_DASH_clause41871,[]);
};
try {
if(--R.GAS > 0) {
$z18631864 = $f18691870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18691870,
"from":L[143]});
}
} catch($e18611862) {
if(R.isCont($e18611862)) {
var $ss18651866 = {"from":L[143],
"go":function(cont_tail_arg71395) {
return $Hcont_tail_arg3101394(cont_tail_arg71395,if_helper21391);
}};
$e18611862.stack[R.EXN_STACKHEIGHT++] = $ss18651866;
}
if(R.isPyretException($e18611862)) {
$e18611862.pyretStack.push(L[143]);
}
throw $e18611862;
}
var $ret18671868 = $Hcont_tail_arg3101394($z18631864,if_helper21391);
++R.GAS;
return $ret18671868;
}
} else {
var cont_tail_arg41875 = R.throwNonBooleanCondition(L[143],("if"),if_DASH_61872);
if(--R.GAS > 0) {
$z18731874 = R.isFunction(if_helper21391)?if_helper21391.app(cont_tail_arg41875):R.ffi.throwNonFunApp(L[143],if_helper21391,[cont_tail_arg41875]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper21391)?if_helper21391.app(cont_tail_arg41875):R.ffi.throwNonFunApp(L[143],if_helper21391,[cont_tail_arg41875]);
},
"from":L[143]});
}
++R.GAS;
return $z18731874;
}
};
},{"length":3});
var anf_variant_member281830 = R.makeMethod(function(self51278) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[143],0,arguments);
}
var anf_arg161844 = G(self51278,"l",L[143]);
var $z18361837 = D;
var $f18421843 = function(_) {
return R.isFunction(torepr8)?torepr8.app(anf_arg161844):R.ffi.throwNonFunApp(L[143],torepr8,[anf_arg161844]);
};
try {
if(--R.GAS > 0) {
$z18361837 = $f18421843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18421843,
"from":L[143]});
}
} catch($e18341835) {
if(R.isCont($e18341835)) {
var $ss18381839 = {"from":L[143],
"go":function(anf_arg171277) {
return $Hanf_arg3201276(anf_arg171277,self51278,_plus4,torepr8);
}};
$e18341835.stack[R.EXN_STACKHEIGHT++] = $ss18381839;
}
if(R.isPyretException($e18341835)) {
$e18341835.pyretStack.push(L[143]);
}
throw $e18341835;
}
var $ret18401841 = $Hanf_arg3201276($z18361837,self51278,_plus4,torepr8);
++R.GAS;
return $ret18401841;
};
},{"length":1});
var anf_assign291404 = (function() {
var $check_DASH_info_DASH_base18241825 = {"_match":anf_variant_member141829,
"_torepr":anf_variant_member281830};
var $check_DASH_info_DASH_brands18271828 = {"$brand-check-info1826":true};
$check_DASH_info_DASH_brands18271828[CheckInfoT1691402._brand] = true
return R.makeObject({"CheckInfo":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CheckInfoT1691402._brand));
}),
"is-check-info":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[143],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-check-info1826"));
}),
"check-info":R.makeFunction(function(l751831,name761832,body771833) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[203],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[204],"SL",SL421,"Srcloc"),$type$String10,R.getDotAnn(L[205],"A",A220,"Expr")],[l751831,name761832,body771833],[L[204],L[206],L[205]],function() {
var dict = R.create($check_DASH_info_DASH_base18241825);
dict["l"] = l751831
dict["name"] = name761832
dict["body"] = body771833
return R.makeBrandedObject(dict,$check_DASH_info_DASH_brands18271828);
});
})});
})();
CheckInfo2701403.$var = anf_assign291404;
var anf_assign301406 = G(CheckInfo2701403.$var,"CheckInfo",L[0]);
CheckInfo711405.$var = anf_assign301406;
var anf_assign311408 = G(CheckInfo2701403.$var,"CheckInfo",L[0]);
is_DASH_CheckInfo721407.$var = anf_assign311408;
var anf_assign321410 = G(CheckInfo2701403.$var,"is-check-info",L[143]);
is_DASH_check_DASH_info731409.$var = anf_assign321410;
var anf_assign331411 = G(CheckInfo2701403.$var,"check-info",L[143]);
check_DASH_info74749.$var = anf_assign331411;
var anf_extend341750 = G(A111,"default-map-visitor",L[202]);
var anf_extend1141751 = R.makeMethod(function(self791823) {
return function(l80891,op81893,left82892,right83894) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[201],4,arguments);
}
var check_DASH_op841752 = {"$var":D,
"$name":"check-op"};
var anf_assign601753 = R.makeFunction(function(fieldname851134) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[142],1,arguments);
}
var anf_fun371132 = G(A111,"s-app",L[200]);
var anf_fun381133 = G(A111,"s-dot",L[199]);
var anf_fun391822 = G(U714,"checkers",L[198]);
var $z18141815 = D;
var $f18201821 = function(_) {
return R.isFunction(anf_fun391822)?anf_fun391822.app(l80891):R.ffi.throwNonFunApp(L[197],anf_fun391822,[l80891]);
};
try {
if(--R.GAS > 0) {
$z18141815 = $f18201821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18201821,
"from":L[197]});
}
} catch($e18121813) {
if(R.isCont($e18121813)) {
var $ss18161817 = {"from":L[197],
"go":function(anf_arg401131) {
return $Hanf_arg3321130(anf_arg401131,A111,anf_fun371132,anf_fun381133,fieldname851134,l80891,left82892,list2787,op81893,right83894);
}};
$e18121813.stack[R.EXN_STACKHEIGHT++] = $ss18161817;
}
if(R.isPyretException($e18121813)) {
$e18121813.pyretStack.push(L[197]);
}
throw $e18121813;
}
var $ret18181819 = $Hanf_arg3321130($z18141815,A111,anf_fun371132,anf_fun381133,fieldname851134,l80891,left82892,list2787,op81893,right83894);
++R.GAS;
return $ret18181819;
});
check_DASH_op841752.$var = anf_assign601753;
var if_DASH_91805 = R.equiv(op81893,("opis"));
var if_helper61880 = R.makeFunction(function(if_helper_arg621810) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[196],1,arguments);
}
var ann_DASH_check_DASH_temp351811 = if_helper_arg621810;
return ann_DASH_check_DASH_temp351811;
});
var anf_if651809 = R.isBoolean(if_DASH_91805);
if(R.isPyretTrue(anf_if651809)) {
if(R.isPyretTrue(if_DASH_91805)) {
var $z17561757 = D;
var $f17621763 = function(_) {
return R.isFunction(check_DASH_op841752.$var)?check_DASH_op841752.$var.app(("check-is")):R.ffi.throwNonFunApp(L[97],check_DASH_op841752.$var,[("check-is")]);
};
try {
if(--R.GAS > 0) {
$z17561757 = $f17621763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17621763,
"from":L[97]});
}
} catch($e17541755) {
if(R.isCont($e17541755)) {
var $ss17581759 = {"from":L[97],
"go":function(cont_tail_arg112879) {
return $Hcont_tail_arg333878(cont_tail_arg112879,if_helper61880);
}};
$e17541755.stack[R.EXN_STACKHEIGHT++] = $ss17581759;
}
if(R.isPyretException($e17541755)) {
$e17541755.pyretStack.push(L[97]);
}
throw $e17541755;
}
var $ret17601761 = $Hcont_tail_arg333878($z17561757,if_helper61880);
++R.GAS;
return $ret17601761;
} else {
var if_DASH_81800 = R.equiv(op81893,("opsatisfies"));
var anf_if681804 = R.isBoolean(if_DASH_81800);
if(R.isPyretTrue(anf_if681804)) {
if(R.isPyretTrue(if_DASH_81800)) {
var $z17661767 = D;
var $f17721773 = function(_) {
return R.isFunction(check_DASH_op841752.$var)?check_DASH_op841752.$var.app(("check-satisfies")):R.ffi.throwNonFunApp(L[98],check_DASH_op841752.$var,[("check-satisfies")]);
};
try {
if(--R.GAS > 0) {
$z17661767 = $f17721773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17721773,
"from":L[98]});
}
} catch($e17641765) {
if(R.isCont($e17641765)) {
var $ss17681769 = {"from":L[98],
"go":function(cont_tail_arg110884) {
return $Hcont_tail_arg334883(cont_tail_arg110884,if_helper61880);
}};
$e17641765.stack[R.EXN_STACKHEIGHT++] = $ss17681769;
}
if(R.isPyretException($e17641765)) {
$e17641765.pyretStack.push(L[98]);
}
throw $e17641765;
}
var $ret17701771 = $Hcont_tail_arg334883($z17661767,if_helper61880);
++R.GAS;
return $ret17701771;
} else {
var if_DASH_71795 = R.equiv(op81893,("opraises"));
var anf_if711799 = R.isBoolean(if_DASH_71795);
if(R.isPyretTrue(anf_if711799)) {
if(R.isPyretTrue(if_DASH_71795)) {
var anf_fun78889 = G(A111,"s-app",L[193]);
var anf_fun79890 = G(A111,"s-dot",L[192]);
var anf_fun801784 = G(U714,"checkers",L[191]);
var $z17761777 = D;
var $f17821783 = function(_) {
return R.isFunction(anf_fun801784)?anf_fun801784.app(l80891):R.ffi.throwNonFunApp(L[190],anf_fun801784,[l80891]);
};
try {
if(--R.GAS > 0) {
$z17761777 = $f17821783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17821783,
"from":L[190]});
}
} catch($e17741775) {
if(R.isCont($e17741775)) {
var $ss17781779 = {"from":L[190],
"go":function(anf_arg81888) {
return $Hanf_arg349887(anf_arg81888,A111,anf_fun78889,anf_fun79890,if_helper61880,l80891,left82892,list2787,none63374,op81893,right83894);
}};
$e17741775.stack[R.EXN_STACKHEIGHT++] = $ss17781779;
}
if(R.isPyretException($e17741775)) {
$e17741775.pyretStack.push(L[190]);
}
throw $e17741775;
}
var $ret17801781 = $Hanf_arg349887($z17761777,A111,anf_fun78889,anf_fun79890,if_helper61880,l80891,left82892,list2787,none63374,op81893,right83894);
++R.GAS;
return $ret17801781;
} else {
var $z17871788 = D;
var $f17931794 = function(_) {
return R.isFunction(_plus4)?_plus4.app(("Check test operator "),op81893):R.ffi.throwNonFunApp(L[122],_plus4,[("Check test operator "),op81893]);
};
try {
if(--R.GAS > 0) {
$z17871788 = $f17931794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17931794,
"from":L[122]});
}
} catch($e17851786) {
if(R.isCont($e17851786)) {
var $ss17891790 = {"from":L[122],
"go":function(anf_arg721079) {
return $Hanf_arg3541078(anf_arg721079,if_helper61880,l80891,_plus4,raise7,torepr8);
}};
$e17851786.stack[R.EXN_STACKHEIGHT++] = $ss17891790;
}
if(R.isPyretException($e17851786)) {
$e17851786.pyretStack.push(L[122]);
}
throw $e17851786;
}
var $ret17911792 = $Hanf_arg3541078($z17871788,if_helper61880,l80891,_plus4,raise7,torepr8);
++R.GAS;
return $ret17911792;
}
} else {
var cont_tail_arg691798 = R.throwNonBooleanCondition(L[194],("if"),if_DASH_71795);
if(--R.GAS > 0) {
$z17961797 = R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg691798):R.ffi.throwNonFunApp(L[194],if_helper61880,[cont_tail_arg691798]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg691798):R.ffi.throwNonFunApp(L[194],if_helper61880,[cont_tail_arg691798]);
},
"from":L[194]});
}
++R.GAS;
return $z17961797;
}
}
} else {
var cont_tail_arg661803 = R.throwNonBooleanCondition(L[195],("if"),if_DASH_81800);
if(--R.GAS > 0) {
$z18011802 = R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg661803):R.ffi.throwNonFunApp(L[195],if_helper61880,[cont_tail_arg661803]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg661803):R.ffi.throwNonFunApp(L[195],if_helper61880,[cont_tail_arg661803]);
},
"from":L[195]});
}
++R.GAS;
return $z18011802;
}
}
} else {
var cont_tail_arg631808 = R.throwNonBooleanCondition(L[196],("if"),if_DASH_91805);
if(--R.GAS > 0) {
$z18061807 = R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg631808):R.ffi.throwNonFunApp(L[196],if_helper61880,[cont_tail_arg631808]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored171) {
return R.isFunction(if_helper61880)?if_helper61880.app(cont_tail_arg631808):R.ffi.throwNonFunApp(L[196],if_helper61880,[cont_tail_arg631808]);
},
"from":L[196]});
}
++R.GAS;
return $z18061807;
}
};
},{"length":5});
var check_DASH_stmts_DASH_visitor78750 = anf_extend341750.extendWith({"s-check-test":anf_extend1141751});
var get_DASH_checks861412 = {"$var":D,
"$name":"get-checks"};
var create_DASH_check_DASH_block8784 = {"$var":D,
"$name":"create-check-block"};
var make_DASH_lam88558 = {"$var":D,
"$name":"make-lam"};
var anf_assign1661413 = R.makeFunction(function(stmts891616) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[86],1,arguments);
}
var standalone_DASH_counter90793 = {"$var":(0),
"$name":"standalone-counter"};
var add_DASH_check91730 = {"$var":D,
"$name":"add-check"};
var anf_assign1621617 = R.makeFunction(function(stmt921629,lst93753) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[174],2,arguments);
}
var cases_DASH_val131749 = stmt921629;
var anf_fun1171640 = G(cases_DASH_val131749,"_match",L[175]);
var anf_obj1301644 = R.makeFunction(function(l94852,name95853,$underscore961713,$underscore971714,$underscore981715,$underscore991716,$underscore1001717,_check1011718) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[185],8,arguments);
}
var cases_DASH_val101748 = _check1011718;
var anf_fun1191729 = G(cases_DASH_val101748,"_match",L[186]);
var anf_obj1241733 = R.makeFunction(function(v1021736) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[96],1,arguments);
}
var anf_fun1211747 = G(v1021736,"visit",L[189]);
var $z17391740 = D;
var $f17451746 = function(_) {
return R.isFunction(anf_fun1211747)?anf_fun1211747.app(check_DASH_stmts_DASH_visitor78750):R.ffi.throwNonFunApp(L[188],anf_fun1211747,[check_DASH_stmts_DASH_visitor78750]);
};
try {
if(--R.GAS > 0) {
$z17391740 = $f17451746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17451746,
"from":L[188]});
}
} catch($e17371738) {
if(R.isCont($e17371738)) {
var $ss17411742 = {"from":L[188],
"go":function(anf_arg122851) {
return $Hanf_arg357850(anf_arg122851,check_DASH_info74749,l94852,link31752,lst93753,name95853);
}};
$e17371738.stack[R.EXN_STACKHEIGHT++] = $ss17411742;
}
if(R.isPyretException($e17371738)) {
$e17371738.pyretStack.push(L[188]);
}
throw $e17371738;
}
var $ret17431744 = $Hanf_arg357850($z17391740,check_DASH_info74749,l94852,link31752,lst93753,name95853);
++R.GAS;
return $ret17431744;
});
var anf_obj1261734 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[187],0,arguments);
}
var ann_DASH_check_DASH_temp1251735 = lst93753;
return ann_DASH_check_DASH_temp1251735;
});
var anf_arg1271730 = R.makeObject({"some":anf_obj1241733,
"none":anf_obj1261734});
var anf_arg1291731 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[186],0,arguments);
}
var ann_DASH_check_DASH_temp1281732 = R.throwNoBranchesMatched(L[186],("cases"));
return ann_DASH_check_DASH_temp1281732;
});
var $z17211722 = D;
var $f17271728 = function(_) {
return R.isFunction(anf_fun1191729)?anf_fun1191729.app(anf_arg1271730,anf_arg1291731):R.ffi.throwNonFunApp(L[185],anf_fun1191729,[anf_arg1271730,anf_arg1291731]);
};
try {
if(--R.GAS > 0) {
$z17211722 = $f17271728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17271728,
"from":L[185]});
}
} catch($e17191720) {
if(R.isCont($e17191720)) {
var $ss17231724 = {"from":L[185],
"go":function(ann_DASH_check_DASH_temp118849) {
return $Hann_DASH_check_DASH_temp358848(ann_DASH_check_DASH_temp118849);
}};
$e17191720.stack[R.EXN_STACKHEIGHT++] = $ss17231724;
}
if(R.isPyretException($e17191720)) {
$e17191720.pyretStack.push(L[185]);
}
throw $e17191720;
}
var $ret17251726 = $Hann_DASH_check_DASH_temp358848($z17211722);
++R.GAS;
return $ret17251726;
});
var anf_obj1431645 = R.makeFunction(function(l103822,name104823,$underscore1051678,$underscore1061679,$underscore1071680,$underscore1081681,_check1091682) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[180],7,arguments);
}
var cases_DASH_val111712 = _check1091682;
var anf_fun1321693 = G(cases_DASH_val111712,"_match",L[181]);
var anf_obj1371697 = R.makeFunction(function(v1101700) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[94],1,arguments);
}
var anf_fun1341711 = G(v1101700,"visit",L[184]);
var $z17031704 = D;
var $f17091710 = function(_) {
return R.isFunction(anf_fun1341711)?anf_fun1341711.app(check_DASH_stmts_DASH_visitor78750):R.ffi.throwNonFunApp(L[183],anf_fun1341711,[check_DASH_stmts_DASH_visitor78750]);
};
try {
if(--R.GAS > 0) {
$z17031704 = $f17091710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17091710,
"from":L[183]});
}
} catch($e17011702) {
if(R.isCont($e17011702)) {
var $ss17051706 = {"from":L[183],
"go":function(anf_arg135821) {
return $Hanf_arg361820(anf_arg135821,check_DASH_info74749,l103822,link31752,lst93753,name104823);
}};
$e17011702.stack[R.EXN_STACKHEIGHT++] = $ss17051706;
}
if(R.isPyretException($e17011702)) {
$e17011702.pyretStack.push(L[183]);
}
throw $e17011702;
}
var $ret17071708 = $Hanf_arg361820($z17031704,check_DASH_info74749,l103822,link31752,lst93753,name104823);
++R.GAS;
return $ret17071708;
});
var anf_obj1391698 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[182],0,arguments);
}
var ann_DASH_check_DASH_temp1381699 = lst93753;
return ann_DASH_check_DASH_temp1381699;
});
var anf_arg1401694 = R.makeObject({"some":anf_obj1371697,
"none":anf_obj1391698});
var anf_arg1421695 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[181],0,arguments);
}
var ann_DASH_check_DASH_temp1411696 = R.throwNoBranchesMatched(L[181],("cases"));
return ann_DASH_check_DASH_temp1411696;
});
var $z16851686 = D;
var $f16911692 = function(_) {
return R.isFunction(anf_fun1321693)?anf_fun1321693.app(anf_arg1401694,anf_arg1421695):R.ffi.throwNonFunApp(L[180],anf_fun1321693,[anf_arg1401694,anf_arg1421695]);
};
try {
if(--R.GAS > 0) {
$z16851686 = $f16911692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16911692,
"from":L[180]});
}
} catch($e16831684) {
if(R.isCont($e16831684)) {
var $ss16871688 = {"from":L[180],
"go":function(ann_DASH_check_DASH_temp131819) {
return $Hann_DASH_check_DASH_temp362818(ann_DASH_check_DASH_temp131819);
}};
$e16831684.stack[R.EXN_STACKHEIGHT++] = $ss16871688;
}
if(R.isPyretException($e16831684)) {
$e16831684.pyretStack.push(L[180]);
}
throw $e16831684;
}
var $ret16891690 = $Hann_DASH_check_DASH_temp362818($z16851686);
++R.GAS;
return $ret16891690;
});
var anf_obj1581646 = R.makeFunction(function(l111751,name1121647,body113748,keyword_DASH_check1141648) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[90],4,arguments);
}
var cases_DASH_val121677 = name1121647;
var anf_fun1451659 = G(cases_DASH_val121677,"_match",L[177]);
var anf_obj1491663 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[92],0,arguments);
}
var $z16691670 = D;
var $f16751676 = function(_) {
return R.isFunction(_plus4)?_plus4.app(standalone_DASH_counter90793.$var,(1)):R.ffi.throwNonFunApp(L[179],_plus4,[standalone_DASH_counter90793.$var,(1)]);
};
try {
if(--R.GAS > 0) {
$z16691670 = $f16751676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16751676,
"from":L[179]});
}
} catch($e16671668) {
if(R.isCont($e16671668)) {
var $ss16711672 = {"from":L[179],
"go":function(anf_assign147792) {
return $Hanf_assign365791(anf_assign147792,standalone_DASH_counter90793,_plus4,tostring9);
}};
$e16671668.stack[R.EXN_STACKHEIGHT++] = $ss16711672;
}
if(R.isPyretException($e16671668)) {
$e16671668.pyretStack.push(L[179]);
}
throw $e16671668;
}
var $ret16731674 = $Hanf_assign365791($z16691670,standalone_DASH_counter90793,_plus4,tostring9);
++R.GAS;
return $ret16731674;
});
var anf_obj1511664 = R.makeFunction(function(v1161665) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[178],1,arguments);
}
var ann_DASH_check_DASH_temp1501666 = v1161665;
return ann_DASH_check_DASH_temp1501666;
});
var anf_arg1521660 = R.makeObject({"none":anf_obj1491663,
"some":anf_obj1511664});
var anf_arg1541661 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[177],0,arguments);
}
var ann_DASH_check_DASH_temp1531662 = R.throwNoBranchesMatched(L[177],("cases"));
return ann_DASH_check_DASH_temp1531662;
});
var $z16511652 = D;
var $f16571658 = function(_) {
return R.isFunction(anf_fun1451659)?anf_fun1451659.app(anf_arg1521660,anf_arg1541661):R.ffi.throwNonFunApp(L[176],anf_fun1451659,[anf_arg1521660,anf_arg1541661]);
};
try {
if(--R.GAS > 0) {
$z16511652 = $f16571658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16571658,
"from":L[176]});
}
} catch($e16491650) {
if(R.isCont($e16491650)) {
var $ss16531654 = {"from":L[176],
"go":function(check_DASH_name115747) {
return $Hcheck_DASH_name369746(check_DASH_name115747,body113748,check_DASH_info74749,check_DASH_stmts_DASH_visitor78750,l111751,link31752,lst93753);
}};
$e16491650.stack[R.EXN_STACKHEIGHT++] = $ss16531654;
}
if(R.isPyretException($e16491650)) {
$e16491650.pyretStack.push(L[176]);
}
throw $e16491650;
}
var $ret16551656 = $Hcheck_DASH_name369746($z16511652,body113748,check_DASH_info74749,check_DASH_stmts_DASH_visitor78750,l111751,link31752,lst93753);
++R.GAS;
return $ret16551656;
});
var anf_arg1591641 = R.makeObject({"s-fun":anf_obj1301644,
"s-data":anf_obj1431645,
"s-check":anf_obj1581646});
var anf_arg1611642 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[175],0,arguments);
}
var ann_DASH_check_DASH_temp1601643 = lst93753;
return ann_DASH_check_DASH_temp1601643;
});
var $z16321633 = D;
var $f16381639 = function(_) {
return R.isFunction(anf_fun1171640)?anf_fun1171640.app(anf_arg1591641,anf_arg1611642):R.ffi.throwNonFunApp(L[174],anf_fun1171640,[anf_arg1591641,anf_arg1611642]);
};
try {
if(--R.GAS > 0) {
$z16321633 = $f16381639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16381639,
"from":L[174]});
}
} catch($e16301631) {
if(R.isCont($e16301631)) {
var $ss16341635 = {"from":L[174],
"go":function(ann_DASH_check_DASH_temp116745) {
return $Hann_DASH_check_DASH_temp370744(ann_DASH_check_DASH_temp116745);
}};
$e16301631.stack[R.EXN_STACKHEIGHT++] = $ss16341635;
}
if(R.isPyretException($e16301631)) {
$e16301631.pyretStack.push(L[174]);
}
throw $e16301631;
}
var $ret16361637 = $Hann_DASH_check_DASH_temp370744($z16321633);
++R.GAS;
return $ret16361637;
});
add_DASH_check91730.$var = anf_assign1621617;
var anf_fun163731 = G(stmts891616,"foldr",L[173]);
var anf_fun1641628 = G(list2787,"make",L[172]);
var $z16201621 = D;
var $f16261627 = function(_) {
return R.isFunction(anf_fun1641628)?anf_fun1641628.app([]):R.ffi.throwNonFunApp(L[172],anf_fun1641628,[[]]);
};
try {
if(--R.GAS > 0) {
$z16201621 = $f16261627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16261627,
"from":L[172]});
}
} catch($e16181619) {
if(R.isCont($e16181619)) {
var $ss16221623 = {"from":L[172],
"go":function(anf_arg165729) {
return $Hanf_arg372728(anf_arg165729,add_DASH_check91730,anf_fun163731);
}};
$e16181619.stack[R.EXN_STACKHEIGHT++] = $ss16221623;
}
if(R.isPyretException($e16181619)) {
$e16181619.pyretStack.push(L[172]);
}
throw $e16181619;
}
var $ret16241625 = $Hanf_arg372728($z16201621,add_DASH_check91730,anf_fun163731);
++R.GAS;
return $ret16241625;
});
get_DASH_checks861412.$var = anf_assign1661413;
var anf_assign2231414 = R.makeFunction(function(l117419,checks1181574) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[61],2,arguments);
}
var create_DASH_checker1191575 = {"$var":D,
"$name":"create-checker"};
var anf_assign2001576 = R.makeFunction(function(c1201588) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[169],1,arguments);
}
var cases_DASH_val141615 = c1201588;
var anf_fun1691599 = G(cases_DASH_val141615,"_match",L[170]);
var anf_obj1961603 = R.makeFunction(function(l2121557,name122559,body123556) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[85],3,arguments);
}
var anf_fun1711614 = G(list2787,"make",L[171]);
var $z16061607 = D;
var $f16121613 = function(_) {
return R.isFunction(anf_fun1711614)?anf_fun1711614.app([]):R.ffi.throwNonFunApp(L[171],anf_fun1711614,[[]]);
};
try {
if(--R.GAS > 0) {
$z16061607 = $f16121613();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16121613,
"from":L[171]});
}
} catch($e16041605) {
if(R.isCont($e16041605)) {
var $ss16081609 = {"from":L[171],
"go":function(anf_arg172555) {
return $Hanf_arg386554(anf_arg172555,A111,body123556,l2121557,list2787,make_DASH_lam88558,name122559);
}};
$e16041605.stack[R.EXN_STACKHEIGHT++] = $ss16081609;
}
if(R.isPyretException($e16041605)) {
$e16041605.pyretStack.push(L[171]);
}
throw $e16041605;
}
var $ret16101611 = $Hanf_arg386554($z16061607,A111,body123556,l2121557,list2787,make_DASH_lam88558,name122559);
++R.GAS;
return $ret16101611;
});
var anf_arg1971600 = R.makeObject({"check-info":anf_obj1961603});
var anf_arg1991601 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[170],0,arguments);
}
var ann_DASH_check_DASH_temp1981602 = R.throwNoBranchesMatched(L[170],("cases"));
return ann_DASH_check_DASH_temp1981602;
});
var $z15911592 = D;
var $f15971598 = function(_) {
return R.isFunction(anf_fun1691599)?anf_fun1691599.app(anf_arg1971600,anf_arg1991601):R.ffi.throwNonFunApp(L[169],anf_fun1691599,[anf_arg1971600,anf_arg1991601]);
};
try {
if(--R.GAS > 0) {
$z15911592 = $f15971598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15971598,
"from":L[169]});
}
} catch($e15891590) {
if(R.isCont($e15891590)) {
var $ss15931594 = {"from":L[169],
"go":function(ann_DASH_check_DASH_temp168553) {
return $Hann_DASH_check_DASH_temp387552(ann_DASH_check_DASH_temp168553);
}};
$e15891590.stack[R.EXN_STACKHEIGHT++] = $ss15931594;
}
if(R.isPyretException($e15891590)) {
$e15891590.pyretStack.push(L[169]);
}
throw $e15891590;
}
var $ret15951596 = $Hann_DASH_check_DASH_temp387552($z15911592);
++R.GAS;
return $ret15951596;
});
create_DASH_checker1191575.$var = anf_assign2001576;
var anf_fun2011587 = G(checks1181574,"map",L[168]);
var $z15791580 = D;
var $f15851586 = function(_) {
return R.isFunction(anf_fun2011587)?anf_fun2011587.app(create_DASH_checker1191575.$var):R.ffi.throwNonFunApp(L[167],anf_fun2011587,[create_DASH_checker1191575.$var]);
};
try {
if(--R.GAS > 0) {
$z15791580 = $f15851586();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15851586,
"from":L[167]});
}
} catch($e15771578) {
if(R.isCont($e15771578)) {
var $ss15811582 = {"from":L[167],
"go":function(checkers125418) {
return $Hcheckers398417(checkers125418,A111,U714,l117419,list2787);
}};
$e15771578.stack[R.EXN_STACKHEIGHT++] = $ss15811582;
}
if(R.isPyretException($e15771578)) {
$e15771578.pyretStack.push(L[167]);
}
throw $e15771578;
}
var $ret15831584 = $Hcheckers398417($z15791580,A111,U714,l117419,list2787);
++R.GAS;
return $ret15831584;
});
create_DASH_check_DASH_block8784.$var = anf_assign2231414;
var anf_assign2351415 = R.makeFunction(function(l126373,args127371,body128372) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[40],3,arguments);
}
var anf_fun225370 = G(A111,"s-lam",L[166]);
var anf_fun2261573 = G(list2787,"make",L[165]);
var $z15651566 = D;
var $f15711572 = function(_) {
return R.isFunction(anf_fun2261573)?anf_fun2261573.app([]):R.ffi.throwNonFunApp(L[165],anf_fun2261573,[[]]);
};
try {
if(--R.GAS > 0) {
$z15651566 = $f15711572();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15711572,
"from":L[165]});
}
} catch($e15631564) {
if(R.isCont($e15631564)) {
var $ss15671568 = {"from":L[165],
"go":function(anf_arg227369) {
return $Hanf_arg402368(anf_arg227369,A111,anf_fun225370,args127371,body128372,l126373,none63374);
}};
$e15631564.stack[R.EXN_STACKHEIGHT++] = $ss15671568;
}
if(R.isPyretException($e15631564)) {
$e15631564.pyretStack.push(L[165]);
}
throw $e15631564;
}
var $ret15691570 = $Hanf_arg402368($z15651566,A111,anf_fun225370,args127371,body128372,l126373,none63374);
++R.GAS;
return $ret15691570;
});
make_DASH_lam88558.$var = anf_assign2351415;
var anf_extend2361546 = G(A111,"default-map-visitor",L[164]);
var anf_extend2411547 = R.makeMethod(function(self1311559) {
return function(l132355,name1331560,body1341561,keyword_DASH_check1351562) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[34],4,arguments);
}
var anf_fun238354 = G(A111,"s-id",L[163]);
var anf_fun2391558 = G(A111,"s-name",L[162]);
var $z15501551 = D;
var $f15561557 = function(_) {
return R.isFunction(anf_fun2391558)?anf_fun2391558.app(l132355,("nothing")):R.ffi.throwNonFunApp(L[161],anf_fun2391558,[l132355,("nothing")]);
};
try {
if(--R.GAS > 0) {
$z15501551 = $f15561557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15561557,
"from":L[161]});
}
} catch($e15481549) {
if(R.isCont($e15481549)) {
var $ss15521553 = {"from":L[161],
"go":function(anf_arg240353) {
return $Hanf_arg404352(anf_arg240353,anf_fun238354,l132355);
}};
$e15481549.stack[R.EXN_STACKHEIGHT++] = $ss15521553;
}
if(R.isPyretException($e15481549)) {
$e15481549.pyretStack.push(L[161]);
}
throw $e15481549;
}
var $ret15541555 = $Hanf_arg404352($z15501551,anf_fun238354,l132355);
++R.GAS;
return $ret15541555;
};
},{"length":5});
var no_DASH_checks_DASH_visitor1301431 = anf_extend2361546.extendWith({"s-check":anf_extend2411547});
var anf_extend2421457 = G(A111,"default-map-visitor",L[160]);
var anf_extend2831458 = R.makeMethod(function(self13788) {
return function(l13886,stmts13989) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[159],2,arguments);
}
var $z15381539 = D;
var $f15441545 = function(_) {
return R.isFunction(get_DASH_checks861412.$var)?get_DASH_checks861412.$var.app(stmts13989):R.ffi.throwNonFunApp(L[158],get_DASH_checks861412.$var,[stmts13989]);
};
try {
if(--R.GAS > 0) {
$z15381539 = $f15441545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15441545,
"from":L[158]});
}
} catch($e15361537) {
if(R.isCont($e15361537)) {
var $ss15401541 = {"from":L[158],
"go":function(checks_DASH_to_DASH_perform14083) {
return $Hchecks_DASH_to_DASH_perform42482(checks_DASH_to_DASH_perform14083,A111,G513,create_DASH_check_DASH_block8784,is_DASH_empty2885,l13886,list2787,self13788,stmts13989,_minus3,_plus4,raise7);
}};
$e15361537.stack[R.EXN_STACKHEIGHT++] = $ss15401541;
}
if(R.isPyretException($e15361537)) {
$e15361537.pyretStack.push(L[158]);
}
throw $e15361537;
}
var $ret15421543 = $Hchecks_DASH_to_DASH_perform42482($z15381539,A111,G513,create_DASH_check_DASH_block8784,is_DASH_empty2885,l13886,list2787,self13788,stmts13989,_minus3,_plus4,raise7);
++R.GAS;
return $ret15421543;
};
},{"length":3});
var anf_extend2861459 = R.makeMethod(function(self1451534) {
return function(l1461527,name1471528,params1481529,args1491530,ann1501531,doc1511532,body1521533,$underscore1531535) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[156],8,arguments);
}
var anf_fun2851526 = G(A111,"s-fun",L[157]);
var $z15181519 = D;
var $f15241525 = function(_) {
return R.isFunction(anf_fun2851526)?anf_fun2851526.app(l1461527,name1471528,params1481529,args1491530,ann1501531,doc1511532,body1521533,none63374):R.ffi.throwNonFunApp(L[156],anf_fun2851526,[l1461527,name1471528,params1481529,args1491530,ann1501531,doc1511532,body1521533,none63374]);
};
try {
if(--R.GAS > 0) {
$z15181519 = $f15241525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15241525,
"from":L[156]});
}
} catch($e15161517) {
if(R.isCont($e15161517)) {
var $ss15201521 = {"from":L[156],
"go":function(ann_DASH_check_DASH_temp28481) {
return $Hann_DASH_check_DASH_temp42580(ann_DASH_check_DASH_temp28481);
}};
$e15161517.stack[R.EXN_STACKHEIGHT++] = $ss15201521;
}
if(R.isPyretException($e15161517)) {
$e15161517.pyretStack.push(L[156]);
}
throw $e15161517;
}
var $ret15221523 = $Hann_DASH_check_DASH_temp42580($z15181519);
++R.GAS;
return $ret15221523;
};
},{"length":9});
var anf_extend2891460 = R.makeMethod(function(self1541514) {
return function(l1551508,name1561509,params1571510,mixins1581511,variants1591512,shared_DASH_members1601513,$underscore1611515) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[154],7,arguments);
}
var anf_fun2881507 = G(A111,"s-data",L[155]);
var $z14991500 = D;
var $f15051506 = function(_) {
return R.isFunction(anf_fun2881507)?anf_fun2881507.app(l1551508,name1561509,params1571510,mixins1581511,variants1591512,shared_DASH_members1601513,none63374):R.ffi.throwNonFunApp(L[154],anf_fun2881507,[l1551508,name1561509,params1571510,mixins1581511,variants1591512,shared_DASH_members1601513,none63374]);
};
try {
if(--R.GAS > 0) {
$z14991500 = $f15051506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15051506,
"from":L[154]});
}
} catch($e14971498) {
if(R.isCont($e14971498)) {
var $ss15011502 = {"from":L[154],
"go":function(ann_DASH_check_DASH_temp28779) {
return $Hann_DASH_check_DASH_temp42678(ann_DASH_check_DASH_temp28779);
}};
$e14971498.stack[R.EXN_STACKHEIGHT++] = $ss15011502;
}
if(R.isPyretException($e14971498)) {
$e14971498.pyretStack.push(L[154]);
}
throw $e14971498;
}
var $ret15031504 = $Hann_DASH_check_DASH_temp42678($z14991500);
++R.GAS;
return $ret15031504;
};
},{"length":8});
var anf_extend2921461 = R.makeMethod(function(self1621495) {
return function(l1631489,params1641490,args1651491,ann1661492,doc1671493,body1681494,$underscore1691496) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[152],7,arguments);
}
var anf_fun2911488 = G(A111,"s-lam",L[153]);
var $z14801481 = D;
var $f14861487 = function(_) {
return R.isFunction(anf_fun2911488)?anf_fun2911488.app(l1631489,params1641490,args1651491,ann1661492,doc1671493,body1681494,none63374):R.ffi.throwNonFunApp(L[152],anf_fun2911488,[l1631489,params1641490,args1651491,ann1661492,doc1671493,body1681494,none63374]);
};
try {
if(--R.GAS > 0) {
$z14801481 = $f14861487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14861487,
"from":L[152]});
}
} catch($e14781479) {
if(R.isCont($e14781479)) {
var $ss14821483 = {"from":L[152],
"go":function(ann_DASH_check_DASH_temp29077) {
return $Hann_DASH_check_DASH_temp42776(ann_DASH_check_DASH_temp29077);
}};
$e14781479.stack[R.EXN_STACKHEIGHT++] = $ss14821483;
}
if(R.isPyretException($e14781479)) {
$e14781479.pyretStack.push(L[152]);
}
throw $e14781479;
}
var $ret14841485 = $Hann_DASH_check_DASH_temp42776($z14801481);
++R.GAS;
return $ret14841485;
};
},{"length":8});
var anf_extend2971462 = R.makeMethod(function(self1701474) {
return function(l17163,name1721475,body1731476,keyword_DASH_check1741477) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1],4,arguments);
}
var anf_fun29462 = G(A111,"s-id",L[151]);
var anf_fun2951473 = G(A111,"s-name",L[150]);
var $z14651466 = D;
var $f14711472 = function(_) {
return R.isFunction(anf_fun2951473)?anf_fun2951473.app(l17163,("nothing")):R.ffi.throwNonFunApp(L[149],anf_fun2951473,[l17163,("nothing")]);
};
try {
if(--R.GAS > 0) {
$z14651466 = $f14711472();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14711472,
"from":L[149]});
}
} catch($e14631464) {
if(R.isCont($e14631464)) {
var $ss14671468 = {"from":L[149],
"go":function(anf_arg29661) {
return $Hanf_arg42960(anf_arg29661,anf_fun29462,l17163);
}};
$e14631464.stack[R.EXN_STACKHEIGHT++] = $ss14671468;
}
if(R.isPyretException($e14631464)) {
$e14631464.pyretStack.push(L[149]);
}
throw $e14631464;
}
var $ret14691470 = $Hanf_arg42960($z14651466,anf_fun29462,l17163);
++R.GAS;
return $ret14691470;
};
},{"length":5});
var check_DASH_visitor1361432 = anf_extend2421457.extendWith({"s-block":anf_extend2831458,
"s-fun":anf_extend2861459,
"s-data":anf_extend2891460,
"s-lam":anf_extend2921461,
"s-check":anf_extend2971462});
var desugar_DASH_check1751416 = {"$var":D,
"$name":"desugar-check"};
var desugar_DASH_no_DASH_checks1761418 = {"$var":D,
"$name":"desugar-no-checks"};
var anf_assign3001417 = R.makeFunction(function(prog1771445) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[147],1,arguments);
}
var anf_fun2991456 = G(prog1771445,"visit",L[148]);
var $z14481449 = D;
var $f14541455 = function(_) {
return R.isFunction(anf_fun2991456)?anf_fun2991456.app(check_DASH_visitor1361432):R.ffi.throwNonFunApp(L[147],anf_fun2991456,[check_DASH_visitor1361432]);
};
try {
if(--R.GAS > 0) {
$z14481449 = $f14541455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14541455,
"from":L[147]});
}
} catch($e14461447) {
if(R.isCont($e14461447)) {
var $ss14501451 = {"from":L[147],
"go":function(ann_DASH_check_DASH_temp29859) {
return $Hann_DASH_check_DASH_temp43058(ann_DASH_check_DASH_temp29859);
}};
$e14461447.stack[R.EXN_STACKHEIGHT++] = $ss14501451;
}
if(R.isPyretException($e14461447)) {
$e14461447.pyretStack.push(L[147]);
}
throw $e14461447;
}
var $ret14521453 = $Hann_DASH_check_DASH_temp43058($z14481449);
++R.GAS;
return $ret14521453;
});
desugar_DASH_check1751416.$var = anf_assign3001417;
var anf_assign3031419 = R.makeFunction(function(prog1781433) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[145],1,arguments);
}
var anf_fun3021444 = G(prog1781433,"visit",L[146]);
var $z14361437 = D;
var $f14421443 = function(_) {
return R.isFunction(anf_fun3021444)?anf_fun3021444.app(no_DASH_checks_DASH_visitor1301431):R.ffi.throwNonFunApp(L[145],anf_fun3021444,[no_DASH_checks_DASH_visitor1301431]);
};
try {
if(--R.GAS > 0) {
$z14361437 = $f14421443();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14421443,
"from":L[145]});
}
} catch($e14341435) {
if(R.isCont($e14341435)) {
var $ss14381439 = {"from":L[145],
"go":function(ann_DASH_check_DASH_temp30157) {
return $Hann_DASH_check_DASH_temp43156(ann_DASH_check_DASH_temp30157);
}};
$e14341435.stack[R.EXN_STACKHEIGHT++] = $ss14381439;
}
if(R.isPyretException($e14341435)) {
$e14341435.pyretStack.push(L[145]);
}
throw $e14341435;
}
var $ret14401441 = $Hann_DASH_check_DASH_temp43156($z14361437);
++R.GAS;
return $ret14401441;
});
desugar_DASH_no_DASH_checks1761418.$var = anf_assign3031419;
var provides30442 = R.makeObject({"CheckInfo":CheckInfo711405.$var,
"is-CheckInfo":is_DASH_CheckInfo721407.$var,
"check-info":check_DASH_info74749.$var,
"is-check-info":is_DASH_check_DASH_info731409.$var,
"check-stmts-visitor":check_DASH_stmts_DASH_visitor78750,
"get-checks":get_DASH_checks861412.$var,
"create-check-block":create_DASH_check_DASH_block8784.$var,
"make-lam":make_DASH_lam88558.$var,
"no-checks-visitor":no_DASH_checks_DASH_visitor1301431,
"check-visitor":check_DASH_visitor1361432,
"desugar-check":desugar_DASH_check1751416.$var,
"desugar-no-checks":desugar_DASH_no_DASH_checks1761418.$var});
var anf_fun3051430 = G(builtins5,"current-checker",L[0]);
var $z14221423 = D;
var $f14281429 = function(_) {
return R.isFunction(anf_fun3051430)?anf_fun3051430.app():R.ffi.throwNonFunApp(L[0],anf_fun3051430,[]);
};
try {
if(--R.GAS > 0) {
$z14221423 = $f14281429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14281429,
"from":L[0]});
}
} catch($e14201421) {
if(R.isCont($e14201421)) {
var $ss14241425 = {"from":L[0],
"go":function(anf_bracket30640) {
return $Hanf_bracket43339(anf_bracket30640,CheckInfo6841,provides30442,nothing6);
}};
$e14201421.stack[R.EXN_STACKHEIGHT++] = $ss14241425;
}
if(R.isPyretException($e14201421)) {
$e14201421.pyretStack.push(L[0]);
}
throw $e14201421;
}
var $ret14261427 = $Hanf_bracket43339($z14221423,CheckInfo6841,provides30442,nothing6);
++R.GAS;
return $ret14261427;
},function(moduleVal) {
R.modules["$src/arr/compiler/desugar-check.arr29"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/desugar.arr',["trove/ast",
"trove/parse-pyret",
"compiler/compile-structs.arr",
"compiler/ast-util.arr",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($A11332,$PP31433,$C51534,$U71635,$arrays91736,$lists111837,$option131938,$error152039,$sets172140) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/desugar.arr31"]) {
return R.modules["$src/arr/compiler/desugar.arr31"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/desugar.arr";
var D = R.undefined;
var L = [[M,20,17,335,20,29,347],
[M,17,2,293,17,21,312],
[M,16,0,280,18,3,316],
[M,17,4,295,17,21,312],
[M,17,15,306,17,20,311],
[M,17,9,300,17,13,304],
[M,13,2,202,13,74,274],
[M,12,0,183,14,3,278],
[M,13,4,204,13,74,274],
[M,13,17,217,13,28,228],
[M,13,38,238,13,49,249],
[M,13,62,262,13,73,273],
[M,13,51,251,13,73,273],
[M,13,30,230,13,49,249],
[M,13,10,210,13,28,228],
[M,20,31,349,20,43,361],
[M,20,45,363,20,57,375],
[M,20,0,318,20,58,376],
[M,10,0,160,610,3,21962],
[M,363,0,10734,610,3,21962],
[M,364,2,10770,568,5,20406],
[M,567,40,20387,567,52,20399],
[M,566,4,20254,566,96,20346],
[M,565,4,20177,565,76,20249],
[M,565,29,20202,565,36,20209],
[M,563,4,20058,565,0,20173],
[M,553,4,19545,562,9,20053],
[M,554,6,19600,562,9,20053],
[M,558,8,19803,561,113,20043],
[M,559,34,19859,559,70,19895],
[M,559,34,19859,559,41,19866],
[M,559,10,19835,559,17,19842],
[M,555,8,19645,557,57,19794],
[M,556,34,19703,556,65,19734],
[M,556,34,19703,556,41,19710],
[M,556,10,19679,556,17,19686],
[M,552,4,19480,552,64,19540],
[M,552,37,19513,552,63,19539],
[M,552,37,19513,552,47,19523],
[M,552,26,19502,552,33,19509],
[M,551,4,19453,551,26,19475],
[M,550,4,19427,550,25,19448],
[M,549,4,19336,550,0,19423],
[M,549,40,19372,549,50,19382],
[M,549,29,19361,549,36,19368],
[M,548,4,19310,548,25,19331],
[M,547,4,19281,547,28,19305],
[M,546,4,19246,546,34,19276],
[M,545,4,19217,545,28,19241],
[M,544,4,19192,544,24,19212],
[M,468,4,15890,543,9,19187],
[M,469,6,15926,543,9,19187],
[M,464,4,15594,467,64,15885],
[M,465,15,15651,465,36,15672],
[M,465,28,15664,465,35,15671],
[M,465,15,15651,465,27,15663],
[M,463,4,15499,463,94,15589],
[M,463,48,15543,463,65,15560],
[M,463,34,15529,463,44,15539],
[M,462,4,15428,462,70,15494],
[M,462,47,15471,462,54,15478],
[M,461,4,15361,461,66,15423],
[M,461,48,15405,461,65,15422],
[M,461,30,15387,461,40,15397],
[M,459,4,15206,460,102,15356],
[M,460,28,15282,460,45,15299],
[M,456,4,15025,458,58,15201],
[M,457,28,15089,457,45,15106],
[M,454,4,14944,455,36,15020],
[M,452,4,14833,453,78,14939],
[M,453,50,14911,453,75,14936],
[M,453,43,14904,453,76,14937],
[M,453,30,14891,453,39,14900],
[M,450,4,14757,451,36,14828],
[M,448,4,14652,449,77,14752],
[M,449,50,14725,449,74,14749],
[M,449,43,14718,449,75,14750],
[M,449,30,14705,449,39,14714],
[M,441,4,14304,447,47,14647],
[M,442,6,14337,442,33,14364],
[M,409,4,12842,440,70,14299],
[M,439,44,14173,439,68,14197],
[M,439,44,14173,439,54,14183],
[M,439,6,14135,439,19,14148],
[M,410,6,12923,438,9,14128],
[M,422,8,13497,437,11,14118],
[M,431,10,13861,436,59,14106],
[M,432,46,13957,432,54,13965],
[M,423,10,13527,430,59,13850],
[M,424,12,13600,424,61,13649],
[M,411,8,12954,421,11,13488],
[M,413,15,13042,413,66,13093],
[M,413,25,13052,413,57,13084],
[M,413,33,13060,413,41,13068],
[M,413,33,13060,413,39,13066],
[M,413,15,13042,413,24,13051],
[M,401,4,12538,408,50,12837],
[M,402,6,12574,407,11,12786],
[M,402,18,12586,407,11,12786],
[M,403,10,12622,406,13,12774],
[M,404,12,12660,405,69,12760],
[M,405,34,12725,405,49,12740],
[M,405,14,12705,405,29,12720],
[M,391,4,12146,400,52,12533],
[M,392,6,12184,399,9,12480],
[M,392,18,12196,399,9,12480],
[M,393,8,12230,398,11,12470],
[M,396,10,12366,397,64,12458],
[M,397,29,12423,397,44,12438],
[M,397,12,12406,397,24,12418],
[M,394,10,12263,395,64,12355],
[M,395,29,12320,395,44,12335],
[M,395,12,12303,395,24,12315],
[M,383,4,11806,390,76,12141],
[M,390,27,12092,390,55,12120],
[M,390,27,12092,390,36,12101],
[M,390,6,12071,390,23,12088],
[M,384,6,11849,389,9,12064],
[M,385,8,11884,388,11,12054],
[M,387,10,12003,387,49,12042],
[M,386,10,11919,386,83,11992],
[M,386,66,11975,386,82,11991],
[M,386,42,11951,386,55,11964],
[M,382,4,11766,382,39,11801],
[M,381,4,11700,381,65,11761],
[M,381,48,11744,381,64,11760],
[M,381,30,11726,381,38,11734],
[M,379,4,11599,380,56,11695],
[M,380,23,11662,380,42,11681],
[M,380,6,11645,380,13,11652],
[M,377,4,11426,378,121,11594],
[M,378,20,11493,378,42,11515],
[M,378,20,11493,378,28,11501],
[M,378,6,11479,378,16,11489],
[M,375,4,11243,376,126,11421],
[M,376,25,11320,376,47,11342],
[M,376,25,11320,376,33,11328],
[M,376,6,11301,376,13,11308],
[M,373,4,11162,374,48,11238],
[M,374,25,11215,374,47,11237],
[M,374,25,11215,374,33,11223],
[M,374,6,11196,374,18,11208],
[M,371,4,11090,372,44,11157],
[M,372,21,11134,372,43,11156],
[M,372,21,11134,372,29,11142],
[M,369,4,11034,370,24,11085],
[M,367,4,10963,368,43,11029],
[M,368,19,11005,368,42,11028],
[M,368,19,11005,368,28,11014],
[M,368,6,10992,368,15,11001],
[M,365,4,10794,366,114,10958],
[M,366,20,10864,366,40,10884],
[M,366,6,10850,366,16,10860],
[M,363,25,10759,363,31,10765],
[M,355,0,10515,361,3,10732],
[M,356,2,10548,360,5,10728],
[M,359,57,10712,359,66,10721],
[M,357,4,10569,358,50,10654],
[M,358,33,10637,358,49,10653],
[M,358,6,10610,358,14,10618],
[M,355,22,10537,355,28,10543],
[M,348,0,10383,353,3,10513],
[M,349,2,10438,352,5,10509],
[M,351,4,10480,351,27,10503],
[M,351,22,10498,351,26,10502],
[M,350,4,10461,350,18,10475],
[M,348,23,10406,348,32,10415],
[M,348,41,10424,348,50,10433],
[M,284,0,8859,346,3,10381],
[M,293,2,9177,305,5,9616],
[M,294,4,9198,303,9,9582],
[M,295,9,9230,295,27,9248],
[M,285,2,8887,292,5,9174],
[M,286,4,8910,286,44,8950],
[M,273,0,8503,282,3,8857],
[M,274,37,8580,274,51,8594],
[M,259,0,8097,271,3,8501],
[M,260,5,8149,260,23,8167],
[M,247,0,7702,257,3,8095],
[M,248,43,7773,248,51,7781],
[M,248,20,7750,255,7,8019],
[M,249,9,7819,249,27,7837],
[M,243,0,7632,245,3,7700],
[M,244,2,7656,244,42,7696],
[M,244,2,7656,244,11,7665],
[M,232,0,7244,241,3,7630],
[M,233,2,7270,240,5,7626],
[M,239,38,7610,239,47,7619],
[M,236,4,7459,237,64,7557],
[M,237,24,7517,237,36,7529],
[M,237,24,7517,237,42,7535],
[M,237,6,7499,237,20,7513],
[M,234,4,7293,235,102,7454],
[M,235,24,7376,235,36,7388],
[M,235,24,7376,235,42,7394],
[M,235,6,7358,235,20,7372],
[M,225,0,7081,230,3,7242],
[M,226,2,7114,229,5,7238],
[M,227,4,7144,228,52,7232],
[M,228,33,7213,228,45,7225],
[M,228,33,7213,228,51,7231],
[M,228,6,7186,228,24,7204],
[M,192,0,6000,223,3,7079],
[M,193,2,6056,193,32,6086],
[M,181,0,5713,190,3,5998],
[M,182,2,5743,189,5,5994],
[M,183,4,5771,188,84,5988],
[M,187,10,5885,187,27,5902],
[M,187,10,5885,187,17,5892],
[M,185,8,5845,185,22,5859],
[M,170,0,5323,179,3,5711],
[M,171,20,5389,171,32,5401],
[M,171,20,5389,171,39,5408],
[M,171,2,5371,178,5,5707],
[M,172,4,5447,172,29,5472],
[M,170,37,5360,170,43,5366],
[M,157,0,4947,168,3,5321],
[M,158,19,4989,158,32,5002],
[M,159,24,5027,159,38,5041],
[M,160,24,5066,160,38,5080],
[M,161,24,5105,161,39,5120],
[M,162,24,5145,162,41,5162],
[M,163,24,5187,163,44,5207],
[M,164,25,5233,164,46,5254],
[M,165,25,5280,165,43,5298],
[M,166,8,5307,166,12,5311],
[M,165,10,5265,165,24,5279],
[M,164,10,5218,164,24,5232],
[M,163,10,5173,163,23,5186],
[M,162,10,5131,162,23,5144],
[M,161,10,5091,161,23,5104],
[M,160,10,5052,160,23,5065],
[M,159,10,5013,159,23,5026],
[M,158,5,4975,158,18,4988],
[M,125,0,3881,154,3,4944],
[M,126,29,3948,126,49,3968],
[M,99,0,3148,123,3,3879],
[M,100,2,3199,100,25,3222],
[M,94,0,3036,97,3,3146],
[M,95,2,3060,95,27,3085],
[M,95,6,3064,95,21,3079],
[M,92,0,2980,92,54,3034],
[M,92,43,3023,92,52,3032],
[M,92,20,3000,92,28,3008],
[M,69,0,1952,90,3,2978],
[M,85,2,2730,89,5,2974],
[M,88,57,2952,88,72,2967],
[M,86,4,2760,87,75,2894],
[M,87,56,2875,87,68,2887],
[M,87,56,2875,87,74,2893],
[M,87,6,2825,87,17,2836],
[M,69,23,1975,69,32,1984],
[M,69,49,2001,69,69,2021],
[M,50,0,1336,67,3,1950],
[M,51,2,1376,66,5,1946],
[M,64,4,1861,65,54,1940],
[M,65,18,1904,65,34,1920],
[M,65,6,1892,65,14,1900],
[M,62,4,1784,63,47,1856],
[M,63,20,1829,63,46,1855],
[M,63,20,1829,63,30,1839],
[M,63,6,1815,63,16,1825],
[M,60,4,1695,61,58,1779],
[M,61,17,1738,61,34,1755],
[M,61,6,1727,61,13,1734],
[M,58,4,1597,59,65,1690],
[M,59,19,1644,59,40,1665],
[M,59,19,1644,59,27,1652],
[M,59,6,1631,59,15,1640],
[M,56,4,1482,57,71,1592],
[M,57,19,1540,57,40,1561],
[M,57,19,1540,57,27,1548],
[M,57,6,1527,57,15,1536],
[M,55,4,1456,55,25,1477],
[M,54,4,1432,54,23,1451],
[M,53,4,1415,53,16,1427],
[M,52,4,1396,52,18,1410],
[M,50,21,1357,50,26,1362],
[M,47,0,1240,49,3,1335],
[M,48,25,1312,48,36,1323],
[M,48,25,1312,48,43,1330],
[M,48,37,1324,48,42,1329],
[M,48,17,1304,48,23,1310],
[M,48,12,1299,48,15,1302],
[M,48,2,1289,48,11,1298],
[M,47,24,1264,47,32,1272],
[M,43,0,1086,45,3,1238],
[M,44,46,1172,44,62,1188],
[M,44,46,1172,44,56,1182],
[M,44,39,1165,44,107,1233],
[M,44,2,1128,44,14,1140],
[M,40,0,961,42,3,1085],
[M,41,53,1041,41,69,1057],
[M,41,53,1041,41,63,1051],
[M,41,46,1034,41,92,1080],
[M,41,2,990,41,14,1002],
[M,37,0,859,39,3,960],
[M,38,43,942,38,56,955],
[M,38,2,901,38,14,913],
[M,34,0,772,36,3,858],
[M,35,30,838,35,45,853],
[M,35,30,838,35,37,845],
[M,31,0,652,33,3,771],
[M,32,51,732,32,67,748],
[M,32,51,732,32,61,742],
[M,32,44,725,32,85,766],
[M,32,2,683,32,14,695],
[M,25,0,440,30,3,651],
[M,26,25,502,26,52,529],
[M,26,41,518,26,48,525],
[M,26,25,502,26,37,514],
[M,26,18,495,26,53,530],
[M,26,2,479,26,14,491],
[M,23,0,405,23,33,438],
[M,23,26,431,23,31,436],
[M,23,16,421,23,22,427],
[M,22,0,378,22,26,404],
[M,22,11,389,22,21,399],
[M,578,2,20778,578,21,20797],
[M,578,8,20784,578,15,20791],
[M,577,7,20741,577,41,20775],
[M,577,25,20759,577,39,20773],
[M,577,25,20759,577,33,20767],
[M,577,15,20749,577,21,20755],
[M,576,7,20657,576,83,20733],
[M,576,18,20668,576,36,20686],
[M,575,6,20576,575,79,20649],
[M,575,16,20586,575,45,20615],
[M,575,16,20586,575,32,20602],
[M,573,4,20516,573,53,20565],
[M,573,32,20544,573,40,20552],
[M,572,4,20473,572,41,20510],
[M,572,23,20492,572,31,20500],
[M,571,13,20445,571,34,20466],
[M,570,6,20420,570,17,20431],
[M,310,20,9720,310,37,9737],
[M,310,20,9720,310,34,9734],
[M,310,10,9710,310,16,9716],
[M,309,7,9666,309,40,9699],
[M,309,25,9684,309,38,9697],
[M,309,25,9684,309,35,9694],
[M,309,15,9674,309,21,9680],
[M,308,6,9648,308,16,9658],
[M,307,6,9630,307,17,9641],
[M,206,6,6455,206,19,6468],
[M,206,6,6455,206,13,6462],
[M,205,6,6437,205,15,6446],
[M,202,6,6386,202,17,6397],
[M,579,2,20800,579,21,20819],
[M,579,8,20806,579,15,20813],
[M,584,2,20987,584,32,21017],
[M,580,11,20831,580,67,20887],
[M,580,22,20842,580,37,20857],
[M,580,22,20842,580,35,20855],
[M,584,2,20987,584,12,20997],
[M,584,15,21000,584,21,21006],
[M,585,2,21020,585,44,21062],
[M,585,2,21020,585,18,21036],
[M,585,21,21039,585,27,21045],
[M,587,2,21068,587,32,21098],
[M,588,2,21101,591,93,21299],
[M,588,2,21101,588,11,21110],
[M,590,44,21175,590,63,21194],
[M,590,44,21175,590,52,21183],
[M,590,34,21165,590,40,21171],
[M,590,23,21154,590,30,21161],
[M,590,12,21143,590,19,21150],
[M,590,4,21135,591,92,21298],
[M,589,7,21118,589,16,21127],
[M,590,34,21165,590,64,21195],
[M,590,23,21154,590,73,21204],
[M,591,57,21263,591,68,21274],
[M,591,46,21252,591,53,21259],
[M,591,29,21235,591,88,21294],
[M,591,16,21222,591,25,21231],
[M,591,8,21214,591,90,21296],
[M,591,70,21276,591,86,21292],
[M,591,46,21252,591,87,21293],
[M,591,16,21222,591,89,21295],
[M,590,12,21143,591,91,21297],
[M,589,7,21118,591,93,21299],
[M,593,2,21303,593,47,21348],
[M,594,2,21351,609,0,21956],
[M,594,2,21351,594,11,21360],
[M,594,15,21364,594,55,21404],
[M,580,22,20842,580,48,20868],
[M,580,22,20842,580,44,20864],
[M,580,22,20842,580,57,20877],
[M,576,18,20668,576,52,20702],
[M,576,18,20668,576,42,20692],
[M,576,59,20709,576,78,20728],
[M,576,18,20668,576,58,20708],
[M,575,58,20628,575,77,20647],
[M,575,16,20586,575,57,20627],
[M,575,16,20586,575,51,20621],
[M,310,2,9702,310,38,9738],
[M,313,6,9774,313,13,9781],
[M,314,21,9804,314,28,9811],
[M,314,6,9789,314,30,9813],
[M,311,2,9741,315,5,9819],
[M,316,2,9822,316,28,9848],
[M,316,18,9838,316,28,9848],
[M,317,2,9851,317,26,9875],
[M,317,2,9851,317,21,9870],
[M,317,2,9851,317,19,9868],
[M,317,2,9851,317,12,9861],
[M,321,6,9913,321,13,9920],
[M,322,6,9928,322,28,9950],
[M,319,2,9879,323,5,9956],
[M,324,2,9959,324,29,9986],
[M,324,19,9976,324,29,9986],
[M,325,2,9989,325,27,10014],
[M,325,2,9989,325,22,10009],
[M,325,2,9989,325,20,10007],
[M,325,2,9989,325,13,10000],
[M,329,6,10052,329,13,10059],
[M,331,8,10083,331,15,10090],
[M,330,6,10067,333,7,10115],
[M,332,8,10100,332,15,10107],
[M,327,2,10018,334,5,10121],
[M,335,2,10124,335,84,10206],
[M,335,2,10124,335,35,10157],
[M,335,15,10137,335,34,10156],
[M,335,2,10124,335,14,10136],
[M,335,50,10172,335,57,10179],
[M,335,39,10161,335,46,10168],
[M,335,66,10188,335,73,10195],
[M,335,59,10181,335,83,10205],
[M,335,75,10197,335,82,10204],
[M,335,39,10161,335,84,10206],
[M,339,6,10248,339,28,10270],
[M,339,6,10248,339,13,10255],
[M,341,8,10294,341,15,10301],
[M,340,6,10278,342,7,10309],
[M,337,2,10214,342,8,10310],
[M,343,2,10313,343,29,10340],
[M,343,19,10330,343,29,10340],
[M,344,2,10343,344,27,10368],
[M,344,2,10343,344,22,10363],
[M,344,2,10343,344,20,10361],
[M,344,2,10343,344,13,10354],
[M,208,26,6510,208,45,6529],
[M,208,26,6510,208,33,6517],
[M,208,8,6492,208,22,6506],
[M,207,6,6476,209,7,6606],
[M,208,58,6542,208,66,6550],
[M,208,47,6531,208,54,6538],
[M,208,68,6552,208,76,6560],
[M,208,93,6577,208,106,6590],
[M,208,93,6577,208,100,6584],
[M,208,78,6562,208,87,6571],
[M,208,47,6531,208,113,6597],
[M,208,8,6492,208,114,6598],
[M,210,6,6614,210,19,6627],
[M,210,6,6614,210,13,6621],
[M,203,2,6400,211,5,6633],
[M,214,2,6667,221,77,7074],
[M,212,7,6641,212,25,6659],
[M,212,7,6641,212,23,6657],
[M,212,7,6641,212,17,6651],
[M,214,2,6667,214,33,6698],
[M,214,13,6678,214,32,6697],
[M,214,2,6667,214,12,6677],
[M,215,26,6752,215,39,6765],
[M,215,26,6752,215,33,6759],
[M,215,6,6732,215,18,6744],
[M,214,53,6718,216,5,6772],
[M,214,37,6702,214,49,6714],
[M,215,6,6732,215,40,6766],
[M,217,26,6800,217,42,6816],
[M,217,36,6810,217,41,6815],
[M,217,26,6800,217,32,6806],
[M,217,15,6789,217,22,6796],
[M,217,4,6778,217,11,6785],
[M,217,15,6789,217,53,6827],
[M,219,30,6894,219,49,6913],
[M,219,30,6894,219,37,6901],
[M,219,12,6876,219,26,6890],
[M,218,19,6856,220,11,6994],
[M,218,8,6845,218,15,6852],
[M,217,55,6829,221,75,7072],
[M,219,62,6926,219,70,6934],
[M,219,51,6915,219,58,6922],
[M,219,72,6936,219,80,6944],
[M,219,97,6961,219,110,6974],
[M,219,97,6961,219,104,6968],
[M,219,82,6946,219,91,6955],
[M,219,51,6915,219,117,6981],
[M,219,12,6876,219,118,6982],
[M,218,8,6845,220,12,6995],
[M,221,19,7016,221,27,7024],
[M,221,8,7005,221,15,7012],
[M,221,29,7026,221,37,7034],
[M,221,54,7051,221,67,7064],
[M,221,54,7051,221,61,7058],
[M,221,39,7036,221,48,7045],
[M,221,8,7005,221,74,7071],
[M,217,4,6778,221,76,7073],
[M,214,37,6702,221,77,7074],
[M,567,20,20367,567,53,20400],
[M,559,21,19846,559,71,19896],
[M,561,18,19948,561,110,20040],
[M,561,27,19957,561,109,20039],
[M,561,50,19980,561,104,20034],
[M,561,79,20009,561,88,20018],
[M,561,58,19988,561,63,19993],
[M,561,50,19980,561,57,19987],
[M,561,18,19948,561,26,19956],
[M,560,19,19917,560,28,19926],
[M,560,12,19910,561,112,20042],
[M,560,19,19917,561,111,20041],
[M,556,21,19690,556,66,19735],
[M,557,32,19769,557,54,19791],
[M,557,32,19769,557,40,19777],
[M,557,19,19756,557,28,19765],
[M,557,12,19749,557,56,19793],
[M,557,19,19756,557,55,19792],
[M,475,8,16158,542,13,19177],
[M,492,30,16885,492,48,16903],
[M,497,30,17091,497,48,17109],
[M,516,12,18003,516,40,18031],
[M,502,12,17311,515,15,17990],
[M,503,14,17347,503,44,17377],
[M,533,12,18809,533,41,18838],
[M,519,12,18106,532,15,18796],
[M,520,14,18142,520,46,18174],
[M,536,12,18911,536,43,18942],
[M,541,18,19133,541,48,19163],
[M,535,18,18886,535,30,18898],
[M,518,18,18079,518,32,18093],
[M,501,18,17285,501,31,17298],
[M,496,18,17047,496,31,17060],
[M,491,13,16841,491,26,16854],
[M,490,27,16807,490,47,16827],
[M,489,25,16757,489,47,16779],
[M,488,24,16710,488,45,16731],
[M,480,10,16420,487,13,16685],
[M,481,15,16464,481,29,16478],
[M,481,15,16464,481,24,16473],
[M,477,10,16283,479,13,16409],
[M,478,34,16334,478,52,16352],
[M,478,23,16323,478,30,16330],
[M,478,12,16312,478,19,16319],
[M,476,10,16178,476,104,16272],
[M,476,35,16203,476,43,16211],
[M,476,24,16192,476,31,16199],
[M,470,8,15966,474,16,16149],
[M,471,28,16011,471,46,16029],
[M,492,50,16905,492,69,16924],
[M,492,12,16867,495,18,17028],
[M,493,14,16940,495,17,17027],
[M,494,41,16994,494,55,17008],
[M,494,16,16969,494,28,16981],
[M,497,50,17111,497,69,17130],
[M,497,12,17073,500,18,17266],
[M,498,14,17146,500,17,17265],
[M,499,71,17230,499,85,17244],
[M,499,46,17205,499,58,17217],
[M,499,39,17198,499,87,17246],
[M,499,16,17175,499,28,17187],
[M,499,46,17205,499,86,17245],
[M,517,12,18044,517,28,18060],
[M,504,14,17392,514,17,17974],
[M,508,16,17628,513,79,17956],
[M,509,41,17685,509,69,17713],
[M,509,54,17698,509,68,17712],
[M,505,16,17435,507,80,17611],
[M,506,41,17487,506,69,17515],
[M,506,54,17500,506,68,17514],
[M,504,26,17404,504,39,17417],
[M,511,60,17810,511,77,17827],
[M,511,60,17810,511,68,17818],
[M,511,46,17796,511,58,17808],
[M,511,29,17779,511,42,17792],
[M,511,22,17772,511,79,17829],
[M,510,20,17735,510,31,17746],
[M,511,29,17779,511,78,17828],
[M,512,22,17853,512,43,17874],
[M,512,29,17860,512,42,17873],
[M,510,20,17735,512,44,17875],
[M,513,20,17897,513,78,17955],
[M,513,65,17942,513,77,17954],
[M,513,32,17909,513,48,17925],
[M,513,32,17909,513,46,17923],
[M,507,20,17551,507,79,17610],
[M,507,66,17597,507,78,17609],
[M,507,32,17563,507,48,17579],
[M,507,32,17563,507,46,17577],
[M,506,71,17517,506,83,17529],
[M,534,12,18851,534,28,18867],
[M,521,14,18189,531,17,18780],
[M,525,16,18429,530,81,18762],
[M,526,42,18487,526,70,18515],
[M,526,55,18500,526,69,18514],
[M,522,16,18232,524,82,18412],
[M,523,42,18285,523,70,18313],
[M,523,55,18298,523,69,18312],
[M,521,26,18201,521,39,18214],
[M,528,61,18613,528,82,18634],
[M,528,68,18620,528,81,18633],
[M,528,46,18598,528,59,18611],
[M,528,29,18581,528,42,18594],
[M,528,22,18574,528,84,18636],
[M,527,20,18537,527,31,18548],
[M,528,29,18581,528,83,18635],
[M,529,22,18660,529,40,18678],
[M,529,22,18660,529,30,18668],
[M,527,20,18537,529,41,18679],
[M,530,20,18701,530,80,18761],
[M,530,66,18747,530,79,18760],
[M,530,32,18713,530,48,18729],
[M,530,32,18713,530,46,18727],
[M,524,20,18350,524,81,18411],
[M,524,67,18397,524,80,18410],
[M,524,32,18362,524,48,18378],
[M,524,32,18362,524,46,18376],
[M,523,72,18315,523,85,18328],
[M,537,30,18973,537,58,19001],
[M,537,43,18986,537,57,19000],
[M,537,12,18955,539,15,19098],
[M,538,27,19053,538,42,19068],
[M,538,22,19048,538,25,19051],
[M,538,14,19040,538,21,19047],
[M,537,67,19010,537,80,19023],
[M,538,44,19070,538,55,19081],
[M,541,12,19127,541,48,19163],
[M,482,35,16515,482,63,16543],
[M,482,54,16534,482,62,16542],
[M,483,20,16596,483,31,16607],
[M,482,17,16497,482,34,16514],
[M,482,17,16497,482,23,16503],
[M,485,18,16644,485,29,16655],
[M,482,66,16546,482,95,16575],
[M,482,85,16565,482,94,16574],
[M,482,35,16515,482,95,16575],
[M,478,23,16323,478,58,16358],
[M,478,73,16373,478,92,16392],
[M,478,60,16360,478,94,16394],
[M,478,67,16367,478,93,16393],
[M,476,45,16213,476,53,16221],
[M,476,83,16251,476,92,16260],
[M,476,70,16238,476,79,16247],
[M,476,55,16223,476,64,16232],
[M,476,70,16238,476,93,16261],
[M,471,48,16031,471,67,16050],
[M,472,12,16064,474,15,16148],
[M,473,25,16102,473,38,16115],
[M,473,14,16091,473,21,16098],
[M,473,40,16117,473,54,16131],
[M,465,6,15642,465,54,15690],
[M,465,15,15651,465,40,15676],
[M,466,32,15723,466,40,15731],
[M,466,21,15712,466,28,15719],
[M,466,42,15733,466,62,15753],
[M,466,55,15746,466,61,15752],
[M,466,42,15733,466,54,15745],
[M,466,42,15733,466,80,15771],
[M,466,42,15733,466,66,15757],
[M,466,82,15773,466,98,15789],
[M,466,104,15795,466,122,15813],
[M,466,6,15697,466,129,15820],
[M,467,17,15838,467,35,15856],
[M,467,6,15827,467,13,15834],
[M,467,37,15858,467,63,15884],
[M,463,67,15562,463,93,15588],
[M,463,67,15562,463,77,15572],
[M,460,47,15301,460,80,15334],
[M,460,47,15301,460,59,15313],
[M,460,82,15336,460,101,15355],
[M,457,47,15108,457,80,15141],
[M,457,47,15108,457,59,15120],
[M,458,28,15171,458,55,15198],
[M,458,21,15164,458,56,15199],
[M,458,8,15151,458,17,15160],
[M,458,8,15151,458,57,15200],
[M,453,30,14891,453,77,14938],
[M,449,30,14705,449,76,14751],
[M,443,29,14394,443,47,14412],
[M,445,68,14505,445,86,14523],
[M,445,61,14498,445,106,14543],
[M,445,48,14485,445,57,14494],
[M,445,34,14471,445,46,14483],
[M,445,17,14454,445,30,14467],
[M,445,10,14447,445,109,14546],
[M,444,8,14422,444,19,14433],
[M,445,88,14525,445,105,14542],
[M,445,48,14485,445,107,14544],
[M,445,17,14454,445,108,14545],
[M,446,30,14578,446,47,14595],
[M,446,23,14571,446,48,14596],
[M,446,10,14558,446,19,14567],
[M,446,10,14558,446,49,14597],
[M,444,8,14422,446,50,14598],
[M,447,8,14608,447,46,14646],
[M,447,33,14633,447,45,14645],
[M,447,17,14617,447,23,14623],
[M,439,70,14199,439,98,14227],
[M,439,70,14199,439,82,14211],
[M,440,8,14237,440,34,14263],
[M,440,8,14237,440,18,14247],
[M,440,36,14265,440,69,14298],
[M,432,12,13923,432,61,13972],
[M,436,15,14062,436,38,14085],
[M,433,12,13985,433,33,14006],
[M,435,20,14046,436,58,14105],
[M,435,20,14046,436,42,14089],
[M,429,14,13754,429,49,13789],
[M,429,14,13754,429,25,13765],
[M,425,12,13662,425,23,13673],
[M,430,15,13806,430,38,13829],
[M,429,50,13790,430,58,13849],
[M,429,50,13790,430,42,13833],
[M,413,68,13095,413,73,13100],
[M,414,44,13145,414,65,13166],
[M,414,44,13145,414,51,13152],
[M,414,25,13126,414,39,13140],
[M,414,18,13119,414,99,13200],
[M,417,15,13254,417,67,13306],
[M,417,25,13264,417,58,13297],
[M,417,33,13272,417,41,13280],
[M,417,33,13272,417,39,13278],
[M,417,15,13254,417,24,13263],
[M,414,67,13168,414,97,13198],
[M,414,25,13126,414,98,13199],
[M,417,69,13308,417,74,13313],
[M,418,44,13358,418,66,13380],
[M,418,44,13358,418,51,13365],
[M,418,25,13339,418,39,13353],
[M,418,18,13332,418,115,13429],
[M,418,68,13382,418,113,13427],
[M,418,25,13339,418,114,13428],
[M,408,31,12818,408,49,12836],
[M,408,6,12793,408,16,12803],
[M,405,51,12742,405,68,12759],
[M,400,33,12514,400,51,12532],
[M,400,6,12487,400,18,12499],
[M,397,46,12440,397,63,12457],
[M,395,46,12337,395,63,12354],
[M,390,57,12122,390,75,12140],
[M,378,44,11517,378,60,11533],
[M,378,67,11540,378,85,11558],
[M,378,87,11560,378,120,11593],
[M,376,49,11344,376,65,11360],
[M,376,72,11367,376,90,11385],
[M,376,92,11387,376,125,11420],
[M,366,42,10886,366,64,10908],
[M,366,66,10910,366,91,10935],
[M,366,66,10910,366,75,10919],
[M,366,93,10937,366,113,10957],
[M,359,20,10675,359,67,10722],
[M,296,8,9258,296,39,9289],
[M,302,8,9559,302,21,9572],
[M,297,8,9298,297,48,9338],
[M,299,19,9396,299,27,9404],
[M,299,8,9385,299,15,9392],
[M,298,17,9356,298,37,9376],
[M,299,29,9406,299,59,9436],
[M,299,34,9411,299,50,9427],
[M,300,23,9476,300,54,9507],
[M,300,34,9487,300,50,9503],
[M,300,23,9476,300,30,9483],
[M,300,12,9465,300,19,9472],
[M,299,61,9438,299,70,9447],
[M,300,12,9465,300,78,9531],
[M,300,56,9509,300,77,9530],
[M,299,8,9385,300,85,9538],
[M,288,11,8996,288,23,9008],
[M,288,4,8989,288,26,9011],
[M,287,13,8964,287,33,8984],
[M,289,7,9019,289,23,9035],
[M,289,25,9037,289,47,9059],
[M,289,25,9037,289,32,9044],
[M,290,21,9081,290,29,9089],
[M,290,10,9070,290,17,9077],
[M,290,54,9114,290,93,9153],
[M,290,71,9131,290,92,9152],
[M,290,54,9114,290,61,9121],
[M,290,39,9099,290,48,9108],
[M,290,10,9070,290,100,9160],
[M,274,2,8545,274,52,8595],
[M,276,2,8630,281,5,8853],
[M,278,4,8685,280,105,8847],
[M,280,17,8759,280,25,8767],
[M,280,6,8748,280,13,8755],
[M,279,19,8720,279,40,8741],
[M,277,4,8654,277,30,8680],
[M,275,11,8607,275,31,8627],
[M,280,50,8792,280,98,8840],
[M,280,76,8818,280,97,8839],
[M,280,76,8818,280,91,8833],
[M,280,58,8800,280,74,8816],
[M,280,35,8777,280,44,8786],
[M,261,4,8173,261,35,8204],
[M,264,20,8343,264,32,8355],
[M,264,20,8343,264,37,8360],
[M,262,15,8220,262,23,8228],
[M,262,4,8209,262,11,8216],
[M,262,25,8230,262,49,8254],
[M,262,32,8237,262,48,8253],
[M,262,66,8271,262,102,8307],
[M,262,82,8287,262,98,8303],
[M,262,51,8256,262,60,8265],
[M,262,4,8209,262,109,8314],
[M,264,4,8327,264,41,8364],
[M,248,53,7783,248,61,7791],
[M,248,38,7768,248,62,7792],
[M,248,2,7732,255,7,8019],
[M,256,7,8027,256,37,8057],
[M,256,7,8027,256,35,8055],
[M,256,7,8027,256,27,8047],
[M,256,39,8059,256,70,8090],
[M,256,39,8059,256,68,8088],
[M,256,39,8059,256,60,8080],
[M,250,8,7847,250,33,7872],
[M,253,23,7980,253,43,8000],
[M,253,33,7990,253,42,7999],
[M,253,13,7970,253,21,7978],
[M,251,13,7886,251,40,7913],
[M,251,31,7904,251,39,7912],
[M,251,18,7891,251,29,7902],
[M,251,42,7915,251,70,7943],
[M,251,60,7933,251,69,7942],
[M,251,47,7920,251,58,7931],
[M,251,8,7881,251,71,7944],
[M,253,8,7965,253,44,8001],
[M,244,37,7691,244,41,7695],
[M,244,19,7673,244,36,7690],
[M,244,2,7656,244,14,7668],
[M,244,19,7673,244,42,7696],
[M,239,12,7584,239,48,7620],
[M,237,44,7537,237,56,7549],
[M,237,44,7537,237,63,7556],
[M,235,57,7409,235,100,7452],
[M,235,57,7409,235,67,7419],
[M,235,44,7396,235,56,7408],
[M,235,44,7396,235,101,7453],
[M,194,2,6089,194,37,6124],
[M,194,17,6104,194,24,6111],
[M,195,26,6151,195,34,6159],
[M,195,15,6140,195,22,6147],
[M,195,36,6161,195,44,6169],
[M,195,2,6127,195,78,6203],
[M,195,46,6171,195,55,6180],
[M,197,8,6238,197,41,6271],
[M,197,24,6254,197,35,6265],
[M,197,8,6238,197,20,6250],
[M,196,18,6222,198,7,6279],
[M,196,2,6206,196,14,6218],
[M,199,17,6298,199,50,6331],
[M,199,28,6309,199,39,6320],
[M,199,17,6298,199,24,6305],
[M,199,6,6287,199,13,6294],
[M,199,52,6333,199,84,6365],
[M,199,6,6287,199,85,6366],
[M,188,22,5926,188,30,5934],
[M,188,10,5914,188,17,5921],
[M,188,41,5945,188,53,5957],
[M,188,32,5936,188,54,5958],
[M,188,32,5936,188,40,5944],
[M,188,10,5914,188,82,5986],
[M,188,56,5960,188,65,5969],
[M,185,8,5845,188,83,5987],
[M,184,6,5821,184,20,5835],
[M,171,53,5422,171,71,5440],
[M,171,53,5422,171,69,5438],
[M,173,34,5507,173,46,5519],
[M,173,34,5507,173,59,5532],
[M,173,47,5520,173,58,5531],
[M,173,15,5488,173,23,5496],
[M,175,53,5608,175,65,5620],
[M,175,53,5608,175,78,5633],
[M,175,66,5621,175,77,5632],
[M,175,39,5594,175,51,5606],
[M,175,29,5584,175,37,5592],
[M,175,15,5570,175,28,5583],
[M,175,8,5563,175,80,5635],
[M,174,6,5540,174,17,5551],
[M,175,15,5570,175,79,5634],
[M,174,6,5540,176,12,5649],
[M,177,6,5657,177,49,5700],
[M,177,36,5687,177,48,5699],
[M,177,15,5666,177,28,5679],
[M,177,15,5666,177,26,5677],
[M,126,2,3921,126,49,3968],
[M,127,2,3971,127,28,3997],
[M,128,2,4000,128,35,4033],
[M,129,2,4036,129,35,4069],
[M,130,2,4072,138,7,4372],
[M,130,9,4079,138,7,4372],
[M,131,6,4109,137,9,4364],
[M,132,8,4143,136,53,4354],
[M,134,58,4276,134,67,4285],
[M,133,10,4192,135,13,4300],
[M,133,15,4197,133,35,4217],
[M,136,36,4337,136,52,4353],
[M,136,36,4337,136,50,4351],
[M,136,36,4337,136,43,4344],
[M,136,22,4323,136,34,4335],
[M,136,10,4311,136,17,4318],
[M,133,24,4206,133,34,4216],
[M,139,16,4389,139,50,4423],
[M,139,2,4375,139,12,4385],
[M,139,16,4389,139,62,4435],
[M,139,55,4428,139,61,4434],
[M,139,16,4389,139,54,4427],
[M,145,40,4627,145,61,4648],
[M,145,40,4627,145,47,4634],
[M,145,25,4612,145,38,4625],
[M,145,18,4605,145,62,4649],
[M,142,14,4522,142,26,4534],
[M,141,10,4491,141,23,4504],
[M,140,21,4473,151,9,4882],
[M,140,6,4458,140,17,4469],
[M,139,64,4437,139,73,4446],
[M,142,14,4522,146,17,4667],
[M,147,75,4744,147,111,4780],
[M,147,86,4755,147,99,4768],
[M,147,75,4744,147,82,4751],
[M,147,53,4722,147,73,4742],
[M,147,37,4706,147,49,4718],
[M,147,30,4699,147,113,4782],
[M,147,14,4683,147,26,4695],
[M,147,37,4706,147,112,4781],
[M,148,18,4802,148,56,4840],
[M,148,29,4813,148,49,4833],
[M,148,18,4802,148,25,4809],
[M,147,14,4683,149,17,4858],
[M,141,10,4491,150,13,4872],
[M,152,33,4917,152,41,4925],
[M,152,19,4903,152,31,4915],
[M,152,8,4892,152,15,4899],
[M,152,8,4892,152,42,4926],
[M,140,6,4458,152,43,4927],
[M,134,18,4236,134,68,4286],
[M,134,12,4230,134,68,4286],
[M,108,2,3430,115,5,3637],
[M,108,12,3440,115,5,3637],
[M,110,4,3487,114,9,3631],
[M,113,10,3607,113,24,3621],
[M,112,10,3528,112,77,3595],
[M,112,44,3562,112,53,3571],
[M,111,6,3509,111,13,3516],
[M,109,4,3464,109,22,3482],
[M,105,2,3373,107,5,3427],
[M,106,4,3397,106,10,3403],
[M,102,2,3257,104,5,3370],
[M,103,15,3294,103,31,3310],
[M,103,4,3283,103,11,3290],
[M,101,2,3225,101,31,3254],
[M,101,14,3237,101,21,3244],
[M,117,18,3675,117,35,3692],
[M,117,25,3682,117,34,3691],
[M,117,4,3661,117,14,3671],
[M,119,18,3753,119,35,3770],
[M,119,25,3760,119,34,3769],
[M,119,4,3739,119,14,3749],
[M,116,5,3643,116,17,3655],
[M,117,52,3709,117,62,3719],
[M,117,37,3694,117,46,3703],
[M,117,4,3661,117,69,3726],
[M,120,13,3800,120,23,3810],
[M,119,37,3772,119,46,3781],
[M,120,32,3819,120,40,3827],
[M,120,58,3845,120,66,3853],
[M,120,42,3829,120,67,3854],
[M,120,25,3812,120,68,3855],
[M,120,6,3793,120,69,3856],
[M,119,4,3739,121,11,3869],
[M,112,55,3573,112,71,3589],
[M,112,37,3555,112,72,3590],
[M,103,62,3341,103,82,3361],
[M,103,62,3341,103,80,3359],
[M,103,62,3341,103,73,3352],
[M,103,62,3341,103,70,3349],
[M,103,51,3330,103,60,3339],
[M,103,40,3319,103,47,3326],
[M,103,33,3312,103,84,3363],
[M,103,40,3319,103,83,3362],
[M,96,17,3103,96,32,3118],
[M,96,40,3126,96,54,3140],
[M,96,40,3126,96,46,3132],
[M,88,20,2915,88,73,2968],
[M,65,36,1922,65,48,1934],
[M,65,36,1922,65,53,1939],
[M,61,36,1757,61,57,1778],
[M,61,36,1757,61,44,1765],
[M,59,42,1667,59,58,1683],
[M,57,42,1563,57,58,1579],
[M,44,64,1190,44,84,1210],
[M,44,64,1190,44,71,1197],
[M,44,86,1212,44,101,1227],
[M,44,86,1212,44,93,1219],
[M,41,71,1059,41,86,1074],
[M,41,71,1059,41,78,1066],
[M,35,2,810,35,26,834],
[M,32,69,750,32,84,765],
[M,32,69,750,32,76,757],
[M,28,59,610,28,74,625],
[M,28,66,617,28,73,624],
[M,28,30,581,28,42,593],
[M,28,13,564,28,26,577],
[M,28,6,557,28,83,634],
[M,27,4,536,27,15,547],
[M,28,30,581,28,75,626],
[M,28,13,564,28,82,633],
[M,27,4,536,29,10,646],
[M,3,0,13,610,3,21962],
[M,10,0,160,10,21,181],
[M,10,8,168,10,18,178]];
var _divide6 = NAMESPACE.get("_divide");
var _plus7 = NAMESPACE.get("_plus");
var builtins8 = NAMESPACE.get("builtins");
var nothing9 = NAMESPACE.get("nothing");
var raise10 = NAMESPACE.get("raise");
var torepr11 = NAMESPACE.get("torepr");
var $type$String12 = NAMESPACE.get("$type$String");
var $Hnames203241 = function(names7242,A113,A222,C624,DesugarEnv6843,DesugarEnvT26944,Option2045,PP314,Pair7046,PairT37147,Set2248,empty3049,fold5550,is_DASH_empty2851,link3152,list2753,lists1118,map3954,none6355,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11,$type$String12) {
var DesugarEnv47358 = {"$var":D,
"$name":"DesugarEnv4"};
var DesugarEnv7460 = {"$var":D,
"$name":"DesugarEnv"};
var is_DASH_DesugarEnv7562 = {"$var":D,
"$name":"is-DesugarEnv"};
var is_DASH_d_DASH_env7664 = {"$var":D,
"$name":"is-d-env"};
var d_DASH_env7766 = {"$var":D,
"$name":"d-env"};
var Pair57868 = {"$var":D,
"$name":"Pair5"};
var Pair7970 = {"$var":D,
"$name":"Pair"};
var is_DASH_Pair8072 = {"$var":D,
"$name":"is-Pair"};
var is_DASH_pair8174 = {"$var":D,
"$name":"is-pair"};
var pair8276 = {"$var":D,
"$name":"pair"};
var anf_variant_member15158 = R.makeMethod(function(self2194) {
return function(cases_DASH_funs3195,else_DASH_clause4206) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[6],2,arguments);
}
var if_DASH_6209 = R.hasField(cases_DASH_funs3195,("d-env"));
var if_helper3192 = R.makeFunction(function(if_helper_arg4214) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
var ann_DASH_check_DASH_temp2215 = if_helper_arg4214;
return ann_DASH_check_DASH_temp2215;
});
var anf_if7213 = R.isBoolean(if_DASH_6209);
if(R.isPyretTrue(anf_if7213)) {
if(R.isPyretTrue(if_DASH_6209)) {
var call_DASH_d_DASH_env1187 = G(cases_DASH_funs3195,"d-env",L[6]);
var anf_arg10188 = G(self2194,"ids",L[14]);
var anf_arg11189 = G(self2194,"vars",L[13]);
var anf_arg12190 = G(self2194,"letrecs",L[12]);
var $z179180 = D;
var $f185186 = function(_) {
return R.isFunction(call_DASH_d_DASH_env1187)?call_DASH_d_DASH_env1187.app(anf_arg10188,anf_arg11189,anf_arg12190):R.ffi.throwNonFunApp(L[6],call_DASH_d_DASH_env1187,[anf_arg10188,anf_arg11189,anf_arg12190]);
};
try {
if(--R.GAS > 0) {
$z179180 = $f185186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f185186,
"from":L[6]});
}
} catch($e177178) {
if(R.isCont($e177178)) {
var $ss181182 = {"from":L[6],
"go":function(cont_tail_arg13191) {
return $Hcont_tail_arg1415193(cont_tail_arg13191,if_helper3192);
}};
$e177178.stack[R.EXN_STACKHEIGHT++] = $ss181182;
}
if(R.isPyretException($e177178)) {
$e177178.pyretStack.push(L[6]);
}
throw $e177178;
}
var $ret183184 = $Hcont_tail_arg1415193($z179180,if_helper3192);
++R.GAS;
return $ret183184;
} else {
var $z198199 = D;
var $f204205 = function(_) {
return R.isFunction(else_DASH_clause4206)?else_DASH_clause4206.app():R.ffi.throwNonFunApp(L[6],else_DASH_clause4206,[]);
};
try {
if(--R.GAS > 0) {
$z198199 = $f204205();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f204205,
"from":L[6]});
}
} catch($e196197) {
if(R.isCont($e196197)) {
var $ss200201 = {"from":L[6],
"go":function(cont_tail_arg8207) {
return $Hcont_tail_arg1416208(cont_tail_arg8207,if_helper3192);
}};
$e196197.stack[R.EXN_STACKHEIGHT++] = $ss200201;
}
if(R.isPyretException($e196197)) {
$e196197.pyretStack.push(L[6]);
}
throw $e196197;
}
var $ret202203 = $Hcont_tail_arg1416208($z198199,if_helper3192);
++R.GAS;
return $ret202203;
}
} else {
var cont_tail_arg5212 = R.throwNonBooleanCondition(L[6],("if"),if_DASH_6209);
if(--R.GAS > 0) {
$z210211 = R.isFunction(if_helper3192)?if_helper3192.app(cont_tail_arg5212):R.ffi.throwNonFunApp(L[6],if_helper3192,[cont_tail_arg5212]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3192)?if_helper3192.app(cont_tail_arg5212):R.ffi.throwNonFunApp(L[6],if_helper3192,[cont_tail_arg5212]);
},
"from":L[6]});
}
++R.GAS;
return $z210211;
}
};
},{"length":3});
var anf_variant_member29159 = R.makeMethod(function(self5175) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[6],0,arguments);
}
var anf_arg17173 = G(self5175,"ids",L[6]);
var $z165166 = D;
var $f171172 = function(_) {
return R.isFunction(torepr11)?torepr11.app(anf_arg17173):R.ffi.throwNonFunApp(L[6],torepr11,[anf_arg17173]);
};
try {
if(--R.GAS > 0) {
$z165166 = $f171172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f171172,
"from":L[6]});
}
} catch($e163164) {
if(R.isCont($e163164)) {
var $ss167168 = {"from":L[6],
"go":function(anf_arg18174) {
return $Hanf_arg1426176(anf_arg18174,self5175,_plus7,torepr11);
}};
$e163164.stack[R.EXN_STACKHEIGHT++] = $ss167168;
}
if(R.isPyretException($e163164)) {
$e163164.pyretStack.push(L[6]);
}
throw $e163164;
}
var $ret169170 = $Hanf_arg1426176($z165166,self5175,_plus7,torepr11);
++R.GAS;
return $ret169170;
};
},{"length":1});
var anf_assign3059 = (function() {
var $d_DASH_env_DASH_base153154 = {"_match":anf_variant_member15158,
"_torepr":anf_variant_member29159};
var $d_DASH_env_DASH_brands156157 = {"$brand-d-env155":true};
$d_DASH_env_DASH_brands156157[DesugarEnvT26944._brand] = true
return R.makeObject({"DesugarEnv":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[7],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,DesugarEnvT26944._brand));
}),
"is-d-env":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-d-env155"));
}),
"d-env":R.makeFunction(function(ids83160,vars84161,letrecs85162) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[8],3,arguments);
}
return R.checkAnnArgs([Set2248,Set2248,Set2248],[ids83160,vars84161,letrecs85162],[L[9],L[10],L[11]],function() {
var dict = R.create($d_DASH_env_DASH_base153154);
dict["ids"] = ids83160
dict["vars"] = vars84161
dict["letrecs"] = letrecs85162
return R.makeBrandedObject(dict,$d_DASH_env_DASH_brands156157);
});
})});
})();
DesugarEnv47358.$var = anf_assign3059;
var anf_assign3161 = G(DesugarEnv47358.$var,"DesugarEnv",L[7]);
DesugarEnv7460.$var = anf_assign3161;
var anf_assign3263 = G(DesugarEnv47358.$var,"DesugarEnv",L[7]);
is_DASH_DesugarEnv7562.$var = anf_assign3263;
var anf_assign3365 = G(DesugarEnv47358.$var,"is-d-env",L[6]);
is_DASH_d_DASH_env7664.$var = anf_assign3365;
var anf_assign3467 = G(DesugarEnv47358.$var,"d-env",L[6]);
d_DASH_env7766.$var = anf_assign3467;
var anf_variant_member4796 = R.makeMethod(function(self8130) {
return function(cases_DASH_funs9131,else_DASH_clause10142) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
var if_DASH_12145 = R.hasField(cases_DASH_funs9131,("pair"));
var if_helper36128 = R.makeFunction(function(if_helper_arg37151) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
var ann_DASH_check_DASH_temp35152 = if_helper_arg37151;
return ann_DASH_check_DASH_temp35152;
});
var anf_if40150 = R.isBoolean(if_DASH_12145);
if(R.isPyretTrue(anf_if40150)) {
if(R.isPyretTrue(if_DASH_12145)) {
var call_DASH_pair7124 = G(cases_DASH_funs9131,"pair",L[1]);
var anf_arg43125 = G(self8130,"left",L[5]);
var anf_arg44126 = G(self8130,"right",L[4]);
var $z116117 = D;
var $f122123 = function(_) {
return R.isFunction(call_DASH_pair7124)?call_DASH_pair7124.app(anf_arg43125,anf_arg44126):R.ffi.throwNonFunApp(L[1],call_DASH_pair7124,[anf_arg43125,anf_arg44126]);
};
try {
if(--R.GAS > 0) {
$z116117 = $f122123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f122123,
"from":L[1]});
}
} catch($e114115) {
if(R.isCont($e114115)) {
var $ss118119 = {"from":L[1],
"go":function(cont_tail_arg45127) {
return $Hcont_tail_arg1427129(cont_tail_arg45127,if_helper36128);
}};
$e114115.stack[R.EXN_STACKHEIGHT++] = $ss118119;
}
if(R.isPyretException($e114115)) {
$e114115.pyretStack.push(L[1]);
}
throw $e114115;
}
var $ret120121 = $Hcont_tail_arg1427129($z116117,if_helper36128);
++R.GAS;
return $ret120121;
} else {
var $z134135 = D;
var $f140141 = function(_) {
return R.isFunction(else_DASH_clause10142)?else_DASH_clause10142.app():R.ffi.throwNonFunApp(L[1],else_DASH_clause10142,[]);
};
try {
if(--R.GAS > 0) {
$z134135 = $f140141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f140141,
"from":L[1]});
}
} catch($e132133) {
if(R.isCont($e132133)) {
var $ss136137 = {"from":L[1],
"go":function(cont_tail_arg41143) {
return $Hcont_tail_arg1428144(cont_tail_arg41143,if_helper36128);
}};
$e132133.stack[R.EXN_STACKHEIGHT++] = $ss136137;
}
if(R.isPyretException($e132133)) {
$e132133.pyretStack.push(L[1]);
}
throw $e132133;
}
var $ret138139 = $Hcont_tail_arg1428144($z134135,if_helper36128);
++R.GAS;
return $ret138139;
}
} else {
var cont_tail_arg38148 = R.throwNonBooleanCondition(L[1],("if"),if_DASH_12145);
if(--R.GAS > 0) {
$z146147 = R.isFunction(if_helper36128)?if_helper36128.app(cont_tail_arg38148):R.ffi.throwNonFunApp(L[1],if_helper36128,[cont_tail_arg38148]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper36128)?if_helper36128.app(cont_tail_arg38148):R.ffi.throwNonFunApp(L[1],if_helper36128,[cont_tail_arg38148]);
},
"from":L[1]});
}
++R.GAS;
return $z146147;
}
};
},{"length":3});
var anf_variant_member5797 = R.makeMethod(function(self11112) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1],0,arguments);
}
var anf_arg49110 = G(self11112,"left",L[1]);
var $z102103 = D;
var $f108109 = function(_) {
return R.isFunction(torepr11)?torepr11.app(anf_arg49110):R.ffi.throwNonFunApp(L[1],torepr11,[anf_arg49110]);
};
try {
if(--R.GAS > 0) {
$z102103 = $f108109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f108109,
"from":L[1]});
}
} catch($e100101) {
if(R.isCont($e100101)) {
var $ss104105 = {"from":L[1],
"go":function(anf_arg50111) {
return $Hanf_arg1435113(anf_arg50111,self11112,_plus7,torepr11);
}};
$e100101.stack[R.EXN_STACKHEIGHT++] = $ss104105;
}
if(R.isPyretException($e100101)) {
$e100101.pyretStack.push(L[1]);
}
throw $e100101;
}
var $ret106107 = $Hanf_arg1435113($z102103,self11112,_plus7,torepr11);
++R.GAS;
return $ret106107;
};
},{"length":1});
var anf_assign5869 = (function() {
var $pair_DASH_base9192 = {"_match":anf_variant_member4796,
"_torepr":anf_variant_member5797};
var $pair_DASH_brands9495 = {"$brand-pair93":true};
$pair_DASH_brands9495[PairT37147._brand] = true
return R.makeObject({"Pair":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,PairT37147._brand));
}),
"is-pair":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-pair93"));
}),
"pair":R.makeFunction(function(left8698,right8799) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[3],2,arguments);
}
var dict = R.create($pair_DASH_base9192);
dict["left"] = left8698
dict["right"] = right8799
return R.makeBrandedObject(dict,$pair_DASH_brands9495);
})});
})();
Pair57868.$var = anf_assign5869;
var anf_assign5971 = G(Pair57868.$var,"Pair",L[2]);
Pair7970.$var = anf_assign5971;
var anf_assign6073 = G(Pair57868.$var,"Pair",L[2]);
is_DASH_Pair8072.$var = anf_assign6073;
var anf_assign6175 = G(Pair57868.$var,"is-pair",L[1]);
is_DASH_pair8174.$var = anf_assign6175;
var anf_assign6277 = G(Pair57868.$var,"pair",L[1]);
pair8276.$var = anf_assign6277;
var anf_fun6388 = G(tree_DASH_set6657,"make",L[0]);
var $z8081 = D;
var $f8687 = function(_) {
return R.isFunction(anf_fun6388)?anf_fun6388.app([]):R.ffi.throwNonFunApp(L[0],anf_fun6388,[[]]);
};
try {
if(--R.GAS > 0) {
$z8081 = $f8687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8687,
"from":L[0]});
}
} catch($e7879) {
if(R.isCont($e7879)) {
var $ss8283 = {"from":L[0],
"go":function(anf_arg6489) {
return $Hanf_arg203190(anf_arg6489,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11);
}};
$e7879.stack[R.EXN_STACKHEIGHT++] = $ss8283;
}
if(R.isPyretException($e7879)) {
$e7879.pyretStack.push(L[0]);
}
throw $e7879;
}
var $ret8485 = $Hanf_arg203190($z8081,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11);
++R.GAS;
return $ret8485;
};
var $Hanf_arg203190 = function(anf_arg6489,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11) {
var anf_fun65226 = G(tree_DASH_set6657,"make",L[15]);
var $z218219 = D;
var $f224225 = function(_) {
return R.isFunction(anf_fun65226)?anf_fun65226.app([]):R.ffi.throwNonFunApp(L[15],anf_fun65226,[[]]);
};
try {
if(--R.GAS > 0) {
$z218219 = $f224225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f224225,
"from":L[15]});
}
} catch($e216217) {
if(R.isCont($e216217)) {
var $ss220221 = {"from":L[15],
"go":function(anf_arg66227) {
return $Hanf_arg2030228(anf_arg66227,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,anf_arg6489,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11);
}};
$e216217.stack[R.EXN_STACKHEIGHT++] = $ss220221;
}
if(R.isPyretException($e216217)) {
$e216217.pyretStack.push(L[15]);
}
throw $e216217;
}
var $ret222223 = $Hanf_arg2030228($z218219,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,anf_arg6489,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11);
++R.GAS;
return $ret222223;
};
var $Hanf_arg2030228 = function(anf_arg66227,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,anf_arg6489,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11) {
var anf_fun67239 = G(tree_DASH_set6657,"make",L[16]);
var $z231232 = D;
var $f237238 = function(_) {
return R.isFunction(anf_fun67239)?anf_fun67239.app([]):R.ffi.throwNonFunApp(L[16],anf_fun67239,[[]]);
};
try {
if(--R.GAS > 0) {
$z231232 = $f237238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f237238,
"from":L[16]});
}
} catch($e229230) {
if(R.isCont($e229230)) {
var $ss233234 = {"from":L[16],
"go":function(anf_arg68240) {
return $Hanf_arg2029241(anf_arg68240,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,anf_arg6489,anf_arg66227,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,_divide6,_plus7,builtins8,nothing9,raise10,torepr11);
}};
$e229230.stack[R.EXN_STACKHEIGHT++] = $ss233234;
}
if(R.isPyretException($e229230)) {
$e229230.pyretStack.push(L[16]);
}
throw $e229230;
}
var $ret235236 = $Hanf_arg2029241($z231232,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,anf_arg6489,anf_arg66227,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,_divide6,_plus7,builtins8,nothing9,raise10,torepr11);
++R.GAS;
return $ret235236;
};
var $Hanf_arg2029241 = function(anf_arg68240,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,anf_arg6489,anf_arg66227,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,_divide6,_plus7,builtins8,nothing9,raise10,torepr11) {
var $z244245 = D;
var $f250251 = function(_) {
return R.isFunction(d_DASH_env7766.$var)?d_DASH_env7766.$var.app(anf_arg6489,anf_arg66227,anf_arg68240):R.ffi.throwNonFunApp(L[17],d_DASH_env7766.$var,[anf_arg6489,anf_arg66227,anf_arg68240]);
};
try {
if(--R.GAS > 0) {
$z244245 = $f250251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f250251,
"from":L[17]});
}
} catch($e242243) {
if(R.isCont($e242243)) {
var $ss246247 = {"from":L[17],
"go":function(mt_DASH_d_DASH_env88252) {
return $Hmt_DASH_d_DASH_env2028253(mt_DASH_d_DASH_env88252,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,_divide6,_plus7,builtins8,nothing9,raise10,torepr11);
}};
$e242243.stack[R.EXN_STACKHEIGHT++] = $ss246247;
}
if(R.isPyretException($e242243)) {
$e242243.pyretStack.push(L[17]);
}
throw $e242243;
}
var $ret248249 = $Hmt_DASH_d_DASH_env2028253($z244245,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,_divide6,_plus7,builtins8,nothing9,raise10,torepr11);
++R.GAS;
return $ret248249;
};
var $Hmt_DASH_d_DASH_env2028253 = function(mt_DASH_d_DASH_env88252,A113,A222,C624,DesugarEnv6843,DesugarEnv7460,Option2045,PP314,Pair7046,Pair7970,d_DASH_env7766,empty3049,fold5550,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_empty2851,is_DASH_pair8174,link3152,list2753,lists1118,map3954,names7242,none6355,pair8276,some6456,_divide6,_plus7,builtins8,nothing9,raise10,torepr11) {
var g89254 = {"$var":D,
"$name":"g"};
var gid90256 = {"$var":D,
"$name":"gid"};
var check_DASH_bool91258 = {"$var":D,
"$name":"check-bool"};
var no_DASH_branches_DASH_exn92260 = {"$var":D,
"$name":"no-branches-exn"};
var make_DASH_message_DASH_exception93262 = {"$var":D,
"$name":"make-message-exception"};
var make_DASH_message_DASH_exception_DASH_e94264 = {"$var":D,
"$name":"make-message-exception-e"};
var bool_DASH_exn95266 = {"$var":D,
"$name":"bool-exn"};
var bool_DASH_op_DASH_exn96268 = {"$var":D,
"$name":"bool-op-exn"};
var desugar_DASH_afield97270 = {"$var":D,
"$name":"desugar-afield"};
var desugar_DASH_ann98272 = {"$var":D,
"$name":"desugar-ann"};
var desugar99274 = {"$var":D,
"$name":"desugar"};
var mk_DASH_bind100276 = {"$var":D,
"$name":"mk-bind"};
var mk_DASH_id101278 = {"$var":D,
"$name":"mk-id"};
var make_DASH_torepr102280 = {"$var":D,
"$name":"make-torepr"};
var make_DASH_match103282 = {"$var":D,
"$name":"make-match"};
var get_DASH_arith_DASH_op104284 = {"$var":D,
"$name":"get-arith-op"};
var desugar_DASH_if105286 = {"$var":D,
"$name":"desugar-if"};
var desugar_DASH_case_DASH_branch106288 = {"$var":D,
"$name":"desugar-case-branch"};
var desugar_DASH_cases107290 = {"$var":D,
"$name":"desugar-cases"};
var desugar_DASH_variant_DASH_member108292 = {"$var":D,
"$name":"desugar-variant-member"};
var desugar_DASH_member109294 = {"$var":D,
"$name":"desugar-member"};
var is_DASH_underscore110296 = {"$var":D,
"$name":"is-underscore"};
var ds_DASH_curry_DASH_args111298 = {"$var":D,
"$name":"ds-curry-args"};
var ds_DASH_curry_DASH_nullary112300 = {"$var":D,
"$name":"ds-curry-nullary"};
var ds_DASH_curry_DASH_binop113302 = {"$var":D,
"$name":"ds-curry-binop"};
var ds_DASH_curry114304 = {"$var":D,
"$name":"ds-curry"};
var desugar_DASH_opt115306 = {"$var":D,
"$name":"desugar-opt"};
var desugar_DASH_bind116308 = {"$var":D,
"$name":"desugar-bind"};
var desugar_DASH_expr117310 = {"$var":D,
"$name":"desugar-expr"};
var anf_assign71255 = R.makeFunction(function(id1182105) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[316],1,arguments);
}
var anf_fun702116 = G(A113,"s-global",L[317]);
var $z21082109 = D;
var $f21142115 = function(_) {
return R.isFunction(anf_fun702116)?anf_fun702116.app(id1182105):R.ffi.throwNonFunApp(L[316],anf_fun702116,[id1182105]);
};
try {
if(--R.GAS > 0) {
$z21082109 = $f21142115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21142115,
"from":L[316]});
}
} catch($e21062107) {
if(R.isCont($e21062107)) {
var $ss21102111 = {"from":L[316],
"go":function(ann_DASH_check_DASH_temp692117) {
return $Hann_DASH_check_DASH_temp14362118(ann_DASH_check_DASH_temp692117);
}};
$e21062107.stack[R.EXN_STACKHEIGHT++] = $ss21102111;
}
if(R.isPyretException($e21062107)) {
$e21062107.pyretStack.push(L[316]);
}
throw $e21062107;
}
var $ret21122113 = $Hann_DASH_check_DASH_temp14362118($z21082109);
++R.GAS;
return $ret21122113;
});
g89254.$var = anf_assign71255;
var anf_assign75257 = R.makeFunction(function(l1192090,id1202091) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[313],2,arguments);
}
var anf_fun732103 = G(A113,"s-id",L[315]);
var $z20942095 = D;
var $f21002101 = function(_) {
return R.isFunction(g89254.$var)?g89254.$var.app(id1202091):R.ffi.throwNonFunApp(L[314],g89254.$var,[id1202091]);
};
try {
if(--R.GAS > 0) {
$z20942095 = $f21002101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21002101,
"from":L[314]});
}
} catch($e20922093) {
if(R.isCont($e20922093)) {
var $ss20962097 = {"from":L[314],
"go":function(anf_arg742102) {
return $Hanf_arg14382104(anf_arg742102,anf_fun732103,l1192090);
}};
$e20922093.stack[R.EXN_STACKHEIGHT++] = $ss20962097;
}
if(R.isPyretException($e20922093)) {
$e20922093.pyretStack.push(L[314]);
}
throw $e20922093;
}
var $ret20982099 = $Hanf_arg14382104($z20942095,anf_fun732103,l1192090);
++R.GAS;
return $ret20982099;
});
gid90256.$var = anf_assign75257;
var anf_assign94259 = R.makeFunction(function(l1212069,id1222070,e1232071,then1242072,err1252073) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[307],5,arguments);
}
var anf_fun772087 = G(A113,"s-let-expr",L[312]);
var anf_fun782088 = G(list2753,"make",L[311]);
var anf_fun792084 = G(A113,"s-let-bind",L[310]);
var anf_arg802085 = G(id1222070,"id-b",L[309]);
var $z20762077 = D;
var $f20822083 = function(_) {
return R.isFunction(anf_fun792084)?anf_fun792084.app(l1212069,anf_arg802085,e1232071):R.ffi.throwNonFunApp(L[308],anf_fun792084,[l1212069,anf_arg802085,e1232071]);
};
try {
if(--R.GAS > 0) {
$z20762077 = $f20822083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20822083,
"from":L[308]});
}
} catch($e20742075) {
if(R.isCont($e20742075)) {
var $ss20782079 = {"from":L[308],
"go":function(anf_array_val812086) {
return $Hanf_array_val14462089(anf_array_val812086,A113,anf_fun772087,anf_fun782088,err1252073,id1222070,l1212069,list2753,then1242072);
}};
$e20742075.stack[R.EXN_STACKHEIGHT++] = $ss20782079;
}
if(R.isPyretException($e20742075)) {
$e20742075.pyretStack.push(L[308]);
}
throw $e20742075;
}
var $ret20802081 = $Hanf_array_val14462089($z20762077,A113,anf_fun772087,anf_fun782088,err1252073,id1222070,l1212069,list2753,then1242072);
++R.GAS;
return $ret20802081;
});
check_DASH_bool91258.$var = anf_assign94259;
var anf_assign103261 = R.makeFunction(function(l1262052,typ1272053) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[302],2,arguments);
}
var anf_fun962066 = G(A113,"s-prim-app",L[306]);
var anf_fun972067 = G(list2753,"make",L[305]);
var anf_fun982064 = G(A113,"s-srcloc",L[304]);
var $z20562057 = D;
var $f20622063 = function(_) {
return R.isFunction(anf_fun982064)?anf_fun982064.app(l1262052,l1262052):R.ffi.throwNonFunApp(L[303],anf_fun982064,[l1262052,l1262052]);
};
try {
if(--R.GAS > 0) {
$z20562057 = $f20622063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20622063,
"from":L[303]});
}
} catch($e20542055) {
if(R.isCont($e20542055)) {
var $ss20582059 = {"from":L[303],
"go":function(anf_array_val992065) {
return $Hanf_array_val14502068(anf_array_val992065,A113,anf_fun962066,anf_fun972067,l1262052,typ1272053);
}};
$e20542055.stack[R.EXN_STACKHEIGHT++] = $ss20582059;
}
if(R.isPyretException($e20542055)) {
$e20542055.pyretStack.push(L[303]);
}
throw $e20542055;
}
var $ret20602061 = $Hanf_array_val14502068($z20562057,A113,anf_fun962066,anf_fun972067,l1262052,typ1272053);
++R.GAS;
return $ret20602061;
});
no_DASH_branches_DASH_exn92260.$var = anf_assign103261;
var anf_assign107263 = R.makeFunction(function(l1282037,msg1292038) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[299],2,arguments);
}
var anf_fun1052049 = G(A113,"s-str",L[301]);
var $z20412042 = D;
var $f20472048 = function(_) {
return R.isFunction(anf_fun1052049)?anf_fun1052049.app(l1282037,msg1292038):R.ffi.throwNonFunApp(L[300],anf_fun1052049,[l1282037,msg1292038]);
};
try {
if(--R.GAS > 0) {
$z20412042 = $f20472048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20472048,
"from":L[300]});
}
} catch($e20392040) {
if(R.isCont($e20392040)) {
var $ss20432044 = {"from":L[300],
"go":function(anf_arg1062050) {
return $Hanf_arg14522051(anf_arg1062050,l1282037,make_DASH_message_DASH_exception_DASH_e94264);
}};
$e20392040.stack[R.EXN_STACKHEIGHT++] = $ss20432044;
}
if(R.isPyretException($e20392040)) {
$e20392040.pyretStack.push(L[300]);
}
throw $e20392040;
}
var $ret20452046 = $Hanf_arg14522051($z20412042,l1282037,make_DASH_message_DASH_exception_DASH_e94264);
++R.GAS;
return $ret20452046;
});
make_DASH_message_DASH_exception93262.$var = anf_assign107263;
var anf_assign112265 = R.makeFunction(function(l1302021,msg_DASH_e1312022) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[296],2,arguments);
}
var anf_fun1092035 = G(A113,"s-prim-app",L[298]);
var anf_fun1102033 = G(list2753,"make",L[297]);
var $z20252026 = D;
var $f20312032 = function(_) {
return R.isFunction(anf_fun1102033)?anf_fun1102033.app([msg_DASH_e1312022]):R.ffi.throwNonFunApp(L[297],anf_fun1102033,[[msg_DASH_e1312022]]);
};
try {
if(--R.GAS > 0) {
$z20252026 = $f20312032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20312032,
"from":L[297]});
}
} catch($e20232024) {
if(R.isCont($e20232024)) {
var $ss20272028 = {"from":L[297],
"go":function(anf_arg1112034) {
return $Hanf_arg14542036(anf_arg1112034,anf_fun1092035,l1302021);
}};
$e20232024.stack[R.EXN_STACKHEIGHT++] = $ss20272028;
}
if(R.isPyretException($e20232024)) {
$e20232024.pyretStack.push(L[297]);
}
throw $e20232024;
}
var $ret20292030 = $Hanf_arg14542036($z20252026,anf_fun1092035,l1302021);
++R.GAS;
return $ret20292030;
});
make_DASH_message_DASH_exception_DASH_e94264.$var = anf_assign112265;
var anf_assign121267 = R.makeFunction(function(l1322003,typ1332004,val1342005) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[291],3,arguments);
}
var anf_fun1142018 = G(A113,"s-prim-app",L[295]);
var anf_fun1152019 = G(list2753,"make",L[294]);
var anf_fun1162016 = G(A113,"s-srcloc",L[293]);
var $z20082009 = D;
var $f20142015 = function(_) {
return R.isFunction(anf_fun1162016)?anf_fun1162016.app(l1322003,l1322003):R.ffi.throwNonFunApp(L[292],anf_fun1162016,[l1322003,l1322003]);
};
try {
if(--R.GAS > 0) {
$z20082009 = $f20142015();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20142015,
"from":L[292]});
}
} catch($e20062007) {
if(R.isCont($e20062007)) {
var $ss20102011 = {"from":L[292],
"go":function(anf_array_val1172017) {
return $Hanf_array_val14582020(anf_array_val1172017,A113,anf_fun1142018,anf_fun1152019,l1322003,typ1332004,val1342005);
}};
$e20062007.stack[R.EXN_STACKHEIGHT++] = $ss20102011;
}
if(R.isPyretException($e20062007)) {
$e20062007.pyretStack.push(L[292]);
}
throw $e20062007;
}
var $ret20122013 = $Hanf_array_val14582020($z20082009,A113,anf_fun1142018,anf_fun1152019,l1322003,typ1332004,val1342005);
++R.GAS;
return $ret20122013;
});
bool_DASH_exn95266.$var = anf_assign121267;
var anf_assign132269 = R.makeFunction(function(l1351984,position1361985,typ1371986,val1381987) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[286],4,arguments);
}
var anf_fun1232000 = G(A113,"s-prim-app",L[290]);
var anf_fun1242001 = G(list2753,"make",L[289]);
var anf_fun1251998 = G(A113,"s-srcloc",L[288]);
var $z19901991 = D;
var $f19961997 = function(_) {
return R.isFunction(anf_fun1251998)?anf_fun1251998.app(l1351984,l1351984):R.ffi.throwNonFunApp(L[287],anf_fun1251998,[l1351984,l1351984]);
};
try {
if(--R.GAS > 0) {
$z19901991 = $f19961997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19961997,
"from":L[287]});
}
} catch($e19881989) {
if(R.isCont($e19881989)) {
var $ss19921993 = {"from":L[287],
"go":function(anf_array_val1261999) {
return $Hanf_array_val14632002(anf_array_val1261999,A113,anf_fun1232000,anf_fun1242001,l1351984,position1361985,typ1371986,val1381987);
}};
$e19881989.stack[R.EXN_STACKHEIGHT++] = $ss19921993;
}
if(R.isPyretException($e19881989)) {
$e19881989.pyretStack.push(L[287]);
}
throw $e19881989;
}
var $ret19941995 = $Hanf_array_val14632002($z19901991,A113,anf_fun1232000,anf_fun1242001,l1351984,position1361985,typ1371986,val1381987);
++R.GAS;
return $ret19941995;
});
bool_DASH_op_DASH_exn96268.$var = anf_assign132269;
var anf_assign139271 = R.makeFunction(function(f1391967) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[278],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[285],"A",A222,"AField")],[f1391967],[L[285]],function() {
var anf_fun1341982 = G(A113,"a-field",L[284]);
var anf_arg1351980 = G(f1391967,"l",L[283]);
var anf_arg1361981 = G(f1391967,"name",L[282]);
var anf_arg1371978 = G(f1391967,"ann",L[281]);
var $z19701971 = D;
var $f19761977 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var === D?U(L[279],"desugar-ann"):desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var === D?U(L[279],"desugar-ann"):desugar_DASH_ann98272.$var.app(anf_arg1371978):R.ffi.throwNonFunApp(L[280],desugar_DASH_ann98272.$var === D?U(L[279],"desugar-ann"):desugar_DASH_ann98272.$var,[anf_arg1371978]);
};
try {
if(--R.GAS > 0) {
$z19701971 = $f19761977();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19761977,
"from":L[280]});
}
} catch($e19681969) {
if(R.isCont($e19681969)) {
var $ss19721973 = {"from":L[280],
"go":function(anf_arg1381979) {
return $Hanf_arg14651983(anf_arg1381979,A222,anf_arg1351980,anf_arg1361981,anf_fun1341982);
}};
$e19681969.stack[R.EXN_STACKHEIGHT++] = $ss19721973;
}
if(R.isPyretException($e19681969)) {
$e19681969.pyretStack.push(L[280]);
}
throw $e19681969;
}
var $ret19741975 = $Hanf_arg14651983($z19701971,A222,anf_arg1351980,anf_arg1361981,anf_fun1341982);
++R.GAS;
return $ret19741975;
});
});
desugar_DASH_afield97270.$var = anf_assign139271;
var anf_assign181273 = R.makeFunction(function(a1401848) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[253],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[277],"A",A222,"Ann")],[a1401848],[L[277]],function() {
var cases_DASH_val131966 = a1401848;
var anf_fun1411859 = G(cases_DASH_val131966,"_match",L[254]);
var anf_obj1431865 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[276],0,arguments);
}
var ann_DASH_check_DASH_temp1421965 = a1401848;
return ann_DASH_check_DASH_temp1421965;
});
var anf_obj1451866 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[275],0,arguments);
}
var ann_DASH_check_DASH_temp1441964 = a1401848;
return ann_DASH_check_DASH_temp1441964;
});
var anf_obj1471867 = R.makeFunction(function($underscore1411961,$underscore1421962) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[274],2,arguments);
}
var ann_DASH_check_DASH_temp1461963 = a1401848;
return ann_DASH_check_DASH_temp1461963;
});
var anf_obj1491868 = R.makeFunction(function($underscore1431957,$underscore1441958,$underscore1451959) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[273],3,arguments);
}
var ann_DASH_check_DASH_temp1481960 = a1401848;
return ann_DASH_check_DASH_temp1481960;
});
var anf_obj1551869 = R.makeFunction(function(l1461939,args1471940,ret1481941,use_DASH_parens1491942) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[269],4,arguments);
}
var anf_fun1511955 = G(A113,"a-arrow",L[272]);
var anf_fun1521953 = G(args1471940,"map",L[271]);
var $z19451946 = D;
var $f19511952 = function(_) {
return R.isFunction(anf_fun1521953)?anf_fun1521953.app(desugar_DASH_ann98272.$var):R.ffi.throwNonFunApp(L[270],anf_fun1521953,[desugar_DASH_ann98272.$var]);
};
try {
if(--R.GAS > 0) {
$z19451946 = $f19511952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19511952,
"from":L[270]});
}
} catch($e19431944) {
if(R.isCont($e19431944)) {
var $ss19471948 = {"from":L[270],
"go":function(anf_arg1531954) {
return $Hanf_arg14681956(anf_arg1531954,anf_fun1511955,desugar_DASH_ann98272,l1461939,ret1481941,use_DASH_parens1491942);
}};
$e19431944.stack[R.EXN_STACKHEIGHT++] = $ss19471948;
}
if(R.isPyretException($e19431944)) {
$e19431944.pyretStack.push(L[270]);
}
throw $e19431944;
}
var $ret19491950 = $Hanf_arg14681956($z19451946,anf_fun1511955,desugar_DASH_ann98272,l1461939,ret1481941,use_DASH_parens1491942);
++R.GAS;
return $ret19491950;
});
var anf_obj1611870 = R.makeFunction(function(l1501922,args1511923,ret1521924) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[265],3,arguments);
}
var anf_fun1571937 = G(A113,"a-arrow",L[268]);
var anf_fun1581935 = G(args1511923,"map",L[267]);
var $z19271928 = D;
var $f19331934 = function(_) {
return R.isFunction(anf_fun1581935)?anf_fun1581935.app(desugar_DASH_ann98272.$var):R.ffi.throwNonFunApp(L[266],anf_fun1581935,[desugar_DASH_ann98272.$var]);
};
try {
if(--R.GAS > 0) {
$z19271928 = $f19331934();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19331934,
"from":L[266]});
}
} catch($e19251926) {
if(R.isCont($e19251926)) {
var $ss19291930 = {"from":L[266],
"go":function(anf_arg1591936) {
return $Hanf_arg14711938(anf_arg1591936,anf_fun1571937,desugar_DASH_ann98272,l1501922,ret1521924);
}};
$e19251926.stack[R.EXN_STACKHEIGHT++] = $ss19291930;
}
if(R.isPyretException($e19251926)) {
$e19251926.pyretStack.push(L[266]);
}
throw $e19251926;
}
var $ret19311932 = $Hanf_arg14711938($z19271928,anf_fun1571937,desugar_DASH_ann98272,l1501922,ret1521924);
++R.GAS;
return $ret19311932;
});
var anf_obj1671871 = R.makeFunction(function(l1531906,base1541907,args1551908) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[262],3,arguments);
}
var anf_fun1631920 = G(A113,"a-app",L[264]);
var $z19111912 = D;
var $f19171918 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(base1541907):R.ffi.throwNonFunApp(L[263],desugar_DASH_ann98272.$var,[base1541907]);
};
try {
if(--R.GAS > 0) {
$z19111912 = $f19171918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19171918,
"from":L[263]});
}
} catch($e19091910) {
if(R.isCont($e19091910)) {
var $ss19131914 = {"from":L[263],
"go":function(anf_arg1641919) {
return $Hanf_arg14741921(anf_arg1641919,anf_fun1631920,args1551908,desugar_DASH_ann98272,l1531906);
}};
$e19091910.stack[R.EXN_STACKHEIGHT++] = $ss19131914;
}
if(R.isPyretException($e19091910)) {
$e19091910.pyretStack.push(L[263]);
}
throw $e19091910;
}
var $ret19151916 = $Hanf_arg14741921($z19111912,anf_fun1631920,args1551908,desugar_DASH_ann98272,l1531906);
++R.GAS;
return $ret19151916;
});
var anf_obj1721872 = R.makeFunction(function(l1561890,fields1571891) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[258],2,arguments);
}
var anf_fun1691904 = G(A113,"a-record",L[261]);
var anf_fun1701902 = G(fields1571891,"map",L[260]);
var $z18941895 = D;
var $f19001901 = function(_) {
return R.isFunction(anf_fun1701902)?anf_fun1701902.app(desugar_DASH_afield97270.$var):R.ffi.throwNonFunApp(L[259],anf_fun1701902,[desugar_DASH_afield97270.$var]);
};
try {
if(--R.GAS > 0) {
$z18941895 = $f19001901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19001901,
"from":L[259]});
}
} catch($e18921893) {
if(R.isCont($e18921893)) {
var $ss18961897 = {"from":L[259],
"go":function(anf_arg1711903) {
return $Hanf_arg14761905(anf_arg1711903,anf_fun1691904,l1561890);
}};
$e18921893.stack[R.EXN_STACKHEIGHT++] = $ss18961897;
}
if(R.isPyretException($e18921893)) {
$e18921893.pyretStack.push(L[259]);
}
throw $e18921893;
}
var $ret18981899 = $Hanf_arg14761905($z18941895,anf_fun1691904,l1561890);
++R.GAS;
return $ret18981899;
});
var anf_obj1771873 = R.makeFunction(function(l1581874,ann1591875,exp1601876) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[255],3,arguments);
}
var anf_fun1741888 = G(A113,"a-pred",L[257]);
var $z18791880 = D;
var $f18851886 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ann1591875):R.ffi.throwNonFunApp(L[256],desugar_DASH_ann98272.$var,[ann1591875]);
};
try {
if(--R.GAS > 0) {
$z18791880 = $f18851886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18851886,
"from":L[256]});
}
} catch($e18771878) {
if(R.isCont($e18771878)) {
var $ss18811882 = {"from":L[256],
"go":function(anf_arg1751887) {
return $Hanf_arg14791889(anf_arg1751887,anf_fun1741888,desugar_DASH_expr117310,exp1601876,l1581874);
}};
$e18771878.stack[R.EXN_STACKHEIGHT++] = $ss18811882;
}
if(R.isPyretException($e18771878)) {
$e18771878.pyretStack.push(L[256]);
}
throw $e18771878;
}
var $ret18831884 = $Hanf_arg14791889($z18791880,anf_fun1741888,desugar_DASH_expr117310,exp1601876,l1581874);
++R.GAS;
return $ret18831884;
});
var anf_arg1781860 = R.makeObject({"a-blank":anf_obj1431865,
"a-any":anf_obj1451866,
"a-name":anf_obj1471867,
"a-dot":anf_obj1491868,
"a-arrow":anf_obj1551869,
"a-method":anf_obj1611870,
"a-app":anf_obj1671871,
"a-record":anf_obj1721872,
"a-pred":anf_obj1771873});
var anf_arg1801861 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[254],0,arguments);
}
var ann_DASH_check_DASH_temp1791864 = R.throwNoBranchesMatched(L[254],("cases"));
return ann_DASH_check_DASH_temp1791864;
});
var $z18511852 = D;
var $f18571858 = function(_) {
return R.isFunction(anf_fun1411859)?anf_fun1411859.app(anf_arg1781860,anf_arg1801861):R.ffi.throwNonFunApp(L[253],anf_fun1411859,[anf_arg1781860,anf_arg1801861]);
};
try {
if(--R.GAS > 0) {
$z18511852 = $f18571858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18571858,
"from":L[253]});
}
} catch($e18491850) {
if(R.isCont($e18491850)) {
var $ss18531854 = {"from":L[253],
"go":function(ann_DASH_check_DASH_temp1401862) {
return $Hann_DASH_check_DASH_temp14801863(ann_DASH_check_DASH_temp1401862,A222);
}};
$e18491850.stack[R.EXN_STACKHEIGHT++] = $ss18531854;
}
if(R.isPyretException($e18491850)) {
$e18491850.pyretStack.push(L[253]);
}
throw $e18491850;
}
var $ret18551856 = $Hann_DASH_check_DASH_temp14801863($z18511852,A222);
++R.GAS;
return $ret18551856;
});
});
desugar_DASH_ann98272.$var = anf_assign181273;
var anf_assign193275 = R.makeFunction(function(program1611799,compile_DASH_env1621800) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[244],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[251],"A",A222,"Program"),R.getDotAnn(L[252],"C",C624,"CompileEnvironment")],[program1611799,compile_DASH_env1621800],[L[251],L[252]],function() {
var cases_DASH_val141847 = program1611799;
var anf_fun1831811 = G(cases_DASH_val141847,"_match",L[245]);
var anf_obj1871828 = R.makeFunction(function(l1631829,_provide1641830,provided_DASH_types1651831,imports1661832,body1671833) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[247],5,arguments);
}
var anf_fun1851845 = G(A113,"s-program",L[250]);
var $z18361837 = D;
var $f18421843 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[248],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[248],"desugar-expr"):desugar_DASH_expr117310.$var.app(body1671833):R.ffi.throwNonFunApp(L[249],desugar_DASH_expr117310.$var === D?U(L[248],"desugar-expr"):desugar_DASH_expr117310.$var,[body1671833]);
};
try {
if(--R.GAS > 0) {
$z18361837 = $f18421843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18421843,
"from":L[249]});
}
} catch($e18341835) {
if(R.isCont($e18341835)) {
var $ss18381839 = {"from":L[249],
"go":function(anf_arg1861844) {
return $Hanf_arg14821846(anf_arg1861844,_provide1641830,anf_fun1851845,imports1661832,l1631829,provided_DASH_types1651831);
}};
$e18341835.stack[R.EXN_STACKHEIGHT++] = $ss18381839;
}
if(R.isPyretException($e18341835)) {
$e18341835.pyretStack.push(L[249]);
}
throw $e18341835;
}
var $ret18401841 = $Hanf_arg14821846($z18361837,_provide1641830,anf_fun1851845,imports1661832,l1631829,provided_DASH_types1651831);
++R.GAS;
return $ret18401841;
});
var anf_arg1881812 = R.makeObject({"s-program":anf_obj1871828});
var anf_arg1921813 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[245],0,arguments);
}
var $z18181819 = D;
var $f18241825 = function(_) {
return R.isFunction(torepr11)?torepr11.app(program1611799):R.ffi.throwNonFunApp(L[246],torepr11,[program1611799]);
};
try {
if(--R.GAS > 0) {
$z18181819 = $f18241825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18241825,
"from":L[246]});
}
} catch($e18161817) {
if(R.isCont($e18161817)) {
var $ss18201821 = {"from":L[246],
"go":function(anf_arg1901826) {
return $Hanf_arg14851827(anf_arg1901826,_plus7,raise10);
}};
$e18161817.stack[R.EXN_STACKHEIGHT++] = $ss18201821;
}
if(R.isPyretException($e18161817)) {
$e18161817.pyretStack.push(L[246]);
}
throw $e18161817;
}
var $ret18221823 = $Hanf_arg14851827($z18181819,_plus7,raise10);
++R.GAS;
return $ret18221823;
});
var $z18031804 = D;
var $f18091810 = function(_) {
return R.isFunction(anf_fun1831811)?anf_fun1831811.app(anf_arg1881812,anf_arg1921813):R.ffi.throwNonFunApp(L[244],anf_fun1831811,[anf_arg1881812,anf_arg1921813]);
};
try {
if(--R.GAS > 0) {
$z18031804 = $f18091810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18091810,
"from":L[244]});
}
} catch($e18011802) {
if(R.isCont($e18011802)) {
var $ss18051806 = {"from":L[244],
"go":function(ann_DASH_check_DASH_temp1821814) {
return $Hann_DASH_check_DASH_temp14861815(ann_DASH_check_DASH_temp1821814);
}};
$e18011802.stack[R.EXN_STACKHEIGHT++] = $ss18051806;
}
if(R.isPyretException($e18011802)) {
$e18011802.pyretStack.push(L[244]);
}
throw $e18011802;
}
var $ret18071808 = $Hann_DASH_check_DASH_temp14861815($z18031804);
++R.GAS;
return $ret18071808;
});
});
desugar99274.$var = anf_assign193275;
var anf_assign197277 = R.makeFunction(function(l1681783,id1691784) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[241],2,arguments);
}
var anf_fun1951795 = G(A113,"s-bind",L[243]);
var anf_arg1961796 = G(A113,"a-blank",L[242]);
var $z17871788 = D;
var $f17931794 = function(_) {
return R.isFunction(anf_fun1951795)?anf_fun1951795.app(l1681783,(false),id1691784,anf_arg1961796):R.ffi.throwNonFunApp(L[241],anf_fun1951795,[l1681783,(false),id1691784,anf_arg1961796]);
};
try {
if(--R.GAS > 0) {
$z17871788 = $f17931794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17931794,
"from":L[241]});
}
} catch($e17851786) {
if(R.isCont($e17851786)) {
var $ss17891790 = {"from":L[241],
"go":function(ann_DASH_check_DASH_temp1941797) {
return $Hann_DASH_check_DASH_temp14871798(ann_DASH_check_DASH_temp1941797);
}};
$e17851786.stack[R.EXN_STACKHEIGHT++] = $ss17891790;
}
if(R.isPyretException($e17851786)) {
$e17851786.pyretStack.push(L[241]);
}
throw $e17851786;
}
var $ret17911792 = $Hann_DASH_check_DASH_temp14871798($z17871788);
++R.GAS;
return $ret17911792;
});
mk_DASH_bind100276.$var = anf_assign197277;
var anf_assign203279 = R.makeFunction(function(loc1701768,base1711769) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[238],2,arguments);
}
var anf_fun1991780 = G(names7242,"make-atom",L[240]);
var $z17721773 = D;
var $f17781779 = function(_) {
return R.isFunction(anf_fun1991780)?anf_fun1991780.app(base1711769):R.ffi.throwNonFunApp(L[239],anf_fun1991780,[base1711769]);
};
try {
if(--R.GAS > 0) {
$z17721773 = $f17781779();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17781779,
"from":L[239]});
}
} catch($e17701771) {
if(R.isCont($e17701771)) {
var $ss17741775 = {"from":L[239],
"go":function(a1721781) {
return $Ha14901782(a1721781,A113,loc1701768,mk_DASH_bind100276);
}};
$e17701771.stack[R.EXN_STACKHEIGHT++] = $ss17741775;
}
if(R.isPyretException($e17701771)) {
$e17701771.pyretStack.push(L[239]);
}
throw $e17701771;
}
var $ret17761777 = $Ha14901782($z17721773,A113,loc1701768,mk_DASH_bind100276);
++R.GAS;
return $ret17761777;
});
mk_DASH_id101278.$var = anf_assign203279;
var anf_assign265281 = R.makeFunction(function(l1731752,vname1741753,fields1751754,is_DASH_singleton1761755) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[236],4,arguments);
}
var $z17581759 = D;
var $f17641765 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l1731752,("self")):R.ffi.throwNonFunApp(L[237],mk_DASH_id101278.$var,[l1731752,("self")]);
};
try {
if(--R.GAS > 0) {
$z17581759 = $f17641765();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17641765,
"from":L[237]});
}
} catch($e17561757) {
if(R.isCont($e17561757)) {
var $ss17601761 = {"from":L[237],
"go":function(self1771766) {
return $Hself15171767(self1771766,A113,fields1751754,gid90256,is_DASH_singleton1761755,l1731752,list2753,none6355,vname1741753);
}};
$e17561757.stack[R.EXN_STACKHEIGHT++] = $ss17601761;
}
if(R.isPyretException($e17561757)) {
$e17561757.pyretStack.push(L[237]);
}
throw $e17561757;
}
var $ret17621763 = $Hself15171767($z17581759,A113,fields1751754,gid90256,is_DASH_singleton1761755,l1731752,list2753,none6355,vname1741753);
++R.GAS;
return $ret17621763;
});
make_DASH_torepr102280.$var = anf_assign265281;
var anf_assign331283 = R.makeFunction(function(l1901737,case_DASH_name1911738,fields1921739) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[234],3,arguments);
}
var $z17421743 = D;
var $f17481749 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("call-"),case_DASH_name1911738):R.ffi.throwNonFunApp(L[235],_plus7,[("call-"),case_DASH_name1911738]);
};
try {
if(--R.GAS > 0) {
$z17421743 = $f17481749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17481749,
"from":L[235]});
}
} catch($e17401741) {
if(R.isCont($e17401741)) {
var $ss17441745 = {"from":L[235],
"go":function(anf_arg2671750) {
return $Hanf_arg15481751(anf_arg2671750,A113,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11);
}};
$e17401741.stack[R.EXN_STACKHEIGHT++] = $ss17441745;
}
if(R.isPyretException($e17401741)) {
$e17401741.pyretStack.push(L[235]);
}
throw $e17401741;
}
var $ret17461747 = $Hanf_arg15481751($z17421743,A113,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11);
++R.GAS;
return $ret17461747;
});
make_DASH_match103282.$var = anf_assign331283;
var anf_assign376285 = R.makeFunction(function(str2021585) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[216],1,arguments);
}
var if_DASH_271730 = R.equiv(str2021585,("op+"));
var if_helper3331597 = R.makeFunction(function(if_helper_arg3341735) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[233],1,arguments);
}
var ann_DASH_check_DASH_temp3321736 = if_helper_arg3341735;
return ann_DASH_check_DASH_temp3321736;
});
var anf_if3371734 = R.isBoolean(if_DASH_271730);
if(R.isPyretTrue(anf_if3371734)) {
if(R.isPyretTrue(if_DASH_271730)) {
var $z15881589 = D;
var $f15941595 = function(_) {
return R.isFunction(some6456)?some6456.app(("_plus")):R.ffi.throwNonFunApp(L[217],some6456,[("_plus")]);
};
try {
if(--R.GAS > 0) {
$z15881589 = $f15941595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15941595,
"from":L[217]});
}
} catch($e15861587) {
if(R.isCont($e15861587)) {
var $ss15901591 = {"from":L[217],
"go":function(cont_tail_arg3741596) {
return $Hcont_tail_arg15491598(cont_tail_arg3741596,if_helper3331597);
}};
$e15861587.stack[R.EXN_STACKHEIGHT++] = $ss15901591;
}
if(R.isPyretException($e15861587)) {
$e15861587.pyretStack.push(L[217]);
}
throw $e15861587;
}
var $ret15921593 = $Hcont_tail_arg15491598($z15881589,if_helper3331597);
++R.GAS;
return $ret15921593;
} else {
var if_DASH_261725 = R.equiv(str2021585,("op-"));
var anf_if3401729 = R.isBoolean(if_DASH_261725);
if(R.isPyretTrue(anf_if3401729)) {
if(R.isPyretTrue(if_DASH_261725)) {
var $z16011602 = D;
var $f16071608 = function(_) {
return R.isFunction(some6456)?some6456.app(("_minus")):R.ffi.throwNonFunApp(L[218],some6456,[("_minus")]);
};
try {
if(--R.GAS > 0) {
$z16011602 = $f16071608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16071608,
"from":L[218]});
}
} catch($e15991600) {
if(R.isCont($e15991600)) {
var $ss16031604 = {"from":L[218],
"go":function(cont_tail_arg3721609) {
return $Hcont_tail_arg15501610(cont_tail_arg3721609,if_helper3331597);
}};
$e15991600.stack[R.EXN_STACKHEIGHT++] = $ss16031604;
}
if(R.isPyretException($e15991600)) {
$e15991600.pyretStack.push(L[218]);
}
throw $e15991600;
}
var $ret16051606 = $Hcont_tail_arg15501610($z16011602,if_helper3331597);
++R.GAS;
return $ret16051606;
} else {
var if_DASH_251720 = R.equiv(str2021585,("op*"));
var anf_if3431724 = R.isBoolean(if_DASH_251720);
if(R.isPyretTrue(anf_if3431724)) {
if(R.isPyretTrue(if_DASH_251720)) {
var $z16131614 = D;
var $f16191620 = function(_) {
return R.isFunction(some6456)?some6456.app(("_times")):R.ffi.throwNonFunApp(L[219],some6456,[("_times")]);
};
try {
if(--R.GAS > 0) {
$z16131614 = $f16191620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16191620,
"from":L[219]});
}
} catch($e16111612) {
if(R.isCont($e16111612)) {
var $ss16151616 = {"from":L[219],
"go":function(cont_tail_arg3701621) {
return $Hcont_tail_arg15511622(cont_tail_arg3701621,if_helper3331597);
}};
$e16111612.stack[R.EXN_STACKHEIGHT++] = $ss16151616;
}
if(R.isPyretException($e16111612)) {
$e16111612.pyretStack.push(L[219]);
}
throw $e16111612;
}
var $ret16171618 = $Hcont_tail_arg15511622($z16131614,if_helper3331597);
++R.GAS;
return $ret16171618;
} else {
var if_DASH_241715 = R.equiv(str2021585,("op/"));
var anf_if3461719 = R.isBoolean(if_DASH_241715);
if(R.isPyretTrue(anf_if3461719)) {
if(R.isPyretTrue(if_DASH_241715)) {
var $z16251626 = D;
var $f16311632 = function(_) {
return R.isFunction(some6456)?some6456.app(("_divide")):R.ffi.throwNonFunApp(L[220],some6456,[("_divide")]);
};
try {
if(--R.GAS > 0) {
$z16251626 = $f16311632();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16311632,
"from":L[220]});
}
} catch($e16231624) {
if(R.isCont($e16231624)) {
var $ss16271628 = {"from":L[220],
"go":function(cont_tail_arg3681633) {
return $Hcont_tail_arg15521634(cont_tail_arg3681633,if_helper3331597);
}};
$e16231624.stack[R.EXN_STACKHEIGHT++] = $ss16271628;
}
if(R.isPyretException($e16231624)) {
$e16231624.pyretStack.push(L[220]);
}
throw $e16231624;
}
var $ret16291630 = $Hcont_tail_arg15521634($z16251626,if_helper3331597);
++R.GAS;
return $ret16291630;
} else {
var if_DASH_231710 = R.equiv(str2021585,("op<"));
var anf_if3491714 = R.isBoolean(if_DASH_231710);
if(R.isPyretTrue(anf_if3491714)) {
if(R.isPyretTrue(if_DASH_231710)) {
var $z16371638 = D;
var $f16431644 = function(_) {
return R.isFunction(some6456)?some6456.app(("_lessthan")):R.ffi.throwNonFunApp(L[221],some6456,[("_lessthan")]);
};
try {
if(--R.GAS > 0) {
$z16371638 = $f16431644();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16431644,
"from":L[221]});
}
} catch($e16351636) {
if(R.isCont($e16351636)) {
var $ss16391640 = {"from":L[221],
"go":function(cont_tail_arg3661645) {
return $Hcont_tail_arg15531646(cont_tail_arg3661645,if_helper3331597);
}};
$e16351636.stack[R.EXN_STACKHEIGHT++] = $ss16391640;
}
if(R.isPyretException($e16351636)) {
$e16351636.pyretStack.push(L[221]);
}
throw $e16351636;
}
var $ret16411642 = $Hcont_tail_arg15531646($z16371638,if_helper3331597);
++R.GAS;
return $ret16411642;
} else {
var if_DASH_221705 = R.equiv(str2021585,("op>"));
var anf_if3521709 = R.isBoolean(if_DASH_221705);
if(R.isPyretTrue(anf_if3521709)) {
if(R.isPyretTrue(if_DASH_221705)) {
var $z16491650 = D;
var $f16551656 = function(_) {
return R.isFunction(some6456)?some6456.app(("_greaterthan")):R.ffi.throwNonFunApp(L[222],some6456,[("_greaterthan")]);
};
try {
if(--R.GAS > 0) {
$z16491650 = $f16551656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16551656,
"from":L[222]});
}
} catch($e16471648) {
if(R.isCont($e16471648)) {
var $ss16511652 = {"from":L[222],
"go":function(cont_tail_arg3641657) {
return $Hcont_tail_arg15541658(cont_tail_arg3641657,if_helper3331597);
}};
$e16471648.stack[R.EXN_STACKHEIGHT++] = $ss16511652;
}
if(R.isPyretException($e16471648)) {
$e16471648.pyretStack.push(L[222]);
}
throw $e16471648;
}
var $ret16531654 = $Hcont_tail_arg15541658($z16491650,if_helper3331597);
++R.GAS;
return $ret16531654;
} else {
var if_DASH_211700 = R.equiv(str2021585,("op>="));
var anf_if3551704 = R.isBoolean(if_DASH_211700);
if(R.isPyretTrue(anf_if3551704)) {
if(R.isPyretTrue(if_DASH_211700)) {
var $z16611662 = D;
var $f16671668 = function(_) {
return R.isFunction(some6456)?some6456.app(("_greaterequal")):R.ffi.throwNonFunApp(L[223],some6456,[("_greaterequal")]);
};
try {
if(--R.GAS > 0) {
$z16611662 = $f16671668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16671668,
"from":L[223]});
}
} catch($e16591660) {
if(R.isCont($e16591660)) {
var $ss16631664 = {"from":L[223],
"go":function(cont_tail_arg3621669) {
return $Hcont_tail_arg15551670(cont_tail_arg3621669,if_helper3331597);
}};
$e16591660.stack[R.EXN_STACKHEIGHT++] = $ss16631664;
}
if(R.isPyretException($e16591660)) {
$e16591660.pyretStack.push(L[223]);
}
throw $e16591660;
}
var $ret16651666 = $Hcont_tail_arg15551670($z16611662,if_helper3331597);
++R.GAS;
return $ret16651666;
} else {
var if_DASH_201695 = R.equiv(str2021585,("op<="));
var anf_if3581699 = R.isBoolean(if_DASH_201695);
if(R.isPyretTrue(anf_if3581699)) {
if(R.isPyretTrue(if_DASH_201695)) {
var $z16731674 = D;
var $f16791680 = function(_) {
return R.isFunction(some6456)?some6456.app(("_lessequal")):R.ffi.throwNonFunApp(L[224],some6456,[("_lessequal")]);
};
try {
if(--R.GAS > 0) {
$z16731674 = $f16791680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16791680,
"from":L[224]});
}
} catch($e16711672) {
if(R.isCont($e16711672)) {
var $ss16751676 = {"from":L[224],
"go":function(cont_tail_arg3601681) {
return $Hcont_tail_arg15561682(cont_tail_arg3601681,if_helper3331597);
}};
$e16711672.stack[R.EXN_STACKHEIGHT++] = $ss16751676;
}
if(R.isPyretException($e16711672)) {
$e16711672.pyretStack.push(L[224]);
}
throw $e16711672;
}
var $ret16771678 = $Hcont_tail_arg15561682($z16731674,if_helper3331597);
++R.GAS;
return $ret16771678;
} else {
var $z16851686 = D;
var $f16911692 = function(_) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(none6355):R.ffi.throwNonFunApp(L[225],if_helper3331597,[none6355]);
};
try {
if(--R.GAS > 0) {
$z16851686 = $f16911692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16911692,
"from":L[225]});
}
} catch($e16831684) {
if(R.isCont($e16831684)) {
var $ss16871688 = {"from":L[225],
"go":function(cont_tail_app3591693) {
return $Hcont_tail_app15571694(cont_tail_app3591693);
}};
$e16831684.stack[R.EXN_STACKHEIGHT++] = $ss16871688;
}
if(R.isPyretException($e16831684)) {
$e16831684.pyretStack.push(L[225]);
}
throw $e16831684;
}
var $ret16891690 = $Hcont_tail_app15571694($z16851686);
++R.GAS;
return $ret16891690;
}
} else {
var cont_tail_arg3561698 = R.throwNonBooleanCondition(L[226],("if"),if_DASH_201695);
if(--R.GAS > 0) {
$z16961697 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3561698):R.ffi.throwNonFunApp(L[226],if_helper3331597,[cont_tail_arg3561698]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3561698):R.ffi.throwNonFunApp(L[226],if_helper3331597,[cont_tail_arg3561698]);
},
"from":L[226]});
}
++R.GAS;
return $z16961697;
}
}
} else {
var cont_tail_arg3531703 = R.throwNonBooleanCondition(L[227],("if"),if_DASH_211700);
if(--R.GAS > 0) {
$z17011702 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3531703):R.ffi.throwNonFunApp(L[227],if_helper3331597,[cont_tail_arg3531703]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3531703):R.ffi.throwNonFunApp(L[227],if_helper3331597,[cont_tail_arg3531703]);
},
"from":L[227]});
}
++R.GAS;
return $z17011702;
}
}
} else {
var cont_tail_arg3501708 = R.throwNonBooleanCondition(L[228],("if"),if_DASH_221705);
if(--R.GAS > 0) {
$z17061707 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3501708):R.ffi.throwNonFunApp(L[228],if_helper3331597,[cont_tail_arg3501708]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3501708):R.ffi.throwNonFunApp(L[228],if_helper3331597,[cont_tail_arg3501708]);
},
"from":L[228]});
}
++R.GAS;
return $z17061707;
}
}
} else {
var cont_tail_arg3471713 = R.throwNonBooleanCondition(L[229],("if"),if_DASH_231710);
if(--R.GAS > 0) {
$z17111712 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3471713):R.ffi.throwNonFunApp(L[229],if_helper3331597,[cont_tail_arg3471713]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3471713):R.ffi.throwNonFunApp(L[229],if_helper3331597,[cont_tail_arg3471713]);
},
"from":L[229]});
}
++R.GAS;
return $z17111712;
}
}
} else {
var cont_tail_arg3441718 = R.throwNonBooleanCondition(L[230],("if"),if_DASH_241715);
if(--R.GAS > 0) {
$z17161717 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3441718):R.ffi.throwNonFunApp(L[230],if_helper3331597,[cont_tail_arg3441718]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3441718):R.ffi.throwNonFunApp(L[230],if_helper3331597,[cont_tail_arg3441718]);
},
"from":L[230]});
}
++R.GAS;
return $z17161717;
}
}
} else {
var cont_tail_arg3411723 = R.throwNonBooleanCondition(L[231],("if"),if_DASH_251720);
if(--R.GAS > 0) {
$z17211722 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3411723):R.ffi.throwNonFunApp(L[231],if_helper3331597,[cont_tail_arg3411723]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3411723):R.ffi.throwNonFunApp(L[231],if_helper3331597,[cont_tail_arg3411723]);
},
"from":L[231]});
}
++R.GAS;
return $z17211722;
}
}
} else {
var cont_tail_arg3381728 = R.throwNonBooleanCondition(L[232],("if"),if_DASH_261725);
if(--R.GAS > 0) {
$z17261727 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3381728):R.ffi.throwNonFunApp(L[232],if_helper3331597,[cont_tail_arg3381728]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3381728):R.ffi.throwNonFunApp(L[232],if_helper3331597,[cont_tail_arg3381728]);
},
"from":L[232]});
}
++R.GAS;
return $z17261727;
}
}
} else {
var cont_tail_arg3351733 = R.throwNonBooleanCondition(L[233],("if"),if_DASH_271730);
if(--R.GAS > 0) {
$z17311732 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3351733):R.ffi.throwNonFunApp(L[233],if_helper3331597,[cont_tail_arg3351733]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3351733):R.ffi.throwNonFunApp(L[233],if_helper3331597,[cont_tail_arg3351733]);
},
"from":L[233]});
}
++R.GAS;
return $z17311732;
}
});
get_DASH_arith_DASH_op104284.$var = anf_assign376285;
var anf_assign400287 = R.makeFunction(function(l2031555,branches2041556,_else2051557) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[210],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[215],"A",A222,"Expr")],[_else2051557],[L[215]],function() {
var anf_arg3961569 = R.makeFunction(function(acc2061571,branch2071572) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[213],2,arguments);
}
var $z15751576 = D;
var $f15811582 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l2031555,("if-")):R.ffi.throwNonFunApp(L[214],mk_DASH_id101278.$var,[l2031555,("if-")]);
};
try {
if(--R.GAS > 0) {
$z15751576 = $f15811582();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15811582,
"from":L[214]});
}
} catch($e15731574) {
if(R.isCont($e15731574)) {
var $ss15771578 = {"from":L[214],
"go":function(test_DASH_id2081583) {
return $Htest_DASH_id15651584(test_DASH_id2081583,A113,acc2061571,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,desugar_DASH_expr117310,l2031555,list2753);
}};
$e15731574.stack[R.EXN_STACKHEIGHT++] = $ss15771578;
}
if(R.isPyretException($e15731574)) {
$e15731574.pyretStack.push(L[214]);
}
throw $e15731574;
}
var $ret15791580 = $Htest_DASH_id15651584($z15751576,A113,acc2061571,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,desugar_DASH_expr117310,l2031555,list2753);
++R.GAS;
return $ret15791580;
});
var $z15601561 = D;
var $f15661567 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[211],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[211],"desugar-expr"):desugar_DASH_expr117310.$var.app(_else2051557):R.ffi.throwNonFunApp(L[212],desugar_DASH_expr117310.$var === D?U(L[211],"desugar-expr"):desugar_DASH_expr117310.$var,[_else2051557]);
};
try {
if(--R.GAS > 0) {
$z15601561 = $f15661567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15661567,
"from":L[212]});
}
} catch($e15581559) {
if(R.isCont($e15581559)) {
var $ss15621563 = {"from":L[212],
"go":function(anf_arg3971568) {
return $Hanf_arg15681570(anf_arg3971568,anf_arg3961569,branches2041556,fold5550);
}};
$e15581559.stack[R.EXN_STACKHEIGHT++] = $ss15621563;
}
if(R.isPyretException($e15581559)) {
$e15581559.pyretStack.push(L[212]);
}
throw $e15581559;
}
var $ret15641565 = $Hanf_arg15681570($z15601561,anf_arg3961569,branches2041556,fold5550);
++R.GAS;
return $ret15641565;
});
});
desugar_DASH_if105286.$var = anf_assign400287;
var anf_assign419289 = R.makeFunction(function(c2091518) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[204],1,arguments);
}
var cases_DASH_val281554 = c2091518;
var anf_fun4021529 = G(cases_DASH_val281554,"_match",L[205]);
var anf_obj4151535 = R.makeFunction(function(l22101536,name2111537,args2121538,body2131539) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[206],4,arguments);
}
var anf_fun4041552 = G(A113,"s-data-field",L[209]);
var anf_fun4051550 = G(A113,"s-str",L[208]);
var $z15421543 = D;
var $f15481549 = function(_) {
return R.isFunction(anf_fun4051550)?anf_fun4051550.app(l22101536,name2111537):R.ffi.throwNonFunApp(L[207],anf_fun4051550,[l22101536,name2111537]);
};
try {
if(--R.GAS > 0) {
$z15421543 = $f15481549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15481549,
"from":L[207]});
}
} catch($e15401541) {
if(R.isCont($e15401541)) {
var $ss15441545 = {"from":L[207],
"go":function(anf_arg4061551) {
return $Hanf_arg15741553(anf_arg4061551,A113,anf_fun4041552,args2121538,body2131539,desugar_DASH_bind116308,desugar_DASH_member109294,l22101536,list2753,none6355);
}};
$e15401541.stack[R.EXN_STACKHEIGHT++] = $ss15441545;
}
if(R.isPyretException($e15401541)) {
$e15401541.pyretStack.push(L[207]);
}
throw $e15401541;
}
var $ret15461547 = $Hanf_arg15741553($z15421543,A113,anf_fun4041552,args2121538,body2131539,desugar_DASH_bind116308,desugar_DASH_member109294,l22101536,list2753,none6355);
++R.GAS;
return $ret15461547;
});
var anf_arg4161530 = R.makeObject({"s-cases-branch":anf_obj4151535});
var anf_arg4181531 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[205],0,arguments);
}
var ann_DASH_check_DASH_temp4171534 = R.throwNoBranchesMatched(L[205],("cases"));
return ann_DASH_check_DASH_temp4171534;
});
var $z15211522 = D;
var $f15271528 = function(_) {
return R.isFunction(anf_fun4021529)?anf_fun4021529.app(anf_arg4161530,anf_arg4181531):R.ffi.throwNonFunApp(L[204],anf_fun4021529,[anf_arg4161530,anf_arg4181531]);
};
try {
if(--R.GAS > 0) {
$z15211522 = $f15271528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15271528,
"from":L[204]});
}
} catch($e15191520) {
if(R.isCont($e15191520)) {
var $ss15231524 = {"from":L[204],
"go":function(ann_DASH_check_DASH_temp4011532) {
return $Hann_DASH_check_DASH_temp15751533(ann_DASH_check_DASH_temp4011532);
}};
$e15191520.stack[R.EXN_STACKHEIGHT++] = $ss15231524;
}
if(R.isPyretException($e15191520)) {
$e15191520.pyretStack.push(L[204]);
}
throw $e15191520;
}
var $ret15251526 = $Hann_DASH_check_DASH_temp15751533($z15211522);
++R.GAS;
return $ret15251526;
});
desugar_DASH_case_DASH_branch106288.$var = anf_assign419289;
var anf_assign441291 = R.makeFunction(function(l2141501,ann2151502,val2161503,branches2171504,else_DASH_block2181505) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[202],5,arguments);
}
var $z15081509 = D;
var $f15141515 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l2141501,("cases-val")):R.ffi.throwNonFunApp(L[203],mk_DASH_id101278.$var,[l2141501,("cases-val")]);
};
try {
if(--R.GAS > 0) {
$z15081509 = $f15141515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15141515,
"from":L[203]});
}
} catch($e15061507) {
if(R.isCont($e15061507)) {
var $ss15101511 = {"from":L[203],
"go":function(val_DASH_id2191516) {
return $Hval_DASH_id15861517(val_DASH_id2191516,A113,branches2171504,else_DASH_block2181505,l2141501,list2753,none6355,val2161503);
}};
$e15061507.stack[R.EXN_STACKHEIGHT++] = $ss15101511;
}
if(R.isPyretException($e15061507)) {
$e15061507.pyretStack.push(L[203]);
}
throw $e15061507;
}
var $ret15121513 = $Hval_DASH_id15861517($z15081509,A113,branches2171504,else_DASH_block2181505,l2141501,list2753,none6355,val2161503);
++R.GAS;
return $ret15121513;
});
desugar_DASH_cases107290.$var = anf_assign441291;
var anf_assign451293 = R.makeFunction(function(m2221466) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[196],1,arguments);
}
var cases_DASH_val291500 = m2221466;
var anf_fun4431477 = G(cases_DASH_val291500,"_match",L[197]);
var anf_obj4471483 = R.makeFunction(function(l2231484,typ2241485,bind2251486) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[198],3,arguments);
}
var anf_fun4451498 = G(A113,"s-variant-member",L[201]);
var $z14891490 = D;
var $f14951496 = function(_) {
return R.isFunction(desugar_DASH_bind116308.$var === D?U(L[199],"desugar-bind"):desugar_DASH_bind116308.$var)?desugar_DASH_bind116308.$var === D?U(L[199],"desugar-bind"):desugar_DASH_bind116308.$var.app(bind2251486):R.ffi.throwNonFunApp(L[200],desugar_DASH_bind116308.$var === D?U(L[199],"desugar-bind"):desugar_DASH_bind116308.$var,[bind2251486]);
};
try {
if(--R.GAS > 0) {
$z14891490 = $f14951496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14951496,
"from":L[200]});
}
} catch($e14871488) {
if(R.isCont($e14871488)) {
var $ss14911492 = {"from":L[200],
"go":function(anf_arg4461497) {
return $Hanf_arg15881499(anf_arg4461497,anf_fun4451498,l2231484,typ2241485);
}};
$e14871488.stack[R.EXN_STACKHEIGHT++] = $ss14911492;
}
if(R.isPyretException($e14871488)) {
$e14871488.pyretStack.push(L[200]);
}
throw $e14871488;
}
var $ret14931494 = $Hanf_arg15881499($z14891490,anf_fun4451498,l2231484,typ2241485);
++R.GAS;
return $ret14931494;
});
var anf_arg4481478 = R.makeObject({"s-variant-member":anf_obj4471483});
var anf_arg4501479 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[197],0,arguments);
}
var ann_DASH_check_DASH_temp4491482 = R.throwNoBranchesMatched(L[197],("cases"));
return ann_DASH_check_DASH_temp4491482;
});
var $z14691470 = D;
var $f14751476 = function(_) {
return R.isFunction(anf_fun4431477)?anf_fun4431477.app(anf_arg4481478,anf_arg4501479):R.ffi.throwNonFunApp(L[196],anf_fun4431477,[anf_arg4481478,anf_arg4501479]);
};
try {
if(--R.GAS > 0) {
$z14691470 = $f14751476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14751476,
"from":L[196]});
}
} catch($e14671468) {
if(R.isCont($e14671468)) {
var $ss14711472 = {"from":L[196],
"go":function(ann_DASH_check_DASH_temp4421480) {
return $Hann_DASH_check_DASH_temp15891481(ann_DASH_check_DASH_temp4421480);
}};
$e14671468.stack[R.EXN_STACKHEIGHT++] = $ss14711472;
}
if(R.isPyretException($e14671468)) {
$e14671468.pyretStack.push(L[196]);
}
throw $e14671468;
}
var $ret14731474 = $Hann_DASH_check_DASH_temp15891481($z14691470);
++R.GAS;
return $ret14731474;
});
desugar_DASH_variant_DASH_member108292.$var = anf_assign451293;
var anf_assign471295 = R.makeFunction(function(f2261399) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[185],1,arguments);
}
var cases_DASH_val301465 = f2261399;
var anf_fun4531410 = G(cases_DASH_val301465,"_match",L[186]);
var anf_obj4601427 = R.makeFunction(function(l2271445,name2281446,args2291447,ann2301448,doc2311449,body2321450,_check2331451) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[192],7,arguments);
}
var anf_fun4551463 = G(A113,"s-data-field",L[195]);
var $z14541455 = D;
var $f14601461 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[193],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[193],"desugar-expr"):desugar_DASH_expr117310.$var.app(name2281446):R.ffi.throwNonFunApp(L[194],desugar_DASH_expr117310.$var === D?U(L[193],"desugar-expr"):desugar_DASH_expr117310.$var,[name2281446]);
};
try {
if(--R.GAS > 0) {
$z14541455 = $f14601461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14601461,
"from":L[194]});
}
} catch($e14521453) {
if(R.isCont($e14521453)) {
var $ss14561457 = {"from":L[194],
"go":function(anf_arg4561462) {
return $Hanf_arg15931464(anf_arg4561462,A113,_check2331451,anf_fun4551463,ann2301448,args2291447,body2321450,desugar_DASH_expr117310,doc2311449,l2271445);
}};
$e14521453.stack[R.EXN_STACKHEIGHT++] = $ss14561457;
}
if(R.isPyretException($e14521453)) {
$e14521453.pyretStack.push(L[194]);
}
throw $e14521453;
}
var $ret14581459 = $Hanf_arg15931464($z14541455,A113,_check2331451,anf_fun4551463,ann2301448,args2291447,body2321450,desugar_DASH_expr117310,doc2311449,l2271445);
++R.GAS;
return $ret14581459;
});
var anf_obj4651428 = R.makeFunction(function(l2341429,name2351430,value2361431) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[188],3,arguments);
}
var anf_fun4621443 = G(A113,"s-data-field",L[191]);
var $z14341435 = D;
var $f14401441 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[189],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[189],"desugar-expr"):desugar_DASH_expr117310.$var.app(name2351430):R.ffi.throwNonFunApp(L[190],desugar_DASH_expr117310.$var === D?U(L[189],"desugar-expr"):desugar_DASH_expr117310.$var,[name2351430]);
};
try {
if(--R.GAS > 0) {
$z14341435 = $f14401441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14401441,
"from":L[190]});
}
} catch($e14321433) {
if(R.isCont($e14321433)) {
var $ss14361437 = {"from":L[190],
"go":function(anf_arg4631442) {
return $Hanf_arg15961444(anf_arg4631442,anf_fun4621443,desugar_DASH_expr117310,l2341429,value2361431);
}};
$e14321433.stack[R.EXN_STACKHEIGHT++] = $ss14361437;
}
if(R.isPyretException($e14321433)) {
$e14321433.pyretStack.push(L[190]);
}
throw $e14321433;
}
var $ret14381439 = $Hanf_arg15961444($z14341435,anf_fun4621443,desugar_DASH_expr117310,l2341429,value2361431);
++R.GAS;
return $ret14381439;
});
var anf_arg4661411 = R.makeObject({"s-method-field":anf_obj4601427,
"s-data-field":anf_obj4651428});
var anf_arg4701412 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[186],0,arguments);
}
var $z14171418 = D;
var $f14231424 = function(_) {
return R.isFunction(torepr11)?torepr11.app(f2261399):R.ffi.throwNonFunApp(L[187],torepr11,[f2261399]);
};
try {
if(--R.GAS > 0) {
$z14171418 = $f14231424();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14231424,
"from":L[187]});
}
} catch($e14151416) {
if(R.isCont($e14151416)) {
var $ss14191420 = {"from":L[187],
"go":function(anf_arg4681425) {
return $Hanf_arg15991426(anf_arg4681425,_plus7,raise10);
}};
$e14151416.stack[R.EXN_STACKHEIGHT++] = $ss14191420;
}
if(R.isPyretException($e14151416)) {
$e14151416.pyretStack.push(L[187]);
}
throw $e14151416;
}
var $ret14211422 = $Hanf_arg15991426($z14171418,_plus7,raise10);
++R.GAS;
return $ret14211422;
});
var $z14021403 = D;
var $f14081409 = function(_) {
return R.isFunction(anf_fun4531410)?anf_fun4531410.app(anf_arg4661411,anf_arg4701412):R.ffi.throwNonFunApp(L[185],anf_fun4531410,[anf_arg4661411,anf_arg4701412]);
};
try {
if(--R.GAS > 0) {
$z14021403 = $f14081409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14081409,
"from":L[185]});
}
} catch($e14001401) {
if(R.isCont($e14001401)) {
var $ss14041405 = {"from":L[185],
"go":function(ann_DASH_check_DASH_temp4521413) {
return $Hann_DASH_check_DASH_temp16001414(ann_DASH_check_DASH_temp4521413);
}};
$e14001401.stack[R.EXN_STACKHEIGHT++] = $ss14041405;
}
if(R.isPyretException($e14001401)) {
$e14001401.pyretStack.push(L[185]);
}
throw $e14001401;
}
var $ret14061407 = $Hann_DASH_check_DASH_temp16001414($z14021403);
++R.GAS;
return $ret14061407;
});
desugar_DASH_member109294.$var = anf_assign471295;
var anf_assign486297 = R.makeFunction(function(e2371385) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[182],1,arguments);
}
var anf_fun4731396 = G(A113,"is-s-id",L[184]);
var $z13881389 = D;
var $f13941395 = function(_) {
return R.isFunction(anf_fun4731396)?anf_fun4731396.app(e2371385):R.ffi.throwNonFunApp(L[183],anf_fun4731396,[e2371385]);
};
try {
if(--R.GAS > 0) {
$z13881389 = $f13941395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13941395,
"from":L[183]});
}
} catch($e13861387) {
if(R.isCont($e13861387)) {
var $ss13901391 = {"from":L[183],
"go":function(and_DASH_oper_DASH_311397) {
return $Hand_DASH_oper_DASH_16041398(and_DASH_oper_DASH_311397,A113,e2371385);
}};
$e13861387.stack[R.EXN_STACKHEIGHT++] = $ss13901391;
}
if(R.isPyretException($e13861387)) {
$e13861387.pyretStack.push(L[183]);
}
throw $e13861387;
}
var $ret13921393 = $Hand_DASH_oper_DASH_16041398($z13881389,A113,e2371385);
++R.GAS;
return $ret13921393;
});
is_DASH_underscore110296.$var = anf_assign486297;
var anf_assign519299 = R.makeFunction(function(l2381355,args2391356) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[178],2,arguments);
}
var anf_arg5071369 = R.makeFunction(function(acc2411371,arg2421372) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[180],2,arguments);
}
var $z13751376 = D;
var $f13811382 = function(_) {
return R.isFunction(is_DASH_underscore110296.$var)?is_DASH_underscore110296.$var.app(arg2421372):R.ffi.throwNonFunApp(L[181],is_DASH_underscore110296.$var,[arg2421372]);
};
try {
if(--R.GAS > 0) {
$z13751376 = $f13811382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13811382,
"from":L[181]});
}
} catch($e13731374) {
if(R.isCont($e13731374)) {
var $ss13771378 = {"from":L[181],
"go":function(if_DASH_331383) {
return $Hif_DASH_16111384(if_DASH_331383,acc2411371,arg2421372,l2381355,link3152,mk_DASH_id101278,pair8276);
}};
$e13731374.stack[R.EXN_STACKHEIGHT++] = $ss13771378;
}
if(R.isPyretException($e13731374)) {
$e13731374.pyretStack.push(L[181]);
}
throw $e13731374;
}
var $ret13791380 = $Hif_DASH_16111384($z13751376,acc2411371,arg2421372,l2381355,link3152,mk_DASH_id101278,pair8276);
++R.GAS;
return $ret13791380;
});
var anf_fun5081367 = G(list2753,"make",L[179]);
var $z13591360 = D;
var $f13651366 = function(_) {
return R.isFunction(anf_fun5081367)?anf_fun5081367.app([]):R.ffi.throwNonFunApp(L[179],anf_fun5081367,[[]]);
};
try {
if(--R.GAS > 0) {
$z13591360 = $f13651366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13651366,
"from":L[179]});
}
} catch($e13571358) {
if(R.isCont($e13571358)) {
var $ss13611362 = {"from":L[179],
"go":function(anf_arg5091368) {
return $Hanf_arg16181370(anf_arg5091368,anf_arg5071369,args2391356,fold5550,list2753,pair8276);
}};
$e13571358.stack[R.EXN_STACKHEIGHT++] = $ss13611362;
}
if(R.isPyretException($e13571358)) {
$e13571358.pyretStack.push(L[179]);
}
throw $e13571358;
}
var $ret13631364 = $Hanf_arg16181370($z13591360,anf_arg5071369,args2391356,fold5550,list2753,pair8276);
++R.GAS;
return $ret13631364;
});
ds_DASH_curry_DASH_args111298.$var = anf_assign519299;
var anf_assign540301 = R.makeFunction(function(rebuild_DASH_node2441339,l2451340,obj2461341,m2471342) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[176],4,arguments);
}
var $z13451346 = D;
var $f13511352 = function(_) {
return R.isFunction(is_DASH_underscore110296.$var)?is_DASH_underscore110296.$var.app(obj2461341):R.ffi.throwNonFunApp(L[177],is_DASH_underscore110296.$var,[obj2461341]);
};
try {
if(--R.GAS > 0) {
$z13451346 = $f13511352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13511352,
"from":L[177]});
}
} catch($e13431344) {
if(R.isCont($e13431344)) {
var $ss13471348 = {"from":L[177],
"go":function(if_DASH_341353) {
return $Hif_DASH_16261354(if_DASH_341353,A113,desugar_DASH_expr117310,l2451340,list2753,m2471342,mk_DASH_id101278,none6355,obj2461341,rebuild_DASH_node2441339);
}};
$e13431344.stack[R.EXN_STACKHEIGHT++] = $ss13471348;
}
if(R.isPyretException($e13431344)) {
$e13431344.pyretStack.push(L[177]);
}
throw $e13431344;
}
var $ret13491350 = $Hif_DASH_16261354($z13451346,A113,desugar_DASH_expr117310,l2451340,list2753,m2471342,mk_DASH_id101278,none6355,obj2461341,rebuild_DASH_node2441339);
++R.GAS;
return $ret13491350;
});
ds_DASH_curry_DASH_nullary112300.$var = anf_assign540301;
var anf_assign560303 = R.makeFunction(function(s2491322,e12501323,e22511324,rebuild2521325) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[174],4,arguments);
}
var anf_fun5421336 = G(list2753,"make",L[175]);
var $z13281329 = D;
var $f13341335 = function(_) {
return R.isFunction(anf_fun5421336)?anf_fun5421336.app([e12501323,e22511324]):R.ffi.throwNonFunApp(L[175],anf_fun5421336,[[e12501323,e22511324]]);
};
try {
if(--R.GAS > 0) {
$z13281329 = $f13341335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13341335,
"from":L[175]});
}
} catch($e13261327) {
if(R.isCont($e13261327)) {
var $ss13301331 = {"from":L[175],
"go":function(anf_arg5431337) {
return $Hanf_arg16331338(anf_arg5431337,A113,ds_DASH_curry_DASH_args111298,e12501323,e22511324,list2753,none6355,rebuild2521325,s2491322);
}};
$e13261327.stack[R.EXN_STACKHEIGHT++] = $ss13301331;
}
if(R.isPyretException($e13261327)) {
$e13261327.pyretStack.push(L[175]);
}
throw $e13261327;
}
var $ret13321333 = $Hanf_arg16331338($z13281329,A113,ds_DASH_curry_DASH_args111298,e12501323,e22511324,list2753,none6355,rebuild2521325,s2491322);
++R.GAS;
return $ret13321333;
});
ds_DASH_curry_DASH_binop113302.$var = anf_assign560303;
var anf_assign608305 = R.makeFunction(function(l2581261,f2591262,args2601263) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[168],3,arguments);
}
var fallthrough2611264 = {"$var":D,
"$name":"fallthrough"};
var anf_assign5801265 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[172],0,arguments);
}
var $z13121313 = D;
var $f13181319 = function(_) {
return R.isFunction(ds_DASH_curry_DASH_args111298.$var)?ds_DASH_curry_DASH_args111298.$var.app(l2581261,args2601263):R.ffi.throwNonFunApp(L[173],ds_DASH_curry_DASH_args111298.$var,[l2581261,args2601263]);
};
try {
if(--R.GAS > 0) {
$z13121313 = $f13181319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13181319,
"from":L[173]});
}
} catch($e13101311) {
if(R.isCont($e13101311)) {
var $ss13141315 = {"from":L[173],
"go":function(params_DASH_and_DASH_args2621320) {
return $Hparams_DASH_and_DASH_args16401321(params_DASH_and_DASH_args2621320,A113,args2601263,desugar_DASH_expr117310,f2591262,is_DASH_empty2851,l2581261,list2753,none6355);
}};
$e13101311.stack[R.EXN_STACKHEIGHT++] = $ss13141315;
}
if(R.isPyretException($e13101311)) {
$e13101311.pyretStack.push(L[173]);
}
throw $e13101311;
}
var $ret13161317 = $Hparams_DASH_and_DASH_args16401321($z13121313,A113,args2601263,desugar_DASH_expr117310,f2591262,is_DASH_empty2851,l2581261,list2753,none6355);
++R.GAS;
return $ret13161317;
});
fallthrough2611264.$var = anf_assign5801265;
var cases_DASH_val381309 = f2591262;
var anf_fun5811276 = G(cases_DASH_val381309,"_match",L[169]);
var anf_obj6041293 = R.makeFunction(function(l22651294,obj2661295,m2671296) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[170],3,arguments);
}
var $z12991300 = D;
var $f13051306 = function(_) {
return R.isFunction(is_DASH_underscore110296.$var)?is_DASH_underscore110296.$var.app(obj2661295):R.ffi.throwNonFunApp(L[171],is_DASH_underscore110296.$var,[obj2661295]);
};
try {
if(--R.GAS > 0) {
$z12991300 = $f13051306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13051306,
"from":L[171]});
}
} catch($e12971298) {
if(R.isCont($e12971298)) {
var $ss13011302 = {"from":L[171],
"go":function(if_DASH_371307) {
return $Hif_DASH_16491308(if_DASH_371307,A113,args2601263,ds_DASH_curry_DASH_args111298,fallthrough2611264,l2581261,link3152,list2753,m2671296,mk_DASH_id101278,none6355);
}};
$e12971298.stack[R.EXN_STACKHEIGHT++] = $ss13011302;
}
if(R.isPyretException($e12971298)) {
$e12971298.pyretStack.push(L[171]);
}
throw $e12971298;
}
var $ret13031304 = $Hif_DASH_16491308($z12991300,A113,args2601263,ds_DASH_curry_DASH_args111298,fallthrough2611264,l2581261,link3152,list2753,m2671296,mk_DASH_id101278,none6355);
++R.GAS;
return $ret13031304;
});
var anf_arg6051277 = R.makeObject({"s-dot":anf_obj6041293});
var anf_arg6071278 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[169],0,arguments);
}
var $z12831284 = D;
var $f12891290 = function(_) {
return R.isFunction(fallthrough2611264.$var)?fallthrough2611264.$var.app():R.ffi.throwNonFunApp(L[169],fallthrough2611264.$var,[]);
};
try {
if(--R.GAS > 0) {
$z12831284 = $f12891290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12891290,
"from":L[169]});
}
} catch($e12811282) {
if(R.isCont($e12811282)) {
var $ss12851286 = {"from":L[169],
"go":function(ann_DASH_check_DASH_temp6061291) {
return $Hann_DASH_check_DASH_temp16501292(ann_DASH_check_DASH_temp6061291);
}};
$e12811282.stack[R.EXN_STACKHEIGHT++] = $ss12851286;
}
if(R.isPyretException($e12811282)) {
$e12811282.pyretStack.push(L[169]);
}
throw $e12811282;
}
var $ret12871288 = $Hann_DASH_check_DASH_temp16501292($z12831284);
++R.GAS;
return $ret12871288;
});
var $z12681269 = D;
var $f12741275 = function(_) {
return R.isFunction(anf_fun5811276)?anf_fun5811276.app(anf_arg6051277,anf_arg6071278):R.ffi.throwNonFunApp(L[168],anf_fun5811276,[anf_arg6051277,anf_arg6071278]);
};
try {
if(--R.GAS > 0) {
$z12681269 = $f12741275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12741275,
"from":L[168]});
}
} catch($e12661267) {
if(R.isCont($e12661267)) {
var $ss12701271 = {"from":L[168],
"go":function(ann_DASH_check_DASH_temp5611279) {
return $Hann_DASH_check_DASH_temp16511280(ann_DASH_check_DASH_temp5611279);
}};
$e12661267.stack[R.EXN_STACKHEIGHT++] = $ss12701271;
}
if(R.isPyretException($e12661267)) {
$e12661267.pyretStack.push(L[168]);
}
throw $e12661267;
}
var $ret12721273 = $Hann_DASH_check_DASH_temp16511280($z12681269);
++R.GAS;
return $ret12721273;
});
ds_DASH_curry114304.$var = anf_assign608305;
var anf_assign619307 = R.makeFunction(function(f2721226,opt2731227) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[161],2,arguments);
}
return R.checkAnnArgs([R.Function,Option2045],[f2721226,opt2731227],[L[166],L[167]],function() {
var cases_DASH_val391260 = opt2731227;
var anf_fun6101238 = G(cases_DASH_val391260,"_match",L[162]);
var anf_obj6121244 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[165],0,arguments);
}
var ann_DASH_check_DASH_temp6111259 = none6355;
return ann_DASH_check_DASH_temp6111259;
});
var anf_obj6151245 = R.makeFunction(function(e2741246) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[163],1,arguments);
}
var $z12491250 = D;
var $f12551256 = function(_) {
return R.isFunction(f2721226)?f2721226.app(e2741246):R.ffi.throwNonFunApp(L[164],f2721226,[e2741246]);
};
try {
if(--R.GAS > 0) {
$z12491250 = $f12551256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12551256,
"from":L[164]});
}
} catch($e12471248) {
if(R.isCont($e12471248)) {
var $ss12511252 = {"from":L[164],
"go":function(anf_arg6141257) {
return $Hanf_arg16531258(anf_arg6141257,some6456);
}};
$e12471248.stack[R.EXN_STACKHEIGHT++] = $ss12511252;
}
if(R.isPyretException($e12471248)) {
$e12471248.pyretStack.push(L[164]);
}
throw $e12471248;
}
var $ret12531254 = $Hanf_arg16531258($z12491250,some6456);
++R.GAS;
return $ret12531254;
});
var anf_arg6161239 = R.makeObject({"none":anf_obj6121244,
"some":anf_obj6151245});
var anf_arg6181240 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[162],0,arguments);
}
var ann_DASH_check_DASH_temp6171243 = R.throwNoBranchesMatched(L[162],("cases"));
return ann_DASH_check_DASH_temp6171243;
});
var $z12301231 = D;
var $f12361237 = function(_) {
return R.isFunction(anf_fun6101238)?anf_fun6101238.app(anf_arg6161239,anf_arg6181240):R.ffi.throwNonFunApp(L[161],anf_fun6101238,[anf_arg6161239,anf_arg6181240]);
};
try {
if(--R.GAS > 0) {
$z12301231 = $f12361237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12361237,
"from":L[161]});
}
} catch($e12281229) {
if(R.isCont($e12281229)) {
var $ss12321233 = {"from":L[161],
"go":function(ann_DASH_check_DASH_temp6091241) {
return $Hann_DASH_check_DASH_temp16541242(ann_DASH_check_DASH_temp6091241);
}};
$e12281229.stack[R.EXN_STACKHEIGHT++] = $ss12321233;
}
if(R.isPyretException($e12281229)) {
$e12281229.pyretStack.push(L[161]);
}
throw $e12281229;
}
var $ret12341235 = $Hann_DASH_check_DASH_temp16541242($z12301231);
++R.GAS;
return $ret12341235;
});
});
desugar_DASH_opt115306.$var = anf_assign619307;
var anf_assign631309 = R.makeFunction(function(b2751179) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[154],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[160],"A",A222,"Bind")],[b2751179],[L[160]],function() {
var cases_DASH_val401225 = b2751179;
var anf_fun6211190 = G(cases_DASH_val401225,"_match",L[155]);
var anf_obj6251207 = R.makeFunction(function(l2761208,shadows2771209,name2781210,ann2791211) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[157],4,arguments);
}
var anf_fun6231223 = G(A113,"s-bind",L[159]);
var $z12141215 = D;
var $f12201221 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ann2791211):R.ffi.throwNonFunApp(L[158],desugar_DASH_ann98272.$var,[ann2791211]);
};
try {
if(--R.GAS > 0) {
$z12141215 = $f12201221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12201221,
"from":L[158]});
}
} catch($e12121213) {
if(R.isCont($e12121213)) {
var $ss12161217 = {"from":L[158],
"go":function(anf_arg6241222) {
return $Hanf_arg16561224(anf_arg6241222,anf_fun6231223,l2761208,name2781210,shadows2771209);
}};
$e12121213.stack[R.EXN_STACKHEIGHT++] = $ss12161217;
}
if(R.isPyretException($e12121213)) {
$e12121213.pyretStack.push(L[158]);
}
throw $e12121213;
}
var $ret12181219 = $Hanf_arg16561224($z12141215,anf_fun6231223,l2761208,name2781210,shadows2771209);
++R.GAS;
return $ret12181219;
});
var anf_arg6261191 = R.makeObject({"s-bind":anf_obj6251207});
var anf_arg6301192 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[155],0,arguments);
}
var $z11971198 = D;
var $f12031204 = function(_) {
return R.isFunction(torepr11)?torepr11.app(b2751179):R.ffi.throwNonFunApp(L[156],torepr11,[b2751179]);
};
try {
if(--R.GAS > 0) {
$z11971198 = $f12031204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12031204,
"from":L[156]});
}
} catch($e11951196) {
if(R.isCont($e11951196)) {
var $ss11991200 = {"from":L[156],
"go":function(anf_arg6281205) {
return $Hanf_arg16591206(anf_arg6281205,_plus7,raise10);
}};
$e11951196.stack[R.EXN_STACKHEIGHT++] = $ss11991200;
}
if(R.isPyretException($e11951196)) {
$e11951196.pyretStack.push(L[156]);
}
throw $e11951196;
}
var $ret12011202 = $Hanf_arg16591206($z11971198,_plus7,raise10);
++R.GAS;
return $ret12011202;
});
var $z11821183 = D;
var $f11881189 = function(_) {
return R.isFunction(anf_fun6211190)?anf_fun6211190.app(anf_arg6261191,anf_arg6301192):R.ffi.throwNonFunApp(L[154],anf_fun6211190,[anf_arg6261191,anf_arg6301192]);
};
try {
if(--R.GAS > 0) {
$z11821183 = $f11881189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11881189,
"from":L[154]});
}
} catch($e11801181) {
if(R.isCont($e11801181)) {
var $ss11841185 = {"from":L[154],
"go":function(ann_DASH_check_DASH_temp6201193) {
return $Hann_DASH_check_DASH_temp16601194(ann_DASH_check_DASH_temp6201193);
}};
$e11801181.stack[R.EXN_STACKHEIGHT++] = $ss11841185;
}
if(R.isPyretException($e11801181)) {
$e11801181.pyretStack.push(L[154]);
}
throw $e11801181;
}
var $ret11861187 = $Hann_DASH_check_DASH_temp16601194($z11821183);
++R.GAS;
return $ret11861187;
});
});
desugar_DASH_bind116308.$var = anf_assign631309;
var anf_assign1165311 = R.makeFunction(function(expr280326) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[19],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[153],"A",A222,"Expr")],[expr280326],[L[153]],function() {
var cases_DASH_val631178 = expr280326;
var anf_fun633337 = G(cases_DASH_val631178,"_match",L[20]);
var anf_obj641354 = R.makeFunction(function(l2811160,answer2821161,provides2831162,types2841163,checks2851164) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[150],5,arguments);
}
var anf_fun6351176 = G(A113,"s-module",L[152]);
var $z11671168 = D;
var $f11731174 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(answer2821161):R.ffi.throwNonFunApp(L[151],desugar_DASH_expr117310.$var,[answer2821161]);
};
try {
if(--R.GAS > 0) {
$z11671168 = $f11731174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11731174,
"from":L[151]});
}
} catch($e11651166) {
if(R.isCont($e11651166)) {
var $ss11691170 = {"from":L[151],
"go":function(anf_arg6361175) {
return $Hanf_arg16651177(anf_arg6361175,anf_fun6351176,checks2851164,desugar_DASH_afield97270,desugar_DASH_expr117310,l2811160,provides2831162,types2841163);
}};
$e11651166.stack[R.EXN_STACKHEIGHT++] = $ss11691170;
}
if(R.isPyretException($e11651166)) {
$e11651166.pyretStack.push(L[151]);
}
throw $e11651166;
}
var $ret11711172 = $Hanf_arg16651177($z11671168,anf_fun6351176,checks2851164,desugar_DASH_afield97270,desugar_DASH_expr117310,l2811160,provides2831162,types2841163);
++R.GAS;
return $ret11711172;
});
var anf_obj646355 = R.makeFunction(function(l2861144,stmts2871145) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[146],2,arguments);
}
var anf_fun6431158 = G(A113,"s-block",L[149]);
var anf_fun6441156 = G(stmts2871145,"map",L[148]);
var $z11481149 = D;
var $f11541155 = function(_) {
return R.isFunction(anf_fun6441156)?anf_fun6441156.app(desugar_DASH_expr117310.$var):R.ffi.throwNonFunApp(L[147],anf_fun6441156,[desugar_DASH_expr117310.$var]);
};
try {
if(--R.GAS > 0) {
$z11481149 = $f11541155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11541155,
"from":L[147]});
}
} catch($e11461147) {
if(R.isCont($e11461147)) {
var $ss11501151 = {"from":L[147],
"go":function(anf_arg6451157) {
return $Hanf_arg16671159(anf_arg6451157,anf_fun6431158,l2861144);
}};
$e11461147.stack[R.EXN_STACKHEIGHT++] = $ss11501151;
}
if(R.isPyretException($e11461147)) {
$e11461147.pyretStack.push(L[147]);
}
throw $e11461147;
}
var $ret11521153 = $Hanf_arg16671159($z11481149,anf_fun6431158,l2861144);
++R.GAS;
return $ret11521153;
});
var anf_obj648356 = R.makeFunction(function(l2881130,body2891131) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[145],2,arguments);
}
var $z11341135 = D;
var $f11401141 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(body2891131):R.ffi.throwNonFunApp(L[145],desugar_DASH_expr117310.$var,[body2891131]);
};
try {
if(--R.GAS > 0) {
$z11341135 = $f11401141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11401141,
"from":L[145]});
}
} catch($e11321133) {
if(R.isCont($e11321133)) {
var $ss11361137 = {"from":L[145],
"go":function(ann_DASH_check_DASH_temp6471142) {
return $Hann_DASH_check_DASH_temp16681143(ann_DASH_check_DASH_temp6471142);
}};
$e11321133.stack[R.EXN_STACKHEIGHT++] = $ss11361137;
}
if(R.isPyretException($e11321133)) {
$e11321133.pyretStack.push(L[145]);
}
throw $e11321133;
}
var $ret11381139 = $Hann_DASH_check_DASH_temp16681143($z11341135);
++R.GAS;
return $ret11381139;
});
var anf_obj652357 = R.makeFunction(function(l2901114,f2911115,args2921116) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[142],3,arguments);
}
var anf_fun6501127 = G(args2921116,"map",L[144]);
var $z11191120 = D;
var $f11251126 = function(_) {
return R.isFunction(anf_fun6501127)?anf_fun6501127.app(desugar_DASH_expr117310.$var):R.ffi.throwNonFunApp(L[143],anf_fun6501127,[desugar_DASH_expr117310.$var]);
};
try {
if(--R.GAS > 0) {
$z11191120 = $f11251126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11251126,
"from":L[143]});
}
} catch($e11171118) {
if(R.isCont($e11171118)) {
var $ss11211122 = {"from":L[143],
"go":function(anf_arg6511128) {
return $Hanf_arg16701129(anf_arg6511128,ds_DASH_curry114304,f2911115,l2901114);
}};
$e11171118.stack[R.EXN_STACKHEIGHT++] = $ss11211122;
}
if(R.isPyretException($e11171118)) {
$e11171118.pyretStack.push(L[143]);
}
throw $e11171118;
}
var $ret11231124 = $Hanf_arg16701129($z11191120,ds_DASH_curry114304,f2911115,l2901114);
++R.GAS;
return $ret11231124;
});
var anf_obj657358 = R.makeFunction(function(l2931097,f2941098,args2951099) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[138],3,arguments);
}
var anf_fun6541112 = G(A113,"s-prim-app",L[141]);
var anf_fun6551110 = G(args2951099,"map",L[140]);
var $z11021103 = D;
var $f11081109 = function(_) {
return R.isFunction(anf_fun6551110)?anf_fun6551110.app(desugar_DASH_expr117310.$var):R.ffi.throwNonFunApp(L[139],anf_fun6551110,[desugar_DASH_expr117310.$var]);
};
try {
if(--R.GAS > 0) {
$z11021103 = $f11081109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11081109,
"from":L[139]});
}
} catch($e11001101) {
if(R.isCont($e11001101)) {
var $ss11041105 = {"from":L[139],
"go":function(anf_arg6561111) {
return $Hanf_arg16721113(anf_arg6561111,anf_fun6541112,f2941098,l2931097);
}};
$e11001101.stack[R.EXN_STACKHEIGHT++] = $ss11041105;
}
if(R.isPyretException($e11001101)) {
$e11001101.pyretStack.push(L[139]);
}
throw $e11001101;
}
var $ret11061107 = $Hanf_arg16721113($z11021103,anf_fun6541112,f2941098,l2931097);
++R.GAS;
return $ret11061107;
});
var anf_obj665359 = R.makeFunction(function(l2961076,params2971077,args2981078,ann2991079,doc3001080,body3011081,_check3021082) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[134],7,arguments);
}
var anf_fun6591095 = G(A113,"s-lam",L[137]);
var anf_fun6601093 = G(args2981078,"map",L[136]);
var $z10851086 = D;
var $f10911092 = function(_) {
return R.isFunction(anf_fun6601093)?anf_fun6601093.app(desugar_DASH_bind116308.$var):R.ffi.throwNonFunApp(L[135],anf_fun6601093,[desugar_DASH_bind116308.$var]);
};
try {
if(--R.GAS > 0) {
$z10851086 = $f10911092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10911092,
"from":L[135]});
}
} catch($e10831084) {
if(R.isCont($e10831084)) {
var $ss10871088 = {"from":L[135],
"go":function(anf_arg6611094) {
return $Hanf_arg16771096(anf_arg6611094,_check3021082,anf_fun6591095,ann2991079,body3011081,desugar_DASH_ann98272,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077);
}};
$e10831084.stack[R.EXN_STACKHEIGHT++] = $ss10871088;
}
if(R.isPyretException($e10831084)) {
$e10831084.pyretStack.push(L[135]);
}
throw $e10831084;
}
var $ret10891090 = $Hanf_arg16771096($z10851086,_check3021082,anf_fun6591095,ann2991079,body3011081,desugar_DASH_ann98272,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077);
++R.GAS;
return $ret10891090;
});
var anf_obj673360 = R.makeFunction(function(l3031056,args3041057,ann3051058,doc3061059,body3071060,_check3081061) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[130],6,arguments);
}
var anf_fun6671074 = G(A113,"s-method",L[133]);
var anf_fun6681072 = G(args3041057,"map",L[132]);
var $z10641065 = D;
var $f10701071 = function(_) {
return R.isFunction(anf_fun6681072)?anf_fun6681072.app(desugar_DASH_bind116308.$var):R.ffi.throwNonFunApp(L[131],anf_fun6681072,[desugar_DASH_bind116308.$var]);
};
try {
if(--R.GAS > 0) {
$z10641065 = $f10701071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10701071,
"from":L[131]});
}
} catch($e10621063) {
if(R.isCont($e10621063)) {
var $ss10661067 = {"from":L[131],
"go":function(anf_arg6691073) {
return $Hanf_arg16821075(anf_arg6691073,_check3081061,anf_fun6671074,ann3051058,body3071060,desugar_DASH_ann98272,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056);
}};
$e10621063.stack[R.EXN_STACKHEIGHT++] = $ss10661067;
}
if(R.isPyretException($e10621063)) {
$e10621063.pyretStack.push(L[131]);
}
throw $e10621063;
}
var $ret10681069 = $Hanf_arg16821075($z10641065,_check3081061,anf_fun6671074,ann3051058,body3071060,desugar_DASH_ann98272,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056);
++R.GAS;
return $ret10681069;
});
var anf_obj677361 = R.makeFunction(function(l3091039,name3101040,value3111041,keyword_DASH_val3121042) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[127],4,arguments);
}
var anf_fun6751054 = G(A113,"s-let",L[129]);
var $z10451046 = D;
var $f10511052 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(value3111041):R.ffi.throwNonFunApp(L[128],desugar_DASH_expr117310.$var,[value3111041]);
};
try {
if(--R.GAS > 0) {
$z10451046 = $f10511052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10511052,
"from":L[128]});
}
} catch($e10431044) {
if(R.isCont($e10431044)) {
var $ss10471048 = {"from":L[128],
"go":function(anf_arg6761053) {
return $Hanf_arg16841055(anf_arg6761053,anf_fun6751054,keyword_DASH_val3121042,l3091039,name3101040);
}};
$e10431044.stack[R.EXN_STACKHEIGHT++] = $ss10471048;
}
if(R.isPyretException($e10431044)) {
$e10431044.pyretStack.push(L[128]);
}
throw $e10431044;
}
var $ret10491050 = $Hanf_arg16841055($z10451046,anf_fun6751054,keyword_DASH_val3121042,l3091039,name3101040);
++R.GAS;
return $ret10491050;
});
var anf_obj681362 = R.makeFunction(function(l3131023,name3141024,ann3151025) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[124],3,arguments);
}
var anf_fun6791037 = G(A113,"s-type",L[126]);
var $z10281029 = D;
var $f10341035 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ann3151025):R.ffi.throwNonFunApp(L[125],desugar_DASH_ann98272.$var,[ann3151025]);
};
try {
if(--R.GAS > 0) {
$z10281029 = $f10341035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10341035,
"from":L[125]});
}
} catch($e10261027) {
if(R.isCont($e10261027)) {
var $ss10301031 = {"from":L[125],
"go":function(anf_arg6801036) {
return $Hanf_arg16861038(anf_arg6801036,anf_fun6791037,l3131023,name3141024);
}};
$e10261027.stack[R.EXN_STACKHEIGHT++] = $ss10301031;
}
if(R.isPyretException($e10261027)) {
$e10261027.pyretStack.push(L[125]);
}
throw $e10261027;
}
var $ret10321033 = $Hanf_arg16861038($z10281029,anf_fun6791037,l3131023,name3141024);
++R.GAS;
return $ret10321033;
});
var anf_obj683363 = R.makeFunction(function(l3161019,name3171020,namet3181021) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[123],3,arguments);
}
var ann_DASH_check_DASH_temp6821022 = expr280326;
return ann_DASH_check_DASH_temp6821022;
});
var anf_obj701364 = R.makeFunction(function(l319960,binds320961,body321962) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[113],3,arguments);
}
var desugar_DASH_type_DASH_bind322963 = {"$var":D,
"$name":"desugar-type-bind"};
var anf_assign696964 = R.makeFunction(function(tb323979) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
var cases_DASH_val411018 = tb323979;
var anf_fun686990 = G(cases_DASH_val411018,"_match",L[118]);
var anf_obj690996 = R.makeFunction(function(l23241002,name3251003,ann3261004) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[120],3,arguments);
}
var anf_fun6881016 = G(A113,"s-type-bind",L[122]);
var $z10071008 = D;
var $f10131014 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ann3261004):R.ffi.throwNonFunApp(L[121],desugar_DASH_ann98272.$var,[ann3261004]);
};
try {
if(--R.GAS > 0) {
$z10071008 = $f10131014();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10131014,
"from":L[121]});
}
} catch($e10051006) {
if(R.isCont($e10051006)) {
var $ss10091010 = {"from":L[121],
"go":function(anf_arg6891015) {
return $Hanf_arg16881017(anf_arg6891015,anf_fun6881016,l23241002,name3251003);
}};
$e10051006.stack[R.EXN_STACKHEIGHT++] = $ss10091010;
}
if(R.isPyretException($e10051006)) {
$e10051006.pyretStack.push(L[121]);
}
throw $e10051006;
}
var $ret10111012 = $Hanf_arg16881017($z10071008,anf_fun6881016,l23241002,name3251003);
++R.GAS;
return $ret10111012;
});
var anf_obj692997 = R.makeFunction(function(l2327998,name328999,nameb3291000) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[119],3,arguments);
}
var ann_DASH_check_DASH_temp6911001 = tb323979;
return ann_DASH_check_DASH_temp6911001;
});
var anf_arg693991 = R.makeObject({"s-type-bind":anf_obj690996,
"s-newtype-bind":anf_obj692997});
var anf_arg695992 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[118],0,arguments);
}
var ann_DASH_check_DASH_temp694995 = R.throwNoBranchesMatched(L[118],("cases"));
return ann_DASH_check_DASH_temp694995;
});
var $z982983 = D;
var $f988989 = function(_) {
return R.isFunction(anf_fun686990)?anf_fun686990.app(anf_arg693991,anf_arg695992):R.ffi.throwNonFunApp(L[117],anf_fun686990,[anf_arg693991,anf_arg695992]);
};
try {
if(--R.GAS > 0) {
$z982983 = $f988989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f988989,
"from":L[117]});
}
} catch($e980981) {
if(R.isCont($e980981)) {
var $ss984985 = {"from":L[117],
"go":function(ann_DASH_check_DASH_temp685993) {
return $Hann_DASH_check_DASH_temp1689994(ann_DASH_check_DASH_temp685993);
}};
$e980981.stack[R.EXN_STACKHEIGHT++] = $ss984985;
}
if(R.isPyretException($e980981)) {
$e980981.pyretStack.push(L[117]);
}
throw $e980981;
}
var $ret986987 = $Hann_DASH_check_DASH_temp1689994($z982983);
++R.GAS;
return $ret986987;
});
desugar_DASH_type_DASH_bind322963.$var = anf_assign696964;
var anf_fun697977 = G(A113,"s-type-let-expr",L[116]);
var anf_fun698975 = G(binds320961,"map",L[115]);
var $z967968 = D;
var $f973974 = function(_) {
return R.isFunction(anf_fun698975)?anf_fun698975.app(desugar_DASH_type_DASH_bind322963.$var):R.ffi.throwNonFunApp(L[114],anf_fun698975,[desugar_DASH_type_DASH_bind322963.$var]);
};
try {
if(--R.GAS > 0) {
$z967968 = $f973974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f973974,
"from":L[114]});
}
} catch($e965966) {
if(R.isCont($e965966)) {
var $ss969970 = {"from":L[114],
"go":function(anf_arg699976) {
return $Hanf_arg1692978(anf_arg699976,anf_fun697977,body321962,desugar_DASH_expr117310,l319960);
}};
$e965966.stack[R.EXN_STACKHEIGHT++] = $ss969970;
}
if(R.isPyretException($e965966)) {
$e965966.pyretStack.push(L[114]);
}
throw $e965966;
}
var $ret971972 = $Hanf_arg1692978($z967968,anf_fun697977,body321962,desugar_DASH_expr117310,l319960);
++R.GAS;
return $ret971972;
});
var anf_obj721365 = R.makeFunction(function(l330892,binds331893,body332894) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[103],3,arguments);
}
var anf_arg718905 = R.makeFunction(function(bind334908) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[105],1,arguments);
}
var cases_DASH_val42959 = bind334908;
var anf_fun704919 = G(cases_DASH_val42959,"_match",L[106]);
var anf_obj709925 = R.makeFunction(function(l2335943,b336944,val337945) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[110],3,arguments);
}
var anf_fun706957 = G(A113,"s-let-bind",L[112]);
var $z948949 = D;
var $f954955 = function(_) {
return R.isFunction(desugar_DASH_bind116308.$var)?desugar_DASH_bind116308.$var.app(b336944):R.ffi.throwNonFunApp(L[111],desugar_DASH_bind116308.$var,[b336944]);
};
try {
if(--R.GAS > 0) {
$z948949 = $f954955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f954955,
"from":L[111]});
}
} catch($e946947) {
if(R.isCont($e946947)) {
var $ss950951 = {"from":L[111],
"go":function(anf_arg707956) {
return $Hanf_arg1695958(anf_arg707956,anf_fun706957,desugar_DASH_expr117310,l2335943,val337945);
}};
$e946947.stack[R.EXN_STACKHEIGHT++] = $ss950951;
}
if(R.isPyretException($e946947)) {
$e946947.pyretStack.push(L[111]);
}
throw $e946947;
}
var $ret952953 = $Hanf_arg1695958($z948949,anf_fun706957,desugar_DASH_expr117310,l2335943,val337945);
++R.GAS;
return $ret952953;
});
var anf_obj714926 = R.makeFunction(function(l2338927,b339928,val340929) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[107],3,arguments);
}
var anf_fun711941 = G(A113,"s-var-bind",L[109]);
var $z932933 = D;
var $f938939 = function(_) {
return R.isFunction(desugar_DASH_bind116308.$var)?desugar_DASH_bind116308.$var.app(b339928):R.ffi.throwNonFunApp(L[108],desugar_DASH_bind116308.$var,[b339928]);
};
try {
if(--R.GAS > 0) {
$z932933 = $f938939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f938939,
"from":L[108]});
}
} catch($e930931) {
if(R.isCont($e930931)) {
var $ss934935 = {"from":L[108],
"go":function(anf_arg712940) {
return $Hanf_arg1698942(anf_arg712940,anf_fun711941,desugar_DASH_expr117310,l2338927,val340929);
}};
$e930931.stack[R.EXN_STACKHEIGHT++] = $ss934935;
}
if(R.isPyretException($e930931)) {
$e930931.pyretStack.push(L[108]);
}
throw $e930931;
}
var $ret936937 = $Hanf_arg1698942($z932933,anf_fun711941,desugar_DASH_expr117310,l2338927,val340929);
++R.GAS;
return $ret936937;
});
var anf_arg715920 = R.makeObject({"s-let-bind":anf_obj709925,
"s-var-bind":anf_obj714926});
var anf_arg717921 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[106],0,arguments);
}
var ann_DASH_check_DASH_temp716924 = R.throwNoBranchesMatched(L[106],("cases"));
return ann_DASH_check_DASH_temp716924;
});
var $z911912 = D;
var $f917918 = function(_) {
return R.isFunction(anf_fun704919)?anf_fun704919.app(anf_arg715920,anf_arg717921):R.ffi.throwNonFunApp(L[105],anf_fun704919,[anf_arg715920,anf_arg717921]);
};
try {
if(--R.GAS > 0) {
$z911912 = $f917918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f917918,
"from":L[105]});
}
} catch($e909910) {
if(R.isCont($e909910)) {
var $ss913914 = {"from":L[105],
"go":function(ann_DASH_check_DASH_temp703922) {
return $Hann_DASH_check_DASH_temp1699923(ann_DASH_check_DASH_temp703922);
}};
$e909910.stack[R.EXN_STACKHEIGHT++] = $ss913914;
}
if(R.isPyretException($e909910)) {
$e909910.pyretStack.push(L[105]);
}
throw $e909910;
}
var $ret915916 = $Hann_DASH_check_DASH_temp1699923($z911912);
++R.GAS;
return $ret915916;
});
var $z897898 = D;
var $f903904 = function(_) {
return R.isFunction(map3954)?map3954.app(anf_arg718905,binds331893):R.ffi.throwNonFunApp(L[104],map3954,[anf_arg718905,binds331893]);
};
try {
if(--R.GAS > 0) {
$z897898 = $f903904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f903904,
"from":L[104]});
}
} catch($e895896) {
if(R.isCont($e895896)) {
var $ss899900 = {"from":L[104],
"go":function(new_DASH_binds333906) {
return $Hnew_DASH_binds1702907(new_DASH_binds333906,A113,body332894,desugar_DASH_expr117310,l330892);
}};
$e895896.stack[R.EXN_STACKHEIGHT++] = $ss899900;
}
if(R.isPyretException($e895896)) {
$e895896.pyretStack.push(L[104]);
}
throw $e895896;
}
var $ret901902 = $Hnew_DASH_binds1702907($z897898,A113,body332894,desugar_DASH_expr117310,l330892);
++R.GAS;
return $ret901902;
});
var anf_obj736366 = R.makeFunction(function(l341841,binds342842,body343843) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[96],3,arguments);
}
var anf_arg733854 = R.makeFunction(function(bind345857) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[98],1,arguments);
}
var cases_DASH_val43891 = bind345857;
var anf_fun724868 = G(cases_DASH_val43891,"_match",L[99]);
var anf_obj729874 = R.makeFunction(function(l2346875,b347876,val348877) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[100],3,arguments);
}
var anf_fun726889 = G(A113,"s-letrec-bind",L[102]);
var $z880881 = D;
var $f886887 = function(_) {
return R.isFunction(desugar_DASH_bind116308.$var)?desugar_DASH_bind116308.$var.app(b347876):R.ffi.throwNonFunApp(L[101],desugar_DASH_bind116308.$var,[b347876]);
};
try {
if(--R.GAS > 0) {
$z880881 = $f886887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f886887,
"from":L[101]});
}
} catch($e878879) {
if(R.isCont($e878879)) {
var $ss882883 = {"from":L[101],
"go":function(anf_arg727888) {
return $Hanf_arg1705890(anf_arg727888,anf_fun726889,desugar_DASH_expr117310,l2346875,val348877);
}};
$e878879.stack[R.EXN_STACKHEIGHT++] = $ss882883;
}
if(R.isPyretException($e878879)) {
$e878879.pyretStack.push(L[101]);
}
throw $e878879;
}
var $ret884885 = $Hanf_arg1705890($z880881,anf_fun726889,desugar_DASH_expr117310,l2346875,val348877);
++R.GAS;
return $ret884885;
});
var anf_arg730869 = R.makeObject({"s-letrec-bind":anf_obj729874});
var anf_arg732870 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[99],0,arguments);
}
var ann_DASH_check_DASH_temp731873 = R.throwNoBranchesMatched(L[99],("cases"));
return ann_DASH_check_DASH_temp731873;
});
var $z860861 = D;
var $f866867 = function(_) {
return R.isFunction(anf_fun724868)?anf_fun724868.app(anf_arg730869,anf_arg732870):R.ffi.throwNonFunApp(L[98],anf_fun724868,[anf_arg730869,anf_arg732870]);
};
try {
if(--R.GAS > 0) {
$z860861 = $f866867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f866867,
"from":L[98]});
}
} catch($e858859) {
if(R.isCont($e858859)) {
var $ss862863 = {"from":L[98],
"go":function(ann_DASH_check_DASH_temp723871) {
return $Hann_DASH_check_DASH_temp1706872(ann_DASH_check_DASH_temp723871);
}};
$e858859.stack[R.EXN_STACKHEIGHT++] = $ss862863;
}
if(R.isPyretException($e858859)) {
$e858859.pyretStack.push(L[98]);
}
throw $e858859;
}
var $ret864865 = $Hann_DASH_check_DASH_temp1706872($z860861);
++R.GAS;
return $ret864865;
});
var $z846847 = D;
var $f852853 = function(_) {
return R.isFunction(map3954)?map3954.app(anf_arg733854,binds342842):R.ffi.throwNonFunApp(L[97],map3954,[anf_arg733854,binds342842]);
};
try {
if(--R.GAS > 0) {
$z846847 = $f852853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f852853,
"from":L[97]});
}
} catch($e844845) {
if(R.isCont($e844845)) {
var $ss848849 = {"from":L[97],
"go":function(new_DASH_binds344855) {
return $Hnew_DASH_binds1709856(new_DASH_binds344855,A113,body343843,desugar_DASH_expr117310,l341841);
}};
$e844845.stack[R.EXN_STACKHEIGHT++] = $ss848849;
}
if(R.isPyretException($e844845)) {
$e844845.pyretStack.push(L[97]);
}
throw $e844845;
}
var $ret850851 = $Hnew_DASH_binds1709856($z846847,A113,body343843,desugar_DASH_expr117310,l341841);
++R.GAS;
return $ret850851;
});
var anf_obj808367 = R.makeFunction(function(l349740,name350741,namet351742,params352743,mixins353744,variants354745,shared355746,_check356747) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[80],8,arguments);
}
var extend_DASH_variant357748 = {"$var":D,
"$name":"extend-variant"};
var anf_assign799749 = R.makeFunction(function(v358764) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[84],1,arguments);
}
var make_DASH_methods359765 = {"$var":D,
"$name":"make-methods"};
var anf_assign778766 = R.makeFunction(function(l2360819,vname361820,members362821,is_DASH_singleton363822) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[90],4,arguments);
}
var anf_fun740833 = G(lists1118,"any",L[95]);
var anf_arg744834 = R.makeFunction(function(s365837) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[92],1,arguments);
}
var anf_bracket742840 = G(s365837,"name",L[94]);
var anf_arg743839 = G(anf_bracket742840,"s",L[93]);
var ann_DASH_check_DASH_temp741838 = R.equiv(anf_arg743839,("_match"));
return ann_DASH_check_DASH_temp741838;
});
var $z825826 = D;
var $f831832 = function(_) {
return R.isFunction(anf_fun740833)?anf_fun740833.app(anf_arg744834,shared355746):R.ffi.throwNonFunApp(L[91],anf_fun740833,[anf_arg744834,shared355746]);
};
try {
if(--R.GAS > 0) {
$z825826 = $f831832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f831832,
"from":L[91]});
}
} catch($e823824) {
if(R.isCont($e823824)) {
var $ss827828 = {"from":L[91],
"go":function(if_DASH_44835) {
return $Hif_DASH_1722836(if_DASH_44835,A113,empty3049,is_DASH_singleton363822,l2360819,list2753,lists1118,make_DASH_match103282,make_DASH_torepr102280,members362821,shared355746,vname361820,_plus7);
}};
$e823824.stack[R.EXN_STACKHEIGHT++] = $ss827828;
}
if(R.isPyretException($e823824)) {
$e823824.pyretStack.push(L[91]);
}
throw $e823824;
}
var $ret829830 = $Hif_DASH_1722836($z825826,A113,empty3049,is_DASH_singleton363822,l2360819,list2753,lists1118,make_DASH_match103282,make_DASH_torepr102280,members362821,shared355746,vname361820,_plus7);
++R.GAS;
return $ret829830;
});
make_DASH_methods359765.$var = anf_assign778766;
var cases_DASH_val46818 = v358764;
var anf_fun779777 = G(cases_DASH_val46818,"_match",L[85]);
var anf_obj787783 = R.makeFunction(function(l2368801,constr_DASH_loc369802,vname370803,members371804,with_DASH_members372805) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[88],5,arguments);
}
var $z808809 = D;
var $f814815 = function(_) {
return R.isFunction(make_DASH_methods359765.$var)?make_DASH_methods359765.$var.app(l2368801,vname370803,members371804,(false)):R.ffi.throwNonFunApp(L[89],make_DASH_methods359765.$var,[l2368801,vname370803,members371804,(false)]);
};
try {
if(--R.GAS > 0) {
$z808809 = $f814815();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f814815,
"from":L[89]});
}
} catch($e806807) {
if(R.isCont($e806807)) {
var $ss810811 = {"from":L[89],
"go":function(methods373816) {
return $Hmethods1727817(methods373816,A113,constr_DASH_loc369802,desugar_DASH_member109294,desugar_DASH_variant_DASH_member108292,l2368801,members371804,vname370803,with_DASH_members372805,_plus7);
}};
$e806807.stack[R.EXN_STACKHEIGHT++] = $ss810811;
}
if(R.isPyretException($e806807)) {
$e806807.pyretStack.push(L[89]);
}
throw $e806807;
}
var $ret812813 = $Hmethods1727817($z808809,A113,constr_DASH_loc369802,desugar_DASH_member109294,desugar_DASH_variant_DASH_member108292,l2368801,members371804,vname370803,with_DASH_members372805,_plus7);
++R.GAS;
return $ret812813;
});
var anf_obj795784 = R.makeFunction(function(l2374785,vname375786,with_DASH_members376787) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[86],3,arguments);
}
var anf_fun789798 = G(list2753,"make",L[87]);
var $z790791 = D;
var $f796797 = function(_) {
return R.isFunction(anf_fun789798)?anf_fun789798.app([]):R.ffi.throwNonFunApp(L[87],anf_fun789798,[[]]);
};
try {
if(--R.GAS > 0) {
$z790791 = $f796797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f796797,
"from":L[87]});
}
} catch($e788789) {
if(R.isCont($e788789)) {
var $ss792793 = {"from":L[87],
"go":function(anf_arg790799) {
return $Hanf_arg1732800(anf_arg790799,A113,desugar_DASH_member109294,l2374785,make_DASH_methods359765,vname375786,with_DASH_members376787,_plus7);
}};
$e788789.stack[R.EXN_STACKHEIGHT++] = $ss792793;
}
if(R.isPyretException($e788789)) {
$e788789.pyretStack.push(L[87]);
}
throw $e788789;
}
var $ret794795 = $Hanf_arg1732800($z790791,A113,desugar_DASH_member109294,l2374785,make_DASH_methods359765,vname375786,with_DASH_members376787,_plus7);
++R.GAS;
return $ret794795;
});
var anf_arg796778 = R.makeObject({"s-variant":anf_obj787783,
"s-singleton-variant":anf_obj795784});
var anf_arg798779 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[85],0,arguments);
}
var ann_DASH_check_DASH_temp797782 = R.throwNoBranchesMatched(L[85],("cases"));
return ann_DASH_check_DASH_temp797782;
});
var $z769770 = D;
var $f775776 = function(_) {
return R.isFunction(anf_fun779777)?anf_fun779777.app(anf_arg796778,anf_arg798779):R.ffi.throwNonFunApp(L[84],anf_fun779777,[anf_arg796778,anf_arg798779]);
};
try {
if(--R.GAS > 0) {
$z769770 = $f775776();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f775776,
"from":L[84]});
}
} catch($e767768) {
if(R.isCont($e767768)) {
var $ss771772 = {"from":L[84],
"go":function(ann_DASH_check_DASH_temp738780) {
return $Hann_DASH_check_DASH_temp1733781(ann_DASH_check_DASH_temp738780);
}};
$e767768.stack[R.EXN_STACKHEIGHT++] = $ss771772;
}
if(R.isPyretException($e767768)) {
$e767768.pyretStack.push(L[84]);
}
throw $e767768;
}
var $ret773774 = $Hann_DASH_check_DASH_temp1733781($z769770);
++R.GAS;
return $ret773774;
});
extend_DASH_variant357748.$var = anf_assign799749;
var anf_fun800762 = G(A113,"s-data-expr",L[83]);
var anf_fun801760 = G(mixins353744,"map",L[82]);
var $z752753 = D;
var $f758759 = function(_) {
return R.isFunction(anf_fun801760)?anf_fun801760.app(desugar_DASH_expr117310.$var):R.ffi.throwNonFunApp(L[81],anf_fun801760,[desugar_DASH_expr117310.$var]);
};
try {
if(--R.GAS > 0) {
$z752753 = $f758759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f758759,
"from":L[81]});
}
} catch($e750751) {
if(R.isCont($e750751)) {
var $ss754755 = {"from":L[81],
"go":function(anf_arg802761) {
return $Hanf_arg1738763(anf_arg802761,_check356747,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_member109294,desugar_DASH_opt115306,extend_DASH_variant357748,l349740,name350741,namet351742,params352743,shared355746,variants354745);
}};
$e750751.stack[R.EXN_STACKHEIGHT++] = $ss754755;
}
if(R.isPyretException($e750751)) {
$e750751.pyretStack.push(L[81]);
}
throw $e750751;
}
var $ret756757 = $Hanf_arg1738763($z752753,_check356747,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_member109294,desugar_DASH_opt115306,extend_DASH_variant357748,l349740,name350741,namet351742,params352743,shared355746,variants354745);
++R.GAS;
return $ret756757;
});
var anf_obj832368 = R.makeFunction(function(l378725,test379726,body380727) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[78],3,arguments);
}
var $z730731 = D;
var $f736737 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l378725,("when-")):R.ffi.throwNonFunApp(L[79],mk_DASH_id101278.$var,[l378725,("when-")]);
};
try {
if(--R.GAS > 0) {
$z730731 = $f736737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f736737,
"from":L[79]});
}
} catch($e728729) {
if(R.isCont($e728729)) {
var $ss732733 = {"from":L[79],
"go":function(test_DASH_id381738) {
return $Htest_DASH_id1752739(test_DASH_id381738,A113,body380727,bool_DASH_exn95266,check_DASH_bool91258,desugar_DASH_expr117310,gid90256,l378725,list2753,test379726);
}};
$e728729.stack[R.EXN_STACKHEIGHT++] = $ss732733;
}
if(R.isPyretException($e728729)) {
$e728729.pyretStack.push(L[79]);
}
throw $e728729;
}
var $ret734735 = $Htest_DASH_id1752739($z730731,A113,body380727,bool_DASH_exn95266,check_DASH_bool91258,desugar_DASH_expr117310,gid90256,l378725,list2753,test379726);
++R.GAS;
return $ret734735;
});
var anf_obj839369 = R.makeFunction(function(l382709,branches383710) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[74],2,arguments);
}
var anf_fun834722 = G(A113,"s-block",L[77]);
var anf_fun835723 = G(list2753,"make",L[76]);
var $z713714 = D;
var $f719720 = function(_) {
return R.isFunction(no_DASH_branches_DASH_exn92260.$var)?no_DASH_branches_DASH_exn92260.$var.app(l382709,("if")):R.ffi.throwNonFunApp(L[75],no_DASH_branches_DASH_exn92260.$var,[l382709,("if")]);
};
try {
if(--R.GAS > 0) {
$z713714 = $f719720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f719720,
"from":L[75]});
}
} catch($e711712) {
if(R.isCont($e711712)) {
var $ss715716 = {"from":L[75],
"go":function(anf_array_val836721) {
return $Hanf_array_val1756724(anf_array_val836721,anf_fun834722,anf_fun835723,branches383710,desugar_DASH_if105286,l382709);
}};
$e711712.stack[R.EXN_STACKHEIGHT++] = $ss715716;
}
if(R.isPyretException($e711712)) {
$e711712.pyretStack.push(L[75]);
}
throw $e711712;
}
var $ret717718 = $Hanf_array_val1756724($z713714,anf_fun834722,anf_fun835723,branches383710,desugar_DASH_if105286,l382709);
++R.GAS;
return $ret717718;
});
var anf_obj841370 = R.makeFunction(function(l384694,branches385695,_else386696) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[73],3,arguments);
}
var $z699700 = D;
var $f705706 = function(_) {
return R.isFunction(desugar_DASH_if105286.$var)?desugar_DASH_if105286.$var.app(l384694,branches385695,_else386696):R.ffi.throwNonFunApp(L[73],desugar_DASH_if105286.$var,[l384694,branches385695,_else386696]);
};
try {
if(--R.GAS > 0) {
$z699700 = $f705706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f705706,
"from":L[73]});
}
} catch($e697698) {
if(R.isCont($e697698)) {
var $ss701702 = {"from":L[73],
"go":function(ann_DASH_check_DASH_temp840707) {
return $Hann_DASH_check_DASH_temp1757708(ann_DASH_check_DASH_temp840707);
}};
$e697698.stack[R.EXN_STACKHEIGHT++] = $ss701702;
}
if(R.isPyretException($e697698)) {
$e697698.pyretStack.push(L[73]);
}
throw $e697698;
}
var $ret703704 = $Hann_DASH_check_DASH_temp1757708($z699700);
++R.GAS;
return $ret703704;
});
var anf_obj848371 = R.makeFunction(function(l387678,branches388679) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[69],2,arguments);
}
var anf_fun843691 = G(A113,"s-block",L[72]);
var anf_fun844692 = G(list2753,"make",L[71]);
var $z682683 = D;
var $f688689 = function(_) {
return R.isFunction(no_DASH_branches_DASH_exn92260.$var)?no_DASH_branches_DASH_exn92260.$var.app(l387678,("ask")):R.ffi.throwNonFunApp(L[70],no_DASH_branches_DASH_exn92260.$var,[l387678,("ask")]);
};
try {
if(--R.GAS > 0) {
$z682683 = $f688689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f688689,
"from":L[70]});
}
} catch($e680681) {
if(R.isCont($e680681)) {
var $ss684685 = {"from":L[70],
"go":function(anf_array_val845690) {
return $Hanf_array_val1761693(anf_array_val845690,anf_fun843691,anf_fun844692,branches388679,desugar_DASH_if105286,l387678);
}};
$e680681.stack[R.EXN_STACKHEIGHT++] = $ss684685;
}
if(R.isPyretException($e680681)) {
$e680681.pyretStack.push(L[70]);
}
throw $e680681;
}
var $ret686687 = $Hanf_array_val1761693($z682683,anf_fun843691,anf_fun844692,branches388679,desugar_DASH_if105286,l387678);
++R.GAS;
return $ret686687;
});
var anf_obj850372 = R.makeFunction(function(l389663,branches390664,_else391665) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[68],3,arguments);
}
var $z668669 = D;
var $f674675 = function(_) {
return R.isFunction(desugar_DASH_if105286.$var)?desugar_DASH_if105286.$var.app(l389663,branches390664,_else391665):R.ffi.throwNonFunApp(L[68],desugar_DASH_if105286.$var,[l389663,branches390664,_else391665]);
};
try {
if(--R.GAS > 0) {
$z668669 = $f674675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f674675,
"from":L[68]});
}
} catch($e666667) {
if(R.isCont($e666667)) {
var $ss670671 = {"from":L[68],
"go":function(ann_DASH_check_DASH_temp849676) {
return $Hann_DASH_check_DASH_temp1762677(ann_DASH_check_DASH_temp849676);
}};
$e666667.stack[R.EXN_STACKHEIGHT++] = $ss670671;
}
if(R.isPyretException($e666667)) {
$e666667.pyretStack.push(L[68]);
}
throw $e666667;
}
var $ret672673 = $Hann_DASH_check_DASH_temp1762677($z668669);
++R.GAS;
return $ret672673;
});
var anf_obj860373 = R.makeFunction(function(l392647,typ393648,val394649,branches395650) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[66],4,arguments);
}
var $z653654 = D;
var $f659660 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(val394649):R.ffi.throwNonFunApp(L[67],desugar_DASH_expr117310.$var,[val394649]);
};
try {
if(--R.GAS > 0) {
$z653654 = $f659660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f659660,
"from":L[67]});
}
} catch($e651652) {
if(R.isCont($e651652)) {
var $ss655656 = {"from":L[67],
"go":function(anf_arg852661) {
return $Hanf_arg1768662(anf_arg852661,A113,branches395650,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,l392647,list2753,no_DASH_branches_DASH_exn92260,typ393648);
}};
$e651652.stack[R.EXN_STACKHEIGHT++] = $ss655656;
}
if(R.isPyretException($e651652)) {
$e651652.pyretStack.push(L[67]);
}
throw $e651652;
}
var $ret657658 = $Hanf_arg1768662($z653654,A113,branches395650,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,l392647,list2753,no_DASH_branches_DASH_exn92260,typ393648);
++R.GAS;
return $ret657658;
});
var anf_obj866374 = R.makeFunction(function(l396630,typ397631,val398632,branches399633,_else400634) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[64],5,arguments);
}
var $z637638 = D;
var $f643644 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(val398632):R.ffi.throwNonFunApp(L[65],desugar_DASH_expr117310.$var,[val398632]);
};
try {
if(--R.GAS > 0) {
$z637638 = $f643644();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f643644,
"from":L[65]});
}
} catch($e635636) {
if(R.isCont($e635636)) {
var $ss639640 = {"from":L[65],
"go":function(anf_arg862645) {
return $Hanf_arg1772646(anf_arg862645,_else400634,branches399633,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,l396630,typ397631);
}};
$e635636.stack[R.EXN_STACKHEIGHT++] = $ss639640;
}
if(R.isPyretException($e635636)) {
$e635636.pyretStack.push(L[65]);
}
throw $e635636;
}
var $ret641642 = $Hanf_arg1772646($z637638,_else400634,branches399633,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,l396630,typ397631);
++R.GAS;
return $ret641642;
});
var anf_obj870375 = R.makeFunction(function(l401614,id402615,val403616) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[61],3,arguments);
}
var anf_fun868628 = G(A113,"s-assign",L[63]);
var $z619620 = D;
var $f625626 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(val403616):R.ffi.throwNonFunApp(L[62],desugar_DASH_expr117310.$var,[val403616]);
};
try {
if(--R.GAS > 0) {
$z619620 = $f625626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f625626,
"from":L[62]});
}
} catch($e617618) {
if(R.isCont($e617618)) {
var $ss621622 = {"from":L[62],
"go":function(anf_arg869627) {
return $Hanf_arg1774629(anf_arg869627,anf_fun868628,id402615,l401614);
}};
$e617618.stack[R.EXN_STACKHEIGHT++] = $ss621622;
}
if(R.isPyretException($e617618)) {
$e617618.pyretStack.push(L[62]);
}
throw $e617618;
}
var $ret623624 = $Hanf_arg1774629($z619620,anf_fun868628,id402615,l401614);
++R.GAS;
return $ret623624;
});
var anf_obj873376 = R.makeFunction(function(l404598,obj405599,field406600) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[59],3,arguments);
}
var anf_arg872611 = G(A113,"s-dot",L[60]);
var $z603604 = D;
var $f609610 = function(_) {
return R.isFunction(ds_DASH_curry_DASH_nullary112300.$var)?ds_DASH_curry_DASH_nullary112300.$var.app(anf_arg872611,l404598,obj405599,field406600):R.ffi.throwNonFunApp(L[59],ds_DASH_curry_DASH_nullary112300.$var,[anf_arg872611,l404598,obj405599,field406600]);
};
try {
if(--R.GAS > 0) {
$z603604 = $f609610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f609610,
"from":L[59]});
}
} catch($e601602) {
if(R.isCont($e601602)) {
var $ss605606 = {"from":L[59],
"go":function(ann_DASH_check_DASH_temp871612) {
return $Hann_DASH_check_DASH_temp1775613(ann_DASH_check_DASH_temp871612);
}};
$e601602.stack[R.EXN_STACKHEIGHT++] = $ss605606;
}
if(R.isPyretException($e601602)) {
$e601602.pyretStack.push(L[59]);
}
throw $e601602;
}
var $ret607608 = $Hann_DASH_check_DASH_temp1775613($z603604);
++R.GAS;
return $ret607608;
});
var anf_obj879377 = R.makeFunction(function(l407582,obj408583,fields409584) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[56],3,arguments);
}
var anf_fun875596 = G(A113,"s-extend",L[58]);
var $z587588 = D;
var $f593594 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(obj408583):R.ffi.throwNonFunApp(L[57],desugar_DASH_expr117310.$var,[obj408583]);
};
try {
if(--R.GAS > 0) {
$z587588 = $f593594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f593594,
"from":L[57]});
}
} catch($e585586) {
if(R.isCont($e585586)) {
var $ss589590 = {"from":L[57],
"go":function(anf_arg876595) {
return $Hanf_arg1778597(anf_arg876595,anf_fun875596,desugar_DASH_member109294,fields409584,l407582);
}};
$e585586.stack[R.EXN_STACKHEIGHT++] = $ss589590;
}
if(R.isPyretException($e585586)) {
$e585586.pyretStack.push(L[57]);
}
throw $e585586;
}
var $ret591592 = $Hanf_arg1778597($z587588,anf_fun875596,desugar_DASH_member109294,fields409584,l407582);
++R.GAS;
return $ret591592;
});
var anf_obj900378 = R.makeFunction(function(l410561,iter411562,bindings412563,ann413564,body414565) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[52],5,arguments);
}
var anf_fun881576 = G(bindings412563,"map",L[55]);
var anf_arg883577 = R.makeFunction(function(recv_DASH_47580) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[54],1,arguments);
}
var ann_DASH_check_DASH_temp882581 = G(recv_DASH_47580,"value",L[54]);
return ann_DASH_check_DASH_temp882581;
});
var $z568569 = D;
var $f574575 = function(_) {
return R.isFunction(anf_fun881576)?anf_fun881576.app(anf_arg883577):R.ffi.throwNonFunApp(L[53],anf_fun881576,[anf_arg883577]);
};
try {
if(--R.GAS > 0) {
$z568569 = $f574575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f574575,
"from":L[53]});
}
} catch($e566567) {
if(R.isCont($e566567)) {
var $ss570571 = {"from":L[53],
"go":function(anf_bracket884578) {
return $Hanf_bracket1789579(anf_bracket884578,A113,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,list2753,none6355);
}};
$e566567.stack[R.EXN_STACKHEIGHT++] = $ss570571;
}
if(R.isPyretException($e566567)) {
$e566567.pyretStack.push(L[53]);
}
throw $e566567;
}
var $ret572573 = $Hanf_bracket1789579($z568569,A113,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,list2753,none6355);
++R.GAS;
return $ret572573;
});
var anf_obj1093379 = R.makeFunction(function(l417545,op418546,left419547,right420548) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[50],4,arguments);
}
var $z551552 = D;
var $f557558 = function(_) {
return R.isFunction(get_DASH_arith_DASH_op104284.$var)?get_DASH_arith_DASH_op104284.$var.app(op418546):R.ffi.throwNonFunApp(L[51],get_DASH_arith_DASH_op104284.$var,[op418546]);
};
try {
if(--R.GAS > 0) {
$z551552 = $f557558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f557558,
"from":L[51]});
}
} catch($e549550) {
if(R.isCont($e549550)) {
var $ss553554 = {"from":L[51],
"go":function(cases_DASH_val61559) {
return $Hcases_DASH_val1867560(cases_DASH_val61559,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,expr280326,fold5550,gid90256,l417545,left419547,list2753,mk_DASH_id101278,none6355,op418546,right420548,_plus7,raise10);
}};
$e549550.stack[R.EXN_STACKHEIGHT++] = $ss553554;
}
if(R.isPyretException($e549550)) {
$e549550.pyretStack.push(L[51]);
}
throw $e549550;
}
var $ret555556 = $Hcases_DASH_val1867560($z551552,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,expr280326,fold5550,gid90256,l417545,left419547,list2753,mk_DASH_id101278,none6355,op418546,right420548,_plus7,raise10);
++R.GAS;
return $ret555556;
});
var anf_obj1095380 = R.makeFunction(function(l453542,x454543) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[49],2,arguments);
}
var ann_DASH_check_DASH_temp1094544 = expr280326;
return ann_DASH_check_DASH_temp1094544;
});
var anf_obj1097381 = R.makeFunction(function(l455539,x456540) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[48],2,arguments);
}
var ann_DASH_check_DASH_temp1096541 = expr280326;
return ann_DASH_check_DASH_temp1096541;
});
var anf_obj1099382 = R.makeFunction(function($underscore457535,$underscore458536,$underscore459537) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[47],3,arguments);
}
var ann_DASH_check_DASH_temp1098538 = expr280326;
return ann_DASH_check_DASH_temp1098538;
});
var anf_obj1101383 = R.makeFunction(function($underscore460532,$underscore461533) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[46],2,arguments);
}
var ann_DASH_check_DASH_temp1100534 = expr280326;
return ann_DASH_check_DASH_temp1100534;
});
var anf_obj1103384 = R.makeFunction(function($underscore462529,$underscore463530) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[45],2,arguments);
}
var ann_DASH_check_DASH_temp1102531 = expr280326;
return ann_DASH_check_DASH_temp1102531;
});
var anf_obj1107385 = R.makeFunction(function(l464513,num465514,den466515) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[42],3,arguments);
}
var anf_fun1105527 = G(A113,"s-num",L[44]);
var $z518519 = D;
var $f524525 = function(_) {
return R.isFunction(_divide6)?_divide6.app(num465514,den466515):R.ffi.throwNonFunApp(L[43],_divide6,[num465514,den466515]);
};
try {
if(--R.GAS > 0) {
$z518519 = $f524525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f524525,
"from":L[43]});
}
} catch($e516517) {
if(R.isCont($e516517)) {
var $ss520521 = {"from":L[43],
"go":function(anf_arg1106526) {
return $Hanf_arg1869528(anf_arg1106526,anf_fun1105527,l464513);
}};
$e516517.stack[R.EXN_STACKHEIGHT++] = $ss520521;
}
if(R.isPyretException($e516517)) {
$e516517.pyretStack.push(L[43]);
}
throw $e516517;
}
var $ret522523 = $Hanf_arg1869528($z518519,anf_fun1105527,l464513);
++R.GAS;
return $ret522523;
});
var anf_obj1109386 = R.makeFunction(function($underscore467510,$underscore468511) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[41],2,arguments);
}
var ann_DASH_check_DASH_temp1108512 = expr280326;
return ann_DASH_check_DASH_temp1108512;
});
var anf_obj1111387 = R.makeFunction(function($underscore469507,$underscore470508) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[40],2,arguments);
}
var ann_DASH_check_DASH_temp1110509 = expr280326;
return ann_DASH_check_DASH_temp1110509;
});
var anf_obj1116388 = R.makeFunction(function(l471491,fields472492) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[36],2,arguments);
}
var anf_fun1113505 = G(A113,"s-obj",L[39]);
var anf_fun1114503 = G(fields472492,"map",L[38]);
var $z495496 = D;
var $f501502 = function(_) {
return R.isFunction(anf_fun1114503)?anf_fun1114503.app(desugar_DASH_member109294.$var):R.ffi.throwNonFunApp(L[37],anf_fun1114503,[desugar_DASH_member109294.$var]);
};
try {
if(--R.GAS > 0) {
$z495496 = $f501502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f501502,
"from":L[37]});
}
} catch($e493494) {
if(R.isCont($e493494)) {
var $ss497498 = {"from":L[37],
"go":function(anf_arg1115504) {
return $Hanf_arg1871506(anf_arg1115504,anf_fun1113505,l471491);
}};
$e493494.stack[R.EXN_STACKHEIGHT++] = $ss497498;
}
if(R.isPyretException($e493494)) {
$e493494.pyretStack.push(L[37]);
}
throw $e493494;
}
var $ret499500 = $Hanf_arg1871506($z495496,anf_fun1113505,l471491);
++R.GAS;
return $ret499500;
});
var anf_obj1152389 = R.makeFunction(function(l473440,modifier474441,constructor475442,elts476443) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[26],4,arguments);
}
var cases_DASH_val62490 = modifier474441;
var anf_fun1118454 = G(cases_DASH_val62490,"_match",L[27]);
var anf_obj1130460 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[32],0,arguments);
}
var anf_fun1120488 = G(A113,"s-app",L[35]);
var anf_fun1121486 = G(A113,"s-dot",L[34]);
var $z478479 = D;
var $f484485 = function(_) {
return R.isFunction(anf_fun1121486)?anf_fun1121486.app(l473440,constructor475442,("make")):R.ffi.throwNonFunApp(L[33],anf_fun1121486,[l473440,constructor475442,("make")]);
};
try {
if(--R.GAS > 0) {
$z478479 = $f484485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f484485,
"from":L[33]});
}
} catch($e476477) {
if(R.isCont($e476477)) {
var $ss480481 = {"from":L[33],
"go":function(anf_arg1122487) {
return $Hanf_arg1877489(anf_arg1122487,A113,anf_fun1120488,desugar_DASH_expr117310,elts476443,l473440,list2753);
}};
$e476477.stack[R.EXN_STACKHEIGHT++] = $ss480481;
}
if(R.isPyretException($e476477)) {
$e476477.pyretStack.push(L[33]);
}
throw $e476477;
}
var $ret482483 = $Hanf_arg1877489($z478479,A113,anf_fun1120488,desugar_DASH_expr117310,elts476443,l473440,list2753);
++R.GAS;
return $ret482483;
});
var anf_obj1148461 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[28],0,arguments);
}
var anf_fun1132474 = G(A113,"s-app",L[31]);
var anf_fun1133472 = G(A113,"s-dot",L[30]);
var $z464465 = D;
var $f470471 = function(_) {
return R.isFunction(anf_fun1133472)?anf_fun1133472.app(l473440,constructor475442,("lazy-make")):R.ffi.throwNonFunApp(L[29],anf_fun1133472,[l473440,constructor475442,("lazy-make")]);
};
try {
if(--R.GAS > 0) {
$z464465 = $f470471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f470471,
"from":L[29]});
}
} catch($e462463) {
if(R.isCont($e462463)) {
var $ss466467 = {"from":L[29],
"go":function(anf_arg1134473) {
return $Hanf_arg1885475(anf_arg1134473,A113,anf_fun1132474,desugar_DASH_expr117310,elts476443,empty3049,l473440,list2753,none6355);
}};
$e462463.stack[R.EXN_STACKHEIGHT++] = $ss466467;
}
if(R.isPyretException($e462463)) {
$e462463.pyretStack.push(L[29]);
}
throw $e462463;
}
var $ret468469 = $Hanf_arg1885475($z464465,A113,anf_fun1132474,desugar_DASH_expr117310,elts476443,empty3049,l473440,list2753,none6355);
++R.GAS;
return $ret468469;
});
var anf_arg1149455 = R.makeObject({"s-construct-normal":anf_obj1130460,
"s-construct-lazy":anf_obj1148461});
var anf_arg1151456 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[27],0,arguments);
}
var ann_DASH_check_DASH_temp1150459 = R.throwNoBranchesMatched(L[27],("cases"));
return ann_DASH_check_DASH_temp1150459;
});
var $z446447 = D;
var $f452453 = function(_) {
return R.isFunction(anf_fun1118454)?anf_fun1118454.app(anf_arg1149455,anf_arg1151456):R.ffi.throwNonFunApp(L[26],anf_fun1118454,[anf_arg1149455,anf_arg1151456]);
};
try {
if(--R.GAS > 0) {
$z446447 = $f452453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f452453,
"from":L[26]});
}
} catch($e444445) {
if(R.isCont($e444445)) {
var $ss448449 = {"from":L[26],
"go":function(ann_DASH_check_DASH_temp1117457) {
return $Hann_DASH_check_DASH_temp1886458(ann_DASH_check_DASH_temp1117457);
}};
$e444445.stack[R.EXN_STACKHEIGHT++] = $ss448449;
}
if(R.isPyretException($e444445)) {
$e444445.pyretStack.push(L[26]);
}
throw $e444445;
}
var $ret450451 = $Hann_DASH_check_DASH_temp1886458($z446447);
++R.GAS;
return $ret450451;
});
var anf_obj1154390 = R.makeFunction(function(l478426,e479427) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[25],2,arguments);
}
var $z430431 = D;
var $f436437 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(e479427):R.ffi.throwNonFunApp(L[25],desugar_DASH_expr117310.$var,[e479427]);
};
try {
if(--R.GAS > 0) {
$z430431 = $f436437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f436437,
"from":L[25]});
}
} catch($e428429) {
if(R.isCont($e428429)) {
var $ss432433 = {"from":L[25],
"go":function(ann_DASH_check_DASH_temp1153438) {
return $Hann_DASH_check_DASH_temp1887439(ann_DASH_check_DASH_temp1153438);
}};
$e428429.stack[R.EXN_STACKHEIGHT++] = $ss432433;
}
if(R.isPyretException($e428429)) {
$e428429.pyretStack.push(L[25]);
}
throw $e428429;
}
var $ret434435 = $Hann_DASH_check_DASH_temp1887439($z430431);
++R.GAS;
return $ret434435;
});
var anf_obj1157391 = R.makeFunction(function(l480409,$underscore481410,$underscore482411,$underscore483412) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[23],4,arguments);
}
var anf_fun1156423 = G(A113,"s-str",L[24]);
var $z415416 = D;
var $f421422 = function(_) {
return R.isFunction(anf_fun1156423)?anf_fun1156423.app(l480409,("Checks should have been desugared")):R.ffi.throwNonFunApp(L[23],anf_fun1156423,[l480409,("Checks should have been desugared")]);
};
try {
if(--R.GAS > 0) {
$z415416 = $f421422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f421422,
"from":L[23]});
}
} catch($e413414) {
if(R.isCont($e413414)) {
var $ss417418 = {"from":L[23],
"go":function(ann_DASH_check_DASH_temp1155424) {
return $Hann_DASH_check_DASH_temp1888425(ann_DASH_check_DASH_temp1155424);
}};
$e413414.stack[R.EXN_STACKHEIGHT++] = $ss417418;
}
if(R.isPyretException($e413414)) {
$e413414.pyretStack.push(L[23]);
}
throw $e413414;
}
var $ret419420 = $Hann_DASH_check_DASH_temp1888425($z415416);
++R.GAS;
return $ret419420;
});
var anf_obj1159392 = R.makeFunction(function(l484393,$underscore485394,$underscore486395,$underscore487396) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[22],4,arguments);
}
var $z399400 = D;
var $f405406 = function(_) {
return R.isFunction(make_DASH_message_DASH_exception93262.$var)?make_DASH_message_DASH_exception93262.$var.app(l484393,("Checks should have been desugared")):R.ffi.throwNonFunApp(L[22],make_DASH_message_DASH_exception93262.$var,[l484393,("Checks should have been desugared")]);
};
try {
if(--R.GAS > 0) {
$z399400 = $f405406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f405406,
"from":L[22]});
}
} catch($e397398) {
if(R.isCont($e397398)) {
var $ss401402 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp1158407) {
return $Hann_DASH_check_DASH_temp1889408(ann_DASH_check_DASH_temp1158407);
}};
$e397398.stack[R.EXN_STACKHEIGHT++] = $ss401402;
}
if(R.isPyretException($e397398)) {
$e397398.pyretStack.push(L[22]);
}
throw $e397398;
}
var $ret403404 = $Hann_DASH_check_DASH_temp1889408($z399400);
++R.GAS;
return $ret403404;
});
var anf_arg1160338 = R.makeObject({"s-module":anf_obj641354,
"s-block":anf_obj646355,
"s-user-block":anf_obj648356,
"s-app":anf_obj652357,
"s-prim-app":anf_obj657358,
"s-lam":anf_obj665359,
"s-method":anf_obj673360,
"s-let":anf_obj677361,
"s-type":anf_obj681362,
"s-newtype":anf_obj683363,
"s-type-let-expr":anf_obj701364,
"s-let-expr":anf_obj721365,
"s-letrec":anf_obj736366,
"s-data-expr":anf_obj808367,
"s-when":anf_obj832368,
"s-if":anf_obj839369,
"s-if-else":anf_obj841370,
"s-if-pipe":anf_obj848371,
"s-if-pipe-else":anf_obj850372,
"s-cases":anf_obj860373,
"s-cases-else":anf_obj866374,
"s-assign":anf_obj870375,
"s-dot":anf_obj873376,
"s-extend":anf_obj879377,
"s-for":anf_obj900378,
"s-op":anf_obj1093379,
"s-id":anf_obj1095380,
"s-id-var":anf_obj1097381,
"s-id-letrec":anf_obj1099382,
"s-srcloc":anf_obj1101383,
"s-num":anf_obj1103384,
"s-frac":anf_obj1107385,
"s-str":anf_obj1109386,
"s-bool":anf_obj1111387,
"s-obj":anf_obj1116388,
"s-construct":anf_obj1152389,
"s-paren":anf_obj1154390,
"s-check":anf_obj1157391,
"s-check-test":anf_obj1159392});
var anf_arg1164339 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[20],0,arguments);
}
var $z344345 = D;
var $f350351 = function(_) {
return R.isFunction(torepr11)?torepr11.app(expr280326):R.ffi.throwNonFunApp(L[21],torepr11,[expr280326]);
};
try {
if(--R.GAS > 0) {
$z344345 = $f350351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f350351,
"from":L[21]});
}
} catch($e342343) {
if(R.isCont($e342343)) {
var $ss346347 = {"from":L[21],
"go":function(anf_arg1162352) {
return $Hanf_arg1892353(anf_arg1162352,_plus7,raise10);
}};
$e342343.stack[R.EXN_STACKHEIGHT++] = $ss346347;
}
if(R.isPyretException($e342343)) {
$e342343.pyretStack.push(L[21]);
}
throw $e342343;
}
var $ret348349 = $Hanf_arg1892353($z344345,_plus7,raise10);
++R.GAS;
return $ret348349;
});
var $z329330 = D;
var $f335336 = function(_) {
return R.isFunction(anf_fun633337)?anf_fun633337.app(anf_arg1160338,anf_arg1164339):R.ffi.throwNonFunApp(L[19],anf_fun633337,[anf_arg1160338,anf_arg1164339]);
};
try {
if(--R.GAS > 0) {
$z329330 = $f335336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f335336,
"from":L[19]});
}
} catch($e327328) {
if(R.isCont($e327328)) {
var $ss331332 = {"from":L[19],
"go":function(ann_DASH_check_DASH_temp632340) {
return $Hann_DASH_check_DASH_temp1893341(ann_DASH_check_DASH_temp632340);
}};
$e327328.stack[R.EXN_STACKHEIGHT++] = $ss331332;
}
if(R.isPyretException($e327328)) {
$e327328.pyretStack.push(L[19]);
}
throw $e327328;
}
var $ret333334 = $Hann_DASH_check_DASH_temp1893341($z329330);
++R.GAS;
return $ret333334;
});
});
desugar_DASH_expr117310.$var = anf_assign1165311;
var result_DASH_after_DASH_checks1488324 = nothing9;
var anf_fun1166322 = G(builtins8,"current-checker",L[18]);
var $z314315 = D;
var $f320321 = function(_) {
return R.isFunction(anf_fun1166322)?anf_fun1166322.app():R.ffi.throwNonFunApp(L[18],anf_fun1166322,[]);
};
try {
if(--R.GAS > 0) {
$z314315 = $f320321();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f320321,
"from":L[18]});
}
} catch($e312313) {
if(R.isCont($e312313)) {
var $ss316317 = {"from":L[18],
"go":function(anf_bracket1167323) {
return $Hanf_bracket2027325(anf_bracket1167323,A113,DesugarEnv6843,DesugarEnv7460,PP314,Pair7046,Pair7970,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,list2753,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,none6355,pair8276,result_DASH_after_DASH_checks1488324,builtins8,nothing9);
}};
$e312313.stack[R.EXN_STACKHEIGHT++] = $ss316317;
}
if(R.isPyretException($e312313)) {
$e312313.pyretStack.push(L[18]);
}
throw $e312313;
}
var $ret318319 = $Hanf_bracket2027325($z314315,A113,DesugarEnv6843,DesugarEnv7460,PP314,Pair7046,Pair7970,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,list2753,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,none6355,pair8276,result_DASH_after_DASH_checks1488324,builtins8,nothing9);
++R.GAS;
return $ret318319;
};
var $Hanf_bracket2027325 = function(anf_bracket1167323,A113,DesugarEnv6843,DesugarEnv7460,PP314,Pair7046,Pair7970,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,list2753,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,none6355,pair8276,result_DASH_after_DASH_checks1488324,builtins8,nothing9) {
var anf_fun11682135 = G(anf_bracket1167323,"run-checks",L[18]);
var anf_fun11692129 = G(list2753,"make",L[18]);
var anf_obj12432270 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[202],0,arguments);
}
var d4892283 = G(A113,"dummy-loc",L[347]);
var anf_arg11712285 = G(A113,"a-blank",L[346]);
var anf_fun11722282 = G(A113,"s-num",L[345]);
var $z22742275 = D;
var $f22802281 = function(_) {
return R.isFunction(anf_fun11722282)?anf_fun11722282.app(d4892283,(1)):R.ffi.throwNonFunApp(L[344],anf_fun11722282,[d4892283,(1)]);
};
try {
if(--R.GAS > 0) {
$z22742275 = $f22802281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22802281,
"from":L[344]});
}
} catch($e22722273) {
if(R.isCont($e22722273)) {
var $ss22762277 = {"from":L[344],
"go":function(anf_arg11732284) {
return $Hanf_arg19262286(anf_arg11732284,A113,anf_arg11712285,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e22722273.stack[R.EXN_STACKHEIGHT++] = $ss22762277;
}
if(R.isPyretException($e22722273)) {
$e22722273.pyretStack.push(L[344]);
}
throw $e22722273;
}
var $ret22782279 = $Hanf_arg19262286($z22742275,A113,anf_arg11712285,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret22782279;
});
var anf_obj12442271 = R.makeSrcloc(L[202]);
var anf_array_val12452130 = R.makeObject({"name":("desugar-cases"),
"run":anf_obj12432270,
"location":anf_obj12442271});
var anf_obj12472267 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[176],0,arguments);
}
var ann_DASH_check_DASH_temp12462269 = nothing9;
return ann_DASH_check_DASH_temp12462269;
});
var anf_obj12482268 = R.makeSrcloc(L[176]);
var anf_array_val12492131 = R.makeObject({"name":("ds-curry-nullary"),
"run":anf_obj12472267,
"location":anf_obj12482268});
var anf_obj13252233 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[168],0,arguments);
}
var d4922246 = G(A113,"dummy-loc",L[343]);
var n4932266 = G(A113,"s-global",L[342]);
var id4942249 = R.makeFunction(function(s4952251) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[338],1,arguments);
}
var anf_fun12522264 = G(A113,"s-id",L[341]);
var anf_fun12532262 = G(A113,"s-global",L[340]);
var $z22542255 = D;
var $f22602261 = function(_) {
return R.isFunction(anf_fun12532262)?anf_fun12532262.app(s4952251):R.ffi.throwNonFunApp(L[339],anf_fun12532262,[s4952251]);
};
try {
if(--R.GAS > 0) {
$z22542255 = $f22602261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22602261,
"from":L[339]});
}
} catch($e22522253) {
if(R.isCont($e22522253)) {
var $ss22562257 = {"from":L[339],
"go":function(anf_arg12542263) {
return $Hanf_arg19282265(anf_arg12542263,anf_fun12522264,d4922246);
}};
$e22522253.stack[R.EXN_STACKHEIGHT++] = $ss22562257;
}
if(R.isPyretException($e22522253)) {
$e22522253.pyretStack.push(L[339]);
}
throw $e22522253;
}
var $ret22582259 = $Hanf_arg19282265($z22542255,anf_fun12522264,d4922246);
++R.GAS;
return $ret22582259;
});
var anf_fun12552248 = G(A113,"s-id",L[337]);
var anf_fun12562245 = G(A113,"s-underscore",L[336]);
var $z22372238 = D;
var $f22432244 = function(_) {
return R.isFunction(anf_fun12562245)?anf_fun12562245.app(d4922246):R.ffi.throwNonFunApp(L[335],anf_fun12562245,[d4922246]);
};
try {
if(--R.GAS > 0) {
$z22372238 = $f22432244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22432244,
"from":L[335]});
}
} catch($e22352236) {
if(R.isCont($e22352236)) {
var $ss22392240 = {"from":L[335],
"go":function(anf_arg12572247) {
return $Hanf_arg19752250(anf_arg12572247,A113,anf_fun12552248,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8);
}};
$e22352236.stack[R.EXN_STACKHEIGHT++] = $ss22392240;
}
if(R.isPyretException($e22352236)) {
$e22352236.pyretStack.push(L[335]);
}
throw $e22352236;
}
var $ret22412242 = $Hanf_arg19752250($z22372238,A113,anf_fun12552248,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8);
++R.GAS;
return $ret22412242;
});
var anf_obj13262234 = R.makeSrcloc(L[168]);
var anf_array_val13272132 = R.makeObject({"name":("ds-curry"),
"run":anf_obj13252233,
"location":anf_obj13262234});
var anf_obj14062137 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[19],0,arguments);
}
var d5012150 = G(A113,"dummy-loc",L[334]);
var anf_extend13292199 = G(A113,"default-map-visitor",L[333]);
var anf_extend13322200 = R.makeMethod(function(self5032232) {
return function(s5042229) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[331],1,arguments);
}
var anf_fun13312228 = G(A113,"s-name",L[332]);
var $z22202221 = D;
var $f22262227 = function(_) {
return R.isFunction(anf_fun13312228)?anf_fun13312228.app(d5012150,s5042229):R.ffi.throwNonFunApp(L[331],anf_fun13312228,[d5012150,s5042229]);
};
try {
if(--R.GAS > 0) {
$z22202221 = $f22262227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22262227,
"from":L[331]});
}
} catch($e22182219) {
if(R.isCont($e22182219)) {
var $ss22222223 = {"from":L[331],
"go":function(ann_DASH_check_DASH_temp13302230) {
return $Hann_DASH_check_DASH_temp19762231(ann_DASH_check_DASH_temp13302230);
}};
$e22182219.stack[R.EXN_STACKHEIGHT++] = $ss22222223;
}
if(R.isPyretException($e22182219)) {
$e22182219.pyretStack.push(L[331]);
}
throw $e22182219;
}
var $ret22242225 = $Hann_DASH_check_DASH_temp19762231($z22202221);
++R.GAS;
return $ret22242225;
};
},{"length":2});
var anf_extend13352201 = R.makeMethod(function(self5052216) {
return function(base5062213,serial5072217) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[329],2,arguments);
}
var anf_fun13342212 = G(A113,"s-name",L[330]);
var $z22042205 = D;
var $f22102211 = function(_) {
return R.isFunction(anf_fun13342212)?anf_fun13342212.app(d5012150,base5062213):R.ffi.throwNonFunApp(L[329],anf_fun13342212,[d5012150,base5062213]);
};
try {
if(--R.GAS > 0) {
$z22042205 = $f22102211();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22102211,
"from":L[329]});
}
} catch($e22022203) {
if(R.isCont($e22022203)) {
var $ss22062207 = {"from":L[329],
"go":function(ann_DASH_check_DASH_temp13332214) {
return $Hann_DASH_check_DASH_temp19772215(ann_DASH_check_DASH_temp13332214);
}};
$e22022203.stack[R.EXN_STACKHEIGHT++] = $ss22062207;
}
if(R.isPyretException($e22022203)) {
$e22022203.pyretStack.push(L[329]);
}
throw $e22022203;
}
var $ret22082209 = $Hann_DASH_check_DASH_temp19772215($z22042205);
++R.GAS;
return $ret22082209;
};
},{"length":3});
var unglobal5022183 = anf_extend13292199.extendWith({"s-global":anf_extend13322200,
"s-atom":anf_extend13352201});
var p5082154 = R.makeFunction(function(str5092185) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[326],1,arguments);
}
var anf_fun13372196 = G(PP314,"surface-parse",L[328]);
var $z21882189 = D;
var $f21942195 = function(_) {
return R.isFunction(anf_fun13372196)?anf_fun13372196.app(str5092185,("test")):R.ffi.throwNonFunApp(L[327],anf_fun13372196,[str5092185,("test")]);
};
try {
if(--R.GAS > 0) {
$z21882189 = $f21942195();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21942195,
"from":L[327]});
}
} catch($e21862187) {
if(R.isCont($e21862187)) {
var $ss21902191 = {"from":L[327],
"go":function(anf_bracket13382197) {
return $Hanf_bracket19792198(anf_bracket13382197,A113);
}};
$e21862187.stack[R.EXN_STACKHEIGHT++] = $ss21902191;
}
if(R.isPyretException($e21862187)) {
$e21862187.pyretStack.push(L[327]);
}
throw $e21862187;
}
var $ret21922193 = $Hanf_bracket19792198($z21882189,A113);
++R.GAS;
return $ret21922193;
});
var ds5102152 = R.makeFunction(function(prog5112171) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[324],1,arguments);
}
var $z21742175 = D;
var $f21802181 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(prog5112171):R.ffi.throwNonFunApp(L[325],desugar_DASH_expr117310.$var,[prog5112171]);
};
try {
if(--R.GAS > 0) {
$z21742175 = $f21802181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21802181,
"from":L[325]});
}
} catch($e21722173) {
if(R.isCont($e21722173)) {
var $ss21762177 = {"from":L[325],
"go":function(anf_bracket13432182) {
return $Hanf_bracket19822184(anf_bracket13432182,A113,unglobal5022183);
}};
$e21722173.stack[R.EXN_STACKHEIGHT++] = $ss21762177;
}
if(R.isPyretException($e21722173)) {
$e21722173.pyretStack.push(L[325]);
}
throw $e21722173;
}
var $ret21782179 = $Hanf_bracket19822184($z21742175,A113,unglobal5022183);
++R.GAS;
return $ret21782179;
});
var id5122153 = R.makeFunction(function(s5132156) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[320],1,arguments);
}
var anf_fun13492169 = G(A113,"s-id",L[323]);
var anf_fun13502167 = G(A113,"s-name",L[322]);
var $z21592160 = D;
var $f21652166 = function(_) {
return R.isFunction(anf_fun13502167)?anf_fun13502167.app(d5012150,s5132156):R.ffi.throwNonFunApp(L[321],anf_fun13502167,[d5012150,s5132156]);
};
try {
if(--R.GAS > 0) {
$z21592160 = $f21652166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21652166,
"from":L[321]});
}
} catch($e21572158) {
if(R.isCont($e21572158)) {
var $ss21612162 = {"from":L[321],
"go":function(anf_arg13512168) {
return $Hanf_arg19842170(anf_arg13512168,anf_fun13492169,d5012150);
}};
$e21572158.stack[R.EXN_STACKHEIGHT++] = $ss21612162;
}
if(R.isPyretException($e21572158)) {
$e21572158.pyretStack.push(L[321]);
}
throw $e21572158;
}
var $ret21632164 = $Hanf_arg19842170($z21592160,anf_fun13492169,d5012150);
++R.GAS;
return $ret21632164;
});
var anf_fun13522149 = G(A113,"s-num",L[319]);
var $z21412142 = D;
var $f21472148 = function(_) {
return R.isFunction(anf_fun13522149)?anf_fun13522149.app(d5012150,(1)):R.ffi.throwNonFunApp(L[318],anf_fun13522149,[d5012150,(1)]);
};
try {
if(--R.GAS > 0) {
$z21412142 = $f21472148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21472148,
"from":L[318]});
}
} catch($e21392140) {
if(R.isCont($e21392140)) {
var $ss21432144 = {"from":L[318],
"go":function(one5142151) {
return $Hone20212155(one5142151,A113,d5012150,ds5102152,id5122153,list2753,p5082154,builtins8);
}};
$e21392140.stack[R.EXN_STACKHEIGHT++] = $ss21432144;
}
if(R.isPyretException($e21392140)) {
$e21392140.pyretStack.push(L[318]);
}
throw $e21392140;
}
var $ret21452146 = $Hone20212155($z21412142,A113,d5012150,ds5102152,id5122153,list2753,p5082154,builtins8);
++R.GAS;
return $ret21452146;
});
var anf_obj14072138 = R.makeSrcloc(L[19]);
var anf_array_val14082133 = R.makeObject({"name":("desugar-expr"),
"run":anf_obj14062137,
"location":anf_obj14072138});
var $z21212122 = D;
var $f21272128 = function(_) {
return R.isFunction(anf_fun11692129)?anf_fun11692129.app([anf_array_val12452130,anf_array_val12492131,anf_array_val13272132,anf_array_val14082133]):R.ffi.throwNonFunApp(L[18],anf_fun11692129,[[anf_array_val12452130,anf_array_val12492131,anf_array_val13272132,anf_array_val14082133]]);
};
try {
if(--R.GAS > 0) {
$z21212122 = $f21272128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21272128,
"from":L[18]});
}
} catch($e21192120) {
if(R.isCont($e21192120)) {
var $ss21232124 = {"from":L[18],
"go":function(anf_arg14092134) {
return $Hanf_arg20262136(anf_arg14092134,DesugarEnv6843,DesugarEnv7460,Pair7046,Pair7970,anf_fun11682135,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,pair8276,result_DASH_after_DASH_checks1488324,builtins8);
}};
$e21192120.stack[R.EXN_STACKHEIGHT++] = $ss21232124;
}
if(R.isPyretException($e21192120)) {
$e21192120.pyretStack.push(L[18]);
}
throw $e21192120;
}
var $ret21252126 = $Hanf_arg20262136($z21212122,DesugarEnv6843,DesugarEnv7460,Pair7046,Pair7970,anf_fun11682135,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,pair8276,result_DASH_after_DASH_checks1488324,builtins8);
++R.GAS;
return $ret21252126;
};
var $Hanf_arg20262136 = function(anf_arg14092134,DesugarEnv6843,DesugarEnv7460,Pair7046,Pair7970,anf_fun11682135,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,pair8276,result_DASH_after_DASH_checks1488324,builtins8) {
var $z22892290 = D;
var $f22952296 = function(_) {
return R.isFunction(anf_fun11682135)?anf_fun11682135.app(("src/arr/compiler/desugar.arr"),anf_arg14092134):R.ffi.throwNonFunApp(L[18],anf_fun11682135,[("src/arr/compiler/desugar.arr"),anf_arg14092134]);
};
try {
if(--R.GAS > 0) {
$z22892290 = $f22952296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22952296,
"from":L[18]});
}
} catch($e22872288) {
if(R.isCont($e22872288)) {
var $ss22912292 = {"from":L[18],
"go":function(anf_begin_app_dropped20222297) {
return $Hanf_begin_app_dropped20252298(anf_begin_app_dropped20222297,DesugarEnv6843,DesugarEnv7460,Pair7046,Pair7970,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,pair8276,result_DASH_after_DASH_checks1488324,builtins8);
}};
$e22872288.stack[R.EXN_STACKHEIGHT++] = $ss22912292;
}
if(R.isPyretException($e22872288)) {
$e22872288.pyretStack.push(L[18]);
}
throw $e22872288;
}
var $ret22932294 = $Hanf_begin_app_dropped20252298($z22892290,DesugarEnv6843,DesugarEnv7460,Pair7046,Pair7970,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,pair8276,result_DASH_after_DASH_checks1488324,builtins8);
++R.GAS;
return $ret22932294;
};
var $Hanf_begin_app_dropped20252298 = function(anf_begin_app_dropped20222297,DesugarEnv6843,DesugarEnv7460,Pair7046,Pair7970,bool_DASH_exn95266,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,d_DASH_env7766,desugar_DASH_afield97270,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,desugar_DASH_if105286,desugar_DASH_member109294,desugar_DASH_opt115306,desugar_DASH_variant_DASH_member108292,desugar99274,ds_DASH_curry_DASH_args111298,ds_DASH_curry_DASH_binop113302,ds_DASH_curry_DASH_nullary112300,ds_DASH_curry114304,g89254,get_DASH_arith_DASH_op104284,gid90256,is_DASH_DesugarEnv7562,is_DASH_Pair8072,is_DASH_d_DASH_env7664,is_DASH_pair8174,is_DASH_underscore110296,make_DASH_match103282,make_DASH_message_DASH_exception_DASH_e94264,make_DASH_message_DASH_exception93262,make_DASH_torepr102280,mk_DASH_bind100276,mk_DASH_id101278,mt_DASH_d_DASH_env88252,names7242,no_DASH_branches_DASH_exn92260,pair8276,result_DASH_after_DASH_checks1488324,builtins8) {
var provides14102311 = R.makeObject({"names":names7242,
"DesugarEnv":DesugarEnv7460.$var,
"is-DesugarEnv":is_DASH_DesugarEnv7562.$var,
"d-env":d_DASH_env7766.$var,
"is-d-env":is_DASH_d_DASH_env7664.$var,
"Pair":Pair7970.$var,
"is-Pair":is_DASH_Pair8072.$var,
"pair":pair8276.$var,
"is-pair":is_DASH_pair8174.$var,
"mt-d-env":mt_DASH_d_DASH_env88252,
"g":g89254.$var,
"gid":gid90256.$var,
"check-bool":check_DASH_bool91258.$var,
"no-branches-exn":no_DASH_branches_DASH_exn92260.$var,
"make-message-exception":make_DASH_message_DASH_exception93262.$var,
"make-message-exception-e":make_DASH_message_DASH_exception_DASH_e94264.$var,
"bool-exn":bool_DASH_exn95266.$var,
"bool-op-exn":bool_DASH_op_DASH_exn96268.$var,
"desugar-afield":desugar_DASH_afield97270.$var,
"desugar-ann":desugar_DASH_ann98272.$var,
"desugar":desugar99274.$var,
"mk-bind":mk_DASH_bind100276.$var,
"mk-id":mk_DASH_id101278.$var,
"make-torepr":make_DASH_torepr102280.$var,
"make-match":make_DASH_match103282.$var,
"get-arith-op":get_DASH_arith_DASH_op104284.$var,
"desugar-if":desugar_DASH_if105286.$var,
"desugar-case-branch":desugar_DASH_case_DASH_branch106288.$var,
"desugar-cases":desugar_DASH_cases107290.$var,
"desugar-variant-member":desugar_DASH_variant_DASH_member108292.$var,
"desugar-member":desugar_DASH_member109294.$var,
"is-underscore":is_DASH_underscore110296.$var,
"ds-curry-args":ds_DASH_curry_DASH_args111298.$var,
"ds-curry-nullary":ds_DASH_curry_DASH_nullary112300.$var,
"ds-curry-binop":ds_DASH_curry_DASH_binop113302.$var,
"ds-curry":ds_DASH_curry114304.$var,
"desugar-opt":desugar_DASH_opt115306.$var,
"desugar-bind":desugar_DASH_bind116308.$var,
"desugar-expr":desugar_DASH_expr117310.$var,
"result-after-checks1":result_DASH_after_DASH_checks1488324});
var anf_fun14112309 = G(builtins8,"current-checker",L[7]);
var $z23012302 = D;
var $f23072308 = function(_) {
return R.isFunction(anf_fun14112309)?anf_fun14112309.app():R.ffi.throwNonFunApp(L[7],anf_fun14112309,[]);
};
try {
if(--R.GAS > 0) {
$z23012302 = $f23072308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23072308,
"from":L[7]});
}
} catch($e22992300) {
if(R.isCont($e22992300)) {
var $ss23032304 = {"from":L[7],
"go":function(anf_bracket14122310) {
return $Hanf_bracket20242312(anf_bracket14122310,DesugarEnv6843,Pair7046,provides14102311,result_DASH_after_DASH_checks1488324);
}};
$e22992300.stack[R.EXN_STACKHEIGHT++] = $ss23032304;
}
if(R.isPyretException($e22992300)) {
$e22992300.pyretStack.push(L[7]);
}
throw $e22992300;
}
var $ret23052306 = $Hanf_bracket20242312($z23012302,DesugarEnv6843,Pair7046,provides14102311,result_DASH_after_DASH_checks1488324);
++R.GAS;
return $ret23052306;
};
var $Hanf_bracket20242312 = function(anf_bracket14122310,DesugarEnv6843,Pair7046,provides14102311,result_DASH_after_DASH_checks1488324) {
var anf_fun14132323 = G(anf_bracket14122310,"results",L[7]);
var $z23152316 = D;
var $f23212322 = function(_) {
return R.isFunction(anf_fun14132323)?anf_fun14132323.app():R.ffi.throwNonFunApp(L[7],anf_fun14132323,[]);
};
try {
if(--R.GAS > 0) {
$z23152316 = $f23212322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23212322,
"from":L[7]});
}
} catch($e23132314) {
if(R.isCont($e23132314)) {
var $ss23172318 = {"from":L[7],
"go":function(checks14142324) {
return $Hchecks20232325(checks14142324,DesugarEnv6843,Pair7046,provides14102311,result_DASH_after_DASH_checks1488324);
}};
$e23132314.stack[R.EXN_STACKHEIGHT++] = $ss23172318;
}
if(R.isPyretException($e23132314)) {
$e23132314.pyretStack.push(L[7]);
}
throw $e23132314;
}
var $ret23192320 = $Hchecks20232325($z23152316,DesugarEnv6843,Pair7046,provides14102311,result_DASH_after_DASH_checks1488324);
++R.GAS;
return $ret23192320;
};
var $Hchecks20232325 = function(checks14142324,DesugarEnv6843,Pair7046,provides14102311,result_DASH_after_DASH_checks1488324) {
return R.makeObject({"answer":result_DASH_after_DASH_checks1488324,
"provide-plus-types":R.makeObject({"values":provides14102311,
"types":{"DesugarEnv":DesugarEnv6843,
"Pair":Pair7046}}),
"checks":checks14142324});
};
var $Hone20212155 = function(one5142151,A113,d5012150,ds5102152,id5122153,list2753,p5082154,builtins8) {
var anf_fun13532336 = G(A113,"s-num",L[349]);
var $z23282329 = D;
var $f23342335 = function(_) {
return R.isFunction(anf_fun13532336)?anf_fun13532336.app(d5012150,(2)):R.ffi.throwNonFunApp(L[348],anf_fun13532336,[d5012150,(2)]);
};
try {
if(--R.GAS > 0) {
$z23282329 = $f23342335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23342335,
"from":L[348]});
}
} catch($e23262327) {
if(R.isCont($e23262327)) {
var $ss23302331 = {"from":L[348],
"go":function(two5152337) {
return $Htwo20202338(two5152337,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,builtins8);
}};
$e23262327.stack[R.EXN_STACKHEIGHT++] = $ss23302331;
}
if(R.isPyretException($e23262327)) {
$e23262327.pyretStack.push(L[348]);
}
throw $e23262327;
}
var $ret23322333 = $Htwo20202338($z23282329,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,builtins8);
++R.GAS;
return $ret23322333;
};
var $Htwo20202338 = function(two5152337,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,builtins8) {
var pretty5162353 = R.makeFunction(function(prog5172355) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[351],1,arguments);
}
var anf_fun13552366 = G(prog5172355,"tosource",L[353]);
var $z23582359 = D;
var $f23642365 = function(_) {
return R.isFunction(anf_fun13552366)?anf_fun13552366.app():R.ffi.throwNonFunApp(L[352],anf_fun13552366,[]);
};
try {
if(--R.GAS > 0) {
$z23582359 = $f23642365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23642365,
"from":L[352]});
}
} catch($e23562357) {
if(R.isCont($e23562357)) {
var $ss23602361 = {"from":L[352],
"go":function(anf_bracket13562367) {
return $Hanf_bracket19872368(anf_bracket13562367);
}};
$e23562357.stack[R.EXN_STACKHEIGHT++] = $ss23602361;
}
if(R.isPyretException($e23562357)) {
$e23562357.pyretStack.push(L[352]);
}
throw $e23562357;
}
var $ret23622363 = $Hanf_bracket19872368($z23582359);
++R.GAS;
return $ret23622363;
});
var if_DASH_else5182352 = ("if true: 5 else: 6 end");
var ask_DASH_otherwise5192351 = ("ask: | true then: 5 | otherwise: 6 end");
var anf_fun13602349 = G(builtins8,"current-checker",L[350]);
var $z23412342 = D;
var $f23472348 = function(_) {
return R.isFunction(anf_fun13602349)?anf_fun13602349.app():R.ffi.throwNonFunApp(L[350],anf_fun13602349,[]);
};
try {
if(--R.GAS > 0) {
$z23412342 = $f23472348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23472348,
"from":L[350]});
}
} catch($e23392340) {
if(R.isCont($e23392340)) {
var $ss23432344 = {"from":L[350],
"go":function(anf_bracket13612350) {
return $Hanf_bracket20192354(anf_bracket13612350,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
}};
$e23392340.stack[R.EXN_STACKHEIGHT++] = $ss23432344;
}
if(R.isPyretException($e23392340)) {
$e23392340.pyretStack.push(L[350]);
}
throw $e23392340;
}
var $ret23452346 = $Hanf_bracket20192354($z23412342,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
++R.GAS;
return $ret23452346;
};
var $Hanf_bracket20192354 = function(anf_bracket13612350,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8) {
var anf_fun13622380 = G(anf_bracket13612350,"check-is",L[350]);
var $z23712372 = D;
var $f23772378 = function(_) {
return R.isFunction(p5082154)?p5082154.app(if_DASH_else5182352):R.ffi.throwNonFunApp(L[354],p5082154,[if_DASH_else5182352]);
};
try {
if(--R.GAS > 0) {
$z23712372 = $f23772378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23772378,
"from":L[354]});
}
} catch($e23692370) {
if(R.isCont($e23692370)) {
var $ss23732374 = {"from":L[354],
"go":function(anf_arg13632379) {
return $Hanf_arg20182381(anf_arg13632379,A113,anf_fun13622380,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
}};
$e23692370.stack[R.EXN_STACKHEIGHT++] = $ss23732374;
}
if(R.isPyretException($e23692370)) {
$e23692370.pyretStack.push(L[354]);
}
throw $e23692370;
}
var $ret23752376 = $Hanf_arg20182381($z23712372,A113,anf_fun13622380,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
++R.GAS;
return $ret23752376;
};
var $Hanf_arg20182381 = function(anf_arg13632379,A113,anf_fun13622380,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8) {
var $z23842385 = D;
var $f23902391 = function(_) {
return R.isFunction(pretty5162353)?pretty5162353.app(anf_arg13632379):R.ffi.throwNonFunApp(L[355],pretty5162353,[anf_arg13632379]);
};
try {
if(--R.GAS > 0) {
$z23842385 = $f23902391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23902391,
"from":L[355]});
}
} catch($e23822383) {
if(R.isCont($e23822383)) {
var $ss23862387 = {"from":L[355],
"go":function(anf_arg13642392) {
return $Hanf_arg20172393(anf_arg13642392,A113,anf_fun13622380,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
}};
$e23822383.stack[R.EXN_STACKHEIGHT++] = $ss23862387;
}
if(R.isPyretException($e23822383)) {
$e23822383.pyretStack.push(L[355]);
}
throw $e23822383;
}
var $ret23882389 = $Hanf_arg20172393($z23842385,A113,anf_fun13622380,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
++R.GAS;
return $ret23882389;
};
var $Hanf_arg20172393 = function(anf_arg13642392,A113,anf_fun13622380,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,if_DASH_else5182352,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8) {
var anf_arg13652404 = R.makeSrcloc(L[350]);
var $z23962397 = D;
var $f24022403 = function(_) {
return R.isFunction(anf_fun13622380)?anf_fun13622380.app(("p(if-else) ^ pretty is if-else"),anf_arg13642392,if_DASH_else5182352,anf_arg13652404):R.ffi.throwNonFunApp(L[350],anf_fun13622380,[("p(if-else) ^ pretty is if-else"),anf_arg13642392,if_DASH_else5182352,anf_arg13652404]);
};
try {
if(--R.GAS > 0) {
$z23962397 = $f24022403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24022403,
"from":L[350]});
}
} catch($e23942395) {
if(R.isCont($e23942395)) {
var $ss23982399 = {"from":L[350],
"go":function(anf_begin_app_dropped19882405) {
return $Hanf_begin_app_dropped20162406(anf_begin_app_dropped19882405,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
}};
$e23942395.stack[R.EXN_STACKHEIGHT++] = $ss23982399;
}
if(R.isPyretException($e23942395)) {
$e23942395.pyretStack.push(L[350]);
}
throw $e23942395;
}
var $ret24002401 = $Hanf_begin_app_dropped20162406($z23962397,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
++R.GAS;
return $ret24002401;
};
var $Hanf_begin_app_dropped20162406 = function(anf_begin_app_dropped19882405,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8) {
var anf_fun13662417 = G(builtins8,"current-checker",L[356]);
var $z24092410 = D;
var $f24152416 = function(_) {
return R.isFunction(anf_fun13662417)?anf_fun13662417.app():R.ffi.throwNonFunApp(L[356],anf_fun13662417,[]);
};
try {
if(--R.GAS > 0) {
$z24092410 = $f24152416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24152416,
"from":L[356]});
}
} catch($e24072408) {
if(R.isCont($e24072408)) {
var $ss24112412 = {"from":L[356],
"go":function(anf_bracket13672418) {
return $Hanf_bracket20152419(anf_bracket13672418,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
}};
$e24072408.stack[R.EXN_STACKHEIGHT++] = $ss24112412;
}
if(R.isPyretException($e24072408)) {
$e24072408.pyretStack.push(L[356]);
}
throw $e24072408;
}
var $ret24132414 = $Hanf_bracket20152419($z24092410,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
++R.GAS;
return $ret24132414;
};
var $Hanf_bracket20152419 = function(anf_bracket13672418,A113,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8) {
var anf_fun13682431 = G(anf_bracket13672418,"check-is",L[356]);
var $z24222423 = D;
var $f24282429 = function(_) {
return R.isFunction(p5082154)?p5082154.app(ask_DASH_otherwise5192351):R.ffi.throwNonFunApp(L[357],p5082154,[ask_DASH_otherwise5192351]);
};
try {
if(--R.GAS > 0) {
$z24222423 = $f24282429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24282429,
"from":L[357]});
}
} catch($e24202421) {
if(R.isCont($e24202421)) {
var $ss24242425 = {"from":L[357],
"go":function(anf_arg13692430) {
return $Hanf_arg20142432(anf_arg13692430,A113,anf_fun13682431,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
}};
$e24202421.stack[R.EXN_STACKHEIGHT++] = $ss24242425;
}
if(R.isPyretException($e24202421)) {
$e24202421.pyretStack.push(L[357]);
}
throw $e24202421;
}
var $ret24262427 = $Hanf_arg20142432($z24222423,A113,anf_fun13682431,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8);
++R.GAS;
return $ret24262427;
};
var $Hanf_arg20142432 = function(anf_arg13692430,A113,anf_fun13682431,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,pretty5162353,two5152337,builtins8) {
var $z24352436 = D;
var $f24412442 = function(_) {
return R.isFunction(pretty5162353)?pretty5162353.app(anf_arg13692430):R.ffi.throwNonFunApp(L[358],pretty5162353,[anf_arg13692430]);
};
try {
if(--R.GAS > 0) {
$z24352436 = $f24412442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24412442,
"from":L[358]});
}
} catch($e24332434) {
if(R.isCont($e24332434)) {
var $ss24372438 = {"from":L[358],
"go":function(anf_arg13702443) {
return $Hanf_arg20132444(anf_arg13702443,A113,anf_fun13682431,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
}};
$e24332434.stack[R.EXN_STACKHEIGHT++] = $ss24372438;
}
if(R.isPyretException($e24332434)) {
$e24332434.pyretStack.push(L[358]);
}
throw $e24332434;
}
var $ret24392440 = $Hanf_arg20132444($z24352436,A113,anf_fun13682431,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret24392440;
};
var $Hanf_arg20132444 = function(anf_arg13702443,A113,anf_fun13682431,ask_DASH_otherwise5192351,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8) {
var anf_arg13712455 = R.makeSrcloc(L[356]);
var $z24472448 = D;
var $f24532454 = function(_) {
return R.isFunction(anf_fun13682431)?anf_fun13682431.app(("p(ask-otherwise) ^ pretty is ask-otherwise"),anf_arg13702443,ask_DASH_otherwise5192351,anf_arg13712455):R.ffi.throwNonFunApp(L[356],anf_fun13682431,[("p(ask-otherwise) ^ pretty is ask-otherwise"),anf_arg13702443,ask_DASH_otherwise5192351,anf_arg13712455]);
};
try {
if(--R.GAS > 0) {
$z24472448 = $f24532454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24532454,
"from":L[356]});
}
} catch($e24452446) {
if(R.isCont($e24452446)) {
var $ss24492450 = {"from":L[356],
"go":function(anf_begin_app_dropped19892456) {
return $Hanf_begin_app_dropped20122457(anf_begin_app_dropped19892456,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
}};
$e24452446.stack[R.EXN_STACKHEIGHT++] = $ss24492450;
}
if(R.isPyretException($e24452446)) {
$e24452446.pyretStack.push(L[356]);
}
throw $e24452446;
}
var $ret24512452 = $Hanf_begin_app_dropped20122457($z24472448,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret24512452;
};
var $Hanf_begin_app_dropped20122457 = function(anf_begin_app_dropped19892456,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8) {
var $z24602461 = D;
var $f24662467 = function(_) {
return R.isFunction(p5082154)?p5082154.app(("[list: 1,2,1 + 2]")):R.ffi.throwNonFunApp(L[359],p5082154,[("[list: 1,2,1 + 2]")]);
};
try {
if(--R.GAS > 0) {
$z24602461 = $f24662467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24662467,
"from":L[359]});
}
} catch($e24582459) {
if(R.isCont($e24582459)) {
var $ss24622463 = {"from":L[359],
"go":function(prog25202468) {
return $Hprog220112469(prog25202468,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
}};
$e24582459.stack[R.EXN_STACKHEIGHT++] = $ss24622463;
}
if(R.isPyretException($e24582459)) {
$e24582459.pyretStack.push(L[359]);
}
throw $e24582459;
}
var $ret24642465 = $Hprog220112469($z24602461,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret24642465;
};
var $Hprog220112469 = function(prog25202468,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8) {
var anf_fun13722480 = G(builtins8,"current-checker",L[360]);
var $z24722473 = D;
var $f24782479 = function(_) {
return R.isFunction(anf_fun13722480)?anf_fun13722480.app():R.ffi.throwNonFunApp(L[360],anf_fun13722480,[]);
};
try {
if(--R.GAS > 0) {
$z24722473 = $f24782479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24782479,
"from":L[360]});
}
} catch($e24702471) {
if(R.isCont($e24702471)) {
var $ss24742475 = {"from":L[360],
"go":function(anf_bracket13732481) {
return $Hanf_bracket20102482(anf_bracket13732481,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,prog25202468,two5152337,builtins8);
}};
$e24702471.stack[R.EXN_STACKHEIGHT++] = $ss24742475;
}
if(R.isPyretException($e24702471)) {
$e24702471.pyretStack.push(L[360]);
}
throw $e24702471;
}
var $ret24762477 = $Hanf_bracket20102482($z24722473,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,prog25202468,two5152337,builtins8);
++R.GAS;
return $ret24762477;
};
var $Hanf_bracket20102482 = function(anf_bracket13732481,A113,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,prog25202468,two5152337,builtins8) {
var anf_fun13742494 = G(anf_bracket13732481,"check-is",L[360]);
var $z24852486 = D;
var $f24912492 = function(_) {
return R.isFunction(ds5102152)?ds5102152.app(prog25202468):R.ffi.throwNonFunApp(L[361],ds5102152,[prog25202468]);
};
try {
if(--R.GAS > 0) {
$z24852486 = $f24912492();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24912492,
"from":L[361]});
}
} catch($e24832484) {
if(R.isCont($e24832484)) {
var $ss24872488 = {"from":L[361],
"go":function(anf_arg13752493) {
return $Hanf_arg20092495(anf_arg13752493,A113,anf_fun13742494,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
}};
$e24832484.stack[R.EXN_STACKHEIGHT++] = $ss24872488;
}
if(R.isPyretException($e24832484)) {
$e24832484.pyretStack.push(L[361]);
}
throw $e24832484;
}
var $ret24892490 = $Hanf_arg20092495($z24852486,A113,anf_fun13742494,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret24892490;
};
var $Hanf_arg20092495 = function(anf_arg13752493,A113,anf_fun13742494,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8) {
var anf_fun13762508 = G(A113,"s-block",L[368]);
var anf_fun13772509 = G(list2753,"make",L[367]);
var anf_fun13782510 = G(A113,"s-app",L[366]);
var anf_fun13792511 = G(A113,"s-dot",L[365]);
var anf_fun13802512 = G(A113,"s-id",L[364]);
var anf_fun13812506 = G(A113,"s-name",L[363]);
var $z24982499 = D;
var $f25042505 = function(_) {
return R.isFunction(anf_fun13812506)?anf_fun13812506.app(d5012150,("list")):R.ffi.throwNonFunApp(L[362],anf_fun13812506,[d5012150,("list")]);
};
try {
if(--R.GAS > 0) {
$z24982499 = $f25042505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25042505,
"from":L[362]});
}
} catch($e24962497) {
if(R.isCont($e24962497)) {
var $ss25002501 = {"from":L[362],
"go":function(anf_arg13822507) {
return $Hanf_arg20082513(anf_arg13822507,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13792511,anf_fun13802512,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
}};
$e24962497.stack[R.EXN_STACKHEIGHT++] = $ss25002501;
}
if(R.isPyretException($e24962497)) {
$e24962497.pyretStack.push(L[362]);
}
throw $e24962497;
}
var $ret25022503 = $Hanf_arg20082513($z24982499,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13792511,anf_fun13802512,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret25022503;
};
var $Hanf_arg20082513 = function(anf_arg13822507,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13792511,anf_fun13802512,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8) {
var $z25162517 = D;
var $f25222523 = function(_) {
return R.isFunction(anf_fun13802512)?anf_fun13802512.app(d5012150,anf_arg13822507):R.ffi.throwNonFunApp(L[369],anf_fun13802512,[d5012150,anf_arg13822507]);
};
try {
if(--R.GAS > 0) {
$z25162517 = $f25222523();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25222523,
"from":L[369]});
}
} catch($e25142515) {
if(R.isCont($e25142515)) {
var $ss25182519 = {"from":L[369],
"go":function(anf_arg13832524) {
return $Hanf_arg20072525(anf_arg13832524,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13792511,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
}};
$e25142515.stack[R.EXN_STACKHEIGHT++] = $ss25182519;
}
if(R.isPyretException($e25142515)) {
$e25142515.pyretStack.push(L[369]);
}
throw $e25142515;
}
var $ret25202521 = $Hanf_arg20072525($z25162517,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13792511,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret25202521;
};
var $Hanf_arg20072525 = function(anf_arg13832524,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13792511,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8) {
var $z25282529 = D;
var $f25342535 = function(_) {
return R.isFunction(anf_fun13792511)?anf_fun13792511.app(d5012150,anf_arg13832524,("make")):R.ffi.throwNonFunApp(L[370],anf_fun13792511,[d5012150,anf_arg13832524,("make")]);
};
try {
if(--R.GAS > 0) {
$z25282529 = $f25342535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25342535,
"from":L[370]});
}
} catch($e25262527) {
if(R.isCont($e25262527)) {
var $ss25302531 = {"from":L[370],
"go":function(anf_arg13842536) {
return $Hanf_arg20062537(anf_arg13842536,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
}};
$e25262527.stack[R.EXN_STACKHEIGHT++] = $ss25302531;
}
if(R.isPyretException($e25262527)) {
$e25262527.pyretStack.push(L[370]);
}
throw $e25262527;
}
var $ret25322533 = $Hanf_arg20062537($z25282529,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret25322533;
};
var $Hanf_arg20062537 = function(anf_arg13842536,A113,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,d5012150,ds5102152,id5122153,list2753,one5142151,p5082154,two5152337,builtins8) {
var anf_fun13852549 = G(list2753,"make",L[375]);
var anf_fun13862550 = G(A113,"s-array",L[374]);
var anf_fun13872551 = G(list2753,"make",L[373]);
var anf_fun13882552 = G(A113,"s-app",L[372]);
var $z25402541 = D;
var $f25462547 = function(_) {
return R.isFunction(id5122153)?id5122153.app(("_plus")):R.ffi.throwNonFunApp(L[371],id5122153,[("_plus")]);
};
try {
if(--R.GAS > 0) {
$z25402541 = $f25462547();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25462547,
"from":L[371]});
}
} catch($e25382539) {
if(R.isCont($e25382539)) {
var $ss25422543 = {"from":L[371],
"go":function(anf_arg13892548) {
return $Hanf_arg20052553(anf_arg13892548,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,anf_fun13882552,d5012150,ds5102152,list2753,one5142151,p5082154,two5152337,builtins8);
}};
$e25382539.stack[R.EXN_STACKHEIGHT++] = $ss25422543;
}
if(R.isPyretException($e25382539)) {
$e25382539.pyretStack.push(L[371]);
}
throw $e25382539;
}
var $ret25442545 = $Hanf_arg20052553($z25402541,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,anf_fun13882552,d5012150,ds5102152,list2753,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret25442545;
};
var $Hanf_arg20052553 = function(anf_arg13892548,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,anf_fun13882552,d5012150,ds5102152,list2753,one5142151,p5082154,two5152337,builtins8) {
var anf_fun13902564 = G(list2753,"make",L[376]);
var $z25562557 = D;
var $f25622563 = function(_) {
return R.isFunction(anf_fun13902564)?anf_fun13902564.app([one5142151,two5152337]):R.ffi.throwNonFunApp(L[376],anf_fun13902564,[[one5142151,two5152337]]);
};
try {
if(--R.GAS > 0) {
$z25562557 = $f25622563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25622563,
"from":L[376]});
}
} catch($e25542555) {
if(R.isCont($e25542555)) {
var $ss25582559 = {"from":L[376],
"go":function(anf_arg13912565) {
return $Hanf_arg20042566(anf_arg13912565,anf_arg13752493,anf_arg13842536,anf_arg13892548,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,anf_fun13882552,d5012150,ds5102152,one5142151,p5082154,two5152337,builtins8);
}};
$e25542555.stack[R.EXN_STACKHEIGHT++] = $ss25582559;
}
if(R.isPyretException($e25542555)) {
$e25542555.pyretStack.push(L[376]);
}
throw $e25542555;
}
var $ret25602561 = $Hanf_arg20042566($z25562557,anf_arg13752493,anf_arg13842536,anf_arg13892548,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,anf_fun13882552,d5012150,ds5102152,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret25602561;
};
var $Hanf_arg20042566 = function(anf_arg13912565,anf_arg13752493,anf_arg13842536,anf_arg13892548,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,anf_fun13882552,d5012150,ds5102152,one5142151,p5082154,two5152337,builtins8) {
var $z25692570 = D;
var $f25752576 = function(_) {
return R.isFunction(anf_fun13882552)?anf_fun13882552.app(d5012150,anf_arg13892548,anf_arg13912565):R.ffi.throwNonFunApp(L[377],anf_fun13882552,[d5012150,anf_arg13892548,anf_arg13912565]);
};
try {
if(--R.GAS > 0) {
$z25692570 = $f25752576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25752576,
"from":L[377]});
}
} catch($e25672568) {
if(R.isCont($e25672568)) {
var $ss25712572 = {"from":L[377],
"go":function(anf_array_val13922577) {
return $Hanf_array_val20032578(anf_array_val13922577,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,d5012150,ds5102152,one5142151,p5082154,two5152337,builtins8);
}};
$e25672568.stack[R.EXN_STACKHEIGHT++] = $ss25712572;
}
if(R.isPyretException($e25672568)) {
$e25672568.pyretStack.push(L[377]);
}
throw $e25672568;
}
var $ret25732574 = $Hanf_array_val20032578($z25692570,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,d5012150,ds5102152,one5142151,p5082154,two5152337,builtins8);
++R.GAS;
return $ret25732574;
};
var $Hanf_array_val20032578 = function(anf_array_val13922577,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,anf_fun13872551,d5012150,ds5102152,one5142151,p5082154,two5152337,builtins8) {
var $z25812582 = D;
var $f25872588 = function(_) {
return R.isFunction(anf_fun13872551)?anf_fun13872551.app([one5142151,two5152337,anf_array_val13922577]):R.ffi.throwNonFunApp(L[373],anf_fun13872551,[[one5142151,two5152337,anf_array_val13922577]]);
};
try {
if(--R.GAS > 0) {
$z25812582 = $f25872588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25872588,
"from":L[373]});
}
} catch($e25792580) {
if(R.isCont($e25792580)) {
var $ss25832584 = {"from":L[373],
"go":function(anf_arg13932589) {
return $Hanf_arg20022590(anf_arg13932589,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,d5012150,ds5102152,p5082154,builtins8);
}};
$e25792580.stack[R.EXN_STACKHEIGHT++] = $ss25832584;
}
if(R.isPyretException($e25792580)) {
$e25792580.pyretStack.push(L[373]);
}
throw $e25792580;
}
var $ret25852586 = $Hanf_arg20022590($z25812582,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,d5012150,ds5102152,p5082154,builtins8);
++R.GAS;
return $ret25852586;
};
var $Hanf_arg20022590 = function(anf_arg13932589,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,anf_fun13862550,d5012150,ds5102152,p5082154,builtins8) {
var $z25932594 = D;
var $f25992600 = function(_) {
return R.isFunction(anf_fun13862550)?anf_fun13862550.app(d5012150,anf_arg13932589):R.ffi.throwNonFunApp(L[378],anf_fun13862550,[d5012150,anf_arg13932589]);
};
try {
if(--R.GAS > 0) {
$z25932594 = $f25992600();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25992600,
"from":L[378]});
}
} catch($e25912592) {
if(R.isCont($e25912592)) {
var $ss25952596 = {"from":L[378],
"go":function(anf_array_val13942601) {
return $Hanf_array_val20012602(anf_array_val13942601,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,d5012150,ds5102152,p5082154,builtins8);
}};
$e25912592.stack[R.EXN_STACKHEIGHT++] = $ss25952596;
}
if(R.isPyretException($e25912592)) {
$e25912592.pyretStack.push(L[378]);
}
throw $e25912592;
}
var $ret25972598 = $Hanf_array_val20012602($z25932594,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,d5012150,ds5102152,p5082154,builtins8);
++R.GAS;
return $ret25972598;
};
var $Hanf_array_val20012602 = function(anf_array_val13942601,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,anf_fun13852549,d5012150,ds5102152,p5082154,builtins8) {
var $z26052606 = D;
var $f26112612 = function(_) {
return R.isFunction(anf_fun13852549)?anf_fun13852549.app([anf_array_val13942601]):R.ffi.throwNonFunApp(L[375],anf_fun13852549,[[anf_array_val13942601]]);
};
try {
if(--R.GAS > 0) {
$z26052606 = $f26112612();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26112612,
"from":L[375]});
}
} catch($e26032604) {
if(R.isCont($e26032604)) {
var $ss26072608 = {"from":L[375],
"go":function(anf_arg13952613) {
return $Hanf_arg20002614(anf_arg13952613,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,d5012150,ds5102152,p5082154,builtins8);
}};
$e26032604.stack[R.EXN_STACKHEIGHT++] = $ss26072608;
}
if(R.isPyretException($e26032604)) {
$e26032604.pyretStack.push(L[375]);
}
throw $e26032604;
}
var $ret26092610 = $Hanf_arg20002614($z26052606,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,d5012150,ds5102152,p5082154,builtins8);
++R.GAS;
return $ret26092610;
};
var $Hanf_arg20002614 = function(anf_arg13952613,anf_arg13752493,anf_arg13842536,anf_fun13742494,anf_fun13762508,anf_fun13772509,anf_fun13782510,d5012150,ds5102152,p5082154,builtins8) {
var $z26172618 = D;
var $f26232624 = function(_) {
return R.isFunction(anf_fun13782510)?anf_fun13782510.app(d5012150,anf_arg13842536,anf_arg13952613):R.ffi.throwNonFunApp(L[379],anf_fun13782510,[d5012150,anf_arg13842536,anf_arg13952613]);
};
try {
if(--R.GAS > 0) {
$z26172618 = $f26232624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26232624,
"from":L[379]});
}
} catch($e26152616) {
if(R.isCont($e26152616)) {
var $ss26192620 = {"from":L[379],
"go":function(anf_array_val13962625) {
return $Hanf_array_val19992626(anf_array_val13962625,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,d5012150,ds5102152,p5082154,builtins8);
}};
$e26152616.stack[R.EXN_STACKHEIGHT++] = $ss26192620;
}
if(R.isPyretException($e26152616)) {
$e26152616.pyretStack.push(L[379]);
}
throw $e26152616;
}
var $ret26212622 = $Hanf_array_val19992626($z26172618,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,d5012150,ds5102152,p5082154,builtins8);
++R.GAS;
return $ret26212622;
};
var $Hanf_array_val19992626 = function(anf_array_val13962625,anf_arg13752493,anf_fun13742494,anf_fun13762508,anf_fun13772509,d5012150,ds5102152,p5082154,builtins8) {
var $z26292630 = D;
var $f26352636 = function(_) {
return R.isFunction(anf_fun13772509)?anf_fun13772509.app([anf_array_val13962625]):R.ffi.throwNonFunApp(L[367],anf_fun13772509,[[anf_array_val13962625]]);
};
try {
if(--R.GAS > 0) {
$z26292630 = $f26352636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26352636,
"from":L[367]});
}
} catch($e26272628) {
if(R.isCont($e26272628)) {
var $ss26312632 = {"from":L[367],
"go":function(anf_arg13972637) {
return $Hanf_arg19982638(anf_arg13972637,anf_arg13752493,anf_fun13742494,anf_fun13762508,d5012150,ds5102152,p5082154,builtins8);
}};
$e26272628.stack[R.EXN_STACKHEIGHT++] = $ss26312632;
}
if(R.isPyretException($e26272628)) {
$e26272628.pyretStack.push(L[367]);
}
throw $e26272628;
}
var $ret26332634 = $Hanf_arg19982638($z26292630,anf_arg13752493,anf_fun13742494,anf_fun13762508,d5012150,ds5102152,p5082154,builtins8);
++R.GAS;
return $ret26332634;
};
var $Hanf_arg19982638 = function(anf_arg13972637,anf_arg13752493,anf_fun13742494,anf_fun13762508,d5012150,ds5102152,p5082154,builtins8) {
var $z26412642 = D;
var $f26472648 = function(_) {
return R.isFunction(anf_fun13762508)?anf_fun13762508.app(d5012150,anf_arg13972637):R.ffi.throwNonFunApp(L[380],anf_fun13762508,[d5012150,anf_arg13972637]);
};
try {
if(--R.GAS > 0) {
$z26412642 = $f26472648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26472648,
"from":L[380]});
}
} catch($e26392640) {
if(R.isCont($e26392640)) {
var $ss26432644 = {"from":L[380],
"go":function(anf_arg13982649) {
return $Hanf_arg19972650(anf_arg13982649,anf_arg13752493,anf_fun13742494,ds5102152,p5082154,builtins8);
}};
$e26392640.stack[R.EXN_STACKHEIGHT++] = $ss26432644;
}
if(R.isPyretException($e26392640)) {
$e26392640.pyretStack.push(L[380]);
}
throw $e26392640;
}
var $ret26452646 = $Hanf_arg19972650($z26412642,anf_arg13752493,anf_fun13742494,ds5102152,p5082154,builtins8);
++R.GAS;
return $ret26452646;
};
var $Hanf_arg19972650 = function(anf_arg13982649,anf_arg13752493,anf_fun13742494,ds5102152,p5082154,builtins8) {
var anf_arg13992661 = R.makeSrcloc(L[360]);
var $z26532654 = D;
var $f26592660 = function(_) {
return R.isFunction(anf_fun13742494)?anf_fun13742494.app(("ds(prog2) is\n  A.s-block(d,\n    [list: \n      A.s-app(d,\n        A.s-dot(d, A.s-id(d, A.s-name(d, \"list\")), \"make\"),\n        [list: \n          A.s-array(d,\n            [list: one, two, A.s-app(d, id(\"_plus\"), [list: one, two])])\n        ])\n    ])"),anf_arg13752493,anf_arg13982649,anf_arg13992661):R.ffi.throwNonFunApp(L[360],anf_fun13742494,[("ds(prog2) is\n  A.s-block(d,\n    [list: \n      A.s-app(d,\n        A.s-dot(d, A.s-id(d, A.s-name(d, \"list\")), \"make\"),\n        [list: \n          A.s-array(d,\n            [list: one, two, A.s-app(d, id(\"_plus\"), [list: one, two])])\n        ])\n    ])"),anf_arg13752493,anf_arg13982649,anf_arg13992661]);
};
try {
if(--R.GAS > 0) {
$z26532654 = $f26592660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26592660,
"from":L[360]});
}
} catch($e26512652) {
if(R.isCont($e26512652)) {
var $ss26552656 = {"from":L[360],
"go":function(anf_begin_app_dropped19902662) {
return $Hanf_begin_app_dropped19962663(anf_begin_app_dropped19902662,ds5102152,p5082154,builtins8);
}};
$e26512652.stack[R.EXN_STACKHEIGHT++] = $ss26552656;
}
if(R.isPyretException($e26512652)) {
$e26512652.pyretStack.push(L[360]);
}
throw $e26512652;
}
var $ret26572658 = $Hanf_begin_app_dropped19962663($z26532654,ds5102152,p5082154,builtins8);
++R.GAS;
return $ret26572658;
};
var $Hanf_begin_app_dropped19962663 = function(anf_begin_app_dropped19902662,ds5102152,p5082154,builtins8) {
var $z26662667 = D;
var $f26722673 = function(_) {
return R.isFunction(p5082154)?p5082154.app(("for map(elt from l): elt + 1 end")):R.ffi.throwNonFunApp(L[381],p5082154,[("for map(elt from l): elt + 1 end")]);
};
try {
if(--R.GAS > 0) {
$z26662667 = $f26722673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26722673,
"from":L[381]});
}
} catch($e26642665) {
if(R.isCont($e26642665)) {
var $ss26682669 = {"from":L[381],
"go":function(prog35212674) {
return $Hprog319952675(prog35212674,ds5102152,p5082154,builtins8);
}};
$e26642665.stack[R.EXN_STACKHEIGHT++] = $ss26682669;
}
if(R.isPyretException($e26642665)) {
$e26642665.pyretStack.push(L[381]);
}
throw $e26642665;
}
var $ret26702671 = $Hprog319952675($z26662667,ds5102152,p5082154,builtins8);
++R.GAS;
return $ret26702671;
};
var $Hprog319952675 = function(prog35212674,ds5102152,p5082154,builtins8) {
var anf_fun14002686 = G(builtins8,"current-checker",L[382]);
var $z26782679 = D;
var $f26842685 = function(_) {
return R.isFunction(anf_fun14002686)?anf_fun14002686.app():R.ffi.throwNonFunApp(L[382],anf_fun14002686,[]);
};
try {
if(--R.GAS > 0) {
$z26782679 = $f26842685();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26842685,
"from":L[382]});
}
} catch($e26762677) {
if(R.isCont($e26762677)) {
var $ss26802681 = {"from":L[382],
"go":function(anf_bracket14012687) {
return $Hanf_bracket19942688(anf_bracket14012687,ds5102152,p5082154,prog35212674);
}};
$e26762677.stack[R.EXN_STACKHEIGHT++] = $ss26802681;
}
if(R.isPyretException($e26762677)) {
$e26762677.pyretStack.push(L[382]);
}
throw $e26762677;
}
var $ret26822683 = $Hanf_bracket19942688($z26782679,ds5102152,p5082154,prog35212674);
++R.GAS;
return $ret26822683;
};
var $Hanf_bracket19942688 = function(anf_bracket14012687,ds5102152,p5082154,prog35212674) {
var anf_fun14022700 = G(anf_bracket14012687,"check-is",L[382]);
var $z26912692 = D;
var $f26972698 = function(_) {
return R.isFunction(ds5102152)?ds5102152.app(prog35212674):R.ffi.throwNonFunApp(L[383],ds5102152,[prog35212674]);
};
try {
if(--R.GAS > 0) {
$z26912692 = $f26972698();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26972698,
"from":L[383]});
}
} catch($e26892690) {
if(R.isCont($e26892690)) {
var $ss26932694 = {"from":L[383],
"go":function(anf_arg14032699) {
return $Hanf_arg19932701(anf_arg14032699,anf_fun14022700,p5082154);
}};
$e26892690.stack[R.EXN_STACKHEIGHT++] = $ss26932694;
}
if(R.isPyretException($e26892690)) {
$e26892690.pyretStack.push(L[383]);
}
throw $e26892690;
}
var $ret26952696 = $Hanf_arg19932701($z26912692,anf_fun14022700,p5082154);
++R.GAS;
return $ret26952696;
};
var $Hanf_arg19932701 = function(anf_arg14032699,anf_fun14022700,p5082154) {
var $z27042705 = D;
var $f27102711 = function(_) {
return R.isFunction(p5082154)?p5082154.app(("map(lam(elt): _plus(elt, 1) end, l)")):R.ffi.throwNonFunApp(L[384],p5082154,[("map(lam(elt): _plus(elt, 1) end, l)")]);
};
try {
if(--R.GAS > 0) {
$z27042705 = $f27102711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27102711,
"from":L[384]});
}
} catch($e27022703) {
if(R.isCont($e27022703)) {
var $ss27062707 = {"from":L[384],
"go":function(anf_arg14042712) {
return $Hanf_arg19922713(anf_arg14042712,anf_arg14032699,anf_fun14022700);
}};
$e27022703.stack[R.EXN_STACKHEIGHT++] = $ss27062707;
}
if(R.isPyretException($e27022703)) {
$e27022703.pyretStack.push(L[384]);
}
throw $e27022703;
}
var $ret27082709 = $Hanf_arg19922713($z27042705,anf_arg14032699,anf_fun14022700);
++R.GAS;
return $ret27082709;
};
var $Hanf_arg19922713 = function(anf_arg14042712,anf_arg14032699,anf_fun14022700) {
var anf_arg14052724 = R.makeSrcloc(L[382]);
var $z27162717 = D;
var $f27222723 = function(_) {
return R.isFunction(anf_fun14022700)?anf_fun14022700.app(("ds(prog3) is p(\"map(lam(elt): _plus(elt, 1) end, l)\")"),anf_arg14032699,anf_arg14042712,anf_arg14052724):R.ffi.throwNonFunApp(L[19],anf_fun14022700,[("ds(prog3) is p(\"map(lam(elt): _plus(elt, 1) end, l)\")"),anf_arg14032699,anf_arg14042712,anf_arg14052724]);
};
try {
if(--R.GAS > 0) {
$z27162717 = $f27222723();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27222723,
"from":L[19]});
}
} catch($e27142715) {
if(R.isCont($e27142715)) {
var $ss27182719 = {"from":L[19],
"go":function(ann_DASH_check_DASH_temp13282725) {
return $Hann_DASH_check_DASH_temp19912726(ann_DASH_check_DASH_temp13282725);
}};
$e27142715.stack[R.EXN_STACKHEIGHT++] = $ss27182719;
}
if(R.isPyretException($e27142715)) {
$e27142715.pyretStack.push(L[19]);
}
throw $e27142715;
}
var $ret27202721 = $Hann_DASH_check_DASH_temp19912726($z27162717);
++R.GAS;
return $ret27202721;
};
var $Hann_DASH_check_DASH_temp19912726 = function(ann_DASH_check_DASH_temp13282725) {
return ann_DASH_check_DASH_temp13282725;
};
var $Hanf_bracket19872368 = function(anf_bracket13562367) {
var anf_fun13572737 = G(anf_bracket13562367,"pretty",L[386]);
var $z27292730 = D;
var $f27352736 = function(_) {
return R.isFunction(anf_fun13572737)?anf_fun13572737.app((80)):R.ffi.throwNonFunApp(L[385],anf_fun13572737,[(80)]);
};
try {
if(--R.GAS > 0) {
$z27292730 = $f27352736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27352736,
"from":L[385]});
}
} catch($e27272728) {
if(R.isCont($e27272728)) {
var $ss27312732 = {"from":L[385],
"go":function(anf_bracket13582738) {
return $Hanf_bracket19862739(anf_bracket13582738);
}};
$e27272728.stack[R.EXN_STACKHEIGHT++] = $ss27312732;
}
if(R.isPyretException($e27272728)) {
$e27272728.pyretStack.push(L[385]);
}
throw $e27272728;
}
var $ret27332734 = $Hanf_bracket19862739($z27292730);
++R.GAS;
return $ret27332734;
};
var $Hanf_bracket19862739 = function(anf_bracket13582738) {
var anf_fun13592750 = G(anf_bracket13582738,"join-str",L[387]);
var $z27422743 = D;
var $f27482749 = function(_) {
return R.isFunction(anf_fun13592750)?anf_fun13592750.app(("\n")):R.ffi.throwNonFunApp(L[351],anf_fun13592750,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z27422743 = $f27482749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27482749,
"from":L[351]});
}
} catch($e27402741) {
if(R.isCont($e27402741)) {
var $ss27442745 = {"from":L[351],
"go":function(ann_DASH_check_DASH_temp13542751) {
return $Hann_DASH_check_DASH_temp19852752(ann_DASH_check_DASH_temp13542751);
}};
$e27402741.stack[R.EXN_STACKHEIGHT++] = $ss27442745;
}
if(R.isPyretException($e27402741)) {
$e27402741.pyretStack.push(L[351]);
}
throw $e27402741;
}
var $ret27462747 = $Hann_DASH_check_DASH_temp19852752($z27422743);
++R.GAS;
return $ret27462747;
};
var $Hann_DASH_check_DASH_temp19852752 = function(ann_DASH_check_DASH_temp13542751) {
return ann_DASH_check_DASH_temp13542751;
};
var $Hanf_arg19842170 = function(anf_arg13512168,anf_fun13492169,d5012150) {
var $z27552756 = D;
var $f27612762 = function(_) {
return R.isFunction(anf_fun13492169)?anf_fun13492169.app(d5012150,anf_arg13512168):R.ffi.throwNonFunApp(L[320],anf_fun13492169,[d5012150,anf_arg13512168]);
};
try {
if(--R.GAS > 0) {
$z27552756 = $f27612762();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27612762,
"from":L[320]});
}
} catch($e27532754) {
if(R.isCont($e27532754)) {
var $ss27572758 = {"from":L[320],
"go":function(ann_DASH_check_DASH_temp13482763) {
return $Hann_DASH_check_DASH_temp19832764(ann_DASH_check_DASH_temp13482763);
}};
$e27532754.stack[R.EXN_STACKHEIGHT++] = $ss27572758;
}
if(R.isPyretException($e27532754)) {
$e27532754.pyretStack.push(L[320]);
}
throw $e27532754;
}
var $ret27592760 = $Hann_DASH_check_DASH_temp19832764($z27552756);
++R.GAS;
return $ret27592760;
};
var $Hann_DASH_check_DASH_temp19832764 = function(ann_DASH_check_DASH_temp13482763) {
return ann_DASH_check_DASH_temp13482763;
};
var $Hanf_bracket19822184 = function(anf_bracket13432182,A113,unglobal5022183) {
var anf_fun13442775 = G(anf_bracket13432182,"visit",L[389]);
var $z27672768 = D;
var $f27732774 = function(_) {
return R.isFunction(anf_fun13442775)?anf_fun13442775.app(unglobal5022183):R.ffi.throwNonFunApp(L[388],anf_fun13442775,[unglobal5022183]);
};
try {
if(--R.GAS > 0) {
$z27672768 = $f27732774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27732774,
"from":L[388]});
}
} catch($e27652766) {
if(R.isCont($e27652766)) {
var $ss27692770 = {"from":L[388],
"go":function(anf_bracket13452776) {
return $Hanf_bracket19812777(anf_bracket13452776,A113);
}};
$e27652766.stack[R.EXN_STACKHEIGHT++] = $ss27692770;
}
if(R.isPyretException($e27652766)) {
$e27652766.pyretStack.push(L[388]);
}
throw $e27652766;
}
var $ret27712772 = $Hanf_bracket19812777($z27672768,A113);
++R.GAS;
return $ret27712772;
};
var $Hanf_bracket19812777 = function(anf_bracket13452776,A113) {
var anf_fun13462788 = G(anf_bracket13452776,"visit",L[391]);
var anf_arg13472789 = G(A113,"dummy-loc-visitor",L[390]);
var $z27802781 = D;
var $f27862787 = function(_) {
return R.isFunction(anf_fun13462788)?anf_fun13462788.app(anf_arg13472789):R.ffi.throwNonFunApp(L[324],anf_fun13462788,[anf_arg13472789]);
};
try {
if(--R.GAS > 0) {
$z27802781 = $f27862787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27862787,
"from":L[324]});
}
} catch($e27782779) {
if(R.isCont($e27782779)) {
var $ss27822783 = {"from":L[324],
"go":function(ann_DASH_check_DASH_temp13422790) {
return $Hann_DASH_check_DASH_temp19802791(ann_DASH_check_DASH_temp13422790);
}};
$e27782779.stack[R.EXN_STACKHEIGHT++] = $ss27822783;
}
if(R.isPyretException($e27782779)) {
$e27782779.pyretStack.push(L[324]);
}
throw $e27782779;
}
var $ret27842785 = $Hann_DASH_check_DASH_temp19802791($z27802781);
++R.GAS;
return $ret27842785;
};
var $Hann_DASH_check_DASH_temp19802791 = function(ann_DASH_check_DASH_temp13422790) {
return ann_DASH_check_DASH_temp13422790;
};
var $Hanf_bracket19792198 = function(anf_bracket13382197,A113) {
var anf_bracket13392806 = G(anf_bracket13382197,"block",L[394]);
var anf_fun13402802 = G(anf_bracket13392806,"visit",L[393]);
var anf_arg13412803 = G(A113,"dummy-loc-visitor",L[392]);
var $z27942795 = D;
var $f28002801 = function(_) {
return R.isFunction(anf_fun13402802)?anf_fun13402802.app(anf_arg13412803):R.ffi.throwNonFunApp(L[326],anf_fun13402802,[anf_arg13412803]);
};
try {
if(--R.GAS > 0) {
$z27942795 = $f28002801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28002801,
"from":L[326]});
}
} catch($e27922793) {
if(R.isCont($e27922793)) {
var $ss27962797 = {"from":L[326],
"go":function(ann_DASH_check_DASH_temp13362804) {
return $Hann_DASH_check_DASH_temp19782805(ann_DASH_check_DASH_temp13362804);
}};
$e27922793.stack[R.EXN_STACKHEIGHT++] = $ss27962797;
}
if(R.isPyretException($e27922793)) {
$e27922793.pyretStack.push(L[326]);
}
throw $e27922793;
}
var $ret27982799 = $Hann_DASH_check_DASH_temp19782805($z27942795);
++R.GAS;
return $ret27982799;
};
var $Hann_DASH_check_DASH_temp19782805 = function(ann_DASH_check_DASH_temp13362804) {
return ann_DASH_check_DASH_temp13362804;
};
var $Hann_DASH_check_DASH_temp19772215 = function(ann_DASH_check_DASH_temp13332214) {
return ann_DASH_check_DASH_temp13332214;
};
var $Hann_DASH_check_DASH_temp19762231 = function(ann_DASH_check_DASH_temp13302230) {
return ann_DASH_check_DASH_temp13302230;
};
var $Hanf_arg19752250 = function(anf_arg12572247,A113,anf_fun12552248,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8) {
var $z28092810 = D;
var $f28152816 = function(_) {
return R.isFunction(anf_fun12552248)?anf_fun12552248.app(d4922246,anf_arg12572247):R.ffi.throwNonFunApp(L[395],anf_fun12552248,[d4922246,anf_arg12572247]);
};
try {
if(--R.GAS > 0) {
$z28092810 = $f28152816();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28152816,
"from":L[395]});
}
} catch($e28072808) {
if(R.isCont($e28072808)) {
var $ss28112812 = {"from":L[395],
"go":function(under4962817) {
return $Hunder19742818(under4962817,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8);
}};
$e28072808.stack[R.EXN_STACKHEIGHT++] = $ss28112812;
}
if(R.isPyretException($e28072808)) {
$e28072808.pyretStack.push(L[395]);
}
throw $e28072808;
}
var $ret28132814 = $Hunder19742818($z28092810,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8);
++R.GAS;
return $ret28132814;
};
var $Hunder19742818 = function(under4962817,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8) {
var $z28212822 = D;
var $f28272828 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("f")):R.ffi.throwNonFunApp(L[396],id4942249,[("f")]);
};
try {
if(--R.GAS > 0) {
$z28212822 = $f28272828();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28272828,
"from":L[396]});
}
} catch($e28192820) {
if(R.isCont($e28192820)) {
var $ss28232824 = {"from":L[396],
"go":function(anf_arg12582829) {
return $Hanf_arg19732830(anf_arg12582829,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e28192820.stack[R.EXN_STACKHEIGHT++] = $ss28232824;
}
if(R.isPyretException($e28192820)) {
$e28192820.pyretStack.push(L[396]);
}
throw $e28192820;
}
var $ret28252826 = $Hanf_arg19732830($z28212822,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret28252826;
};
var $Hanf_arg19732830 = function(anf_arg12582829,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun12592842 = G(list2753,"make",L[398]);
var $z28332834 = D;
var $f28392840 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("x")):R.ffi.throwNonFunApp(L[397],id4942249,[("x")]);
};
try {
if(--R.GAS > 0) {
$z28332834 = $f28392840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28392840,
"from":L[397]});
}
} catch($e28312832) {
if(R.isCont($e28312832)) {
var $ss28352836 = {"from":L[397],
"go":function(anf_array_val12602841) {
return $Hanf_array_val19722843(anf_array_val12602841,A113,anf_arg12582829,anf_fun12592842,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e28312832.stack[R.EXN_STACKHEIGHT++] = $ss28352836;
}
if(R.isPyretException($e28312832)) {
$e28312832.pyretStack.push(L[397]);
}
throw $e28312832;
}
var $ret28372838 = $Hanf_array_val19722843($z28332834,A113,anf_arg12582829,anf_fun12592842,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret28372838;
};
var $Hanf_array_val19722843 = function(anf_array_val12602841,A113,anf_arg12582829,anf_fun12592842,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z28462847 = D;
var $f28522853 = function(_) {
return R.isFunction(anf_fun12592842)?anf_fun12592842.app([under4962817,anf_array_val12602841]):R.ffi.throwNonFunApp(L[398],anf_fun12592842,[[under4962817,anf_array_val12602841]]);
};
try {
if(--R.GAS > 0) {
$z28462847 = $f28522853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28522853,
"from":L[398]});
}
} catch($e28442845) {
if(R.isCont($e28442845)) {
var $ss28482849 = {"from":L[398],
"go":function(anf_arg12612854) {
return $Hanf_arg19712855(anf_arg12612854,A113,anf_arg12582829,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e28442845.stack[R.EXN_STACKHEIGHT++] = $ss28482849;
}
if(R.isPyretException($e28442845)) {
$e28442845.pyretStack.push(L[398]);
}
throw $e28442845;
}
var $ret28502851 = $Hanf_arg19712855($z28462847,A113,anf_arg12582829,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret28502851;
};
var $Hanf_arg19712855 = function(anf_arg12612854,A113,anf_arg12582829,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z28582859 = D;
var $f28642865 = function(_) {
return R.isFunction(ds_DASH_curry114304.$var)?ds_DASH_curry114304.$var.app(d4922246,anf_arg12582829,anf_arg12612854):R.ffi.throwNonFunApp(L[399],ds_DASH_curry114304.$var,[d4922246,anf_arg12582829,anf_arg12612854]);
};
try {
if(--R.GAS > 0) {
$z28582859 = $f28642865();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28642865,
"from":L[399]});
}
} catch($e28562857) {
if(R.isCont($e28562857)) {
var $ss28602861 = {"from":L[399],
"go":function(ds_DASH_ed4972866) {
return $Hds_DASH_ed19702867(ds_DASH_ed4972866,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e28562857.stack[R.EXN_STACKHEIGHT++] = $ss28602861;
}
if(R.isPyretException($e28562857)) {
$e28562857.pyretStack.push(L[399]);
}
throw $e28562857;
}
var $ret28622863 = $Hds_DASH_ed19702867($z28582859,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret28622863;
};
var $Hds_DASH_ed19702867 = function(ds_DASH_ed4972866,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun12622878 = G(builtins8,"current-checker",L[400]);
var $z28702871 = D;
var $f28762877 = function(_) {
return R.isFunction(anf_fun12622878)?anf_fun12622878.app():R.ffi.throwNonFunApp(L[400],anf_fun12622878,[]);
};
try {
if(--R.GAS > 0) {
$z28702871 = $f28762877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28762877,
"from":L[400]});
}
} catch($e28682869) {
if(R.isCont($e28682869)) {
var $ss28722873 = {"from":L[400],
"go":function(anf_bracket12632879) {
return $Hanf_bracket19692880(anf_bracket12632879,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8);
}};
$e28682869.stack[R.EXN_STACKHEIGHT++] = $ss28722873;
}
if(R.isPyretException($e28682869)) {
$e28682869.pyretStack.push(L[400]);
}
throw $e28682869;
}
var $ret28742875 = $Hanf_bracket19692880($z28702871,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret28742875;
};
var $Hanf_bracket19692880 = function(anf_bracket12632879,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8) {
var anf_fun12642891 = G(anf_bracket12632879,"check-satisfies",L[400]);
var anf_arg12652892 = G(A113,"is-s-lam",L[401]);
var anf_arg12662893 = R.makeSrcloc(L[400]);
var $z28832884 = D;
var $f28892890 = function(_) {
return R.isFunction(anf_fun12642891)?anf_fun12642891.app(("ds-ed satisfies A.is-s-lam"),ds_DASH_ed4972866,anf_arg12652892,anf_arg12662893):R.ffi.throwNonFunApp(L[400],anf_fun12642891,[("ds-ed satisfies A.is-s-lam"),ds_DASH_ed4972866,anf_arg12652892,anf_arg12662893]);
};
try {
if(--R.GAS > 0) {
$z28832884 = $f28892890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28892890,
"from":L[400]});
}
} catch($e28812882) {
if(R.isCont($e28812882)) {
var $ss28852886 = {"from":L[400],
"go":function(anf_begin_app_dropped19292894) {
return $Hanf_begin_app_dropped19682895(anf_begin_app_dropped19292894,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8);
}};
$e28812882.stack[R.EXN_STACKHEIGHT++] = $ss28852886;
}
if(R.isPyretException($e28812882)) {
$e28812882.pyretStack.push(L[400]);
}
throw $e28812882;
}
var $ret28872888 = $Hanf_begin_app_dropped19682895($z28832884,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret28872888;
};
var $Hanf_begin_app_dropped19682895 = function(anf_begin_app_dropped19292894,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8) {
var anf_fun12672906 = G(builtins8,"current-checker",L[402]);
var $z28982899 = D;
var $f29042905 = function(_) {
return R.isFunction(anf_fun12672906)?anf_fun12672906.app():R.ffi.throwNonFunApp(L[402],anf_fun12672906,[]);
};
try {
if(--R.GAS > 0) {
$z28982899 = $f29042905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29042905,
"from":L[402]});
}
} catch($e28962897) {
if(R.isCont($e28962897)) {
var $ss29002901 = {"from":L[402],
"go":function(anf_bracket12682907) {
return $Hanf_bracket19672908(anf_bracket12682907,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8);
}};
$e28962897.stack[R.EXN_STACKHEIGHT++] = $ss29002901;
}
if(R.isPyretException($e28962897)) {
$e28962897.pyretStack.push(L[402]);
}
throw $e28962897;
}
var $ret29022903 = $Hanf_bracket19672908($z28982899,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret29022903;
};
var $Hanf_bracket19672908 = function(anf_bracket12682907,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed4972866,id4942249,list2753,under4962817,builtins8) {
var anf_fun12692921 = G(anf_bracket12682907,"check-is",L[402]);
var anf_bracket12702923 = G(ds_DASH_ed4972866,"args",L[405]);
var anf_fun12712919 = G(anf_bracket12702923,"length",L[404]);
var $z29112912 = D;
var $f29172918 = function(_) {
return R.isFunction(anf_fun12712919)?anf_fun12712919.app():R.ffi.throwNonFunApp(L[403],anf_fun12712919,[]);
};
try {
if(--R.GAS > 0) {
$z29112912 = $f29172918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29172918,
"from":L[403]});
}
} catch($e29092910) {
if(R.isCont($e29092910)) {
var $ss29132914 = {"from":L[403],
"go":function(anf_arg12722920) {
return $Hanf_arg19662922(anf_arg12722920,A113,anf_fun12692921,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e29092910.stack[R.EXN_STACKHEIGHT++] = $ss29132914;
}
if(R.isPyretException($e29092910)) {
$e29092910.pyretStack.push(L[403]);
}
throw $e29092910;
}
var $ret29152916 = $Hanf_arg19662922($z29112912,A113,anf_fun12692921,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret29152916;
};
var $Hanf_arg19662922 = function(anf_arg12722920,A113,anf_fun12692921,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_arg12732934 = R.makeSrcloc(L[402]);
var $z29262927 = D;
var $f29322933 = function(_) {
return R.isFunction(anf_fun12692921)?anf_fun12692921.app(("ds-ed.args.length() is 1"),anf_arg12722920,(1),anf_arg12732934):R.ffi.throwNonFunApp(L[402],anf_fun12692921,[("ds-ed.args.length() is 1"),anf_arg12722920,(1),anf_arg12732934]);
};
try {
if(--R.GAS > 0) {
$z29262927 = $f29322933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29322933,
"from":L[402]});
}
} catch($e29242925) {
if(R.isCont($e29242925)) {
var $ss29282929 = {"from":L[402],
"go":function(anf_begin_app_dropped19302935) {
return $Hanf_begin_app_dropped19652936(anf_begin_app_dropped19302935,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e29242925.stack[R.EXN_STACKHEIGHT++] = $ss29282929;
}
if(R.isPyretException($e29242925)) {
$e29242925.pyretStack.push(L[402]);
}
throw $e29242925;
}
var $ret29302931 = $Hanf_begin_app_dropped19652936($z29262927,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret29302931;
};
var $Hanf_begin_app_dropped19652936 = function(anf_begin_app_dropped19302935,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z29392940 = D;
var $f29452946 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("f")):R.ffi.throwNonFunApp(L[406],id4942249,[("f")]);
};
try {
if(--R.GAS > 0) {
$z29392940 = $f29452946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29452946,
"from":L[406]});
}
} catch($e29372938) {
if(R.isCont($e29372938)) {
var $ss29412942 = {"from":L[406],
"go":function(anf_arg12742947) {
return $Hanf_arg19642948(anf_arg12742947,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e29372938.stack[R.EXN_STACKHEIGHT++] = $ss29412942;
}
if(R.isPyretException($e29372938)) {
$e29372938.pyretStack.push(L[406]);
}
throw $e29372938;
}
var $ret29432944 = $Hanf_arg19642948($z29392940,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret29432944;
};
var $Hanf_arg19642948 = function(anf_arg12742947,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun12752959 = G(list2753,"make",L[407]);
var $z29512952 = D;
var $f29572958 = function(_) {
return R.isFunction(anf_fun12752959)?anf_fun12752959.app([under4962817,under4962817]):R.ffi.throwNonFunApp(L[407],anf_fun12752959,[[under4962817,under4962817]]);
};
try {
if(--R.GAS > 0) {
$z29512952 = $f29572958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29572958,
"from":L[407]});
}
} catch($e29492950) {
if(R.isCont($e29492950)) {
var $ss29532954 = {"from":L[407],
"go":function(anf_arg12762960) {
return $Hanf_arg19632961(anf_arg12762960,A113,anf_arg12742947,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e29492950.stack[R.EXN_STACKHEIGHT++] = $ss29532954;
}
if(R.isPyretException($e29492950)) {
$e29492950.pyretStack.push(L[407]);
}
throw $e29492950;
}
var $ret29552956 = $Hanf_arg19632961($z29512952,A113,anf_arg12742947,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret29552956;
};
var $Hanf_arg19632961 = function(anf_arg12762960,A113,anf_arg12742947,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z29642965 = D;
var $f29702971 = function(_) {
return R.isFunction(ds_DASH_curry114304.$var)?ds_DASH_curry114304.$var.app(d4922246,anf_arg12742947,anf_arg12762960):R.ffi.throwNonFunApp(L[408],ds_DASH_curry114304.$var,[d4922246,anf_arg12742947,anf_arg12762960]);
};
try {
if(--R.GAS > 0) {
$z29642965 = $f29702971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29702971,
"from":L[408]});
}
} catch($e29622963) {
if(R.isCont($e29622963)) {
var $ss29662967 = {"from":L[408],
"go":function(ds_DASH_ed24982972) {
return $Hds_DASH_ed219622973(ds_DASH_ed24982972,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e29622963.stack[R.EXN_STACKHEIGHT++] = $ss29662967;
}
if(R.isPyretException($e29622963)) {
$e29622963.pyretStack.push(L[408]);
}
throw $e29622963;
}
var $ret29682969 = $Hds_DASH_ed219622973($z29642965,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret29682969;
};
var $Hds_DASH_ed219622973 = function(ds_DASH_ed24982972,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun12772984 = G(builtins8,"current-checker",L[409]);
var $z29762977 = D;
var $f29822983 = function(_) {
return R.isFunction(anf_fun12772984)?anf_fun12772984.app():R.ffi.throwNonFunApp(L[409],anf_fun12772984,[]);
};
try {
if(--R.GAS > 0) {
$z29762977 = $f29822983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29822983,
"from":L[409]});
}
} catch($e29742975) {
if(R.isCont($e29742975)) {
var $ss29782979 = {"from":L[409],
"go":function(anf_bracket12782985) {
return $Hanf_bracket19612986(anf_bracket12782985,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8);
}};
$e29742975.stack[R.EXN_STACKHEIGHT++] = $ss29782979;
}
if(R.isPyretException($e29742975)) {
$e29742975.pyretStack.push(L[409]);
}
throw $e29742975;
}
var $ret29802981 = $Hanf_bracket19612986($z29762977,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret29802981;
};
var $Hanf_bracket19612986 = function(anf_bracket12782985,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8) {
var anf_fun12792997 = G(anf_bracket12782985,"check-satisfies",L[409]);
var anf_arg12802998 = G(A113,"is-s-lam",L[410]);
var anf_arg12812999 = R.makeSrcloc(L[409]);
var $z29892990 = D;
var $f29952996 = function(_) {
return R.isFunction(anf_fun12792997)?anf_fun12792997.app(("ds-ed2 satisfies A.is-s-lam"),ds_DASH_ed24982972,anf_arg12802998,anf_arg12812999):R.ffi.throwNonFunApp(L[409],anf_fun12792997,[("ds-ed2 satisfies A.is-s-lam"),ds_DASH_ed24982972,anf_arg12802998,anf_arg12812999]);
};
try {
if(--R.GAS > 0) {
$z29892990 = $f29952996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29952996,
"from":L[409]});
}
} catch($e29872988) {
if(R.isCont($e29872988)) {
var $ss29912992 = {"from":L[409],
"go":function(anf_begin_app_dropped19313000) {
return $Hanf_begin_app_dropped19603001(anf_begin_app_dropped19313000,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8);
}};
$e29872988.stack[R.EXN_STACKHEIGHT++] = $ss29912992;
}
if(R.isPyretException($e29872988)) {
$e29872988.pyretStack.push(L[409]);
}
throw $e29872988;
}
var $ret29932994 = $Hanf_begin_app_dropped19603001($z29892990,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret29932994;
};
var $Hanf_begin_app_dropped19603001 = function(anf_begin_app_dropped19313000,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8) {
var anf_fun12823012 = G(builtins8,"current-checker",L[411]);
var $z30043005 = D;
var $f30103011 = function(_) {
return R.isFunction(anf_fun12823012)?anf_fun12823012.app():R.ffi.throwNonFunApp(L[411],anf_fun12823012,[]);
};
try {
if(--R.GAS > 0) {
$z30043005 = $f30103011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30103011,
"from":L[411]});
}
} catch($e30023003) {
if(R.isCont($e30023003)) {
var $ss30063007 = {"from":L[411],
"go":function(anf_bracket12833013) {
return $Hanf_bracket19593014(anf_bracket12833013,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8);
}};
$e30023003.stack[R.EXN_STACKHEIGHT++] = $ss30063007;
}
if(R.isPyretException($e30023003)) {
$e30023003.pyretStack.push(L[411]);
}
throw $e30023003;
}
var $ret30083009 = $Hanf_bracket19593014($z30043005,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret30083009;
};
var $Hanf_bracket19593014 = function(anf_bracket12833013,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed24982972,id4942249,list2753,under4962817,builtins8) {
var anf_fun12843027 = G(anf_bracket12833013,"check-is",L[411]);
var anf_bracket12853029 = G(ds_DASH_ed24982972,"args",L[414]);
var anf_fun12863025 = G(anf_bracket12853029,"length",L[413]);
var $z30173018 = D;
var $f30233024 = function(_) {
return R.isFunction(anf_fun12863025)?anf_fun12863025.app():R.ffi.throwNonFunApp(L[412],anf_fun12863025,[]);
};
try {
if(--R.GAS > 0) {
$z30173018 = $f30233024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30233024,
"from":L[412]});
}
} catch($e30153016) {
if(R.isCont($e30153016)) {
var $ss30193020 = {"from":L[412],
"go":function(anf_arg12873026) {
return $Hanf_arg19583028(anf_arg12873026,A113,anf_fun12843027,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e30153016.stack[R.EXN_STACKHEIGHT++] = $ss30193020;
}
if(R.isPyretException($e30153016)) {
$e30153016.pyretStack.push(L[412]);
}
throw $e30153016;
}
var $ret30213022 = $Hanf_arg19583028($z30173018,A113,anf_fun12843027,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret30213022;
};
var $Hanf_arg19583028 = function(anf_arg12873026,A113,anf_fun12843027,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_arg12883040 = R.makeSrcloc(L[411]);
var $z30323033 = D;
var $f30383039 = function(_) {
return R.isFunction(anf_fun12843027)?anf_fun12843027.app(("ds-ed2.args.length() is 2"),anf_arg12873026,(2),anf_arg12883040):R.ffi.throwNonFunApp(L[411],anf_fun12843027,[("ds-ed2.args.length() is 2"),anf_arg12873026,(2),anf_arg12883040]);
};
try {
if(--R.GAS > 0) {
$z30323033 = $f30383039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30383039,
"from":L[411]});
}
} catch($e30303031) {
if(R.isCont($e30303031)) {
var $ss30343035 = {"from":L[411],
"go":function(anf_begin_app_dropped19323041) {
return $Hanf_begin_app_dropped19573042(anf_begin_app_dropped19323041,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e30303031.stack[R.EXN_STACKHEIGHT++] = $ss30343035;
}
if(R.isPyretException($e30303031)) {
$e30303031.pyretStack.push(L[411]);
}
throw $e30303031;
}
var $ret30363037 = $Hanf_begin_app_dropped19573042($z30323033,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret30363037;
};
var $Hanf_begin_app_dropped19573042 = function(anf_begin_app_dropped19323041,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z30453046 = D;
var $f30513052 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("f")):R.ffi.throwNonFunApp(L[415],id4942249,[("f")]);
};
try {
if(--R.GAS > 0) {
$z30453046 = $f30513052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30513052,
"from":L[415]});
}
} catch($e30433044) {
if(R.isCont($e30433044)) {
var $ss30473048 = {"from":L[415],
"go":function(anf_arg12893053) {
return $Hanf_arg19563054(anf_arg12893053,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e30433044.stack[R.EXN_STACKHEIGHT++] = $ss30473048;
}
if(R.isPyretException($e30433044)) {
$e30433044.pyretStack.push(L[415]);
}
throw $e30433044;
}
var $ret30493050 = $Hanf_arg19563054($z30453046,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret30493050;
};
var $Hanf_arg19563054 = function(anf_arg12893053,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun12903066 = G(list2753,"make",L[417]);
var $z30573058 = D;
var $f30633064 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("x")):R.ffi.throwNonFunApp(L[416],id4942249,[("x")]);
};
try {
if(--R.GAS > 0) {
$z30573058 = $f30633064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30633064,
"from":L[416]});
}
} catch($e30553056) {
if(R.isCont($e30553056)) {
var $ss30593060 = {"from":L[416],
"go":function(anf_array_val12913065) {
return $Hanf_array_val19553067(anf_array_val12913065,A113,anf_arg12893053,anf_fun12903066,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e30553056.stack[R.EXN_STACKHEIGHT++] = $ss30593060;
}
if(R.isPyretException($e30553056)) {
$e30553056.pyretStack.push(L[416]);
}
throw $e30553056;
}
var $ret30613062 = $Hanf_array_val19553067($z30573058,A113,anf_arg12893053,anf_fun12903066,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret30613062;
};
var $Hanf_array_val19553067 = function(anf_array_val12913065,A113,anf_arg12893053,anf_fun12903066,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z30703071 = D;
var $f30763077 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("y")):R.ffi.throwNonFunApp(L[418],id4942249,[("y")]);
};
try {
if(--R.GAS > 0) {
$z30703071 = $f30763077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30763077,
"from":L[418]});
}
} catch($e30683069) {
if(R.isCont($e30683069)) {
var $ss30723073 = {"from":L[418],
"go":function(anf_array_val12923078) {
return $Hanf_array_val19543079(anf_array_val12923078,A113,anf_arg12893053,anf_array_val12913065,anf_fun12903066,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e30683069.stack[R.EXN_STACKHEIGHT++] = $ss30723073;
}
if(R.isPyretException($e30683069)) {
$e30683069.pyretStack.push(L[418]);
}
throw $e30683069;
}
var $ret30743075 = $Hanf_array_val19543079($z30703071,A113,anf_arg12893053,anf_array_val12913065,anf_fun12903066,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret30743075;
};
var $Hanf_array_val19543079 = function(anf_array_val12923078,A113,anf_arg12893053,anf_array_val12913065,anf_fun12903066,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z30823083 = D;
var $f30883089 = function(_) {
return R.isFunction(anf_fun12903066)?anf_fun12903066.app([anf_array_val12913065,anf_array_val12923078]):R.ffi.throwNonFunApp(L[417],anf_fun12903066,[[anf_array_val12913065,anf_array_val12923078]]);
};
try {
if(--R.GAS > 0) {
$z30823083 = $f30883089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30883089,
"from":L[417]});
}
} catch($e30803081) {
if(R.isCont($e30803081)) {
var $ss30843085 = {"from":L[417],
"go":function(anf_arg12933090) {
return $Hanf_arg19533091(anf_arg12933090,A113,anf_arg12893053,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e30803081.stack[R.EXN_STACKHEIGHT++] = $ss30843085;
}
if(R.isPyretException($e30803081)) {
$e30803081.pyretStack.push(L[417]);
}
throw $e30803081;
}
var $ret30863087 = $Hanf_arg19533091($z30823083,A113,anf_arg12893053,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret30863087;
};
var $Hanf_arg19533091 = function(anf_arg12933090,A113,anf_arg12893053,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z30943095 = D;
var $f31003101 = function(_) {
return R.isFunction(ds_DASH_curry114304.$var)?ds_DASH_curry114304.$var.app(d4922246,anf_arg12893053,anf_arg12933090):R.ffi.throwNonFunApp(L[419],ds_DASH_curry114304.$var,[d4922246,anf_arg12893053,anf_arg12933090]);
};
try {
if(--R.GAS > 0) {
$z30943095 = $f31003101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31003101,
"from":L[419]});
}
} catch($e30923093) {
if(R.isCont($e30923093)) {
var $ss30963097 = {"from":L[419],
"go":function(ds_DASH_ed34993102) {
return $Hds_DASH_ed319523103(ds_DASH_ed34993102,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e30923093.stack[R.EXN_STACKHEIGHT++] = $ss30963097;
}
if(R.isPyretException($e30923093)) {
$e30923093.pyretStack.push(L[419]);
}
throw $e30923093;
}
var $ret30983099 = $Hds_DASH_ed319523103($z30943095,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret30983099;
};
var $Hds_DASH_ed319523103 = function(ds_DASH_ed34993102,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun12943114 = G(builtins8,"current-checker",L[420]);
var $z31063107 = D;
var $f31123113 = function(_) {
return R.isFunction(anf_fun12943114)?anf_fun12943114.app():R.ffi.throwNonFunApp(L[420],anf_fun12943114,[]);
};
try {
if(--R.GAS > 0) {
$z31063107 = $f31123113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31123113,
"from":L[420]});
}
} catch($e31043105) {
if(R.isCont($e31043105)) {
var $ss31083109 = {"from":L[420],
"go":function(anf_bracket12953115) {
return $Hanf_bracket19513116(anf_bracket12953115,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed34993102,id4942249,list2753,under4962817,builtins8);
}};
$e31043105.stack[R.EXN_STACKHEIGHT++] = $ss31083109;
}
if(R.isPyretException($e31043105)) {
$e31043105.pyretStack.push(L[420]);
}
throw $e31043105;
}
var $ret31103111 = $Hanf_bracket19513116($z31063107,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed34993102,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret31103111;
};
var $Hanf_bracket19513116 = function(anf_bracket12953115,A113,d4922246,ds_DASH_curry114304,ds_DASH_ed34993102,id4942249,list2753,under4962817,builtins8) {
var anf_fun12963130 = G(anf_bracket12953115,"check-is",L[420]);
var anf_fun12973127 = G(ds_DASH_ed34993102,"visit",L[423]);
var anf_arg12983128 = G(A113,"dummy-loc-visitor",L[422]);
var $z31193120 = D;
var $f31253126 = function(_) {
return R.isFunction(anf_fun12973127)?anf_fun12973127.app(anf_arg12983128):R.ffi.throwNonFunApp(L[421],anf_fun12973127,[anf_arg12983128]);
};
try {
if(--R.GAS > 0) {
$z31193120 = $f31253126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31253126,
"from":L[421]});
}
} catch($e31173118) {
if(R.isCont($e31173118)) {
var $ss31213122 = {"from":L[421],
"go":function(anf_arg12993129) {
return $Hanf_arg19503131(anf_arg12993129,A113,anf_fun12963130,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e31173118.stack[R.EXN_STACKHEIGHT++] = $ss31213122;
}
if(R.isPyretException($e31173118)) {
$e31173118.pyretStack.push(L[421]);
}
throw $e31173118;
}
var $ret31233124 = $Hanf_arg19503131($z31193120,A113,anf_fun12963130,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret31233124;
};
var $Hanf_arg19503131 = function(anf_arg12993129,A113,anf_fun12963130,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun13003143 = G(A113,"s-app",L[425]);
var $z31343135 = D;
var $f31403141 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("f")):R.ffi.throwNonFunApp(L[424],id4942249,[("f")]);
};
try {
if(--R.GAS > 0) {
$z31343135 = $f31403141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31403141,
"from":L[424]});
}
} catch($e31323133) {
if(R.isCont($e31323133)) {
var $ss31363137 = {"from":L[424],
"go":function(anf_arg13013142) {
return $Hanf_arg19493144(anf_arg13013142,A113,anf_arg12993129,anf_fun12963130,anf_fun13003143,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e31323133.stack[R.EXN_STACKHEIGHT++] = $ss31363137;
}
if(R.isPyretException($e31323133)) {
$e31323133.pyretStack.push(L[424]);
}
throw $e31323133;
}
var $ret31383139 = $Hanf_arg19493144($z31343135,A113,anf_arg12993129,anf_fun12963130,anf_fun13003143,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret31383139;
};
var $Hanf_arg19493144 = function(anf_arg13013142,A113,anf_arg12993129,anf_fun12963130,anf_fun13003143,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun13023156 = G(list2753,"make",L[427]);
var $z31473148 = D;
var $f31533154 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("x")):R.ffi.throwNonFunApp(L[426],id4942249,[("x")]);
};
try {
if(--R.GAS > 0) {
$z31473148 = $f31533154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31533154,
"from":L[426]});
}
} catch($e31453146) {
if(R.isCont($e31453146)) {
var $ss31493150 = {"from":L[426],
"go":function(anf_array_val13033155) {
return $Hanf_array_val19483157(anf_array_val13033155,A113,anf_arg12993129,anf_arg13013142,anf_fun12963130,anf_fun13003143,anf_fun13023156,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e31453146.stack[R.EXN_STACKHEIGHT++] = $ss31493150;
}
if(R.isPyretException($e31453146)) {
$e31453146.pyretStack.push(L[426]);
}
throw $e31453146;
}
var $ret31513152 = $Hanf_array_val19483157($z31473148,A113,anf_arg12993129,anf_arg13013142,anf_fun12963130,anf_fun13003143,anf_fun13023156,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret31513152;
};
var $Hanf_array_val19483157 = function(anf_array_val13033155,A113,anf_arg12993129,anf_arg13013142,anf_fun12963130,anf_fun13003143,anf_fun13023156,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z31603161 = D;
var $f31663167 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("y")):R.ffi.throwNonFunApp(L[428],id4942249,[("y")]);
};
try {
if(--R.GAS > 0) {
$z31603161 = $f31663167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31663167,
"from":L[428]});
}
} catch($e31583159) {
if(R.isCont($e31583159)) {
var $ss31623163 = {"from":L[428],
"go":function(anf_array_val13043168) {
return $Hanf_array_val19473169(anf_array_val13043168,A113,anf_arg12993129,anf_arg13013142,anf_array_val13033155,anf_fun12963130,anf_fun13003143,anf_fun13023156,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e31583159.stack[R.EXN_STACKHEIGHT++] = $ss31623163;
}
if(R.isPyretException($e31583159)) {
$e31583159.pyretStack.push(L[428]);
}
throw $e31583159;
}
var $ret31643165 = $Hanf_array_val19473169($z31603161,A113,anf_arg12993129,anf_arg13013142,anf_array_val13033155,anf_fun12963130,anf_fun13003143,anf_fun13023156,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret31643165;
};
var $Hanf_array_val19473169 = function(anf_array_val13043168,A113,anf_arg12993129,anf_arg13013142,anf_array_val13033155,anf_fun12963130,anf_fun13003143,anf_fun13023156,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z31723173 = D;
var $f31783179 = function(_) {
return R.isFunction(anf_fun13023156)?anf_fun13023156.app([anf_array_val13033155,anf_array_val13043168]):R.ffi.throwNonFunApp(L[427],anf_fun13023156,[[anf_array_val13033155,anf_array_val13043168]]);
};
try {
if(--R.GAS > 0) {
$z31723173 = $f31783179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31783179,
"from":L[427]});
}
} catch($e31703171) {
if(R.isCont($e31703171)) {
var $ss31743175 = {"from":L[427],
"go":function(anf_arg13053180) {
return $Hanf_arg19463181(anf_arg13053180,A113,anf_arg12993129,anf_arg13013142,anf_fun12963130,anf_fun13003143,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e31703171.stack[R.EXN_STACKHEIGHT++] = $ss31743175;
}
if(R.isPyretException($e31703171)) {
$e31703171.pyretStack.push(L[427]);
}
throw $e31703171;
}
var $ret31763177 = $Hanf_arg19463181($z31723173,A113,anf_arg12993129,anf_arg13013142,anf_fun12963130,anf_fun13003143,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret31763177;
};
var $Hanf_arg19463181 = function(anf_arg13053180,A113,anf_arg12993129,anf_arg13013142,anf_fun12963130,anf_fun13003143,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var $z31843185 = D;
var $f31903191 = function(_) {
return R.isFunction(anf_fun13003143)?anf_fun13003143.app(d4922246,anf_arg13013142,anf_arg13053180):R.ffi.throwNonFunApp(L[429],anf_fun13003143,[d4922246,anf_arg13013142,anf_arg13053180]);
};
try {
if(--R.GAS > 0) {
$z31843185 = $f31903191();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31903191,
"from":L[429]});
}
} catch($e31823183) {
if(R.isCont($e31823183)) {
var $ss31863187 = {"from":L[429],
"go":function(anf_arg13063192) {
return $Hanf_arg19453193(anf_arg13063192,A113,anf_arg12993129,anf_fun12963130,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e31823183.stack[R.EXN_STACKHEIGHT++] = $ss31863187;
}
if(R.isPyretException($e31823183)) {
$e31823183.pyretStack.push(L[429]);
}
throw $e31823183;
}
var $ret31883189 = $Hanf_arg19453193($z31843185,A113,anf_arg12993129,anf_fun12963130,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret31883189;
};
var $Hanf_arg19453193 = function(anf_arg13063192,A113,anf_arg12993129,anf_fun12963130,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_arg13073204 = R.makeSrcloc(L[420]);
var $z31963197 = D;
var $f32023203 = function(_) {
return R.isFunction(anf_fun12963130)?anf_fun12963130.app(("ds-ed3.visit(A.dummy-loc-visitor) is\n  A.s-app(d, id(\"f\"), [list: id(\"x\"), id(\"y\")])"),anf_arg12993129,anf_arg13063192,anf_arg13073204):R.ffi.throwNonFunApp(L[420],anf_fun12963130,[("ds-ed3.visit(A.dummy-loc-visitor) is\n  A.s-app(d, id(\"f\"), [list: id(\"x\"), id(\"y\")])"),anf_arg12993129,anf_arg13063192,anf_arg13073204]);
};
try {
if(--R.GAS > 0) {
$z31963197 = $f32023203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32023203,
"from":L[420]});
}
} catch($e31943195) {
if(R.isCont($e31943195)) {
var $ss31983199 = {"from":L[420],
"go":function(anf_begin_app_dropped19333205) {
return $Hanf_begin_app_dropped19443206(anf_begin_app_dropped19333205,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
}};
$e31943195.stack[R.EXN_STACKHEIGHT++] = $ss31983199;
}
if(R.isPyretException($e31943195)) {
$e31943195.pyretStack.push(L[420]);
}
throw $e31943195;
}
var $ret32003201 = $Hanf_begin_app_dropped19443206($z31963197,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8);
++R.GAS;
return $ret32003201;
};
var $Hanf_begin_app_dropped19443206 = function(anf_begin_app_dropped19333205,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,under4962817,builtins8) {
var anf_fun13083217 = G(A113,"s-dot",L[431]);
var $z32093210 = D;
var $f32153216 = function(_) {
return R.isFunction(anf_fun13083217)?anf_fun13083217.app(d4922246,under4962817,("f")):R.ffi.throwNonFunApp(L[430],anf_fun13083217,[d4922246,under4962817,("f")]);
};
try {
if(--R.GAS > 0) {
$z32093210 = $f32153216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32153216,
"from":L[430]});
}
} catch($e32073208) {
if(R.isCont($e32073208)) {
var $ss32113212 = {"from":L[430],
"go":function(anf_arg13093218) {
return $Hanf_arg19433219(anf_arg13093218,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8);
}};
$e32073208.stack[R.EXN_STACKHEIGHT++] = $ss32113212;
}
if(R.isPyretException($e32073208)) {
$e32073208.pyretStack.push(L[430]);
}
throw $e32073208;
}
var $ret32133214 = $Hanf_arg19433219($z32093210,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8);
++R.GAS;
return $ret32133214;
};
var $Hanf_arg19433219 = function(anf_arg13093218,A113,d4922246,ds_DASH_curry114304,id4942249,list2753,builtins8) {
var anf_fun13103231 = G(list2753,"make",L[433]);
var $z32223223 = D;
var $f32283229 = function(_) {
return R.isFunction(id4942249)?id4942249.app(("x")):R.ffi.throwNonFunApp(L[432],id4942249,[("x")]);
};
try {
if(--R.GAS > 0) {
$z32223223 = $f32283229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32283229,
"from":L[432]});
}
} catch($e32203221) {
if(R.isCont($e32203221)) {
var $ss32243225 = {"from":L[432],
"go":function(anf_array_val13113230) {
return $Hanf_array_val19423232(anf_array_val13113230,A113,anf_arg13093218,anf_fun13103231,d4922246,ds_DASH_curry114304,builtins8);
}};
$e32203221.stack[R.EXN_STACKHEIGHT++] = $ss32243225;
}
if(R.isPyretException($e32203221)) {
$e32203221.pyretStack.push(L[432]);
}
throw $e32203221;
}
var $ret32263227 = $Hanf_array_val19423232($z32223223,A113,anf_arg13093218,anf_fun13103231,d4922246,ds_DASH_curry114304,builtins8);
++R.GAS;
return $ret32263227;
};
var $Hanf_array_val19423232 = function(anf_array_val13113230,A113,anf_arg13093218,anf_fun13103231,d4922246,ds_DASH_curry114304,builtins8) {
var $z32353236 = D;
var $f32413242 = function(_) {
return R.isFunction(anf_fun13103231)?anf_fun13103231.app([anf_array_val13113230]):R.ffi.throwNonFunApp(L[433],anf_fun13103231,[[anf_array_val13113230]]);
};
try {
if(--R.GAS > 0) {
$z32353236 = $f32413242();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32413242,
"from":L[433]});
}
} catch($e32333234) {
if(R.isCont($e32333234)) {
var $ss32373238 = {"from":L[433],
"go":function(anf_arg13123243) {
return $Hanf_arg19413244(anf_arg13123243,A113,anf_arg13093218,d4922246,ds_DASH_curry114304,builtins8);
}};
$e32333234.stack[R.EXN_STACKHEIGHT++] = $ss32373238;
}
if(R.isPyretException($e32333234)) {
$e32333234.pyretStack.push(L[433]);
}
throw $e32333234;
}
var $ret32393240 = $Hanf_arg19413244($z32353236,A113,anf_arg13093218,d4922246,ds_DASH_curry114304,builtins8);
++R.GAS;
return $ret32393240;
};
var $Hanf_arg19413244 = function(anf_arg13123243,A113,anf_arg13093218,d4922246,ds_DASH_curry114304,builtins8) {
var $z32473248 = D;
var $f32533254 = function(_) {
return R.isFunction(ds_DASH_curry114304.$var)?ds_DASH_curry114304.$var.app(d4922246,anf_arg13093218,anf_arg13123243):R.ffi.throwNonFunApp(L[434],ds_DASH_curry114304.$var,[d4922246,anf_arg13093218,anf_arg13123243]);
};
try {
if(--R.GAS > 0) {
$z32473248 = $f32533254();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32533254,
"from":L[434]});
}
} catch($e32453246) {
if(R.isCont($e32453246)) {
var $ss32493250 = {"from":L[434],
"go":function(ds_DASH_ed45003255) {
return $Hds_DASH_ed419403256(ds_DASH_ed45003255,A113,builtins8);
}};
$e32453246.stack[R.EXN_STACKHEIGHT++] = $ss32493250;
}
if(R.isPyretException($e32453246)) {
$e32453246.pyretStack.push(L[434]);
}
throw $e32453246;
}
var $ret32513252 = $Hds_DASH_ed419403256($z32473248,A113,builtins8);
++R.GAS;
return $ret32513252;
};
var $Hds_DASH_ed419403256 = function(ds_DASH_ed45003255,A113,builtins8) {
var anf_fun13133267 = G(builtins8,"current-checker",L[435]);
var $z32593260 = D;
var $f32653266 = function(_) {
return R.isFunction(anf_fun13133267)?anf_fun13133267.app():R.ffi.throwNonFunApp(L[435],anf_fun13133267,[]);
};
try {
if(--R.GAS > 0) {
$z32593260 = $f32653266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32653266,
"from":L[435]});
}
} catch($e32573258) {
if(R.isCont($e32573258)) {
var $ss32613262 = {"from":L[435],
"go":function(anf_bracket13143268) {
return $Hanf_bracket19393269(anf_bracket13143268,A113,ds_DASH_ed45003255,builtins8);
}};
$e32573258.stack[R.EXN_STACKHEIGHT++] = $ss32613262;
}
if(R.isPyretException($e32573258)) {
$e32573258.pyretStack.push(L[435]);
}
throw $e32573258;
}
var $ret32633264 = $Hanf_bracket19393269($z32593260,A113,ds_DASH_ed45003255,builtins8);
++R.GAS;
return $ret32633264;
};
var $Hanf_bracket19393269 = function(anf_bracket13143268,A113,ds_DASH_ed45003255,builtins8) {
var anf_fun13153280 = G(anf_bracket13143268,"check-satisfies",L[435]);
var anf_arg13163281 = G(A113,"is-s-lam",L[436]);
var anf_arg13173282 = R.makeSrcloc(L[435]);
var $z32723273 = D;
var $f32783279 = function(_) {
return R.isFunction(anf_fun13153280)?anf_fun13153280.app(("ds-ed4 satisfies A.is-s-lam"),ds_DASH_ed45003255,anf_arg13163281,anf_arg13173282):R.ffi.throwNonFunApp(L[435],anf_fun13153280,[("ds-ed4 satisfies A.is-s-lam"),ds_DASH_ed45003255,anf_arg13163281,anf_arg13173282]);
};
try {
if(--R.GAS > 0) {
$z32723273 = $f32783279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32783279,
"from":L[435]});
}
} catch($e32703271) {
if(R.isCont($e32703271)) {
var $ss32743275 = {"from":L[435],
"go":function(anf_begin_app_dropped19343283) {
return $Hanf_begin_app_dropped19383284(anf_begin_app_dropped19343283,ds_DASH_ed45003255,builtins8);
}};
$e32703271.stack[R.EXN_STACKHEIGHT++] = $ss32743275;
}
if(R.isPyretException($e32703271)) {
$e32703271.pyretStack.push(L[435]);
}
throw $e32703271;
}
var $ret32763277 = $Hanf_begin_app_dropped19383284($z32723273,ds_DASH_ed45003255,builtins8);
++R.GAS;
return $ret32763277;
};
var $Hanf_begin_app_dropped19383284 = function(anf_begin_app_dropped19343283,ds_DASH_ed45003255,builtins8) {
var anf_fun13183295 = G(builtins8,"current-checker",L[437]);
var $z32873288 = D;
var $f32933294 = function(_) {
return R.isFunction(anf_fun13183295)?anf_fun13183295.app():R.ffi.throwNonFunApp(L[437],anf_fun13183295,[]);
};
try {
if(--R.GAS > 0) {
$z32873288 = $f32933294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32933294,
"from":L[437]});
}
} catch($e32853286) {
if(R.isCont($e32853286)) {
var $ss32893290 = {"from":L[437],
"go":function(anf_bracket13193296) {
return $Hanf_bracket19373297(anf_bracket13193296,ds_DASH_ed45003255);
}};
$e32853286.stack[R.EXN_STACKHEIGHT++] = $ss32893290;
}
if(R.isPyretException($e32853286)) {
$e32853286.pyretStack.push(L[437]);
}
throw $e32853286;
}
var $ret32913292 = $Hanf_bracket19373297($z32873288,ds_DASH_ed45003255);
++R.GAS;
return $ret32913292;
};
var $Hanf_bracket19373297 = function(anf_bracket13193296,ds_DASH_ed45003255) {
var anf_fun13203310 = G(anf_bracket13193296,"check-is",L[437]);
var anf_bracket13213312 = G(ds_DASH_ed45003255,"args",L[440]);
var anf_fun13223308 = G(anf_bracket13213312,"length",L[439]);
var $z33003301 = D;
var $f33063307 = function(_) {
return R.isFunction(anf_fun13223308)?anf_fun13223308.app():R.ffi.throwNonFunApp(L[438],anf_fun13223308,[]);
};
try {
if(--R.GAS > 0) {
$z33003301 = $f33063307();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33063307,
"from":L[438]});
}
} catch($e32983299) {
if(R.isCont($e32983299)) {
var $ss33023303 = {"from":L[438],
"go":function(anf_arg13233309) {
return $Hanf_arg19363311(anf_arg13233309,anf_fun13203310);
}};
$e32983299.stack[R.EXN_STACKHEIGHT++] = $ss33023303;
}
if(R.isPyretException($e32983299)) {
$e32983299.pyretStack.push(L[438]);
}
throw $e32983299;
}
var $ret33043305 = $Hanf_arg19363311($z33003301,anf_fun13203310);
++R.GAS;
return $ret33043305;
};
var $Hanf_arg19363311 = function(anf_arg13233309,anf_fun13203310) {
var anf_arg13243323 = R.makeSrcloc(L[437]);
var $z33153316 = D;
var $f33213322 = function(_) {
return R.isFunction(anf_fun13203310)?anf_fun13203310.app(("ds-ed4.args.length() is 1"),anf_arg13233309,(1),anf_arg13243323):R.ffi.throwNonFunApp(L[168],anf_fun13203310,[("ds-ed4.args.length() is 1"),anf_arg13233309,(1),anf_arg13243323]);
};
try {
if(--R.GAS > 0) {
$z33153316 = $f33213322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33213322,
"from":L[168]});
}
} catch($e33133314) {
if(R.isCont($e33133314)) {
var $ss33173318 = {"from":L[168],
"go":function(ann_DASH_check_DASH_temp12503324) {
return $Hann_DASH_check_DASH_temp19353325(ann_DASH_check_DASH_temp12503324);
}};
$e33133314.stack[R.EXN_STACKHEIGHT++] = $ss33173318;
}
if(R.isPyretException($e33133314)) {
$e33133314.pyretStack.push(L[168]);
}
throw $e33133314;
}
var $ret33193320 = $Hann_DASH_check_DASH_temp19353325($z33153316);
++R.GAS;
return $ret33193320;
};
var $Hann_DASH_check_DASH_temp19353325 = function(ann_DASH_check_DASH_temp12503324) {
return ann_DASH_check_DASH_temp12503324;
};
var $Hanf_arg19282265 = function(anf_arg12542263,anf_fun12522264,d4922246) {
var $z33283329 = D;
var $f33343335 = function(_) {
return R.isFunction(anf_fun12522264)?anf_fun12522264.app(d4922246,anf_arg12542263):R.ffi.throwNonFunApp(L[338],anf_fun12522264,[d4922246,anf_arg12542263]);
};
try {
if(--R.GAS > 0) {
$z33283329 = $f33343335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33343335,
"from":L[338]});
}
} catch($e33263327) {
if(R.isCont($e33263327)) {
var $ss33303331 = {"from":L[338],
"go":function(ann_DASH_check_DASH_temp12513336) {
return $Hann_DASH_check_DASH_temp19273337(ann_DASH_check_DASH_temp12513336);
}};
$e33263327.stack[R.EXN_STACKHEIGHT++] = $ss33303331;
}
if(R.isPyretException($e33263327)) {
$e33263327.pyretStack.push(L[338]);
}
throw $e33263327;
}
var $ret33323333 = $Hann_DASH_check_DASH_temp19273337($z33283329);
++R.GAS;
return $ret33323333;
};
var $Hann_DASH_check_DASH_temp19273337 = function(ann_DASH_check_DASH_temp12513336) {
return ann_DASH_check_DASH_temp12513336;
};
var $Hanf_arg19262286 = function(anf_arg11732284,A113,anf_arg11712285,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var anf_fun11743350 = G(list2753,"make",L[444]);
var anf_fun11753351 = G(A113,"s-data-field",L[443]);
var anf_fun11763348 = G(A113,"s-str",L[442]);
var $z33403341 = D;
var $f33463347 = function(_) {
return R.isFunction(anf_fun11763348)?anf_fun11763348.app(d4892283,("empty")):R.ffi.throwNonFunApp(L[441],anf_fun11763348,[d4892283,("empty")]);
};
try {
if(--R.GAS > 0) {
$z33403341 = $f33463347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33463347,
"from":L[441]});
}
} catch($e33383339) {
if(R.isCont($e33383339)) {
var $ss33423343 = {"from":L[441],
"go":function(anf_arg11773349) {
return $Hanf_arg19253352(anf_arg11773349,A113,anf_arg11712285,anf_arg11732284,anf_fun11743350,anf_fun11753351,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e33383339.stack[R.EXN_STACKHEIGHT++] = $ss33423343;
}
if(R.isPyretException($e33383339)) {
$e33383339.pyretStack.push(L[441]);
}
throw $e33383339;
}
var $ret33443345 = $Hanf_arg19253352($z33403341,A113,anf_arg11712285,anf_arg11732284,anf_fun11743350,anf_fun11753351,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret33443345;
};
var $Hanf_arg19253352 = function(anf_arg11773349,A113,anf_arg11712285,anf_arg11732284,anf_fun11743350,anf_fun11753351,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var anf_fun11783365 = G(A113,"s-lam",L[446]);
var anf_fun11793363 = G(list2753,"make",L[445]);
var $z33553356 = D;
var $f33613362 = function(_) {
return R.isFunction(anf_fun11793363)?anf_fun11793363.app([]):R.ffi.throwNonFunApp(L[445],anf_fun11793363,[[]]);
};
try {
if(--R.GAS > 0) {
$z33553356 = $f33613362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33613362,
"from":L[445]});
}
} catch($e33533354) {
if(R.isCont($e33533354)) {
var $ss33573358 = {"from":L[445],
"go":function(anf_arg11803364) {
return $Hanf_arg19243366(anf_arg11803364,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e33533354.stack[R.EXN_STACKHEIGHT++] = $ss33573358;
}
if(R.isPyretException($e33533354)) {
$e33533354.pyretStack.push(L[445]);
}
throw $e33533354;
}
var $ret33593360 = $Hanf_arg19243366($z33553356,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret33593360;
};
var $Hanf_arg19243366 = function(anf_arg11803364,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var anf_fun11813377 = G(list2753,"make",L[447]);
var $z33693370 = D;
var $f33753376 = function(_) {
return R.isFunction(anf_fun11813377)?anf_fun11813377.app([]):R.ffi.throwNonFunApp(L[447],anf_fun11813377,[[]]);
};
try {
if(--R.GAS > 0) {
$z33693370 = $f33753376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33753376,
"from":L[447]});
}
} catch($e33673368) {
if(R.isCont($e33673368)) {
var $ss33713372 = {"from":L[447],
"go":function(anf_arg11823378) {
return $Hanf_arg19233379(anf_arg11823378,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_arg11803364,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e33673368.stack[R.EXN_STACKHEIGHT++] = $ss33713372;
}
if(R.isPyretException($e33673368)) {
$e33673368.pyretStack.push(L[447]);
}
throw $e33673368;
}
var $ret33733374 = $Hanf_arg19233379($z33693370,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_arg11803364,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret33733374;
};
var $Hanf_arg19233379 = function(anf_arg11823378,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_arg11803364,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var anf_arg11833392 = G(A113,"a-blank",L[450]);
var anf_fun11843390 = G(A113,"s-num",L[449]);
var $z33823383 = D;
var $f33883389 = function(_) {
return R.isFunction(anf_fun11843390)?anf_fun11843390.app(d4892283,(5)):R.ffi.throwNonFunApp(L[448],anf_fun11843390,[d4892283,(5)]);
};
try {
if(--R.GAS > 0) {
$z33823383 = $f33883389();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33883389,
"from":L[448]});
}
} catch($e33803381) {
if(R.isCont($e33803381)) {
var $ss33843385 = {"from":L[448],
"go":function(anf_arg11853391) {
return $Hanf_arg19223393(anf_arg11853391,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_arg11803364,anf_arg11823378,anf_arg11833392,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e33803381.stack[R.EXN_STACKHEIGHT++] = $ss33843385;
}
if(R.isPyretException($e33803381)) {
$e33803381.pyretStack.push(L[448]);
}
throw $e33803381;
}
var $ret33863387 = $Hanf_arg19223393($z33823383,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_arg11803364,anf_arg11823378,anf_arg11833392,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret33863387;
};
var $Hanf_arg19223393 = function(anf_arg11853391,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_arg11803364,anf_arg11823378,anf_arg11833392,anf_fun11743350,anf_fun11753351,anf_fun11783365,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var $z33963397 = D;
var $f34023403 = function(_) {
return R.isFunction(anf_fun11783365)?anf_fun11783365.app(d4892283,anf_arg11803364,anf_arg11823378,anf_arg11833392,(""),anf_arg11853391,none6355):R.ffi.throwNonFunApp(L[451],anf_fun11783365,[d4892283,anf_arg11803364,anf_arg11823378,anf_arg11833392,(""),anf_arg11853391,none6355]);
};
try {
if(--R.GAS > 0) {
$z33963397 = $f34023403();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34023403,
"from":L[451]});
}
} catch($e33943395) {
if(R.isCont($e33943395)) {
var $ss33983399 = {"from":L[451],
"go":function(anf_arg11863404) {
return $Hanf_arg19213405(anf_arg11863404,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_fun11743350,anf_fun11753351,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e33943395.stack[R.EXN_STACKHEIGHT++] = $ss33983399;
}
if(R.isPyretException($e33943395)) {
$e33943395.pyretStack.push(L[451]);
}
throw $e33943395;
}
var $ret34003401 = $Hanf_arg19213405($z33963397,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_fun11743350,anf_fun11753351,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret34003401;
};
var $Hanf_arg19213405 = function(anf_arg11863404,A113,anf_arg11712285,anf_arg11732284,anf_arg11773349,anf_fun11743350,anf_fun11753351,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var $z34083409 = D;
var $f34143415 = function(_) {
return R.isFunction(anf_fun11753351)?anf_fun11753351.app(d4892283,anf_arg11773349,anf_arg11863404):R.ffi.throwNonFunApp(L[452],anf_fun11753351,[d4892283,anf_arg11773349,anf_arg11863404]);
};
try {
if(--R.GAS > 0) {
$z34083409 = $f34143415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34143415,
"from":L[452]});
}
} catch($e34063407) {
if(R.isCont($e34063407)) {
var $ss34103411 = {"from":L[452],
"go":function(anf_array_val11873416) {
return $Hanf_array_val19203417(anf_array_val11873416,A113,anf_arg11712285,anf_arg11732284,anf_fun11743350,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e34063407.stack[R.EXN_STACKHEIGHT++] = $ss34103411;
}
if(R.isPyretException($e34063407)) {
$e34063407.pyretStack.push(L[452]);
}
throw $e34063407;
}
var $ret34123413 = $Hanf_array_val19203417($z34083409,A113,anf_arg11712285,anf_arg11732284,anf_fun11743350,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret34123413;
};
var $Hanf_array_val19203417 = function(anf_array_val11873416,A113,anf_arg11712285,anf_arg11732284,anf_fun11743350,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var $z34203421 = D;
var $f34263427 = function(_) {
return R.isFunction(anf_fun11743350)?anf_fun11743350.app([anf_array_val11873416]):R.ffi.throwNonFunApp(L[444],anf_fun11743350,[[anf_array_val11873416]]);
};
try {
if(--R.GAS > 0) {
$z34203421 = $f34263427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34263427,
"from":L[444]});
}
} catch($e34183419) {
if(R.isCont($e34183419)) {
var $ss34223423 = {"from":L[444],
"go":function(anf_arg11883428) {
return $Hanf_arg19193429(anf_arg11883428,A113,anf_arg11712285,anf_arg11732284,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e34183419.stack[R.EXN_STACKHEIGHT++] = $ss34223423;
}
if(R.isPyretException($e34183419)) {
$e34183419.pyretStack.push(L[444]);
}
throw $e34183419;
}
var $ret34243425 = $Hanf_arg19193429($z34203421,A113,anf_arg11712285,anf_arg11732284,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret34243425;
};
var $Hanf_arg19193429 = function(anf_arg11883428,A113,anf_arg11712285,anf_arg11732284,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var anf_fun11893440 = G(A113,"s-num",L[454]);
var $z34323433 = D;
var $f34383439 = function(_) {
return R.isFunction(anf_fun11893440)?anf_fun11893440.app(d4892283,(4)):R.ffi.throwNonFunApp(L[453],anf_fun11893440,[d4892283,(4)]);
};
try {
if(--R.GAS > 0) {
$z34323433 = $f34383439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34383439,
"from":L[453]});
}
} catch($e34303431) {
if(R.isCont($e34303431)) {
var $ss34343435 = {"from":L[453],
"go":function(anf_arg11903441) {
return $Hanf_arg19183442(anf_arg11903441,A113,anf_arg11712285,anf_arg11732284,anf_arg11883428,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
}};
$e34303431.stack[R.EXN_STACKHEIGHT++] = $ss34343435;
}
if(R.isPyretException($e34303431)) {
$e34303431.pyretStack.push(L[453]);
}
throw $e34303431;
}
var $ret34363437 = $Hanf_arg19183442($z34323433,A113,anf_arg11712285,anf_arg11732284,anf_arg11883428,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8);
++R.GAS;
return $ret34363437;
};
var $Hanf_arg19183442 = function(anf_arg11903441,A113,anf_arg11712285,anf_arg11732284,anf_arg11883428,d4892283,desugar_DASH_cases107290,list2753,none6355,builtins8) {
var $z34453446 = D;
var $f34513452 = function(_) {
return R.isFunction(desugar_DASH_cases107290.$var)?desugar_DASH_cases107290.$var.app(d4892283,anf_arg11712285,anf_arg11732284,anf_arg11883428,anf_arg11903441):R.ffi.throwNonFunApp(L[455],desugar_DASH_cases107290.$var,[d4892283,anf_arg11712285,anf_arg11732284,anf_arg11883428,anf_arg11903441]);
};
try {
if(--R.GAS > 0) {
$z34453446 = $f34513452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34513452,
"from":L[455]});
}
} catch($e34433444) {
if(R.isCont($e34433444)) {
var $ss34473448 = {"from":L[455],
"go":function(prog4903453) {
return $Hprog19173454(prog4903453,A113,d4892283,list2753,none6355,builtins8);
}};
$e34433444.stack[R.EXN_STACKHEIGHT++] = $ss34473448;
}
if(R.isPyretException($e34433444)) {
$e34433444.pyretStack.push(L[455]);
}
throw $e34433444;
}
var $ret34493450 = $Hprog19173454($z34453446,A113,d4892283,list2753,none6355,builtins8);
++R.GAS;
return $ret34493450;
};
var $Hprog19173454 = function(prog4903453,A113,d4892283,list2753,none6355,builtins8) {
var anf_bracket11913470 = G(prog4903453,"binds",L[459]);
var anf_bracket11923469 = G(anf_bracket11913470,"first",L[458]);
var id4913467 = G(anf_bracket11923469,"b",L[457]);
var anf_fun11933465 = G(builtins8,"current-checker",L[456]);
var $z34573458 = D;
var $f34633464 = function(_) {
return R.isFunction(anf_fun11933465)?anf_fun11933465.app():R.ffi.throwNonFunApp(L[456],anf_fun11933465,[]);
};
try {
if(--R.GAS > 0) {
$z34573458 = $f34633464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34633464,
"from":L[456]});
}
} catch($e34553456) {
if(R.isCont($e34553456)) {
var $ss34593460 = {"from":L[456],
"go":function(anf_bracket11943466) {
return $Hanf_bracket19163468(anf_bracket11943466,A113,d4892283,id4913467,list2753,none6355,prog4903453);
}};
$e34553456.stack[R.EXN_STACKHEIGHT++] = $ss34593460;
}
if(R.isPyretException($e34553456)) {
$e34553456.pyretStack.push(L[456]);
}
throw $e34553456;
}
var $ret34613462 = $Hanf_bracket19163468($z34573458,A113,d4892283,id4913467,list2753,none6355,prog4903453);
++R.GAS;
return $ret34613462;
};
var $Hanf_bracket19163468 = function(anf_bracket11943466,A113,d4892283,id4913467,list2753,none6355,prog4903453) {
var anf_fun11953484 = G(anf_bracket11943466,"check-is",L[456]);
var anf_fun11963481 = G(prog4903453,"visit",L[462]);
var anf_arg11973482 = G(A113,"dummy-loc-visitor",L[461]);
var $z34733474 = D;
var $f34793480 = function(_) {
return R.isFunction(anf_fun11963481)?anf_fun11963481.app(anf_arg11973482):R.ffi.throwNonFunApp(L[460],anf_fun11963481,[anf_arg11973482]);
};
try {
if(--R.GAS > 0) {
$z34733474 = $f34793480();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34793480,
"from":L[460]});
}
} catch($e34713472) {
if(R.isCont($e34713472)) {
var $ss34753476 = {"from":L[460],
"go":function(anf_arg11983483) {
return $Hanf_arg19153485(anf_arg11983483,A113,anf_fun11953484,d4892283,id4913467,list2753,none6355);
}};
$e34713472.stack[R.EXN_STACKHEIGHT++] = $ss34753476;
}
if(R.isPyretException($e34713472)) {
$e34713472.pyretStack.push(L[460]);
}
throw $e34713472;
}
var $ret34773478 = $Hanf_arg19153485($z34733474,A113,anf_fun11953484,d4892283,id4913467,list2753,none6355);
++R.GAS;
return $ret34773478;
};
var $Hanf_arg19153485 = function(anf_arg11983483,A113,anf_fun11953484,d4892283,id4913467,list2753,none6355) {
var anf_fun11993498 = G(A113,"s-let-expr",L[467]);
var anf_fun12003499 = G(list2753,"make",L[466]);
var anf_fun12013500 = G(A113,"s-let-bind",L[465]);
var anf_fun12023496 = G(A113,"s-num",L[464]);
var $z34883489 = D;
var $f34943495 = function(_) {
return R.isFunction(anf_fun12023496)?anf_fun12023496.app(d4892283,(1)):R.ffi.throwNonFunApp(L[463],anf_fun12023496,[d4892283,(1)]);
};
try {
if(--R.GAS > 0) {
$z34883489 = $f34943495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34943495,
"from":L[463]});
}
} catch($e34863487) {
if(R.isCont($e34863487)) {
var $ss34903491 = {"from":L[463],
"go":function(anf_arg12033497) {
return $Hanf_arg19143501(anf_arg12033497,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,anf_fun12003499,anf_fun12013500,d4892283,id4913467,list2753,none6355);
}};
$e34863487.stack[R.EXN_STACKHEIGHT++] = $ss34903491;
}
if(R.isPyretException($e34863487)) {
$e34863487.pyretStack.push(L[463]);
}
throw $e34863487;
}
var $ret34923493 = $Hanf_arg19143501($z34883489,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,anf_fun12003499,anf_fun12013500,d4892283,id4913467,list2753,none6355);
++R.GAS;
return $ret34923493;
};
var $Hanf_arg19143501 = function(anf_arg12033497,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,anf_fun12003499,anf_fun12013500,d4892283,id4913467,list2753,none6355) {
var $z35043505 = D;
var $f35103511 = function(_) {
return R.isFunction(anf_fun12013500)?anf_fun12013500.app(d4892283,id4913467,anf_arg12033497):R.ffi.throwNonFunApp(L[468],anf_fun12013500,[d4892283,id4913467,anf_arg12033497]);
};
try {
if(--R.GAS > 0) {
$z35043505 = $f35103511();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35103511,
"from":L[468]});
}
} catch($e35023503) {
if(R.isCont($e35023503)) {
var $ss35063507 = {"from":L[468],
"go":function(anf_array_val12043512) {
return $Hanf_array_val19133513(anf_array_val12043512,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,anf_fun12003499,d4892283,id4913467,list2753,none6355);
}};
$e35023503.stack[R.EXN_STACKHEIGHT++] = $ss35063507;
}
if(R.isPyretException($e35023503)) {
$e35023503.pyretStack.push(L[468]);
}
throw $e35023503;
}
var $ret35083509 = $Hanf_array_val19133513($z35043505,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,anf_fun12003499,d4892283,id4913467,list2753,none6355);
++R.GAS;
return $ret35083509;
};
var $Hanf_array_val19133513 = function(anf_array_val12043512,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,anf_fun12003499,d4892283,id4913467,list2753,none6355) {
var $z35163517 = D;
var $f35223523 = function(_) {
return R.isFunction(anf_fun12003499)?anf_fun12003499.app([anf_array_val12043512]):R.ffi.throwNonFunApp(L[466],anf_fun12003499,[[anf_array_val12043512]]);
};
try {
if(--R.GAS > 0) {
$z35163517 = $f35223523();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35223523,
"from":L[466]});
}
} catch($e35143515) {
if(R.isCont($e35143515)) {
var $ss35183519 = {"from":L[466],
"go":function(anf_arg12053524) {
return $Hanf_arg19123525(anf_arg12053524,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,d4892283,id4913467,list2753,none6355);
}};
$e35143515.stack[R.EXN_STACKHEIGHT++] = $ss35183519;
}
if(R.isPyretException($e35143515)) {
$e35143515.pyretStack.push(L[466]);
}
throw $e35143515;
}
var $ret35203521 = $Hanf_arg19123525($z35163517,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,d4892283,id4913467,list2753,none6355);
++R.GAS;
return $ret35203521;
};
var $Hanf_arg19123525 = function(anf_arg12053524,A113,anf_arg11983483,anf_fun11953484,anf_fun11993498,d4892283,id4913467,list2753,none6355) {
var anf_fun12063539 = G(A113,"s-app",L[473]);
var anf_fun12073540 = G(A113,"s-dot",L[472]);
var anf_fun12083536 = G(A113,"s-id",L[471]);
var anf_arg12093537 = G(id4913467,"id",L[470]);
var $z35283529 = D;
var $f35343535 = function(_) {
return R.isFunction(anf_fun12083536)?anf_fun12083536.app(d4892283,anf_arg12093537):R.ffi.throwNonFunApp(L[469],anf_fun12083536,[d4892283,anf_arg12093537]);
};
try {
if(--R.GAS > 0) {
$z35283529 = $f35343535();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35343535,
"from":L[469]});
}
} catch($e35263527) {
if(R.isCont($e35263527)) {
var $ss35303531 = {"from":L[469],
"go":function(anf_arg12103538) {
return $Hanf_arg19113541(anf_arg12103538,A113,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12073540,d4892283,list2753,none6355);
}};
$e35263527.stack[R.EXN_STACKHEIGHT++] = $ss35303531;
}
if(R.isPyretException($e35263527)) {
$e35263527.pyretStack.push(L[469]);
}
throw $e35263527;
}
var $ret35323533 = $Hanf_arg19113541($z35283529,A113,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12073540,d4892283,list2753,none6355);
++R.GAS;
return $ret35323533;
};
var $Hanf_arg19113541 = function(anf_arg12103538,A113,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12073540,d4892283,list2753,none6355) {
var $z35443545 = D;
var $f35503551 = function(_) {
return R.isFunction(anf_fun12073540)?anf_fun12073540.app(d4892283,anf_arg12103538,("_match")):R.ffi.throwNonFunApp(L[474],anf_fun12073540,[d4892283,anf_arg12103538,("_match")]);
};
try {
if(--R.GAS > 0) {
$z35443545 = $f35503551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35503551,
"from":L[474]});
}
} catch($e35423543) {
if(R.isCont($e35423543)) {
var $ss35463547 = {"from":L[474],
"go":function(anf_arg12113552) {
return $Hanf_arg19103553(anf_arg12113552,A113,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,anf_fun12063539,d4892283,list2753,none6355);
}};
$e35423543.stack[R.EXN_STACKHEIGHT++] = $ss35463547;
}
if(R.isPyretException($e35423543)) {
$e35423543.pyretStack.push(L[474]);
}
throw $e35423543;
}
var $ret35483549 = $Hanf_arg19103553($z35443545,A113,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,anf_fun12063539,d4892283,list2753,none6355);
++R.GAS;
return $ret35483549;
};
var $Hanf_arg19103553 = function(anf_arg12113552,A113,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,anf_fun12063539,d4892283,list2753,none6355) {
var anf_fun12123566 = G(list2753,"make",L[480]);
var anf_fun12133567 = G(A113,"s-obj",L[479]);
var anf_fun12143568 = G(list2753,"make",L[478]);
var anf_fun12153569 = G(A113,"s-data-field",L[477]);
var anf_fun12163564 = G(A113,"s-str",L[476]);
var $z35563557 = D;
var $f35623563 = function(_) {
return R.isFunction(anf_fun12163564)?anf_fun12163564.app(d4892283,("empty")):R.ffi.throwNonFunApp(L[475],anf_fun12163564,[d4892283,("empty")]);
};
try {
if(--R.GAS > 0) {
$z35563557 = $f35623563();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35623563,
"from":L[475]});
}
} catch($e35543555) {
if(R.isCont($e35543555)) {
var $ss35583559 = {"from":L[475],
"go":function(anf_arg12173565) {
return $Hanf_arg19093570(anf_arg12173565,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,d4892283,list2753,none6355);
}};
$e35543555.stack[R.EXN_STACKHEIGHT++] = $ss35583559;
}
if(R.isPyretException($e35543555)) {
$e35543555.pyretStack.push(L[475]);
}
throw $e35543555;
}
var $ret35603561 = $Hanf_arg19093570($z35563557,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,d4892283,list2753,none6355);
++R.GAS;
return $ret35603561;
};
var $Hanf_arg19093570 = function(anf_arg12173565,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,d4892283,list2753,none6355) {
var anf_fun12183583 = G(A113,"s-lam",L[482]);
var anf_fun12193581 = G(list2753,"make",L[481]);
var $z35733574 = D;
var $f35793580 = function(_) {
return R.isFunction(anf_fun12193581)?anf_fun12193581.app([]):R.ffi.throwNonFunApp(L[481],anf_fun12193581,[[]]);
};
try {
if(--R.GAS > 0) {
$z35733574 = $f35793580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35793580,
"from":L[481]});
}
} catch($e35713572) {
if(R.isCont($e35713572)) {
var $ss35753576 = {"from":L[481],
"go":function(anf_arg12203582) {
return $Hanf_arg19083584(anf_arg12203582,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355);
}};
$e35713572.stack[R.EXN_STACKHEIGHT++] = $ss35753576;
}
if(R.isPyretException($e35713572)) {
$e35713572.pyretStack.push(L[481]);
}
throw $e35713572;
}
var $ret35773578 = $Hanf_arg19083584($z35733574,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355);
++R.GAS;
return $ret35773578;
};
var $Hanf_arg19083584 = function(anf_arg12203582,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355) {
var anf_fun12213595 = G(list2753,"make",L[483]);
var $z35873588 = D;
var $f35933594 = function(_) {
return R.isFunction(anf_fun12213595)?anf_fun12213595.app([]):R.ffi.throwNonFunApp(L[483],anf_fun12213595,[[]]);
};
try {
if(--R.GAS > 0) {
$z35873588 = $f35933594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35933594,
"from":L[483]});
}
} catch($e35853586) {
if(R.isCont($e35853586)) {
var $ss35893590 = {"from":L[483],
"go":function(anf_arg12223596) {
return $Hanf_arg19073597(anf_arg12223596,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_arg12203582,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355);
}};
$e35853586.stack[R.EXN_STACKHEIGHT++] = $ss35893590;
}
if(R.isPyretException($e35853586)) {
$e35853586.pyretStack.push(L[483]);
}
throw $e35853586;
}
var $ret35913592 = $Hanf_arg19073597($z35873588,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_arg12203582,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355);
++R.GAS;
return $ret35913592;
};
var $Hanf_arg19073597 = function(anf_arg12223596,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_arg12203582,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355) {
var anf_arg12233610 = G(A113,"a-blank",L[486]);
var anf_fun12243608 = G(A113,"s-num",L[485]);
var $z36003601 = D;
var $f36063607 = function(_) {
return R.isFunction(anf_fun12243608)?anf_fun12243608.app(d4892283,(5)):R.ffi.throwNonFunApp(L[484],anf_fun12243608,[d4892283,(5)]);
};
try {
if(--R.GAS > 0) {
$z36003601 = $f36063607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36063607,
"from":L[484]});
}
} catch($e35983599) {
if(R.isCont($e35983599)) {
var $ss36023603 = {"from":L[484],
"go":function(anf_arg12253609) {
return $Hanf_arg19063611(anf_arg12253609,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_arg12203582,anf_arg12223596,anf_arg12233610,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355);
}};
$e35983599.stack[R.EXN_STACKHEIGHT++] = $ss36023603;
}
if(R.isPyretException($e35983599)) {
$e35983599.pyretStack.push(L[484]);
}
throw $e35983599;
}
var $ret36043605 = $Hanf_arg19063611($z36003601,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_arg12203582,anf_arg12223596,anf_arg12233610,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355);
++R.GAS;
return $ret36043605;
};
var $Hanf_arg19063611 = function(anf_arg12253609,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_arg12203582,anf_arg12223596,anf_arg12233610,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,anf_fun12183583,d4892283,list2753,none6355) {
var $z36143615 = D;
var $f36203621 = function(_) {
return R.isFunction(anf_fun12183583)?anf_fun12183583.app(d4892283,anf_arg12203582,anf_arg12223596,anf_arg12233610,(""),anf_arg12253609,none6355):R.ffi.throwNonFunApp(L[487],anf_fun12183583,[d4892283,anf_arg12203582,anf_arg12223596,anf_arg12233610,(""),anf_arg12253609,none6355]);
};
try {
if(--R.GAS > 0) {
$z36143615 = $f36203621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36203621,
"from":L[487]});
}
} catch($e36123613) {
if(R.isCont($e36123613)) {
var $ss36163617 = {"from":L[487],
"go":function(anf_arg12263622) {
return $Hanf_arg19053623(anf_arg12263622,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,d4892283,list2753,none6355);
}};
$e36123613.stack[R.EXN_STACKHEIGHT++] = $ss36163617;
}
if(R.isPyretException($e36123613)) {
$e36123613.pyretStack.push(L[487]);
}
throw $e36123613;
}
var $ret36183619 = $Hanf_arg19053623($z36143615,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,d4892283,list2753,none6355);
++R.GAS;
return $ret36183619;
};
var $Hanf_arg19053623 = function(anf_arg12263622,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12173565,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,anf_fun12153569,d4892283,list2753,none6355) {
var $z36263627 = D;
var $f36323633 = function(_) {
return R.isFunction(anf_fun12153569)?anf_fun12153569.app(d4892283,anf_arg12173565,anf_arg12263622):R.ffi.throwNonFunApp(L[488],anf_fun12153569,[d4892283,anf_arg12173565,anf_arg12263622]);
};
try {
if(--R.GAS > 0) {
$z36263627 = $f36323633();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36323633,
"from":L[488]});
}
} catch($e36243625) {
if(R.isCont($e36243625)) {
var $ss36283629 = {"from":L[488],
"go":function(anf_array_val12273634) {
return $Hanf_array_val19043635(anf_array_val12273634,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,d4892283,list2753,none6355);
}};
$e36243625.stack[R.EXN_STACKHEIGHT++] = $ss36283629;
}
if(R.isPyretException($e36243625)) {
$e36243625.pyretStack.push(L[488]);
}
throw $e36243625;
}
var $ret36303631 = $Hanf_array_val19043635($z36263627,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,d4892283,list2753,none6355);
++R.GAS;
return $ret36303631;
};
var $Hanf_array_val19043635 = function(anf_array_val12273634,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,anf_fun12143568,d4892283,list2753,none6355) {
var $z36383639 = D;
var $f36443645 = function(_) {
return R.isFunction(anf_fun12143568)?anf_fun12143568.app([anf_array_val12273634]):R.ffi.throwNonFunApp(L[478],anf_fun12143568,[[anf_array_val12273634]]);
};
try {
if(--R.GAS > 0) {
$z36383639 = $f36443645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36443645,
"from":L[478]});
}
} catch($e36363637) {
if(R.isCont($e36363637)) {
var $ss36403641 = {"from":L[478],
"go":function(anf_arg12283646) {
return $Hanf_arg19033647(anf_arg12283646,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,d4892283,list2753,none6355);
}};
$e36363637.stack[R.EXN_STACKHEIGHT++] = $ss36403641;
}
if(R.isPyretException($e36363637)) {
$e36363637.pyretStack.push(L[478]);
}
throw $e36363637;
}
var $ret36423643 = $Hanf_arg19033647($z36383639,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,d4892283,list2753,none6355);
++R.GAS;
return $ret36423643;
};
var $Hanf_arg19033647 = function(anf_arg12283646,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12133567,d4892283,list2753,none6355) {
var $z36503651 = D;
var $f36563657 = function(_) {
return R.isFunction(anf_fun12133567)?anf_fun12133567.app(d4892283,anf_arg12283646):R.ffi.throwNonFunApp(L[489],anf_fun12133567,[d4892283,anf_arg12283646]);
};
try {
if(--R.GAS > 0) {
$z36503651 = $f36563657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36563657,
"from":L[489]});
}
} catch($e36483649) {
if(R.isCont($e36483649)) {
var $ss36523653 = {"from":L[489],
"go":function(anf_array_val12293658) {
return $Hanf_array_val19023659(anf_array_val12293658,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,d4892283,list2753,none6355);
}};
$e36483649.stack[R.EXN_STACKHEIGHT++] = $ss36523653;
}
if(R.isPyretException($e36483649)) {
$e36483649.pyretStack.push(L[489]);
}
throw $e36483649;
}
var $ret36543655 = $Hanf_array_val19023659($z36503651,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,d4892283,list2753,none6355);
++R.GAS;
return $ret36543655;
};
var $Hanf_array_val19023659 = function(anf_array_val12293658,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,d4892283,list2753,none6355) {
var anf_fun12303672 = G(A113,"s-lam",L[491]);
var anf_fun12313670 = G(list2753,"make",L[490]);
var $z36623663 = D;
var $f36683669 = function(_) {
return R.isFunction(anf_fun12313670)?anf_fun12313670.app([]):R.ffi.throwNonFunApp(L[490],anf_fun12313670,[[]]);
};
try {
if(--R.GAS > 0) {
$z36623663 = $f36683669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36683669,
"from":L[490]});
}
} catch($e36603661) {
if(R.isCont($e36603661)) {
var $ss36643665 = {"from":L[490],
"go":function(anf_arg12323671) {
return $Hanf_arg19013673(anf_arg12323671,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,list2753,none6355);
}};
$e36603661.stack[R.EXN_STACKHEIGHT++] = $ss36643665;
}
if(R.isPyretException($e36603661)) {
$e36603661.pyretStack.push(L[490]);
}
throw $e36603661;
}
var $ret36663667 = $Hanf_arg19013673($z36623663,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,list2753,none6355);
++R.GAS;
return $ret36663667;
};
var $Hanf_arg19013673 = function(anf_arg12323671,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,list2753,none6355) {
var anf_fun12333684 = G(list2753,"make",L[492]);
var $z36763677 = D;
var $f36823683 = function(_) {
return R.isFunction(anf_fun12333684)?anf_fun12333684.app([]):R.ffi.throwNonFunApp(L[492],anf_fun12333684,[[]]);
};
try {
if(--R.GAS > 0) {
$z36763677 = $f36823683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36823683,
"from":L[492]});
}
} catch($e36743675) {
if(R.isCont($e36743675)) {
var $ss36783679 = {"from":L[492],
"go":function(anf_arg12343685) {
return $Hanf_arg19003686(anf_arg12343685,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12323671,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,none6355);
}};
$e36743675.stack[R.EXN_STACKHEIGHT++] = $ss36783679;
}
if(R.isPyretException($e36743675)) {
$e36743675.pyretStack.push(L[492]);
}
throw $e36743675;
}
var $ret36803681 = $Hanf_arg19003686($z36763677,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12323671,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,none6355);
++R.GAS;
return $ret36803681;
};
var $Hanf_arg19003686 = function(anf_arg12343685,A113,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12323671,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,none6355) {
var anf_arg12353699 = G(A113,"a-blank",L[495]);
var anf_fun12363697 = G(A113,"s-num",L[494]);
var $z36893690 = D;
var $f36953696 = function(_) {
return R.isFunction(anf_fun12363697)?anf_fun12363697.app(d4892283,(4)):R.ffi.throwNonFunApp(L[493],anf_fun12363697,[d4892283,(4)]);
};
try {
if(--R.GAS > 0) {
$z36893690 = $f36953696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36953696,
"from":L[493]});
}
} catch($e36873688) {
if(R.isCont($e36873688)) {
var $ss36913692 = {"from":L[493],
"go":function(anf_arg12373698) {
return $Hanf_arg18993700(anf_arg12373698,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12323671,anf_arg12343685,anf_arg12353699,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,none6355);
}};
$e36873688.stack[R.EXN_STACKHEIGHT++] = $ss36913692;
}
if(R.isPyretException($e36873688)) {
$e36873688.pyretStack.push(L[493]);
}
throw $e36873688;
}
var $ret36933694 = $Hanf_arg18993700($z36893690,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12323671,anf_arg12343685,anf_arg12353699,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,none6355);
++R.GAS;
return $ret36933694;
};
var $Hanf_arg18993700 = function(anf_arg12373698,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_arg12323671,anf_arg12343685,anf_arg12353699,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,anf_fun12303672,d4892283,none6355) {
var $z37033704 = D;
var $f37093710 = function(_) {
return R.isFunction(anf_fun12303672)?anf_fun12303672.app(d4892283,anf_arg12323671,anf_arg12343685,anf_arg12353699,(""),anf_arg12373698,none6355):R.ffi.throwNonFunApp(L[496],anf_fun12303672,[d4892283,anf_arg12323671,anf_arg12343685,anf_arg12353699,(""),anf_arg12373698,none6355]);
};
try {
if(--R.GAS > 0) {
$z37033704 = $f37093710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37093710,
"from":L[496]});
}
} catch($e37013702) {
if(R.isCont($e37013702)) {
var $ss37053706 = {"from":L[496],
"go":function(anf_array_val12383711) {
return $Hanf_array_val18983712(anf_array_val12383711,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,d4892283);
}};
$e37013702.stack[R.EXN_STACKHEIGHT++] = $ss37053706;
}
if(R.isPyretException($e37013702)) {
$e37013702.pyretStack.push(L[496]);
}
throw $e37013702;
}
var $ret37073708 = $Hanf_array_val18983712($z37033704,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,d4892283);
++R.GAS;
return $ret37073708;
};
var $Hanf_array_val18983712 = function(anf_array_val12383711,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_array_val12293658,anf_fun11953484,anf_fun11993498,anf_fun12063539,anf_fun12123566,d4892283) {
var $z37153716 = D;
var $f37213722 = function(_) {
return R.isFunction(anf_fun12123566)?anf_fun12123566.app([anf_array_val12293658,anf_array_val12383711]):R.ffi.throwNonFunApp(L[480],anf_fun12123566,[[anf_array_val12293658,anf_array_val12383711]]);
};
try {
if(--R.GAS > 0) {
$z37153716 = $f37213722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37213722,
"from":L[480]});
}
} catch($e37133714) {
if(R.isCont($e37133714)) {
var $ss37173718 = {"from":L[480],
"go":function(anf_arg12393723) {
return $Hanf_arg18973724(anf_arg12393723,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,d4892283);
}};
$e37133714.stack[R.EXN_STACKHEIGHT++] = $ss37173718;
}
if(R.isPyretException($e37133714)) {
$e37133714.pyretStack.push(L[480]);
}
throw $e37133714;
}
var $ret37193720 = $Hanf_arg18973724($z37153716,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,d4892283);
++R.GAS;
return $ret37193720;
};
var $Hanf_arg18973724 = function(anf_arg12393723,anf_arg11983483,anf_arg12053524,anf_arg12113552,anf_fun11953484,anf_fun11993498,anf_fun12063539,d4892283) {
var $z37273728 = D;
var $f37333734 = function(_) {
return R.isFunction(anf_fun12063539)?anf_fun12063539.app(d4892283,anf_arg12113552,anf_arg12393723):R.ffi.throwNonFunApp(L[497],anf_fun12063539,[d4892283,anf_arg12113552,anf_arg12393723]);
};
try {
if(--R.GAS > 0) {
$z37273728 = $f37333734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37333734,
"from":L[497]});
}
} catch($e37253726) {
if(R.isCont($e37253726)) {
var $ss37293730 = {"from":L[497],
"go":function(anf_arg12403735) {
return $Hanf_arg18963736(anf_arg12403735,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,d4892283);
}};
$e37253726.stack[R.EXN_STACKHEIGHT++] = $ss37293730;
}
if(R.isPyretException($e37253726)) {
$e37253726.pyretStack.push(L[497]);
}
throw $e37253726;
}
var $ret37313732 = $Hanf_arg18963736($z37273728,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,d4892283);
++R.GAS;
return $ret37313732;
};
var $Hanf_arg18963736 = function(anf_arg12403735,anf_arg11983483,anf_arg12053524,anf_fun11953484,anf_fun11993498,d4892283) {
var $z37393740 = D;
var $f37453746 = function(_) {
return R.isFunction(anf_fun11993498)?anf_fun11993498.app(d4892283,anf_arg12053524,anf_arg12403735):R.ffi.throwNonFunApp(L[498],anf_fun11993498,[d4892283,anf_arg12053524,anf_arg12403735]);
};
try {
if(--R.GAS > 0) {
$z37393740 = $f37453746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37453746,
"from":L[498]});
}
} catch($e37373738) {
if(R.isCont($e37373738)) {
var $ss37413742 = {"from":L[498],
"go":function(anf_arg12413747) {
return $Hanf_arg18953748(anf_arg12413747,anf_arg11983483,anf_fun11953484);
}};
$e37373738.stack[R.EXN_STACKHEIGHT++] = $ss37413742;
}
if(R.isPyretException($e37373738)) {
$e37373738.pyretStack.push(L[498]);
}
throw $e37373738;
}
var $ret37433744 = $Hanf_arg18953748($z37393740,anf_arg11983483,anf_fun11953484);
++R.GAS;
return $ret37433744;
};
var $Hanf_arg18953748 = function(anf_arg12413747,anf_arg11983483,anf_fun11953484) {
var anf_arg12423759 = R.makeSrcloc(L[456]);
var $z37513752 = D;
var $f37573758 = function(_) {
return R.isFunction(anf_fun11953484)?anf_fun11953484.app(("prog.visit(A.dummy-loc-visitor) is\n  A.s-let-expr(d,\n    [list: A.s-let-bind(d, id, A.s-num(d, 1))],\n    A.s-app(d,\n      A.s-dot(d, A.s-id(d, id.id), \"_match\"),\n      [list: \n        A.s-obj(d,\n          [list: \n            A.s-data-field(d,\n              A.s-str(d, \"empty\"),\n              A.s-lam(d, [list: ], [list: ], A.a-blank, \"\", A.s-num(d, 5), none))\n          ]),\n        A.s-lam(d, [list: ], [list: ], A.a-blank, \"\", A.s-num(d, 4), none)\n      ]))"),anf_arg11983483,anf_arg12413747,anf_arg12423759):R.ffi.throwNonFunApp(L[202],anf_fun11953484,[("prog.visit(A.dummy-loc-visitor) is\n  A.s-let-expr(d,\n    [list: A.s-let-bind(d, id, A.s-num(d, 1))],\n    A.s-app(d,\n      A.s-dot(d, A.s-id(d, id.id), \"_match\"),\n      [list: \n        A.s-obj(d,\n          [list: \n            A.s-data-field(d,\n              A.s-str(d, \"empty\"),\n              A.s-lam(d, [list: ], [list: ], A.a-blank, \"\", A.s-num(d, 5), none))\n          ]),\n        A.s-lam(d, [list: ], [list: ], A.a-blank, \"\", A.s-num(d, 4), none)\n      ]))"),anf_arg11983483,anf_arg12413747,anf_arg12423759]);
};
try {
if(--R.GAS > 0) {
$z37513752 = $f37573758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37573758,
"from":L[202]});
}
} catch($e37493750) {
if(R.isCont($e37493750)) {
var $ss37533754 = {"from":L[202],
"go":function(ann_DASH_check_DASH_temp11703760) {
return $Hann_DASH_check_DASH_temp18943761(ann_DASH_check_DASH_temp11703760);
}};
$e37493750.stack[R.EXN_STACKHEIGHT++] = $ss37533754;
}
if(R.isPyretException($e37493750)) {
$e37493750.pyretStack.push(L[202]);
}
throw $e37493750;
}
var $ret37553756 = $Hann_DASH_check_DASH_temp18943761($z37513752);
++R.GAS;
return $ret37553756;
};
var $Hann_DASH_check_DASH_temp18943761 = function(ann_DASH_check_DASH_temp11703760) {
return ann_DASH_check_DASH_temp11703760;
};
var $Hann_DASH_check_DASH_temp1893341 = function(ann_DASH_check_DASH_temp632340) {
return ann_DASH_check_DASH_temp632340;
};
var $Hanf_arg1892353 = function(anf_arg1162352,_plus7,raise10) {
var $z37643765 = D;
var $f37703771 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("NYI (desugar): "),anf_arg1162352):R.ffi.throwNonFunApp(L[499],_plus7,[("NYI (desugar): "),anf_arg1162352]);
};
try {
if(--R.GAS > 0) {
$z37643765 = $f37703771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37703771,
"from":L[499]});
}
} catch($e37623763) {
if(R.isCont($e37623763)) {
var $ss37663767 = {"from":L[499],
"go":function(anf_arg11633772) {
return $Hanf_arg18913773(anf_arg11633772,raise10);
}};
$e37623763.stack[R.EXN_STACKHEIGHT++] = $ss37663767;
}
if(R.isPyretException($e37623763)) {
$e37623763.pyretStack.push(L[499]);
}
throw $e37623763;
}
var $ret37683769 = $Hanf_arg18913773($z37643765,raise10);
++R.GAS;
return $ret37683769;
};
var $Hanf_arg18913773 = function(anf_arg11633772,raise10) {
var $z37763777 = D;
var $f37823783 = function(_) {
return R.isFunction(raise10)?raise10.app(anf_arg11633772):R.ffi.throwNonFunApp(L[20],raise10,[anf_arg11633772]);
};
try {
if(--R.GAS > 0) {
$z37763777 = $f37823783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37823783,
"from":L[20]});
}
} catch($e37743775) {
if(R.isCont($e37743775)) {
var $ss37783779 = {"from":L[20],
"go":function(ann_DASH_check_DASH_temp11613784) {
return $Hann_DASH_check_DASH_temp18903785(ann_DASH_check_DASH_temp11613784);
}};
$e37743775.stack[R.EXN_STACKHEIGHT++] = $ss37783779;
}
if(R.isPyretException($e37743775)) {
$e37743775.pyretStack.push(L[20]);
}
throw $e37743775;
}
var $ret37803781 = $Hann_DASH_check_DASH_temp18903785($z37763777);
++R.GAS;
return $ret37803781;
};
var $Hann_DASH_check_DASH_temp18903785 = function(ann_DASH_check_DASH_temp11613784) {
return ann_DASH_check_DASH_temp11613784;
};
var $Hann_DASH_check_DASH_temp1889408 = function(ann_DASH_check_DASH_temp1158407) {
return ann_DASH_check_DASH_temp1158407;
};
var $Hann_DASH_check_DASH_temp1888425 = function(ann_DASH_check_DASH_temp1155424) {
return ann_DASH_check_DASH_temp1155424;
};
var $Hann_DASH_check_DASH_temp1887439 = function(ann_DASH_check_DASH_temp1153438) {
return ann_DASH_check_DASH_temp1153438;
};
var $Hann_DASH_check_DASH_temp1886458 = function(ann_DASH_check_DASH_temp1117457) {
return ann_DASH_check_DASH_temp1117457;
};
var $Hanf_arg1885475 = function(anf_arg1134473,A113,anf_fun1132474,desugar_DASH_expr117310,elts476443,empty3049,l473440,list2753,none6355) {
var $z37883789 = D;
var $f37943795 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(anf_arg1134473):R.ffi.throwNonFunApp(L[500],desugar_DASH_expr117310.$var,[anf_arg1134473]);
};
try {
if(--R.GAS > 0) {
$z37883789 = $f37943795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37943795,
"from":L[500]});
}
} catch($e37863787) {
if(R.isCont($e37863787)) {
var $ss37903791 = {"from":L[500],
"go":function(anf_arg11353796) {
return $Hanf_arg18843797(anf_arg11353796,A113,anf_fun1132474,desugar_DASH_expr117310,elts476443,empty3049,l473440,list2753,none6355);
}};
$e37863787.stack[R.EXN_STACKHEIGHT++] = $ss37903791;
}
if(R.isPyretException($e37863787)) {
$e37863787.pyretStack.push(L[500]);
}
throw $e37863787;
}
var $ret37923793 = $Hanf_arg18843797($z37883789,A113,anf_fun1132474,desugar_DASH_expr117310,elts476443,empty3049,l473440,list2753,none6355);
++R.GAS;
return $ret37923793;
};
var $Hanf_arg18843797 = function(anf_arg11353796,A113,anf_fun1132474,desugar_DASH_expr117310,elts476443,empty3049,l473440,list2753,none6355) {
var anf_fun11363811 = G(list2753,"make",L[509]);
var anf_fun11373812 = G(A113,"s-array",L[508]);
var anf_fun11383808 = G(elts476443,"map",L[507]);
var anf_arg11443809 = R.makeFunction(function(elt4773814) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[502],1,arguments);
}
var anf_fun11403825 = G(A113,"s-lam",L[506]);
var anf_arg11413826 = G(elt4773814,"l",L[505]);
var anf_arg11423827 = G(A113,"a-blank",L[504]);
var $z38173818 = D;
var $f38233824 = function(_) {
return R.isFunction(anf_fun11403825)?anf_fun11403825.app(anf_arg11413826,empty3049,empty3049,anf_arg11423827,(""),elt4773814,none6355):R.ffi.throwNonFunApp(L[503],anf_fun11403825,[anf_arg11413826,empty3049,empty3049,anf_arg11423827,(""),elt4773814,none6355]);
};
try {
if(--R.GAS > 0) {
$z38173818 = $f38233824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38233824,
"from":L[503]});
}
} catch($e38153816) {
if(R.isCont($e38153816)) {
var $ss38193820 = {"from":L[503],
"go":function(anf_arg11433828) {
return $Hanf_arg18793829(anf_arg11433828,desugar_DASH_expr117310);
}};
$e38153816.stack[R.EXN_STACKHEIGHT++] = $ss38193820;
}
if(R.isPyretException($e38153816)) {
$e38153816.pyretStack.push(L[503]);
}
throw $e38153816;
}
var $ret38213822 = $Hanf_arg18793829($z38173818,desugar_DASH_expr117310);
++R.GAS;
return $ret38213822;
});
var $z38003801 = D;
var $f38063807 = function(_) {
return R.isFunction(anf_fun11383808)?anf_fun11383808.app(anf_arg11443809):R.ffi.throwNonFunApp(L[501],anf_fun11383808,[anf_arg11443809]);
};
try {
if(--R.GAS > 0) {
$z38003801 = $f38063807();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38063807,
"from":L[501]});
}
} catch($e37983799) {
if(R.isCont($e37983799)) {
var $ss38023803 = {"from":L[501],
"go":function(anf_arg11453810) {
return $Hanf_arg18833813(anf_arg11453810,anf_arg11353796,anf_fun1132474,anf_fun11363811,anf_fun11373812,l473440);
}};
$e37983799.stack[R.EXN_STACKHEIGHT++] = $ss38023803;
}
if(R.isPyretException($e37983799)) {
$e37983799.pyretStack.push(L[501]);
}
throw $e37983799;
}
var $ret38043805 = $Hanf_arg18833813($z38003801,anf_arg11353796,anf_fun1132474,anf_fun11363811,anf_fun11373812,l473440);
++R.GAS;
return $ret38043805;
};
var $Hanf_arg18833813 = function(anf_arg11453810,anf_arg11353796,anf_fun1132474,anf_fun11363811,anf_fun11373812,l473440) {
var $z38323833 = D;
var $f38383839 = function(_) {
return R.isFunction(anf_fun11373812)?anf_fun11373812.app(l473440,anf_arg11453810):R.ffi.throwNonFunApp(L[510],anf_fun11373812,[l473440,anf_arg11453810]);
};
try {
if(--R.GAS > 0) {
$z38323833 = $f38383839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38383839,
"from":L[510]});
}
} catch($e38303831) {
if(R.isCont($e38303831)) {
var $ss38343835 = {"from":L[510],
"go":function(anf_array_val11463840) {
return $Hanf_array_val18823841(anf_array_val11463840,anf_arg11353796,anf_fun1132474,anf_fun11363811,l473440);
}};
$e38303831.stack[R.EXN_STACKHEIGHT++] = $ss38343835;
}
if(R.isPyretException($e38303831)) {
$e38303831.pyretStack.push(L[510]);
}
throw $e38303831;
}
var $ret38363837 = $Hanf_array_val18823841($z38323833,anf_arg11353796,anf_fun1132474,anf_fun11363811,l473440);
++R.GAS;
return $ret38363837;
};
var $Hanf_array_val18823841 = function(anf_array_val11463840,anf_arg11353796,anf_fun1132474,anf_fun11363811,l473440) {
var $z38443845 = D;
var $f38503851 = function(_) {
return R.isFunction(anf_fun11363811)?anf_fun11363811.app([anf_array_val11463840]):R.ffi.throwNonFunApp(L[509],anf_fun11363811,[[anf_array_val11463840]]);
};
try {
if(--R.GAS > 0) {
$z38443845 = $f38503851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38503851,
"from":L[509]});
}
} catch($e38423843) {
if(R.isCont($e38423843)) {
var $ss38463847 = {"from":L[509],
"go":function(anf_arg11473852) {
return $Hanf_arg18813853(anf_arg11473852,anf_arg11353796,anf_fun1132474,l473440);
}};
$e38423843.stack[R.EXN_STACKHEIGHT++] = $ss38463847;
}
if(R.isPyretException($e38423843)) {
$e38423843.pyretStack.push(L[509]);
}
throw $e38423843;
}
var $ret38483849 = $Hanf_arg18813853($z38443845,anf_arg11353796,anf_fun1132474,l473440);
++R.GAS;
return $ret38483849;
};
var $Hanf_arg18813853 = function(anf_arg11473852,anf_arg11353796,anf_fun1132474,l473440) {
var $z38563857 = D;
var $f38623863 = function(_) {
return R.isFunction(anf_fun1132474)?anf_fun1132474.app(l473440,anf_arg11353796,anf_arg11473852):R.ffi.throwNonFunApp(L[28],anf_fun1132474,[l473440,anf_arg11353796,anf_arg11473852]);
};
try {
if(--R.GAS > 0) {
$z38563857 = $f38623863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38623863,
"from":L[28]});
}
} catch($e38543855) {
if(R.isCont($e38543855)) {
var $ss38583859 = {"from":L[28],
"go":function(ann_DASH_check_DASH_temp11313864) {
return $Hann_DASH_check_DASH_temp18803865(ann_DASH_check_DASH_temp11313864);
}};
$e38543855.stack[R.EXN_STACKHEIGHT++] = $ss38583859;
}
if(R.isPyretException($e38543855)) {
$e38543855.pyretStack.push(L[28]);
}
throw $e38543855;
}
var $ret38603861 = $Hann_DASH_check_DASH_temp18803865($z38563857);
++R.GAS;
return $ret38603861;
};
var $Hann_DASH_check_DASH_temp18803865 = function(ann_DASH_check_DASH_temp11313864) {
return ann_DASH_check_DASH_temp11313864;
};
var $Hanf_arg18793829 = function(anf_arg11433828,desugar_DASH_expr117310) {
var $z38683869 = D;
var $f38743875 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(anf_arg11433828):R.ffi.throwNonFunApp(L[502],desugar_DASH_expr117310.$var,[anf_arg11433828]);
};
try {
if(--R.GAS > 0) {
$z38683869 = $f38743875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38743875,
"from":L[502]});
}
} catch($e38663867) {
if(R.isCont($e38663867)) {
var $ss38703871 = {"from":L[502],
"go":function(ann_DASH_check_DASH_temp11393876) {
return $Hann_DASH_check_DASH_temp18783877(ann_DASH_check_DASH_temp11393876);
}};
$e38663867.stack[R.EXN_STACKHEIGHT++] = $ss38703871;
}
if(R.isPyretException($e38663867)) {
$e38663867.pyretStack.push(L[502]);
}
throw $e38663867;
}
var $ret38723873 = $Hann_DASH_check_DASH_temp18783877($z38683869);
++R.GAS;
return $ret38723873;
};
var $Hann_DASH_check_DASH_temp18783877 = function(ann_DASH_check_DASH_temp11393876) {
return ann_DASH_check_DASH_temp11393876;
};
var $Hanf_arg1877489 = function(anf_arg1122487,A113,anf_fun1120488,desugar_DASH_expr117310,elts476443,l473440,list2753) {
var $z38803881 = D;
var $f38863887 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(anf_arg1122487):R.ffi.throwNonFunApp(L[511],desugar_DASH_expr117310.$var,[anf_arg1122487]);
};
try {
if(--R.GAS > 0) {
$z38803881 = $f38863887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38863887,
"from":L[511]});
}
} catch($e38783879) {
if(R.isCont($e38783879)) {
var $ss38823883 = {"from":L[511],
"go":function(anf_arg11233888) {
return $Hanf_arg18763889(anf_arg11233888,A113,anf_fun1120488,desugar_DASH_expr117310,elts476443,l473440,list2753);
}};
$e38783879.stack[R.EXN_STACKHEIGHT++] = $ss38823883;
}
if(R.isPyretException($e38783879)) {
$e38783879.pyretStack.push(L[511]);
}
throw $e38783879;
}
var $ret38843885 = $Hanf_arg18763889($z38803881,A113,anf_fun1120488,desugar_DASH_expr117310,elts476443,l473440,list2753);
++R.GAS;
return $ret38843885;
};
var $Hanf_arg18763889 = function(anf_arg11233888,A113,anf_fun1120488,desugar_DASH_expr117310,elts476443,l473440,list2753) {
var anf_fun11243902 = G(list2753,"make",L[515]);
var anf_fun11253903 = G(A113,"s-array",L[514]);
var anf_fun11263900 = G(elts476443,"map",L[513]);
var $z38923893 = D;
var $f38983899 = function(_) {
return R.isFunction(anf_fun11263900)?anf_fun11263900.app(desugar_DASH_expr117310.$var):R.ffi.throwNonFunApp(L[512],anf_fun11263900,[desugar_DASH_expr117310.$var]);
};
try {
if(--R.GAS > 0) {
$z38923893 = $f38983899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38983899,
"from":L[512]});
}
} catch($e38903891) {
if(R.isCont($e38903891)) {
var $ss38943895 = {"from":L[512],
"go":function(anf_arg11273901) {
return $Hanf_arg18753904(anf_arg11273901,anf_arg11233888,anf_fun1120488,anf_fun11243902,anf_fun11253903,l473440);
}};
$e38903891.stack[R.EXN_STACKHEIGHT++] = $ss38943895;
}
if(R.isPyretException($e38903891)) {
$e38903891.pyretStack.push(L[512]);
}
throw $e38903891;
}
var $ret38963897 = $Hanf_arg18753904($z38923893,anf_arg11233888,anf_fun1120488,anf_fun11243902,anf_fun11253903,l473440);
++R.GAS;
return $ret38963897;
};
var $Hanf_arg18753904 = function(anf_arg11273901,anf_arg11233888,anf_fun1120488,anf_fun11243902,anf_fun11253903,l473440) {
var $z39073908 = D;
var $f39133914 = function(_) {
return R.isFunction(anf_fun11253903)?anf_fun11253903.app(l473440,anf_arg11273901):R.ffi.throwNonFunApp(L[516],anf_fun11253903,[l473440,anf_arg11273901]);
};
try {
if(--R.GAS > 0) {
$z39073908 = $f39133914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39133914,
"from":L[516]});
}
} catch($e39053906) {
if(R.isCont($e39053906)) {
var $ss39093910 = {"from":L[516],
"go":function(anf_array_val11283915) {
return $Hanf_array_val18743916(anf_array_val11283915,anf_arg11233888,anf_fun1120488,anf_fun11243902,l473440);
}};
$e39053906.stack[R.EXN_STACKHEIGHT++] = $ss39093910;
}
if(R.isPyretException($e39053906)) {
$e39053906.pyretStack.push(L[516]);
}
throw $e39053906;
}
var $ret39113912 = $Hanf_array_val18743916($z39073908,anf_arg11233888,anf_fun1120488,anf_fun11243902,l473440);
++R.GAS;
return $ret39113912;
};
var $Hanf_array_val18743916 = function(anf_array_val11283915,anf_arg11233888,anf_fun1120488,anf_fun11243902,l473440) {
var $z39193920 = D;
var $f39253926 = function(_) {
return R.isFunction(anf_fun11243902)?anf_fun11243902.app([anf_array_val11283915]):R.ffi.throwNonFunApp(L[515],anf_fun11243902,[[anf_array_val11283915]]);
};
try {
if(--R.GAS > 0) {
$z39193920 = $f39253926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39253926,
"from":L[515]});
}
} catch($e39173918) {
if(R.isCont($e39173918)) {
var $ss39213922 = {"from":L[515],
"go":function(anf_arg11293927) {
return $Hanf_arg18733928(anf_arg11293927,anf_arg11233888,anf_fun1120488,l473440);
}};
$e39173918.stack[R.EXN_STACKHEIGHT++] = $ss39213922;
}
if(R.isPyretException($e39173918)) {
$e39173918.pyretStack.push(L[515]);
}
throw $e39173918;
}
var $ret39233924 = $Hanf_arg18733928($z39193920,anf_arg11233888,anf_fun1120488,l473440);
++R.GAS;
return $ret39233924;
};
var $Hanf_arg18733928 = function(anf_arg11293927,anf_arg11233888,anf_fun1120488,l473440) {
var $z39313932 = D;
var $f39373938 = function(_) {
return R.isFunction(anf_fun1120488)?anf_fun1120488.app(l473440,anf_arg11233888,anf_arg11293927):R.ffi.throwNonFunApp(L[32],anf_fun1120488,[l473440,anf_arg11233888,anf_arg11293927]);
};
try {
if(--R.GAS > 0) {
$z39313932 = $f39373938();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39373938,
"from":L[32]});
}
} catch($e39293930) {
if(R.isCont($e39293930)) {
var $ss39333934 = {"from":L[32],
"go":function(ann_DASH_check_DASH_temp11193939) {
return $Hann_DASH_check_DASH_temp18723940(ann_DASH_check_DASH_temp11193939);
}};
$e39293930.stack[R.EXN_STACKHEIGHT++] = $ss39333934;
}
if(R.isPyretException($e39293930)) {
$e39293930.pyretStack.push(L[32]);
}
throw $e39293930;
}
var $ret39353936 = $Hann_DASH_check_DASH_temp18723940($z39313932);
++R.GAS;
return $ret39353936;
};
var $Hann_DASH_check_DASH_temp18723940 = function(ann_DASH_check_DASH_temp11193939) {
return ann_DASH_check_DASH_temp11193939;
};
var $Hanf_arg1871506 = function(anf_arg1115504,anf_fun1113505,l471491) {
var $z39433944 = D;
var $f39493950 = function(_) {
return R.isFunction(anf_fun1113505)?anf_fun1113505.app(l471491,anf_arg1115504):R.ffi.throwNonFunApp(L[36],anf_fun1113505,[l471491,anf_arg1115504]);
};
try {
if(--R.GAS > 0) {
$z39433944 = $f39493950();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39493950,
"from":L[36]});
}
} catch($e39413942) {
if(R.isCont($e39413942)) {
var $ss39453946 = {"from":L[36],
"go":function(ann_DASH_check_DASH_temp11123951) {
return $Hann_DASH_check_DASH_temp18703952(ann_DASH_check_DASH_temp11123951);
}};
$e39413942.stack[R.EXN_STACKHEIGHT++] = $ss39453946;
}
if(R.isPyretException($e39413942)) {
$e39413942.pyretStack.push(L[36]);
}
throw $e39413942;
}
var $ret39473948 = $Hann_DASH_check_DASH_temp18703952($z39433944);
++R.GAS;
return $ret39473948;
};
var $Hann_DASH_check_DASH_temp18703952 = function(ann_DASH_check_DASH_temp11123951) {
return ann_DASH_check_DASH_temp11123951;
};
var $Hanf_arg1869528 = function(anf_arg1106526,anf_fun1105527,l464513) {
var $z39553956 = D;
var $f39613962 = function(_) {
return R.isFunction(anf_fun1105527)?anf_fun1105527.app(l464513,anf_arg1106526):R.ffi.throwNonFunApp(L[42],anf_fun1105527,[l464513,anf_arg1106526]);
};
try {
if(--R.GAS > 0) {
$z39553956 = $f39613962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39613962,
"from":L[42]});
}
} catch($e39533954) {
if(R.isCont($e39533954)) {
var $ss39573958 = {"from":L[42],
"go":function(ann_DASH_check_DASH_temp11043963) {
return $Hann_DASH_check_DASH_temp18683964(ann_DASH_check_DASH_temp11043963);
}};
$e39533954.stack[R.EXN_STACKHEIGHT++] = $ss39573958;
}
if(R.isPyretException($e39533954)) {
$e39533954.pyretStack.push(L[42]);
}
throw $e39533954;
}
var $ret39593960 = $Hann_DASH_check_DASH_temp18683964($z39553956);
++R.GAS;
return $ret39593960;
};
var $Hann_DASH_check_DASH_temp18683964 = function(ann_DASH_check_DASH_temp11043963) {
return ann_DASH_check_DASH_temp11043963;
};
var $Hcases_DASH_val1867560 = function(cases_DASH_val61559,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,expr280326,fold5550,gid90256,l417545,left419547,list2753,mk_DASH_id101278,none6355,op418546,right420548,_plus7,raise10) {
var anf_fun9023975 = G(cases_DASH_val61559,"_match",L[51]);
var anf_obj9123981 = R.makeFunction(function(field4214206) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[546],1,arguments);
}
var $z42094210 = D;
var $f42154216 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(left419547):R.ffi.throwNonFunApp(L[547],desugar_DASH_expr117310.$var,[left419547]);
};
try {
if(--R.GAS > 0) {
$z42094210 = $f42154216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42154216,
"from":L[547]});
}
} catch($e42074208) {
if(R.isCont($e42074208)) {
var $ss42114212 = {"from":L[547],
"go":function(anf_arg9044217) {
return $Hanf_arg17954218(anf_arg9044217,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,field4214206,gid90256,l417545,list2753,right420548);
}};
$e42074208.stack[R.EXN_STACKHEIGHT++] = $ss42114212;
}
if(R.isPyretException($e42074208)) {
$e42074208.pyretStack.push(L[547]);
}
throw $e42074208;
}
var $ret42134214 = $Hanf_arg17954218($z42094210,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,field4214206,gid90256,l417545,list2753,right420548);
++R.GAS;
return $ret42134214;
});
var anf_obj10893982 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[517],0,arguments);
}
var thunk4243983 = {"$var":D,
"$name":"thunk"};
var opbool4253985 = {"$var":D,
"$name":"opbool"};
var collect_DASH_op4263987 = {"$var":D,
"$name":"collect-op"};
var anf_assign9253984 = R.makeFunction(function(e4274191) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[543],1,arguments);
}
var anf_fun9154204 = G(A113,"s-lam",L[545]);
var anf_fun9164202 = G(list2753,"make",L[544]);
var $z41944195 = D;
var $f42004201 = function(_) {
return R.isFunction(anf_fun9164202)?anf_fun9164202.app([]):R.ffi.throwNonFunApp(L[544],anf_fun9164202,[[]]);
};
try {
if(--R.GAS > 0) {
$z41944195 = $f42004201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42004201,
"from":L[544]});
}
} catch($e41924193) {
if(R.isCont($e41924193)) {
var $ss41964197 = {"from":L[544],
"go":function(anf_arg9174203) {
return $Hanf_arg18004205(anf_arg9174203,A113,anf_fun9154204,e4274191,l417545,list2753,none6355);
}};
$e41924193.stack[R.EXN_STACKHEIGHT++] = $ss41964197;
}
if(R.isPyretException($e41924193)) {
$e41924193.pyretStack.push(L[544]);
}
throw $e41924193;
}
var $ret41984199 = $Hanf_arg18004205($z41944195,A113,anf_fun9154204,e4274191,l417545,list2753,none6355);
++R.GAS;
return $ret41984199;
});
thunk4243983.$var = anf_assign9253984;
var anf_assign9353986 = R.makeFunction(function(fld4284176) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[539],1,arguments);
}
var anf_fun9274188 = G(A113,"s-app",L[542]);
var anf_fun9284189 = G(A113,"s-dot",L[541]);
var $z41794180 = D;
var $f41854186 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(left419547):R.ffi.throwNonFunApp(L[540],desugar_DASH_expr117310.$var,[left419547]);
};
try {
if(--R.GAS > 0) {
$z41794180 = $f41854186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41854186,
"from":L[540]});
}
} catch($e41774178) {
if(R.isCont($e41774178)) {
var $ss41814182 = {"from":L[540],
"go":function(anf_arg9294187) {
return $Hanf_arg18064190(anf_arg9294187,anf_fun9274188,anf_fun9284189,desugar_DASH_expr117310,fld4284176,l417545,list2753,right420548,thunk4243983);
}};
$e41774178.stack[R.EXN_STACKHEIGHT++] = $ss41814182;
}
if(R.isPyretException($e41774178)) {
$e41774178.pyretStack.push(L[540]);
}
throw $e41774178;
}
var $ret41834184 = $Hanf_arg18064190($z41794180,anf_fun9274188,anf_fun9284189,desugar_DASH_expr117310,fld4284176,l417545,list2753,right420548,thunk4243983);
++R.GAS;
return $ret41834184;
});
opbool4253985.$var = anf_assign9353986;
var anf_assign9593988 = R.makeFunction(function(opname4294161,exp4304162) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[536],2,arguments);
}
var anf_fun9374173 = G(A113,"is-s-op",L[538]);
var $z41654166 = D;
var $f41714172 = function(_) {
return R.isFunction(anf_fun9374173)?anf_fun9374173.app(exp4304162):R.ffi.throwNonFunApp(L[537],anf_fun9374173,[exp4304162]);
};
try {
if(--R.GAS > 0) {
$z41654166 = $f41714172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41714172,
"from":L[537]});
}
} catch($e41634164) {
if(R.isCont($e41634164)) {
var $ss41674168 = {"from":L[537],
"go":function(if_DASH_494174) {
return $Hif_DASH_18124175(if_DASH_494174,collect_DASH_op4263987,exp4304162,list2753,opname4294161,_plus7);
}};
$e41634164.stack[R.EXN_STACKHEIGHT++] = $ss41674168;
}
if(R.isPyretException($e41634164)) {
$e41634164.pyretStack.push(L[537]);
}
throw $e41634164;
}
var $ret41694170 = $Hif_DASH_18124175($z41654166,collect_DASH_op4263987,exp4304162,list2753,opname4294161,_plus7);
++R.GAS;
return $ret41694170;
});
collect_DASH_op4263987.$var = anf_assign9593988;
var collect_DASH_ors4314026 = R.makeFunction(function(arg_DASH_514148) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[535],1,arguments);
}
var $z41514152 = D;
var $f41574158 = function(_) {
return R.isFunction(collect_DASH_op4263987.$var)?collect_DASH_op4263987.$var.app(("opor"),arg_DASH_514148):R.ffi.throwNonFunApp(L[535],collect_DASH_op4263987.$var,[("opor"),arg_DASH_514148]);
};
try {
if(--R.GAS > 0) {
$z41514152 = $f41574158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41574158,
"from":L[535]});
}
} catch($e41494150) {
if(R.isCont($e41494150)) {
var $ss41534154 = {"from":L[535],
"go":function(ann_DASH_check_DASH_temp9604159) {
return $Hann_DASH_check_DASH_temp18134160(ann_DASH_check_DASH_temp9604159);
}};
$e41494150.stack[R.EXN_STACKHEIGHT++] = $ss41534154;
}
if(R.isPyretException($e41494150)) {
$e41494150.pyretStack.push(L[535]);
}
throw $e41494150;
}
var $ret41554156 = $Hann_DASH_check_DASH_temp18134160($z41514152);
++R.GAS;
return $ret41554156;
});
var collect_DASH_ands4324054 = R.makeFunction(function(arg_DASH_524135) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[534],1,arguments);
}
var $z41384139 = D;
var $f41444145 = function(_) {
return R.isFunction(collect_DASH_op4263987.$var)?collect_DASH_op4263987.$var.app(("opand"),arg_DASH_524135):R.ffi.throwNonFunApp(L[534],collect_DASH_op4263987.$var,[("opand"),arg_DASH_524135]);
};
try {
if(--R.GAS > 0) {
$z41384139 = $f41444145();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41444145,
"from":L[534]});
}
} catch($e41364137) {
if(R.isCont($e41364137)) {
var $ss41404141 = {"from":L[534],
"go":function(ann_DASH_check_DASH_temp9614146) {
return $Hann_DASH_check_DASH_temp18144147(ann_DASH_check_DASH_temp9614146);
}};
$e41364137.stack[R.EXN_STACKHEIGHT++] = $ss41404141;
}
if(R.isPyretException($e41364137)) {
$e41364137.pyretStack.push(L[534]);
}
throw $e41364137;
}
var $ret41424143 = $Hann_DASH_check_DASH_temp18144147($z41384139);
++R.GAS;
return $ret41424143;
});
var collect_DASH_carets4334080 = R.makeFunction(function(arg_DASH_534122) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[533],1,arguments);
}
var $z41254126 = D;
var $f41314132 = function(_) {
return R.isFunction(collect_DASH_op4263987.$var)?collect_DASH_op4263987.$var.app(("op^"),arg_DASH_534122):R.ffi.throwNonFunApp(L[533],collect_DASH_op4263987.$var,[("op^"),arg_DASH_534122]);
};
try {
if(--R.GAS > 0) {
$z41254126 = $f41314132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41314132,
"from":L[533]});
}
} catch($e41234124) {
if(R.isCont($e41234124)) {
var $ss41274128 = {"from":L[533],
"go":function(ann_DASH_check_DASH_temp9624133) {
return $Hann_DASH_check_DASH_temp18154134(ann_DASH_check_DASH_temp9624133);
}};
$e41234124.stack[R.EXN_STACKHEIGHT++] = $ss41274128;
}
if(R.isPyretException($e41234124)) {
$e41234124.pyretStack.push(L[533]);
}
throw $e41234124;
}
var $ret41294130 = $Hann_DASH_check_DASH_temp18154134($z41254126);
++R.GAS;
return $ret41294130;
});
var if_DASH_604115 = R.equiv(op418546,("op=="));
var if_helper9634000 = R.makeFunction(function(if_helper_arg9644120) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[532],1,arguments);
}
var ann_DASH_check_DASH_temp9134121 = if_helper_arg9644120;
return ann_DASH_check_DASH_temp9134121;
});
var anf_if9674119 = R.isBoolean(if_DASH_604115);
if(R.isPyretTrue(anf_if9674119)) {
if(R.isPyretTrue(if_DASH_604115)) {
var $z39913992 = D;
var $f39973998 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(left419547):R.ffi.throwNonFunApp(L[518],desugar_DASH_expr117310.$var,[left419547]);
};
try {
if(--R.GAS > 0) {
$z39913992 = $f39973998();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39973998,
"from":L[518]});
}
} catch($e39893990) {
if(R.isCont($e39893990)) {
var $ss39933994 = {"from":L[518],
"go":function(anf_arg10803999) {
return $Hanf_arg18204001(anf_arg10803999,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753,right420548);
}};
$e39893990.stack[R.EXN_STACKHEIGHT++] = $ss39933994;
}
if(R.isPyretException($e39893990)) {
$e39893990.pyretStack.push(L[518]);
}
throw $e39893990;
}
var $ret39953996 = $Hanf_arg18204001($z39913992,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753,right420548);
++R.GAS;
return $ret39953996;
} else {
var if_DASH_594110 = R.equiv(op418546,("op<>"));
var anf_if9704114 = R.isBoolean(if_DASH_594110);
if(R.isPyretTrue(anf_if9704114)) {
if(R.isPyretTrue(if_DASH_594110)) {
var $z40044005 = D;
var $f40104011 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(left419547):R.ffi.throwNonFunApp(L[519],desugar_DASH_expr117310.$var,[left419547]);
};
try {
if(--R.GAS > 0) {
$z40044005 = $f40104011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40104011,
"from":L[519]});
}
} catch($e40024003) {
if(R.isCont($e40024003)) {
var $ss40064007 = {"from":L[519],
"go":function(anf_arg10674012) {
return $Hanf_arg18274013(anf_arg10674012,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753,right420548);
}};
$e40024003.stack[R.EXN_STACKHEIGHT++] = $ss40064007;
}
if(R.isPyretException($e40024003)) {
$e40024003.pyretStack.push(L[519]);
}
throw $e40024003;
}
var $ret40084009 = $Hanf_arg18274013($z40044005,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753,right420548);
++R.GAS;
return $ret40084009;
} else {
var if_DASH_574105 = R.equiv(op418546,("opor"));
var anf_if9734109 = R.isBoolean(if_DASH_574105);
if(R.isPyretTrue(anf_if9734109)) {
if(R.isPyretTrue(if_DASH_574105)) {
var helper4384014 = {"$var":D,
"$name":"helper"};
var anf_assign10644015 = R.makeFunction(function(operands4394029) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[521],1,arguments);
}
var $z40324033 = D;
var $f40384039 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l417545,("or-oper-")):R.ffi.throwNonFunApp(L[522],mk_DASH_id101278.$var,[l417545,("or-oper-")]);
};
try {
if(--R.GAS > 0) {
$z40324033 = $f40384039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40384039,
"from":L[522]});
}
} catch($e40304031) {
if(R.isCont($e40304031)) {
var $ss40344035 = {"from":L[522],
"go":function(or_DASH_oper4404040) {
return $Hor_DASH_oper18404041(or_DASH_oper4404040,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,helper4384014,l417545,list2753,operands4394029);
}};
$e40304031.stack[R.EXN_STACKHEIGHT++] = $ss40344035;
}
if(R.isPyretException($e40304031)) {
$e40304031.pyretStack.push(L[522]);
}
throw $e40304031;
}
var $ret40364037 = $Hor_DASH_oper18404041($z40324033,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,helper4384014,l417545,list2753,operands4394029);
++R.GAS;
return $ret40364037;
});
helper4384014.$var = anf_assign10644015;
var $z40184019 = D;
var $f40244025 = function(_) {
return R.isFunction(collect_DASH_ors4314026)?collect_DASH_ors4314026.app(expr280326):R.ffi.throwNonFunApp(L[520],collect_DASH_ors4314026,[expr280326]);
};
try {
if(--R.GAS > 0) {
$z40184019 = $f40244025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40244025,
"from":L[520]});
}
} catch($e40164017) {
if(R.isCont($e40164017)) {
var $ss40204021 = {"from":L[520],
"go":function(operands4434027) {
return $Hoperands18424028(operands4434027,helper4384014,if_helper9634000);
}};
$e40164017.stack[R.EXN_STACKHEIGHT++] = $ss40204021;
}
if(R.isPyretException($e40164017)) {
$e40164017.pyretStack.push(L[520]);
}
throw $e40164017;
}
var $ret40224023 = $Hoperands18424028($z40184019,helper4384014,if_helper9634000);
++R.GAS;
return $ret40224023;
} else {
var if_DASH_554100 = R.equiv(op418546,("opand"));
var anf_if9764104 = R.isBoolean(if_DASH_554100);
if(R.isPyretTrue(anf_if9764104)) {
if(R.isPyretTrue(if_DASH_554100)) {
var helper4444042 = {"$var":D,
"$name":"helper"};
var anf_assign10284043 = R.makeFunction(function(operands4454057) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[524],1,arguments);
}
var $z40604061 = D;
var $f40664067 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l417545,("and-oper-")):R.ffi.throwNonFunApp(L[525],mk_DASH_id101278.$var,[l417545,("and-oper-")]);
};
try {
if(--R.GAS > 0) {
$z40604061 = $f40664067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40664067,
"from":L[525]});
}
} catch($e40584059) {
if(R.isCont($e40584059)) {
var $ss40624063 = {"from":L[525],
"go":function(and_DASH_oper4464068) {
return $Hand_DASH_oper18554069(and_DASH_oper4464068,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,helper4444042,l417545,list2753,operands4454057);
}};
$e40584059.stack[R.EXN_STACKHEIGHT++] = $ss40624063;
}
if(R.isPyretException($e40584059)) {
$e40584059.pyretStack.push(L[525]);
}
throw $e40584059;
}
var $ret40644065 = $Hand_DASH_oper18554069($z40604061,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,helper4444042,l417545,list2753,operands4454057);
++R.GAS;
return $ret40644065;
});
helper4444042.$var = anf_assign10284043;
var $z40464047 = D;
var $f40524053 = function(_) {
return R.isFunction(collect_DASH_ands4324054)?collect_DASH_ands4324054.app(expr280326):R.ffi.throwNonFunApp(L[523],collect_DASH_ands4324054,[expr280326]);
};
try {
if(--R.GAS > 0) {
$z40464047 = $f40524053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40524053,
"from":L[523]});
}
} catch($e40444045) {
if(R.isCont($e40444045)) {
var $ss40484049 = {"from":L[523],
"go":function(operands4494055) {
return $Hoperands18574056(operands4494055,helper4444042,if_helper9634000);
}};
$e40444045.stack[R.EXN_STACKHEIGHT++] = $ss40484049;
}
if(R.isPyretException($e40444045)) {
$e40444045.pyretStack.push(L[523]);
}
throw $e40444045;
}
var $ret40504051 = $Hoperands18574056($z40464047,helper4444042,if_helper9634000);
++R.GAS;
return $ret40504051;
} else {
var if_DASH_544095 = R.equiv(op418546,("op^"));
var anf_if9794099 = R.isBoolean(if_DASH_544095);
if(R.isPyretTrue(anf_if9794099)) {
if(R.isPyretTrue(if_DASH_544095)) {
var $z40724073 = D;
var $f40784079 = function(_) {
return R.isFunction(collect_DASH_carets4334080)?collect_DASH_carets4334080.app(expr280326):R.ffi.throwNonFunApp(L[526],collect_DASH_carets4334080,[expr280326]);
};
try {
if(--R.GAS > 0) {
$z40724073 = $f40784079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40784079,
"from":L[526]});
}
} catch($e40704071) {
if(R.isCont($e40704071)) {
var $ss40744075 = {"from":L[526],
"go":function(operands4504081) {
return $Hoperands18634082(operands4504081,A113,desugar_DASH_expr117310,fold5550,if_helper9634000,list2753);
}};
$e40704071.stack[R.EXN_STACKHEIGHT++] = $ss40744075;
}
if(R.isPyretException($e40704071)) {
$e40704071.pyretStack.push(L[526]);
}
throw $e40704071;
}
var $ret40764077 = $Hoperands18634082($z40724073,A113,desugar_DASH_expr117310,fold5550,if_helper9634000,list2753);
++R.GAS;
return $ret40764077;
} else {
var $z40854086 = D;
var $f40914092 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("No implementation for "),op418546):R.ffi.throwNonFunApp(L[527],_plus7,[("No implementation for "),op418546]);
};
try {
if(--R.GAS > 0) {
$z40854086 = $f40914092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40914092,
"from":L[527]});
}
} catch($e40834084) {
if(R.isCont($e40834084)) {
var $ss40874088 = {"from":L[527],
"go":function(anf_arg9804093) {
return $Hanf_arg18654094(anf_arg9804093,if_helper9634000,raise10);
}};
$e40834084.stack[R.EXN_STACKHEIGHT++] = $ss40874088;
}
if(R.isPyretException($e40834084)) {
$e40834084.pyretStack.push(L[527]);
}
throw $e40834084;
}
var $ret40894090 = $Hanf_arg18654094($z40854086,if_helper9634000,raise10);
++R.GAS;
return $ret40894090;
}
} else {
var cont_tail_arg9774098 = R.throwNonBooleanCondition(L[528],("if"),if_DASH_544095);
if(--R.GAS > 0) {
$z40964097 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9774098):R.ffi.throwNonFunApp(L[528],if_helper9634000,[cont_tail_arg9774098]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9774098):R.ffi.throwNonFunApp(L[528],if_helper9634000,[cont_tail_arg9774098]);
},
"from":L[528]});
}
++R.GAS;
return $z40964097;
}
}
} else {
var cont_tail_arg9744103 = R.throwNonBooleanCondition(L[529],("if"),if_DASH_554100);
if(--R.GAS > 0) {
$z41014102 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9744103):R.ffi.throwNonFunApp(L[529],if_helper9634000,[cont_tail_arg9744103]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9744103):R.ffi.throwNonFunApp(L[529],if_helper9634000,[cont_tail_arg9744103]);
},
"from":L[529]});
}
++R.GAS;
return $z41014102;
}
}
} else {
var cont_tail_arg9714108 = R.throwNonBooleanCondition(L[530],("if"),if_DASH_574105);
if(--R.GAS > 0) {
$z41064107 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9714108):R.ffi.throwNonFunApp(L[530],if_helper9634000,[cont_tail_arg9714108]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9714108):R.ffi.throwNonFunApp(L[530],if_helper9634000,[cont_tail_arg9714108]);
},
"from":L[530]});
}
++R.GAS;
return $z41064107;
}
}
} else {
var cont_tail_arg9684113 = R.throwNonBooleanCondition(L[531],("if"),if_DASH_594110);
if(--R.GAS > 0) {
$z41114112 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9684113):R.ffi.throwNonFunApp(L[531],if_helper9634000,[cont_tail_arg9684113]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9684113):R.ffi.throwNonFunApp(L[531],if_helper9634000,[cont_tail_arg9684113]);
},
"from":L[531]});
}
++R.GAS;
return $z41114112;
}
}
} else {
var cont_tail_arg9654118 = R.throwNonBooleanCondition(L[532],("if"),if_DASH_604115);
if(--R.GAS > 0) {
$z41164117 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9654118):R.ffi.throwNonFunApp(L[532],if_helper9634000,[cont_tail_arg9654118]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9654118):R.ffi.throwNonFunApp(L[532],if_helper9634000,[cont_tail_arg9654118]);
},
"from":L[532]});
}
++R.GAS;
return $z41164117;
}
});
var anf_arg10903976 = R.makeObject({"some":anf_obj9123981,
"none":anf_obj10893982});
var anf_arg10923977 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[51],0,arguments);
}
var ann_DASH_check_DASH_temp10913980 = R.throwNoBranchesMatched(L[51],("cases"));
return ann_DASH_check_DASH_temp10913980;
});
var $z39673968 = D;
var $f39733974 = function(_) {
return R.isFunction(anf_fun9023975)?anf_fun9023975.app(anf_arg10903976,anf_arg10923977):R.ffi.throwNonFunApp(L[50],anf_fun9023975,[anf_arg10903976,anf_arg10923977]);
};
try {
if(--R.GAS > 0) {
$z39673968 = $f39733974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39733974,
"from":L[50]});
}
} catch($e39653966) {
if(R.isCont($e39653966)) {
var $ss39693970 = {"from":L[50],
"go":function(ann_DASH_check_DASH_temp9013978) {
return $Hann_DASH_check_DASH_temp18663979(ann_DASH_check_DASH_temp9013978);
}};
$e39653966.stack[R.EXN_STACKHEIGHT++] = $ss39693970;
}
if(R.isPyretException($e39653966)) {
$e39653966.pyretStack.push(L[50]);
}
throw $e39653966;
}
var $ret39713972 = $Hann_DASH_check_DASH_temp18663979($z39673968);
++R.GAS;
return $ret39713972;
};
var $Hann_DASH_check_DASH_temp18663979 = function(ann_DASH_check_DASH_temp9013978) {
return ann_DASH_check_DASH_temp9013978;
};
var $Hanf_arg18204001 = function(anf_arg10803999,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753,right420548) {
var $z42214222 = D;
var $f42274228 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(right420548):R.ffi.throwNonFunApp(L[548],desugar_DASH_expr117310.$var,[right420548]);
};
try {
if(--R.GAS > 0) {
$z42214222 = $f42274228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42274228,
"from":L[548]});
}
} catch($e42194220) {
if(R.isCont($e42194220)) {
var $ss42234224 = {"from":L[548],
"go":function(anf_arg10814229) {
return $Hanf_arg18194230(anf_arg10814229,A113,anf_arg10803999,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753);
}};
$e42194220.stack[R.EXN_STACKHEIGHT++] = $ss42234224;
}
if(R.isPyretException($e42194220)) {
$e42194220.pyretStack.push(L[548]);
}
throw $e42194220;
}
var $ret42254226 = $Hanf_arg18194230($z42214222,A113,anf_arg10803999,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753);
++R.GAS;
return $ret42254226;
};
var $Hanf_arg18194230 = function(anf_arg10814229,A113,anf_arg10803999,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753) {
var anf_arg10864241 = R.makeFunction(function(e14344244,e24354245) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[550],2,arguments);
}
var anf_fun10834258 = G(A113,"s-prim-app",L[552]);
var anf_fun10844256 = G(list2753,"make",L[551]);
var $z42484249 = D;
var $f42544255 = function(_) {
return R.isFunction(anf_fun10844256)?anf_fun10844256.app([e14344244,e24354245]):R.ffi.throwNonFunApp(L[551],anf_fun10844256,[[e14344244,e24354245]]);
};
try {
if(--R.GAS > 0) {
$z42484249 = $f42544255();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42544255,
"from":L[551]});
}
} catch($e42464247) {
if(R.isCont($e42464247)) {
var $ss42504251 = {"from":L[551],
"go":function(anf_arg10854257) {
return $Hanf_arg18174259(anf_arg10854257,anf_fun10834258,l417545);
}};
$e42464247.stack[R.EXN_STACKHEIGHT++] = $ss42504251;
}
if(R.isPyretException($e42464247)) {
$e42464247.pyretStack.push(L[551]);
}
throw $e42464247;
}
var $ret42524253 = $Hanf_arg18174259($z42484249,anf_fun10834258,l417545);
++R.GAS;
return $ret42524253;
});
var $z42334234 = D;
var $f42394240 = function(_) {
return R.isFunction(ds_DASH_curry_DASH_binop113302.$var)?ds_DASH_curry_DASH_binop113302.$var.app(l417545,anf_arg10803999,anf_arg10814229,anf_arg10864241):R.ffi.throwNonFunApp(L[549],ds_DASH_curry_DASH_binop113302.$var,[l417545,anf_arg10803999,anf_arg10814229,anf_arg10864241]);
};
try {
if(--R.GAS > 0) {
$z42334234 = $f42394240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42394240,
"from":L[549]});
}
} catch($e42314232) {
if(R.isCont($e42314232)) {
var $ss42354236 = {"from":L[549],
"go":function(cont_tail_arg10874242) {
return $Hcont_tail_arg18184243(cont_tail_arg10874242,if_helper9634000);
}};
$e42314232.stack[R.EXN_STACKHEIGHT++] = $ss42354236;
}
if(R.isPyretException($e42314232)) {
$e42314232.pyretStack.push(L[549]);
}
throw $e42314232;
}
var $ret42374238 = $Hcont_tail_arg18184243($z42334234,if_helper9634000);
++R.GAS;
return $ret42374238;
};
var $Hcont_tail_arg18184243 = function(cont_tail_arg10874242,if_helper9634000) {
if(--R.GAS > 0) {
$z42604261 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg10874242):R.ffi.throwNonFunApp(L[549],if_helper9634000,[cont_tail_arg10874242]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg10874242):R.ffi.throwNonFunApp(L[549],if_helper9634000,[cont_tail_arg10874242]);
},
"from":L[549]});
}
++R.GAS;
return $z42604261;
};
var $Hanf_arg18174259 = function(anf_arg10854257,anf_fun10834258,l417545) {
var $z42644265 = D;
var $f42704271 = function(_) {
return R.isFunction(anf_fun10834258)?anf_fun10834258.app(l417545,("equiv"),anf_arg10854257):R.ffi.throwNonFunApp(L[550],anf_fun10834258,[l417545,("equiv"),anf_arg10854257]);
};
try {
if(--R.GAS > 0) {
$z42644265 = $f42704271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42704271,
"from":L[550]});
}
} catch($e42624263) {
if(R.isCont($e42624263)) {
var $ss42664267 = {"from":L[550],
"go":function(ann_DASH_check_DASH_temp10824272) {
return $Hann_DASH_check_DASH_temp18164273(ann_DASH_check_DASH_temp10824272);
}};
$e42624263.stack[R.EXN_STACKHEIGHT++] = $ss42664267;
}
if(R.isPyretException($e42624263)) {
$e42624263.pyretStack.push(L[550]);
}
throw $e42624263;
}
var $ret42684269 = $Hann_DASH_check_DASH_temp18164273($z42644265);
++R.GAS;
return $ret42684269;
};
var $Hann_DASH_check_DASH_temp18164273 = function(ann_DASH_check_DASH_temp10824272) {
return ann_DASH_check_DASH_temp10824272;
};
var $Hanf_arg18274013 = function(anf_arg10674012,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753,right420548) {
var $z42764277 = D;
var $f42824283 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(right420548):R.ffi.throwNonFunApp(L[553],desugar_DASH_expr117310.$var,[right420548]);
};
try {
if(--R.GAS > 0) {
$z42764277 = $f42824283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42824283,
"from":L[553]});
}
} catch($e42744275) {
if(R.isCont($e42744275)) {
var $ss42784279 = {"from":L[553],
"go":function(anf_arg10684284) {
return $Hanf_arg18264285(anf_arg10684284,A113,anf_arg10674012,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753);
}};
$e42744275.stack[R.EXN_STACKHEIGHT++] = $ss42784279;
}
if(R.isPyretException($e42744275)) {
$e42744275.pyretStack.push(L[553]);
}
throw $e42744275;
}
var $ret42804281 = $Hanf_arg18264285($z42764277,A113,anf_arg10674012,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753);
++R.GAS;
return $ret42804281;
};
var $Hanf_arg18264285 = function(anf_arg10684284,A113,anf_arg10674012,ds_DASH_curry_DASH_binop113302,if_helper9634000,l417545,list2753) {
var anf_arg10774296 = R.makeFunction(function(e14364299,e24374300) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[555],2,arguments);
}
var anf_fun10704313 = G(A113,"s-prim-app",L[559]);
var anf_fun10714314 = G(list2753,"make",L[558]);
var anf_fun10724315 = G(A113,"s-prim-app",L[557]);
var anf_fun10734311 = G(list2753,"make",L[556]);
var $z43034304 = D;
var $f43094310 = function(_) {
return R.isFunction(anf_fun10734311)?anf_fun10734311.app([e14364299,e24374300]):R.ffi.throwNonFunApp(L[556],anf_fun10734311,[[e14364299,e24374300]]);
};
try {
if(--R.GAS > 0) {
$z43034304 = $f43094310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43094310,
"from":L[556]});
}
} catch($e43014302) {
if(R.isCont($e43014302)) {
var $ss43054306 = {"from":L[556],
"go":function(anf_arg10744312) {
return $Hanf_arg18244316(anf_arg10744312,anf_fun10704313,anf_fun10714314,anf_fun10724315,l417545);
}};
$e43014302.stack[R.EXN_STACKHEIGHT++] = $ss43054306;
}
if(R.isPyretException($e43014302)) {
$e43014302.pyretStack.push(L[556]);
}
throw $e43014302;
}
var $ret43074308 = $Hanf_arg18244316($z43034304,anf_fun10704313,anf_fun10714314,anf_fun10724315,l417545);
++R.GAS;
return $ret43074308;
});
var $z42884289 = D;
var $f42944295 = function(_) {
return R.isFunction(ds_DASH_curry_DASH_binop113302.$var)?ds_DASH_curry_DASH_binop113302.$var.app(l417545,anf_arg10674012,anf_arg10684284,anf_arg10774296):R.ffi.throwNonFunApp(L[554],ds_DASH_curry_DASH_binop113302.$var,[l417545,anf_arg10674012,anf_arg10684284,anf_arg10774296]);
};
try {
if(--R.GAS > 0) {
$z42884289 = $f42944295();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42944295,
"from":L[554]});
}
} catch($e42864287) {
if(R.isCont($e42864287)) {
var $ss42904291 = {"from":L[554],
"go":function(cont_tail_arg10784297) {
return $Hcont_tail_arg18254298(cont_tail_arg10784297,if_helper9634000);
}};
$e42864287.stack[R.EXN_STACKHEIGHT++] = $ss42904291;
}
if(R.isPyretException($e42864287)) {
$e42864287.pyretStack.push(L[554]);
}
throw $e42864287;
}
var $ret42924293 = $Hcont_tail_arg18254298($z42884289,if_helper9634000);
++R.GAS;
return $ret42924293;
};
var $Hcont_tail_arg18254298 = function(cont_tail_arg10784297,if_helper9634000) {
if(--R.GAS > 0) {
$z43174318 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg10784297):R.ffi.throwNonFunApp(L[554],if_helper9634000,[cont_tail_arg10784297]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg10784297):R.ffi.throwNonFunApp(L[554],if_helper9634000,[cont_tail_arg10784297]);
},
"from":L[554]});
}
++R.GAS;
return $z43174318;
};
var $Hanf_arg18244316 = function(anf_arg10744312,anf_fun10704313,anf_fun10714314,anf_fun10724315,l417545) {
var $z43214322 = D;
var $f43274328 = function(_) {
return R.isFunction(anf_fun10724315)?anf_fun10724315.app(l417545,("equiv"),anf_arg10744312):R.ffi.throwNonFunApp(L[560],anf_fun10724315,[l417545,("equiv"),anf_arg10744312]);
};
try {
if(--R.GAS > 0) {
$z43214322 = $f43274328();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43274328,
"from":L[560]});
}
} catch($e43194320) {
if(R.isCont($e43194320)) {
var $ss43234324 = {"from":L[560],
"go":function(anf_array_val10754329) {
return $Hanf_array_val18234330(anf_array_val10754329,anf_fun10704313,anf_fun10714314,l417545);
}};
$e43194320.stack[R.EXN_STACKHEIGHT++] = $ss43234324;
}
if(R.isPyretException($e43194320)) {
$e43194320.pyretStack.push(L[560]);
}
throw $e43194320;
}
var $ret43254326 = $Hanf_array_val18234330($z43214322,anf_fun10704313,anf_fun10714314,l417545);
++R.GAS;
return $ret43254326;
};
var $Hanf_array_val18234330 = function(anf_array_val10754329,anf_fun10704313,anf_fun10714314,l417545) {
var $z43334334 = D;
var $f43394340 = function(_) {
return R.isFunction(anf_fun10714314)?anf_fun10714314.app([anf_array_val10754329]):R.ffi.throwNonFunApp(L[558],anf_fun10714314,[[anf_array_val10754329]]);
};
try {
if(--R.GAS > 0) {
$z43334334 = $f43394340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43394340,
"from":L[558]});
}
} catch($e43314332) {
if(R.isCont($e43314332)) {
var $ss43354336 = {"from":L[558],
"go":function(anf_arg10764341) {
return $Hanf_arg18224342(anf_arg10764341,anf_fun10704313,l417545);
}};
$e43314332.stack[R.EXN_STACKHEIGHT++] = $ss43354336;
}
if(R.isPyretException($e43314332)) {
$e43314332.pyretStack.push(L[558]);
}
throw $e43314332;
}
var $ret43374338 = $Hanf_arg18224342($z43334334,anf_fun10704313,l417545);
++R.GAS;
return $ret43374338;
};
var $Hanf_arg18224342 = function(anf_arg10764341,anf_fun10704313,l417545) {
var $z43454346 = D;
var $f43514352 = function(_) {
return R.isFunction(anf_fun10704313)?anf_fun10704313.app(l417545,("not"),anf_arg10764341):R.ffi.throwNonFunApp(L[555],anf_fun10704313,[l417545,("not"),anf_arg10764341]);
};
try {
if(--R.GAS > 0) {
$z43454346 = $f43514352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43514352,
"from":L[555]});
}
} catch($e43434344) {
if(R.isCont($e43434344)) {
var $ss43474348 = {"from":L[555],
"go":function(ann_DASH_check_DASH_temp10694353) {
return $Hann_DASH_check_DASH_temp18214354(ann_DASH_check_DASH_temp10694353);
}};
$e43434344.stack[R.EXN_STACKHEIGHT++] = $ss43474348;
}
if(R.isPyretException($e43434344)) {
$e43434344.pyretStack.push(L[555]);
}
throw $e43434344;
}
var $ret43494350 = $Hann_DASH_check_DASH_temp18214354($z43454346);
++R.GAS;
return $ret43494350;
};
var $Hann_DASH_check_DASH_temp18214354 = function(ann_DASH_check_DASH_temp10694353) {
return ann_DASH_check_DASH_temp10694353;
};
var $Hoperands18424028 = function(operands4434027,helper4384014,if_helper9634000) {
var $z43574358 = D;
var $f43634364 = function(_) {
return R.isFunction(helper4384014.$var)?helper4384014.$var.app(operands4434027):R.ffi.throwNonFunApp(L[561],helper4384014.$var,[operands4434027]);
};
try {
if(--R.GAS > 0) {
$z43574358 = $f43634364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43634364,
"from":L[561]});
}
} catch($e43554356) {
if(R.isCont($e43554356)) {
var $ss43594360 = {"from":L[561],
"go":function(cont_tail_arg10654365) {
return $Hcont_tail_arg18414366(cont_tail_arg10654365,if_helper9634000);
}};
$e43554356.stack[R.EXN_STACKHEIGHT++] = $ss43594360;
}
if(R.isPyretException($e43554356)) {
$e43554356.pyretStack.push(L[561]);
}
throw $e43554356;
}
var $ret43614362 = $Hcont_tail_arg18414366($z43574358,if_helper9634000);
++R.GAS;
return $ret43614362;
};
var $Hcont_tail_arg18414366 = function(cont_tail_arg10654365,if_helper9634000) {
if(--R.GAS > 0) {
$z43674368 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg10654365):R.ffi.throwNonFunApp(L[561],if_helper9634000,[cont_tail_arg10654365]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg10654365):R.ffi.throwNonFunApp(L[561],if_helper9634000,[cont_tail_arg10654365]);
},
"from":L[561]});
}
++R.GAS;
return $z43674368;
};
var $Hor_DASH_oper18404041 = function(or_DASH_oper4404040,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,helper4384014,l417545,list2753,operands4394029) {
var cases_DASH_val584415 = G(operands4394029,"rest",L[569]);
var anf_fun10324379 = G(cases_DASH_val584415,"_match",L[562]);
var anf_obj10414385 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[566],0,arguments);
}
var anf_arg10344412 = G(operands4394029,"first",L[568]);
var $z44044405 = D;
var $f44104411 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(anf_arg10344412):R.ffi.throwNonFunApp(L[567],desugar_DASH_expr117310.$var,[anf_arg10344412]);
};
try {
if(--R.GAS > 0) {
$z44044405 = $f44104411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44104411,
"from":L[567]});
}
} catch($e44024403) {
if(R.isCont($e44024403)) {
var $ss44064407 = {"from":L[567],
"go":function(anf_arg10354413) {
return $Hanf_arg18304414(anf_arg10354413,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040);
}};
$e44024403.stack[R.EXN_STACKHEIGHT++] = $ss44064407;
}
if(R.isPyretException($e44024403)) {
$e44024403.pyretStack.push(L[567]);
}
throw $e44024403;
}
var $ret44084409 = $Hanf_arg18304414($z44044405,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040);
++R.GAS;
return $ret44084409;
});
var anf_obj10604386 = R.makeFunction(function($underscore4414387,$underscore4424388) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[563],2,arguments);
}
var anf_arg10434399 = G(operands4394029,"first",L[565]);
var $z43914392 = D;
var $f43974398 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(anf_arg10434399):R.ffi.throwNonFunApp(L[564],desugar_DASH_expr117310.$var,[anf_arg10434399]);
};
try {
if(--R.GAS > 0) {
$z43914392 = $f43974398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43974398,
"from":L[564]});
}
} catch($e43894390) {
if(R.isCont($e43894390)) {
var $ss43934394 = {"from":L[564],
"go":function(anf_arg10444400) {
return $Hanf_arg18384401(anf_arg10444400,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,list2753,operands4394029,or_DASH_oper4404040);
}};
$e43894390.stack[R.EXN_STACKHEIGHT++] = $ss43934394;
}
if(R.isPyretException($e43894390)) {
$e43894390.pyretStack.push(L[564]);
}
throw $e43894390;
}
var $ret43954396 = $Hanf_arg18384401($z43914392,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,list2753,operands4394029,or_DASH_oper4404040);
++R.GAS;
return $ret43954396;
});
var anf_arg10614380 = R.makeObject({"empty":anf_obj10414385,
"link":anf_obj10604386});
var anf_arg10634381 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[562],0,arguments);
}
var ann_DASH_check_DASH_temp10624384 = R.throwNoBranchesMatched(L[562],("cases"));
return ann_DASH_check_DASH_temp10624384;
});
var $z43714372 = D;
var $f43774378 = function(_) {
return R.isFunction(anf_fun10324379)?anf_fun10324379.app(anf_arg10614380,anf_arg10634381):R.ffi.throwNonFunApp(L[521],anf_fun10324379,[anf_arg10614380,anf_arg10634381]);
};
try {
if(--R.GAS > 0) {
$z43714372 = $f43774378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43774378,
"from":L[521]});
}
} catch($e43694370) {
if(R.isCont($e43694370)) {
var $ss43734374 = {"from":L[521],
"go":function(ann_DASH_check_DASH_temp10314382) {
return $Hann_DASH_check_DASH_temp18394383(ann_DASH_check_DASH_temp10314382);
}};
$e43694370.stack[R.EXN_STACKHEIGHT++] = $ss43734374;
}
if(R.isPyretException($e43694370)) {
$e43694370.pyretStack.push(L[521]);
}
throw $e43694370;
}
var $ret43754376 = $Hann_DASH_check_DASH_temp18394383($z43714372);
++R.GAS;
return $ret43754376;
};
var $Hann_DASH_check_DASH_temp18394383 = function(ann_DASH_check_DASH_temp10314382) {
return ann_DASH_check_DASH_temp10314382;
};
var $Hanf_arg18384401 = function(anf_arg10444400,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,list2753,operands4394029,or_DASH_oper4404040) {
var anf_fun10454429 = G(A113,"s-if-else",L[575]);
var anf_fun10464430 = G(list2753,"make",L[574]);
var anf_fun10474431 = G(A113,"s-if-branch",L[573]);
var anf_arg10484428 = G(or_DASH_oper4404040,"id-e",L[572]);
var anf_fun10494426 = G(A113,"s-bool",L[571]);
var $z44184419 = D;
var $f44244425 = function(_) {
return R.isFunction(anf_fun10494426)?anf_fun10494426.app(l417545,(true)):R.ffi.throwNonFunApp(L[570],anf_fun10494426,[l417545,(true)]);
};
try {
if(--R.GAS > 0) {
$z44184419 = $f44244425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44244425,
"from":L[570]});
}
} catch($e44164417) {
if(R.isCont($e44164417)) {
var $ss44204421 = {"from":L[570],
"go":function(anf_arg10504427) {
return $Hanf_arg18374432(anf_arg10504427,anf_arg10444400,anf_arg10484428,anf_fun10454429,anf_fun10464430,anf_fun10474431,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040);
}};
$e44164417.stack[R.EXN_STACKHEIGHT++] = $ss44204421;
}
if(R.isPyretException($e44164417)) {
$e44164417.pyretStack.push(L[570]);
}
throw $e44164417;
}
var $ret44224423 = $Hanf_arg18374432($z44184419,anf_arg10444400,anf_arg10484428,anf_fun10454429,anf_fun10464430,anf_fun10474431,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040);
++R.GAS;
return $ret44224423;
};
var $Hanf_arg18374432 = function(anf_arg10504427,anf_arg10444400,anf_arg10484428,anf_fun10454429,anf_fun10464430,anf_fun10474431,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040) {
var $z44354436 = D;
var $f44414442 = function(_) {
return R.isFunction(anf_fun10474431)?anf_fun10474431.app(l417545,anf_arg10484428,anf_arg10504427):R.ffi.throwNonFunApp(L[576],anf_fun10474431,[l417545,anf_arg10484428,anf_arg10504427]);
};
try {
if(--R.GAS > 0) {
$z44354436 = $f44414442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44414442,
"from":L[576]});
}
} catch($e44334434) {
if(R.isCont($e44334434)) {
var $ss44374438 = {"from":L[576],
"go":function(anf_array_val10514443) {
return $Hanf_array_val18364444(anf_array_val10514443,anf_arg10444400,anf_fun10454429,anf_fun10464430,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040);
}};
$e44334434.stack[R.EXN_STACKHEIGHT++] = $ss44374438;
}
if(R.isPyretException($e44334434)) {
$e44334434.pyretStack.push(L[576]);
}
throw $e44334434;
}
var $ret44394440 = $Hanf_array_val18364444($z44354436,anf_arg10444400,anf_fun10454429,anf_fun10464430,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040);
++R.GAS;
return $ret44394440;
};
var $Hanf_array_val18364444 = function(anf_array_val10514443,anf_arg10444400,anf_fun10454429,anf_fun10464430,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040) {
var $z44474448 = D;
var $f44534454 = function(_) {
return R.isFunction(anf_fun10464430)?anf_fun10464430.app([anf_array_val10514443]):R.ffi.throwNonFunApp(L[574],anf_fun10464430,[[anf_array_val10514443]]);
};
try {
if(--R.GAS > 0) {
$z44474448 = $f44534454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44534454,
"from":L[574]});
}
} catch($e44454446) {
if(R.isCont($e44454446)) {
var $ss44494450 = {"from":L[574],
"go":function(anf_arg10524455) {
return $Hanf_arg18354456(anf_arg10524455,anf_arg10444400,anf_fun10454429,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040);
}};
$e44454446.stack[R.EXN_STACKHEIGHT++] = $ss44494450;
}
if(R.isPyretException($e44454446)) {
$e44454446.pyretStack.push(L[574]);
}
throw $e44454446;
}
var $ret44514452 = $Hanf_arg18354456($z44474448,anf_arg10444400,anf_fun10454429,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040);
++R.GAS;
return $ret44514452;
};
var $Hanf_arg18354456 = function(anf_arg10524455,anf_arg10444400,anf_fun10454429,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4384014,l417545,operands4394029,or_DASH_oper4404040) {
var anf_arg10534467 = G(operands4394029,"rest",L[578]);
var $z44594460 = D;
var $f44654466 = function(_) {
return R.isFunction(helper4384014.$var)?helper4384014.$var.app(anf_arg10534467):R.ffi.throwNonFunApp(L[577],helper4384014.$var,[anf_arg10534467]);
};
try {
if(--R.GAS > 0) {
$z44594460 = $f44654466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44654466,
"from":L[577]});
}
} catch($e44574458) {
if(R.isCont($e44574458)) {
var $ss44614462 = {"from":L[577],
"go":function(anf_arg10544468) {
return $Hanf_arg18344469(anf_arg10544468,anf_arg10444400,anf_arg10524455,anf_fun10454429,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040);
}};
$e44574458.stack[R.EXN_STACKHEIGHT++] = $ss44614462;
}
if(R.isPyretException($e44574458)) {
$e44574458.pyretStack.push(L[577]);
}
throw $e44574458;
}
var $ret44634464 = $Hanf_arg18344469($z44594460,anf_arg10444400,anf_arg10524455,anf_fun10454429,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040);
++R.GAS;
return $ret44634464;
};
var $Hanf_arg18344469 = function(anf_arg10544468,anf_arg10444400,anf_arg10524455,anf_fun10454429,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040) {
var $z44724473 = D;
var $f44784479 = function(_) {
return R.isFunction(anf_fun10454429)?anf_fun10454429.app(l417545,anf_arg10524455,anf_arg10544468):R.ffi.throwNonFunApp(L[579],anf_fun10454429,[l417545,anf_arg10524455,anf_arg10544468]);
};
try {
if(--R.GAS > 0) {
$z44724473 = $f44784479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44784479,
"from":L[579]});
}
} catch($e44704471) {
if(R.isCont($e44704471)) {
var $ss44744475 = {"from":L[579],
"go":function(anf_arg10554480) {
return $Hanf_arg18334481(anf_arg10554480,anf_arg10444400,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040);
}};
$e44704471.stack[R.EXN_STACKHEIGHT++] = $ss44744475;
}
if(R.isPyretException($e44704471)) {
$e44704471.pyretStack.push(L[579]);
}
throw $e44704471;
}
var $ret44764477 = $Hanf_arg18334481($z44724473,anf_arg10444400,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040);
++R.GAS;
return $ret44764477;
};
var $Hanf_arg18334481 = function(anf_arg10554480,anf_arg10444400,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040) {
var anf_bracket10564496 = G(operands4394029,"first",L[583]);
var anf_arg10574492 = G(anf_bracket10564496,"l",L[582]);
var anf_arg10584493 = G(or_DASH_oper4404040,"id-e",L[581]);
var $z44844485 = D;
var $f44904491 = function(_) {
return R.isFunction(bool_DASH_op_DASH_exn96268.$var)?bool_DASH_op_DASH_exn96268.$var.app(anf_arg10574492,("first"),("or"),anf_arg10584493):R.ffi.throwNonFunApp(L[580],bool_DASH_op_DASH_exn96268.$var,[anf_arg10574492,("first"),("or"),anf_arg10584493]);
};
try {
if(--R.GAS > 0) {
$z44844485 = $f44904491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44904491,
"from":L[580]});
}
} catch($e44824483) {
if(R.isCont($e44824483)) {
var $ss44864487 = {"from":L[580],
"go":function(anf_arg10594494) {
return $Hanf_arg18324495(anf_arg10594494,anf_arg10444400,anf_arg10554480,check_DASH_bool91258,l417545,or_DASH_oper4404040);
}};
$e44824483.stack[R.EXN_STACKHEIGHT++] = $ss44864487;
}
if(R.isPyretException($e44824483)) {
$e44824483.pyretStack.push(L[580]);
}
throw $e44824483;
}
var $ret44884489 = $Hanf_arg18324495($z44844485,anf_arg10444400,anf_arg10554480,check_DASH_bool91258,l417545,or_DASH_oper4404040);
++R.GAS;
return $ret44884489;
};
var $Hanf_arg18324495 = function(anf_arg10594494,anf_arg10444400,anf_arg10554480,check_DASH_bool91258,l417545,or_DASH_oper4404040) {
var $z44994500 = D;
var $f45054506 = function(_) {
return R.isFunction(check_DASH_bool91258.$var)?check_DASH_bool91258.$var.app(l417545,or_DASH_oper4404040,anf_arg10444400,anf_arg10554480,anf_arg10594494):R.ffi.throwNonFunApp(L[563],check_DASH_bool91258.$var,[l417545,or_DASH_oper4404040,anf_arg10444400,anf_arg10554480,anf_arg10594494]);
};
try {
if(--R.GAS > 0) {
$z44994500 = $f45054506();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45054506,
"from":L[563]});
}
} catch($e44974498) {
if(R.isCont($e44974498)) {
var $ss45014502 = {"from":L[563],
"go":function(ann_DASH_check_DASH_temp10424507) {
return $Hann_DASH_check_DASH_temp18314508(ann_DASH_check_DASH_temp10424507);
}};
$e44974498.stack[R.EXN_STACKHEIGHT++] = $ss45014502;
}
if(R.isPyretException($e44974498)) {
$e44974498.pyretStack.push(L[563]);
}
throw $e44974498;
}
var $ret45034504 = $Hann_DASH_check_DASH_temp18314508($z44994500);
++R.GAS;
return $ret45034504;
};
var $Hann_DASH_check_DASH_temp18314508 = function(ann_DASH_check_DASH_temp10424507) {
return ann_DASH_check_DASH_temp10424507;
};
var $Hanf_arg18304414 = function(anf_arg10354413,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4394029,or_DASH_oper4404040) {
var anf_arg10364522 = G(or_DASH_oper4404040,"id-e",L[588]);
var anf_bracket10374524 = G(operands4394029,"first",L[587]);
var anf_arg10384519 = G(anf_bracket10374524,"l",L[586]);
var anf_arg10394520 = G(or_DASH_oper4404040,"id-e",L[585]);
var $z45114512 = D;
var $f45174518 = function(_) {
return R.isFunction(bool_DASH_op_DASH_exn96268.$var)?bool_DASH_op_DASH_exn96268.$var.app(anf_arg10384519,("second"),("or"),anf_arg10394520):R.ffi.throwNonFunApp(L[584],bool_DASH_op_DASH_exn96268.$var,[anf_arg10384519,("second"),("or"),anf_arg10394520]);
};
try {
if(--R.GAS > 0) {
$z45114512 = $f45174518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45174518,
"from":L[584]});
}
} catch($e45094510) {
if(R.isCont($e45094510)) {
var $ss45134514 = {"from":L[584],
"go":function(anf_arg10404521) {
return $Hanf_arg18294523(anf_arg10404521,anf_arg10354413,anf_arg10364522,check_DASH_bool91258,l417545,or_DASH_oper4404040);
}};
$e45094510.stack[R.EXN_STACKHEIGHT++] = $ss45134514;
}
if(R.isPyretException($e45094510)) {
$e45094510.pyretStack.push(L[584]);
}
throw $e45094510;
}
var $ret45154516 = $Hanf_arg18294523($z45114512,anf_arg10354413,anf_arg10364522,check_DASH_bool91258,l417545,or_DASH_oper4404040);
++R.GAS;
return $ret45154516;
};
var $Hanf_arg18294523 = function(anf_arg10404521,anf_arg10354413,anf_arg10364522,check_DASH_bool91258,l417545,or_DASH_oper4404040) {
var $z45274528 = D;
var $f45334534 = function(_) {
return R.isFunction(check_DASH_bool91258.$var)?check_DASH_bool91258.$var.app(l417545,or_DASH_oper4404040,anf_arg10354413,anf_arg10364522,anf_arg10404521):R.ffi.throwNonFunApp(L[566],check_DASH_bool91258.$var,[l417545,or_DASH_oper4404040,anf_arg10354413,anf_arg10364522,anf_arg10404521]);
};
try {
if(--R.GAS > 0) {
$z45274528 = $f45334534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45334534,
"from":L[566]});
}
} catch($e45254526) {
if(R.isCont($e45254526)) {
var $ss45294530 = {"from":L[566],
"go":function(ann_DASH_check_DASH_temp10334535) {
return $Hann_DASH_check_DASH_temp18284536(ann_DASH_check_DASH_temp10334535);
}};
$e45254526.stack[R.EXN_STACKHEIGHT++] = $ss45294530;
}
if(R.isPyretException($e45254526)) {
$e45254526.pyretStack.push(L[566]);
}
throw $e45254526;
}
var $ret45314532 = $Hann_DASH_check_DASH_temp18284536($z45274528);
++R.GAS;
return $ret45314532;
};
var $Hann_DASH_check_DASH_temp18284536 = function(ann_DASH_check_DASH_temp10334535) {
return ann_DASH_check_DASH_temp10334535;
};
var $Hoperands18574056 = function(operands4494055,helper4444042,if_helper9634000) {
var $z45394540 = D;
var $f45454546 = function(_) {
return R.isFunction(helper4444042.$var)?helper4444042.$var.app(operands4494055):R.ffi.throwNonFunApp(L[589],helper4444042.$var,[operands4494055]);
};
try {
if(--R.GAS > 0) {
$z45394540 = $f45454546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45454546,
"from":L[589]});
}
} catch($e45374538) {
if(R.isCont($e45374538)) {
var $ss45414542 = {"from":L[589],
"go":function(cont_tail_arg10294547) {
return $Hcont_tail_arg18564548(cont_tail_arg10294547,if_helper9634000);
}};
$e45374538.stack[R.EXN_STACKHEIGHT++] = $ss45414542;
}
if(R.isPyretException($e45374538)) {
$e45374538.pyretStack.push(L[589]);
}
throw $e45374538;
}
var $ret45434544 = $Hcont_tail_arg18564548($z45394540,if_helper9634000);
++R.GAS;
return $ret45434544;
};
var $Hcont_tail_arg18564548 = function(cont_tail_arg10294547,if_helper9634000) {
if(--R.GAS > 0) {
$z45494550 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg10294547):R.ffi.throwNonFunApp(L[589],if_helper9634000,[cont_tail_arg10294547]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg10294547):R.ffi.throwNonFunApp(L[589],if_helper9634000,[cont_tail_arg10294547]);
},
"from":L[589]});
}
++R.GAS;
return $z45494550;
};
var $Hand_DASH_oper18554069 = function(and_DASH_oper4464068,A113,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,desugar_DASH_expr117310,helper4444042,l417545,list2753,operands4454057) {
var cases_DASH_val564597 = G(operands4454057,"rest",L[597]);
var anf_fun9964561 = G(cases_DASH_val564597,"_match",L[590]);
var anf_obj10054567 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[594],0,arguments);
}
var anf_arg9984594 = G(operands4454057,"first",L[596]);
var $z45864587 = D;
var $f45924593 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(anf_arg9984594):R.ffi.throwNonFunApp(L[595],desugar_DASH_expr117310.$var,[anf_arg9984594]);
};
try {
if(--R.GAS > 0) {
$z45864587 = $f45924593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45924593,
"from":L[595]});
}
} catch($e45844585) {
if(R.isCont($e45844585)) {
var $ss45884589 = {"from":L[595],
"go":function(anf_arg9994595) {
return $Hanf_arg18454596(anf_arg9994595,and_DASH_oper4464068,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
}};
$e45844585.stack[R.EXN_STACKHEIGHT++] = $ss45884589;
}
if(R.isPyretException($e45844585)) {
$e45844585.pyretStack.push(L[595]);
}
throw $e45844585;
}
var $ret45904591 = $Hanf_arg18454596($z45864587,and_DASH_oper4464068,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
++R.GAS;
return $ret45904591;
});
var anf_obj10244568 = R.makeFunction(function($underscore4474569,$underscore4484570) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[591],2,arguments);
}
var anf_arg10074581 = G(operands4454057,"first",L[593]);
var $z45734574 = D;
var $f45794580 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(anf_arg10074581):R.ffi.throwNonFunApp(L[592],desugar_DASH_expr117310.$var,[anf_arg10074581]);
};
try {
if(--R.GAS > 0) {
$z45734574 = $f45794580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45794580,
"from":L[592]});
}
} catch($e45714572) {
if(R.isCont($e45714572)) {
var $ss45754576 = {"from":L[592],
"go":function(anf_arg10084582) {
return $Hanf_arg18534583(anf_arg10084582,A113,and_DASH_oper4464068,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4444042,l417545,list2753,operands4454057);
}};
$e45714572.stack[R.EXN_STACKHEIGHT++] = $ss45754576;
}
if(R.isPyretException($e45714572)) {
$e45714572.pyretStack.push(L[592]);
}
throw $e45714572;
}
var $ret45774578 = $Hanf_arg18534583($z45734574,A113,and_DASH_oper4464068,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4444042,l417545,list2753,operands4454057);
++R.GAS;
return $ret45774578;
});
var anf_arg10254562 = R.makeObject({"empty":anf_obj10054567,
"link":anf_obj10244568});
var anf_arg10274563 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[590],0,arguments);
}
var ann_DASH_check_DASH_temp10264566 = R.throwNoBranchesMatched(L[590],("cases"));
return ann_DASH_check_DASH_temp10264566;
});
var $z45534554 = D;
var $f45594560 = function(_) {
return R.isFunction(anf_fun9964561)?anf_fun9964561.app(anf_arg10254562,anf_arg10274563):R.ffi.throwNonFunApp(L[524],anf_fun9964561,[anf_arg10254562,anf_arg10274563]);
};
try {
if(--R.GAS > 0) {
$z45534554 = $f45594560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45594560,
"from":L[524]});
}
} catch($e45514552) {
if(R.isCont($e45514552)) {
var $ss45554556 = {"from":L[524],
"go":function(ann_DASH_check_DASH_temp9954564) {
return $Hann_DASH_check_DASH_temp18544565(ann_DASH_check_DASH_temp9954564);
}};
$e45514552.stack[R.EXN_STACKHEIGHT++] = $ss45554556;
}
if(R.isPyretException($e45514552)) {
$e45514552.pyretStack.push(L[524]);
}
throw $e45514552;
}
var $ret45574558 = $Hann_DASH_check_DASH_temp18544565($z45534554);
++R.GAS;
return $ret45574558;
};
var $Hann_DASH_check_DASH_temp18544565 = function(ann_DASH_check_DASH_temp9954564) {
return ann_DASH_check_DASH_temp9954564;
};
var $Hanf_arg18534583 = function(anf_arg10084582,A113,and_DASH_oper4464068,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,helper4444042,l417545,list2753,operands4454057) {
var anf_fun10094611 = G(A113,"s-if-else",L[603]);
var anf_fun10104612 = G(list2753,"make",L[602]);
var anf_fun10114613 = G(A113,"s-if-branch",L[601]);
var anf_arg10124610 = G(and_DASH_oper4464068,"id-e",L[600]);
var anf_arg10134608 = G(operands4454057,"rest",L[599]);
var $z46004601 = D;
var $f46064607 = function(_) {
return R.isFunction(helper4444042.$var)?helper4444042.$var.app(anf_arg10134608):R.ffi.throwNonFunApp(L[598],helper4444042.$var,[anf_arg10134608]);
};
try {
if(--R.GAS > 0) {
$z46004601 = $f46064607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46064607,
"from":L[598]});
}
} catch($e45984599) {
if(R.isCont($e45984599)) {
var $ss46024603 = {"from":L[598],
"go":function(anf_arg10144609) {
return $Hanf_arg18524614(anf_arg10144609,A113,and_DASH_oper4464068,anf_arg10084582,anf_arg10124610,anf_fun10094611,anf_fun10104612,anf_fun10114613,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
}};
$e45984599.stack[R.EXN_STACKHEIGHT++] = $ss46024603;
}
if(R.isPyretException($e45984599)) {
$e45984599.pyretStack.push(L[598]);
}
throw $e45984599;
}
var $ret46044605 = $Hanf_arg18524614($z46004601,A113,and_DASH_oper4464068,anf_arg10084582,anf_arg10124610,anf_fun10094611,anf_fun10104612,anf_fun10114613,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
++R.GAS;
return $ret46044605;
};
var $Hanf_arg18524614 = function(anf_arg10144609,A113,and_DASH_oper4464068,anf_arg10084582,anf_arg10124610,anf_fun10094611,anf_fun10104612,anf_fun10114613,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057) {
var $z46174618 = D;
var $f46234624 = function(_) {
return R.isFunction(anf_fun10114613)?anf_fun10114613.app(l417545,anf_arg10124610,anf_arg10144609):R.ffi.throwNonFunApp(L[604],anf_fun10114613,[l417545,anf_arg10124610,anf_arg10144609]);
};
try {
if(--R.GAS > 0) {
$z46174618 = $f46234624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46234624,
"from":L[604]});
}
} catch($e46154616) {
if(R.isCont($e46154616)) {
var $ss46194620 = {"from":L[604],
"go":function(anf_array_val10154625) {
return $Hanf_array_val18514626(anf_array_val10154625,A113,and_DASH_oper4464068,anf_arg10084582,anf_fun10094611,anf_fun10104612,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
}};
$e46154616.stack[R.EXN_STACKHEIGHT++] = $ss46194620;
}
if(R.isPyretException($e46154616)) {
$e46154616.pyretStack.push(L[604]);
}
throw $e46154616;
}
var $ret46214622 = $Hanf_array_val18514626($z46174618,A113,and_DASH_oper4464068,anf_arg10084582,anf_fun10094611,anf_fun10104612,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
++R.GAS;
return $ret46214622;
};
var $Hanf_array_val18514626 = function(anf_array_val10154625,A113,and_DASH_oper4464068,anf_arg10084582,anf_fun10094611,anf_fun10104612,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057) {
var $z46294630 = D;
var $f46354636 = function(_) {
return R.isFunction(anf_fun10104612)?anf_fun10104612.app([anf_array_val10154625]):R.ffi.throwNonFunApp(L[602],anf_fun10104612,[[anf_array_val10154625]]);
};
try {
if(--R.GAS > 0) {
$z46294630 = $f46354636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46354636,
"from":L[602]});
}
} catch($e46274628) {
if(R.isCont($e46274628)) {
var $ss46314632 = {"from":L[602],
"go":function(anf_arg10164637) {
return $Hanf_arg18504638(anf_arg10164637,A113,and_DASH_oper4464068,anf_arg10084582,anf_fun10094611,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
}};
$e46274628.stack[R.EXN_STACKHEIGHT++] = $ss46314632;
}
if(R.isPyretException($e46274628)) {
$e46274628.pyretStack.push(L[602]);
}
throw $e46274628;
}
var $ret46334634 = $Hanf_arg18504638($z46294630,A113,and_DASH_oper4464068,anf_arg10084582,anf_fun10094611,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
++R.GAS;
return $ret46334634;
};
var $Hanf_arg18504638 = function(anf_arg10164637,A113,and_DASH_oper4464068,anf_arg10084582,anf_fun10094611,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057) {
var anf_fun10174649 = G(A113,"s-bool",L[606]);
var $z46414642 = D;
var $f46474648 = function(_) {
return R.isFunction(anf_fun10174649)?anf_fun10174649.app(l417545,(false)):R.ffi.throwNonFunApp(L[605],anf_fun10174649,[l417545,(false)]);
};
try {
if(--R.GAS > 0) {
$z46414642 = $f46474648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46474648,
"from":L[605]});
}
} catch($e46394640) {
if(R.isCont($e46394640)) {
var $ss46434644 = {"from":L[605],
"go":function(anf_arg10184650) {
return $Hanf_arg18494651(anf_arg10184650,and_DASH_oper4464068,anf_arg10084582,anf_arg10164637,anf_fun10094611,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
}};
$e46394640.stack[R.EXN_STACKHEIGHT++] = $ss46434644;
}
if(R.isPyretException($e46394640)) {
$e46394640.pyretStack.push(L[605]);
}
throw $e46394640;
}
var $ret46454646 = $Hanf_arg18494651($z46414642,and_DASH_oper4464068,anf_arg10084582,anf_arg10164637,anf_fun10094611,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
++R.GAS;
return $ret46454646;
};
var $Hanf_arg18494651 = function(anf_arg10184650,and_DASH_oper4464068,anf_arg10084582,anf_arg10164637,anf_fun10094611,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057) {
var $z46544655 = D;
var $f46604661 = function(_) {
return R.isFunction(anf_fun10094611)?anf_fun10094611.app(l417545,anf_arg10164637,anf_arg10184650):R.ffi.throwNonFunApp(L[607],anf_fun10094611,[l417545,anf_arg10164637,anf_arg10184650]);
};
try {
if(--R.GAS > 0) {
$z46544655 = $f46604661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46604661,
"from":L[607]});
}
} catch($e46524653) {
if(R.isCont($e46524653)) {
var $ss46564657 = {"from":L[607],
"go":function(anf_arg10194662) {
return $Hanf_arg18484663(anf_arg10194662,and_DASH_oper4464068,anf_arg10084582,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
}};
$e46524653.stack[R.EXN_STACKHEIGHT++] = $ss46564657;
}
if(R.isPyretException($e46524653)) {
$e46524653.pyretStack.push(L[607]);
}
throw $e46524653;
}
var $ret46584659 = $Hanf_arg18484663($z46544655,and_DASH_oper4464068,anf_arg10084582,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057);
++R.GAS;
return $ret46584659;
};
var $Hanf_arg18484663 = function(anf_arg10194662,and_DASH_oper4464068,anf_arg10084582,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057) {
var anf_bracket10204678 = G(operands4454057,"first",L[611]);
var anf_arg10214674 = G(anf_bracket10204678,"l",L[610]);
var anf_arg10224675 = G(and_DASH_oper4464068,"id-e",L[609]);
var $z46664667 = D;
var $f46724673 = function(_) {
return R.isFunction(bool_DASH_op_DASH_exn96268.$var)?bool_DASH_op_DASH_exn96268.$var.app(anf_arg10214674,("first"),("and"),anf_arg10224675):R.ffi.throwNonFunApp(L[608],bool_DASH_op_DASH_exn96268.$var,[anf_arg10214674,("first"),("and"),anf_arg10224675]);
};
try {
if(--R.GAS > 0) {
$z46664667 = $f46724673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46724673,
"from":L[608]});
}
} catch($e46644665) {
if(R.isCont($e46644665)) {
var $ss46684669 = {"from":L[608],
"go":function(anf_arg10234676) {
return $Hanf_arg18474677(anf_arg10234676,and_DASH_oper4464068,anf_arg10084582,anf_arg10194662,check_DASH_bool91258,l417545);
}};
$e46644665.stack[R.EXN_STACKHEIGHT++] = $ss46684669;
}
if(R.isPyretException($e46644665)) {
$e46644665.pyretStack.push(L[608]);
}
throw $e46644665;
}
var $ret46704671 = $Hanf_arg18474677($z46664667,and_DASH_oper4464068,anf_arg10084582,anf_arg10194662,check_DASH_bool91258,l417545);
++R.GAS;
return $ret46704671;
};
var $Hanf_arg18474677 = function(anf_arg10234676,and_DASH_oper4464068,anf_arg10084582,anf_arg10194662,check_DASH_bool91258,l417545) {
var $z46814682 = D;
var $f46874688 = function(_) {
return R.isFunction(check_DASH_bool91258.$var)?check_DASH_bool91258.$var.app(l417545,and_DASH_oper4464068,anf_arg10084582,anf_arg10194662,anf_arg10234676):R.ffi.throwNonFunApp(L[591],check_DASH_bool91258.$var,[l417545,and_DASH_oper4464068,anf_arg10084582,anf_arg10194662,anf_arg10234676]);
};
try {
if(--R.GAS > 0) {
$z46814682 = $f46874688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46874688,
"from":L[591]});
}
} catch($e46794680) {
if(R.isCont($e46794680)) {
var $ss46834684 = {"from":L[591],
"go":function(ann_DASH_check_DASH_temp10064689) {
return $Hann_DASH_check_DASH_temp18464690(ann_DASH_check_DASH_temp10064689);
}};
$e46794680.stack[R.EXN_STACKHEIGHT++] = $ss46834684;
}
if(R.isPyretException($e46794680)) {
$e46794680.pyretStack.push(L[591]);
}
throw $e46794680;
}
var $ret46854686 = $Hann_DASH_check_DASH_temp18464690($z46814682);
++R.GAS;
return $ret46854686;
};
var $Hann_DASH_check_DASH_temp18464690 = function(ann_DASH_check_DASH_temp10064689) {
return ann_DASH_check_DASH_temp10064689;
};
var $Hanf_arg18454596 = function(anf_arg9994595,and_DASH_oper4464068,bool_DASH_op_DASH_exn96268,check_DASH_bool91258,l417545,operands4454057) {
var anf_arg10004704 = G(and_DASH_oper4464068,"id-e",L[616]);
var anf_bracket10014706 = G(operands4454057,"first",L[615]);
var anf_arg10024701 = G(anf_bracket10014706,"l",L[614]);
var anf_arg10034702 = G(and_DASH_oper4464068,"id-e",L[613]);
var $z46934694 = D;
var $f46994700 = function(_) {
return R.isFunction(bool_DASH_op_DASH_exn96268.$var)?bool_DASH_op_DASH_exn96268.$var.app(anf_arg10024701,("second"),("and"),anf_arg10034702):R.ffi.throwNonFunApp(L[612],bool_DASH_op_DASH_exn96268.$var,[anf_arg10024701,("second"),("and"),anf_arg10034702]);
};
try {
if(--R.GAS > 0) {
$z46934694 = $f46994700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46994700,
"from":L[612]});
}
} catch($e46914692) {
if(R.isCont($e46914692)) {
var $ss46954696 = {"from":L[612],
"go":function(anf_arg10044703) {
return $Hanf_arg18444705(anf_arg10044703,and_DASH_oper4464068,anf_arg10004704,anf_arg9994595,check_DASH_bool91258,l417545);
}};
$e46914692.stack[R.EXN_STACKHEIGHT++] = $ss46954696;
}
if(R.isPyretException($e46914692)) {
$e46914692.pyretStack.push(L[612]);
}
throw $e46914692;
}
var $ret46974698 = $Hanf_arg18444705($z46934694,and_DASH_oper4464068,anf_arg10004704,anf_arg9994595,check_DASH_bool91258,l417545);
++R.GAS;
return $ret46974698;
};
var $Hanf_arg18444705 = function(anf_arg10044703,and_DASH_oper4464068,anf_arg10004704,anf_arg9994595,check_DASH_bool91258,l417545) {
var $z47094710 = D;
var $f47154716 = function(_) {
return R.isFunction(check_DASH_bool91258.$var)?check_DASH_bool91258.$var.app(l417545,and_DASH_oper4464068,anf_arg9994595,anf_arg10004704,anf_arg10044703):R.ffi.throwNonFunApp(L[594],check_DASH_bool91258.$var,[l417545,and_DASH_oper4464068,anf_arg9994595,anf_arg10004704,anf_arg10044703]);
};
try {
if(--R.GAS > 0) {
$z47094710 = $f47154716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47154716,
"from":L[594]});
}
} catch($e47074708) {
if(R.isCont($e47074708)) {
var $ss47114712 = {"from":L[594],
"go":function(ann_DASH_check_DASH_temp9974717) {
return $Hann_DASH_check_DASH_temp18434718(ann_DASH_check_DASH_temp9974717);
}};
$e47074708.stack[R.EXN_STACKHEIGHT++] = $ss47114712;
}
if(R.isPyretException($e47074708)) {
$e47074708.pyretStack.push(L[594]);
}
throw $e47074708;
}
var $ret47134714 = $Hann_DASH_check_DASH_temp18434718($z47094710);
++R.GAS;
return $ret47134714;
};
var $Hann_DASH_check_DASH_temp18434718 = function(ann_DASH_check_DASH_temp9974717) {
return ann_DASH_check_DASH_temp9974717;
};
var $Hoperands18634082 = function(operands4504081,A113,desugar_DASH_expr117310,fold5550,if_helper9634000,list2753) {
var anf_arg9894731 = R.makeFunction(function(acc4514733,f4524734) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[619],2,arguments);
}
var anf_fun9844747 = G(A113,"s-app",L[622]);
var anf_arg9854746 = G(f4524734,"l",L[621]);
var $z47374738 = D;
var $f47434744 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(f4524734):R.ffi.throwNonFunApp(L[620],desugar_DASH_expr117310.$var,[f4524734]);
};
try {
if(--R.GAS > 0) {
$z47374738 = $f47434744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47434744,
"from":L[620]});
}
} catch($e47354736) {
if(R.isCont($e47354736)) {
var $ss47394740 = {"from":L[620],
"go":function(anf_arg9864745) {
return $Hanf_arg18604748(anf_arg9864745,acc4514733,anf_arg9854746,anf_fun9844747,list2753);
}};
$e47354736.stack[R.EXN_STACKHEIGHT++] = $ss47394740;
}
if(R.isPyretException($e47354736)) {
$e47354736.pyretStack.push(L[620]);
}
throw $e47354736;
}
var $ret47414742 = $Hanf_arg18604748($z47374738,acc4514733,anf_arg9854746,anf_fun9844747,list2753);
++R.GAS;
return $ret47414742;
});
var anf_arg9904729 = G(operands4504081,"first",L[618]);
var $z47214722 = D;
var $f47274728 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(anf_arg9904729):R.ffi.throwNonFunApp(L[617],desugar_DASH_expr117310.$var,[anf_arg9904729]);
};
try {
if(--R.GAS > 0) {
$z47214722 = $f47274728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47274728,
"from":L[617]});
}
} catch($e47194720) {
if(R.isCont($e47194720)) {
var $ss47234724 = {"from":L[617],
"go":function(anf_arg9914730) {
return $Hanf_arg18624732(anf_arg9914730,anf_arg9894731,fold5550,if_helper9634000,operands4504081);
}};
$e47194720.stack[R.EXN_STACKHEIGHT++] = $ss47234724;
}
if(R.isPyretException($e47194720)) {
$e47194720.pyretStack.push(L[617]);
}
throw $e47194720;
}
var $ret47254726 = $Hanf_arg18624732($z47214722,anf_arg9894731,fold5550,if_helper9634000,operands4504081);
++R.GAS;
return $ret47254726;
};
var $Hanf_arg18624732 = function(anf_arg9914730,anf_arg9894731,fold5550,if_helper9634000,operands4504081) {
var anf_arg9924759 = G(operands4504081,"rest",L[623]);
var $z47514752 = D;
var $f47574758 = function(_) {
return R.isFunction(fold5550)?fold5550.app(anf_arg9894731,anf_arg9914730,anf_arg9924759):R.ffi.throwNonFunApp(L[619],fold5550,[anf_arg9894731,anf_arg9914730,anf_arg9924759]);
};
try {
if(--R.GAS > 0) {
$z47514752 = $f47574758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47574758,
"from":L[619]});
}
} catch($e47494750) {
if(R.isCont($e47494750)) {
var $ss47534754 = {"from":L[619],
"go":function(cont_tail_arg9934760) {
return $Hcont_tail_arg18614761(cont_tail_arg9934760,if_helper9634000);
}};
$e47494750.stack[R.EXN_STACKHEIGHT++] = $ss47534754;
}
if(R.isPyretException($e47494750)) {
$e47494750.pyretStack.push(L[619]);
}
throw $e47494750;
}
var $ret47554756 = $Hcont_tail_arg18614761($z47514752,if_helper9634000);
++R.GAS;
return $ret47554756;
};
var $Hcont_tail_arg18614761 = function(cont_tail_arg9934760,if_helper9634000) {
if(--R.GAS > 0) {
$z47624763 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9934760):R.ffi.throwNonFunApp(L[619],if_helper9634000,[cont_tail_arg9934760]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9934760):R.ffi.throwNonFunApp(L[619],if_helper9634000,[cont_tail_arg9934760]);
},
"from":L[619]});
}
++R.GAS;
return $z47624763;
};
var $Hanf_arg18604748 = function(anf_arg9864745,acc4514733,anf_arg9854746,anf_fun9844747,list2753) {
var anf_fun9874774 = G(list2753,"make",L[624]);
var $z47664767 = D;
var $f47724773 = function(_) {
return R.isFunction(anf_fun9874774)?anf_fun9874774.app([acc4514733]):R.ffi.throwNonFunApp(L[624],anf_fun9874774,[[acc4514733]]);
};
try {
if(--R.GAS > 0) {
$z47664767 = $f47724773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47724773,
"from":L[624]});
}
} catch($e47644765) {
if(R.isCont($e47644765)) {
var $ss47684769 = {"from":L[624],
"go":function(anf_arg9884775) {
return $Hanf_arg18594776(anf_arg9884775,anf_arg9854746,anf_arg9864745,anf_fun9844747);
}};
$e47644765.stack[R.EXN_STACKHEIGHT++] = $ss47684769;
}
if(R.isPyretException($e47644765)) {
$e47644765.pyretStack.push(L[624]);
}
throw $e47644765;
}
var $ret47704771 = $Hanf_arg18594776($z47664767,anf_arg9854746,anf_arg9864745,anf_fun9844747);
++R.GAS;
return $ret47704771;
};
var $Hanf_arg18594776 = function(anf_arg9884775,anf_arg9854746,anf_arg9864745,anf_fun9844747) {
var $z47794780 = D;
var $f47854786 = function(_) {
return R.isFunction(anf_fun9844747)?anf_fun9844747.app(anf_arg9854746,anf_arg9864745,anf_arg9884775):R.ffi.throwNonFunApp(L[619],anf_fun9844747,[anf_arg9854746,anf_arg9864745,anf_arg9884775]);
};
try {
if(--R.GAS > 0) {
$z47794780 = $f47854786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47854786,
"from":L[619]});
}
} catch($e47774778) {
if(R.isCont($e47774778)) {
var $ss47814782 = {"from":L[619],
"go":function(ann_DASH_check_DASH_temp9834787) {
return $Hann_DASH_check_DASH_temp18584788(ann_DASH_check_DASH_temp9834787);
}};
$e47774778.stack[R.EXN_STACKHEIGHT++] = $ss47814782;
}
if(R.isPyretException($e47774778)) {
$e47774778.pyretStack.push(L[619]);
}
throw $e47774778;
}
var $ret47834784 = $Hann_DASH_check_DASH_temp18584788($z47794780);
++R.GAS;
return $ret47834784;
};
var $Hann_DASH_check_DASH_temp18584788 = function(ann_DASH_check_DASH_temp9834787) {
return ann_DASH_check_DASH_temp9834787;
};
var $Hanf_arg18654094 = function(anf_arg9804093,if_helper9634000,raise10) {
var $z47914792 = D;
var $f47974798 = function(_) {
return R.isFunction(raise10)?raise10.app(anf_arg9804093):R.ffi.throwNonFunApp(L[625],raise10,[anf_arg9804093]);
};
try {
if(--R.GAS > 0) {
$z47914792 = $f47974798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47974798,
"from":L[625]});
}
} catch($e47894790) {
if(R.isCont($e47894790)) {
var $ss47934794 = {"from":L[625],
"go":function(cont_tail_arg9814799) {
return $Hcont_tail_arg18644800(cont_tail_arg9814799,if_helper9634000);
}};
$e47894790.stack[R.EXN_STACKHEIGHT++] = $ss47934794;
}
if(R.isPyretException($e47894790)) {
$e47894790.pyretStack.push(L[625]);
}
throw $e47894790;
}
var $ret47954796 = $Hcont_tail_arg18644800($z47914792,if_helper9634000);
++R.GAS;
return $ret47954796;
};
var $Hcont_tail_arg18644800 = function(cont_tail_arg9814799,if_helper9634000) {
if(--R.GAS > 0) {
$z48014802 = R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9814799):R.ffi.throwNonFunApp(L[625],if_helper9634000,[cont_tail_arg9814799]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9634000)?if_helper9634000.app(cont_tail_arg9814799):R.ffi.throwNonFunApp(L[625],if_helper9634000,[cont_tail_arg9814799]);
},
"from":L[625]});
}
++R.GAS;
return $z48014802;
};
var $Hann_DASH_check_DASH_temp18154134 = function(ann_DASH_check_DASH_temp9624133) {
return ann_DASH_check_DASH_temp9624133;
};
var $Hann_DASH_check_DASH_temp18144147 = function(ann_DASH_check_DASH_temp9614146) {
return ann_DASH_check_DASH_temp9614146;
};
var $Hann_DASH_check_DASH_temp18134160 = function(ann_DASH_check_DASH_temp9604159) {
return ann_DASH_check_DASH_temp9604159;
};
var $Hif_DASH_18124175 = function(if_DASH_494174,collect_DASH_op4263987,exp4304162,list2753,opname4294161,_plus7) {
var if_helper9384815 = R.makeFunction(function(if_helper_arg9394853) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[537],1,arguments);
}
var ann_DASH_check_DASH_temp9364854 = if_helper_arg9394853;
return ann_DASH_check_DASH_temp9364854;
});
var anf_if9424852 = R.isBoolean(if_DASH_494174);
if(R.isPyretTrue(anf_if9424852)) {
if(R.isPyretTrue(if_DASH_494174)) {
var anf_arg9464835 = G(exp4304162,"op",L[630]);
var if_DASH_504830 = R.equiv(anf_arg9464835,opname4294161);
var anf_if9494834 = R.isBoolean(if_DASH_504830);
if(R.isPyretTrue(anf_if9494834)) {
if(R.isPyretTrue(if_DASH_504830)) {
var anf_arg9534813 = G(exp4304162,"left",L[627]);
var $z48054806 = D;
var $f48114812 = function(_) {
return R.isFunction(collect_DASH_op4263987.$var)?collect_DASH_op4263987.$var.app(opname4294161,anf_arg9534813):R.ffi.throwNonFunApp(L[626],collect_DASH_op4263987.$var,[opname4294161,anf_arg9534813]);
};
try {
if(--R.GAS > 0) {
$z48054806 = $f48114812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48114812,
"from":L[626]});
}
} catch($e48034804) {
if(R.isCont($e48034804)) {
var $ss48074808 = {"from":L[626],
"go":function(anf_arg9544814) {
return $Hanf_arg18094816(anf_arg9544814,collect_DASH_op4263987,exp4304162,if_helper9384815,opname4294161,_plus7);
}};
$e48034804.stack[R.EXN_STACKHEIGHT++] = $ss48074808;
}
if(R.isPyretException($e48034804)) {
$e48034804.pyretStack.push(L[626]);
}
throw $e48034804;
}
var $ret48094810 = $Hanf_arg18094816($z48054806,collect_DASH_op4263987,exp4304162,if_helper9384815,opname4294161,_plus7);
++R.GAS;
return $ret48094810;
} else {
var anf_fun9504827 = G(list2753,"make",L[628]);
var $z48194820 = D;
var $f48254826 = function(_) {
return R.isFunction(anf_fun9504827)?anf_fun9504827.app([exp4304162]):R.ffi.throwNonFunApp(L[628],anf_fun9504827,[[exp4304162]]);
};
try {
if(--R.GAS > 0) {
$z48194820 = $f48254826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48254826,
"from":L[628]});
}
} catch($e48174818) {
if(R.isCont($e48174818)) {
var $ss48214822 = {"from":L[628],
"go":function(cont_tail_arg9514828) {
return $Hcont_tail_arg18104829(cont_tail_arg9514828,if_helper9384815);
}};
$e48174818.stack[R.EXN_STACKHEIGHT++] = $ss48214822;
}
if(R.isPyretException($e48174818)) {
$e48174818.pyretStack.push(L[628]);
}
throw $e48174818;
}
var $ret48234824 = $Hcont_tail_arg18104829($z48194820,if_helper9384815);
++R.GAS;
return $ret48234824;
}
} else {
var cont_tail_arg9474833 = R.throwNonBooleanCondition(L[629],("if"),if_DASH_504830);
if(--R.GAS > 0) {
$z48314832 = R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9474833):R.ffi.throwNonFunApp(L[629],if_helper9384815,[cont_tail_arg9474833]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9474833):R.ffi.throwNonFunApp(L[629],if_helper9384815,[cont_tail_arg9474833]);
},
"from":L[629]});
}
++R.GAS;
return $z48314832;
}
} else {
var anf_fun9434846 = G(list2753,"make",L[631]);
var $z48384839 = D;
var $f48444845 = function(_) {
return R.isFunction(anf_fun9434846)?anf_fun9434846.app([exp4304162]):R.ffi.throwNonFunApp(L[631],anf_fun9434846,[[exp4304162]]);
};
try {
if(--R.GAS > 0) {
$z48384839 = $f48444845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48444845,
"from":L[631]});
}
} catch($e48364837) {
if(R.isCont($e48364837)) {
var $ss48404841 = {"from":L[631],
"go":function(cont_tail_arg9444847) {
return $Hcont_tail_arg18114848(cont_tail_arg9444847,if_helper9384815);
}};
$e48364837.stack[R.EXN_STACKHEIGHT++] = $ss48404841;
}
if(R.isPyretException($e48364837)) {
$e48364837.pyretStack.push(L[631]);
}
throw $e48364837;
}
var $ret48424843 = $Hcont_tail_arg18114848($z48384839,if_helper9384815);
++R.GAS;
return $ret48424843;
}
} else {
var cont_tail_arg9404851 = R.throwNonBooleanCondition(L[537],("if"),if_DASH_494174);
if(--R.GAS > 0) {
$z48494850 = R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9404851):R.ffi.throwNonFunApp(L[537],if_helper9384815,[cont_tail_arg9404851]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9404851):R.ffi.throwNonFunApp(L[537],if_helper9384815,[cont_tail_arg9404851]);
},
"from":L[537]});
}
++R.GAS;
return $z48494850;
}
};
var $Hanf_arg18094816 = function(anf_arg9544814,collect_DASH_op4263987,exp4304162,if_helper9384815,opname4294161,_plus7) {
var anf_arg9554865 = G(exp4304162,"right",L[633]);
var $z48574858 = D;
var $f48634864 = function(_) {
return R.isFunction(collect_DASH_op4263987.$var)?collect_DASH_op4263987.$var.app(opname4294161,anf_arg9554865):R.ffi.throwNonFunApp(L[632],collect_DASH_op4263987.$var,[opname4294161,anf_arg9554865]);
};
try {
if(--R.GAS > 0) {
$z48574858 = $f48634864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48634864,
"from":L[632]});
}
} catch($e48554856) {
if(R.isCont($e48554856)) {
var $ss48594860 = {"from":L[632],
"go":function(anf_arg9564866) {
return $Hanf_arg18084867(anf_arg9564866,anf_arg9544814,if_helper9384815,_plus7);
}};
$e48554856.stack[R.EXN_STACKHEIGHT++] = $ss48594860;
}
if(R.isPyretException($e48554856)) {
$e48554856.pyretStack.push(L[632]);
}
throw $e48554856;
}
var $ret48614862 = $Hanf_arg18084867($z48574858,anf_arg9544814,if_helper9384815,_plus7);
++R.GAS;
return $ret48614862;
};
var $Hanf_arg18084867 = function(anf_arg9564866,anf_arg9544814,if_helper9384815,_plus7) {
var $z48704871 = D;
var $f48764877 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg9544814,anf_arg9564866):R.ffi.throwNonFunApp(L[634],_plus7,[anf_arg9544814,anf_arg9564866]);
};
try {
if(--R.GAS > 0) {
$z48704871 = $f48764877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48764877,
"from":L[634]});
}
} catch($e48684869) {
if(R.isCont($e48684869)) {
var $ss48724873 = {"from":L[634],
"go":function(cont_tail_arg9574878) {
return $Hcont_tail_arg18074879(cont_tail_arg9574878,if_helper9384815);
}};
$e48684869.stack[R.EXN_STACKHEIGHT++] = $ss48724873;
}
if(R.isPyretException($e48684869)) {
$e48684869.pyretStack.push(L[634]);
}
throw $e48684869;
}
var $ret48744875 = $Hcont_tail_arg18074879($z48704871,if_helper9384815);
++R.GAS;
return $ret48744875;
};
var $Hcont_tail_arg18074879 = function(cont_tail_arg9574878,if_helper9384815) {
if(--R.GAS > 0) {
$z48804881 = R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9574878):R.ffi.throwNonFunApp(L[634],if_helper9384815,[cont_tail_arg9574878]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9574878):R.ffi.throwNonFunApp(L[634],if_helper9384815,[cont_tail_arg9574878]);
},
"from":L[634]});
}
++R.GAS;
return $z48804881;
};
var $Hcont_tail_arg18104829 = function(cont_tail_arg9514828,if_helper9384815) {
if(--R.GAS > 0) {
$z48824883 = R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9514828):R.ffi.throwNonFunApp(L[628],if_helper9384815,[cont_tail_arg9514828]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9514828):R.ffi.throwNonFunApp(L[628],if_helper9384815,[cont_tail_arg9514828]);
},
"from":L[628]});
}
++R.GAS;
return $z48824883;
};
var $Hcont_tail_arg18114848 = function(cont_tail_arg9444847,if_helper9384815) {
if(--R.GAS > 0) {
$z48844885 = R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9444847):R.ffi.throwNonFunApp(L[631],if_helper9384815,[cont_tail_arg9444847]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper9384815)?if_helper9384815.app(cont_tail_arg9444847):R.ffi.throwNonFunApp(L[631],if_helper9384815,[cont_tail_arg9444847]);
},
"from":L[631]});
}
++R.GAS;
return $z48844885;
};
var $Hanf_arg18064190 = function(anf_arg9294187,anf_fun9274188,anf_fun9284189,desugar_DASH_expr117310,fld4284176,l417545,list2753,right420548,thunk4243983) {
var $z48884889 = D;
var $f48944895 = function(_) {
return R.isFunction(anf_fun9284189)?anf_fun9284189.app(l417545,anf_arg9294187,fld4284176):R.ffi.throwNonFunApp(L[635],anf_fun9284189,[l417545,anf_arg9294187,fld4284176]);
};
try {
if(--R.GAS > 0) {
$z48884889 = $f48944895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48944895,
"from":L[635]});
}
} catch($e48864887) {
if(R.isCont($e48864887)) {
var $ss48904891 = {"from":L[635],
"go":function(anf_arg9304896) {
return $Hanf_arg18054897(anf_arg9304896,anf_fun9274188,desugar_DASH_expr117310,l417545,list2753,right420548,thunk4243983);
}};
$e48864887.stack[R.EXN_STACKHEIGHT++] = $ss48904891;
}
if(R.isPyretException($e48864887)) {
$e48864887.pyretStack.push(L[635]);
}
throw $e48864887;
}
var $ret48924893 = $Hanf_arg18054897($z48884889,anf_fun9274188,desugar_DASH_expr117310,l417545,list2753,right420548,thunk4243983);
++R.GAS;
return $ret48924893;
};
var $Hanf_arg18054897 = function(anf_arg9304896,anf_fun9274188,desugar_DASH_expr117310,l417545,list2753,right420548,thunk4243983) {
var anf_fun9314909 = G(list2753,"make",L[637]);
var $z49004901 = D;
var $f49064907 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(right420548):R.ffi.throwNonFunApp(L[636],desugar_DASH_expr117310.$var,[right420548]);
};
try {
if(--R.GAS > 0) {
$z49004901 = $f49064907();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49064907,
"from":L[636]});
}
} catch($e48984899) {
if(R.isCont($e48984899)) {
var $ss49024903 = {"from":L[636],
"go":function(anf_arg9324908) {
return $Hanf_arg18044910(anf_arg9324908,anf_arg9304896,anf_fun9274188,anf_fun9314909,l417545,thunk4243983);
}};
$e48984899.stack[R.EXN_STACKHEIGHT++] = $ss49024903;
}
if(R.isPyretException($e48984899)) {
$e48984899.pyretStack.push(L[636]);
}
throw $e48984899;
}
var $ret49044905 = $Hanf_arg18044910($z49004901,anf_arg9304896,anf_fun9274188,anf_fun9314909,l417545,thunk4243983);
++R.GAS;
return $ret49044905;
};
var $Hanf_arg18044910 = function(anf_arg9324908,anf_arg9304896,anf_fun9274188,anf_fun9314909,l417545,thunk4243983) {
var $z49134914 = D;
var $f49194920 = function(_) {
return R.isFunction(thunk4243983.$var)?thunk4243983.$var.app(anf_arg9324908):R.ffi.throwNonFunApp(L[638],thunk4243983.$var,[anf_arg9324908]);
};
try {
if(--R.GAS > 0) {
$z49134914 = $f49194920();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49194920,
"from":L[638]});
}
} catch($e49114912) {
if(R.isCont($e49114912)) {
var $ss49154916 = {"from":L[638],
"go":function(anf_array_val9334921) {
return $Hanf_array_val18034922(anf_array_val9334921,anf_arg9304896,anf_fun9274188,anf_fun9314909,l417545);
}};
$e49114912.stack[R.EXN_STACKHEIGHT++] = $ss49154916;
}
if(R.isPyretException($e49114912)) {
$e49114912.pyretStack.push(L[638]);
}
throw $e49114912;
}
var $ret49174918 = $Hanf_array_val18034922($z49134914,anf_arg9304896,anf_fun9274188,anf_fun9314909,l417545);
++R.GAS;
return $ret49174918;
};
var $Hanf_array_val18034922 = function(anf_array_val9334921,anf_arg9304896,anf_fun9274188,anf_fun9314909,l417545) {
var $z49254926 = D;
var $f49314932 = function(_) {
return R.isFunction(anf_fun9314909)?anf_fun9314909.app([anf_array_val9334921]):R.ffi.throwNonFunApp(L[637],anf_fun9314909,[[anf_array_val9334921]]);
};
try {
if(--R.GAS > 0) {
$z49254926 = $f49314932();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49314932,
"from":L[637]});
}
} catch($e49234924) {
if(R.isCont($e49234924)) {
var $ss49274928 = {"from":L[637],
"go":function(anf_arg9344933) {
return $Hanf_arg18024934(anf_arg9344933,anf_arg9304896,anf_fun9274188,l417545);
}};
$e49234924.stack[R.EXN_STACKHEIGHT++] = $ss49274928;
}
if(R.isPyretException($e49234924)) {
$e49234924.pyretStack.push(L[637]);
}
throw $e49234924;
}
var $ret49294930 = $Hanf_arg18024934($z49254926,anf_arg9304896,anf_fun9274188,l417545);
++R.GAS;
return $ret49294930;
};
var $Hanf_arg18024934 = function(anf_arg9344933,anf_arg9304896,anf_fun9274188,l417545) {
var $z49374938 = D;
var $f49434944 = function(_) {
return R.isFunction(anf_fun9274188)?anf_fun9274188.app(l417545,anf_arg9304896,anf_arg9344933):R.ffi.throwNonFunApp(L[539],anf_fun9274188,[l417545,anf_arg9304896,anf_arg9344933]);
};
try {
if(--R.GAS > 0) {
$z49374938 = $f49434944();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49434944,
"from":L[539]});
}
} catch($e49354936) {
if(R.isCont($e49354936)) {
var $ss49394940 = {"from":L[539],
"go":function(ann_DASH_check_DASH_temp9264945) {
return $Hann_DASH_check_DASH_temp18014946(ann_DASH_check_DASH_temp9264945);
}};
$e49354936.stack[R.EXN_STACKHEIGHT++] = $ss49394940;
}
if(R.isPyretException($e49354936)) {
$e49354936.pyretStack.push(L[539]);
}
throw $e49354936;
}
var $ret49414942 = $Hann_DASH_check_DASH_temp18014946($z49374938);
++R.GAS;
return $ret49414942;
};
var $Hann_DASH_check_DASH_temp18014946 = function(ann_DASH_check_DASH_temp9264945) {
return ann_DASH_check_DASH_temp9264945;
};
var $Hanf_arg18004205 = function(anf_arg9174203,A113,anf_fun9154204,e4274191,l417545,list2753,none6355) {
var anf_fun9184957 = G(list2753,"make",L[639]);
var $z49494950 = D;
var $f49554956 = function(_) {
return R.isFunction(anf_fun9184957)?anf_fun9184957.app([]):R.ffi.throwNonFunApp(L[639],anf_fun9184957,[[]]);
};
try {
if(--R.GAS > 0) {
$z49494950 = $f49554956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49554956,
"from":L[639]});
}
} catch($e49474948) {
if(R.isCont($e49474948)) {
var $ss49514952 = {"from":L[639],
"go":function(anf_arg9194958) {
return $Hanf_arg17994959(anf_arg9194958,A113,anf_arg9174203,anf_fun9154204,e4274191,l417545,list2753,none6355);
}};
$e49474948.stack[R.EXN_STACKHEIGHT++] = $ss49514952;
}
if(R.isPyretException($e49474948)) {
$e49474948.pyretStack.push(L[639]);
}
throw $e49474948;
}
var $ret49534954 = $Hanf_arg17994959($z49494950,A113,anf_arg9174203,anf_fun9154204,e4274191,l417545,list2753,none6355);
++R.GAS;
return $ret49534954;
};
var $Hanf_arg17994959 = function(anf_arg9194958,A113,anf_arg9174203,anf_fun9154204,e4274191,l417545,list2753,none6355) {
var anf_arg9204972 = G(A113,"a-blank",L[642]);
var anf_fun9214973 = G(A113,"s-block",L[641]);
var anf_fun9224970 = G(list2753,"make",L[640]);
var $z49624963 = D;
var $f49684969 = function(_) {
return R.isFunction(anf_fun9224970)?anf_fun9224970.app([e4274191]):R.ffi.throwNonFunApp(L[640],anf_fun9224970,[[e4274191]]);
};
try {
if(--R.GAS > 0) {
$z49624963 = $f49684969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49684969,
"from":L[640]});
}
} catch($e49604961) {
if(R.isCont($e49604961)) {
var $ss49644965 = {"from":L[640],
"go":function(anf_arg9234971) {
return $Hanf_arg17984974(anf_arg9234971,anf_arg9174203,anf_arg9194958,anf_arg9204972,anf_fun9154204,anf_fun9214973,l417545,none6355);
}};
$e49604961.stack[R.EXN_STACKHEIGHT++] = $ss49644965;
}
if(R.isPyretException($e49604961)) {
$e49604961.pyretStack.push(L[640]);
}
throw $e49604961;
}
var $ret49664967 = $Hanf_arg17984974($z49624963,anf_arg9174203,anf_arg9194958,anf_arg9204972,anf_fun9154204,anf_fun9214973,l417545,none6355);
++R.GAS;
return $ret49664967;
};
var $Hanf_arg17984974 = function(anf_arg9234971,anf_arg9174203,anf_arg9194958,anf_arg9204972,anf_fun9154204,anf_fun9214973,l417545,none6355) {
var $z49774978 = D;
var $f49834984 = function(_) {
return R.isFunction(anf_fun9214973)?anf_fun9214973.app(l417545,anf_arg9234971):R.ffi.throwNonFunApp(L[643],anf_fun9214973,[l417545,anf_arg9234971]);
};
try {
if(--R.GAS > 0) {
$z49774978 = $f49834984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49834984,
"from":L[643]});
}
} catch($e49754976) {
if(R.isCont($e49754976)) {
var $ss49794980 = {"from":L[643],
"go":function(anf_arg9244985) {
return $Hanf_arg17974986(anf_arg9244985,anf_arg9174203,anf_arg9194958,anf_arg9204972,anf_fun9154204,l417545,none6355);
}};
$e49754976.stack[R.EXN_STACKHEIGHT++] = $ss49794980;
}
if(R.isPyretException($e49754976)) {
$e49754976.pyretStack.push(L[643]);
}
throw $e49754976;
}
var $ret49814982 = $Hanf_arg17974986($z49774978,anf_arg9174203,anf_arg9194958,anf_arg9204972,anf_fun9154204,l417545,none6355);
++R.GAS;
return $ret49814982;
};
var $Hanf_arg17974986 = function(anf_arg9244985,anf_arg9174203,anf_arg9194958,anf_arg9204972,anf_fun9154204,l417545,none6355) {
var $z49894990 = D;
var $f49954996 = function(_) {
return R.isFunction(anf_fun9154204)?anf_fun9154204.app(l417545,anf_arg9174203,anf_arg9194958,anf_arg9204972,(""),anf_arg9244985,none6355):R.ffi.throwNonFunApp(L[543],anf_fun9154204,[l417545,anf_arg9174203,anf_arg9194958,anf_arg9204972,(""),anf_arg9244985,none6355]);
};
try {
if(--R.GAS > 0) {
$z49894990 = $f49954996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49954996,
"from":L[543]});
}
} catch($e49874988) {
if(R.isCont($e49874988)) {
var $ss49914992 = {"from":L[543],
"go":function(ann_DASH_check_DASH_temp9144997) {
return $Hann_DASH_check_DASH_temp17964998(ann_DASH_check_DASH_temp9144997);
}};
$e49874988.stack[R.EXN_STACKHEIGHT++] = $ss49914992;
}
if(R.isPyretException($e49874988)) {
$e49874988.pyretStack.push(L[543]);
}
throw $e49874988;
}
var $ret49934994 = $Hann_DASH_check_DASH_temp17964998($z49894990);
++R.GAS;
return $ret49934994;
};
var $Hann_DASH_check_DASH_temp17964998 = function(ann_DASH_check_DASH_temp9144997) {
return ann_DASH_check_DASH_temp9144997;
};
var $Hanf_arg17954218 = function(anf_arg9044217,A113,desugar_DASH_expr117310,ds_DASH_curry_DASH_binop113302,field4214206,gid90256,l417545,list2753,right420548) {
var $z50015002 = D;
var $f50075008 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(right420548):R.ffi.throwNonFunApp(L[644],desugar_DASH_expr117310.$var,[right420548]);
};
try {
if(--R.GAS > 0) {
$z50015002 = $f50075008();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50075008,
"from":L[644]});
}
} catch($e49995000) {
if(R.isCont($e49995000)) {
var $ss50035004 = {"from":L[644],
"go":function(anf_arg9055009) {
return $Hanf_arg17945010(anf_arg9055009,A113,anf_arg9044217,ds_DASH_curry_DASH_binop113302,field4214206,gid90256,l417545,list2753);
}};
$e49995000.stack[R.EXN_STACKHEIGHT++] = $ss50035004;
}
if(R.isPyretException($e49995000)) {
$e49995000.pyretStack.push(L[644]);
}
throw $e49995000;
}
var $ret50055006 = $Hanf_arg17945010($z50015002,A113,anf_arg9044217,ds_DASH_curry_DASH_binop113302,field4214206,gid90256,l417545,list2753);
++R.GAS;
return $ret50055006;
};
var $Hanf_arg17945010 = function(anf_arg9055009,A113,anf_arg9044217,ds_DASH_curry_DASH_binop113302,field4214206,gid90256,l417545,list2753) {
var anf_arg9115021 = R.makeFunction(function(e14225024,e24235025) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[645],2,arguments);
}
var anf_fun9075037 = G(A113,"s-app",L[647]);
var $z50285029 = D;
var $f50345035 = function(_) {
return R.isFunction(gid90256.$var)?gid90256.$var.app(l417545,field4214206):R.ffi.throwNonFunApp(L[646],gid90256.$var,[l417545,field4214206]);
};
try {
if(--R.GAS > 0) {
$z50285029 = $f50345035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50345035,
"from":L[646]});
}
} catch($e50265027) {
if(R.isCont($e50265027)) {
var $ss50305031 = {"from":L[646],
"go":function(anf_arg9085036) {
return $Hanf_arg17925038(anf_arg9085036,anf_fun9075037,e14225024,e24235025,l417545,list2753);
}};
$e50265027.stack[R.EXN_STACKHEIGHT++] = $ss50305031;
}
if(R.isPyretException($e50265027)) {
$e50265027.pyretStack.push(L[646]);
}
throw $e50265027;
}
var $ret50325033 = $Hanf_arg17925038($z50285029,anf_fun9075037,e14225024,e24235025,l417545,list2753);
++R.GAS;
return $ret50325033;
});
var $z50135014 = D;
var $f50195020 = function(_) {
return R.isFunction(ds_DASH_curry_DASH_binop113302.$var)?ds_DASH_curry_DASH_binop113302.$var.app(l417545,anf_arg9044217,anf_arg9055009,anf_arg9115021):R.ffi.throwNonFunApp(L[546],ds_DASH_curry_DASH_binop113302.$var,[l417545,anf_arg9044217,anf_arg9055009,anf_arg9115021]);
};
try {
if(--R.GAS > 0) {
$z50135014 = $f50195020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50195020,
"from":L[546]});
}
} catch($e50115012) {
if(R.isCont($e50115012)) {
var $ss50155016 = {"from":L[546],
"go":function(ann_DASH_check_DASH_temp9035022) {
return $Hann_DASH_check_DASH_temp17935023(ann_DASH_check_DASH_temp9035022);
}};
$e50115012.stack[R.EXN_STACKHEIGHT++] = $ss50155016;
}
if(R.isPyretException($e50115012)) {
$e50115012.pyretStack.push(L[546]);
}
throw $e50115012;
}
var $ret50175018 = $Hann_DASH_check_DASH_temp17935023($z50135014);
++R.GAS;
return $ret50175018;
};
var $Hann_DASH_check_DASH_temp17935023 = function(ann_DASH_check_DASH_temp9035022) {
return ann_DASH_check_DASH_temp9035022;
};
var $Hanf_arg17925038 = function(anf_arg9085036,anf_fun9075037,e14225024,e24235025,l417545,list2753) {
var anf_fun9095049 = G(list2753,"make",L[648]);
var $z50415042 = D;
var $f50475048 = function(_) {
return R.isFunction(anf_fun9095049)?anf_fun9095049.app([e14225024,e24235025]):R.ffi.throwNonFunApp(L[648],anf_fun9095049,[[e14225024,e24235025]]);
};
try {
if(--R.GAS > 0) {
$z50415042 = $f50475048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50475048,
"from":L[648]});
}
} catch($e50395040) {
if(R.isCont($e50395040)) {
var $ss50435044 = {"from":L[648],
"go":function(anf_arg9105050) {
return $Hanf_arg17915051(anf_arg9105050,anf_arg9085036,anf_fun9075037,l417545);
}};
$e50395040.stack[R.EXN_STACKHEIGHT++] = $ss50435044;
}
if(R.isPyretException($e50395040)) {
$e50395040.pyretStack.push(L[648]);
}
throw $e50395040;
}
var $ret50455046 = $Hanf_arg17915051($z50415042,anf_arg9085036,anf_fun9075037,l417545);
++R.GAS;
return $ret50455046;
};
var $Hanf_arg17915051 = function(anf_arg9105050,anf_arg9085036,anf_fun9075037,l417545) {
var $z50545055 = D;
var $f50605061 = function(_) {
return R.isFunction(anf_fun9075037)?anf_fun9075037.app(l417545,anf_arg9085036,anf_arg9105050):R.ffi.throwNonFunApp(L[645],anf_fun9075037,[l417545,anf_arg9085036,anf_arg9105050]);
};
try {
if(--R.GAS > 0) {
$z50545055 = $f50605061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50605061,
"from":L[645]});
}
} catch($e50525053) {
if(R.isCont($e50525053)) {
var $ss50565057 = {"from":L[645],
"go":function(ann_DASH_check_DASH_temp9065062) {
return $Hann_DASH_check_DASH_temp17905063(ann_DASH_check_DASH_temp9065062);
}};
$e50525053.stack[R.EXN_STACKHEIGHT++] = $ss50565057;
}
if(R.isPyretException($e50525053)) {
$e50525053.pyretStack.push(L[645]);
}
throw $e50525053;
}
var $ret50585059 = $Hann_DASH_check_DASH_temp17905063($z50545055);
++R.GAS;
return $ret50585059;
};
var $Hann_DASH_check_DASH_temp17905063 = function(ann_DASH_check_DASH_temp9065062) {
return ann_DASH_check_DASH_temp9065062;
};
var $Hanf_bracket1789579 = function(anf_bracket884578,A113,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,list2753,none6355) {
var anf_fun8855074 = G(anf_bracket884578,"map",L[650]);
var $z50665067 = D;
var $f50725073 = function(_) {
return R.isFunction(anf_fun8855074)?anf_fun8855074.app(desugar_DASH_expr117310.$var):R.ffi.throwNonFunApp(L[649],anf_fun8855074,[desugar_DASH_expr117310.$var]);
};
try {
if(--R.GAS > 0) {
$z50665067 = $f50725073();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50725073,
"from":L[649]});
}
} catch($e50645065) {
if(R.isCont($e50645065)) {
var $ss50685069 = {"from":L[649],
"go":function(values4155075) {
return $Hvalues17885076(values4155075,A113,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,list2753,none6355);
}};
$e50645065.stack[R.EXN_STACKHEIGHT++] = $ss50685069;
}
if(R.isPyretException($e50645065)) {
$e50645065.pyretStack.push(L[649]);
}
throw $e50645065;
}
var $ret50705071 = $Hvalues17885076($z50665067,A113,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,list2753,none6355);
++R.GAS;
return $ret50705071;
};
var $Hvalues17885076 = function(values4155075,A113,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,list2753,none6355) {
var anf_fun8865089 = G(A113,"s-lam",L[652]);
var anf_fun8875087 = G(list2753,"make",L[651]);
var $z50795080 = D;
var $f50855086 = function(_) {
return R.isFunction(anf_fun8875087)?anf_fun8875087.app([]):R.ffi.throwNonFunApp(L[651],anf_fun8875087,[[]]);
};
try {
if(--R.GAS > 0) {
$z50795080 = $f50855086();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50855086,
"from":L[651]});
}
} catch($e50775078) {
if(R.isCont($e50775078)) {
var $ss50815082 = {"from":L[651],
"go":function(anf_arg8885088) {
return $Hanf_arg17875090(anf_arg8885088,A113,anf_fun8865089,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
}};
$e50775078.stack[R.EXN_STACKHEIGHT++] = $ss50815082;
}
if(R.isPyretException($e50775078)) {
$e50775078.pyretStack.push(L[651]);
}
throw $e50775078;
}
var $ret50835084 = $Hanf_arg17875090($z50795080,A113,anf_fun8865089,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
++R.GAS;
return $ret50835084;
};
var $Hanf_arg17875090 = function(anf_arg8885088,A113,anf_fun8865089,ann413564,bindings412563,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075) {
var anf_fun8895101 = G(bindings412563,"map",L[655]);
var anf_arg8915102 = R.makeFunction(function(recv_DASH_485105) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[654],1,arguments);
}
var ann_DASH_check_DASH_temp8905106 = G(recv_DASH_485105,"bind",L[654]);
return ann_DASH_check_DASH_temp8905106;
});
var $z50935094 = D;
var $f50995100 = function(_) {
return R.isFunction(anf_fun8895101)?anf_fun8895101.app(anf_arg8915102):R.ffi.throwNonFunApp(L[653],anf_fun8895101,[anf_arg8915102]);
};
try {
if(--R.GAS > 0) {
$z50935094 = $f50995100();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50995100,
"from":L[653]});
}
} catch($e50915092) {
if(R.isCont($e50915092)) {
var $ss50955096 = {"from":L[653],
"go":function(anf_bracket8925103) {
return $Hanf_bracket17865104(anf_bracket8925103,A113,anf_arg8885088,anf_fun8865089,ann413564,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
}};
$e50915092.stack[R.EXN_STACKHEIGHT++] = $ss50955096;
}
if(R.isPyretException($e50915092)) {
$e50915092.pyretStack.push(L[653]);
}
throw $e50915092;
}
var $ret50975098 = $Hanf_bracket17865104($z50935094,A113,anf_arg8885088,anf_fun8865089,ann413564,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
++R.GAS;
return $ret50975098;
};
var $Hanf_bracket17865104 = function(anf_bracket8925103,A113,anf_arg8885088,anf_fun8865089,ann413564,body414565,desugar_DASH_ann98272,desugar_DASH_bind116308,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075) {
var anf_fun8935117 = G(anf_bracket8925103,"map",L[657]);
var $z51095110 = D;
var $f51155116 = function(_) {
return R.isFunction(anf_fun8935117)?anf_fun8935117.app(desugar_DASH_bind116308.$var):R.ffi.throwNonFunApp(L[656],anf_fun8935117,[desugar_DASH_bind116308.$var]);
};
try {
if(--R.GAS > 0) {
$z51095110 = $f51155116();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51155116,
"from":L[656]});
}
} catch($e51075108) {
if(R.isCont($e51075108)) {
var $ss51115112 = {"from":L[656],
"go":function(anf_arg8945118) {
return $Hanf_arg17855119(anf_arg8945118,A113,anf_arg8885088,anf_fun8865089,ann413564,body414565,desugar_DASH_ann98272,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
}};
$e51075108.stack[R.EXN_STACKHEIGHT++] = $ss51115112;
}
if(R.isPyretException($e51075108)) {
$e51075108.pyretStack.push(L[656]);
}
throw $e51075108;
}
var $ret51135114 = $Hanf_arg17855119($z51095110,A113,anf_arg8885088,anf_fun8865089,ann413564,body414565,desugar_DASH_ann98272,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
++R.GAS;
return $ret51135114;
};
var $Hanf_arg17855119 = function(anf_arg8945118,A113,anf_arg8885088,anf_fun8865089,ann413564,body414565,desugar_DASH_ann98272,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075) {
var $z51225123 = D;
var $f51285129 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ann413564):R.ffi.throwNonFunApp(L[658],desugar_DASH_ann98272.$var,[ann413564]);
};
try {
if(--R.GAS > 0) {
$z51225123 = $f51285129();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51285129,
"from":L[658]});
}
} catch($e51205121) {
if(R.isCont($e51205121)) {
var $ss51245125 = {"from":L[658],
"go":function(anf_arg8955130) {
return $Hanf_arg17845131(anf_arg8955130,A113,anf_arg8885088,anf_arg8945118,anf_fun8865089,body414565,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
}};
$e51205121.stack[R.EXN_STACKHEIGHT++] = $ss51245125;
}
if(R.isPyretException($e51205121)) {
$e51205121.pyretStack.push(L[658]);
}
throw $e51205121;
}
var $ret51265127 = $Hanf_arg17845131($z51225123,A113,anf_arg8885088,anf_arg8945118,anf_fun8865089,body414565,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
++R.GAS;
return $ret51265127;
};
var $Hanf_arg17845131 = function(anf_arg8955130,A113,anf_arg8885088,anf_arg8945118,anf_fun8865089,body414565,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075) {
var $z51345135 = D;
var $f51405141 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(body414565):R.ffi.throwNonFunApp(L[659],desugar_DASH_expr117310.$var,[body414565]);
};
try {
if(--R.GAS > 0) {
$z51345135 = $f51405141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51405141,
"from":L[659]});
}
} catch($e51325133) {
if(R.isCont($e51325133)) {
var $ss51365137 = {"from":L[659],
"go":function(anf_arg8965142) {
return $Hanf_arg17835143(anf_arg8965142,A113,anf_arg8885088,anf_arg8945118,anf_arg8955130,anf_fun8865089,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
}};
$e51325133.stack[R.EXN_STACKHEIGHT++] = $ss51365137;
}
if(R.isPyretException($e51325133)) {
$e51325133.pyretStack.push(L[659]);
}
throw $e51325133;
}
var $ret51385139 = $Hanf_arg17835143($z51345135,A113,anf_arg8885088,anf_arg8945118,anf_arg8955130,anf_fun8865089,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075);
++R.GAS;
return $ret51385139;
};
var $Hanf_arg17835143 = function(anf_arg8965142,A113,anf_arg8885088,anf_arg8945118,anf_arg8955130,anf_fun8865089,desugar_DASH_expr117310,iter411562,l410561,link3152,none6355,values4155075) {
var $z51465147 = D;
var $f51525153 = function(_) {
return R.isFunction(anf_fun8865089)?anf_fun8865089.app(l410561,anf_arg8885088,anf_arg8945118,anf_arg8955130,(""),anf_arg8965142,none6355):R.ffi.throwNonFunApp(L[660],anf_fun8865089,[l410561,anf_arg8885088,anf_arg8945118,anf_arg8955130,(""),anf_arg8965142,none6355]);
};
try {
if(--R.GAS > 0) {
$z51465147 = $f51525153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51525153,
"from":L[660]});
}
} catch($e51445145) {
if(R.isCont($e51445145)) {
var $ss51485149 = {"from":L[660],
"go":function(the_DASH_function4165154) {
return $Hthe_DASH_function17825155(the_DASH_function4165154,A113,desugar_DASH_expr117310,iter411562,l410561,link3152,values4155075);
}};
$e51445145.stack[R.EXN_STACKHEIGHT++] = $ss51485149;
}
if(R.isPyretException($e51445145)) {
$e51445145.pyretStack.push(L[660]);
}
throw $e51445145;
}
var $ret51505151 = $Hthe_DASH_function17825155($z51465147,A113,desugar_DASH_expr117310,iter411562,l410561,link3152,values4155075);
++R.GAS;
return $ret51505151;
};
var $Hthe_DASH_function17825155 = function(the_DASH_function4165154,A113,desugar_DASH_expr117310,iter411562,l410561,link3152,values4155075) {
var anf_fun8975167 = G(A113,"s-app",L[662]);
var $z51585159 = D;
var $f51645165 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(iter411562):R.ffi.throwNonFunApp(L[661],desugar_DASH_expr117310.$var,[iter411562]);
};
try {
if(--R.GAS > 0) {
$z51585159 = $f51645165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51645165,
"from":L[661]});
}
} catch($e51565157) {
if(R.isCont($e51565157)) {
var $ss51605161 = {"from":L[661],
"go":function(anf_arg8985166) {
return $Hanf_arg17815168(anf_arg8985166,anf_fun8975167,l410561,link3152,the_DASH_function4165154,values4155075);
}};
$e51565157.stack[R.EXN_STACKHEIGHT++] = $ss51605161;
}
if(R.isPyretException($e51565157)) {
$e51565157.pyretStack.push(L[661]);
}
throw $e51565157;
}
var $ret51625163 = $Hanf_arg17815168($z51585159,anf_fun8975167,l410561,link3152,the_DASH_function4165154,values4155075);
++R.GAS;
return $ret51625163;
};
var $Hanf_arg17815168 = function(anf_arg8985166,anf_fun8975167,l410561,link3152,the_DASH_function4165154,values4155075) {
var $z51715172 = D;
var $f51775178 = function(_) {
return R.isFunction(link3152)?link3152.app(the_DASH_function4165154,values4155075):R.ffi.throwNonFunApp(L[663],link3152,[the_DASH_function4165154,values4155075]);
};
try {
if(--R.GAS > 0) {
$z51715172 = $f51775178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51775178,
"from":L[663]});
}
} catch($e51695170) {
if(R.isCont($e51695170)) {
var $ss51735174 = {"from":L[663],
"go":function(anf_arg8995179) {
return $Hanf_arg17805180(anf_arg8995179,anf_arg8985166,anf_fun8975167,l410561);
}};
$e51695170.stack[R.EXN_STACKHEIGHT++] = $ss51735174;
}
if(R.isPyretException($e51695170)) {
$e51695170.pyretStack.push(L[663]);
}
throw $e51695170;
}
var $ret51755176 = $Hanf_arg17805180($z51715172,anf_arg8985166,anf_fun8975167,l410561);
++R.GAS;
return $ret51755176;
};
var $Hanf_arg17805180 = function(anf_arg8995179,anf_arg8985166,anf_fun8975167,l410561) {
var $z51835184 = D;
var $f51895190 = function(_) {
return R.isFunction(anf_fun8975167)?anf_fun8975167.app(l410561,anf_arg8985166,anf_arg8995179):R.ffi.throwNonFunApp(L[52],anf_fun8975167,[l410561,anf_arg8985166,anf_arg8995179]);
};
try {
if(--R.GAS > 0) {
$z51835184 = $f51895190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51895190,
"from":L[52]});
}
} catch($e51815182) {
if(R.isCont($e51815182)) {
var $ss51855186 = {"from":L[52],
"go":function(ann_DASH_check_DASH_temp8805191) {
return $Hann_DASH_check_DASH_temp17795192(ann_DASH_check_DASH_temp8805191);
}};
$e51815182.stack[R.EXN_STACKHEIGHT++] = $ss51855186;
}
if(R.isPyretException($e51815182)) {
$e51815182.pyretStack.push(L[52]);
}
throw $e51815182;
}
var $ret51875188 = $Hann_DASH_check_DASH_temp17795192($z51835184);
++R.GAS;
return $ret51875188;
};
var $Hann_DASH_check_DASH_temp17795192 = function(ann_DASH_check_DASH_temp8805191) {
return ann_DASH_check_DASH_temp8805191;
};
var $Hanf_arg1778597 = function(anf_arg876595,anf_fun875596,desugar_DASH_member109294,fields409584,l407582) {
var anf_fun8775203 = G(fields409584,"map",L[665]);
var $z51955196 = D;
var $f52015202 = function(_) {
return R.isFunction(anf_fun8775203)?anf_fun8775203.app(desugar_DASH_member109294.$var):R.ffi.throwNonFunApp(L[664],anf_fun8775203,[desugar_DASH_member109294.$var]);
};
try {
if(--R.GAS > 0) {
$z51955196 = $f52015202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52015202,
"from":L[664]});
}
} catch($e51935194) {
if(R.isCont($e51935194)) {
var $ss51975198 = {"from":L[664],
"go":function(anf_arg8785204) {
return $Hanf_arg17775205(anf_arg8785204,anf_arg876595,anf_fun875596,l407582);
}};
$e51935194.stack[R.EXN_STACKHEIGHT++] = $ss51975198;
}
if(R.isPyretException($e51935194)) {
$e51935194.pyretStack.push(L[664]);
}
throw $e51935194;
}
var $ret51995200 = $Hanf_arg17775205($z51955196,anf_arg876595,anf_fun875596,l407582);
++R.GAS;
return $ret51995200;
};
var $Hanf_arg17775205 = function(anf_arg8785204,anf_arg876595,anf_fun875596,l407582) {
var $z52085209 = D;
var $f52145215 = function(_) {
return R.isFunction(anf_fun875596)?anf_fun875596.app(l407582,anf_arg876595,anf_arg8785204):R.ffi.throwNonFunApp(L[56],anf_fun875596,[l407582,anf_arg876595,anf_arg8785204]);
};
try {
if(--R.GAS > 0) {
$z52085209 = $f52145215();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52145215,
"from":L[56]});
}
} catch($e52065207) {
if(R.isCont($e52065207)) {
var $ss52105211 = {"from":L[56],
"go":function(ann_DASH_check_DASH_temp8745216) {
return $Hann_DASH_check_DASH_temp17765217(ann_DASH_check_DASH_temp8745216);
}};
$e52065207.stack[R.EXN_STACKHEIGHT++] = $ss52105211;
}
if(R.isPyretException($e52065207)) {
$e52065207.pyretStack.push(L[56]);
}
throw $e52065207;
}
var $ret52125213 = $Hann_DASH_check_DASH_temp17765217($z52085209);
++R.GAS;
return $ret52125213;
};
var $Hann_DASH_check_DASH_temp17765217 = function(ann_DASH_check_DASH_temp8745216) {
return ann_DASH_check_DASH_temp8745216;
};
var $Hann_DASH_check_DASH_temp1775613 = function(ann_DASH_check_DASH_temp871612) {
return ann_DASH_check_DASH_temp871612;
};
var $Hanf_arg1774629 = function(anf_arg869627,anf_fun868628,id402615,l401614) {
var $z52205221 = D;
var $f52265227 = function(_) {
return R.isFunction(anf_fun868628)?anf_fun868628.app(l401614,id402615,anf_arg869627):R.ffi.throwNonFunApp(L[61],anf_fun868628,[l401614,id402615,anf_arg869627]);
};
try {
if(--R.GAS > 0) {
$z52205221 = $f52265227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52265227,
"from":L[61]});
}
} catch($e52185219) {
if(R.isCont($e52185219)) {
var $ss52225223 = {"from":L[61],
"go":function(ann_DASH_check_DASH_temp8675228) {
return $Hann_DASH_check_DASH_temp17735229(ann_DASH_check_DASH_temp8675228);
}};
$e52185219.stack[R.EXN_STACKHEIGHT++] = $ss52225223;
}
if(R.isPyretException($e52185219)) {
$e52185219.pyretStack.push(L[61]);
}
throw $e52185219;
}
var $ret52245225 = $Hann_DASH_check_DASH_temp17735229($z52205221);
++R.GAS;
return $ret52245225;
};
var $Hann_DASH_check_DASH_temp17735229 = function(ann_DASH_check_DASH_temp8675228) {
return ann_DASH_check_DASH_temp8675228;
};
var $Hanf_arg1772646 = function(anf_arg862645,_else400634,branches399633,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,desugar_DASH_expr117310,l396630,typ397631) {
var anf_fun8635240 = G(branches399633,"map",L[667]);
var $z52325233 = D;
var $f52385239 = function(_) {
return R.isFunction(anf_fun8635240)?anf_fun8635240.app(desugar_DASH_case_DASH_branch106288.$var):R.ffi.throwNonFunApp(L[666],anf_fun8635240,[desugar_DASH_case_DASH_branch106288.$var]);
};
try {
if(--R.GAS > 0) {
$z52325233 = $f52385239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52385239,
"from":L[666]});
}
} catch($e52305231) {
if(R.isCont($e52305231)) {
var $ss52345235 = {"from":L[666],
"go":function(anf_arg8645241) {
return $Hanf_arg17715242(anf_arg8645241,_else400634,anf_arg862645,desugar_DASH_cases107290,desugar_DASH_expr117310,l396630,typ397631);
}};
$e52305231.stack[R.EXN_STACKHEIGHT++] = $ss52345235;
}
if(R.isPyretException($e52305231)) {
$e52305231.pyretStack.push(L[666]);
}
throw $e52305231;
}
var $ret52365237 = $Hanf_arg17715242($z52325233,_else400634,anf_arg862645,desugar_DASH_cases107290,desugar_DASH_expr117310,l396630,typ397631);
++R.GAS;
return $ret52365237;
};
var $Hanf_arg17715242 = function(anf_arg8645241,_else400634,anf_arg862645,desugar_DASH_cases107290,desugar_DASH_expr117310,l396630,typ397631) {
var $z52455246 = D;
var $f52515252 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(_else400634):R.ffi.throwNonFunApp(L[668],desugar_DASH_expr117310.$var,[_else400634]);
};
try {
if(--R.GAS > 0) {
$z52455246 = $f52515252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52515252,
"from":L[668]});
}
} catch($e52435244) {
if(R.isCont($e52435244)) {
var $ss52475248 = {"from":L[668],
"go":function(anf_arg8655253) {
return $Hanf_arg17705254(anf_arg8655253,anf_arg862645,anf_arg8645241,desugar_DASH_cases107290,l396630,typ397631);
}};
$e52435244.stack[R.EXN_STACKHEIGHT++] = $ss52475248;
}
if(R.isPyretException($e52435244)) {
$e52435244.pyretStack.push(L[668]);
}
throw $e52435244;
}
var $ret52495250 = $Hanf_arg17705254($z52455246,anf_arg862645,anf_arg8645241,desugar_DASH_cases107290,l396630,typ397631);
++R.GAS;
return $ret52495250;
};
var $Hanf_arg17705254 = function(anf_arg8655253,anf_arg862645,anf_arg8645241,desugar_DASH_cases107290,l396630,typ397631) {
var $z52575258 = D;
var $f52635264 = function(_) {
return R.isFunction(desugar_DASH_cases107290.$var)?desugar_DASH_cases107290.$var.app(l396630,typ397631,anf_arg862645,anf_arg8645241,anf_arg8655253):R.ffi.throwNonFunApp(L[64],desugar_DASH_cases107290.$var,[l396630,typ397631,anf_arg862645,anf_arg8645241,anf_arg8655253]);
};
try {
if(--R.GAS > 0) {
$z52575258 = $f52635264();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52635264,
"from":L[64]});
}
} catch($e52555256) {
if(R.isCont($e52555256)) {
var $ss52595260 = {"from":L[64],
"go":function(ann_DASH_check_DASH_temp8615265) {
return $Hann_DASH_check_DASH_temp17695266(ann_DASH_check_DASH_temp8615265);
}};
$e52555256.stack[R.EXN_STACKHEIGHT++] = $ss52595260;
}
if(R.isPyretException($e52555256)) {
$e52555256.pyretStack.push(L[64]);
}
throw $e52555256;
}
var $ret52615262 = $Hann_DASH_check_DASH_temp17695266($z52575258);
++R.GAS;
return $ret52615262;
};
var $Hann_DASH_check_DASH_temp17695266 = function(ann_DASH_check_DASH_temp8615265) {
return ann_DASH_check_DASH_temp8615265;
};
var $Hanf_arg1768662 = function(anf_arg852661,A113,branches395650,desugar_DASH_case_DASH_branch106288,desugar_DASH_cases107290,l392647,list2753,no_DASH_branches_DASH_exn92260,typ393648) {
var anf_fun8535277 = G(branches395650,"map",L[670]);
var $z52695270 = D;
var $f52755276 = function(_) {
return R.isFunction(anf_fun8535277)?anf_fun8535277.app(desugar_DASH_case_DASH_branch106288.$var):R.ffi.throwNonFunApp(L[669],anf_fun8535277,[desugar_DASH_case_DASH_branch106288.$var]);
};
try {
if(--R.GAS > 0) {
$z52695270 = $f52755276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52755276,
"from":L[669]});
}
} catch($e52675268) {
if(R.isCont($e52675268)) {
var $ss52715272 = {"from":L[669],
"go":function(anf_arg8545278) {
return $Hanf_arg17675279(anf_arg8545278,A113,anf_arg852661,desugar_DASH_cases107290,l392647,list2753,no_DASH_branches_DASH_exn92260,typ393648);
}};
$e52675268.stack[R.EXN_STACKHEIGHT++] = $ss52715272;
}
if(R.isPyretException($e52675268)) {
$e52675268.pyretStack.push(L[669]);
}
throw $e52675268;
}
var $ret52735274 = $Hanf_arg17675279($z52695270,A113,anf_arg852661,desugar_DASH_cases107290,l392647,list2753,no_DASH_branches_DASH_exn92260,typ393648);
++R.GAS;
return $ret52735274;
};
var $Hanf_arg17675279 = function(anf_arg8545278,A113,anf_arg852661,desugar_DASH_cases107290,l392647,list2753,no_DASH_branches_DASH_exn92260,typ393648) {
var anf_fun8555291 = G(A113,"s-block",L[673]);
var anf_fun8565292 = G(list2753,"make",L[672]);
var $z52825283 = D;
var $f52885289 = function(_) {
return R.isFunction(no_DASH_branches_DASH_exn92260.$var)?no_DASH_branches_DASH_exn92260.$var.app(l392647,("cases")):R.ffi.throwNonFunApp(L[671],no_DASH_branches_DASH_exn92260.$var,[l392647,("cases")]);
};
try {
if(--R.GAS > 0) {
$z52825283 = $f52885289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52885289,
"from":L[671]});
}
} catch($e52805281) {
if(R.isCont($e52805281)) {
var $ss52845285 = {"from":L[671],
"go":function(anf_array_val8575290) {
return $Hanf_array_val17665293(anf_array_val8575290,anf_arg852661,anf_arg8545278,anf_fun8555291,anf_fun8565292,desugar_DASH_cases107290,l392647,typ393648);
}};
$e52805281.stack[R.EXN_STACKHEIGHT++] = $ss52845285;
}
if(R.isPyretException($e52805281)) {
$e52805281.pyretStack.push(L[671]);
}
throw $e52805281;
}
var $ret52865287 = $Hanf_array_val17665293($z52825283,anf_arg852661,anf_arg8545278,anf_fun8555291,anf_fun8565292,desugar_DASH_cases107290,l392647,typ393648);
++R.GAS;
return $ret52865287;
};
var $Hanf_array_val17665293 = function(anf_array_val8575290,anf_arg852661,anf_arg8545278,anf_fun8555291,anf_fun8565292,desugar_DASH_cases107290,l392647,typ393648) {
var $z52965297 = D;
var $f53025303 = function(_) {
return R.isFunction(anf_fun8565292)?anf_fun8565292.app([anf_array_val8575290]):R.ffi.throwNonFunApp(L[672],anf_fun8565292,[[anf_array_val8575290]]);
};
try {
if(--R.GAS > 0) {
$z52965297 = $f53025303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53025303,
"from":L[672]});
}
} catch($e52945295) {
if(R.isCont($e52945295)) {
var $ss52985299 = {"from":L[672],
"go":function(anf_arg8585304) {
return $Hanf_arg17655305(anf_arg8585304,anf_arg852661,anf_arg8545278,anf_fun8555291,desugar_DASH_cases107290,l392647,typ393648);
}};
$e52945295.stack[R.EXN_STACKHEIGHT++] = $ss52985299;
}
if(R.isPyretException($e52945295)) {
$e52945295.pyretStack.push(L[672]);
}
throw $e52945295;
}
var $ret53005301 = $Hanf_arg17655305($z52965297,anf_arg852661,anf_arg8545278,anf_fun8555291,desugar_DASH_cases107290,l392647,typ393648);
++R.GAS;
return $ret53005301;
};
var $Hanf_arg17655305 = function(anf_arg8585304,anf_arg852661,anf_arg8545278,anf_fun8555291,desugar_DASH_cases107290,l392647,typ393648) {
var $z53085309 = D;
var $f53145315 = function(_) {
return R.isFunction(anf_fun8555291)?anf_fun8555291.app(l392647,anf_arg8585304):R.ffi.throwNonFunApp(L[674],anf_fun8555291,[l392647,anf_arg8585304]);
};
try {
if(--R.GAS > 0) {
$z53085309 = $f53145315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53145315,
"from":L[674]});
}
} catch($e53065307) {
if(R.isCont($e53065307)) {
var $ss53105311 = {"from":L[674],
"go":function(anf_arg8595316) {
return $Hanf_arg17645317(anf_arg8595316,anf_arg852661,anf_arg8545278,desugar_DASH_cases107290,l392647,typ393648);
}};
$e53065307.stack[R.EXN_STACKHEIGHT++] = $ss53105311;
}
if(R.isPyretException($e53065307)) {
$e53065307.pyretStack.push(L[674]);
}
throw $e53065307;
}
var $ret53125313 = $Hanf_arg17645317($z53085309,anf_arg852661,anf_arg8545278,desugar_DASH_cases107290,l392647,typ393648);
++R.GAS;
return $ret53125313;
};
var $Hanf_arg17645317 = function(anf_arg8595316,anf_arg852661,anf_arg8545278,desugar_DASH_cases107290,l392647,typ393648) {
var $z53205321 = D;
var $f53265327 = function(_) {
return R.isFunction(desugar_DASH_cases107290.$var)?desugar_DASH_cases107290.$var.app(l392647,typ393648,anf_arg852661,anf_arg8545278,anf_arg8595316):R.ffi.throwNonFunApp(L[66],desugar_DASH_cases107290.$var,[l392647,typ393648,anf_arg852661,anf_arg8545278,anf_arg8595316]);
};
try {
if(--R.GAS > 0) {
$z53205321 = $f53265327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53265327,
"from":L[66]});
}
} catch($e53185319) {
if(R.isCont($e53185319)) {
var $ss53225323 = {"from":L[66],
"go":function(ann_DASH_check_DASH_temp8515328) {
return $Hann_DASH_check_DASH_temp17635329(ann_DASH_check_DASH_temp8515328);
}};
$e53185319.stack[R.EXN_STACKHEIGHT++] = $ss53225323;
}
if(R.isPyretException($e53185319)) {
$e53185319.pyretStack.push(L[66]);
}
throw $e53185319;
}
var $ret53245325 = $Hann_DASH_check_DASH_temp17635329($z53205321);
++R.GAS;
return $ret53245325;
};
var $Hann_DASH_check_DASH_temp17635329 = function(ann_DASH_check_DASH_temp8515328) {
return ann_DASH_check_DASH_temp8515328;
};
var $Hann_DASH_check_DASH_temp1762677 = function(ann_DASH_check_DASH_temp849676) {
return ann_DASH_check_DASH_temp849676;
};
var $Hanf_array_val1761693 = function(anf_array_val845690,anf_fun843691,anf_fun844692,branches388679,desugar_DASH_if105286,l387678) {
var $z53325333 = D;
var $f53385339 = function(_) {
return R.isFunction(anf_fun844692)?anf_fun844692.app([anf_array_val845690]):R.ffi.throwNonFunApp(L[71],anf_fun844692,[[anf_array_val845690]]);
};
try {
if(--R.GAS > 0) {
$z53325333 = $f53385339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53385339,
"from":L[71]});
}
} catch($e53305331) {
if(R.isCont($e53305331)) {
var $ss53345335 = {"from":L[71],
"go":function(anf_arg8465340) {
return $Hanf_arg17605341(anf_arg8465340,anf_fun843691,branches388679,desugar_DASH_if105286,l387678);
}};
$e53305331.stack[R.EXN_STACKHEIGHT++] = $ss53345335;
}
if(R.isPyretException($e53305331)) {
$e53305331.pyretStack.push(L[71]);
}
throw $e53305331;
}
var $ret53365337 = $Hanf_arg17605341($z53325333,anf_fun843691,branches388679,desugar_DASH_if105286,l387678);
++R.GAS;
return $ret53365337;
};
var $Hanf_arg17605341 = function(anf_arg8465340,anf_fun843691,branches388679,desugar_DASH_if105286,l387678) {
var $z53445345 = D;
var $f53505351 = function(_) {
return R.isFunction(anf_fun843691)?anf_fun843691.app(l387678,anf_arg8465340):R.ffi.throwNonFunApp(L[675],anf_fun843691,[l387678,anf_arg8465340]);
};
try {
if(--R.GAS > 0) {
$z53445345 = $f53505351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53505351,
"from":L[675]});
}
} catch($e53425343) {
if(R.isCont($e53425343)) {
var $ss53465347 = {"from":L[675],
"go":function(anf_arg8475352) {
return $Hanf_arg17595353(anf_arg8475352,branches388679,desugar_DASH_if105286,l387678);
}};
$e53425343.stack[R.EXN_STACKHEIGHT++] = $ss53465347;
}
if(R.isPyretException($e53425343)) {
$e53425343.pyretStack.push(L[675]);
}
throw $e53425343;
}
var $ret53485349 = $Hanf_arg17595353($z53445345,branches388679,desugar_DASH_if105286,l387678);
++R.GAS;
return $ret53485349;
};
var $Hanf_arg17595353 = function(anf_arg8475352,branches388679,desugar_DASH_if105286,l387678) {
var $z53565357 = D;
var $f53625363 = function(_) {
return R.isFunction(desugar_DASH_if105286.$var)?desugar_DASH_if105286.$var.app(l387678,branches388679,anf_arg8475352):R.ffi.throwNonFunApp(L[69],desugar_DASH_if105286.$var,[l387678,branches388679,anf_arg8475352]);
};
try {
if(--R.GAS > 0) {
$z53565357 = $f53625363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53625363,
"from":L[69]});
}
} catch($e53545355) {
if(R.isCont($e53545355)) {
var $ss53585359 = {"from":L[69],
"go":function(ann_DASH_check_DASH_temp8425364) {
return $Hann_DASH_check_DASH_temp17585365(ann_DASH_check_DASH_temp8425364);
}};
$e53545355.stack[R.EXN_STACKHEIGHT++] = $ss53585359;
}
if(R.isPyretException($e53545355)) {
$e53545355.pyretStack.push(L[69]);
}
throw $e53545355;
}
var $ret53605361 = $Hann_DASH_check_DASH_temp17585365($z53565357);
++R.GAS;
return $ret53605361;
};
var $Hann_DASH_check_DASH_temp17585365 = function(ann_DASH_check_DASH_temp8425364) {
return ann_DASH_check_DASH_temp8425364;
};
var $Hann_DASH_check_DASH_temp1757708 = function(ann_DASH_check_DASH_temp840707) {
return ann_DASH_check_DASH_temp840707;
};
var $Hanf_array_val1756724 = function(anf_array_val836721,anf_fun834722,anf_fun835723,branches383710,desugar_DASH_if105286,l382709) {
var $z53685369 = D;
var $f53745375 = function(_) {
return R.isFunction(anf_fun835723)?anf_fun835723.app([anf_array_val836721]):R.ffi.throwNonFunApp(L[76],anf_fun835723,[[anf_array_val836721]]);
};
try {
if(--R.GAS > 0) {
$z53685369 = $f53745375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53745375,
"from":L[76]});
}
} catch($e53665367) {
if(R.isCont($e53665367)) {
var $ss53705371 = {"from":L[76],
"go":function(anf_arg8375376) {
return $Hanf_arg17555377(anf_arg8375376,anf_fun834722,branches383710,desugar_DASH_if105286,l382709);
}};
$e53665367.stack[R.EXN_STACKHEIGHT++] = $ss53705371;
}
if(R.isPyretException($e53665367)) {
$e53665367.pyretStack.push(L[76]);
}
throw $e53665367;
}
var $ret53725373 = $Hanf_arg17555377($z53685369,anf_fun834722,branches383710,desugar_DASH_if105286,l382709);
++R.GAS;
return $ret53725373;
};
var $Hanf_arg17555377 = function(anf_arg8375376,anf_fun834722,branches383710,desugar_DASH_if105286,l382709) {
var $z53805381 = D;
var $f53865387 = function(_) {
return R.isFunction(anf_fun834722)?anf_fun834722.app(l382709,anf_arg8375376):R.ffi.throwNonFunApp(L[676],anf_fun834722,[l382709,anf_arg8375376]);
};
try {
if(--R.GAS > 0) {
$z53805381 = $f53865387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53865387,
"from":L[676]});
}
} catch($e53785379) {
if(R.isCont($e53785379)) {
var $ss53825383 = {"from":L[676],
"go":function(anf_arg8385388) {
return $Hanf_arg17545389(anf_arg8385388,branches383710,desugar_DASH_if105286,l382709);
}};
$e53785379.stack[R.EXN_STACKHEIGHT++] = $ss53825383;
}
if(R.isPyretException($e53785379)) {
$e53785379.pyretStack.push(L[676]);
}
throw $e53785379;
}
var $ret53845385 = $Hanf_arg17545389($z53805381,branches383710,desugar_DASH_if105286,l382709);
++R.GAS;
return $ret53845385;
};
var $Hanf_arg17545389 = function(anf_arg8385388,branches383710,desugar_DASH_if105286,l382709) {
var $z53925393 = D;
var $f53985399 = function(_) {
return R.isFunction(desugar_DASH_if105286.$var)?desugar_DASH_if105286.$var.app(l382709,branches383710,anf_arg8385388):R.ffi.throwNonFunApp(L[74],desugar_DASH_if105286.$var,[l382709,branches383710,anf_arg8385388]);
};
try {
if(--R.GAS > 0) {
$z53925393 = $f53985399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53985399,
"from":L[74]});
}
} catch($e53905391) {
if(R.isCont($e53905391)) {
var $ss53945395 = {"from":L[74],
"go":function(ann_DASH_check_DASH_temp8335400) {
return $Hann_DASH_check_DASH_temp17535401(ann_DASH_check_DASH_temp8335400);
}};
$e53905391.stack[R.EXN_STACKHEIGHT++] = $ss53945395;
}
if(R.isPyretException($e53905391)) {
$e53905391.pyretStack.push(L[74]);
}
throw $e53905391;
}
var $ret53965397 = $Hann_DASH_check_DASH_temp17535401($z53925393);
++R.GAS;
return $ret53965397;
};
var $Hann_DASH_check_DASH_temp17535401 = function(ann_DASH_check_DASH_temp8335400) {
return ann_DASH_check_DASH_temp8335400;
};
var $Htest_DASH_id1752739 = function(test_DASH_id381738,A113,body380727,bool_DASH_exn95266,check_DASH_bool91258,desugar_DASH_expr117310,gid90256,l378725,list2753,test379726) {
var $z54045405 = D;
var $f54105411 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(test379726):R.ffi.throwNonFunApp(L[677],desugar_DASH_expr117310.$var,[test379726]);
};
try {
if(--R.GAS > 0) {
$z54045405 = $f54105411();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54105411,
"from":L[677]});
}
} catch($e54025403) {
if(R.isCont($e54025403)) {
var $ss54065407 = {"from":L[677],
"go":function(anf_arg8105412) {
return $Hanf_arg17515413(anf_arg8105412,A113,body380727,bool_DASH_exn95266,check_DASH_bool91258,desugar_DASH_expr117310,gid90256,l378725,list2753,test_DASH_id381738,test379726);
}};
$e54025403.stack[R.EXN_STACKHEIGHT++] = $ss54065407;
}
if(R.isPyretException($e54025403)) {
$e54025403.pyretStack.push(L[677]);
}
throw $e54025403;
}
var $ret54085409 = $Hanf_arg17515413($z54045405,A113,body380727,bool_DASH_exn95266,check_DASH_bool91258,desugar_DASH_expr117310,gid90256,l378725,list2753,test_DASH_id381738,test379726);
++R.GAS;
return $ret54085409;
};
var $Hanf_arg17515413 = function(anf_arg8105412,A113,body380727,bool_DASH_exn95266,check_DASH_bool91258,desugar_DASH_expr117310,gid90256,l378725,list2753,test_DASH_id381738,test379726) {
var anf_fun8115426 = G(A113,"s-if-else",L[684]);
var anf_fun8125427 = G(list2753,"make",L[683]);
var anf_fun8135428 = G(A113,"s-if-branch",L[682]);
var anf_arg8145425 = G(test_DASH_id381738,"id-e",L[681]);
var anf_fun8155429 = G(A113,"s-block",L[680]);
var anf_fun8165430 = G(list2753,"make",L[679]);
var $z54165417 = D;
var $f54225423 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(body380727):R.ffi.throwNonFunApp(L[678],desugar_DASH_expr117310.$var,[body380727]);
};
try {
if(--R.GAS > 0) {
$z54165417 = $f54225423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54225423,
"from":L[678]});
}
} catch($e54145415) {
if(R.isCont($e54145415)) {
var $ss54185419 = {"from":L[678],
"go":function(anf_array_val8175424) {
return $Hanf_array_val17505431(anf_array_val8175424,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,anf_fun8165430,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
}};
$e54145415.stack[R.EXN_STACKHEIGHT++] = $ss54185419;
}
if(R.isPyretException($e54145415)) {
$e54145415.pyretStack.push(L[678]);
}
throw $e54145415;
}
var $ret54205421 = $Hanf_array_val17505431($z54165417,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,anf_fun8165430,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
++R.GAS;
return $ret54205421;
};
var $Hanf_array_val17505431 = function(anf_array_val8175424,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,anf_fun8165430,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726) {
var $z54345435 = D;
var $f54405441 = function(_) {
return R.isFunction(gid90256.$var)?gid90256.$var.app(l378725,("nothing")):R.ffi.throwNonFunApp(L[685],gid90256.$var,[l378725,("nothing")]);
};
try {
if(--R.GAS > 0) {
$z54345435 = $f54405441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54405441,
"from":L[685]});
}
} catch($e54325433) {
if(R.isCont($e54325433)) {
var $ss54365437 = {"from":L[685],
"go":function(anf_array_val8185442) {
return $Hanf_array_val17495443(anf_array_val8185442,A113,anf_arg8105412,anf_arg8145425,anf_array_val8175424,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,anf_fun8165430,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
}};
$e54325433.stack[R.EXN_STACKHEIGHT++] = $ss54365437;
}
if(R.isPyretException($e54325433)) {
$e54325433.pyretStack.push(L[685]);
}
throw $e54325433;
}
var $ret54385439 = $Hanf_array_val17495443($z54345435,A113,anf_arg8105412,anf_arg8145425,anf_array_val8175424,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,anf_fun8165430,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
++R.GAS;
return $ret54385439;
};
var $Hanf_array_val17495443 = function(anf_array_val8185442,A113,anf_arg8105412,anf_arg8145425,anf_array_val8175424,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,anf_fun8165430,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726) {
var $z54465447 = D;
var $f54525453 = function(_) {
return R.isFunction(anf_fun8165430)?anf_fun8165430.app([anf_array_val8175424,anf_array_val8185442]):R.ffi.throwNonFunApp(L[679],anf_fun8165430,[[anf_array_val8175424,anf_array_val8185442]]);
};
try {
if(--R.GAS > 0) {
$z54465447 = $f54525453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54525453,
"from":L[679]});
}
} catch($e54445445) {
if(R.isCont($e54445445)) {
var $ss54485449 = {"from":L[679],
"go":function(anf_arg8195454) {
return $Hanf_arg17485455(anf_arg8195454,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
}};
$e54445445.stack[R.EXN_STACKHEIGHT++] = $ss54485449;
}
if(R.isPyretException($e54445445)) {
$e54445445.pyretStack.push(L[679]);
}
throw $e54445445;
}
var $ret54505451 = $Hanf_arg17485455($z54465447,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
++R.GAS;
return $ret54505451;
};
var $Hanf_arg17485455 = function(anf_arg8195454,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,anf_fun8155429,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726) {
var $z54585459 = D;
var $f54645465 = function(_) {
return R.isFunction(anf_fun8155429)?anf_fun8155429.app(l378725,anf_arg8195454):R.ffi.throwNonFunApp(L[686],anf_fun8155429,[l378725,anf_arg8195454]);
};
try {
if(--R.GAS > 0) {
$z54585459 = $f54645465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54645465,
"from":L[686]});
}
} catch($e54565457) {
if(R.isCont($e54565457)) {
var $ss54605461 = {"from":L[686],
"go":function(anf_arg8205466) {
return $Hanf_arg17475467(anf_arg8205466,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
}};
$e54565457.stack[R.EXN_STACKHEIGHT++] = $ss54605461;
}
if(R.isPyretException($e54565457)) {
$e54565457.pyretStack.push(L[686]);
}
throw $e54565457;
}
var $ret54625463 = $Hanf_arg17475467($z54585459,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
++R.GAS;
return $ret54625463;
};
var $Hanf_arg17475467 = function(anf_arg8205466,A113,anf_arg8105412,anf_arg8145425,anf_fun8115426,anf_fun8125427,anf_fun8135428,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726) {
var $z54705471 = D;
var $f54765477 = function(_) {
return R.isFunction(anf_fun8135428)?anf_fun8135428.app(l378725,anf_arg8145425,anf_arg8205466):R.ffi.throwNonFunApp(L[687],anf_fun8135428,[l378725,anf_arg8145425,anf_arg8205466]);
};
try {
if(--R.GAS > 0) {
$z54705471 = $f54765477();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54765477,
"from":L[687]});
}
} catch($e54685469) {
if(R.isCont($e54685469)) {
var $ss54725473 = {"from":L[687],
"go":function(anf_array_val8215478) {
return $Hanf_array_val17465479(anf_array_val8215478,A113,anf_arg8105412,anf_fun8115426,anf_fun8125427,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
}};
$e54685469.stack[R.EXN_STACKHEIGHT++] = $ss54725473;
}
if(R.isPyretException($e54685469)) {
$e54685469.pyretStack.push(L[687]);
}
throw $e54685469;
}
var $ret54745475 = $Hanf_array_val17465479($z54705471,A113,anf_arg8105412,anf_fun8115426,anf_fun8125427,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
++R.GAS;
return $ret54745475;
};
var $Hanf_array_val17465479 = function(anf_array_val8215478,A113,anf_arg8105412,anf_fun8115426,anf_fun8125427,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726) {
var $z54825483 = D;
var $f54885489 = function(_) {
return R.isFunction(anf_fun8125427)?anf_fun8125427.app([anf_array_val8215478]):R.ffi.throwNonFunApp(L[683],anf_fun8125427,[[anf_array_val8215478]]);
};
try {
if(--R.GAS > 0) {
$z54825483 = $f54885489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54885489,
"from":L[683]});
}
} catch($e54805481) {
if(R.isCont($e54805481)) {
var $ss54845485 = {"from":L[683],
"go":function(anf_arg8225490) {
return $Hanf_arg17455491(anf_arg8225490,A113,anf_arg8105412,anf_fun8115426,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
}};
$e54805481.stack[R.EXN_STACKHEIGHT++] = $ss54845485;
}
if(R.isPyretException($e54805481)) {
$e54805481.pyretStack.push(L[683]);
}
throw $e54805481;
}
var $ret54865487 = $Hanf_arg17455491($z54825483,A113,anf_arg8105412,anf_fun8115426,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726);
++R.GAS;
return $ret54865487;
};
var $Hanf_arg17455491 = function(anf_arg8225490,A113,anf_arg8105412,anf_fun8115426,bool_DASH_exn95266,check_DASH_bool91258,gid90256,l378725,list2753,test_DASH_id381738,test379726) {
var anf_fun8235503 = G(A113,"s-block",L[690]);
var anf_fun8245504 = G(list2753,"make",L[689]);
var $z54945495 = D;
var $f55005501 = function(_) {
return R.isFunction(gid90256.$var)?gid90256.$var.app(l378725,("nothing")):R.ffi.throwNonFunApp(L[688],gid90256.$var,[l378725,("nothing")]);
};
try {
if(--R.GAS > 0) {
$z54945495 = $f55005501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55005501,
"from":L[688]});
}
} catch($e54925493) {
if(R.isCont($e54925493)) {
var $ss54965497 = {"from":L[688],
"go":function(anf_array_val8255502) {
return $Hanf_array_val17445505(anf_array_val8255502,anf_arg8105412,anf_arg8225490,anf_fun8115426,anf_fun8235503,anf_fun8245504,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726);
}};
$e54925493.stack[R.EXN_STACKHEIGHT++] = $ss54965497;
}
if(R.isPyretException($e54925493)) {
$e54925493.pyretStack.push(L[688]);
}
throw $e54925493;
}
var $ret54985499 = $Hanf_array_val17445505($z54945495,anf_arg8105412,anf_arg8225490,anf_fun8115426,anf_fun8235503,anf_fun8245504,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726);
++R.GAS;
return $ret54985499;
};
var $Hanf_array_val17445505 = function(anf_array_val8255502,anf_arg8105412,anf_arg8225490,anf_fun8115426,anf_fun8235503,anf_fun8245504,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726) {
var $z55085509 = D;
var $f55145515 = function(_) {
return R.isFunction(anf_fun8245504)?anf_fun8245504.app([anf_array_val8255502]):R.ffi.throwNonFunApp(L[689],anf_fun8245504,[[anf_array_val8255502]]);
};
try {
if(--R.GAS > 0) {
$z55085509 = $f55145515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55145515,
"from":L[689]});
}
} catch($e55065507) {
if(R.isCont($e55065507)) {
var $ss55105511 = {"from":L[689],
"go":function(anf_arg8265516) {
return $Hanf_arg17435517(anf_arg8265516,anf_arg8105412,anf_arg8225490,anf_fun8115426,anf_fun8235503,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726);
}};
$e55065507.stack[R.EXN_STACKHEIGHT++] = $ss55105511;
}
if(R.isPyretException($e55065507)) {
$e55065507.pyretStack.push(L[689]);
}
throw $e55065507;
}
var $ret55125513 = $Hanf_arg17435517($z55085509,anf_arg8105412,anf_arg8225490,anf_fun8115426,anf_fun8235503,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726);
++R.GAS;
return $ret55125513;
};
var $Hanf_arg17435517 = function(anf_arg8265516,anf_arg8105412,anf_arg8225490,anf_fun8115426,anf_fun8235503,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726) {
var $z55205521 = D;
var $f55265527 = function(_) {
return R.isFunction(anf_fun8235503)?anf_fun8235503.app(l378725,anf_arg8265516):R.ffi.throwNonFunApp(L[691],anf_fun8235503,[l378725,anf_arg8265516]);
};
try {
if(--R.GAS > 0) {
$z55205521 = $f55265527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55265527,
"from":L[691]});
}
} catch($e55185519) {
if(R.isCont($e55185519)) {
var $ss55225523 = {"from":L[691],
"go":function(anf_arg8275528) {
return $Hanf_arg17425529(anf_arg8275528,anf_arg8105412,anf_arg8225490,anf_fun8115426,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726);
}};
$e55185519.stack[R.EXN_STACKHEIGHT++] = $ss55225523;
}
if(R.isPyretException($e55185519)) {
$e55185519.pyretStack.push(L[691]);
}
throw $e55185519;
}
var $ret55245525 = $Hanf_arg17425529($z55205521,anf_arg8105412,anf_arg8225490,anf_fun8115426,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726);
++R.GAS;
return $ret55245525;
};
var $Hanf_arg17425529 = function(anf_arg8275528,anf_arg8105412,anf_arg8225490,anf_fun8115426,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726) {
var $z55325533 = D;
var $f55385539 = function(_) {
return R.isFunction(anf_fun8115426)?anf_fun8115426.app(l378725,anf_arg8225490,anf_arg8275528):R.ffi.throwNonFunApp(L[692],anf_fun8115426,[l378725,anf_arg8225490,anf_arg8275528]);
};
try {
if(--R.GAS > 0) {
$z55325533 = $f55385539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55385539,
"from":L[692]});
}
} catch($e55305531) {
if(R.isCont($e55305531)) {
var $ss55345535 = {"from":L[692],
"go":function(anf_arg8285540) {
return $Hanf_arg17415541(anf_arg8285540,anf_arg8105412,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726);
}};
$e55305531.stack[R.EXN_STACKHEIGHT++] = $ss55345535;
}
if(R.isPyretException($e55305531)) {
$e55305531.pyretStack.push(L[692]);
}
throw $e55305531;
}
var $ret55365537 = $Hanf_arg17415541($z55325533,anf_arg8105412,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726);
++R.GAS;
return $ret55365537;
};
var $Hanf_arg17415541 = function(anf_arg8285540,anf_arg8105412,bool_DASH_exn95266,check_DASH_bool91258,l378725,test_DASH_id381738,test379726) {
var anf_arg8295552 = G(test379726,"l",L[695]);
var anf_arg8305553 = G(test_DASH_id381738,"id-e",L[694]);
var $z55445545 = D;
var $f55505551 = function(_) {
return R.isFunction(bool_DASH_exn95266.$var)?bool_DASH_exn95266.$var.app(anf_arg8295552,("when"),anf_arg8305553):R.ffi.throwNonFunApp(L[693],bool_DASH_exn95266.$var,[anf_arg8295552,("when"),anf_arg8305553]);
};
try {
if(--R.GAS > 0) {
$z55445545 = $f55505551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55505551,
"from":L[693]});
}
} catch($e55425543) {
if(R.isCont($e55425543)) {
var $ss55465547 = {"from":L[693],
"go":function(anf_arg8315554) {
return $Hanf_arg17405555(anf_arg8315554,anf_arg8105412,anf_arg8285540,check_DASH_bool91258,l378725,test_DASH_id381738);
}};
$e55425543.stack[R.EXN_STACKHEIGHT++] = $ss55465547;
}
if(R.isPyretException($e55425543)) {
$e55425543.pyretStack.push(L[693]);
}
throw $e55425543;
}
var $ret55485549 = $Hanf_arg17405555($z55445545,anf_arg8105412,anf_arg8285540,check_DASH_bool91258,l378725,test_DASH_id381738);
++R.GAS;
return $ret55485549;
};
var $Hanf_arg17405555 = function(anf_arg8315554,anf_arg8105412,anf_arg8285540,check_DASH_bool91258,l378725,test_DASH_id381738) {
var $z55585559 = D;
var $f55645565 = function(_) {
return R.isFunction(check_DASH_bool91258.$var)?check_DASH_bool91258.$var.app(l378725,test_DASH_id381738,anf_arg8105412,anf_arg8285540,anf_arg8315554):R.ffi.throwNonFunApp(L[78],check_DASH_bool91258.$var,[l378725,test_DASH_id381738,anf_arg8105412,anf_arg8285540,anf_arg8315554]);
};
try {
if(--R.GAS > 0) {
$z55585559 = $f55645565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55645565,
"from":L[78]});
}
} catch($e55565557) {
if(R.isCont($e55565557)) {
var $ss55605561 = {"from":L[78],
"go":function(ann_DASH_check_DASH_temp8095566) {
return $Hann_DASH_check_DASH_temp17395567(ann_DASH_check_DASH_temp8095566);
}};
$e55565557.stack[R.EXN_STACKHEIGHT++] = $ss55605561;
}
if(R.isPyretException($e55565557)) {
$e55565557.pyretStack.push(L[78]);
}
throw $e55565557;
}
var $ret55625563 = $Hann_DASH_check_DASH_temp17395567($z55585559);
++R.GAS;
return $ret55625563;
};
var $Hann_DASH_check_DASH_temp17395567 = function(ann_DASH_check_DASH_temp8095566) {
return ann_DASH_check_DASH_temp8095566;
};
var $Hanf_arg1738763 = function(anf_arg802761,_check356747,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_member109294,desugar_DASH_opt115306,extend_DASH_variant357748,l349740,name350741,namet351742,params352743,shared355746,variants354745) {
var anf_fun8035578 = G(variants354745,"map",L[697]);
var $z55705571 = D;
var $f55765577 = function(_) {
return R.isFunction(anf_fun8035578)?anf_fun8035578.app(extend_DASH_variant357748.$var):R.ffi.throwNonFunApp(L[696],anf_fun8035578,[extend_DASH_variant357748.$var]);
};
try {
if(--R.GAS > 0) {
$z55705571 = $f55765577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55765577,
"from":L[696]});
}
} catch($e55685569) {
if(R.isCont($e55685569)) {
var $ss55725573 = {"from":L[696],
"go":function(anf_arg8045579) {
return $Hanf_arg17375580(anf_arg8045579,_check356747,anf_arg802761,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_member109294,desugar_DASH_opt115306,l349740,name350741,namet351742,params352743,shared355746);
}};
$e55685569.stack[R.EXN_STACKHEIGHT++] = $ss55725573;
}
if(R.isPyretException($e55685569)) {
$e55685569.pyretStack.push(L[696]);
}
throw $e55685569;
}
var $ret55745575 = $Hanf_arg17375580($z55705571,_check356747,anf_arg802761,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_member109294,desugar_DASH_opt115306,l349740,name350741,namet351742,params352743,shared355746);
++R.GAS;
return $ret55745575;
};
var $Hanf_arg17375580 = function(anf_arg8045579,_check356747,anf_arg802761,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_member109294,desugar_DASH_opt115306,l349740,name350741,namet351742,params352743,shared355746) {
var anf_fun8055591 = G(shared355746,"map",L[699]);
var $z55835584 = D;
var $f55895590 = function(_) {
return R.isFunction(anf_fun8055591)?anf_fun8055591.app(desugar_DASH_member109294.$var):R.ffi.throwNonFunApp(L[698],anf_fun8055591,[desugar_DASH_member109294.$var]);
};
try {
if(--R.GAS > 0) {
$z55835584 = $f55895590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55895590,
"from":L[698]});
}
} catch($e55815582) {
if(R.isCont($e55815582)) {
var $ss55855586 = {"from":L[698],
"go":function(anf_arg8065592) {
return $Hanf_arg17365593(anf_arg8065592,_check356747,anf_arg802761,anf_arg8045579,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_opt115306,l349740,name350741,namet351742,params352743);
}};
$e55815582.stack[R.EXN_STACKHEIGHT++] = $ss55855586;
}
if(R.isPyretException($e55815582)) {
$e55815582.pyretStack.push(L[698]);
}
throw $e55815582;
}
var $ret55875588 = $Hanf_arg17365593($z55835584,_check356747,anf_arg802761,anf_arg8045579,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_opt115306,l349740,name350741,namet351742,params352743);
++R.GAS;
return $ret55875588;
};
var $Hanf_arg17365593 = function(anf_arg8065592,_check356747,anf_arg802761,anf_arg8045579,anf_fun800762,desugar_DASH_expr117310,desugar_DASH_opt115306,l349740,name350741,namet351742,params352743) {
var $z55965597 = D;
var $f56025603 = function(_) {
return R.isFunction(desugar_DASH_opt115306.$var)?desugar_DASH_opt115306.$var.app(desugar_DASH_expr117310.$var,_check356747):R.ffi.throwNonFunApp(L[700],desugar_DASH_opt115306.$var,[desugar_DASH_expr117310.$var,_check356747]);
};
try {
if(--R.GAS > 0) {
$z55965597 = $f56025603();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56025603,
"from":L[700]});
}
} catch($e55945595) {
if(R.isCont($e55945595)) {
var $ss55985599 = {"from":L[700],
"go":function(anf_arg8075604) {
return $Hanf_arg17355605(anf_arg8075604,anf_arg802761,anf_arg8045579,anf_arg8065592,anf_fun800762,l349740,name350741,namet351742,params352743);
}};
$e55945595.stack[R.EXN_STACKHEIGHT++] = $ss55985599;
}
if(R.isPyretException($e55945595)) {
$e55945595.pyretStack.push(L[700]);
}
throw $e55945595;
}
var $ret56005601 = $Hanf_arg17355605($z55965597,anf_arg802761,anf_arg8045579,anf_arg8065592,anf_fun800762,l349740,name350741,namet351742,params352743);
++R.GAS;
return $ret56005601;
};
var $Hanf_arg17355605 = function(anf_arg8075604,anf_arg802761,anf_arg8045579,anf_arg8065592,anf_fun800762,l349740,name350741,namet351742,params352743) {
var $z56085609 = D;
var $f56145615 = function(_) {
return R.isFunction(anf_fun800762)?anf_fun800762.app(l349740,name350741,namet351742,params352743,anf_arg802761,anf_arg8045579,anf_arg8065592,anf_arg8075604):R.ffi.throwNonFunApp(L[80],anf_fun800762,[l349740,name350741,namet351742,params352743,anf_arg802761,anf_arg8045579,anf_arg8065592,anf_arg8075604]);
};
try {
if(--R.GAS > 0) {
$z56085609 = $f56145615();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56145615,
"from":L[80]});
}
} catch($e56065607) {
if(R.isCont($e56065607)) {
var $ss56105611 = {"from":L[80],
"go":function(ann_DASH_check_DASH_temp7375616) {
return $Hann_DASH_check_DASH_temp17345617(ann_DASH_check_DASH_temp7375616);
}};
$e56065607.stack[R.EXN_STACKHEIGHT++] = $ss56105611;
}
if(R.isPyretException($e56065607)) {
$e56065607.pyretStack.push(L[80]);
}
throw $e56065607;
}
var $ret56125613 = $Hann_DASH_check_DASH_temp17345617($z56085609);
++R.GAS;
return $ret56125613;
};
var $Hann_DASH_check_DASH_temp17345617 = function(ann_DASH_check_DASH_temp7375616) {
return ann_DASH_check_DASH_temp7375616;
};
var $Hann_DASH_check_DASH_temp1733781 = function(ann_DASH_check_DASH_temp738780) {
return ann_DASH_check_DASH_temp738780;
};
var $Hanf_arg1732800 = function(anf_arg790799,A113,desugar_DASH_member109294,l2374785,make_DASH_methods359765,vname375786,with_DASH_members376787,_plus7) {
var $z56205621 = D;
var $f56265627 = function(_) {
return R.isFunction(make_DASH_methods359765.$var)?make_DASH_methods359765.$var.app(l2374785,vname375786,anf_arg790799,(true)):R.ffi.throwNonFunApp(L[701],make_DASH_methods359765.$var,[l2374785,vname375786,anf_arg790799,(true)]);
};
try {
if(--R.GAS > 0) {
$z56205621 = $f56265627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56265627,
"from":L[701]});
}
} catch($e56185619) {
if(R.isCont($e56185619)) {
var $ss56225623 = {"from":L[701],
"go":function(methods3775628) {
return $Hmethods17315629(methods3775628,A113,desugar_DASH_member109294,l2374785,vname375786,with_DASH_members376787,_plus7);
}};
$e56185619.stack[R.EXN_STACKHEIGHT++] = $ss56225623;
}
if(R.isPyretException($e56185619)) {
$e56185619.pyretStack.push(L[701]);
}
throw $e56185619;
}
var $ret56245625 = $Hmethods17315629($z56205621,A113,desugar_DASH_member109294,l2374785,vname375786,with_DASH_members376787,_plus7);
++R.GAS;
return $ret56245625;
};
var $Hmethods17315629 = function(methods3775628,A113,desugar_DASH_member109294,l2374785,vname375786,with_DASH_members376787,_plus7) {
var anf_fun7915641 = G(A113,"s-singleton-variant",L[703]);
var $z56325633 = D;
var $f56385639 = function(_) {
return R.isFunction(_plus7)?_plus7.app(methods3775628,with_DASH_members376787):R.ffi.throwNonFunApp(L[702],_plus7,[methods3775628,with_DASH_members376787]);
};
try {
if(--R.GAS > 0) {
$z56325633 = $f56385639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56385639,
"from":L[702]});
}
} catch($e56305631) {
if(R.isCont($e56305631)) {
var $ss56345635 = {"from":L[702],
"go":function(anf_bracket7925640) {
return $Hanf_bracket17305642(anf_bracket7925640,anf_fun7915641,desugar_DASH_member109294,l2374785,vname375786);
}};
$e56305631.stack[R.EXN_STACKHEIGHT++] = $ss56345635;
}
if(R.isPyretException($e56305631)) {
$e56305631.pyretStack.push(L[702]);
}
throw $e56305631;
}
var $ret56365637 = $Hanf_bracket17305642($z56325633,anf_fun7915641,desugar_DASH_member109294,l2374785,vname375786);
++R.GAS;
return $ret56365637;
};
var $Hanf_bracket17305642 = function(anf_bracket7925640,anf_fun7915641,desugar_DASH_member109294,l2374785,vname375786) {
var anf_fun7935653 = G(anf_bracket7925640,"map",L[705]);
var $z56455646 = D;
var $f56515652 = function(_) {
return R.isFunction(anf_fun7935653)?anf_fun7935653.app(desugar_DASH_member109294.$var):R.ffi.throwNonFunApp(L[704],anf_fun7935653,[desugar_DASH_member109294.$var]);
};
try {
if(--R.GAS > 0) {
$z56455646 = $f56515652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56515652,
"from":L[704]});
}
} catch($e56435644) {
if(R.isCont($e56435644)) {
var $ss56475648 = {"from":L[704],
"go":function(anf_arg7945654) {
return $Hanf_arg17295655(anf_arg7945654,anf_fun7915641,l2374785,vname375786);
}};
$e56435644.stack[R.EXN_STACKHEIGHT++] = $ss56475648;
}
if(R.isPyretException($e56435644)) {
$e56435644.pyretStack.push(L[704]);
}
throw $e56435644;
}
var $ret56495650 = $Hanf_arg17295655($z56455646,anf_fun7915641,l2374785,vname375786);
++R.GAS;
return $ret56495650;
};
var $Hanf_arg17295655 = function(anf_arg7945654,anf_fun7915641,l2374785,vname375786) {
var $z56585659 = D;
var $f56645665 = function(_) {
return R.isFunction(anf_fun7915641)?anf_fun7915641.app(l2374785,vname375786,anf_arg7945654):R.ffi.throwNonFunApp(L[86],anf_fun7915641,[l2374785,vname375786,anf_arg7945654]);
};
try {
if(--R.GAS > 0) {
$z56585659 = $f56645665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56645665,
"from":L[86]});
}
} catch($e56565657) {
if(R.isCont($e56565657)) {
var $ss56605661 = {"from":L[86],
"go":function(ann_DASH_check_DASH_temp7885666) {
return $Hann_DASH_check_DASH_temp17285667(ann_DASH_check_DASH_temp7885666);
}};
$e56565657.stack[R.EXN_STACKHEIGHT++] = $ss56605661;
}
if(R.isPyretException($e56565657)) {
$e56565657.pyretStack.push(L[86]);
}
throw $e56565657;
}
var $ret56625663 = $Hann_DASH_check_DASH_temp17285667($z56585659);
++R.GAS;
return $ret56625663;
};
var $Hann_DASH_check_DASH_temp17285667 = function(ann_DASH_check_DASH_temp7885666) {
return ann_DASH_check_DASH_temp7885666;
};
var $Hmethods1727817 = function(methods373816,A113,constr_DASH_loc369802,desugar_DASH_member109294,desugar_DASH_variant_DASH_member108292,l2368801,members371804,vname370803,with_DASH_members372805,_plus7) {
var anf_fun7815680 = G(A113,"s-variant",L[708]);
var anf_fun7825678 = G(members371804,"map",L[707]);
var $z56705671 = D;
var $f56765677 = function(_) {
return R.isFunction(anf_fun7825678)?anf_fun7825678.app(desugar_DASH_variant_DASH_member108292.$var):R.ffi.throwNonFunApp(L[706],anf_fun7825678,[desugar_DASH_variant_DASH_member108292.$var]);
};
try {
if(--R.GAS > 0) {
$z56705671 = $f56765677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56765677,
"from":L[706]});
}
} catch($e56685669) {
if(R.isCont($e56685669)) {
var $ss56725673 = {"from":L[706],
"go":function(anf_arg7835679) {
return $Hanf_arg17265681(anf_arg7835679,anf_fun7815680,constr_DASH_loc369802,desugar_DASH_member109294,l2368801,methods373816,vname370803,with_DASH_members372805,_plus7);
}};
$e56685669.stack[R.EXN_STACKHEIGHT++] = $ss56725673;
}
if(R.isPyretException($e56685669)) {
$e56685669.pyretStack.push(L[706]);
}
throw $e56685669;
}
var $ret56745675 = $Hanf_arg17265681($z56705671,anf_fun7815680,constr_DASH_loc369802,desugar_DASH_member109294,l2368801,methods373816,vname370803,with_DASH_members372805,_plus7);
++R.GAS;
return $ret56745675;
};
var $Hanf_arg17265681 = function(anf_arg7835679,anf_fun7815680,constr_DASH_loc369802,desugar_DASH_member109294,l2368801,methods373816,vname370803,with_DASH_members372805,_plus7) {
var $z56845685 = D;
var $f56905691 = function(_) {
return R.isFunction(_plus7)?_plus7.app(methods373816,with_DASH_members372805):R.ffi.throwNonFunApp(L[709],_plus7,[methods373816,with_DASH_members372805]);
};
try {
if(--R.GAS > 0) {
$z56845685 = $f56905691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56905691,
"from":L[709]});
}
} catch($e56825683) {
if(R.isCont($e56825683)) {
var $ss56865687 = {"from":L[709],
"go":function(anf_bracket7845692) {
return $Hanf_bracket17255693(anf_bracket7845692,anf_arg7835679,anf_fun7815680,constr_DASH_loc369802,desugar_DASH_member109294,l2368801,vname370803);
}};
$e56825683.stack[R.EXN_STACKHEIGHT++] = $ss56865687;
}
if(R.isPyretException($e56825683)) {
$e56825683.pyretStack.push(L[709]);
}
throw $e56825683;
}
var $ret56885689 = $Hanf_bracket17255693($z56845685,anf_arg7835679,anf_fun7815680,constr_DASH_loc369802,desugar_DASH_member109294,l2368801,vname370803);
++R.GAS;
return $ret56885689;
};
var $Hanf_bracket17255693 = function(anf_bracket7845692,anf_arg7835679,anf_fun7815680,constr_DASH_loc369802,desugar_DASH_member109294,l2368801,vname370803) {
var anf_fun7855704 = G(anf_bracket7845692,"map",L[711]);
var $z56965697 = D;
var $f57025703 = function(_) {
return R.isFunction(anf_fun7855704)?anf_fun7855704.app(desugar_DASH_member109294.$var):R.ffi.throwNonFunApp(L[710],anf_fun7855704,[desugar_DASH_member109294.$var]);
};
try {
if(--R.GAS > 0) {
$z56965697 = $f57025703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57025703,
"from":L[710]});
}
} catch($e56945695) {
if(R.isCont($e56945695)) {
var $ss56985699 = {"from":L[710],
"go":function(anf_arg7865705) {
return $Hanf_arg17245706(anf_arg7865705,anf_arg7835679,anf_fun7815680,constr_DASH_loc369802,l2368801,vname370803);
}};
$e56945695.stack[R.EXN_STACKHEIGHT++] = $ss56985699;
}
if(R.isPyretException($e56945695)) {
$e56945695.pyretStack.push(L[710]);
}
throw $e56945695;
}
var $ret57005701 = $Hanf_arg17245706($z56965697,anf_arg7835679,anf_fun7815680,constr_DASH_loc369802,l2368801,vname370803);
++R.GAS;
return $ret57005701;
};
var $Hanf_arg17245706 = function(anf_arg7865705,anf_arg7835679,anf_fun7815680,constr_DASH_loc369802,l2368801,vname370803) {
var $z57095710 = D;
var $f57155716 = function(_) {
return R.isFunction(anf_fun7815680)?anf_fun7815680.app(l2368801,constr_DASH_loc369802,vname370803,anf_arg7835679,anf_arg7865705):R.ffi.throwNonFunApp(L[88],anf_fun7815680,[l2368801,constr_DASH_loc369802,vname370803,anf_arg7835679,anf_arg7865705]);
};
try {
if(--R.GAS > 0) {
$z57095710 = $f57155716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57155716,
"from":L[88]});
}
} catch($e57075708) {
if(R.isCont($e57075708)) {
var $ss57115712 = {"from":L[88],
"go":function(ann_DASH_check_DASH_temp7805717) {
return $Hann_DASH_check_DASH_temp17235718(ann_DASH_check_DASH_temp7805717);
}};
$e57075708.stack[R.EXN_STACKHEIGHT++] = $ss57115712;
}
if(R.isPyretException($e57075708)) {
$e57075708.pyretStack.push(L[88]);
}
throw $e57075708;
}
var $ret57135714 = $Hann_DASH_check_DASH_temp17235718($z57095710);
++R.GAS;
return $ret57135714;
};
var $Hann_DASH_check_DASH_temp17235718 = function(ann_DASH_check_DASH_temp7805717) {
return ann_DASH_check_DASH_temp7805717;
};
var $Hif_DASH_1722836 = function(if_DASH_44835,A113,empty3049,is_DASH_singleton363822,l2360819,list2753,lists1118,make_DASH_match103282,make_DASH_torepr102280,members362821,shared355746,vname361820,_plus7) {
var if_helper7455729 = R.makeFunction(function(if_helper_arg7465751) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[91],1,arguments);
}
var do_DASH_match3645765 = if_helper_arg7465751;
var anf_fun7475762 = G(lists1118,"any",L[721]);
var anf_arg7515763 = R.makeFunction(function(s3675767) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[718],1,arguments);
}
var anf_bracket7495770 = G(s3675767,"name",L[720]);
var anf_arg7505769 = G(anf_bracket7495770,"s",L[719]);
var ann_DASH_check_DASH_temp7485768 = R.equiv(anf_arg7505769,("_torepr"));
return ann_DASH_check_DASH_temp7485768;
});
var $z57545755 = D;
var $f57605761 = function(_) {
return R.isFunction(anf_fun7475762)?anf_fun7475762.app(anf_arg7515763,shared355746):R.ffi.throwNonFunApp(L[717],anf_fun7475762,[anf_arg7515763,shared355746]);
};
try {
if(--R.GAS > 0) {
$z57545755 = $f57605761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57605761,
"from":L[717]});
}
} catch($e57525753) {
if(R.isCont($e57525753)) {
var $ss57565757 = {"from":L[717],
"go":function(if_DASH_455764) {
return $Hif_DASH_17165766(if_DASH_455764,A113,do_DASH_match3645765,empty3049,is_DASH_singleton363822,l2360819,list2753,make_DASH_torepr102280,members362821,vname361820,_plus7);
}};
$e57525753.stack[R.EXN_STACKHEIGHT++] = $ss57565757;
}
if(R.isPyretException($e57525753)) {
$e57525753.pyretStack.push(L[717]);
}
throw $e57525753;
}
var $ret57585759 = $Hif_DASH_17165766($z57545755,A113,do_DASH_match3645765,empty3049,is_DASH_singleton363822,l2360819,list2753,make_DASH_torepr102280,members362821,vname361820,_plus7);
++R.GAS;
return $ret57585759;
});
var anf_if7685750 = R.isBoolean(if_DASH_44835);
if(R.isPyretTrue(anf_if7685750)) {
if(R.isPyretTrue(if_DASH_44835)) {
var $z57215722 = D;
var $f57275728 = function(_) {
return R.isFunction(if_helper7455729)?if_helper7455729.app(empty3049):R.ffi.throwNonFunApp(L[712],if_helper7455729,[empty3049]);
};
try {
if(--R.GAS > 0) {
$z57215722 = $f57275728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57275728,
"from":L[712]});
}
} catch($e57195720) {
if(R.isCont($e57195720)) {
var $ss57235724 = {"from":L[712],
"go":function(cont_tail_app7775730) {
return $Hcont_tail_app17175731(cont_tail_app7775730);
}};
$e57195720.stack[R.EXN_STACKHEIGHT++] = $ss57235724;
}
if(R.isPyretException($e57195720)) {
$e57195720.pyretStack.push(L[712]);
}
throw $e57195720;
}
var $ret57255726 = $Hcont_tail_app17175731($z57215722);
++R.GAS;
return $ret57255726;
} else {
var anf_fun7695744 = G(list2753,"make",L[716]);
var anf_fun7705745 = G(A113,"s-data-field",L[715]);
var anf_fun7715742 = G(A113,"s-str",L[714]);
var $z57345735 = D;
var $f57405741 = function(_) {
return R.isFunction(anf_fun7715742)?anf_fun7715742.app(l2360819,("_match")):R.ffi.throwNonFunApp(L[713],anf_fun7715742,[l2360819,("_match")]);
};
try {
if(--R.GAS > 0) {
$z57345735 = $f57405741();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57405741,
"from":L[713]});
}
} catch($e57325733) {
if(R.isCont($e57325733)) {
var $ss57365737 = {"from":L[713],
"go":function(anf_arg7725743) {
return $Hanf_arg17215746(anf_arg7725743,anf_fun7695744,anf_fun7705745,if_helper7455729,l2360819,make_DASH_match103282,members362821,vname361820);
}};
$e57325733.stack[R.EXN_STACKHEIGHT++] = $ss57365737;
}
if(R.isPyretException($e57325733)) {
$e57325733.pyretStack.push(L[713]);
}
throw $e57325733;
}
var $ret57385739 = $Hanf_arg17215746($z57345735,anf_fun7695744,anf_fun7705745,if_helper7455729,l2360819,make_DASH_match103282,members362821,vname361820);
++R.GAS;
return $ret57385739;
}
} else {
var cont_tail_arg7665749 = R.throwNonBooleanCondition(L[91],("if"),if_DASH_44835);
if(--R.GAS > 0) {
$z57475748 = R.isFunction(if_helper7455729)?if_helper7455729.app(cont_tail_arg7665749):R.ffi.throwNonFunApp(L[91],if_helper7455729,[cont_tail_arg7665749]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper7455729)?if_helper7455729.app(cont_tail_arg7665749):R.ffi.throwNonFunApp(L[91],if_helper7455729,[cont_tail_arg7665749]);
},
"from":L[91]});
}
++R.GAS;
return $z57475748;
}
};
var $Hcont_tail_app17175731 = function(cont_tail_app7775730) {
return cont_tail_app7775730;
};
var $Hanf_arg17215746 = function(anf_arg7725743,anf_fun7695744,anf_fun7705745,if_helper7455729,l2360819,make_DASH_match103282,members362821,vname361820) {
var $z57735774 = D;
var $f57795780 = function(_) {
return R.isFunction(make_DASH_match103282.$var)?make_DASH_match103282.$var.app(l2360819,vname361820,members362821):R.ffi.throwNonFunApp(L[722],make_DASH_match103282.$var,[l2360819,vname361820,members362821]);
};
try {
if(--R.GAS > 0) {
$z57735774 = $f57795780();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57795780,
"from":L[722]});
}
} catch($e57715772) {
if(R.isCont($e57715772)) {
var $ss57755776 = {"from":L[722],
"go":function(anf_arg7735781) {
return $Hanf_arg17205782(anf_arg7735781,anf_arg7725743,anf_fun7695744,anf_fun7705745,if_helper7455729,l2360819);
}};
$e57715772.stack[R.EXN_STACKHEIGHT++] = $ss57755776;
}
if(R.isPyretException($e57715772)) {
$e57715772.pyretStack.push(L[722]);
}
throw $e57715772;
}
var $ret57775778 = $Hanf_arg17205782($z57735774,anf_arg7725743,anf_fun7695744,anf_fun7705745,if_helper7455729,l2360819);
++R.GAS;
return $ret57775778;
};
var $Hanf_arg17205782 = function(anf_arg7735781,anf_arg7725743,anf_fun7695744,anf_fun7705745,if_helper7455729,l2360819) {
var $z57855786 = D;
var $f57915792 = function(_) {
return R.isFunction(anf_fun7705745)?anf_fun7705745.app(l2360819,anf_arg7725743,anf_arg7735781):R.ffi.throwNonFunApp(L[723],anf_fun7705745,[l2360819,anf_arg7725743,anf_arg7735781]);
};
try {
if(--R.GAS > 0) {
$z57855786 = $f57915792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57915792,
"from":L[723]});
}
} catch($e57835784) {
if(R.isCont($e57835784)) {
var $ss57875788 = {"from":L[723],
"go":function(anf_array_val7745793) {
return $Hanf_array_val17195794(anf_array_val7745793,anf_fun7695744,if_helper7455729);
}};
$e57835784.stack[R.EXN_STACKHEIGHT++] = $ss57875788;
}
if(R.isPyretException($e57835784)) {
$e57835784.pyretStack.push(L[723]);
}
throw $e57835784;
}
var $ret57895790 = $Hanf_array_val17195794($z57855786,anf_fun7695744,if_helper7455729);
++R.GAS;
return $ret57895790;
};
var $Hanf_array_val17195794 = function(anf_array_val7745793,anf_fun7695744,if_helper7455729) {
var $z57975798 = D;
var $f58035804 = function(_) {
return R.isFunction(anf_fun7695744)?anf_fun7695744.app([anf_array_val7745793]):R.ffi.throwNonFunApp(L[716],anf_fun7695744,[[anf_array_val7745793]]);
};
try {
if(--R.GAS > 0) {
$z57975798 = $f58035804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58035804,
"from":L[716]});
}
} catch($e57955796) {
if(R.isCont($e57955796)) {
var $ss57995800 = {"from":L[716],
"go":function(cont_tail_arg7755805) {
return $Hcont_tail_arg17185806(cont_tail_arg7755805,if_helper7455729);
}};
$e57955796.stack[R.EXN_STACKHEIGHT++] = $ss57995800;
}
if(R.isPyretException($e57955796)) {
$e57955796.pyretStack.push(L[716]);
}
throw $e57955796;
}
var $ret58015802 = $Hcont_tail_arg17185806($z57975798,if_helper7455729);
++R.GAS;
return $ret58015802;
};
var $Hcont_tail_arg17185806 = function(cont_tail_arg7755805,if_helper7455729) {
if(--R.GAS > 0) {
$z58075808 = R.isFunction(if_helper7455729)?if_helper7455729.app(cont_tail_arg7755805):R.ffi.throwNonFunApp(L[716],if_helper7455729,[cont_tail_arg7755805]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper7455729)?if_helper7455729.app(cont_tail_arg7755805):R.ffi.throwNonFunApp(L[716],if_helper7455729,[cont_tail_arg7755805]);
},
"from":L[716]});
}
++R.GAS;
return $z58075808;
};
var $Hif_DASH_17165766 = function(if_DASH_455764,A113,do_DASH_match3645765,empty3049,is_DASH_singleton363822,l2360819,list2753,make_DASH_torepr102280,members362821,vname361820,_plus7) {
var if_helper7525819 = R.makeFunction(function(if_helper_arg7535841) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[717],1,arguments);
}
var do_DASH_torepr3665852 = if_helper_arg7535841;
var $z58445845 = D;
var $f58505851 = function(_) {
return R.isFunction(_plus7)?_plus7.app(do_DASH_match3645765,do_DASH_torepr3665852):R.ffi.throwNonFunApp(L[90],_plus7,[do_DASH_match3645765,do_DASH_torepr3665852]);
};
try {
if(--R.GAS > 0) {
$z58445845 = $f58505851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58505851,
"from":L[90]});
}
} catch($e58425843) {
if(R.isCont($e58425843)) {
var $ss58465847 = {"from":L[90],
"go":function(ann_DASH_check_DASH_temp7395853) {
return $Hann_DASH_check_DASH_temp17105854(ann_DASH_check_DASH_temp7395853);
}};
$e58425843.stack[R.EXN_STACKHEIGHT++] = $ss58465847;
}
if(R.isPyretException($e58425843)) {
$e58425843.pyretStack.push(L[90]);
}
throw $e58425843;
}
var $ret58485849 = $Hann_DASH_check_DASH_temp17105854($z58445845);
++R.GAS;
return $ret58485849;
});
var anf_if7565840 = R.isBoolean(if_DASH_455764);
if(R.isPyretTrue(anf_if7565840)) {
if(R.isPyretTrue(if_DASH_455764)) {
var $z58115812 = D;
var $f58175818 = function(_) {
return R.isFunction(if_helper7525819)?if_helper7525819.app(empty3049):R.ffi.throwNonFunApp(L[724],if_helper7525819,[empty3049]);
};
try {
if(--R.GAS > 0) {
$z58115812 = $f58175818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58175818,
"from":L[724]});
}
} catch($e58095810) {
if(R.isCont($e58095810)) {
var $ss58135814 = {"from":L[724],
"go":function(cont_tail_app7655820) {
return $Hcont_tail_app17115821(cont_tail_app7655820);
}};
$e58095810.stack[R.EXN_STACKHEIGHT++] = $ss58135814;
}
if(R.isPyretException($e58095810)) {
$e58095810.pyretStack.push(L[724]);
}
throw $e58095810;
}
var $ret58155816 = $Hcont_tail_app17115821($z58115812);
++R.GAS;
return $ret58155816;
} else {
var anf_fun7575834 = G(list2753,"make",L[728]);
var anf_fun7585835 = G(A113,"s-data-field",L[727]);
var anf_fun7595832 = G(A113,"s-str",L[726]);
var $z58245825 = D;
var $f58305831 = function(_) {
return R.isFunction(anf_fun7595832)?anf_fun7595832.app(l2360819,("_torepr")):R.ffi.throwNonFunApp(L[725],anf_fun7595832,[l2360819,("_torepr")]);
};
try {
if(--R.GAS > 0) {
$z58245825 = $f58305831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58305831,
"from":L[725]});
}
} catch($e58225823) {
if(R.isCont($e58225823)) {
var $ss58265827 = {"from":L[725],
"go":function(anf_arg7605833) {
return $Hanf_arg17155836(anf_arg7605833,anf_fun7575834,anf_fun7585835,if_helper7525819,is_DASH_singleton363822,l2360819,make_DASH_torepr102280,members362821,vname361820);
}};
$e58225823.stack[R.EXN_STACKHEIGHT++] = $ss58265827;
}
if(R.isPyretException($e58225823)) {
$e58225823.pyretStack.push(L[725]);
}
throw $e58225823;
}
var $ret58285829 = $Hanf_arg17155836($z58245825,anf_fun7575834,anf_fun7585835,if_helper7525819,is_DASH_singleton363822,l2360819,make_DASH_torepr102280,members362821,vname361820);
++R.GAS;
return $ret58285829;
}
} else {
var cont_tail_arg7545839 = R.throwNonBooleanCondition(L[717],("if"),if_DASH_455764);
if(--R.GAS > 0) {
$z58375838 = R.isFunction(if_helper7525819)?if_helper7525819.app(cont_tail_arg7545839):R.ffi.throwNonFunApp(L[717],if_helper7525819,[cont_tail_arg7545839]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper7525819)?if_helper7525819.app(cont_tail_arg7545839):R.ffi.throwNonFunApp(L[717],if_helper7525819,[cont_tail_arg7545839]);
},
"from":L[717]});
}
++R.GAS;
return $z58375838;
}
};
var $Hcont_tail_app17115821 = function(cont_tail_app7655820) {
return cont_tail_app7655820;
};
var $Hanf_arg17155836 = function(anf_arg7605833,anf_fun7575834,anf_fun7585835,if_helper7525819,is_DASH_singleton363822,l2360819,make_DASH_torepr102280,members362821,vname361820) {
var $z58575858 = D;
var $f58635864 = function(_) {
return R.isFunction(make_DASH_torepr102280.$var)?make_DASH_torepr102280.$var.app(l2360819,vname361820,members362821,is_DASH_singleton363822):R.ffi.throwNonFunApp(L[729],make_DASH_torepr102280.$var,[l2360819,vname361820,members362821,is_DASH_singleton363822]);
};
try {
if(--R.GAS > 0) {
$z58575858 = $f58635864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58635864,
"from":L[729]});
}
} catch($e58555856) {
if(R.isCont($e58555856)) {
var $ss58595860 = {"from":L[729],
"go":function(anf_arg7615865) {
return $Hanf_arg17145866(anf_arg7615865,anf_arg7605833,anf_fun7575834,anf_fun7585835,if_helper7525819,l2360819);
}};
$e58555856.stack[R.EXN_STACKHEIGHT++] = $ss58595860;
}
if(R.isPyretException($e58555856)) {
$e58555856.pyretStack.push(L[729]);
}
throw $e58555856;
}
var $ret58615862 = $Hanf_arg17145866($z58575858,anf_arg7605833,anf_fun7575834,anf_fun7585835,if_helper7525819,l2360819);
++R.GAS;
return $ret58615862;
};
var $Hanf_arg17145866 = function(anf_arg7615865,anf_arg7605833,anf_fun7575834,anf_fun7585835,if_helper7525819,l2360819) {
var $z58695870 = D;
var $f58755876 = function(_) {
return R.isFunction(anf_fun7585835)?anf_fun7585835.app(l2360819,anf_arg7605833,anf_arg7615865):R.ffi.throwNonFunApp(L[730],anf_fun7585835,[l2360819,anf_arg7605833,anf_arg7615865]);
};
try {
if(--R.GAS > 0) {
$z58695870 = $f58755876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58755876,
"from":L[730]});
}
} catch($e58675868) {
if(R.isCont($e58675868)) {
var $ss58715872 = {"from":L[730],
"go":function(anf_array_val7625877) {
return $Hanf_array_val17135878(anf_array_val7625877,anf_fun7575834,if_helper7525819);
}};
$e58675868.stack[R.EXN_STACKHEIGHT++] = $ss58715872;
}
if(R.isPyretException($e58675868)) {
$e58675868.pyretStack.push(L[730]);
}
throw $e58675868;
}
var $ret58735874 = $Hanf_array_val17135878($z58695870,anf_fun7575834,if_helper7525819);
++R.GAS;
return $ret58735874;
};
var $Hanf_array_val17135878 = function(anf_array_val7625877,anf_fun7575834,if_helper7525819) {
var $z58815882 = D;
var $f58875888 = function(_) {
return R.isFunction(anf_fun7575834)?anf_fun7575834.app([anf_array_val7625877]):R.ffi.throwNonFunApp(L[728],anf_fun7575834,[[anf_array_val7625877]]);
};
try {
if(--R.GAS > 0) {
$z58815882 = $f58875888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58875888,
"from":L[728]});
}
} catch($e58795880) {
if(R.isCont($e58795880)) {
var $ss58835884 = {"from":L[728],
"go":function(cont_tail_arg7635889) {
return $Hcont_tail_arg17125890(cont_tail_arg7635889,if_helper7525819);
}};
$e58795880.stack[R.EXN_STACKHEIGHT++] = $ss58835884;
}
if(R.isPyretException($e58795880)) {
$e58795880.pyretStack.push(L[728]);
}
throw $e58795880;
}
var $ret58855886 = $Hcont_tail_arg17125890($z58815882,if_helper7525819);
++R.GAS;
return $ret58855886;
};
var $Hcont_tail_arg17125890 = function(cont_tail_arg7635889,if_helper7525819) {
if(--R.GAS > 0) {
$z58915892 = R.isFunction(if_helper7525819)?if_helper7525819.app(cont_tail_arg7635889):R.ffi.throwNonFunApp(L[728],if_helper7525819,[cont_tail_arg7635889]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper7525819)?if_helper7525819.app(cont_tail_arg7635889):R.ffi.throwNonFunApp(L[728],if_helper7525819,[cont_tail_arg7635889]);
},
"from":L[728]});
}
++R.GAS;
return $z58915892;
};
var $Hann_DASH_check_DASH_temp17105854 = function(ann_DASH_check_DASH_temp7395853) {
return ann_DASH_check_DASH_temp7395853;
};
var $Hnew_DASH_binds1709856 = function(new_DASH_binds344855,A113,body343843,desugar_DASH_expr117310,l341841) {
var anf_fun7345904 = G(A113,"s-letrec",L[732]);
var $z58955896 = D;
var $f59015902 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(body343843):R.ffi.throwNonFunApp(L[731],desugar_DASH_expr117310.$var,[body343843]);
};
try {
if(--R.GAS > 0) {
$z58955896 = $f59015902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59015902,
"from":L[731]});
}
} catch($e58935894) {
if(R.isCont($e58935894)) {
var $ss58975898 = {"from":L[731],
"go":function(anf_arg7355903) {
return $Hanf_arg17085905(anf_arg7355903,anf_fun7345904,l341841,new_DASH_binds344855);
}};
$e58935894.stack[R.EXN_STACKHEIGHT++] = $ss58975898;
}
if(R.isPyretException($e58935894)) {
$e58935894.pyretStack.push(L[731]);
}
throw $e58935894;
}
var $ret58995900 = $Hanf_arg17085905($z58955896,anf_fun7345904,l341841,new_DASH_binds344855);
++R.GAS;
return $ret58995900;
};
var $Hanf_arg17085905 = function(anf_arg7355903,anf_fun7345904,l341841,new_DASH_binds344855) {
var $z59085909 = D;
var $f59145915 = function(_) {
return R.isFunction(anf_fun7345904)?anf_fun7345904.app(l341841,new_DASH_binds344855,anf_arg7355903):R.ffi.throwNonFunApp(L[96],anf_fun7345904,[l341841,new_DASH_binds344855,anf_arg7355903]);
};
try {
if(--R.GAS > 0) {
$z59085909 = $f59145915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59145915,
"from":L[96]});
}
} catch($e59065907) {
if(R.isCont($e59065907)) {
var $ss59105911 = {"from":L[96],
"go":function(ann_DASH_check_DASH_temp7225916) {
return $Hann_DASH_check_DASH_temp17075917(ann_DASH_check_DASH_temp7225916);
}};
$e59065907.stack[R.EXN_STACKHEIGHT++] = $ss59105911;
}
if(R.isPyretException($e59065907)) {
$e59065907.pyretStack.push(L[96]);
}
throw $e59065907;
}
var $ret59125913 = $Hann_DASH_check_DASH_temp17075917($z59085909);
++R.GAS;
return $ret59125913;
};
var $Hann_DASH_check_DASH_temp17075917 = function(ann_DASH_check_DASH_temp7225916) {
return ann_DASH_check_DASH_temp7225916;
};
var $Hann_DASH_check_DASH_temp1706872 = function(ann_DASH_check_DASH_temp723871) {
return ann_DASH_check_DASH_temp723871;
};
var $Hanf_arg1705890 = function(anf_arg727888,anf_fun726889,desugar_DASH_expr117310,l2346875,val348877) {
var $z59205921 = D;
var $f59265927 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(val348877):R.ffi.throwNonFunApp(L[733],desugar_DASH_expr117310.$var,[val348877]);
};
try {
if(--R.GAS > 0) {
$z59205921 = $f59265927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59265927,
"from":L[733]});
}
} catch($e59185919) {
if(R.isCont($e59185919)) {
var $ss59225923 = {"from":L[733],
"go":function(anf_arg7285928) {
return $Hanf_arg17045929(anf_arg7285928,anf_arg727888,anf_fun726889,l2346875);
}};
$e59185919.stack[R.EXN_STACKHEIGHT++] = $ss59225923;
}
if(R.isPyretException($e59185919)) {
$e59185919.pyretStack.push(L[733]);
}
throw $e59185919;
}
var $ret59245925 = $Hanf_arg17045929($z59205921,anf_arg727888,anf_fun726889,l2346875);
++R.GAS;
return $ret59245925;
};
var $Hanf_arg17045929 = function(anf_arg7285928,anf_arg727888,anf_fun726889,l2346875) {
var $z59325933 = D;
var $f59385939 = function(_) {
return R.isFunction(anf_fun726889)?anf_fun726889.app(l2346875,anf_arg727888,anf_arg7285928):R.ffi.throwNonFunApp(L[100],anf_fun726889,[l2346875,anf_arg727888,anf_arg7285928]);
};
try {
if(--R.GAS > 0) {
$z59325933 = $f59385939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59385939,
"from":L[100]});
}
} catch($e59305931) {
if(R.isCont($e59305931)) {
var $ss59345935 = {"from":L[100],
"go":function(ann_DASH_check_DASH_temp7255940) {
return $Hann_DASH_check_DASH_temp17035941(ann_DASH_check_DASH_temp7255940);
}};
$e59305931.stack[R.EXN_STACKHEIGHT++] = $ss59345935;
}
if(R.isPyretException($e59305931)) {
$e59305931.pyretStack.push(L[100]);
}
throw $e59305931;
}
var $ret59365937 = $Hann_DASH_check_DASH_temp17035941($z59325933);
++R.GAS;
return $ret59365937;
};
var $Hann_DASH_check_DASH_temp17035941 = function(ann_DASH_check_DASH_temp7255940) {
return ann_DASH_check_DASH_temp7255940;
};
var $Hnew_DASH_binds1702907 = function(new_DASH_binds333906,A113,body332894,desugar_DASH_expr117310,l330892) {
var anf_fun7195953 = G(A113,"s-let-expr",L[735]);
var $z59445945 = D;
var $f59505951 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(body332894):R.ffi.throwNonFunApp(L[734],desugar_DASH_expr117310.$var,[body332894]);
};
try {
if(--R.GAS > 0) {
$z59445945 = $f59505951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59505951,
"from":L[734]});
}
} catch($e59425943) {
if(R.isCont($e59425943)) {
var $ss59465947 = {"from":L[734],
"go":function(anf_arg7205952) {
return $Hanf_arg17015954(anf_arg7205952,anf_fun7195953,l330892,new_DASH_binds333906);
}};
$e59425943.stack[R.EXN_STACKHEIGHT++] = $ss59465947;
}
if(R.isPyretException($e59425943)) {
$e59425943.pyretStack.push(L[734]);
}
throw $e59425943;
}
var $ret59485949 = $Hanf_arg17015954($z59445945,anf_fun7195953,l330892,new_DASH_binds333906);
++R.GAS;
return $ret59485949;
};
var $Hanf_arg17015954 = function(anf_arg7205952,anf_fun7195953,l330892,new_DASH_binds333906) {
var $z59575958 = D;
var $f59635964 = function(_) {
return R.isFunction(anf_fun7195953)?anf_fun7195953.app(l330892,new_DASH_binds333906,anf_arg7205952):R.ffi.throwNonFunApp(L[103],anf_fun7195953,[l330892,new_DASH_binds333906,anf_arg7205952]);
};
try {
if(--R.GAS > 0) {
$z59575958 = $f59635964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59635964,
"from":L[103]});
}
} catch($e59555956) {
if(R.isCont($e59555956)) {
var $ss59595960 = {"from":L[103],
"go":function(ann_DASH_check_DASH_temp7025965) {
return $Hann_DASH_check_DASH_temp17005966(ann_DASH_check_DASH_temp7025965);
}};
$e59555956.stack[R.EXN_STACKHEIGHT++] = $ss59595960;
}
if(R.isPyretException($e59555956)) {
$e59555956.pyretStack.push(L[103]);
}
throw $e59555956;
}
var $ret59615962 = $Hann_DASH_check_DASH_temp17005966($z59575958);
++R.GAS;
return $ret59615962;
};
var $Hann_DASH_check_DASH_temp17005966 = function(ann_DASH_check_DASH_temp7025965) {
return ann_DASH_check_DASH_temp7025965;
};
var $Hann_DASH_check_DASH_temp1699923 = function(ann_DASH_check_DASH_temp703922) {
return ann_DASH_check_DASH_temp703922;
};
var $Hanf_arg1698942 = function(anf_arg712940,anf_fun711941,desugar_DASH_expr117310,l2338927,val340929) {
var $z59695970 = D;
var $f59755976 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(val340929):R.ffi.throwNonFunApp(L[736],desugar_DASH_expr117310.$var,[val340929]);
};
try {
if(--R.GAS > 0) {
$z59695970 = $f59755976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59755976,
"from":L[736]});
}
} catch($e59675968) {
if(R.isCont($e59675968)) {
var $ss59715972 = {"from":L[736],
"go":function(anf_arg7135977) {
return $Hanf_arg16975978(anf_arg7135977,anf_arg712940,anf_fun711941,l2338927);
}};
$e59675968.stack[R.EXN_STACKHEIGHT++] = $ss59715972;
}
if(R.isPyretException($e59675968)) {
$e59675968.pyretStack.push(L[736]);
}
throw $e59675968;
}
var $ret59735974 = $Hanf_arg16975978($z59695970,anf_arg712940,anf_fun711941,l2338927);
++R.GAS;
return $ret59735974;
};
var $Hanf_arg16975978 = function(anf_arg7135977,anf_arg712940,anf_fun711941,l2338927) {
var $z59815982 = D;
var $f59875988 = function(_) {
return R.isFunction(anf_fun711941)?anf_fun711941.app(l2338927,anf_arg712940,anf_arg7135977):R.ffi.throwNonFunApp(L[107],anf_fun711941,[l2338927,anf_arg712940,anf_arg7135977]);
};
try {
if(--R.GAS > 0) {
$z59815982 = $f59875988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59875988,
"from":L[107]});
}
} catch($e59795980) {
if(R.isCont($e59795980)) {
var $ss59835984 = {"from":L[107],
"go":function(ann_DASH_check_DASH_temp7105989) {
return $Hann_DASH_check_DASH_temp16965990(ann_DASH_check_DASH_temp7105989);
}};
$e59795980.stack[R.EXN_STACKHEIGHT++] = $ss59835984;
}
if(R.isPyretException($e59795980)) {
$e59795980.pyretStack.push(L[107]);
}
throw $e59795980;
}
var $ret59855986 = $Hann_DASH_check_DASH_temp16965990($z59815982);
++R.GAS;
return $ret59855986;
};
var $Hann_DASH_check_DASH_temp16965990 = function(ann_DASH_check_DASH_temp7105989) {
return ann_DASH_check_DASH_temp7105989;
};
var $Hanf_arg1695958 = function(anf_arg707956,anf_fun706957,desugar_DASH_expr117310,l2335943,val337945) {
var $z59935994 = D;
var $f59996000 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(val337945):R.ffi.throwNonFunApp(L[737],desugar_DASH_expr117310.$var,[val337945]);
};
try {
if(--R.GAS > 0) {
$z59935994 = $f59996000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59996000,
"from":L[737]});
}
} catch($e59915992) {
if(R.isCont($e59915992)) {
var $ss59955996 = {"from":L[737],
"go":function(anf_arg7086001) {
return $Hanf_arg16946002(anf_arg7086001,anf_arg707956,anf_fun706957,l2335943);
}};
$e59915992.stack[R.EXN_STACKHEIGHT++] = $ss59955996;
}
if(R.isPyretException($e59915992)) {
$e59915992.pyretStack.push(L[737]);
}
throw $e59915992;
}
var $ret59975998 = $Hanf_arg16946002($z59935994,anf_arg707956,anf_fun706957,l2335943);
++R.GAS;
return $ret59975998;
};
var $Hanf_arg16946002 = function(anf_arg7086001,anf_arg707956,anf_fun706957,l2335943) {
var $z60056006 = D;
var $f60116012 = function(_) {
return R.isFunction(anf_fun706957)?anf_fun706957.app(l2335943,anf_arg707956,anf_arg7086001):R.ffi.throwNonFunApp(L[110],anf_fun706957,[l2335943,anf_arg707956,anf_arg7086001]);
};
try {
if(--R.GAS > 0) {
$z60056006 = $f60116012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60116012,
"from":L[110]});
}
} catch($e60036004) {
if(R.isCont($e60036004)) {
var $ss60076008 = {"from":L[110],
"go":function(ann_DASH_check_DASH_temp7056013) {
return $Hann_DASH_check_DASH_temp16936014(ann_DASH_check_DASH_temp7056013);
}};
$e60036004.stack[R.EXN_STACKHEIGHT++] = $ss60076008;
}
if(R.isPyretException($e60036004)) {
$e60036004.pyretStack.push(L[110]);
}
throw $e60036004;
}
var $ret60096010 = $Hann_DASH_check_DASH_temp16936014($z60056006);
++R.GAS;
return $ret60096010;
};
var $Hann_DASH_check_DASH_temp16936014 = function(ann_DASH_check_DASH_temp7056013) {
return ann_DASH_check_DASH_temp7056013;
};
var $Hanf_arg1692978 = function(anf_arg699976,anf_fun697977,body321962,desugar_DASH_expr117310,l319960) {
var $z60176018 = D;
var $f60236024 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(body321962):R.ffi.throwNonFunApp(L[738],desugar_DASH_expr117310.$var,[body321962]);
};
try {
if(--R.GAS > 0) {
$z60176018 = $f60236024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60236024,
"from":L[738]});
}
} catch($e60156016) {
if(R.isCont($e60156016)) {
var $ss60196020 = {"from":L[738],
"go":function(anf_arg7006025) {
return $Hanf_arg16916026(anf_arg7006025,anf_arg699976,anf_fun697977,l319960);
}};
$e60156016.stack[R.EXN_STACKHEIGHT++] = $ss60196020;
}
if(R.isPyretException($e60156016)) {
$e60156016.pyretStack.push(L[738]);
}
throw $e60156016;
}
var $ret60216022 = $Hanf_arg16916026($z60176018,anf_arg699976,anf_fun697977,l319960);
++R.GAS;
return $ret60216022;
};
var $Hanf_arg16916026 = function(anf_arg7006025,anf_arg699976,anf_fun697977,l319960) {
var $z60296030 = D;
var $f60356036 = function(_) {
return R.isFunction(anf_fun697977)?anf_fun697977.app(l319960,anf_arg699976,anf_arg7006025):R.ffi.throwNonFunApp(L[113],anf_fun697977,[l319960,anf_arg699976,anf_arg7006025]);
};
try {
if(--R.GAS > 0) {
$z60296030 = $f60356036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60356036,
"from":L[113]});
}
} catch($e60276028) {
if(R.isCont($e60276028)) {
var $ss60316032 = {"from":L[113],
"go":function(ann_DASH_check_DASH_temp6846037) {
return $Hann_DASH_check_DASH_temp16906038(ann_DASH_check_DASH_temp6846037);
}};
$e60276028.stack[R.EXN_STACKHEIGHT++] = $ss60316032;
}
if(R.isPyretException($e60276028)) {
$e60276028.pyretStack.push(L[113]);
}
throw $e60276028;
}
var $ret60336034 = $Hann_DASH_check_DASH_temp16906038($z60296030);
++R.GAS;
return $ret60336034;
};
var $Hann_DASH_check_DASH_temp16906038 = function(ann_DASH_check_DASH_temp6846037) {
return ann_DASH_check_DASH_temp6846037;
};
var $Hann_DASH_check_DASH_temp1689994 = function(ann_DASH_check_DASH_temp685993) {
return ann_DASH_check_DASH_temp685993;
};
var $Hanf_arg16881017 = function(anf_arg6891015,anf_fun6881016,l23241002,name3251003) {
var $z60416042 = D;
var $f60476048 = function(_) {
return R.isFunction(anf_fun6881016)?anf_fun6881016.app(l23241002,name3251003,anf_arg6891015):R.ffi.throwNonFunApp(L[120],anf_fun6881016,[l23241002,name3251003,anf_arg6891015]);
};
try {
if(--R.GAS > 0) {
$z60416042 = $f60476048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60476048,
"from":L[120]});
}
} catch($e60396040) {
if(R.isCont($e60396040)) {
var $ss60436044 = {"from":L[120],
"go":function(ann_DASH_check_DASH_temp6876049) {
return $Hann_DASH_check_DASH_temp16876050(ann_DASH_check_DASH_temp6876049);
}};
$e60396040.stack[R.EXN_STACKHEIGHT++] = $ss60436044;
}
if(R.isPyretException($e60396040)) {
$e60396040.pyretStack.push(L[120]);
}
throw $e60396040;
}
var $ret60456046 = $Hann_DASH_check_DASH_temp16876050($z60416042);
++R.GAS;
return $ret60456046;
};
var $Hann_DASH_check_DASH_temp16876050 = function(ann_DASH_check_DASH_temp6876049) {
return ann_DASH_check_DASH_temp6876049;
};
var $Hanf_arg16861038 = function(anf_arg6801036,anf_fun6791037,l3131023,name3141024) {
var $z60536054 = D;
var $f60596060 = function(_) {
return R.isFunction(anf_fun6791037)?anf_fun6791037.app(l3131023,name3141024,anf_arg6801036):R.ffi.throwNonFunApp(L[124],anf_fun6791037,[l3131023,name3141024,anf_arg6801036]);
};
try {
if(--R.GAS > 0) {
$z60536054 = $f60596060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60596060,
"from":L[124]});
}
} catch($e60516052) {
if(R.isCont($e60516052)) {
var $ss60556056 = {"from":L[124],
"go":function(ann_DASH_check_DASH_temp6786061) {
return $Hann_DASH_check_DASH_temp16856062(ann_DASH_check_DASH_temp6786061);
}};
$e60516052.stack[R.EXN_STACKHEIGHT++] = $ss60556056;
}
if(R.isPyretException($e60516052)) {
$e60516052.pyretStack.push(L[124]);
}
throw $e60516052;
}
var $ret60576058 = $Hann_DASH_check_DASH_temp16856062($z60536054);
++R.GAS;
return $ret60576058;
};
var $Hann_DASH_check_DASH_temp16856062 = function(ann_DASH_check_DASH_temp6786061) {
return ann_DASH_check_DASH_temp6786061;
};
var $Hanf_arg16841055 = function(anf_arg6761053,anf_fun6751054,keyword_DASH_val3121042,l3091039,name3101040) {
var $z60656066 = D;
var $f60716072 = function(_) {
return R.isFunction(anf_fun6751054)?anf_fun6751054.app(l3091039,name3101040,anf_arg6761053,keyword_DASH_val3121042):R.ffi.throwNonFunApp(L[127],anf_fun6751054,[l3091039,name3101040,anf_arg6761053,keyword_DASH_val3121042]);
};
try {
if(--R.GAS > 0) {
$z60656066 = $f60716072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60716072,
"from":L[127]});
}
} catch($e60636064) {
if(R.isCont($e60636064)) {
var $ss60676068 = {"from":L[127],
"go":function(ann_DASH_check_DASH_temp6746073) {
return $Hann_DASH_check_DASH_temp16836074(ann_DASH_check_DASH_temp6746073);
}};
$e60636064.stack[R.EXN_STACKHEIGHT++] = $ss60676068;
}
if(R.isPyretException($e60636064)) {
$e60636064.pyretStack.push(L[127]);
}
throw $e60636064;
}
var $ret60696070 = $Hann_DASH_check_DASH_temp16836074($z60656066);
++R.GAS;
return $ret60696070;
};
var $Hann_DASH_check_DASH_temp16836074 = function(ann_DASH_check_DASH_temp6746073) {
return ann_DASH_check_DASH_temp6746073;
};
var $Hanf_arg16821075 = function(anf_arg6691073,_check3081061,anf_fun6671074,ann3051058,body3071060,desugar_DASH_ann98272,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056) {
var $z60776078 = D;
var $f60836084 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ann3051058):R.ffi.throwNonFunApp(L[739],desugar_DASH_ann98272.$var,[ann3051058]);
};
try {
if(--R.GAS > 0) {
$z60776078 = $f60836084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60836084,
"from":L[739]});
}
} catch($e60756076) {
if(R.isCont($e60756076)) {
var $ss60796080 = {"from":L[739],
"go":function(anf_arg6706085) {
return $Hanf_arg16816086(anf_arg6706085,_check3081061,anf_arg6691073,anf_fun6671074,body3071060,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056);
}};
$e60756076.stack[R.EXN_STACKHEIGHT++] = $ss60796080;
}
if(R.isPyretException($e60756076)) {
$e60756076.pyretStack.push(L[739]);
}
throw $e60756076;
}
var $ret60816082 = $Hanf_arg16816086($z60776078,_check3081061,anf_arg6691073,anf_fun6671074,body3071060,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056);
++R.GAS;
return $ret60816082;
};
var $Hanf_arg16816086 = function(anf_arg6706085,_check3081061,anf_arg6691073,anf_fun6671074,body3071060,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056) {
var $z60896090 = D;
var $f60956096 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(body3071060):R.ffi.throwNonFunApp(L[740],desugar_DASH_expr117310.$var,[body3071060]);
};
try {
if(--R.GAS > 0) {
$z60896090 = $f60956096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60956096,
"from":L[740]});
}
} catch($e60876088) {
if(R.isCont($e60876088)) {
var $ss60916092 = {"from":L[740],
"go":function(anf_arg6716097) {
return $Hanf_arg16806098(anf_arg6716097,_check3081061,anf_arg6691073,anf_arg6706085,anf_fun6671074,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056);
}};
$e60876088.stack[R.EXN_STACKHEIGHT++] = $ss60916092;
}
if(R.isPyretException($e60876088)) {
$e60876088.pyretStack.push(L[740]);
}
throw $e60876088;
}
var $ret60936094 = $Hanf_arg16806098($z60896090,_check3081061,anf_arg6691073,anf_arg6706085,anf_fun6671074,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056);
++R.GAS;
return $ret60936094;
};
var $Hanf_arg16806098 = function(anf_arg6716097,_check3081061,anf_arg6691073,anf_arg6706085,anf_fun6671074,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3061059,l3031056) {
var $z61016102 = D;
var $f61076108 = function(_) {
return R.isFunction(desugar_DASH_opt115306.$var)?desugar_DASH_opt115306.$var.app(desugar_DASH_expr117310.$var,_check3081061):R.ffi.throwNonFunApp(L[741],desugar_DASH_opt115306.$var,[desugar_DASH_expr117310.$var,_check3081061]);
};
try {
if(--R.GAS > 0) {
$z61016102 = $f61076108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61076108,
"from":L[741]});
}
} catch($e60996100) {
if(R.isCont($e60996100)) {
var $ss61036104 = {"from":L[741],
"go":function(anf_arg6726109) {
return $Hanf_arg16796110(anf_arg6726109,anf_arg6691073,anf_arg6706085,anf_arg6716097,anf_fun6671074,doc3061059,l3031056);
}};
$e60996100.stack[R.EXN_STACKHEIGHT++] = $ss61036104;
}
if(R.isPyretException($e60996100)) {
$e60996100.pyretStack.push(L[741]);
}
throw $e60996100;
}
var $ret61056106 = $Hanf_arg16796110($z61016102,anf_arg6691073,anf_arg6706085,anf_arg6716097,anf_fun6671074,doc3061059,l3031056);
++R.GAS;
return $ret61056106;
};
var $Hanf_arg16796110 = function(anf_arg6726109,anf_arg6691073,anf_arg6706085,anf_arg6716097,anf_fun6671074,doc3061059,l3031056) {
var $z61136114 = D;
var $f61196120 = function(_) {
return R.isFunction(anf_fun6671074)?anf_fun6671074.app(l3031056,anf_arg6691073,anf_arg6706085,doc3061059,anf_arg6716097,anf_arg6726109):R.ffi.throwNonFunApp(L[130],anf_fun6671074,[l3031056,anf_arg6691073,anf_arg6706085,doc3061059,anf_arg6716097,anf_arg6726109]);
};
try {
if(--R.GAS > 0) {
$z61136114 = $f61196120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61196120,
"from":L[130]});
}
} catch($e61116112) {
if(R.isCont($e61116112)) {
var $ss61156116 = {"from":L[130],
"go":function(ann_DASH_check_DASH_temp6666121) {
return $Hann_DASH_check_DASH_temp16786122(ann_DASH_check_DASH_temp6666121);
}};
$e61116112.stack[R.EXN_STACKHEIGHT++] = $ss61156116;
}
if(R.isPyretException($e61116112)) {
$e61116112.pyretStack.push(L[130]);
}
throw $e61116112;
}
var $ret61176118 = $Hann_DASH_check_DASH_temp16786122($z61136114);
++R.GAS;
return $ret61176118;
};
var $Hann_DASH_check_DASH_temp16786122 = function(ann_DASH_check_DASH_temp6666121) {
return ann_DASH_check_DASH_temp6666121;
};
var $Hanf_arg16771096 = function(anf_arg6611094,_check3021082,anf_fun6591095,ann2991079,body3011081,desugar_DASH_ann98272,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077) {
var $z61256126 = D;
var $f61316132 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ann2991079):R.ffi.throwNonFunApp(L[742],desugar_DASH_ann98272.$var,[ann2991079]);
};
try {
if(--R.GAS > 0) {
$z61256126 = $f61316132();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61316132,
"from":L[742]});
}
} catch($e61236124) {
if(R.isCont($e61236124)) {
var $ss61276128 = {"from":L[742],
"go":function(anf_arg6626133) {
return $Hanf_arg16766134(anf_arg6626133,_check3021082,anf_arg6611094,anf_fun6591095,body3011081,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077);
}};
$e61236124.stack[R.EXN_STACKHEIGHT++] = $ss61276128;
}
if(R.isPyretException($e61236124)) {
$e61236124.pyretStack.push(L[742]);
}
throw $e61236124;
}
var $ret61296130 = $Hanf_arg16766134($z61256126,_check3021082,anf_arg6611094,anf_fun6591095,body3011081,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077);
++R.GAS;
return $ret61296130;
};
var $Hanf_arg16766134 = function(anf_arg6626133,_check3021082,anf_arg6611094,anf_fun6591095,body3011081,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077) {
var $z61376138 = D;
var $f61436144 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(body3011081):R.ffi.throwNonFunApp(L[743],desugar_DASH_expr117310.$var,[body3011081]);
};
try {
if(--R.GAS > 0) {
$z61376138 = $f61436144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61436144,
"from":L[743]});
}
} catch($e61356136) {
if(R.isCont($e61356136)) {
var $ss61396140 = {"from":L[743],
"go":function(anf_arg6636145) {
return $Hanf_arg16756146(anf_arg6636145,_check3021082,anf_arg6611094,anf_arg6626133,anf_fun6591095,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077);
}};
$e61356136.stack[R.EXN_STACKHEIGHT++] = $ss61396140;
}
if(R.isPyretException($e61356136)) {
$e61356136.pyretStack.push(L[743]);
}
throw $e61356136;
}
var $ret61416142 = $Hanf_arg16756146($z61376138,_check3021082,anf_arg6611094,anf_arg6626133,anf_fun6591095,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077);
++R.GAS;
return $ret61416142;
};
var $Hanf_arg16756146 = function(anf_arg6636145,_check3021082,anf_arg6611094,anf_arg6626133,anf_fun6591095,desugar_DASH_expr117310,desugar_DASH_opt115306,doc3001080,l2961076,params2971077) {
var $z61496150 = D;
var $f61556156 = function(_) {
return R.isFunction(desugar_DASH_opt115306.$var)?desugar_DASH_opt115306.$var.app(desugar_DASH_expr117310.$var,_check3021082):R.ffi.throwNonFunApp(L[744],desugar_DASH_opt115306.$var,[desugar_DASH_expr117310.$var,_check3021082]);
};
try {
if(--R.GAS > 0) {
$z61496150 = $f61556156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61556156,
"from":L[744]});
}
} catch($e61476148) {
if(R.isCont($e61476148)) {
var $ss61516152 = {"from":L[744],
"go":function(anf_arg6646157) {
return $Hanf_arg16746158(anf_arg6646157,anf_arg6611094,anf_arg6626133,anf_arg6636145,anf_fun6591095,doc3001080,l2961076,params2971077);
}};
$e61476148.stack[R.EXN_STACKHEIGHT++] = $ss61516152;
}
if(R.isPyretException($e61476148)) {
$e61476148.pyretStack.push(L[744]);
}
throw $e61476148;
}
var $ret61536154 = $Hanf_arg16746158($z61496150,anf_arg6611094,anf_arg6626133,anf_arg6636145,anf_fun6591095,doc3001080,l2961076,params2971077);
++R.GAS;
return $ret61536154;
};
var $Hanf_arg16746158 = function(anf_arg6646157,anf_arg6611094,anf_arg6626133,anf_arg6636145,anf_fun6591095,doc3001080,l2961076,params2971077) {
var $z61616162 = D;
var $f61676168 = function(_) {
return R.isFunction(anf_fun6591095)?anf_fun6591095.app(l2961076,params2971077,anf_arg6611094,anf_arg6626133,doc3001080,anf_arg6636145,anf_arg6646157):R.ffi.throwNonFunApp(L[134],anf_fun6591095,[l2961076,params2971077,anf_arg6611094,anf_arg6626133,doc3001080,anf_arg6636145,anf_arg6646157]);
};
try {
if(--R.GAS > 0) {
$z61616162 = $f61676168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61676168,
"from":L[134]});
}
} catch($e61596160) {
if(R.isCont($e61596160)) {
var $ss61636164 = {"from":L[134],
"go":function(ann_DASH_check_DASH_temp6586169) {
return $Hann_DASH_check_DASH_temp16736170(ann_DASH_check_DASH_temp6586169);
}};
$e61596160.stack[R.EXN_STACKHEIGHT++] = $ss61636164;
}
if(R.isPyretException($e61596160)) {
$e61596160.pyretStack.push(L[134]);
}
throw $e61596160;
}
var $ret61656166 = $Hann_DASH_check_DASH_temp16736170($z61616162);
++R.GAS;
return $ret61656166;
};
var $Hann_DASH_check_DASH_temp16736170 = function(ann_DASH_check_DASH_temp6586169) {
return ann_DASH_check_DASH_temp6586169;
};
var $Hanf_arg16721113 = function(anf_arg6561111,anf_fun6541112,f2941098,l2931097) {
var $z61736174 = D;
var $f61796180 = function(_) {
return R.isFunction(anf_fun6541112)?anf_fun6541112.app(l2931097,f2941098,anf_arg6561111):R.ffi.throwNonFunApp(L[138],anf_fun6541112,[l2931097,f2941098,anf_arg6561111]);
};
try {
if(--R.GAS > 0) {
$z61736174 = $f61796180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61796180,
"from":L[138]});
}
} catch($e61716172) {
if(R.isCont($e61716172)) {
var $ss61756176 = {"from":L[138],
"go":function(ann_DASH_check_DASH_temp6536181) {
return $Hann_DASH_check_DASH_temp16716182(ann_DASH_check_DASH_temp6536181);
}};
$e61716172.stack[R.EXN_STACKHEIGHT++] = $ss61756176;
}
if(R.isPyretException($e61716172)) {
$e61716172.pyretStack.push(L[138]);
}
throw $e61716172;
}
var $ret61776178 = $Hann_DASH_check_DASH_temp16716182($z61736174);
++R.GAS;
return $ret61776178;
};
var $Hann_DASH_check_DASH_temp16716182 = function(ann_DASH_check_DASH_temp6536181) {
return ann_DASH_check_DASH_temp6536181;
};
var $Hanf_arg16701129 = function(anf_arg6511128,ds_DASH_curry114304,f2911115,l2901114) {
var $z61856186 = D;
var $f61916192 = function(_) {
return R.isFunction(ds_DASH_curry114304.$var)?ds_DASH_curry114304.$var.app(l2901114,f2911115,anf_arg6511128):R.ffi.throwNonFunApp(L[142],ds_DASH_curry114304.$var,[l2901114,f2911115,anf_arg6511128]);
};
try {
if(--R.GAS > 0) {
$z61856186 = $f61916192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61916192,
"from":L[142]});
}
} catch($e61836184) {
if(R.isCont($e61836184)) {
var $ss61876188 = {"from":L[142],
"go":function(ann_DASH_check_DASH_temp6496193) {
return $Hann_DASH_check_DASH_temp16696194(ann_DASH_check_DASH_temp6496193);
}};
$e61836184.stack[R.EXN_STACKHEIGHT++] = $ss61876188;
}
if(R.isPyretException($e61836184)) {
$e61836184.pyretStack.push(L[142]);
}
throw $e61836184;
}
var $ret61896190 = $Hann_DASH_check_DASH_temp16696194($z61856186);
++R.GAS;
return $ret61896190;
};
var $Hann_DASH_check_DASH_temp16696194 = function(ann_DASH_check_DASH_temp6496193) {
return ann_DASH_check_DASH_temp6496193;
};
var $Hann_DASH_check_DASH_temp16681143 = function(ann_DASH_check_DASH_temp6471142) {
return ann_DASH_check_DASH_temp6471142;
};
var $Hanf_arg16671159 = function(anf_arg6451157,anf_fun6431158,l2861144) {
var $z61976198 = D;
var $f62036204 = function(_) {
return R.isFunction(anf_fun6431158)?anf_fun6431158.app(l2861144,anf_arg6451157):R.ffi.throwNonFunApp(L[146],anf_fun6431158,[l2861144,anf_arg6451157]);
};
try {
if(--R.GAS > 0) {
$z61976198 = $f62036204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62036204,
"from":L[146]});
}
} catch($e61956196) {
if(R.isCont($e61956196)) {
var $ss61996200 = {"from":L[146],
"go":function(ann_DASH_check_DASH_temp6426205) {
return $Hann_DASH_check_DASH_temp16666206(ann_DASH_check_DASH_temp6426205);
}};
$e61956196.stack[R.EXN_STACKHEIGHT++] = $ss61996200;
}
if(R.isPyretException($e61956196)) {
$e61956196.pyretStack.push(L[146]);
}
throw $e61956196;
}
var $ret62016202 = $Hann_DASH_check_DASH_temp16666206($z61976198);
++R.GAS;
return $ret62016202;
};
var $Hann_DASH_check_DASH_temp16666206 = function(ann_DASH_check_DASH_temp6426205) {
return ann_DASH_check_DASH_temp6426205;
};
var $Hanf_arg16651177 = function(anf_arg6361175,anf_fun6351176,checks2851164,desugar_DASH_afield97270,desugar_DASH_expr117310,l2811160,provides2831162,types2841163) {
var $z62096210 = D;
var $f62156216 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(provides2831162):R.ffi.throwNonFunApp(L[745],desugar_DASH_expr117310.$var,[provides2831162]);
};
try {
if(--R.GAS > 0) {
$z62096210 = $f62156216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62156216,
"from":L[745]});
}
} catch($e62076208) {
if(R.isCont($e62076208)) {
var $ss62116212 = {"from":L[745],
"go":function(anf_arg6376217) {
return $Hanf_arg16646218(anf_arg6376217,anf_arg6361175,anf_fun6351176,checks2851164,desugar_DASH_afield97270,desugar_DASH_expr117310,l2811160,types2841163);
}};
$e62076208.stack[R.EXN_STACKHEIGHT++] = $ss62116212;
}
if(R.isPyretException($e62076208)) {
$e62076208.pyretStack.push(L[745]);
}
throw $e62076208;
}
var $ret62136214 = $Hanf_arg16646218($z62096210,anf_arg6361175,anf_fun6351176,checks2851164,desugar_DASH_afield97270,desugar_DASH_expr117310,l2811160,types2841163);
++R.GAS;
return $ret62136214;
};
var $Hanf_arg16646218 = function(anf_arg6376217,anf_arg6361175,anf_fun6351176,checks2851164,desugar_DASH_afield97270,desugar_DASH_expr117310,l2811160,types2841163) {
var anf_fun6386229 = G(types2841163,"map",L[747]);
var $z62216222 = D;
var $f62276228 = function(_) {
return R.isFunction(anf_fun6386229)?anf_fun6386229.app(desugar_DASH_afield97270.$var):R.ffi.throwNonFunApp(L[746],anf_fun6386229,[desugar_DASH_afield97270.$var]);
};
try {
if(--R.GAS > 0) {
$z62216222 = $f62276228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62276228,
"from":L[746]});
}
} catch($e62196220) {
if(R.isCont($e62196220)) {
var $ss62236224 = {"from":L[746],
"go":function(anf_arg6396230) {
return $Hanf_arg16636231(anf_arg6396230,anf_arg6361175,anf_arg6376217,anf_fun6351176,checks2851164,desugar_DASH_expr117310,l2811160);
}};
$e62196220.stack[R.EXN_STACKHEIGHT++] = $ss62236224;
}
if(R.isPyretException($e62196220)) {
$e62196220.pyretStack.push(L[746]);
}
throw $e62196220;
}
var $ret62256226 = $Hanf_arg16636231($z62216222,anf_arg6361175,anf_arg6376217,anf_fun6351176,checks2851164,desugar_DASH_expr117310,l2811160);
++R.GAS;
return $ret62256226;
};
var $Hanf_arg16636231 = function(anf_arg6396230,anf_arg6361175,anf_arg6376217,anf_fun6351176,checks2851164,desugar_DASH_expr117310,l2811160) {
var $z62346235 = D;
var $f62406241 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var.app(checks2851164):R.ffi.throwNonFunApp(L[748],desugar_DASH_expr117310.$var,[checks2851164]);
};
try {
if(--R.GAS > 0) {
$z62346235 = $f62406241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62406241,
"from":L[748]});
}
} catch($e62326233) {
if(R.isCont($e62326233)) {
var $ss62366237 = {"from":L[748],
"go":function(anf_arg6406242) {
return $Hanf_arg16626243(anf_arg6406242,anf_arg6361175,anf_arg6376217,anf_arg6396230,anf_fun6351176,l2811160);
}};
$e62326233.stack[R.EXN_STACKHEIGHT++] = $ss62366237;
}
if(R.isPyretException($e62326233)) {
$e62326233.pyretStack.push(L[748]);
}
throw $e62326233;
}
var $ret62386239 = $Hanf_arg16626243($z62346235,anf_arg6361175,anf_arg6376217,anf_arg6396230,anf_fun6351176,l2811160);
++R.GAS;
return $ret62386239;
};
var $Hanf_arg16626243 = function(anf_arg6406242,anf_arg6361175,anf_arg6376217,anf_arg6396230,anf_fun6351176,l2811160) {
var $z62466247 = D;
var $f62526253 = function(_) {
return R.isFunction(anf_fun6351176)?anf_fun6351176.app(l2811160,anf_arg6361175,anf_arg6376217,anf_arg6396230,anf_arg6406242):R.ffi.throwNonFunApp(L[150],anf_fun6351176,[l2811160,anf_arg6361175,anf_arg6376217,anf_arg6396230,anf_arg6406242]);
};
try {
if(--R.GAS > 0) {
$z62466247 = $f62526253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62526253,
"from":L[150]});
}
} catch($e62446245) {
if(R.isCont($e62446245)) {
var $ss62486249 = {"from":L[150],
"go":function(ann_DASH_check_DASH_temp6346254) {
return $Hann_DASH_check_DASH_temp16616255(ann_DASH_check_DASH_temp6346254);
}};
$e62446245.stack[R.EXN_STACKHEIGHT++] = $ss62486249;
}
if(R.isPyretException($e62446245)) {
$e62446245.pyretStack.push(L[150]);
}
throw $e62446245;
}
var $ret62506251 = $Hann_DASH_check_DASH_temp16616255($z62466247);
++R.GAS;
return $ret62506251;
};
var $Hann_DASH_check_DASH_temp16616255 = function(ann_DASH_check_DASH_temp6346254) {
return ann_DASH_check_DASH_temp6346254;
};
var $Hann_DASH_check_DASH_temp16601194 = function(ann_DASH_check_DASH_temp6201193) {
return ann_DASH_check_DASH_temp6201193;
};
var $Hanf_arg16591206 = function(anf_arg6281205,_plus7,raise10) {
var $z62586259 = D;
var $f62646265 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Non-bind given to desugar-bind: "),anf_arg6281205):R.ffi.throwNonFunApp(L[749],_plus7,[("Non-bind given to desugar-bind: "),anf_arg6281205]);
};
try {
if(--R.GAS > 0) {
$z62586259 = $f62646265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62646265,
"from":L[749]});
}
} catch($e62566257) {
if(R.isCont($e62566257)) {
var $ss62606261 = {"from":L[749],
"go":function(anf_arg6296266) {
return $Hanf_arg16586267(anf_arg6296266,raise10);
}};
$e62566257.stack[R.EXN_STACKHEIGHT++] = $ss62606261;
}
if(R.isPyretException($e62566257)) {
$e62566257.pyretStack.push(L[749]);
}
throw $e62566257;
}
var $ret62626263 = $Hanf_arg16586267($z62586259,raise10);
++R.GAS;
return $ret62626263;
};
var $Hanf_arg16586267 = function(anf_arg6296266,raise10) {
var $z62706271 = D;
var $f62766277 = function(_) {
return R.isFunction(raise10)?raise10.app(anf_arg6296266):R.ffi.throwNonFunApp(L[155],raise10,[anf_arg6296266]);
};
try {
if(--R.GAS > 0) {
$z62706271 = $f62766277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62766277,
"from":L[155]});
}
} catch($e62686269) {
if(R.isCont($e62686269)) {
var $ss62726273 = {"from":L[155],
"go":function(ann_DASH_check_DASH_temp6276278) {
return $Hann_DASH_check_DASH_temp16576279(ann_DASH_check_DASH_temp6276278);
}};
$e62686269.stack[R.EXN_STACKHEIGHT++] = $ss62726273;
}
if(R.isPyretException($e62686269)) {
$e62686269.pyretStack.push(L[155]);
}
throw $e62686269;
}
var $ret62746275 = $Hann_DASH_check_DASH_temp16576279($z62706271);
++R.GAS;
return $ret62746275;
};
var $Hann_DASH_check_DASH_temp16576279 = function(ann_DASH_check_DASH_temp6276278) {
return ann_DASH_check_DASH_temp6276278;
};
var $Hanf_arg16561224 = function(anf_arg6241222,anf_fun6231223,l2761208,name2781210,shadows2771209) {
var $z62826283 = D;
var $f62886289 = function(_) {
return R.isFunction(anf_fun6231223)?anf_fun6231223.app(l2761208,shadows2771209,name2781210,anf_arg6241222):R.ffi.throwNonFunApp(L[157],anf_fun6231223,[l2761208,shadows2771209,name2781210,anf_arg6241222]);
};
try {
if(--R.GAS > 0) {
$z62826283 = $f62886289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62886289,
"from":L[157]});
}
} catch($e62806281) {
if(R.isCont($e62806281)) {
var $ss62846285 = {"from":L[157],
"go":function(ann_DASH_check_DASH_temp6226290) {
return $Hann_DASH_check_DASH_temp16556291(ann_DASH_check_DASH_temp6226290);
}};
$e62806281.stack[R.EXN_STACKHEIGHT++] = $ss62846285;
}
if(R.isPyretException($e62806281)) {
$e62806281.pyretStack.push(L[157]);
}
throw $e62806281;
}
var $ret62866287 = $Hann_DASH_check_DASH_temp16556291($z62826283);
++R.GAS;
return $ret62866287;
};
var $Hann_DASH_check_DASH_temp16556291 = function(ann_DASH_check_DASH_temp6226290) {
return ann_DASH_check_DASH_temp6226290;
};
var $Hann_DASH_check_DASH_temp16541242 = function(ann_DASH_check_DASH_temp6091241) {
return ann_DASH_check_DASH_temp6091241;
};
var $Hanf_arg16531258 = function(anf_arg6141257,some6456) {
var $z62946295 = D;
var $f63006301 = function(_) {
return R.isFunction(some6456)?some6456.app(anf_arg6141257):R.ffi.throwNonFunApp(L[163],some6456,[anf_arg6141257]);
};
try {
if(--R.GAS > 0) {
$z62946295 = $f63006301();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63006301,
"from":L[163]});
}
} catch($e62926293) {
if(R.isCont($e62926293)) {
var $ss62966297 = {"from":L[163],
"go":function(ann_DASH_check_DASH_temp6136302) {
return $Hann_DASH_check_DASH_temp16526303(ann_DASH_check_DASH_temp6136302);
}};
$e62926293.stack[R.EXN_STACKHEIGHT++] = $ss62966297;
}
if(R.isPyretException($e62926293)) {
$e62926293.pyretStack.push(L[163]);
}
throw $e62926293;
}
var $ret62986299 = $Hann_DASH_check_DASH_temp16526303($z62946295);
++R.GAS;
return $ret62986299;
};
var $Hann_DASH_check_DASH_temp16526303 = function(ann_DASH_check_DASH_temp6136302) {
return ann_DASH_check_DASH_temp6136302;
};
var $Hann_DASH_check_DASH_temp16511280 = function(ann_DASH_check_DASH_temp5611279) {
return ann_DASH_check_DASH_temp5611279;
};
var $Hann_DASH_check_DASH_temp16501292 = function(ann_DASH_check_DASH_temp6061291) {
return ann_DASH_check_DASH_temp6061291;
};
var $Hif_DASH_16491308 = function(if_DASH_371307,A113,args2601263,ds_DASH_curry_DASH_args111298,fallthrough2611264,l2581261,link3152,list2753,m2671296,mk_DASH_id101278,none6355) {
var if_helper5836315 = R.makeFunction(function(if_helper_arg5846333) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[171],1,arguments);
}
var ann_DASH_check_DASH_temp5826334 = if_helper_arg5846333;
return ann_DASH_check_DASH_temp5826334;
});
var anf_if5876332 = R.isBoolean(if_DASH_371307);
if(R.isPyretTrue(anf_if5876332)) {
if(R.isPyretTrue(if_DASH_371307)) {
var $z63066307 = D;
var $f63126313 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l2581261,("recv-")):R.ffi.throwNonFunApp(L[750],mk_DASH_id101278.$var,[l2581261,("recv-")]);
};
try {
if(--R.GAS > 0) {
$z63066307 = $f63126313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63126313,
"from":L[750]});
}
} catch($e63046305) {
if(R.isCont($e63046305)) {
var $ss63086309 = {"from":L[750],
"go":function(curried_DASH_obj2686314) {
return $Hcurried_DASH_obj16476316(curried_DASH_obj2686314,A113,args2601263,ds_DASH_curry_DASH_args111298,if_helper5836315,l2581261,link3152,list2753,m2671296,none6355);
}};
$e63046305.stack[R.EXN_STACKHEIGHT++] = $ss63086309;
}
if(R.isPyretException($e63046305)) {
$e63046305.pyretStack.push(L[750]);
}
throw $e63046305;
}
var $ret63106311 = $Hcurried_DASH_obj16476316($z63066307,A113,args2601263,ds_DASH_curry_DASH_args111298,if_helper5836315,l2581261,link3152,list2753,m2671296,none6355);
++R.GAS;
return $ret63106311;
} else {
var $z63196320 = D;
var $f63256326 = function(_) {
return R.isFunction(fallthrough2611264.$var)?fallthrough2611264.$var.app():R.ffi.throwNonFunApp(L[751],fallthrough2611264.$var,[]);
};
try {
if(--R.GAS > 0) {
$z63196320 = $f63256326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63256326,
"from":L[751]});
}
} catch($e63176318) {
if(R.isCont($e63176318)) {
var $ss63216322 = {"from":L[751],
"go":function(cont_tail_arg5886327) {
return $Hcont_tail_arg16486328(cont_tail_arg5886327,if_helper5836315);
}};
$e63176318.stack[R.EXN_STACKHEIGHT++] = $ss63216322;
}
if(R.isPyretException($e63176318)) {
$e63176318.pyretStack.push(L[751]);
}
throw $e63176318;
}
var $ret63236324 = $Hcont_tail_arg16486328($z63196320,if_helper5836315);
++R.GAS;
return $ret63236324;
}
} else {
var cont_tail_arg5856331 = R.throwNonBooleanCondition(L[171],("if"),if_DASH_371307);
if(--R.GAS > 0) {
$z63296330 = R.isFunction(if_helper5836315)?if_helper5836315.app(cont_tail_arg5856331):R.ffi.throwNonFunApp(L[171],if_helper5836315,[cont_tail_arg5856331]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5836315)?if_helper5836315.app(cont_tail_arg5856331):R.ffi.throwNonFunApp(L[171],if_helper5836315,[cont_tail_arg5856331]);
},
"from":L[171]});
}
++R.GAS;
return $z63296330;
}
};
var $Hcurried_DASH_obj16476316 = function(curried_DASH_obj2686314,A113,args2601263,ds_DASH_curry_DASH_args111298,if_helper5836315,l2581261,link3152,list2753,m2671296,none6355) {
var $z63376338 = D;
var $f63436344 = function(_) {
return R.isFunction(ds_DASH_curry_DASH_args111298.$var)?ds_DASH_curry_DASH_args111298.$var.app(l2581261,args2601263):R.ffi.throwNonFunApp(L[752],ds_DASH_curry_DASH_args111298.$var,[l2581261,args2601263]);
};
try {
if(--R.GAS > 0) {
$z63376338 = $f63436344();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63436344,
"from":L[752]});
}
} catch($e63356336) {
if(R.isCont($e63356336)) {
var $ss63396340 = {"from":L[752],
"go":function(params_DASH_and_DASH_args2696345) {
return $Hparams_DASH_and_DASH_args16466346(params_DASH_and_DASH_args2696345,A113,curried_DASH_obj2686314,if_helper5836315,l2581261,link3152,list2753,m2671296,none6355);
}};
$e63356336.stack[R.EXN_STACKHEIGHT++] = $ss63396340;
}
if(R.isPyretException($e63356336)) {
$e63356336.pyretStack.push(L[752]);
}
throw $e63356336;
}
var $ret63416342 = $Hparams_DASH_and_DASH_args16466346($z63376338,A113,curried_DASH_obj2686314,if_helper5836315,l2581261,link3152,list2753,m2671296,none6355);
++R.GAS;
return $ret63416342;
};
var $Hparams_DASH_and_DASH_args16466346 = function(params_DASH_and_DASH_args2696345,A113,curried_DASH_obj2686314,if_helper5836315,l2581261,link3152,list2753,m2671296,none6355) {
var params2706360 = G(params_DASH_and_DASH_args2696345,"left",L[755]);
var anf_fun5906359 = G(A113,"s-lam",L[754]);
var anf_fun5916357 = G(list2753,"make",L[753]);
var $z63496350 = D;
var $f63556356 = function(_) {
return R.isFunction(anf_fun5916357)?anf_fun5916357.app([]):R.ffi.throwNonFunApp(L[753],anf_fun5916357,[[]]);
};
try {
if(--R.GAS > 0) {
$z63496350 = $f63556356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63556356,
"from":L[753]});
}
} catch($e63476348) {
if(R.isCont($e63476348)) {
var $ss63516352 = {"from":L[753],
"go":function(anf_arg5926358) {
return $Hanf_arg16456361(anf_arg5926358,A113,anf_fun5906359,curried_DASH_obj2686314,if_helper5836315,l2581261,link3152,m2671296,none6355,params_DASH_and_DASH_args2696345,params2706360);
}};
$e63476348.stack[R.EXN_STACKHEIGHT++] = $ss63516352;
}
if(R.isPyretException($e63476348)) {
$e63476348.pyretStack.push(L[753]);
}
throw $e63476348;
}
var $ret63536354 = $Hanf_arg16456361($z63496350,A113,anf_fun5906359,curried_DASH_obj2686314,if_helper5836315,l2581261,link3152,m2671296,none6355,params_DASH_and_DASH_args2696345,params2706360);
++R.GAS;
return $ret63536354;
};
var $Hanf_arg16456361 = function(anf_arg5926358,A113,anf_fun5906359,curried_DASH_obj2686314,if_helper5836315,l2581261,link3152,m2671296,none6355,params_DASH_and_DASH_args2696345,params2706360) {
var anf_arg5936372 = G(curried_DASH_obj2686314,"id-b",L[757]);
var $z63646365 = D;
var $f63706371 = function(_) {
return R.isFunction(link3152)?link3152.app(anf_arg5936372,params2706360):R.ffi.throwNonFunApp(L[756],link3152,[anf_arg5936372,params2706360]);
};
try {
if(--R.GAS > 0) {
$z63646365 = $f63706371();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63706371,
"from":L[756]});
}
} catch($e63626363) {
if(R.isCont($e63626363)) {
var $ss63666367 = {"from":L[756],
"go":function(anf_arg5946373) {
return $Hanf_arg16446374(anf_arg5946373,A113,anf_arg5926358,anf_fun5906359,curried_DASH_obj2686314,if_helper5836315,l2581261,m2671296,none6355,params_DASH_and_DASH_args2696345);
}};
$e63626363.stack[R.EXN_STACKHEIGHT++] = $ss63666367;
}
if(R.isPyretException($e63626363)) {
$e63626363.pyretStack.push(L[756]);
}
throw $e63626363;
}
var $ret63686369 = $Hanf_arg16446374($z63646365,A113,anf_arg5926358,anf_fun5906359,curried_DASH_obj2686314,if_helper5836315,l2581261,m2671296,none6355,params_DASH_and_DASH_args2696345);
++R.GAS;
return $ret63686369;
};
var $Hanf_arg16446374 = function(anf_arg5946373,A113,anf_arg5926358,anf_fun5906359,curried_DASH_obj2686314,if_helper5836315,l2581261,m2671296,none6355,params_DASH_and_DASH_args2696345) {
var anf_arg5956388 = G(A113,"a-blank",L[762]);
var anf_fun5966389 = G(A113,"s-app",L[761]);
var anf_fun5976385 = G(A113,"s-dot",L[760]);
var anf_arg5986386 = G(curried_DASH_obj2686314,"id-e",L[759]);
var $z63776378 = D;
var $f63836384 = function(_) {
return R.isFunction(anf_fun5976385)?anf_fun5976385.app(l2581261,anf_arg5986386,m2671296):R.ffi.throwNonFunApp(L[758],anf_fun5976385,[l2581261,anf_arg5986386,m2671296]);
};
try {
if(--R.GAS > 0) {
$z63776378 = $f63836384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63836384,
"from":L[758]});
}
} catch($e63756376) {
if(R.isCont($e63756376)) {
var $ss63796380 = {"from":L[758],
"go":function(anf_arg5996387) {
return $Hanf_arg16436390(anf_arg5996387,anf_arg5926358,anf_arg5946373,anf_arg5956388,anf_fun5906359,anf_fun5966389,if_helper5836315,l2581261,none6355,params_DASH_and_DASH_args2696345);
}};
$e63756376.stack[R.EXN_STACKHEIGHT++] = $ss63796380;
}
if(R.isPyretException($e63756376)) {
$e63756376.pyretStack.push(L[758]);
}
throw $e63756376;
}
var $ret63816382 = $Hanf_arg16436390($z63776378,anf_arg5926358,anf_arg5946373,anf_arg5956388,anf_fun5906359,anf_fun5966389,if_helper5836315,l2581261,none6355,params_DASH_and_DASH_args2696345);
++R.GAS;
return $ret63816382;
};
var $Hanf_arg16436390 = function(anf_arg5996387,anf_arg5926358,anf_arg5946373,anf_arg5956388,anf_fun5906359,anf_fun5966389,if_helper5836315,l2581261,none6355,params_DASH_and_DASH_args2696345) {
var anf_arg6006401 = G(params_DASH_and_DASH_args2696345,"right",L[764]);
var $z63936394 = D;
var $f63996400 = function(_) {
return R.isFunction(anf_fun5966389)?anf_fun5966389.app(l2581261,anf_arg5996387,anf_arg6006401):R.ffi.throwNonFunApp(L[763],anf_fun5966389,[l2581261,anf_arg5996387,anf_arg6006401]);
};
try {
if(--R.GAS > 0) {
$z63936394 = $f63996400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63996400,
"from":L[763]});
}
} catch($e63916392) {
if(R.isCont($e63916392)) {
var $ss63956396 = {"from":L[763],
"go":function(anf_arg6016402) {
return $Hanf_arg16426403(anf_arg6016402,anf_arg5926358,anf_arg5946373,anf_arg5956388,anf_fun5906359,if_helper5836315,l2581261,none6355);
}};
$e63916392.stack[R.EXN_STACKHEIGHT++] = $ss63956396;
}
if(R.isPyretException($e63916392)) {
$e63916392.pyretStack.push(L[763]);
}
throw $e63916392;
}
var $ret63976398 = $Hanf_arg16426403($z63936394,anf_arg5926358,anf_arg5946373,anf_arg5956388,anf_fun5906359,if_helper5836315,l2581261,none6355);
++R.GAS;
return $ret63976398;
};
var $Hanf_arg16426403 = function(anf_arg6016402,anf_arg5926358,anf_arg5946373,anf_arg5956388,anf_fun5906359,if_helper5836315,l2581261,none6355) {
var $z64066407 = D;
var $f64126413 = function(_) {
return R.isFunction(anf_fun5906359)?anf_fun5906359.app(l2581261,anf_arg5926358,anf_arg5946373,anf_arg5956388,(""),anf_arg6016402,none6355):R.ffi.throwNonFunApp(L[765],anf_fun5906359,[l2581261,anf_arg5926358,anf_arg5946373,anf_arg5956388,(""),anf_arg6016402,none6355]);
};
try {
if(--R.GAS > 0) {
$z64066407 = $f64126413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64126413,
"from":L[765]});
}
} catch($e64046405) {
if(R.isCont($e64046405)) {
var $ss64086409 = {"from":L[765],
"go":function(cont_tail_arg6026414) {
return $Hcont_tail_arg16416415(cont_tail_arg6026414,if_helper5836315);
}};
$e64046405.stack[R.EXN_STACKHEIGHT++] = $ss64086409;
}
if(R.isPyretException($e64046405)) {
$e64046405.pyretStack.push(L[765]);
}
throw $e64046405;
}
var $ret64106411 = $Hcont_tail_arg16416415($z64066407,if_helper5836315);
++R.GAS;
return $ret64106411;
};
var $Hcont_tail_arg16416415 = function(cont_tail_arg6026414,if_helper5836315) {
if(--R.GAS > 0) {
$z64166417 = R.isFunction(if_helper5836315)?if_helper5836315.app(cont_tail_arg6026414):R.ffi.throwNonFunApp(L[765],if_helper5836315,[cont_tail_arg6026414]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5836315)?if_helper5836315.app(cont_tail_arg6026414):R.ffi.throwNonFunApp(L[765],if_helper5836315,[cont_tail_arg6026414]);
},
"from":L[765]});
}
++R.GAS;
return $z64166417;
};
var $Hcont_tail_arg16486328 = function(cont_tail_arg5886327,if_helper5836315) {
if(--R.GAS > 0) {
$z64186419 = R.isFunction(if_helper5836315)?if_helper5836315.app(cont_tail_arg5886327):R.ffi.throwNonFunApp(L[751],if_helper5836315,[cont_tail_arg5886327]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5836315)?if_helper5836315.app(cont_tail_arg5886327):R.ffi.throwNonFunApp(L[751],if_helper5836315,[cont_tail_arg5886327]);
},
"from":L[751]});
}
++R.GAS;
return $z64186419;
};
var $Hparams_DASH_and_DASH_args16401321 = function(params_DASH_and_DASH_args2621320,A113,args2601263,desugar_DASH_expr117310,f2591262,is_DASH_empty2851,l2581261,list2753,none6355) {
var params2636431 = G(params_DASH_and_DASH_args2621320,"left",L[768]);
var $z64226423 = D;
var $f64286429 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[766],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[766],"desugar-expr"):desugar_DASH_expr117310.$var.app(f2591262):R.ffi.throwNonFunApp(L[767],desugar_DASH_expr117310.$var === D?U(L[766],"desugar-expr"):desugar_DASH_expr117310.$var,[f2591262]);
};
try {
if(--R.GAS > 0) {
$z64226423 = $f64286429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64286429,
"from":L[767]});
}
} catch($e64206421) {
if(R.isCont($e64206421)) {
var $ss64246425 = {"from":L[767],
"go":function(ds_DASH_f2646430) {
return $Hds_DASH_f16396432(ds_DASH_f2646430,A113,args2601263,is_DASH_empty2851,l2581261,list2753,none6355,params_DASH_and_DASH_args2621320,params2636431);
}};
$e64206421.stack[R.EXN_STACKHEIGHT++] = $ss64246425;
}
if(R.isPyretException($e64206421)) {
$e64206421.pyretStack.push(L[767]);
}
throw $e64206421;
}
var $ret64266427 = $Hds_DASH_f16396432($z64226423,A113,args2601263,is_DASH_empty2851,l2581261,list2753,none6355,params_DASH_and_DASH_args2621320,params2636431);
++R.GAS;
return $ret64266427;
};
var $Hds_DASH_f16396432 = function(ds_DASH_f2646430,A113,args2601263,is_DASH_empty2851,l2581261,list2753,none6355,params_DASH_and_DASH_args2621320,params2636431) {
var $z64356436 = D;
var $f64416442 = function(_) {
return R.isFunction(is_DASH_empty2851)?is_DASH_empty2851.app(params2636431):R.ffi.throwNonFunApp(L[769],is_DASH_empty2851,[params2636431]);
};
try {
if(--R.GAS > 0) {
$z64356436 = $f64416442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64416442,
"from":L[769]});
}
} catch($e64336434) {
if(R.isCont($e64336434)) {
var $ss64376438 = {"from":L[769],
"go":function(if_DASH_366443) {
return $Hif_DASH_16386444(if_DASH_366443,A113,args2601263,ds_DASH_f2646430,l2581261,list2753,none6355,params_DASH_and_DASH_args2621320,params2636431);
}};
$e64336434.stack[R.EXN_STACKHEIGHT++] = $ss64376438;
}
if(R.isPyretException($e64336434)) {
$e64336434.pyretStack.push(L[769]);
}
throw $e64336434;
}
var $ret64396440 = $Hif_DASH_16386444($z64356436,A113,args2601263,ds_DASH_f2646430,l2581261,list2753,none6355,params_DASH_and_DASH_args2621320,params2636431);
++R.GAS;
return $ret64396440;
};
var $Hif_DASH_16386444 = function(if_DASH_366443,A113,args2601263,ds_DASH_f2646430,l2581261,list2753,none6355,params_DASH_and_DASH_args2621320,params2636431) {
var if_helper5636457 = R.makeFunction(function(if_helper_arg5646477) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[769],1,arguments);
}
var ann_DASH_check_DASH_temp5626478 = if_helper_arg5646477;
return ann_DASH_check_DASH_temp5626478;
});
var anf_if5676476 = R.isBoolean(if_DASH_366443);
if(R.isPyretTrue(anf_if5676476)) {
if(R.isPyretTrue(if_DASH_366443)) {
var anf_fun5776455 = G(A113,"s-app",L[771]);
var $z64476448 = D;
var $f64536454 = function(_) {
return R.isFunction(anf_fun5776455)?anf_fun5776455.app(l2581261,ds_DASH_f2646430,args2601263):R.ffi.throwNonFunApp(L[770],anf_fun5776455,[l2581261,ds_DASH_f2646430,args2601263]);
};
try {
if(--R.GAS > 0) {
$z64476448 = $f64536454();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64536454,
"from":L[770]});
}
} catch($e64456446) {
if(R.isCont($e64456446)) {
var $ss64496450 = {"from":L[770],
"go":function(cont_tail_arg5786456) {
return $Hcont_tail_arg16346458(cont_tail_arg5786456,if_helper5636457);
}};
$e64456446.stack[R.EXN_STACKHEIGHT++] = $ss64496450;
}
if(R.isPyretException($e64456446)) {
$e64456446.pyretStack.push(L[770]);
}
throw $e64456446;
}
var $ret64516452 = $Hcont_tail_arg16346458($z64476448,if_helper5636457);
++R.GAS;
return $ret64516452;
} else {
var anf_fun5686471 = G(A113,"s-lam",L[773]);
var anf_fun5696469 = G(list2753,"make",L[772]);
var $z64616462 = D;
var $f64676468 = function(_) {
return R.isFunction(anf_fun5696469)?anf_fun5696469.app([]):R.ffi.throwNonFunApp(L[772],anf_fun5696469,[[]]);
};
try {
if(--R.GAS > 0) {
$z64616462 = $f64676468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64676468,
"from":L[772]});
}
} catch($e64596460) {
if(R.isCont($e64596460)) {
var $ss64636464 = {"from":L[772],
"go":function(anf_arg5706470) {
return $Hanf_arg16376472(anf_arg5706470,A113,anf_fun5686471,ds_DASH_f2646430,if_helper5636457,l2581261,none6355,params_DASH_and_DASH_args2621320,params2636431);
}};
$e64596460.stack[R.EXN_STACKHEIGHT++] = $ss64636464;
}
if(R.isPyretException($e64596460)) {
$e64596460.pyretStack.push(L[772]);
}
throw $e64596460;
}
var $ret64656466 = $Hanf_arg16376472($z64616462,A113,anf_fun5686471,ds_DASH_f2646430,if_helper5636457,l2581261,none6355,params_DASH_and_DASH_args2621320,params2636431);
++R.GAS;
return $ret64656466;
}
} else {
var cont_tail_arg5656475 = R.throwNonBooleanCondition(L[769],("if"),if_DASH_366443);
if(--R.GAS > 0) {
$z64736474 = R.isFunction(if_helper5636457)?if_helper5636457.app(cont_tail_arg5656475):R.ffi.throwNonFunApp(L[769],if_helper5636457,[cont_tail_arg5656475]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5636457)?if_helper5636457.app(cont_tail_arg5656475):R.ffi.throwNonFunApp(L[769],if_helper5636457,[cont_tail_arg5656475]);
},
"from":L[769]});
}
++R.GAS;
return $z64736474;
}
};
var $Hcont_tail_arg16346458 = function(cont_tail_arg5786456,if_helper5636457) {
if(--R.GAS > 0) {
$z64796480 = R.isFunction(if_helper5636457)?if_helper5636457.app(cont_tail_arg5786456):R.ffi.throwNonFunApp(L[770],if_helper5636457,[cont_tail_arg5786456]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5636457)?if_helper5636457.app(cont_tail_arg5786456):R.ffi.throwNonFunApp(L[770],if_helper5636457,[cont_tail_arg5786456]);
},
"from":L[770]});
}
++R.GAS;
return $z64796480;
};
var $Hanf_arg16376472 = function(anf_arg5706470,A113,anf_fun5686471,ds_DASH_f2646430,if_helper5636457,l2581261,none6355,params_DASH_and_DASH_args2621320,params2636431) {
var anf_arg5716494 = G(A113,"a-blank",L[777]);
var anf_fun5726491 = G(A113,"s-app",L[776]);
var anf_arg5736492 = G(params_DASH_and_DASH_args2621320,"right",L[775]);
var $z64836484 = D;
var $f64896490 = function(_) {
return R.isFunction(anf_fun5726491)?anf_fun5726491.app(l2581261,ds_DASH_f2646430,anf_arg5736492):R.ffi.throwNonFunApp(L[774],anf_fun5726491,[l2581261,ds_DASH_f2646430,anf_arg5736492]);
};
try {
if(--R.GAS > 0) {
$z64836484 = $f64896490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64896490,
"from":L[774]});
}
} catch($e64816482) {
if(R.isCont($e64816482)) {
var $ss64856486 = {"from":L[774],
"go":function(anf_arg5746493) {
return $Hanf_arg16366495(anf_arg5746493,anf_arg5706470,anf_arg5716494,anf_fun5686471,if_helper5636457,l2581261,none6355,params2636431);
}};
$e64816482.stack[R.EXN_STACKHEIGHT++] = $ss64856486;
}
if(R.isPyretException($e64816482)) {
$e64816482.pyretStack.push(L[774]);
}
throw $e64816482;
}
var $ret64876488 = $Hanf_arg16366495($z64836484,anf_arg5706470,anf_arg5716494,anf_fun5686471,if_helper5636457,l2581261,none6355,params2636431);
++R.GAS;
return $ret64876488;
};
var $Hanf_arg16366495 = function(anf_arg5746493,anf_arg5706470,anf_arg5716494,anf_fun5686471,if_helper5636457,l2581261,none6355,params2636431) {
var $z64986499 = D;
var $f65046505 = function(_) {
return R.isFunction(anf_fun5686471)?anf_fun5686471.app(l2581261,anf_arg5706470,params2636431,anf_arg5716494,(""),anf_arg5746493,none6355):R.ffi.throwNonFunApp(L[778],anf_fun5686471,[l2581261,anf_arg5706470,params2636431,anf_arg5716494,(""),anf_arg5746493,none6355]);
};
try {
if(--R.GAS > 0) {
$z64986499 = $f65046505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65046505,
"from":L[778]});
}
} catch($e64966497) {
if(R.isCont($e64966497)) {
var $ss65006501 = {"from":L[778],
"go":function(cont_tail_arg5756506) {
return $Hcont_tail_arg16356507(cont_tail_arg5756506,if_helper5636457);
}};
$e64966497.stack[R.EXN_STACKHEIGHT++] = $ss65006501;
}
if(R.isPyretException($e64966497)) {
$e64966497.pyretStack.push(L[778]);
}
throw $e64966497;
}
var $ret65026503 = $Hcont_tail_arg16356507($z64986499,if_helper5636457);
++R.GAS;
return $ret65026503;
};
var $Hcont_tail_arg16356507 = function(cont_tail_arg5756506,if_helper5636457) {
if(--R.GAS > 0) {
$z65086509 = R.isFunction(if_helper5636457)?if_helper5636457.app(cont_tail_arg5756506):R.ffi.throwNonFunApp(L[778],if_helper5636457,[cont_tail_arg5756506]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5636457)?if_helper5636457.app(cont_tail_arg5756506):R.ffi.throwNonFunApp(L[778],if_helper5636457,[cont_tail_arg5756506]);
},
"from":L[778]});
}
++R.GAS;
return $z65086509;
};
var $Hanf_arg16331338 = function(anf_arg5431337,A113,ds_DASH_curry_DASH_args111298,e12501323,e22511324,list2753,none6355,rebuild2521325,s2491322) {
var $z65126513 = D;
var $f65186519 = function(_) {
return R.isFunction(ds_DASH_curry_DASH_args111298.$var)?ds_DASH_curry_DASH_args111298.$var.app(s2491322,anf_arg5431337):R.ffi.throwNonFunApp(L[779],ds_DASH_curry_DASH_args111298.$var,[s2491322,anf_arg5431337]);
};
try {
if(--R.GAS > 0) {
$z65126513 = $f65186519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65186519,
"from":L[779]});
}
} catch($e65106511) {
if(R.isCont($e65106511)) {
var $ss65146515 = {"from":L[779],
"go":function(params_DASH_and_DASH_args2536520) {
return $Hparams_DASH_and_DASH_args16326521(params_DASH_and_DASH_args2536520,A113,e12501323,e22511324,list2753,none6355,rebuild2521325,s2491322);
}};
$e65106511.stack[R.EXN_STACKHEIGHT++] = $ss65146515;
}
if(R.isPyretException($e65106511)) {
$e65106511.pyretStack.push(L[779]);
}
throw $e65106511;
}
var $ret65166517 = $Hparams_DASH_and_DASH_args16326521($z65126513,A113,e12501323,e22511324,list2753,none6355,rebuild2521325,s2491322);
++R.GAS;
return $ret65166517;
};
var $Hparams_DASH_and_DASH_args16326521 = function(params_DASH_and_DASH_args2536520,A113,e12501323,e22511324,list2753,none6355,rebuild2521325,s2491322) {
var params2546556 = G(params_DASH_and_DASH_args2536520,"left",L[786]);
var cases_DASH_val356570 = params2546556;
var anf_fun5446532 = G(cases_DASH_val356570,"_match",L[780]);
var anf_obj5466538 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[785],0,arguments);
}
var $z65606561 = D;
var $f65666567 = function(_) {
return R.isFunction(rebuild2521325)?rebuild2521325.app(e12501323,e22511324):R.ffi.throwNonFunApp(L[785],rebuild2521325,[e12501323,e22511324]);
};
try {
if(--R.GAS > 0) {
$z65606561 = $f65666567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65666567,
"from":L[785]});
}
} catch($e65586559) {
if(R.isCont($e65586559)) {
var $ss65626563 = {"from":L[785],
"go":function(ann_DASH_check_DASH_temp5456568) {
return $Hann_DASH_check_DASH_temp16276569(ann_DASH_check_DASH_temp5456568);
}};
$e65586559.stack[R.EXN_STACKHEIGHT++] = $ss65626563;
}
if(R.isPyretException($e65586559)) {
$e65586559.pyretStack.push(L[785]);
}
throw $e65586559;
}
var $ret65646565 = $Hann_DASH_check_DASH_temp16276569($z65606561);
++R.GAS;
return $ret65646565;
});
var anf_obj5566539 = R.makeFunction(function(f2556540,r2566541) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[781],2,arguments);
}
var curry_DASH_args2576555 = G(params_DASH_and_DASH_args2536520,"right",L[784]);
var anf_fun5486554 = G(A113,"s-lam",L[783]);
var anf_fun5496552 = G(list2753,"make",L[782]);
var $z65446545 = D;
var $f65506551 = function(_) {
return R.isFunction(anf_fun5496552)?anf_fun5496552.app([]):R.ffi.throwNonFunApp(L[782],anf_fun5496552,[[]]);
};
try {
if(--R.GAS > 0) {
$z65446545 = $f65506551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65506551,
"from":L[782]});
}
} catch($e65426543) {
if(R.isCont($e65426543)) {
var $ss65466547 = {"from":L[782],
"go":function(anf_arg5506553) {
return $Hanf_arg16306557(anf_arg5506553,A113,anf_fun5486554,curry_DASH_args2576555,none6355,params2546556,rebuild2521325,s2491322);
}};
$e65426543.stack[R.EXN_STACKHEIGHT++] = $ss65466547;
}
if(R.isPyretException($e65426543)) {
$e65426543.pyretStack.push(L[782]);
}
throw $e65426543;
}
var $ret65486549 = $Hanf_arg16306557($z65446545,A113,anf_fun5486554,curry_DASH_args2576555,none6355,params2546556,rebuild2521325,s2491322);
++R.GAS;
return $ret65486549;
});
var anf_arg5576533 = R.makeObject({"empty":anf_obj5466538,
"link":anf_obj5566539});
var anf_arg5596534 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[780],0,arguments);
}
var ann_DASH_check_DASH_temp5586537 = R.throwNoBranchesMatched(L[780],("cases"));
return ann_DASH_check_DASH_temp5586537;
});
var $z65246525 = D;
var $f65306531 = function(_) {
return R.isFunction(anf_fun5446532)?anf_fun5446532.app(anf_arg5576533,anf_arg5596534):R.ffi.throwNonFunApp(L[174],anf_fun5446532,[anf_arg5576533,anf_arg5596534]);
};
try {
if(--R.GAS > 0) {
$z65246525 = $f65306531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65306531,
"from":L[174]});
}
} catch($e65226523) {
if(R.isCont($e65226523)) {
var $ss65266527 = {"from":L[174],
"go":function(ann_DASH_check_DASH_temp5416535) {
return $Hann_DASH_check_DASH_temp16316536(ann_DASH_check_DASH_temp5416535);
}};
$e65226523.stack[R.EXN_STACKHEIGHT++] = $ss65266527;
}
if(R.isPyretException($e65226523)) {
$e65226523.pyretStack.push(L[174]);
}
throw $e65226523;
}
var $ret65286529 = $Hann_DASH_check_DASH_temp16316536($z65246525);
++R.GAS;
return $ret65286529;
};
var $Hann_DASH_check_DASH_temp16316536 = function(ann_DASH_check_DASH_temp5416535) {
return ann_DASH_check_DASH_temp5416535;
};
var $Hanf_arg16306557 = function(anf_arg5506553,A113,anf_fun5486554,curry_DASH_args2576555,none6355,params2546556,rebuild2521325,s2491322) {
var anf_arg5516584 = G(A113,"a-blank",L[791]);
var anf_arg5526581 = G(curry_DASH_args2576555,"first",L[790]);
var anf_bracket5536586 = G(curry_DASH_args2576555,"rest",L[789]);
var anf_arg5546582 = G(anf_bracket5536586,"first",L[788]);
var $z65736574 = D;
var $f65796580 = function(_) {
return R.isFunction(rebuild2521325)?rebuild2521325.app(anf_arg5526581,anf_arg5546582):R.ffi.throwNonFunApp(L[787],rebuild2521325,[anf_arg5526581,anf_arg5546582]);
};
try {
if(--R.GAS > 0) {
$z65736574 = $f65796580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65796580,
"from":L[787]});
}
} catch($e65716572) {
if(R.isCont($e65716572)) {
var $ss65756576 = {"from":L[787],
"go":function(anf_arg5556583) {
return $Hanf_arg16296585(anf_arg5556583,anf_arg5506553,anf_arg5516584,anf_fun5486554,none6355,params2546556,s2491322);
}};
$e65716572.stack[R.EXN_STACKHEIGHT++] = $ss65756576;
}
if(R.isPyretException($e65716572)) {
$e65716572.pyretStack.push(L[787]);
}
throw $e65716572;
}
var $ret65776578 = $Hanf_arg16296585($z65736574,anf_arg5506553,anf_arg5516584,anf_fun5486554,none6355,params2546556,s2491322);
++R.GAS;
return $ret65776578;
};
var $Hanf_arg16296585 = function(anf_arg5556583,anf_arg5506553,anf_arg5516584,anf_fun5486554,none6355,params2546556,s2491322) {
var $z65896590 = D;
var $f65956596 = function(_) {
return R.isFunction(anf_fun5486554)?anf_fun5486554.app(s2491322,anf_arg5506553,params2546556,anf_arg5516584,(""),anf_arg5556583,none6355):R.ffi.throwNonFunApp(L[781],anf_fun5486554,[s2491322,anf_arg5506553,params2546556,anf_arg5516584,(""),anf_arg5556583,none6355]);
};
try {
if(--R.GAS > 0) {
$z65896590 = $f65956596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65956596,
"from":L[781]});
}
} catch($e65876588) {
if(R.isCont($e65876588)) {
var $ss65916592 = {"from":L[781],
"go":function(ann_DASH_check_DASH_temp5476597) {
return $Hann_DASH_check_DASH_temp16286598(ann_DASH_check_DASH_temp5476597);
}};
$e65876588.stack[R.EXN_STACKHEIGHT++] = $ss65916592;
}
if(R.isPyretException($e65876588)) {
$e65876588.pyretStack.push(L[781]);
}
throw $e65876588;
}
var $ret65936594 = $Hann_DASH_check_DASH_temp16286598($z65896590);
++R.GAS;
return $ret65936594;
};
var $Hann_DASH_check_DASH_temp16286598 = function(ann_DASH_check_DASH_temp5476597) {
return ann_DASH_check_DASH_temp5476597;
};
var $Hann_DASH_check_DASH_temp16276569 = function(ann_DASH_check_DASH_temp5456568) {
return ann_DASH_check_DASH_temp5456568;
};
var $Hif_DASH_16261354 = function(if_DASH_341353,A113,desugar_DASH_expr117310,l2451340,list2753,m2471342,mk_DASH_id101278,none6355,obj2461341,rebuild_DASH_node2441339) {
var if_helper5216610 = R.makeFunction(function(if_helper_arg5226628) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[177],1,arguments);
}
var ann_DASH_check_DASH_temp5206629 = if_helper_arg5226628;
return ann_DASH_check_DASH_temp5206629;
});
var anf_if5256627 = R.isBoolean(if_DASH_341353);
if(R.isPyretTrue(anf_if5256627)) {
if(R.isPyretTrue(if_DASH_341353)) {
var $z66016602 = D;
var $f66076608 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l2451340,("recv-")):R.ffi.throwNonFunApp(L[792],mk_DASH_id101278.$var,[l2451340,("recv-")]);
};
try {
if(--R.GAS > 0) {
$z66016602 = $f66076608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66076608,
"from":L[792]});
}
} catch($e65996600) {
if(R.isCont($e65996600)) {
var $ss66036604 = {"from":L[792],
"go":function(curried_DASH_obj2486609) {
return $Hcurried_DASH_obj16236611(curried_DASH_obj2486609,A113,if_helper5216610,l2451340,list2753,m2471342,none6355,rebuild_DASH_node2441339);
}};
$e65996600.stack[R.EXN_STACKHEIGHT++] = $ss66036604;
}
if(R.isPyretException($e65996600)) {
$e65996600.pyretStack.push(L[792]);
}
throw $e65996600;
}
var $ret66056606 = $Hcurried_DASH_obj16236611($z66016602,A113,if_helper5216610,l2451340,list2753,m2471342,none6355,rebuild_DASH_node2441339);
++R.GAS;
return $ret66056606;
} else {
var $z66146615 = D;
var $f66206621 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[793],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[793],"desugar-expr"):desugar_DASH_expr117310.$var.app(obj2461341):R.ffi.throwNonFunApp(L[794],desugar_DASH_expr117310.$var === D?U(L[793],"desugar-expr"):desugar_DASH_expr117310.$var,[obj2461341]);
};
try {
if(--R.GAS > 0) {
$z66146615 = $f66206621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66206621,
"from":L[794]});
}
} catch($e66126613) {
if(R.isCont($e66126613)) {
var $ss66166617 = {"from":L[794],
"go":function(anf_arg5266622) {
return $Hanf_arg16256623(anf_arg5266622,if_helper5216610,l2451340,m2471342,rebuild_DASH_node2441339);
}};
$e66126613.stack[R.EXN_STACKHEIGHT++] = $ss66166617;
}
if(R.isPyretException($e66126613)) {
$e66126613.pyretStack.push(L[794]);
}
throw $e66126613;
}
var $ret66186619 = $Hanf_arg16256623($z66146615,if_helper5216610,l2451340,m2471342,rebuild_DASH_node2441339);
++R.GAS;
return $ret66186619;
}
} else {
var cont_tail_arg5236626 = R.throwNonBooleanCondition(L[177],("if"),if_DASH_341353);
if(--R.GAS > 0) {
$z66246625 = R.isFunction(if_helper5216610)?if_helper5216610.app(cont_tail_arg5236626):R.ffi.throwNonFunApp(L[177],if_helper5216610,[cont_tail_arg5236626]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5216610)?if_helper5216610.app(cont_tail_arg5236626):R.ffi.throwNonFunApp(L[177],if_helper5216610,[cont_tail_arg5236626]);
},
"from":L[177]});
}
++R.GAS;
return $z66246625;
}
};
var $Hcurried_DASH_obj16236611 = function(curried_DASH_obj2486609,A113,if_helper5216610,l2451340,list2753,m2471342,none6355,rebuild_DASH_node2441339) {
var anf_fun5296642 = G(A113,"s-lam",L[796]);
var anf_fun5306640 = G(list2753,"make",L[795]);
var $z66326633 = D;
var $f66386639 = function(_) {
return R.isFunction(anf_fun5306640)?anf_fun5306640.app([]):R.ffi.throwNonFunApp(L[795],anf_fun5306640,[[]]);
};
try {
if(--R.GAS > 0) {
$z66326633 = $f66386639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66386639,
"from":L[795]});
}
} catch($e66306631) {
if(R.isCont($e66306631)) {
var $ss66346635 = {"from":L[795],
"go":function(anf_arg5316641) {
return $Hanf_arg16226643(anf_arg5316641,A113,anf_fun5296642,curried_DASH_obj2486609,if_helper5216610,l2451340,list2753,m2471342,none6355,rebuild_DASH_node2441339);
}};
$e66306631.stack[R.EXN_STACKHEIGHT++] = $ss66346635;
}
if(R.isPyretException($e66306631)) {
$e66306631.pyretStack.push(L[795]);
}
throw $e66306631;
}
var $ret66366637 = $Hanf_arg16226643($z66326633,A113,anf_fun5296642,curried_DASH_obj2486609,if_helper5216610,l2451340,list2753,m2471342,none6355,rebuild_DASH_node2441339);
++R.GAS;
return $ret66366637;
};
var $Hanf_arg16226643 = function(anf_arg5316641,A113,anf_fun5296642,curried_DASH_obj2486609,if_helper5216610,l2451340,list2753,m2471342,none6355,rebuild_DASH_node2441339) {
var anf_fun5326654 = G(list2753,"make",L[797]);
var anf_array_val5336655 = G(curried_DASH_obj2486609,"id-b",L[798]);
var $z66466647 = D;
var $f66526653 = function(_) {
return R.isFunction(anf_fun5326654)?anf_fun5326654.app([anf_array_val5336655]):R.ffi.throwNonFunApp(L[797],anf_fun5326654,[[anf_array_val5336655]]);
};
try {
if(--R.GAS > 0) {
$z66466647 = $f66526653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66526653,
"from":L[797]});
}
} catch($e66446645) {
if(R.isCont($e66446645)) {
var $ss66486649 = {"from":L[797],
"go":function(anf_arg5346656) {
return $Hanf_arg16216657(anf_arg5346656,A113,anf_arg5316641,anf_fun5296642,curried_DASH_obj2486609,if_helper5216610,l2451340,m2471342,none6355,rebuild_DASH_node2441339);
}};
$e66446645.stack[R.EXN_STACKHEIGHT++] = $ss66486649;
}
if(R.isPyretException($e66446645)) {
$e66446645.pyretStack.push(L[797]);
}
throw $e66446645;
}
var $ret66506651 = $Hanf_arg16216657($z66466647,A113,anf_arg5316641,anf_fun5296642,curried_DASH_obj2486609,if_helper5216610,l2451340,m2471342,none6355,rebuild_DASH_node2441339);
++R.GAS;
return $ret66506651;
};
var $Hanf_arg16216657 = function(anf_arg5346656,A113,anf_arg5316641,anf_fun5296642,curried_DASH_obj2486609,if_helper5216610,l2451340,m2471342,none6355,rebuild_DASH_node2441339) {
var anf_arg5356670 = G(A113,"a-blank",L[801]);
var anf_arg5366668 = G(curried_DASH_obj2486609,"id-e",L[800]);
var $z66606661 = D;
var $f66666667 = function(_) {
return R.isFunction(rebuild_DASH_node2441339)?rebuild_DASH_node2441339.app(l2451340,anf_arg5366668,m2471342):R.ffi.throwNonFunApp(L[799],rebuild_DASH_node2441339,[l2451340,anf_arg5366668,m2471342]);
};
try {
if(--R.GAS > 0) {
$z66606661 = $f66666667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66666667,
"from":L[799]});
}
} catch($e66586659) {
if(R.isCont($e66586659)) {
var $ss66626663 = {"from":L[799],
"go":function(anf_arg5376669) {
return $Hanf_arg16206671(anf_arg5376669,anf_arg5316641,anf_arg5346656,anf_arg5356670,anf_fun5296642,if_helper5216610,l2451340,none6355);
}};
$e66586659.stack[R.EXN_STACKHEIGHT++] = $ss66626663;
}
if(R.isPyretException($e66586659)) {
$e66586659.pyretStack.push(L[799]);
}
throw $e66586659;
}
var $ret66646665 = $Hanf_arg16206671($z66606661,anf_arg5316641,anf_arg5346656,anf_arg5356670,anf_fun5296642,if_helper5216610,l2451340,none6355);
++R.GAS;
return $ret66646665;
};
var $Hanf_arg16206671 = function(anf_arg5376669,anf_arg5316641,anf_arg5346656,anf_arg5356670,anf_fun5296642,if_helper5216610,l2451340,none6355) {
var $z66746675 = D;
var $f66806681 = function(_) {
return R.isFunction(anf_fun5296642)?anf_fun5296642.app(l2451340,anf_arg5316641,anf_arg5346656,anf_arg5356670,(""),anf_arg5376669,none6355):R.ffi.throwNonFunApp(L[802],anf_fun5296642,[l2451340,anf_arg5316641,anf_arg5346656,anf_arg5356670,(""),anf_arg5376669,none6355]);
};
try {
if(--R.GAS > 0) {
$z66746675 = $f66806681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66806681,
"from":L[802]});
}
} catch($e66726673) {
if(R.isCont($e66726673)) {
var $ss66766677 = {"from":L[802],
"go":function(cont_tail_arg5386682) {
return $Hcont_tail_arg16196683(cont_tail_arg5386682,if_helper5216610);
}};
$e66726673.stack[R.EXN_STACKHEIGHT++] = $ss66766677;
}
if(R.isPyretException($e66726673)) {
$e66726673.pyretStack.push(L[802]);
}
throw $e66726673;
}
var $ret66786679 = $Hcont_tail_arg16196683($z66746675,if_helper5216610);
++R.GAS;
return $ret66786679;
};
var $Hcont_tail_arg16196683 = function(cont_tail_arg5386682,if_helper5216610) {
if(--R.GAS > 0) {
$z66846685 = R.isFunction(if_helper5216610)?if_helper5216610.app(cont_tail_arg5386682):R.ffi.throwNonFunApp(L[802],if_helper5216610,[cont_tail_arg5386682]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5216610)?if_helper5216610.app(cont_tail_arg5386682):R.ffi.throwNonFunApp(L[802],if_helper5216610,[cont_tail_arg5386682]);
},
"from":L[802]});
}
++R.GAS;
return $z66846685;
};
var $Hanf_arg16256623 = function(anf_arg5266622,if_helper5216610,l2451340,m2471342,rebuild_DASH_node2441339) {
var $z66886689 = D;
var $f66946695 = function(_) {
return R.isFunction(rebuild_DASH_node2441339)?rebuild_DASH_node2441339.app(l2451340,anf_arg5266622,m2471342):R.ffi.throwNonFunApp(L[803],rebuild_DASH_node2441339,[l2451340,anf_arg5266622,m2471342]);
};
try {
if(--R.GAS > 0) {
$z66886689 = $f66946695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66946695,
"from":L[803]});
}
} catch($e66866687) {
if(R.isCont($e66866687)) {
var $ss66906691 = {"from":L[803],
"go":function(cont_tail_arg5276696) {
return $Hcont_tail_arg16246697(cont_tail_arg5276696,if_helper5216610);
}};
$e66866687.stack[R.EXN_STACKHEIGHT++] = $ss66906691;
}
if(R.isPyretException($e66866687)) {
$e66866687.pyretStack.push(L[803]);
}
throw $e66866687;
}
var $ret66926693 = $Hcont_tail_arg16246697($z66886689,if_helper5216610);
++R.GAS;
return $ret66926693;
};
var $Hcont_tail_arg16246697 = function(cont_tail_arg5276696,if_helper5216610) {
if(--R.GAS > 0) {
$z66986699 = R.isFunction(if_helper5216610)?if_helper5216610.app(cont_tail_arg5276696):R.ffi.throwNonFunApp(L[803],if_helper5216610,[cont_tail_arg5276696]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper5216610)?if_helper5216610.app(cont_tail_arg5276696):R.ffi.throwNonFunApp(L[803],if_helper5216610,[cont_tail_arg5276696]);
},
"from":L[803]});
}
++R.GAS;
return $z66986699;
};
var $Hanf_arg16181370 = function(anf_arg5091368,anf_arg5071369,args2391356,fold5550,list2753,pair8276) {
var anf_fun5106710 = G(list2753,"make",L[804]);
var $z67026703 = D;
var $f67086709 = function(_) {
return R.isFunction(anf_fun5106710)?anf_fun5106710.app([]):R.ffi.throwNonFunApp(L[804],anf_fun5106710,[[]]);
};
try {
if(--R.GAS > 0) {
$z67026703 = $f67086709();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67086709,
"from":L[804]});
}
} catch($e67006701) {
if(R.isCont($e67006701)) {
var $ss67046705 = {"from":L[804],
"go":function(anf_arg5116711) {
return $Hanf_arg16176712(anf_arg5116711,anf_arg5071369,anf_arg5091368,args2391356,fold5550,pair8276);
}};
$e67006701.stack[R.EXN_STACKHEIGHT++] = $ss67046705;
}
if(R.isPyretException($e67006701)) {
$e67006701.pyretStack.push(L[804]);
}
throw $e67006701;
}
var $ret67066707 = $Hanf_arg16176712($z67026703,anf_arg5071369,anf_arg5091368,args2391356,fold5550,pair8276);
++R.GAS;
return $ret67066707;
};
var $Hanf_arg16176712 = function(anf_arg5116711,anf_arg5071369,anf_arg5091368,args2391356,fold5550,pair8276) {
var $z67156716 = D;
var $f67216722 = function(_) {
return R.isFunction(pair8276.$var)?pair8276.$var.app(anf_arg5091368,anf_arg5116711):R.ffi.throwNonFunApp(L[805],pair8276.$var,[anf_arg5091368,anf_arg5116711]);
};
try {
if(--R.GAS > 0) {
$z67156716 = $f67216722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67216722,
"from":L[805]});
}
} catch($e67136714) {
if(R.isCont($e67136714)) {
var $ss67176718 = {"from":L[805],
"go":function(anf_arg5126723) {
return $Hanf_arg16166724(anf_arg5126723,anf_arg5071369,args2391356,fold5550,pair8276);
}};
$e67136714.stack[R.EXN_STACKHEIGHT++] = $ss67176718;
}
if(R.isPyretException($e67136714)) {
$e67136714.pyretStack.push(L[805]);
}
throw $e67136714;
}
var $ret67196720 = $Hanf_arg16166724($z67156716,anf_arg5071369,args2391356,fold5550,pair8276);
++R.GAS;
return $ret67196720;
};
var $Hanf_arg16166724 = function(anf_arg5126723,anf_arg5071369,args2391356,fold5550,pair8276) {
var $z67276728 = D;
var $f67336734 = function(_) {
return R.isFunction(fold5550)?fold5550.app(anf_arg5071369,anf_arg5126723,args2391356):R.ffi.throwNonFunApp(L[806],fold5550,[anf_arg5071369,anf_arg5126723,args2391356]);
};
try {
if(--R.GAS > 0) {
$z67276728 = $f67336734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67336734,
"from":L[806]});
}
} catch($e67256726) {
if(R.isCont($e67256726)) {
var $ss67296730 = {"from":L[806],
"go":function(params_DASH_and_DASH_args2406735) {
return $Hparams_DASH_and_DASH_args16156736(params_DASH_and_DASH_args2406735,pair8276);
}};
$e67256726.stack[R.EXN_STACKHEIGHT++] = $ss67296730;
}
if(R.isPyretException($e67256726)) {
$e67256726.pyretStack.push(L[806]);
}
throw $e67256726;
}
var $ret67316732 = $Hparams_DASH_and_DASH_args16156736($z67276728,pair8276);
++R.GAS;
return $ret67316732;
};
var $Hparams_DASH_and_DASH_args16156736 = function(params_DASH_and_DASH_args2406735,pair8276) {
var anf_bracket5136750 = G(params_DASH_and_DASH_args2406735,"left",L[809]);
var anf_fun5146747 = G(anf_bracket5136750,"reverse",L[808]);
var $z67396740 = D;
var $f67456746 = function(_) {
return R.isFunction(anf_fun5146747)?anf_fun5146747.app():R.ffi.throwNonFunApp(L[807],anf_fun5146747,[]);
};
try {
if(--R.GAS > 0) {
$z67396740 = $f67456746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67456746,
"from":L[807]});
}
} catch($e67376738) {
if(R.isCont($e67376738)) {
var $ss67416742 = {"from":L[807],
"go":function(anf_arg5156748) {
return $Hanf_arg16146749(anf_arg5156748,pair8276,params_DASH_and_DASH_args2406735);
}};
$e67376738.stack[R.EXN_STACKHEIGHT++] = $ss67416742;
}
if(R.isPyretException($e67376738)) {
$e67376738.pyretStack.push(L[807]);
}
throw $e67376738;
}
var $ret67436744 = $Hanf_arg16146749($z67396740,pair8276,params_DASH_and_DASH_args2406735);
++R.GAS;
return $ret67436744;
};
var $Hanf_arg16146749 = function(anf_arg5156748,pair8276,params_DASH_and_DASH_args2406735) {
var anf_bracket5166764 = G(params_DASH_and_DASH_args2406735,"right",L[812]);
var anf_fun5176761 = G(anf_bracket5166764,"reverse",L[811]);
var $z67536754 = D;
var $f67596760 = function(_) {
return R.isFunction(anf_fun5176761)?anf_fun5176761.app():R.ffi.throwNonFunApp(L[810],anf_fun5176761,[]);
};
try {
if(--R.GAS > 0) {
$z67536754 = $f67596760();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67596760,
"from":L[810]});
}
} catch($e67516752) {
if(R.isCont($e67516752)) {
var $ss67556756 = {"from":L[810],
"go":function(anf_arg5186762) {
return $Hanf_arg16136763(anf_arg5186762,anf_arg5156748,pair8276);
}};
$e67516752.stack[R.EXN_STACKHEIGHT++] = $ss67556756;
}
if(R.isPyretException($e67516752)) {
$e67516752.pyretStack.push(L[810]);
}
throw $e67516752;
}
var $ret67576758 = $Hanf_arg16136763($z67536754,anf_arg5156748,pair8276);
++R.GAS;
return $ret67576758;
};
var $Hanf_arg16136763 = function(anf_arg5186762,anf_arg5156748,pair8276) {
var $z67676768 = D;
var $f67736774 = function(_) {
return R.isFunction(pair8276.$var)?pair8276.$var.app(anf_arg5156748,anf_arg5186762):R.ffi.throwNonFunApp(L[178],pair8276.$var,[anf_arg5156748,anf_arg5186762]);
};
try {
if(--R.GAS > 0) {
$z67676768 = $f67736774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67736774,
"from":L[178]});
}
} catch($e67656766) {
if(R.isCont($e67656766)) {
var $ss67696770 = {"from":L[178],
"go":function(ann_DASH_check_DASH_temp4876775) {
return $Hann_DASH_check_DASH_temp16126776(ann_DASH_check_DASH_temp4876775);
}};
$e67656766.stack[R.EXN_STACKHEIGHT++] = $ss67696770;
}
if(R.isPyretException($e67656766)) {
$e67656766.pyretStack.push(L[178]);
}
throw $e67656766;
}
var $ret67716772 = $Hann_DASH_check_DASH_temp16126776($z67676768);
++R.GAS;
return $ret67716772;
};
var $Hann_DASH_check_DASH_temp16126776 = function(ann_DASH_check_DASH_temp4876775) {
return ann_DASH_check_DASH_temp4876775;
};
var $Hif_DASH_16111384 = function(if_DASH_331383,acc2411371,arg2421372,l2381355,link3152,mk_DASH_id101278,pair8276) {
var if_helper4896788 = R.makeFunction(function(if_helper_arg4906808) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[181],1,arguments);
}
var ann_DASH_check_DASH_temp4886809 = if_helper_arg4906808;
return ann_DASH_check_DASH_temp4886809;
});
var anf_if4936807 = R.isBoolean(if_DASH_331383);
if(R.isPyretTrue(anf_if4936807)) {
if(R.isPyretTrue(if_DASH_331383)) {
var $z67796780 = D;
var $f67856786 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l2381355,("arg-")):R.ffi.throwNonFunApp(L[813],mk_DASH_id101278.$var,[l2381355,("arg-")]);
};
try {
if(--R.GAS > 0) {
$z67796780 = $f67856786();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67856786,
"from":L[813]});
}
} catch($e67776778) {
if(R.isCont($e67776778)) {
var $ss67816782 = {"from":L[813],
"go":function(arg_DASH_id2436787) {
return $Harg_DASH_id16086789(arg_DASH_id2436787,acc2411371,if_helper4896788,link3152,pair8276);
}};
$e67776778.stack[R.EXN_STACKHEIGHT++] = $ss67816782;
}
if(R.isPyretException($e67776778)) {
$e67776778.pyretStack.push(L[813]);
}
throw $e67776778;
}
var $ret67836784 = $Harg_DASH_id16086789($z67796780,acc2411371,if_helper4896788,link3152,pair8276);
++R.GAS;
return $ret67836784;
} else {
var anf_arg4946802 = G(acc2411371,"left",L[816]);
var anf_arg4956800 = G(acc2411371,"right",L[815]);
var $z67926793 = D;
var $f67986799 = function(_) {
return R.isFunction(link3152)?link3152.app(arg2421372,anf_arg4956800):R.ffi.throwNonFunApp(L[814],link3152,[arg2421372,anf_arg4956800]);
};
try {
if(--R.GAS > 0) {
$z67926793 = $f67986799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67986799,
"from":L[814]});
}
} catch($e67906791) {
if(R.isCont($e67906791)) {
var $ss67946795 = {"from":L[814],
"go":function(anf_arg4966801) {
return $Hanf_arg16106803(anf_arg4966801,anf_arg4946802,if_helper4896788,pair8276);
}};
$e67906791.stack[R.EXN_STACKHEIGHT++] = $ss67946795;
}
if(R.isPyretException($e67906791)) {
$e67906791.pyretStack.push(L[814]);
}
throw $e67906791;
}
var $ret67966797 = $Hanf_arg16106803($z67926793,anf_arg4946802,if_helper4896788,pair8276);
++R.GAS;
return $ret67966797;
}
} else {
var cont_tail_arg4916806 = R.throwNonBooleanCondition(L[181],("if"),if_DASH_331383);
if(--R.GAS > 0) {
$z68046805 = R.isFunction(if_helper4896788)?if_helper4896788.app(cont_tail_arg4916806):R.ffi.throwNonFunApp(L[181],if_helper4896788,[cont_tail_arg4916806]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper4896788)?if_helper4896788.app(cont_tail_arg4916806):R.ffi.throwNonFunApp(L[181],if_helper4896788,[cont_tail_arg4916806]);
},
"from":L[181]});
}
++R.GAS;
return $z68046805;
}
};
var $Harg_DASH_id16086789 = function(arg_DASH_id2436787,acc2411371,if_helper4896788,link3152,pair8276) {
var anf_arg4996820 = G(arg_DASH_id2436787,"id-b",L[819]);
var anf_arg5006821 = G(acc2411371,"left",L[818]);
var $z68126813 = D;
var $f68186819 = function(_) {
return R.isFunction(link3152)?link3152.app(anf_arg4996820,anf_arg5006821):R.ffi.throwNonFunApp(L[817],link3152,[anf_arg4996820,anf_arg5006821]);
};
try {
if(--R.GAS > 0) {
$z68126813 = $f68186819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68186819,
"from":L[817]});
}
} catch($e68106811) {
if(R.isCont($e68106811)) {
var $ss68146815 = {"from":L[817],
"go":function(anf_arg5016822) {
return $Hanf_arg16076823(anf_arg5016822,acc2411371,arg_DASH_id2436787,if_helper4896788,link3152,pair8276);
}};
$e68106811.stack[R.EXN_STACKHEIGHT++] = $ss68146815;
}
if(R.isPyretException($e68106811)) {
$e68106811.pyretStack.push(L[817]);
}
throw $e68106811;
}
var $ret68166817 = $Hanf_arg16076823($z68126813,acc2411371,arg_DASH_id2436787,if_helper4896788,link3152,pair8276);
++R.GAS;
return $ret68166817;
};
var $Hanf_arg16076823 = function(anf_arg5016822,acc2411371,arg_DASH_id2436787,if_helper4896788,link3152,pair8276) {
var anf_arg5026834 = G(arg_DASH_id2436787,"id-e",L[822]);
var anf_arg5036835 = G(acc2411371,"right",L[821]);
var $z68266827 = D;
var $f68326833 = function(_) {
return R.isFunction(link3152)?link3152.app(anf_arg5026834,anf_arg5036835):R.ffi.throwNonFunApp(L[820],link3152,[anf_arg5026834,anf_arg5036835]);
};
try {
if(--R.GAS > 0) {
$z68266827 = $f68326833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68326833,
"from":L[820]});
}
} catch($e68246825) {
if(R.isCont($e68246825)) {
var $ss68286829 = {"from":L[820],
"go":function(anf_arg5046836) {
return $Hanf_arg16066837(anf_arg5046836,anf_arg5016822,if_helper4896788,pair8276);
}};
$e68246825.stack[R.EXN_STACKHEIGHT++] = $ss68286829;
}
if(R.isPyretException($e68246825)) {
$e68246825.pyretStack.push(L[820]);
}
throw $e68246825;
}
var $ret68306831 = $Hanf_arg16066837($z68266827,anf_arg5016822,if_helper4896788,pair8276);
++R.GAS;
return $ret68306831;
};
var $Hanf_arg16066837 = function(anf_arg5046836,anf_arg5016822,if_helper4896788,pair8276) {
var $z68406841 = D;
var $f68466847 = function(_) {
return R.isFunction(pair8276.$var)?pair8276.$var.app(anf_arg5016822,anf_arg5046836):R.ffi.throwNonFunApp(L[823],pair8276.$var,[anf_arg5016822,anf_arg5046836]);
};
try {
if(--R.GAS > 0) {
$z68406841 = $f68466847();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68466847,
"from":L[823]});
}
} catch($e68386839) {
if(R.isCont($e68386839)) {
var $ss68426843 = {"from":L[823],
"go":function(cont_tail_arg5056848) {
return $Hcont_tail_arg16056849(cont_tail_arg5056848,if_helper4896788);
}};
$e68386839.stack[R.EXN_STACKHEIGHT++] = $ss68426843;
}
if(R.isPyretException($e68386839)) {
$e68386839.pyretStack.push(L[823]);
}
throw $e68386839;
}
var $ret68446845 = $Hcont_tail_arg16056849($z68406841,if_helper4896788);
++R.GAS;
return $ret68446845;
};
var $Hcont_tail_arg16056849 = function(cont_tail_arg5056848,if_helper4896788) {
if(--R.GAS > 0) {
$z68506851 = R.isFunction(if_helper4896788)?if_helper4896788.app(cont_tail_arg5056848):R.ffi.throwNonFunApp(L[823],if_helper4896788,[cont_tail_arg5056848]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper4896788)?if_helper4896788.app(cont_tail_arg5056848):R.ffi.throwNonFunApp(L[823],if_helper4896788,[cont_tail_arg5056848]);
},
"from":L[823]});
}
++R.GAS;
return $z68506851;
};
var $Hanf_arg16106803 = function(anf_arg4966801,anf_arg4946802,if_helper4896788,pair8276) {
var $z68546855 = D;
var $f68606861 = function(_) {
return R.isFunction(pair8276.$var)?pair8276.$var.app(anf_arg4946802,anf_arg4966801):R.ffi.throwNonFunApp(L[824],pair8276.$var,[anf_arg4946802,anf_arg4966801]);
};
try {
if(--R.GAS > 0) {
$z68546855 = $f68606861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68606861,
"from":L[824]});
}
} catch($e68526853) {
if(R.isCont($e68526853)) {
var $ss68566857 = {"from":L[824],
"go":function(cont_tail_arg4976862) {
return $Hcont_tail_arg16096863(cont_tail_arg4976862,if_helper4896788);
}};
$e68526853.stack[R.EXN_STACKHEIGHT++] = $ss68566857;
}
if(R.isPyretException($e68526853)) {
$e68526853.pyretStack.push(L[824]);
}
throw $e68526853;
}
var $ret68586859 = $Hcont_tail_arg16096863($z68546855,if_helper4896788);
++R.GAS;
return $ret68586859;
};
var $Hcont_tail_arg16096863 = function(cont_tail_arg4976862,if_helper4896788) {
if(--R.GAS > 0) {
$z68646865 = R.isFunction(if_helper4896788)?if_helper4896788.app(cont_tail_arg4976862):R.ffi.throwNonFunApp(L[824],if_helper4896788,[cont_tail_arg4976862]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper4896788)?if_helper4896788.app(cont_tail_arg4976862):R.ffi.throwNonFunApp(L[824],if_helper4896788,[cont_tail_arg4976862]);
},
"from":L[824]});
}
++R.GAS;
return $z68646865;
};
var $Hand_DASH_oper_DASH_16041398 = function(and_DASH_oper_DASH_311397,A113,e2371385) {
var if_helper4746879 = R.makeFunction(function(if_helper_arg4756897) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[183],1,arguments);
}
var ann_DASH_check_DASH_temp4726898 = if_helper_arg4756897;
return ann_DASH_check_DASH_temp4726898;
});
var anf_if4786896 = R.isBoolean(and_DASH_oper_DASH_311397);
if(R.isPyretTrue(anf_if4786896)) {
if(R.isPyretTrue(and_DASH_oper_DASH_311397)) {
var anf_fun4806876 = G(A113,"is-s-underscore",L[826]);
var anf_arg4816877 = G(e2371385,"id",L[825]);
var $z68686869 = D;
var $f68746875 = function(_) {
return R.isFunction(anf_fun4806876)?anf_fun4806876.app(anf_arg4816877):R.ffi.throwNonFunApp(L[183],anf_fun4806876,[anf_arg4816877]);
};
try {
if(--R.GAS > 0) {
$z68686869 = $f68746875();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68746875,
"from":L[183]});
}
} catch($e68666867) {
if(R.isCont($e68666867)) {
var $ss68706871 = {"from":L[183],
"go":function(and_DASH_oper_DASH_326878) {
return $Hand_DASH_oper_DASH_16026880(and_DASH_oper_DASH_326878,if_helper4746879);
}};
$e68666867.stack[R.EXN_STACKHEIGHT++] = $ss68706871;
}
if(R.isPyretException($e68666867)) {
$e68666867.pyretStack.push(L[183]);
}
throw $e68666867;
}
var $ret68726873 = $Hand_DASH_oper_DASH_16026880($z68686869,if_helper4746879);
++R.GAS;
return $ret68726873;
} else {
var $z68836884 = D;
var $f68896890 = function(_) {
return R.isFunction(if_helper4746879)?if_helper4746879.app((false)):R.ffi.throwNonFunApp(L[183],if_helper4746879,[(false)]);
};
try {
if(--R.GAS > 0) {
$z68836884 = $f68896890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68896890,
"from":L[183]});
}
} catch($e68816882) {
if(R.isCont($e68816882)) {
var $ss68856886 = {"from":L[183],
"go":function(cont_tail_app4796891) {
return $Hcont_tail_app16036892(cont_tail_app4796891);
}};
$e68816882.stack[R.EXN_STACKHEIGHT++] = $ss68856886;
}
if(R.isPyretException($e68816882)) {
$e68816882.pyretStack.push(L[183]);
}
throw $e68816882;
}
var $ret68876888 = $Hcont_tail_app16036892($z68836884);
++R.GAS;
return $ret68876888;
}
} else {
var cont_tail_arg4766895 = R.throwNonBooleanOp(L[827],("first"),("and"),and_DASH_oper_DASH_311397);
if(--R.GAS > 0) {
$z68936894 = R.isFunction(if_helper4746879)?if_helper4746879.app(cont_tail_arg4766895):R.ffi.throwNonFunApp(L[827],if_helper4746879,[cont_tail_arg4766895]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper4746879)?if_helper4746879.app(cont_tail_arg4766895):R.ffi.throwNonFunApp(L[827],if_helper4746879,[cont_tail_arg4766895]);
},
"from":L[827]});
}
++R.GAS;
return $z68936894;
}
};
var $Hand_DASH_oper_DASH_16026880 = function(and_DASH_oper_DASH_326878,if_helper4746879) {
var anf_if4846914 = R.isBoolean(and_DASH_oper_DASH_326878);
if(R.isPyretTrue(anf_if4846914)) {
var $z69016902 = D;
var $f69076908 = function(_) {
return R.isFunction(if_helper4746879)?if_helper4746879.app(and_DASH_oper_DASH_326878):R.ffi.throwNonFunApp(L[183],if_helper4746879,[and_DASH_oper_DASH_326878]);
};
try {
if(--R.GAS > 0) {
$z69016902 = $f69076908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69076908,
"from":L[183]});
}
} catch($e68996900) {
if(R.isCont($e68996900)) {
var $ss69036904 = {"from":L[183],
"go":function(cont_tail_app4856909) {
return $Hcont_tail_app16016910(cont_tail_app4856909);
}};
$e68996900.stack[R.EXN_STACKHEIGHT++] = $ss69036904;
}
if(R.isPyretException($e68996900)) {
$e68996900.pyretStack.push(L[183]);
}
throw $e68996900;
}
var $ret69056906 = $Hcont_tail_app16016910($z69016902);
++R.GAS;
return $ret69056906;
} else {
var cont_tail_arg4826913 = R.throwNonBooleanOp(L[828],("second"),("and"),and_DASH_oper_DASH_326878);
if(--R.GAS > 0) {
$z69116912 = R.isFunction(if_helper4746879)?if_helper4746879.app(cont_tail_arg4826913):R.ffi.throwNonFunApp(L[828],if_helper4746879,[cont_tail_arg4826913]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper4746879)?if_helper4746879.app(cont_tail_arg4826913):R.ffi.throwNonFunApp(L[828],if_helper4746879,[cont_tail_arg4826913]);
},
"from":L[828]});
}
++R.GAS;
return $z69116912;
}
};
var $Hcont_tail_app16016910 = function(cont_tail_app4856909) {
return cont_tail_app4856909;
};
var $Hcont_tail_app16036892 = function(cont_tail_app4796891) {
return cont_tail_app4796891;
};
var $Hann_DASH_check_DASH_temp16001414 = function(ann_DASH_check_DASH_temp4521413) {
return ann_DASH_check_DASH_temp4521413;
};
var $Hanf_arg15991426 = function(anf_arg4681425,_plus7,raise10) {
var $z69176918 = D;
var $f69236924 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("NYI(desugar-member): "),anf_arg4681425):R.ffi.throwNonFunApp(L[829],_plus7,[("NYI(desugar-member): "),anf_arg4681425]);
};
try {
if(--R.GAS > 0) {
$z69176918 = $f69236924();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69236924,
"from":L[829]});
}
} catch($e69156916) {
if(R.isCont($e69156916)) {
var $ss69196920 = {"from":L[829],
"go":function(anf_arg4696925) {
return $Hanf_arg15986926(anf_arg4696925,raise10);
}};
$e69156916.stack[R.EXN_STACKHEIGHT++] = $ss69196920;
}
if(R.isPyretException($e69156916)) {
$e69156916.pyretStack.push(L[829]);
}
throw $e69156916;
}
var $ret69216922 = $Hanf_arg15986926($z69176918,raise10);
++R.GAS;
return $ret69216922;
};
var $Hanf_arg15986926 = function(anf_arg4696925,raise10) {
var $z69296930 = D;
var $f69356936 = function(_) {
return R.isFunction(raise10)?raise10.app(anf_arg4696925):R.ffi.throwNonFunApp(L[186],raise10,[anf_arg4696925]);
};
try {
if(--R.GAS > 0) {
$z69296930 = $f69356936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69356936,
"from":L[186]});
}
} catch($e69276928) {
if(R.isCont($e69276928)) {
var $ss69316932 = {"from":L[186],
"go":function(ann_DASH_check_DASH_temp4676937) {
return $Hann_DASH_check_DASH_temp15976938(ann_DASH_check_DASH_temp4676937);
}};
$e69276928.stack[R.EXN_STACKHEIGHT++] = $ss69316932;
}
if(R.isPyretException($e69276928)) {
$e69276928.pyretStack.push(L[186]);
}
throw $e69276928;
}
var $ret69336934 = $Hann_DASH_check_DASH_temp15976938($z69296930);
++R.GAS;
return $ret69336934;
};
var $Hann_DASH_check_DASH_temp15976938 = function(ann_DASH_check_DASH_temp4676937) {
return ann_DASH_check_DASH_temp4676937;
};
var $Hanf_arg15961444 = function(anf_arg4631442,anf_fun4621443,desugar_DASH_expr117310,l2341429,value2361431) {
var $z69416942 = D;
var $f69476948 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[830],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[830],"desugar-expr"):desugar_DASH_expr117310.$var.app(value2361431):R.ffi.throwNonFunApp(L[831],desugar_DASH_expr117310.$var === D?U(L[830],"desugar-expr"):desugar_DASH_expr117310.$var,[value2361431]);
};
try {
if(--R.GAS > 0) {
$z69416942 = $f69476948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69476948,
"from":L[831]});
}
} catch($e69396940) {
if(R.isCont($e69396940)) {
var $ss69436944 = {"from":L[831],
"go":function(anf_arg4646949) {
return $Hanf_arg15956950(anf_arg4646949,anf_arg4631442,anf_fun4621443,l2341429);
}};
$e69396940.stack[R.EXN_STACKHEIGHT++] = $ss69436944;
}
if(R.isPyretException($e69396940)) {
$e69396940.pyretStack.push(L[831]);
}
throw $e69396940;
}
var $ret69456946 = $Hanf_arg15956950($z69416942,anf_arg4631442,anf_fun4621443,l2341429);
++R.GAS;
return $ret69456946;
};
var $Hanf_arg15956950 = function(anf_arg4646949,anf_arg4631442,anf_fun4621443,l2341429) {
var $z69536954 = D;
var $f69596960 = function(_) {
return R.isFunction(anf_fun4621443)?anf_fun4621443.app(l2341429,anf_arg4631442,anf_arg4646949):R.ffi.throwNonFunApp(L[188],anf_fun4621443,[l2341429,anf_arg4631442,anf_arg4646949]);
};
try {
if(--R.GAS > 0) {
$z69536954 = $f69596960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69596960,
"from":L[188]});
}
} catch($e69516952) {
if(R.isCont($e69516952)) {
var $ss69556956 = {"from":L[188],
"go":function(ann_DASH_check_DASH_temp4616961) {
return $Hann_DASH_check_DASH_temp15946962(ann_DASH_check_DASH_temp4616961);
}};
$e69516952.stack[R.EXN_STACKHEIGHT++] = $ss69556956;
}
if(R.isPyretException($e69516952)) {
$e69516952.pyretStack.push(L[188]);
}
throw $e69516952;
}
var $ret69576958 = $Hann_DASH_check_DASH_temp15946962($z69536954);
++R.GAS;
return $ret69576958;
};
var $Hann_DASH_check_DASH_temp15946962 = function(ann_DASH_check_DASH_temp4616961) {
return ann_DASH_check_DASH_temp4616961;
};
var $Hanf_arg15931464 = function(anf_arg4561462,A113,_check2331451,anf_fun4551463,ann2301448,args2291447,body2321450,desugar_DASH_expr117310,doc2311449,l2271445) {
var anf_fun4576973 = G(A113,"s-method",L[833]);
var $z69656966 = D;
var $f69716972 = function(_) {
return R.isFunction(anf_fun4576973)?anf_fun4576973.app(l2271445,args2291447,ann2301448,doc2311449,body2321450,_check2331451):R.ffi.throwNonFunApp(L[832],anf_fun4576973,[l2271445,args2291447,ann2301448,doc2311449,body2321450,_check2331451]);
};
try {
if(--R.GAS > 0) {
$z69656966 = $f69716972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69716972,
"from":L[832]});
}
} catch($e69636964) {
if(R.isCont($e69636964)) {
var $ss69676968 = {"from":L[832],
"go":function(anf_arg4586974) {
return $Hanf_arg15926975(anf_arg4586974,anf_arg4561462,anf_fun4551463,desugar_DASH_expr117310,l2271445);
}};
$e69636964.stack[R.EXN_STACKHEIGHT++] = $ss69676968;
}
if(R.isPyretException($e69636964)) {
$e69636964.pyretStack.push(L[832]);
}
throw $e69636964;
}
var $ret69696970 = $Hanf_arg15926975($z69656966,anf_arg4561462,anf_fun4551463,desugar_DASH_expr117310,l2271445);
++R.GAS;
return $ret69696970;
};
var $Hanf_arg15926975 = function(anf_arg4586974,anf_arg4561462,anf_fun4551463,desugar_DASH_expr117310,l2271445) {
var $z69786979 = D;
var $f69846985 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[834],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[834],"desugar-expr"):desugar_DASH_expr117310.$var.app(anf_arg4586974):R.ffi.throwNonFunApp(L[835],desugar_DASH_expr117310.$var === D?U(L[834],"desugar-expr"):desugar_DASH_expr117310.$var,[anf_arg4586974]);
};
try {
if(--R.GAS > 0) {
$z69786979 = $f69846985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69846985,
"from":L[835]});
}
} catch($e69766977) {
if(R.isCont($e69766977)) {
var $ss69806981 = {"from":L[835],
"go":function(anf_arg4596986) {
return $Hanf_arg15916987(anf_arg4596986,anf_arg4561462,anf_fun4551463,l2271445);
}};
$e69766977.stack[R.EXN_STACKHEIGHT++] = $ss69806981;
}
if(R.isPyretException($e69766977)) {
$e69766977.pyretStack.push(L[835]);
}
throw $e69766977;
}
var $ret69826983 = $Hanf_arg15916987($z69786979,anf_arg4561462,anf_fun4551463,l2271445);
++R.GAS;
return $ret69826983;
};
var $Hanf_arg15916987 = function(anf_arg4596986,anf_arg4561462,anf_fun4551463,l2271445) {
var $z69906991 = D;
var $f69966997 = function(_) {
return R.isFunction(anf_fun4551463)?anf_fun4551463.app(l2271445,anf_arg4561462,anf_arg4596986):R.ffi.throwNonFunApp(L[192],anf_fun4551463,[l2271445,anf_arg4561462,anf_arg4596986]);
};
try {
if(--R.GAS > 0) {
$z69906991 = $f69966997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69966997,
"from":L[192]});
}
} catch($e69886989) {
if(R.isCont($e69886989)) {
var $ss69926993 = {"from":L[192],
"go":function(ann_DASH_check_DASH_temp4546998) {
return $Hann_DASH_check_DASH_temp15906999(ann_DASH_check_DASH_temp4546998);
}};
$e69886989.stack[R.EXN_STACKHEIGHT++] = $ss69926993;
}
if(R.isPyretException($e69886989)) {
$e69886989.pyretStack.push(L[192]);
}
throw $e69886989;
}
var $ret69946995 = $Hann_DASH_check_DASH_temp15906999($z69906991);
++R.GAS;
return $ret69946995;
};
var $Hann_DASH_check_DASH_temp15906999 = function(ann_DASH_check_DASH_temp4546998) {
return ann_DASH_check_DASH_temp4546998;
};
var $Hann_DASH_check_DASH_temp15891481 = function(ann_DASH_check_DASH_temp4421480) {
return ann_DASH_check_DASH_temp4421480;
};
var $Hanf_arg15881499 = function(anf_arg4461497,anf_fun4451498,l2231484,typ2241485) {
var $z70027003 = D;
var $f70087009 = function(_) {
return R.isFunction(anf_fun4451498)?anf_fun4451498.app(l2231484,typ2241485,anf_arg4461497):R.ffi.throwNonFunApp(L[198],anf_fun4451498,[l2231484,typ2241485,anf_arg4461497]);
};
try {
if(--R.GAS > 0) {
$z70027003 = $f70087009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70087009,
"from":L[198]});
}
} catch($e70007001) {
if(R.isCont($e70007001)) {
var $ss70047005 = {"from":L[198],
"go":function(ann_DASH_check_DASH_temp4447010) {
return $Hann_DASH_check_DASH_temp15877011(ann_DASH_check_DASH_temp4447010);
}};
$e70007001.stack[R.EXN_STACKHEIGHT++] = $ss70047005;
}
if(R.isPyretException($e70007001)) {
$e70007001.pyretStack.push(L[198]);
}
throw $e70007001;
}
var $ret70067007 = $Hann_DASH_check_DASH_temp15877011($z70027003);
++R.GAS;
return $ret70067007;
};
var $Hann_DASH_check_DASH_temp15877011 = function(ann_DASH_check_DASH_temp4447010) {
return ann_DASH_check_DASH_temp4447010;
};
var $Hval_DASH_id15861517 = function(val_DASH_id2191516,A113,branches2171504,else_DASH_block2181505,l2141501,list2753,none6355,val2161503) {
var anf_fun4217022 = G(A113,"s-obj",L[837]);
var $z70147015 = D;
var $f70207021 = function(_) {
return R.isFunction(anf_fun4217022)?anf_fun4217022.app(l2141501,branches2171504):R.ffi.throwNonFunApp(L[836],anf_fun4217022,[l2141501,branches2171504]);
};
try {
if(--R.GAS > 0) {
$z70147015 = $f70207021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70207021,
"from":L[836]});
}
} catch($e70127013) {
if(R.isCont($e70127013)) {
var $ss70167017 = {"from":L[836],
"go":function(cases_DASH_object2207023) {
return $Hcases_DASH_object15857024(cases_DASH_object2207023,A113,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503);
}};
$e70127013.stack[R.EXN_STACKHEIGHT++] = $ss70167017;
}
if(R.isPyretException($e70127013)) {
$e70127013.pyretStack.push(L[836]);
}
throw $e70127013;
}
var $ret70187019 = $Hcases_DASH_object15857024($z70147015,A113,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503);
++R.GAS;
return $ret70187019;
};
var $Hcases_DASH_object15857024 = function(cases_DASH_object2207023,A113,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503) {
var anf_fun4227037 = G(A113,"s-lam",L[839]);
var anf_fun4237035 = G(list2753,"make",L[838]);
var $z70277028 = D;
var $f70337034 = function(_) {
return R.isFunction(anf_fun4237035)?anf_fun4237035.app([]):R.ffi.throwNonFunApp(L[838],anf_fun4237035,[[]]);
};
try {
if(--R.GAS > 0) {
$z70277028 = $f70337034();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70337034,
"from":L[838]});
}
} catch($e70257026) {
if(R.isCont($e70257026)) {
var $ss70297030 = {"from":L[838],
"go":function(anf_arg4247036) {
return $Hanf_arg15847038(anf_arg4247036,A113,anf_fun4227037,cases_DASH_object2207023,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503);
}};
$e70257026.stack[R.EXN_STACKHEIGHT++] = $ss70297030;
}
if(R.isPyretException($e70257026)) {
$e70257026.pyretStack.push(L[838]);
}
throw $e70257026;
}
var $ret70317032 = $Hanf_arg15847038($z70277028,A113,anf_fun4227037,cases_DASH_object2207023,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503);
++R.GAS;
return $ret70317032;
};
var $Hanf_arg15847038 = function(anf_arg4247036,A113,anf_fun4227037,cases_DASH_object2207023,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503) {
var anf_fun4257049 = G(list2753,"make",L[840]);
var $z70417042 = D;
var $f70477048 = function(_) {
return R.isFunction(anf_fun4257049)?anf_fun4257049.app([]):R.ffi.throwNonFunApp(L[840],anf_fun4257049,[[]]);
};
try {
if(--R.GAS > 0) {
$z70417042 = $f70477048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70477048,
"from":L[840]});
}
} catch($e70397040) {
if(R.isCont($e70397040)) {
var $ss70437044 = {"from":L[840],
"go":function(anf_arg4267050) {
return $Hanf_arg15837051(anf_arg4267050,A113,anf_arg4247036,anf_fun4227037,cases_DASH_object2207023,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503);
}};
$e70397040.stack[R.EXN_STACKHEIGHT++] = $ss70437044;
}
if(R.isPyretException($e70397040)) {
$e70397040.pyretStack.push(L[840]);
}
throw $e70397040;
}
var $ret70457046 = $Hanf_arg15837051($z70417042,A113,anf_arg4247036,anf_fun4227037,cases_DASH_object2207023,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503);
++R.GAS;
return $ret70457046;
};
var $Hanf_arg15837051 = function(anf_arg4267050,A113,anf_arg4247036,anf_fun4227037,cases_DASH_object2207023,else_DASH_block2181505,l2141501,list2753,none6355,val_DASH_id2191516,val2161503) {
var anf_arg4277062 = G(A113,"a-blank",L[842]);
var $z70547055 = D;
var $f70607061 = function(_) {
return R.isFunction(anf_fun4227037)?anf_fun4227037.app(l2141501,anf_arg4247036,anf_arg4267050,anf_arg4277062,(""),else_DASH_block2181505,none6355):R.ffi.throwNonFunApp(L[841],anf_fun4227037,[l2141501,anf_arg4247036,anf_arg4267050,anf_arg4277062,(""),else_DASH_block2181505,none6355]);
};
try {
if(--R.GAS > 0) {
$z70547055 = $f70607061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70607061,
"from":L[841]});
}
} catch($e70527053) {
if(R.isCont($e70527053)) {
var $ss70567057 = {"from":L[841],
"go":function(else_DASH_thunk2217063) {
return $Helse_DASH_thunk15827064(else_DASH_thunk2217063,A113,cases_DASH_object2207023,l2141501,list2753,val_DASH_id2191516,val2161503);
}};
$e70527053.stack[R.EXN_STACKHEIGHT++] = $ss70567057;
}
if(R.isPyretException($e70527053)) {
$e70527053.pyretStack.push(L[841]);
}
throw $e70527053;
}
var $ret70587059 = $Helse_DASH_thunk15827064($z70547055,A113,cases_DASH_object2207023,l2141501,list2753,val_DASH_id2191516,val2161503);
++R.GAS;
return $ret70587059;
};
var $Helse_DASH_thunk15827064 = function(else_DASH_thunk2217063,A113,cases_DASH_object2207023,l2141501,list2753,val_DASH_id2191516,val2161503) {
var anf_fun4287078 = G(A113,"s-let-expr",L[847]);
var anf_fun4297079 = G(list2753,"make",L[846]);
var anf_fun4307075 = G(A113,"s-let-bind",L[845]);
var anf_arg4317076 = G(val_DASH_id2191516,"id-b",L[844]);
var $z70677068 = D;
var $f70737074 = function(_) {
return R.isFunction(anf_fun4307075)?anf_fun4307075.app(l2141501,anf_arg4317076,val2161503):R.ffi.throwNonFunApp(L[843],anf_fun4307075,[l2141501,anf_arg4317076,val2161503]);
};
try {
if(--R.GAS > 0) {
$z70677068 = $f70737074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70737074,
"from":L[843]});
}
} catch($e70657066) {
if(R.isCont($e70657066)) {
var $ss70697070 = {"from":L[843],
"go":function(anf_array_val4327077) {
return $Hanf_array_val15817080(anf_array_val4327077,A113,anf_fun4287078,anf_fun4297079,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753,val_DASH_id2191516);
}};
$e70657066.stack[R.EXN_STACKHEIGHT++] = $ss70697070;
}
if(R.isPyretException($e70657066)) {
$e70657066.pyretStack.push(L[843]);
}
throw $e70657066;
}
var $ret70717072 = $Hanf_array_val15817080($z70677068,A113,anf_fun4287078,anf_fun4297079,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753,val_DASH_id2191516);
++R.GAS;
return $ret70717072;
};
var $Hanf_array_val15817080 = function(anf_array_val4327077,A113,anf_fun4287078,anf_fun4297079,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753,val_DASH_id2191516) {
var $z70837084 = D;
var $f70897090 = function(_) {
return R.isFunction(anf_fun4297079)?anf_fun4297079.app([anf_array_val4327077]):R.ffi.throwNonFunApp(L[846],anf_fun4297079,[[anf_array_val4327077]]);
};
try {
if(--R.GAS > 0) {
$z70837084 = $f70897090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70897090,
"from":L[846]});
}
} catch($e70817082) {
if(R.isCont($e70817082)) {
var $ss70857086 = {"from":L[846],
"go":function(anf_arg4337091) {
return $Hanf_arg15807092(anf_arg4337091,A113,anf_fun4287078,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753,val_DASH_id2191516);
}};
$e70817082.stack[R.EXN_STACKHEIGHT++] = $ss70857086;
}
if(R.isPyretException($e70817082)) {
$e70817082.pyretStack.push(L[846]);
}
throw $e70817082;
}
var $ret70877088 = $Hanf_arg15807092($z70837084,A113,anf_fun4287078,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753,val_DASH_id2191516);
++R.GAS;
return $ret70877088;
};
var $Hanf_arg15807092 = function(anf_arg4337091,A113,anf_fun4287078,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753,val_DASH_id2191516) {
var anf_fun4347106 = G(A113,"s-app",L[851]);
var anf_fun4357103 = G(A113,"s-dot",L[850]);
var anf_arg4367104 = G(val_DASH_id2191516,"id-e",L[849]);
var $z70957096 = D;
var $f71017102 = function(_) {
return R.isFunction(anf_fun4357103)?anf_fun4357103.app(l2141501,anf_arg4367104,("_match")):R.ffi.throwNonFunApp(L[848],anf_fun4357103,[l2141501,anf_arg4367104,("_match")]);
};
try {
if(--R.GAS > 0) {
$z70957096 = $f71017102();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71017102,
"from":L[848]});
}
} catch($e70937094) {
if(R.isCont($e70937094)) {
var $ss70977098 = {"from":L[848],
"go":function(anf_arg4377105) {
return $Hanf_arg15797107(anf_arg4377105,anf_arg4337091,anf_fun4287078,anf_fun4347106,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753);
}};
$e70937094.stack[R.EXN_STACKHEIGHT++] = $ss70977098;
}
if(R.isPyretException($e70937094)) {
$e70937094.pyretStack.push(L[848]);
}
throw $e70937094;
}
var $ret70997100 = $Hanf_arg15797107($z70957096,anf_arg4337091,anf_fun4287078,anf_fun4347106,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753);
++R.GAS;
return $ret70997100;
};
var $Hanf_arg15797107 = function(anf_arg4377105,anf_arg4337091,anf_fun4287078,anf_fun4347106,cases_DASH_object2207023,else_DASH_thunk2217063,l2141501,list2753) {
var anf_fun4387118 = G(list2753,"make",L[852]);
var $z71107111 = D;
var $f71167117 = function(_) {
return R.isFunction(anf_fun4387118)?anf_fun4387118.app([cases_DASH_object2207023,else_DASH_thunk2217063]):R.ffi.throwNonFunApp(L[852],anf_fun4387118,[[cases_DASH_object2207023,else_DASH_thunk2217063]]);
};
try {
if(--R.GAS > 0) {
$z71107111 = $f71167117();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71167117,
"from":L[852]});
}
} catch($e71087109) {
if(R.isCont($e71087109)) {
var $ss71127113 = {"from":L[852],
"go":function(anf_arg4397119) {
return $Hanf_arg15787120(anf_arg4397119,anf_arg4337091,anf_arg4377105,anf_fun4287078,anf_fun4347106,l2141501);
}};
$e71087109.stack[R.EXN_STACKHEIGHT++] = $ss71127113;
}
if(R.isPyretException($e71087109)) {
$e71087109.pyretStack.push(L[852]);
}
throw $e71087109;
}
var $ret71147115 = $Hanf_arg15787120($z71107111,anf_arg4337091,anf_arg4377105,anf_fun4287078,anf_fun4347106,l2141501);
++R.GAS;
return $ret71147115;
};
var $Hanf_arg15787120 = function(anf_arg4397119,anf_arg4337091,anf_arg4377105,anf_fun4287078,anf_fun4347106,l2141501) {
var $z71237124 = D;
var $f71297130 = function(_) {
return R.isFunction(anf_fun4347106)?anf_fun4347106.app(l2141501,anf_arg4377105,anf_arg4397119):R.ffi.throwNonFunApp(L[853],anf_fun4347106,[l2141501,anf_arg4377105,anf_arg4397119]);
};
try {
if(--R.GAS > 0) {
$z71237124 = $f71297130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71297130,
"from":L[853]});
}
} catch($e71217122) {
if(R.isCont($e71217122)) {
var $ss71257126 = {"from":L[853],
"go":function(anf_arg4407131) {
return $Hanf_arg15777132(anf_arg4407131,anf_arg4337091,anf_fun4287078,l2141501);
}};
$e71217122.stack[R.EXN_STACKHEIGHT++] = $ss71257126;
}
if(R.isPyretException($e71217122)) {
$e71217122.pyretStack.push(L[853]);
}
throw $e71217122;
}
var $ret71277128 = $Hanf_arg15777132($z71237124,anf_arg4337091,anf_fun4287078,l2141501);
++R.GAS;
return $ret71277128;
};
var $Hanf_arg15777132 = function(anf_arg4407131,anf_arg4337091,anf_fun4287078,l2141501) {
var $z71357136 = D;
var $f71417142 = function(_) {
return R.isFunction(anf_fun4287078)?anf_fun4287078.app(l2141501,anf_arg4337091,anf_arg4407131):R.ffi.throwNonFunApp(L[202],anf_fun4287078,[l2141501,anf_arg4337091,anf_arg4407131]);
};
try {
if(--R.GAS > 0) {
$z71357136 = $f71417142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71417142,
"from":L[202]});
}
} catch($e71337134) {
if(R.isCont($e71337134)) {
var $ss71377138 = {"from":L[202],
"go":function(ann_DASH_check_DASH_temp4207143) {
return $Hann_DASH_check_DASH_temp15767144(ann_DASH_check_DASH_temp4207143);
}};
$e71337134.stack[R.EXN_STACKHEIGHT++] = $ss71377138;
}
if(R.isPyretException($e71337134)) {
$e71337134.pyretStack.push(L[202]);
}
throw $e71337134;
}
var $ret71397140 = $Hann_DASH_check_DASH_temp15767144($z71357136);
++R.GAS;
return $ret71397140;
};
var $Hann_DASH_check_DASH_temp15767144 = function(ann_DASH_check_DASH_temp4207143) {
return ann_DASH_check_DASH_temp4207143;
};
var $Hann_DASH_check_DASH_temp15751533 = function(ann_DASH_check_DASH_temp4011532) {
return ann_DASH_check_DASH_temp4011532;
};
var $Hanf_arg15741553 = function(anf_arg4061551,A113,anf_fun4041552,args2121538,body2131539,desugar_DASH_bind116308,desugar_DASH_member109294,l22101536,list2753,none6355) {
var anf_fun4077157 = G(A113,"s-lam",L[855]);
var anf_fun4087155 = G(list2753,"make",L[854]);
var $z71477148 = D;
var $f71537154 = function(_) {
return R.isFunction(anf_fun4087155)?anf_fun4087155.app([]):R.ffi.throwNonFunApp(L[854],anf_fun4087155,[[]]);
};
try {
if(--R.GAS > 0) {
$z71477148 = $f71537154();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71537154,
"from":L[854]});
}
} catch($e71457146) {
if(R.isCont($e71457146)) {
var $ss71497150 = {"from":L[854],
"go":function(anf_arg4097156) {
return $Hanf_arg15737158(anf_arg4097156,A113,anf_arg4061551,anf_fun4041552,anf_fun4077157,args2121538,body2131539,desugar_DASH_bind116308,desugar_DASH_member109294,l22101536,none6355);
}};
$e71457146.stack[R.EXN_STACKHEIGHT++] = $ss71497150;
}
if(R.isPyretException($e71457146)) {
$e71457146.pyretStack.push(L[854]);
}
throw $e71457146;
}
var $ret71517152 = $Hanf_arg15737158($z71477148,A113,anf_arg4061551,anf_fun4041552,anf_fun4077157,args2121538,body2131539,desugar_DASH_bind116308,desugar_DASH_member109294,l22101536,none6355);
++R.GAS;
return $ret71517152;
};
var $Hanf_arg15737158 = function(anf_arg4097156,A113,anf_arg4061551,anf_fun4041552,anf_fun4077157,args2121538,body2131539,desugar_DASH_bind116308,desugar_DASH_member109294,l22101536,none6355) {
var anf_fun4107169 = G(args2121538,"map",L[858]);
var $z71617162 = D;
var $f71677168 = function(_) {
return R.isFunction(anf_fun4107169)?anf_fun4107169.app(desugar_DASH_bind116308.$var === D?U(L[856],"desugar-bind"):desugar_DASH_bind116308.$var):R.ffi.throwNonFunApp(L[857],anf_fun4107169,[desugar_DASH_bind116308.$var === D?U(L[856],"desugar-bind"):desugar_DASH_bind116308.$var]);
};
try {
if(--R.GAS > 0) {
$z71617162 = $f71677168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71677168,
"from":L[857]});
}
} catch($e71597160) {
if(R.isCont($e71597160)) {
var $ss71637164 = {"from":L[857],
"go":function(anf_arg4117170) {
return $Hanf_arg15727171(anf_arg4117170,A113,anf_arg4061551,anf_arg4097156,anf_fun4041552,anf_fun4077157,body2131539,desugar_DASH_member109294,l22101536,none6355);
}};
$e71597160.stack[R.EXN_STACKHEIGHT++] = $ss71637164;
}
if(R.isPyretException($e71597160)) {
$e71597160.pyretStack.push(L[857]);
}
throw $e71597160;
}
var $ret71657166 = $Hanf_arg15727171($z71617162,A113,anf_arg4061551,anf_arg4097156,anf_fun4041552,anf_fun4077157,body2131539,desugar_DASH_member109294,l22101536,none6355);
++R.GAS;
return $ret71657166;
};
var $Hanf_arg15727171 = function(anf_arg4117170,A113,anf_arg4061551,anf_arg4097156,anf_fun4041552,anf_fun4077157,body2131539,desugar_DASH_member109294,l22101536,none6355) {
var anf_arg4127182 = G(A113,"a-blank",L[860]);
var $z71747175 = D;
var $f71807181 = function(_) {
return R.isFunction(anf_fun4077157)?anf_fun4077157.app(l22101536,anf_arg4097156,anf_arg4117170,anf_arg4127182,(""),body2131539,none6355):R.ffi.throwNonFunApp(L[859],anf_fun4077157,[l22101536,anf_arg4097156,anf_arg4117170,anf_arg4127182,(""),body2131539,none6355]);
};
try {
if(--R.GAS > 0) {
$z71747175 = $f71807181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71807181,
"from":L[859]});
}
} catch($e71727173) {
if(R.isCont($e71727173)) {
var $ss71767177 = {"from":L[859],
"go":function(anf_arg4137183) {
return $Hanf_arg15717184(anf_arg4137183,anf_arg4061551,anf_fun4041552,desugar_DASH_member109294,l22101536);
}};
$e71727173.stack[R.EXN_STACKHEIGHT++] = $ss71767177;
}
if(R.isPyretException($e71727173)) {
$e71727173.pyretStack.push(L[859]);
}
throw $e71727173;
}
var $ret71787179 = $Hanf_arg15717184($z71747175,anf_arg4061551,anf_fun4041552,desugar_DASH_member109294,l22101536);
++R.GAS;
return $ret71787179;
};
var $Hanf_arg15717184 = function(anf_arg4137183,anf_arg4061551,anf_fun4041552,desugar_DASH_member109294,l22101536) {
var $z71877188 = D;
var $f71937194 = function(_) {
return R.isFunction(anf_fun4041552)?anf_fun4041552.app(l22101536,anf_arg4061551,anf_arg4137183):R.ffi.throwNonFunApp(L[861],anf_fun4041552,[l22101536,anf_arg4061551,anf_arg4137183]);
};
try {
if(--R.GAS > 0) {
$z71877188 = $f71937194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71937194,
"from":L[861]});
}
} catch($e71857186) {
if(R.isCont($e71857186)) {
var $ss71897190 = {"from":L[861],
"go":function(anf_arg4147195) {
return $Hanf_arg15707196(anf_arg4147195,desugar_DASH_member109294);
}};
$e71857186.stack[R.EXN_STACKHEIGHT++] = $ss71897190;
}
if(R.isPyretException($e71857186)) {
$e71857186.pyretStack.push(L[861]);
}
throw $e71857186;
}
var $ret71917192 = $Hanf_arg15707196($z71877188,desugar_DASH_member109294);
++R.GAS;
return $ret71917192;
};
var $Hanf_arg15707196 = function(anf_arg4147195,desugar_DASH_member109294) {
var $z71997200 = D;
var $f72057206 = function(_) {
return R.isFunction(desugar_DASH_member109294.$var === D?U(L[862],"desugar-member"):desugar_DASH_member109294.$var)?desugar_DASH_member109294.$var === D?U(L[862],"desugar-member"):desugar_DASH_member109294.$var.app(anf_arg4147195):R.ffi.throwNonFunApp(L[206],desugar_DASH_member109294.$var === D?U(L[862],"desugar-member"):desugar_DASH_member109294.$var,[anf_arg4147195]);
};
try {
if(--R.GAS > 0) {
$z71997200 = $f72057206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72057206,
"from":L[206]});
}
} catch($e71977198) {
if(R.isCont($e71977198)) {
var $ss72017202 = {"from":L[206],
"go":function(ann_DASH_check_DASH_temp4037207) {
return $Hann_DASH_check_DASH_temp15697208(ann_DASH_check_DASH_temp4037207);
}};
$e71977198.stack[R.EXN_STACKHEIGHT++] = $ss72017202;
}
if(R.isPyretException($e71977198)) {
$e71977198.pyretStack.push(L[206]);
}
throw $e71977198;
}
var $ret72037204 = $Hann_DASH_check_DASH_temp15697208($z71997200);
++R.GAS;
return $ret72037204;
};
var $Hann_DASH_check_DASH_temp15697208 = function(ann_DASH_check_DASH_temp4037207) {
return ann_DASH_check_DASH_temp4037207;
};
var $Hanf_arg15681570 = function(anf_arg3971568,anf_arg3961569,branches2041556,fold5550) {
var anf_fun3987219 = G(branches2041556,"reverse",L[864]);
var $z72117212 = D;
var $f72177218 = function(_) {
return R.isFunction(anf_fun3987219)?anf_fun3987219.app():R.ffi.throwNonFunApp(L[863],anf_fun3987219,[]);
};
try {
if(--R.GAS > 0) {
$z72117212 = $f72177218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72177218,
"from":L[863]});
}
} catch($e72097210) {
if(R.isCont($e72097210)) {
var $ss72137214 = {"from":L[863],
"go":function(anf_arg3997220) {
return $Hanf_arg15677221(anf_arg3997220,anf_arg3961569,anf_arg3971568,fold5550);
}};
$e72097210.stack[R.EXN_STACKHEIGHT++] = $ss72137214;
}
if(R.isPyretException($e72097210)) {
$e72097210.pyretStack.push(L[863]);
}
throw $e72097210;
}
var $ret72157216 = $Hanf_arg15677221($z72117212,anf_arg3961569,anf_arg3971568,fold5550);
++R.GAS;
return $ret72157216;
};
var $Hanf_arg15677221 = function(anf_arg3997220,anf_arg3961569,anf_arg3971568,fold5550) {
var $z72247225 = D;
var $f72307231 = function(_) {
return R.isFunction(fold5550)?fold5550.app(anf_arg3961569,anf_arg3971568,anf_arg3997220):R.ffi.throwNonFunApp(L[210],fold5550,[anf_arg3961569,anf_arg3971568,anf_arg3997220]);
};
try {
if(--R.GAS > 0) {
$z72247225 = $f72307231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72307231,
"from":L[210]});
}
} catch($e72227223) {
if(R.isCont($e72227223)) {
var $ss72267227 = {"from":L[210],
"go":function(ann_DASH_check_DASH_temp3777232) {
return $Hann_DASH_check_DASH_temp15667233(ann_DASH_check_DASH_temp3777232);
}};
$e72227223.stack[R.EXN_STACKHEIGHT++] = $ss72267227;
}
if(R.isPyretException($e72227223)) {
$e72227223.pyretStack.push(L[210]);
}
throw $e72227223;
}
var $ret72287229 = $Hann_DASH_check_DASH_temp15667233($z72247225);
++R.GAS;
return $ret72287229;
};
var $Hann_DASH_check_DASH_temp15667233 = function(ann_DASH_check_DASH_temp3777232) {
return ann_DASH_check_DASH_temp3777232;
};
var $Htest_DASH_id15651584 = function(test_DASH_id2081583,A113,acc2061571,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,desugar_DASH_expr117310,l2031555,list2753) {
var anf_arg3797246 = G(branch2071572,"l",L[868]);
var anf_arg3807244 = G(branch2071572,"test",L[867]);
var $z72367237 = D;
var $f72427243 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[865],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[865],"desugar-expr"):desugar_DASH_expr117310.$var.app(anf_arg3807244):R.ffi.throwNonFunApp(L[866],desugar_DASH_expr117310.$var === D?U(L[865],"desugar-expr"):desugar_DASH_expr117310.$var,[anf_arg3807244]);
};
try {
if(--R.GAS > 0) {
$z72367237 = $f72427243();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72427243,
"from":L[866]});
}
} catch($e72347235) {
if(R.isCont($e72347235)) {
var $ss72387239 = {"from":L[866],
"go":function(anf_arg3817245) {
return $Hanf_arg15647247(anf_arg3817245,A113,acc2061571,anf_arg3797246,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,desugar_DASH_expr117310,l2031555,list2753,test_DASH_id2081583);
}};
$e72347235.stack[R.EXN_STACKHEIGHT++] = $ss72387239;
}
if(R.isPyretException($e72347235)) {
$e72347235.pyretStack.push(L[866]);
}
throw $e72347235;
}
var $ret72407241 = $Hanf_arg15647247($z72367237,A113,acc2061571,anf_arg3797246,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,desugar_DASH_expr117310,l2031555,list2753,test_DASH_id2081583);
++R.GAS;
return $ret72407241;
};
var $Hanf_arg15647247 = function(anf_arg3817245,A113,acc2061571,anf_arg3797246,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,desugar_DASH_expr117310,l2031555,list2753,test_DASH_id2081583) {
var anf_fun3827262 = G(A113,"s-if-else",L[876]);
var anf_fun3837263 = G(list2753,"make",L[875]);
var anf_fun3847264 = G(A113,"s-if-branch",L[874]);
var anf_arg3857260 = G(branch2071572,"l",L[873]);
var anf_arg3867261 = G(test_DASH_id2081583,"id-e",L[872]);
var anf_arg3877258 = G(branch2071572,"body",L[871]);
var $z72507251 = D;
var $f72567257 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[869],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[869],"desugar-expr"):desugar_DASH_expr117310.$var.app(anf_arg3877258):R.ffi.throwNonFunApp(L[870],desugar_DASH_expr117310.$var === D?U(L[869],"desugar-expr"):desugar_DASH_expr117310.$var,[anf_arg3877258]);
};
try {
if(--R.GAS > 0) {
$z72507251 = $f72567257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72567257,
"from":L[870]});
}
} catch($e72487249) {
if(R.isCont($e72487249)) {
var $ss72527253 = {"from":L[870],
"go":function(anf_arg3887259) {
return $Hanf_arg15637265(anf_arg3887259,acc2061571,anf_arg3797246,anf_arg3817245,anf_arg3857260,anf_arg3867261,anf_fun3827262,anf_fun3837263,anf_fun3847264,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583);
}};
$e72487249.stack[R.EXN_STACKHEIGHT++] = $ss72527253;
}
if(R.isPyretException($e72487249)) {
$e72487249.pyretStack.push(L[870]);
}
throw $e72487249;
}
var $ret72547255 = $Hanf_arg15637265($z72507251,acc2061571,anf_arg3797246,anf_arg3817245,anf_arg3857260,anf_arg3867261,anf_fun3827262,anf_fun3837263,anf_fun3847264,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583);
++R.GAS;
return $ret72547255;
};
var $Hanf_arg15637265 = function(anf_arg3887259,acc2061571,anf_arg3797246,anf_arg3817245,anf_arg3857260,anf_arg3867261,anf_fun3827262,anf_fun3837263,anf_fun3847264,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583) {
var $z72687269 = D;
var $f72747275 = function(_) {
return R.isFunction(anf_fun3847264)?anf_fun3847264.app(anf_arg3857260,anf_arg3867261,anf_arg3887259):R.ffi.throwNonFunApp(L[877],anf_fun3847264,[anf_arg3857260,anf_arg3867261,anf_arg3887259]);
};
try {
if(--R.GAS > 0) {
$z72687269 = $f72747275();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72747275,
"from":L[877]});
}
} catch($e72667267) {
if(R.isCont($e72667267)) {
var $ss72707271 = {"from":L[877],
"go":function(anf_array_val3897276) {
return $Hanf_array_val15627277(anf_array_val3897276,acc2061571,anf_arg3797246,anf_arg3817245,anf_fun3827262,anf_fun3837263,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583);
}};
$e72667267.stack[R.EXN_STACKHEIGHT++] = $ss72707271;
}
if(R.isPyretException($e72667267)) {
$e72667267.pyretStack.push(L[877]);
}
throw $e72667267;
}
var $ret72727273 = $Hanf_array_val15627277($z72687269,acc2061571,anf_arg3797246,anf_arg3817245,anf_fun3827262,anf_fun3837263,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583);
++R.GAS;
return $ret72727273;
};
var $Hanf_array_val15627277 = function(anf_array_val3897276,acc2061571,anf_arg3797246,anf_arg3817245,anf_fun3827262,anf_fun3837263,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583) {
var $z72807281 = D;
var $f72867287 = function(_) {
return R.isFunction(anf_fun3837263)?anf_fun3837263.app([anf_array_val3897276]):R.ffi.throwNonFunApp(L[875],anf_fun3837263,[[anf_array_val3897276]]);
};
try {
if(--R.GAS > 0) {
$z72807281 = $f72867287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72867287,
"from":L[875]});
}
} catch($e72787279) {
if(R.isCont($e72787279)) {
var $ss72827283 = {"from":L[875],
"go":function(anf_arg3907288) {
return $Hanf_arg15617289(anf_arg3907288,acc2061571,anf_arg3797246,anf_arg3817245,anf_fun3827262,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583);
}};
$e72787279.stack[R.EXN_STACKHEIGHT++] = $ss72827283;
}
if(R.isPyretException($e72787279)) {
$e72787279.pyretStack.push(L[875]);
}
throw $e72787279;
}
var $ret72847285 = $Hanf_arg15617289($z72807281,acc2061571,anf_arg3797246,anf_arg3817245,anf_fun3827262,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583);
++R.GAS;
return $ret72847285;
};
var $Hanf_arg15617289 = function(anf_arg3907288,acc2061571,anf_arg3797246,anf_arg3817245,anf_fun3827262,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,l2031555,test_DASH_id2081583) {
var $z72927293 = D;
var $f72987299 = function(_) {
return R.isFunction(anf_fun3827262)?anf_fun3827262.app(l2031555,anf_arg3907288,acc2061571):R.ffi.throwNonFunApp(L[878],anf_fun3827262,[l2031555,anf_arg3907288,acc2061571]);
};
try {
if(--R.GAS > 0) {
$z72927293 = $f72987299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72987299,
"from":L[878]});
}
} catch($e72907291) {
if(R.isCont($e72907291)) {
var $ss72947295 = {"from":L[878],
"go":function(anf_arg3917300) {
return $Hanf_arg15607301(anf_arg3917300,anf_arg3797246,anf_arg3817245,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,test_DASH_id2081583);
}};
$e72907291.stack[R.EXN_STACKHEIGHT++] = $ss72947295;
}
if(R.isPyretException($e72907291)) {
$e72907291.pyretStack.push(L[878]);
}
throw $e72907291;
}
var $ret72967297 = $Hanf_arg15607301($z72927293,anf_arg3797246,anf_arg3817245,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,test_DASH_id2081583);
++R.GAS;
return $ret72967297;
};
var $Hanf_arg15607301 = function(anf_arg3917300,anf_arg3797246,anf_arg3817245,bool_DASH_exn95266,branch2071572,check_DASH_bool91258,test_DASH_id2081583) {
var anf_bracket3927316 = G(branch2071572,"test",L[882]);
var anf_arg3937312 = G(anf_bracket3927316,"l",L[881]);
var anf_arg3947313 = G(test_DASH_id2081583,"id-e",L[880]);
var $z73047305 = D;
var $f73107311 = function(_) {
return R.isFunction(bool_DASH_exn95266.$var)?bool_DASH_exn95266.$var.app(anf_arg3937312,("if"),anf_arg3947313):R.ffi.throwNonFunApp(L[879],bool_DASH_exn95266.$var,[anf_arg3937312,("if"),anf_arg3947313]);
};
try {
if(--R.GAS > 0) {
$z73047305 = $f73107311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73107311,
"from":L[879]});
}
} catch($e73027303) {
if(R.isCont($e73027303)) {
var $ss73067307 = {"from":L[879],
"go":function(anf_arg3957314) {
return $Hanf_arg15597315(anf_arg3957314,anf_arg3797246,anf_arg3817245,anf_arg3917300,check_DASH_bool91258,test_DASH_id2081583);
}};
$e73027303.stack[R.EXN_STACKHEIGHT++] = $ss73067307;
}
if(R.isPyretException($e73027303)) {
$e73027303.pyretStack.push(L[879]);
}
throw $e73027303;
}
var $ret73087309 = $Hanf_arg15597315($z73047305,anf_arg3797246,anf_arg3817245,anf_arg3917300,check_DASH_bool91258,test_DASH_id2081583);
++R.GAS;
return $ret73087309;
};
var $Hanf_arg15597315 = function(anf_arg3957314,anf_arg3797246,anf_arg3817245,anf_arg3917300,check_DASH_bool91258,test_DASH_id2081583) {
var $z73197320 = D;
var $f73257326 = function(_) {
return R.isFunction(check_DASH_bool91258.$var)?check_DASH_bool91258.$var.app(anf_arg3797246,test_DASH_id2081583,anf_arg3817245,anf_arg3917300,anf_arg3957314):R.ffi.throwNonFunApp(L[213],check_DASH_bool91258.$var,[anf_arg3797246,test_DASH_id2081583,anf_arg3817245,anf_arg3917300,anf_arg3957314]);
};
try {
if(--R.GAS > 0) {
$z73197320 = $f73257326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73257326,
"from":L[213]});
}
} catch($e73177318) {
if(R.isCont($e73177318)) {
var $ss73217322 = {"from":L[213],
"go":function(ann_DASH_check_DASH_temp3787327) {
return $Hann_DASH_check_DASH_temp15587328(ann_DASH_check_DASH_temp3787327);
}};
$e73177318.stack[R.EXN_STACKHEIGHT++] = $ss73217322;
}
if(R.isPyretException($e73177318)) {
$e73177318.pyretStack.push(L[213]);
}
throw $e73177318;
}
var $ret73237324 = $Hann_DASH_check_DASH_temp15587328($z73197320);
++R.GAS;
return $ret73237324;
};
var $Hann_DASH_check_DASH_temp15587328 = function(ann_DASH_check_DASH_temp3787327) {
return ann_DASH_check_DASH_temp3787327;
};
var $Hcont_tail_arg15491598 = function(cont_tail_arg3741596,if_helper3331597) {
if(--R.GAS > 0) {
$z73297330 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3741596):R.ffi.throwNonFunApp(L[217],if_helper3331597,[cont_tail_arg3741596]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3741596):R.ffi.throwNonFunApp(L[217],if_helper3331597,[cont_tail_arg3741596]);
},
"from":L[217]});
}
++R.GAS;
return $z73297330;
};
var $Hcont_tail_arg15501610 = function(cont_tail_arg3721609,if_helper3331597) {
if(--R.GAS > 0) {
$z73317332 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3721609):R.ffi.throwNonFunApp(L[218],if_helper3331597,[cont_tail_arg3721609]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3721609):R.ffi.throwNonFunApp(L[218],if_helper3331597,[cont_tail_arg3721609]);
},
"from":L[218]});
}
++R.GAS;
return $z73317332;
};
var $Hcont_tail_arg15511622 = function(cont_tail_arg3701621,if_helper3331597) {
if(--R.GAS > 0) {
$z73337334 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3701621):R.ffi.throwNonFunApp(L[219],if_helper3331597,[cont_tail_arg3701621]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3701621):R.ffi.throwNonFunApp(L[219],if_helper3331597,[cont_tail_arg3701621]);
},
"from":L[219]});
}
++R.GAS;
return $z73337334;
};
var $Hcont_tail_arg15521634 = function(cont_tail_arg3681633,if_helper3331597) {
if(--R.GAS > 0) {
$z73357336 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3681633):R.ffi.throwNonFunApp(L[220],if_helper3331597,[cont_tail_arg3681633]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3681633):R.ffi.throwNonFunApp(L[220],if_helper3331597,[cont_tail_arg3681633]);
},
"from":L[220]});
}
++R.GAS;
return $z73357336;
};
var $Hcont_tail_arg15531646 = function(cont_tail_arg3661645,if_helper3331597) {
if(--R.GAS > 0) {
$z73377338 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3661645):R.ffi.throwNonFunApp(L[221],if_helper3331597,[cont_tail_arg3661645]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3661645):R.ffi.throwNonFunApp(L[221],if_helper3331597,[cont_tail_arg3661645]);
},
"from":L[221]});
}
++R.GAS;
return $z73377338;
};
var $Hcont_tail_arg15541658 = function(cont_tail_arg3641657,if_helper3331597) {
if(--R.GAS > 0) {
$z73397340 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3641657):R.ffi.throwNonFunApp(L[222],if_helper3331597,[cont_tail_arg3641657]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3641657):R.ffi.throwNonFunApp(L[222],if_helper3331597,[cont_tail_arg3641657]);
},
"from":L[222]});
}
++R.GAS;
return $z73397340;
};
var $Hcont_tail_arg15551670 = function(cont_tail_arg3621669,if_helper3331597) {
if(--R.GAS > 0) {
$z73417342 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3621669):R.ffi.throwNonFunApp(L[223],if_helper3331597,[cont_tail_arg3621669]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3621669):R.ffi.throwNonFunApp(L[223],if_helper3331597,[cont_tail_arg3621669]);
},
"from":L[223]});
}
++R.GAS;
return $z73417342;
};
var $Hcont_tail_arg15561682 = function(cont_tail_arg3601681,if_helper3331597) {
if(--R.GAS > 0) {
$z73437344 = R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3601681):R.ffi.throwNonFunApp(L[224],if_helper3331597,[cont_tail_arg3601681]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3331597)?if_helper3331597.app(cont_tail_arg3601681):R.ffi.throwNonFunApp(L[224],if_helper3331597,[cont_tail_arg3601681]);
},
"from":L[224]});
}
++R.GAS;
return $z73437344;
};
var $Hcont_tail_app15571694 = function(cont_tail_app3591693) {
return cont_tail_app3591693;
};
var $Hanf_arg15481751 = function(anf_arg2671750,A113,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11) {
var $z73477348 = D;
var $f73537354 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l1901737,anf_arg2671750):R.ffi.throwNonFunApp(L[883],mk_DASH_id101278.$var,[l1901737,anf_arg2671750]);
};
try {
if(--R.GAS > 0) {
$z73477348 = $f73537354();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73537354,
"from":L[883]});
}
} catch($e73457346) {
if(R.isCont($e73457346)) {
var $ss73497350 = {"from":L[883],
"go":function(call_DASH_match_DASH_case1937355) {
return $Hcall_DASH_match_DASH_case15477356(call_DASH_match_DASH_case1937355,A113,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11);
}};
$e73457346.stack[R.EXN_STACKHEIGHT++] = $ss73497350;
}
if(R.isPyretException($e73457346)) {
$e73457346.pyretStack.push(L[883]);
}
throw $e73457346;
}
var $ret73517352 = $Hcall_DASH_match_DASH_case15477356($z73477348,A113,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11);
++R.GAS;
return $ret73517352;
};
var $Hcall_DASH_match_DASH_case15477356 = function(call_DASH_match_DASH_case1937355,A113,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11) {
var $z73597360 = D;
var $f73657366 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l1901737,("self")):R.ffi.throwNonFunApp(L[884],mk_DASH_id101278.$var,[l1901737,("self")]);
};
try {
if(--R.GAS > 0) {
$z73597360 = $f73657366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73657366,
"from":L[884]});
}
} catch($e73577358) {
if(R.isCont($e73577358)) {
var $ss73617362 = {"from":L[884],
"go":function(self_DASH_id1947367) {
return $Hself_DASH_id15467368(self_DASH_id1947367,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11);
}};
$e73577358.stack[R.EXN_STACKHEIGHT++] = $ss73617362;
}
if(R.isPyretException($e73577358)) {
$e73577358.pyretStack.push(L[884]);
}
throw $e73577358;
}
var $ret73637364 = $Hself_DASH_id15467368($z73597360,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11);
++R.GAS;
return $ret73637364;
};
var $Hself_DASH_id15467368 = function(self_DASH_id1947367,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,_plus7,nothing9,raise10,torepr11) {
var $z73717372 = D;
var $f73777378 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l1901737,("cases-funs")):R.ffi.throwNonFunApp(L[885],mk_DASH_id101278.$var,[l1901737,("cases-funs")]);
};
try {
if(--R.GAS > 0) {
$z73717372 = $f73777378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73777378,
"from":L[885]});
}
} catch($e73697370) {
if(R.isCont($e73697370)) {
var $ss73737374 = {"from":L[885],
"go":function(cases_DASH_id1957379) {
return $Hcases_DASH_id15457380(cases_DASH_id1957379,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,self_DASH_id1947367,_plus7,nothing9,raise10,torepr11);
}};
$e73697370.stack[R.EXN_STACKHEIGHT++] = $ss73737374;
}
if(R.isPyretException($e73697370)) {
$e73697370.pyretStack.push(L[885]);
}
throw $e73697370;
}
var $ret73757376 = $Hcases_DASH_id15457380($z73717372,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,self_DASH_id1947367,_plus7,nothing9,raise10,torepr11);
++R.GAS;
return $ret73757376;
};
var $Hcases_DASH_id15457380 = function(cases_DASH_id1957379,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,fields1921739,l1901737,list2753,map3954,mk_DASH_id101278,none6355,self_DASH_id1947367,_plus7,nothing9,raise10,torepr11) {
var $z73837384 = D;
var $f73897390 = function(_) {
return R.isFunction(mk_DASH_id101278.$var)?mk_DASH_id101278.$var.app(l1901737,("else-clause")):R.ffi.throwNonFunApp(L[886],mk_DASH_id101278.$var,[l1901737,("else-clause")]);
};
try {
if(--R.GAS > 0) {
$z73837384 = $f73897390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73897390,
"from":L[886]});
}
} catch($e73817382) {
if(R.isCont($e73817382)) {
var $ss73857386 = {"from":L[886],
"go":function(else_DASH_id1967391) {
return $Helse_DASH_id15447392(else_DASH_id1967391,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,fields1921739,l1901737,list2753,map3954,none6355,self_DASH_id1947367,_plus7,nothing9,raise10,torepr11);
}};
$e73817382.stack[R.EXN_STACKHEIGHT++] = $ss73857386;
}
if(R.isPyretException($e73817382)) {
$e73817382.pyretStack.push(L[886]);
}
throw $e73817382;
}
var $ret73877388 = $Helse_DASH_id15447392($z73837384,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,fields1921739,l1901737,list2753,map3954,none6355,self_DASH_id1947367,_plus7,nothing9,raise10,torepr11);
++R.GAS;
return $ret73877388;
};
var $Helse_DASH_id15447392 = function(else_DASH_id1967391,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,fields1921739,l1901737,list2753,map3954,none6355,self_DASH_id1947367,_plus7,nothing9,raise10,torepr11) {
var anf_arg2917403 = R.makeFunction(function(f1987406) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[888],1,arguments);
}
var cases_DASH_val187476 = f1987406;
var anf_fun2697417 = G(cases_DASH_val187476,"_match",L[889]);
var anf_obj2877423 = R.makeFunction(function(l21997424,mtype2007425,bind2017426) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[890],3,arguments);
}
var anf_arg2717475 = G(A113,"s-normal",L[899]);
var anf_arg2727474 = R.equiv(mtype2007425,anf_arg2717475);
var when_DASH_177452 = R.not(anf_arg2727474);
var if_helper2737438 = R.makeFunction(function(if_helper_arg2747457) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[892],1,arguments);
}
if_helper_arg2747457;
var anf_fun2757471 = G(A113,"s-dot",L[898]);
var anf_arg2767470 = G(self_DASH_id1947367,"id-e",L[897]);
var anf_bracket2777473 = G(bind2017426,"id",L[896]);
var anf_fun2787468 = G(anf_bracket2777473,"toname",L[895]);
var $z74607461 = D;
var $f74667467 = function(_) {
return R.isFunction(anf_fun2787468)?anf_fun2787468.app():R.ffi.throwNonFunApp(L[894],anf_fun2787468,[]);
};
try {
if(--R.GAS > 0) {
$z74607461 = $f74667467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74667467,
"from":L[894]});
}
} catch($e74587459) {
if(R.isCont($e74587459)) {
var $ss74627463 = {"from":L[894],
"go":function(anf_arg2797469) {
return $Hanf_arg15197472(anf_arg2797469,anf_arg2767470,anf_fun2757471,l21997424);
}};
$e74587459.stack[R.EXN_STACKHEIGHT++] = $ss74627463;
}
if(R.isPyretException($e74587459)) {
$e74587459.pyretStack.push(L[894]);
}
throw $e74587459;
}
var $ret74647465 = $Hanf_arg15197472($z74607461,anf_arg2767470,anf_fun2757471,l21997424);
++R.GAS;
return $ret74647465;
});
var anf_if2827456 = R.isBoolean(when_DASH_177452);
if(R.isPyretTrue(anf_if2827456)) {
if(R.isPyretTrue(when_DASH_177452)) {
var $z74297430 = D;
var $f74357436 = function(_) {
return R.isFunction(torepr11)?torepr11.app(f1987406):R.ffi.throwNonFunApp(L[891],torepr11,[f1987406]);
};
try {
if(--R.GAS > 0) {
$z74297430 = $f74357436();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74357436,
"from":L[891]});
}
} catch($e74277428) {
if(R.isCont($e74277428)) {
var $ss74317432 = {"from":L[891],
"go":function(anf_arg2847437) {
return $Hanf_arg15247439(anf_arg2847437,if_helper2737438,_plus7,nothing9,raise10);
}};
$e74277428.stack[R.EXN_STACKHEIGHT++] = $ss74317432;
}
if(R.isPyretException($e74277428)) {
$e74277428.pyretStack.push(L[891]);
}
throw $e74277428;
}
var $ret74337434 = $Hanf_arg15247439($z74297430,if_helper2737438,_plus7,nothing9,raise10);
++R.GAS;
return $ret74337434;
} else {
var $z74427443 = D;
var $f74487449 = function(_) {
return R.isFunction(if_helper2737438)?if_helper2737438.app(nothing9):R.ffi.throwNonFunApp(L[892],if_helper2737438,[nothing9]);
};
try {
if(--R.GAS > 0) {
$z74427443 = $f74487449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74487449,
"from":L[892]});
}
} catch($e74407441) {
if(R.isCont($e74407441)) {
var $ss74447445 = {"from":L[892],
"go":function(cont_tail_app2837450) {
return $Hcont_tail_app15257451(cont_tail_app2837450);
}};
$e74407441.stack[R.EXN_STACKHEIGHT++] = $ss74447445;
}
if(R.isPyretException($e74407441)) {
$e74407441.pyretStack.push(L[892]);
}
throw $e74407441;
}
var $ret74467447 = $Hcont_tail_app15257451($z74427443);
++R.GAS;
return $ret74467447;
}
} else {
var cont_tail_arg2807455 = R.throwNonBooleanCondition(L[893],("when"),when_DASH_177452);
if(--R.GAS > 0) {
$z74537454 = R.isFunction(if_helper2737438)?if_helper2737438.app(cont_tail_arg2807455):R.ffi.throwNonFunApp(L[893],if_helper2737438,[cont_tail_arg2807455]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper2737438)?if_helper2737438.app(cont_tail_arg2807455):R.ffi.throwNonFunApp(L[893],if_helper2737438,[cont_tail_arg2807455]);
},
"from":L[893]});
}
++R.GAS;
return $z74537454;
}
});
var anf_arg2887418 = R.makeObject({"s-variant-member":anf_obj2877423});
var anf_arg2907419 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[889],0,arguments);
}
var ann_DASH_check_DASH_temp2897422 = R.throwNoBranchesMatched(L[889],("cases"));
return ann_DASH_check_DASH_temp2897422;
});
var $z74097410 = D;
var $f74157416 = function(_) {
return R.isFunction(anf_fun2697417)?anf_fun2697417.app(anf_arg2887418,anf_arg2907419):R.ffi.throwNonFunApp(L[888],anf_fun2697417,[anf_arg2887418,anf_arg2907419]);
};
try {
if(--R.GAS > 0) {
$z74097410 = $f74157416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74157416,
"from":L[888]});
}
} catch($e74077408) {
if(R.isCont($e74077408)) {
var $ss74117412 = {"from":L[888],
"go":function(ann_DASH_check_DASH_temp2687420) {
return $Hann_DASH_check_DASH_temp15267421(ann_DASH_check_DASH_temp2687420);
}};
$e74077408.stack[R.EXN_STACKHEIGHT++] = $ss74117412;
}
if(R.isPyretException($e74077408)) {
$e74077408.pyretStack.push(L[888]);
}
throw $e74077408;
}
var $ret74137414 = $Hann_DASH_check_DASH_temp15267421($z74097410);
++R.GAS;
return $ret74137414;
});
var $z73957396 = D;
var $f74017402 = function(_) {
return R.isFunction(map3954)?map3954.app(anf_arg2917403,fields1921739):R.ffi.throwNonFunApp(L[887],map3954,[anf_arg2917403,fields1921739]);
};
try {
if(--R.GAS > 0) {
$z73957396 = $f74017402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74017402,
"from":L[887]});
}
} catch($e73937394) {
if(R.isCont($e73937394)) {
var $ss73977398 = {"from":L[887],
"go":function(args1977404) {
return $Hargs15437405(args1977404,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355,self_DASH_id1947367);
}};
$e73937394.stack[R.EXN_STACKHEIGHT++] = $ss73977398;
}
if(R.isPyretException($e73937394)) {
$e73937394.pyretStack.push(L[887]);
}
throw $e73937394;
}
var $ret73997400 = $Hargs15437405($z73957396,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355,self_DASH_id1947367);
++R.GAS;
return $ret73997400;
};
var $Hargs15437405 = function(args1977404,A113,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355,self_DASH_id1947367) {
var anf_fun2927489 = G(A113,"s-method",L[901]);
var anf_fun2937487 = G(list2753,"make",L[900]);
var $z74797480 = D;
var $f74857486 = function(_) {
return R.isFunction(anf_fun2937487)?anf_fun2937487.app([self_DASH_id1947367,cases_DASH_id1957379,else_DASH_id1967391]):R.ffi.throwNonFunApp(L[900],anf_fun2937487,[[self_DASH_id1947367,cases_DASH_id1957379,else_DASH_id1967391]]);
};
try {
if(--R.GAS > 0) {
$z74797480 = $f74857486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74857486,
"from":L[900]});
}
} catch($e74777478) {
if(R.isCont($e74777478)) {
var $ss74817482 = {"from":L[900],
"go":function(anf_bracket2947488) {
return $Hanf_bracket15427490(anf_bracket2947488,A113,anf_fun2927489,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e74777478.stack[R.EXN_STACKHEIGHT++] = $ss74817482;
}
if(R.isPyretException($e74777478)) {
$e74777478.pyretStack.push(L[900]);
}
throw $e74777478;
}
var $ret74837484 = $Hanf_bracket15427490($z74797480,A113,anf_fun2927489,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret74837484;
};
var $Hanf_bracket15427490 = function(anf_bracket2947488,A113,anf_fun2927489,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355) {
var anf_fun2957501 = G(anf_bracket2947488,"map",L[904]);
var anf_arg2977502 = R.makeFunction(function(recv_DASH_197505) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[903],1,arguments);
}
var ann_DASH_check_DASH_temp2967506 = G(recv_DASH_197505,"id-b",L[903]);
return ann_DASH_check_DASH_temp2967506;
});
var $z74937494 = D;
var $f74997500 = function(_) {
return R.isFunction(anf_fun2957501)?anf_fun2957501.app(anf_arg2977502):R.ffi.throwNonFunApp(L[902],anf_fun2957501,[anf_arg2977502]);
};
try {
if(--R.GAS > 0) {
$z74937494 = $f74997500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74997500,
"from":L[902]});
}
} catch($e74917492) {
if(R.isCont($e74917492)) {
var $ss74957496 = {"from":L[902],
"go":function(anf_arg2987503) {
return $Hanf_arg15417504(anf_arg2987503,A113,anf_fun2927489,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e74917492.stack[R.EXN_STACKHEIGHT++] = $ss74957496;
}
if(R.isPyretException($e74917492)) {
$e74917492.pyretStack.push(L[902]);
}
throw $e74917492;
}
var $ret74977498 = $Hanf_arg15417504($z74937494,A113,anf_fun2927489,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret74977498;
};
var $Hanf_arg15417504 = function(anf_arg2987503,A113,anf_fun2927489,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355) {
var anf_arg2997519 = G(A113,"a-blank",L[913]);
var anf_fun3007521 = G(A113,"s-if-else",L[912]);
var anf_fun3017522 = G(list2753,"make",L[911]);
var anf_fun3027523 = G(A113,"s-if-branch",L[910]);
var anf_fun3037524 = G(A113,"s-prim-app",L[909]);
var anf_fun3047525 = G(list2753,"make",L[908]);
var anf_array_val3057520 = G(cases_DASH_id1957379,"id-e",L[907]);
var anf_fun3067517 = G(A113,"s-str",L[906]);
var $z75097510 = D;
var $f75157516 = function(_) {
return R.isFunction(anf_fun3067517)?anf_fun3067517.app(l1901737,case_DASH_name1911738):R.ffi.throwNonFunApp(L[905],anf_fun3067517,[l1901737,case_DASH_name1911738]);
};
try {
if(--R.GAS > 0) {
$z75097510 = $f75157516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75157516,
"from":L[905]});
}
} catch($e75077508) {
if(R.isCont($e75077508)) {
var $ss75117512 = {"from":L[905],
"go":function(anf_array_val3077518) {
return $Hanf_array_val15407526(anf_array_val3077518,A113,anf_arg2987503,anf_arg2997519,anf_array_val3057520,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3037524,anf_fun3047525,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e75077508.stack[R.EXN_STACKHEIGHT++] = $ss75117512;
}
if(R.isPyretException($e75077508)) {
$e75077508.pyretStack.push(L[905]);
}
throw $e75077508;
}
var $ret75137514 = $Hanf_array_val15407526($z75097510,A113,anf_arg2987503,anf_arg2997519,anf_array_val3057520,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3037524,anf_fun3047525,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret75137514;
};
var $Hanf_array_val15407526 = function(anf_array_val3077518,A113,anf_arg2987503,anf_arg2997519,anf_array_val3057520,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3037524,anf_fun3047525,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355) {
var $z75297530 = D;
var $f75357536 = function(_) {
return R.isFunction(anf_fun3047525)?anf_fun3047525.app([anf_array_val3057520,anf_array_val3077518]):R.ffi.throwNonFunApp(L[908],anf_fun3047525,[[anf_array_val3057520,anf_array_val3077518]]);
};
try {
if(--R.GAS > 0) {
$z75297530 = $f75357536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75357536,
"from":L[908]});
}
} catch($e75277528) {
if(R.isCont($e75277528)) {
var $ss75317532 = {"from":L[908],
"go":function(anf_arg3087537) {
return $Hanf_arg15397538(anf_arg3087537,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3037524,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e75277528.stack[R.EXN_STACKHEIGHT++] = $ss75317532;
}
if(R.isPyretException($e75277528)) {
$e75277528.pyretStack.push(L[908]);
}
throw $e75277528;
}
var $ret75337534 = $Hanf_arg15397538($z75297530,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3037524,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret75337534;
};
var $Hanf_arg15397538 = function(anf_arg3087537,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3037524,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355) {
var $z75417542 = D;
var $f75477548 = function(_) {
return R.isFunction(anf_fun3037524)?anf_fun3037524.app(l1901737,("hasField"),anf_arg3087537):R.ffi.throwNonFunApp(L[914],anf_fun3037524,[l1901737,("hasField"),anf_arg3087537]);
};
try {
if(--R.GAS > 0) {
$z75417542 = $f75477548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75477548,
"from":L[914]});
}
} catch($e75397540) {
if(R.isCont($e75397540)) {
var $ss75437544 = {"from":L[914],
"go":function(anf_arg3097549) {
return $Hanf_arg15387550(anf_arg3097549,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e75397540.stack[R.EXN_STACKHEIGHT++] = $ss75437544;
}
if(R.isPyretException($e75397540)) {
$e75397540.pyretStack.push(L[914]);
}
throw $e75397540;
}
var $ret75457546 = $Hanf_arg15387550($z75417542,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret75457546;
};
var $Hanf_arg15387550 = function(anf_arg3097549,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,args1977404,call_DASH_match_DASH_case1937355,case_DASH_name1911738,cases_DASH_id1957379,else_DASH_id1967391,l1901737,list2753,none6355) {
var anf_fun3107565 = G(A113,"s-let-expr",L[921]);
var anf_fun3117566 = G(list2753,"make",L[920]);
var anf_fun3127567 = G(A113,"s-let-bind",L[919]);
var anf_arg3137564 = G(call_DASH_match_DASH_case1937355,"id-b",L[918]);
var anf_fun3147561 = G(A113,"s-dot",L[917]);
var anf_arg3157562 = G(cases_DASH_id1957379,"id-e",L[916]);
var $z75537554 = D;
var $f75597560 = function(_) {
return R.isFunction(anf_fun3147561)?anf_fun3147561.app(l1901737,anf_arg3157562,case_DASH_name1911738):R.ffi.throwNonFunApp(L[915],anf_fun3147561,[l1901737,anf_arg3157562,case_DASH_name1911738]);
};
try {
if(--R.GAS > 0) {
$z75537554 = $f75597560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75597560,
"from":L[915]});
}
} catch($e75517552) {
if(R.isCont($e75517552)) {
var $ss75557556 = {"from":L[915],
"go":function(anf_arg3167563) {
return $Hanf_arg15377568(anf_arg3167563,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_arg3137564,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,anf_fun3117566,anf_fun3127567,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e75517552.stack[R.EXN_STACKHEIGHT++] = $ss75557556;
}
if(R.isPyretException($e75517552)) {
$e75517552.pyretStack.push(L[915]);
}
throw $e75517552;
}
var $ret75577558 = $Hanf_arg15377568($z75537554,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_arg3137564,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,anf_fun3117566,anf_fun3127567,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret75577558;
};
var $Hanf_arg15377568 = function(anf_arg3167563,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_arg3137564,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,anf_fun3117566,anf_fun3127567,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355) {
var $z75717572 = D;
var $f75777578 = function(_) {
return R.isFunction(anf_fun3127567)?anf_fun3127567.app(l1901737,anf_arg3137564,anf_arg3167563):R.ffi.throwNonFunApp(L[922],anf_fun3127567,[l1901737,anf_arg3137564,anf_arg3167563]);
};
try {
if(--R.GAS > 0) {
$z75717572 = $f75777578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75777578,
"from":L[922]});
}
} catch($e75697570) {
if(R.isCont($e75697570)) {
var $ss75737574 = {"from":L[922],
"go":function(anf_array_val3177579) {
return $Hanf_array_val15367580(anf_array_val3177579,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,anf_fun3117566,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e75697570.stack[R.EXN_STACKHEIGHT++] = $ss75737574;
}
if(R.isPyretException($e75697570)) {
$e75697570.pyretStack.push(L[922]);
}
throw $e75697570;
}
var $ret75757576 = $Hanf_array_val15367580($z75717572,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,anf_fun3117566,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret75757576;
};
var $Hanf_array_val15367580 = function(anf_array_val3177579,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,anf_fun3117566,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355) {
var $z75837584 = D;
var $f75897590 = function(_) {
return R.isFunction(anf_fun3117566)?anf_fun3117566.app([anf_array_val3177579]):R.ffi.throwNonFunApp(L[920],anf_fun3117566,[[anf_array_val3177579]]);
};
try {
if(--R.GAS > 0) {
$z75837584 = $f75897590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75897590,
"from":L[920]});
}
} catch($e75817582) {
if(R.isCont($e75817582)) {
var $ss75857586 = {"from":L[920],
"go":function(anf_arg3187591) {
return $Hanf_arg15357592(anf_arg3187591,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e75817582.stack[R.EXN_STACKHEIGHT++] = $ss75857586;
}
if(R.isPyretException($e75817582)) {
$e75817582.pyretStack.push(L[920]);
}
throw $e75817582;
}
var $ret75877588 = $Hanf_arg15357592($z75837584,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret75877588;
};
var $Hanf_arg15357592 = function(anf_arg3187591,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,args1977404,call_DASH_match_DASH_case1937355,else_DASH_id1967391,l1901737,list2753,none6355) {
var anf_fun3197603 = G(A113,"s-app",L[925]);
var anf_arg3207604 = G(call_DASH_match_DASH_case1937355,"id-e",L[924]);
var $z75957596 = D;
var $f76017602 = function(_) {
return R.isFunction(anf_fun3197603)?anf_fun3197603.app(l1901737,anf_arg3207604,args1977404):R.ffi.throwNonFunApp(L[923],anf_fun3197603,[l1901737,anf_arg3207604,args1977404]);
};
try {
if(--R.GAS > 0) {
$z75957596 = $f76017602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76017602,
"from":L[923]});
}
} catch($e75937594) {
if(R.isCont($e75937594)) {
var $ss75977598 = {"from":L[923],
"go":function(anf_arg3217605) {
return $Hanf_arg15347606(anf_arg3217605,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_arg3187591,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e75937594.stack[R.EXN_STACKHEIGHT++] = $ss75977598;
}
if(R.isPyretException($e75937594)) {
$e75937594.pyretStack.push(L[923]);
}
throw $e75937594;
}
var $ret75997600 = $Hanf_arg15347606($z75957596,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_arg3187591,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret75997600;
};
var $Hanf_arg15347606 = function(anf_arg3217605,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_arg3187591,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,anf_fun3107565,else_DASH_id1967391,l1901737,list2753,none6355) {
var $z76097610 = D;
var $f76157616 = function(_) {
return R.isFunction(anf_fun3107565)?anf_fun3107565.app(l1901737,anf_arg3187591,anf_arg3217605):R.ffi.throwNonFunApp(L[926],anf_fun3107565,[l1901737,anf_arg3187591,anf_arg3217605]);
};
try {
if(--R.GAS > 0) {
$z76097610 = $f76157616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76157616,
"from":L[926]});
}
} catch($e76077608) {
if(R.isCont($e76077608)) {
var $ss76117612 = {"from":L[926],
"go":function(anf_arg3227617) {
return $Hanf_arg15337618(anf_arg3227617,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e76077608.stack[R.EXN_STACKHEIGHT++] = $ss76117612;
}
if(R.isPyretException($e76077608)) {
$e76077608.pyretStack.push(L[926]);
}
throw $e76077608;
}
var $ret76137614 = $Hanf_arg15337618($z76097610,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret76137614;
};
var $Hanf_arg15337618 = function(anf_arg3227617,A113,anf_arg2987503,anf_arg2997519,anf_arg3097549,anf_fun2927489,anf_fun3007521,anf_fun3017522,anf_fun3027523,else_DASH_id1967391,l1901737,list2753,none6355) {
var $z76217622 = D;
var $f76277628 = function(_) {
return R.isFunction(anf_fun3027523)?anf_fun3027523.app(l1901737,anf_arg3097549,anf_arg3227617):R.ffi.throwNonFunApp(L[927],anf_fun3027523,[l1901737,anf_arg3097549,anf_arg3227617]);
};
try {
if(--R.GAS > 0) {
$z76217622 = $f76277628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76277628,
"from":L[927]});
}
} catch($e76197620) {
if(R.isCont($e76197620)) {
var $ss76237624 = {"from":L[927],
"go":function(anf_array_val3237629) {
return $Hanf_array_val15327630(anf_array_val3237629,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e76197620.stack[R.EXN_STACKHEIGHT++] = $ss76237624;
}
if(R.isPyretException($e76197620)) {
$e76197620.pyretStack.push(L[927]);
}
throw $e76197620;
}
var $ret76257626 = $Hanf_array_val15327630($z76217622,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret76257626;
};
var $Hanf_array_val15327630 = function(anf_array_val3237629,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,anf_fun3017522,else_DASH_id1967391,l1901737,list2753,none6355) {
var $z76337634 = D;
var $f76397640 = function(_) {
return R.isFunction(anf_fun3017522)?anf_fun3017522.app([anf_array_val3237629]):R.ffi.throwNonFunApp(L[911],anf_fun3017522,[[anf_array_val3237629]]);
};
try {
if(--R.GAS > 0) {
$z76337634 = $f76397640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76397640,
"from":L[911]});
}
} catch($e76317632) {
if(R.isCont($e76317632)) {
var $ss76357636 = {"from":L[911],
"go":function(anf_arg3247641) {
return $Hanf_arg15317642(anf_arg3247641,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,else_DASH_id1967391,l1901737,list2753,none6355);
}};
$e76317632.stack[R.EXN_STACKHEIGHT++] = $ss76357636;
}
if(R.isPyretException($e76317632)) {
$e76317632.pyretStack.push(L[911]);
}
throw $e76317632;
}
var $ret76377638 = $Hanf_arg15317642($z76337634,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,else_DASH_id1967391,l1901737,list2753,none6355);
++R.GAS;
return $ret76377638;
};
var $Hanf_arg15317642 = function(anf_arg3247641,A113,anf_arg2987503,anf_arg2997519,anf_fun2927489,anf_fun3007521,else_DASH_id1967391,l1901737,list2753,none6355) {
var anf_fun3257656 = G(A113,"s-app",L[930]);
var anf_arg3267655 = G(else_DASH_id1967391,"id-e",L[929]);
var anf_fun3277653 = G(list2753,"make",L[928]);
var $z76457646 = D;
var $f76517652 = function(_) {
return R.isFunction(anf_fun3277653)?anf_fun3277653.app([]):R.ffi.throwNonFunApp(L[928],anf_fun3277653,[[]]);
};
try {
if(--R.GAS > 0) {
$z76457646 = $f76517652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76517652,
"from":L[928]});
}
} catch($e76437644) {
if(R.isCont($e76437644)) {
var $ss76477648 = {"from":L[928],
"go":function(anf_arg3287654) {
return $Hanf_arg15307657(anf_arg3287654,anf_arg2987503,anf_arg2997519,anf_arg3247641,anf_arg3267655,anf_fun2927489,anf_fun3007521,anf_fun3257656,l1901737,none6355);
}};
$e76437644.stack[R.EXN_STACKHEIGHT++] = $ss76477648;
}
if(R.isPyretException($e76437644)) {
$e76437644.pyretStack.push(L[928]);
}
throw $e76437644;
}
var $ret76497650 = $Hanf_arg15307657($z76457646,anf_arg2987503,anf_arg2997519,anf_arg3247641,anf_arg3267655,anf_fun2927489,anf_fun3007521,anf_fun3257656,l1901737,none6355);
++R.GAS;
return $ret76497650;
};
var $Hanf_arg15307657 = function(anf_arg3287654,anf_arg2987503,anf_arg2997519,anf_arg3247641,anf_arg3267655,anf_fun2927489,anf_fun3007521,anf_fun3257656,l1901737,none6355) {
var $z76607661 = D;
var $f76667667 = function(_) {
return R.isFunction(anf_fun3257656)?anf_fun3257656.app(l1901737,anf_arg3267655,anf_arg3287654):R.ffi.throwNonFunApp(L[931],anf_fun3257656,[l1901737,anf_arg3267655,anf_arg3287654]);
};
try {
if(--R.GAS > 0) {
$z76607661 = $f76667667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76667667,
"from":L[931]});
}
} catch($e76587659) {
if(R.isCont($e76587659)) {
var $ss76627663 = {"from":L[931],
"go":function(anf_arg3297668) {
return $Hanf_arg15297669(anf_arg3297668,anf_arg2987503,anf_arg2997519,anf_arg3247641,anf_fun2927489,anf_fun3007521,l1901737,none6355);
}};
$e76587659.stack[R.EXN_STACKHEIGHT++] = $ss76627663;
}
if(R.isPyretException($e76587659)) {
$e76587659.pyretStack.push(L[931]);
}
throw $e76587659;
}
var $ret76647665 = $Hanf_arg15297669($z76607661,anf_arg2987503,anf_arg2997519,anf_arg3247641,anf_fun2927489,anf_fun3007521,l1901737,none6355);
++R.GAS;
return $ret76647665;
};
var $Hanf_arg15297669 = function(anf_arg3297668,anf_arg2987503,anf_arg2997519,anf_arg3247641,anf_fun2927489,anf_fun3007521,l1901737,none6355) {
var $z76727673 = D;
var $f76787679 = function(_) {
return R.isFunction(anf_fun3007521)?anf_fun3007521.app(l1901737,anf_arg3247641,anf_arg3297668):R.ffi.throwNonFunApp(L[932],anf_fun3007521,[l1901737,anf_arg3247641,anf_arg3297668]);
};
try {
if(--R.GAS > 0) {
$z76727673 = $f76787679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76787679,
"from":L[932]});
}
} catch($e76707671) {
if(R.isCont($e76707671)) {
var $ss76747675 = {"from":L[932],
"go":function(anf_arg3307680) {
return $Hanf_arg15287681(anf_arg3307680,anf_arg2987503,anf_arg2997519,anf_fun2927489,l1901737,none6355);
}};
$e76707671.stack[R.EXN_STACKHEIGHT++] = $ss76747675;
}
if(R.isPyretException($e76707671)) {
$e76707671.pyretStack.push(L[932]);
}
throw $e76707671;
}
var $ret76767677 = $Hanf_arg15287681($z76727673,anf_arg2987503,anf_arg2997519,anf_fun2927489,l1901737,none6355);
++R.GAS;
return $ret76767677;
};
var $Hanf_arg15287681 = function(anf_arg3307680,anf_arg2987503,anf_arg2997519,anf_fun2927489,l1901737,none6355) {
var $z76847685 = D;
var $f76907691 = function(_) {
return R.isFunction(anf_fun2927489)?anf_fun2927489.app(l1901737,anf_arg2987503,anf_arg2997519,(""),anf_arg3307680,none6355):R.ffi.throwNonFunApp(L[234],anf_fun2927489,[l1901737,anf_arg2987503,anf_arg2997519,(""),anf_arg3307680,none6355]);
};
try {
if(--R.GAS > 0) {
$z76847685 = $f76907691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76907691,
"from":L[234]});
}
} catch($e76827683) {
if(R.isCont($e76827683)) {
var $ss76867687 = {"from":L[234],
"go":function(ann_DASH_check_DASH_temp2667692) {
return $Hann_DASH_check_DASH_temp15277693(ann_DASH_check_DASH_temp2667692);
}};
$e76827683.stack[R.EXN_STACKHEIGHT++] = $ss76867687;
}
if(R.isPyretException($e76827683)) {
$e76827683.pyretStack.push(L[234]);
}
throw $e76827683;
}
var $ret76887689 = $Hann_DASH_check_DASH_temp15277693($z76847685);
++R.GAS;
return $ret76887689;
};
var $Hann_DASH_check_DASH_temp15277693 = function(ann_DASH_check_DASH_temp2667692) {
return ann_DASH_check_DASH_temp2667692;
};
var $Hann_DASH_check_DASH_temp15267421 = function(ann_DASH_check_DASH_temp2687420) {
return ann_DASH_check_DASH_temp2687420;
};
var $Hanf_arg15247439 = function(anf_arg2847437,if_helper2737438,_plus7,nothing9,raise10) {
var $z76967697 = D;
var $f77027703 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Non-normal member in variant, NYI: "),anf_arg2847437):R.ffi.throwNonFunApp(L[933],_plus7,[("Non-normal member in variant, NYI: "),anf_arg2847437]);
};
try {
if(--R.GAS > 0) {
$z76967697 = $f77027703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77027703,
"from":L[933]});
}
} catch($e76947695) {
if(R.isCont($e76947695)) {
var $ss76987699 = {"from":L[933],
"go":function(anf_arg2857704) {
return $Hanf_arg15237705(anf_arg2857704,if_helper2737438,nothing9,raise10);
}};
$e76947695.stack[R.EXN_STACKHEIGHT++] = $ss76987699;
}
if(R.isPyretException($e76947695)) {
$e76947695.pyretStack.push(L[933]);
}
throw $e76947695;
}
var $ret77007701 = $Hanf_arg15237705($z76967697,if_helper2737438,nothing9,raise10);
++R.GAS;
return $ret77007701;
};
var $Hanf_arg15237705 = function(anf_arg2857704,if_helper2737438,nothing9,raise10) {
var $z77087709 = D;
var $f77147715 = function(_) {
return R.isFunction(raise10)?raise10.app(anf_arg2857704):R.ffi.throwNonFunApp(L[934],raise10,[anf_arg2857704]);
};
try {
if(--R.GAS > 0) {
$z77087709 = $f77147715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77147715,
"from":L[934]});
}
} catch($e77067707) {
if(R.isCont($e77067707)) {
var $ss77107711 = {"from":L[934],
"go":function(anf_begin_app_dropped15207716) {
return $Hanf_begin_app_dropped15227717(anf_begin_app_dropped15207716,if_helper2737438,nothing9);
}};
$e77067707.stack[R.EXN_STACKHEIGHT++] = $ss77107711;
}
if(R.isPyretException($e77067707)) {
$e77067707.pyretStack.push(L[934]);
}
throw $e77067707;
}
var $ret77127713 = $Hanf_begin_app_dropped15227717($z77087709,if_helper2737438,nothing9);
++R.GAS;
return $ret77127713;
};
var $Hanf_begin_app_dropped15227717 = function(anf_begin_app_dropped15207716,if_helper2737438,nothing9) {
var $z77207721 = D;
var $f77267727 = function(_) {
return R.isFunction(if_helper2737438)?if_helper2737438.app(nothing9):R.ffi.throwNonFunApp(L[892],if_helper2737438,[nothing9]);
};
try {
if(--R.GAS > 0) {
$z77207721 = $f77267727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77267727,
"from":L[892]});
}
} catch($e77187719) {
if(R.isCont($e77187719)) {
var $ss77227723 = {"from":L[892],
"go":function(cont_tail_app2867728) {
return $Hcont_tail_app15217729(cont_tail_app2867728);
}};
$e77187719.stack[R.EXN_STACKHEIGHT++] = $ss77227723;
}
if(R.isPyretException($e77187719)) {
$e77187719.pyretStack.push(L[892]);
}
throw $e77187719;
}
var $ret77247725 = $Hcont_tail_app15217729($z77207721);
++R.GAS;
return $ret77247725;
};
var $Hcont_tail_app15217729 = function(cont_tail_app2867728) {
return cont_tail_app2867728;
};
var $Hcont_tail_app15257451 = function(cont_tail_app2837450) {
return cont_tail_app2837450;
};
var $Hanf_arg15197472 = function(anf_arg2797469,anf_arg2767470,anf_fun2757471,l21997424) {
var $z77327733 = D;
var $f77387739 = function(_) {
return R.isFunction(anf_fun2757471)?anf_fun2757471.app(l21997424,anf_arg2767470,anf_arg2797469):R.ffi.throwNonFunApp(L[890],anf_fun2757471,[l21997424,anf_arg2767470,anf_arg2797469]);
};
try {
if(--R.GAS > 0) {
$z77327733 = $f77387739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77387739,
"from":L[890]});
}
} catch($e77307731) {
if(R.isCont($e77307731)) {
var $ss77347735 = {"from":L[890],
"go":function(ann_DASH_check_DASH_temp2707740) {
return $Hann_DASH_check_DASH_temp15187741(ann_DASH_check_DASH_temp2707740);
}};
$e77307731.stack[R.EXN_STACKHEIGHT++] = $ss77347735;
}
if(R.isPyretException($e77307731)) {
$e77307731.pyretStack.push(L[890]);
}
throw $e77307731;
}
var $ret77367737 = $Hann_DASH_check_DASH_temp15187741($z77327733);
++R.GAS;
return $ret77367737;
};
var $Hann_DASH_check_DASH_temp15187741 = function(ann_DASH_check_DASH_temp2707740) {
return ann_DASH_check_DASH_temp2707740;
};
var $Hself15171767 = function(self1771766,A113,fields1751754,gid90256,is_DASH_singleton1761755,l1731752,list2753,none6355,vname1741753) {
var str1787742 = {"$var":D,
"$name":"str"};
var call_DASH_torepr1797744 = {"$var":D,
"$name":"call-torepr"};
var concat1807746 = {"$var":D,
"$name":"concat"};
var anf_assign2077743 = R.makeFunction(function(s1817838) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[948],1,arguments);
}
var anf_fun2067849 = G(A113,"s-str",L[949]);
var $z78417842 = D;
var $f78477848 = function(_) {
return R.isFunction(anf_fun2067849)?anf_fun2067849.app(l1731752,s1817838):R.ffi.throwNonFunApp(L[948],anf_fun2067849,[l1731752,s1817838]);
};
try {
if(--R.GAS > 0) {
$z78417842 = $f78477848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78477848,
"from":L[948]});
}
} catch($e78397840) {
if(R.isCont($e78397840)) {
var $ss78437844 = {"from":L[948],
"go":function(ann_DASH_check_DASH_temp2057850) {
return $Hann_DASH_check_DASH_temp14917851(ann_DASH_check_DASH_temp2057850);
}};
$e78397840.stack[R.EXN_STACKHEIGHT++] = $ss78437844;
}
if(R.isPyretException($e78397840)) {
$e78397840.pyretStack.push(L[948]);
}
throw $e78397840;
}
var $ret78457846 = $Hann_DASH_check_DASH_temp14917851($z78417842);
++R.GAS;
return $ret78457846;
});
str1787742.$var = anf_assign2077743;
var anf_assign2207745 = R.makeFunction(function(val1827824) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[945],1,arguments);
}
var anf_fun2097836 = G(A113,"s-app",L[947]);
var $z78277828 = D;
var $f78337834 = function(_) {
return R.isFunction(gid90256.$var)?gid90256.$var.app(l1731752,("torepr")):R.ffi.throwNonFunApp(L[946],gid90256.$var,[l1731752,("torepr")]);
};
try {
if(--R.GAS > 0) {
$z78277828 = $f78337834();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78337834,
"from":L[946]});
}
} catch($e78257826) {
if(R.isCont($e78257826)) {
var $ss78297830 = {"from":L[946],
"go":function(anf_arg2107835) {
return $Hanf_arg14967837(anf_arg2107835,A113,anf_fun2097836,l1731752,list2753,self1771766,val1827824);
}};
$e78257826.stack[R.EXN_STACKHEIGHT++] = $ss78297830;
}
if(R.isPyretException($e78257826)) {
$e78257826.pyretStack.push(L[946]);
}
throw $e78257826;
}
var $ret78317832 = $Hanf_arg14967837($z78277828,A113,anf_fun2097836,l1731752,list2753,self1771766,val1827824);
++R.GAS;
return $ret78317832;
});
call_DASH_torepr1797744.$var = anf_assign2207745;
var anf_assign2237747 = R.makeFunction(function(v11837809,v21847810) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[943],2,arguments);
}
var anf_fun2227821 = G(A113,"s-op",L[944]);
var $z78137814 = D;
var $f78197820 = function(_) {
return R.isFunction(anf_fun2227821)?anf_fun2227821.app(l1731752,("op+"),v11837809,v21847810):R.ffi.throwNonFunApp(L[943],anf_fun2227821,[l1731752,("op+"),v11837809,v21847810]);
};
try {
if(--R.GAS > 0) {
$z78137814 = $f78197820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78197820,
"from":L[943]});
}
} catch($e78117812) {
if(R.isCont($e78117812)) {
var $ss78157816 = {"from":L[943],
"go":function(ann_DASH_check_DASH_temp2217822) {
return $Hann_DASH_check_DASH_temp14977823(ann_DASH_check_DASH_temp2217822);
}};
$e78117812.stack[R.EXN_STACKHEIGHT++] = $ss78157816;
}
if(R.isPyretException($e78117812)) {
$e78117812.pyretStack.push(L[943]);
}
throw $e78117812;
}
var $ret78177818 = $Hann_DASH_check_DASH_temp14977823($z78137814);
++R.GAS;
return $ret78177818;
});
concat1807746.$var = anf_assign2237747;
var cases_DASH_val157808 = fields1751754;
var anf_fun2247758 = G(cases_DASH_val157808,"_match",L[936]);
var anf_obj2267764 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[942],0,arguments);
}
var $z77987799 = D;
var $f78047805 = function(_) {
return R.isFunction(str1787742.$var)?str1787742.$var.app(("")):R.ffi.throwNonFunApp(L[942],str1787742.$var,[("")]);
};
try {
if(--R.GAS > 0) {
$z77987799 = $f78047805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78047805,
"from":L[942]});
}
} catch($e77967797) {
if(R.isCont($e77967797)) {
var $ss78007801 = {"from":L[942],
"go":function(ann_DASH_check_DASH_temp2257806) {
return $Hann_DASH_check_DASH_temp14987807(ann_DASH_check_DASH_temp2257806);
}};
$e77967797.stack[R.EXN_STACKHEIGHT++] = $ss78007801;
}
if(R.isPyretException($e77967797)) {
$e77967797.pyretStack.push(L[942]);
}
throw $e77967797;
}
var $ret78027803 = $Hann_DASH_check_DASH_temp14987807($z77987799);
++R.GAS;
return $ret78027803;
});
var anf_obj2357765 = R.makeFunction(function(f1867766,r1877767) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[937],2,arguments);
}
var anf_fun2287780 = G(r1877767,"foldl",L[941]);
var anf_arg2337779 = R.makeFunction(function(val1887782,acc1897783) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[939],2,arguments);
}
var $z77867787 = D;
var $f77927793 = function(_) {
return R.isFunction(str1787742.$var)?str1787742.$var.app((", ")):R.ffi.throwNonFunApp(L[940],str1787742.$var,[(", ")]);
};
try {
if(--R.GAS > 0) {
$z77867787 = $f77927793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77927793,
"from":L[940]});
}
} catch($e77847785) {
if(R.isCont($e77847785)) {
var $ss77887789 = {"from":L[940],
"go":function(anf_arg2307794) {
return $Hanf_arg15027795(anf_arg2307794,acc1897783,call_DASH_torepr1797744,concat1807746,val1887782);
}};
$e77847785.stack[R.EXN_STACKHEIGHT++] = $ss77887789;
}
if(R.isPyretException($e77847785)) {
$e77847785.pyretStack.push(L[940]);
}
throw $e77847785;
}
var $ret77907791 = $Hanf_arg15027795($z77867787,acc1897783,call_DASH_torepr1797744,concat1807746,val1887782);
++R.GAS;
return $ret77907791;
});
var $z77707771 = D;
var $f77767777 = function(_) {
return R.isFunction(call_DASH_torepr1797744.$var)?call_DASH_torepr1797744.$var.app(f1867766):R.ffi.throwNonFunApp(L[938],call_DASH_torepr1797744.$var,[f1867766]);
};
try {
if(--R.GAS > 0) {
$z77707771 = $f77767777();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77767777,
"from":L[938]});
}
} catch($e77687769) {
if(R.isCont($e77687769)) {
var $ss77727773 = {"from":L[938],
"go":function(anf_arg2347778) {
return $Hanf_arg15047781(anf_arg2347778,anf_arg2337779,anf_fun2287780);
}};
$e77687769.stack[R.EXN_STACKHEIGHT++] = $ss77727773;
}
if(R.isPyretException($e77687769)) {
$e77687769.pyretStack.push(L[938]);
}
throw $e77687769;
}
var $ret77747775 = $Hanf_arg15047781($z77707771,anf_arg2337779,anf_fun2287780);
++R.GAS;
return $ret77747775;
});
var anf_arg2367759 = R.makeObject({"empty":anf_obj2267764,
"link":anf_obj2357765});
var anf_arg2387760 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[936],0,arguments);
}
var ann_DASH_check_DASH_temp2377763 = R.throwNoBranchesMatched(L[936],("cases"));
return ann_DASH_check_DASH_temp2377763;
});
var $z77507751 = D;
var $f77567757 = function(_) {
return R.isFunction(anf_fun2247758)?anf_fun2247758.app(anf_arg2367759,anf_arg2387760):R.ffi.throwNonFunApp(L[935],anf_fun2247758,[anf_arg2367759,anf_arg2387760]);
};
try {
if(--R.GAS > 0) {
$z77507751 = $f77567757();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77567757,
"from":L[935]});
}
} catch($e77487749) {
if(R.isCont($e77487749)) {
var $ss77527753 = {"from":L[935],
"go":function(argstrs1857761) {
return $Hargstrs15167762(argstrs1857761,A113,concat1807746,is_DASH_singleton1761755,l1731752,list2753,none6355,self1771766,str1787742,vname1741753);
}};
$e77487749.stack[R.EXN_STACKHEIGHT++] = $ss77527753;
}
if(R.isPyretException($e77487749)) {
$e77487749.pyretStack.push(L[935]);
}
throw $e77487749;
}
var $ret77547755 = $Hargstrs15167762($z77507751,A113,concat1807746,is_DASH_singleton1761755,l1731752,list2753,none6355,self1771766,str1787742,vname1741753);
++R.GAS;
return $ret77547755;
};
var $Hargstrs15167762 = function(argstrs1857761,A113,concat1807746,is_DASH_singleton1761755,l1731752,list2753,none6355,self1771766,str1787742,vname1741753) {
var if_DASH_167883 = is_DASH_singleton1761755;
var if_helper2397866 = R.makeFunction(function(if_helper_arg2407888) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[956],1,arguments);
}
var ann_DASH_check_DASH_temp2047889 = if_helper_arg2407888;
return ann_DASH_check_DASH_temp2047889;
});
var anf_if2437887 = R.isBoolean(if_DASH_167883);
if(R.isPyretTrue(anf_if2437887)) {
if(R.isPyretTrue(if_DASH_167883)) {
var anf_fun2577865 = G(A113,"s-method",L[952]);
var anf_fun2587862 = G(list2753,"make",L[950]);
var anf_array_val2597863 = G(self1771766,"id-b",L[951]);
var $z78547855 = D;
var $f78607861 = function(_) {
return R.isFunction(anf_fun2587862)?anf_fun2587862.app([anf_array_val2597863]):R.ffi.throwNonFunApp(L[950],anf_fun2587862,[[anf_array_val2597863]]);
};
try {
if(--R.GAS > 0) {
$z78547855 = $f78607861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78607861,
"from":L[950]});
}
} catch($e78527853) {
if(R.isCont($e78527853)) {
var $ss78567857 = {"from":L[950],
"go":function(anf_arg2607864) {
return $Hanf_arg15077867(anf_arg2607864,A113,anf_fun2577865,if_helper2397866,l1731752,none6355,str1787742,vname1741753);
}};
$e78527853.stack[R.EXN_STACKHEIGHT++] = $ss78567857;
}
if(R.isPyretException($e78527853)) {
$e78527853.pyretStack.push(L[950]);
}
throw $e78527853;
}
var $ret78587859 = $Hanf_arg15077867($z78547855,A113,anf_fun2577865,if_helper2397866,l1731752,none6355,str1787742,vname1741753);
++R.GAS;
return $ret78587859;
} else {
var anf_fun2447881 = G(A113,"s-method",L[955]);
var anf_fun2457878 = G(list2753,"make",L[953]);
var anf_array_val2467879 = G(self1771766,"id-b",L[954]);
var $z78707871 = D;
var $f78767877 = function(_) {
return R.isFunction(anf_fun2457878)?anf_fun2457878.app([anf_array_val2467879]):R.ffi.throwNonFunApp(L[953],anf_fun2457878,[[anf_array_val2467879]]);
};
try {
if(--R.GAS > 0) {
$z78707871 = $f78767877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78767877,
"from":L[953]});
}
} catch($e78687869) {
if(R.isCont($e78687869)) {
var $ss78727873 = {"from":L[953],
"go":function(anf_arg2477880) {
return $Hanf_arg15157882(anf_arg2477880,A113,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742,vname1741753);
}};
$e78687869.stack[R.EXN_STACKHEIGHT++] = $ss78727873;
}
if(R.isPyretException($e78687869)) {
$e78687869.pyretStack.push(L[953]);
}
throw $e78687869;
}
var $ret78747875 = $Hanf_arg15157882($z78707871,A113,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742,vname1741753);
++R.GAS;
return $ret78747875;
}
} else {
var cont_tail_arg2417886 = R.throwNonBooleanCondition(L[956],("if"),if_DASH_167883);
if(--R.GAS > 0) {
$z78847885 = R.isFunction(if_helper2397866)?if_helper2397866.app(cont_tail_arg2417886):R.ffi.throwNonFunApp(L[956],if_helper2397866,[cont_tail_arg2417886]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper2397866)?if_helper2397866.app(cont_tail_arg2417886):R.ffi.throwNonFunApp(L[956],if_helper2397866,[cont_tail_arg2417886]);
},
"from":L[956]});
}
++R.GAS;
return $z78847885;
}
};
var $Hanf_arg15077867 = function(anf_arg2607864,A113,anf_fun2577865,if_helper2397866,l1731752,none6355,str1787742,vname1741753) {
var anf_arg2617901 = G(A113,"a-blank",L[958]);
var $z78927893 = D;
var $f78987899 = function(_) {
return R.isFunction(str1787742.$var)?str1787742.$var.app(vname1741753):R.ffi.throwNonFunApp(L[957],str1787742.$var,[vname1741753]);
};
try {
if(--R.GAS > 0) {
$z78927893 = $f78987899();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78987899,
"from":L[957]});
}
} catch($e78907891) {
if(R.isCont($e78907891)) {
var $ss78947895 = {"from":L[957],
"go":function(anf_arg2627900) {
return $Hanf_arg15067902(anf_arg2627900,anf_arg2607864,anf_arg2617901,anf_fun2577865,if_helper2397866,l1731752,none6355);
}};
$e78907891.stack[R.EXN_STACKHEIGHT++] = $ss78947895;
}
if(R.isPyretException($e78907891)) {
$e78907891.pyretStack.push(L[957]);
}
throw $e78907891;
}
var $ret78967897 = $Hanf_arg15067902($z78927893,anf_arg2607864,anf_arg2617901,anf_fun2577865,if_helper2397866,l1731752,none6355);
++R.GAS;
return $ret78967897;
};
var $Hanf_arg15067902 = function(anf_arg2627900,anf_arg2607864,anf_arg2617901,anf_fun2577865,if_helper2397866,l1731752,none6355) {
var $z79057906 = D;
var $f79117912 = function(_) {
return R.isFunction(anf_fun2577865)?anf_fun2577865.app(l1731752,anf_arg2607864,anf_arg2617901,(""),anf_arg2627900,none6355):R.ffi.throwNonFunApp(L[959],anf_fun2577865,[l1731752,anf_arg2607864,anf_arg2617901,(""),anf_arg2627900,none6355]);
};
try {
if(--R.GAS > 0) {
$z79057906 = $f79117912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79117912,
"from":L[959]});
}
} catch($e79037904) {
if(R.isCont($e79037904)) {
var $ss79077908 = {"from":L[959],
"go":function(cont_tail_arg2637913) {
return $Hcont_tail_arg15057914(cont_tail_arg2637913,if_helper2397866);
}};
$e79037904.stack[R.EXN_STACKHEIGHT++] = $ss79077908;
}
if(R.isPyretException($e79037904)) {
$e79037904.pyretStack.push(L[959]);
}
throw $e79037904;
}
var $ret79097910 = $Hcont_tail_arg15057914($z79057906,if_helper2397866);
++R.GAS;
return $ret79097910;
};
var $Hcont_tail_arg15057914 = function(cont_tail_arg2637913,if_helper2397866) {
if(--R.GAS > 0) {
$z79157916 = R.isFunction(if_helper2397866)?if_helper2397866.app(cont_tail_arg2637913):R.ffi.throwNonFunApp(L[959],if_helper2397866,[cont_tail_arg2637913]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper2397866)?if_helper2397866.app(cont_tail_arg2637913):R.ffi.throwNonFunApp(L[959],if_helper2397866,[cont_tail_arg2637913]);
},
"from":L[959]});
}
++R.GAS;
return $z79157916;
};
var $Hanf_arg15157882 = function(anf_arg2477880,A113,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742,vname1741753) {
var anf_arg2487928 = G(A113,"a-blank",L[961]);
var $z79197920 = D;
var $f79257926 = function(_) {
return R.isFunction(str1787742.$var)?str1787742.$var.app(vname1741753):R.ffi.throwNonFunApp(L[960],str1787742.$var,[vname1741753]);
};
try {
if(--R.GAS > 0) {
$z79197920 = $f79257926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79257926,
"from":L[960]});
}
} catch($e79177918) {
if(R.isCont($e79177918)) {
var $ss79217922 = {"from":L[960],
"go":function(anf_arg2497927) {
return $Hanf_arg15147929(anf_arg2497927,anf_arg2477880,anf_arg2487928,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742);
}};
$e79177918.stack[R.EXN_STACKHEIGHT++] = $ss79217922;
}
if(R.isPyretException($e79177918)) {
$e79177918.pyretStack.push(L[960]);
}
throw $e79177918;
}
var $ret79237924 = $Hanf_arg15147929($z79197920,anf_arg2477880,anf_arg2487928,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742);
++R.GAS;
return $ret79237924;
};
var $Hanf_arg15147929 = function(anf_arg2497927,anf_arg2477880,anf_arg2487928,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742) {
var $z79327933 = D;
var $f79387939 = function(_) {
return R.isFunction(str1787742.$var)?str1787742.$var.app(("(")):R.ffi.throwNonFunApp(L[962],str1787742.$var,[("(")]);
};
try {
if(--R.GAS > 0) {
$z79327933 = $f79387939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79387939,
"from":L[962]});
}
} catch($e79307931) {
if(R.isCont($e79307931)) {
var $ss79347935 = {"from":L[962],
"go":function(anf_arg2507940) {
return $Hanf_arg15137941(anf_arg2507940,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742);
}};
$e79307931.stack[R.EXN_STACKHEIGHT++] = $ss79347935;
}
if(R.isPyretException($e79307931)) {
$e79307931.pyretStack.push(L[962]);
}
throw $e79307931;
}
var $ret79367937 = $Hanf_arg15137941($z79327933,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742);
++R.GAS;
return $ret79367937;
};
var $Hanf_arg15137941 = function(anf_arg2507940,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355,str1787742) {
var $z79447945 = D;
var $f79507951 = function(_) {
return R.isFunction(str1787742.$var)?str1787742.$var.app((")")):R.ffi.throwNonFunApp(L[963],str1787742.$var,[(")")]);
};
try {
if(--R.GAS > 0) {
$z79447945 = $f79507951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79507951,
"from":L[963]});
}
} catch($e79427943) {
if(R.isCont($e79427943)) {
var $ss79467947 = {"from":L[963],
"go":function(anf_arg2517952) {
return $Hanf_arg15127953(anf_arg2517952,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_arg2507940,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355);
}};
$e79427943.stack[R.EXN_STACKHEIGHT++] = $ss79467947;
}
if(R.isPyretException($e79427943)) {
$e79427943.pyretStack.push(L[963]);
}
throw $e79427943;
}
var $ret79487949 = $Hanf_arg15127953($z79447945,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_arg2507940,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355);
++R.GAS;
return $ret79487949;
};
var $Hanf_arg15127953 = function(anf_arg2517952,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_arg2507940,anf_fun2447881,argstrs1857761,concat1807746,if_helper2397866,l1731752,none6355) {
var $z79567957 = D;
var $f79627963 = function(_) {
return R.isFunction(concat1807746.$var)?concat1807746.$var.app(argstrs1857761,anf_arg2517952):R.ffi.throwNonFunApp(L[964],concat1807746.$var,[argstrs1857761,anf_arg2517952]);
};
try {
if(--R.GAS > 0) {
$z79567957 = $f79627963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79627963,
"from":L[964]});
}
} catch($e79547955) {
if(R.isCont($e79547955)) {
var $ss79587959 = {"from":L[964],
"go":function(anf_arg2527964) {
return $Hanf_arg15117965(anf_arg2527964,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_arg2507940,anf_fun2447881,concat1807746,if_helper2397866,l1731752,none6355);
}};
$e79547955.stack[R.EXN_STACKHEIGHT++] = $ss79587959;
}
if(R.isPyretException($e79547955)) {
$e79547955.pyretStack.push(L[964]);
}
throw $e79547955;
}
var $ret79607961 = $Hanf_arg15117965($z79567957,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_arg2507940,anf_fun2447881,concat1807746,if_helper2397866,l1731752,none6355);
++R.GAS;
return $ret79607961;
};
var $Hanf_arg15117965 = function(anf_arg2527964,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_arg2507940,anf_fun2447881,concat1807746,if_helper2397866,l1731752,none6355) {
var $z79687969 = D;
var $f79747975 = function(_) {
return R.isFunction(concat1807746.$var)?concat1807746.$var.app(anf_arg2507940,anf_arg2527964):R.ffi.throwNonFunApp(L[965],concat1807746.$var,[anf_arg2507940,anf_arg2527964]);
};
try {
if(--R.GAS > 0) {
$z79687969 = $f79747975();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79747975,
"from":L[965]});
}
} catch($e79667967) {
if(R.isCont($e79667967)) {
var $ss79707971 = {"from":L[965],
"go":function(anf_arg2537976) {
return $Hanf_arg15107977(anf_arg2537976,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_fun2447881,concat1807746,if_helper2397866,l1731752,none6355);
}};
$e79667967.stack[R.EXN_STACKHEIGHT++] = $ss79707971;
}
if(R.isPyretException($e79667967)) {
$e79667967.pyretStack.push(L[965]);
}
throw $e79667967;
}
var $ret79727973 = $Hanf_arg15107977($z79687969,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_fun2447881,concat1807746,if_helper2397866,l1731752,none6355);
++R.GAS;
return $ret79727973;
};
var $Hanf_arg15107977 = function(anf_arg2537976,anf_arg2477880,anf_arg2487928,anf_arg2497927,anf_fun2447881,concat1807746,if_helper2397866,l1731752,none6355) {
var $z79807981 = D;
var $f79867987 = function(_) {
return R.isFunction(concat1807746.$var)?concat1807746.$var.app(anf_arg2497927,anf_arg2537976):R.ffi.throwNonFunApp(L[966],concat1807746.$var,[anf_arg2497927,anf_arg2537976]);
};
try {
if(--R.GAS > 0) {
$z79807981 = $f79867987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79867987,
"from":L[966]});
}
} catch($e79787979) {
if(R.isCont($e79787979)) {
var $ss79827983 = {"from":L[966],
"go":function(anf_arg2547988) {
return $Hanf_arg15097989(anf_arg2547988,anf_arg2477880,anf_arg2487928,anf_fun2447881,if_helper2397866,l1731752,none6355);
}};
$e79787979.stack[R.EXN_STACKHEIGHT++] = $ss79827983;
}
if(R.isPyretException($e79787979)) {
$e79787979.pyretStack.push(L[966]);
}
throw $e79787979;
}
var $ret79847985 = $Hanf_arg15097989($z79807981,anf_arg2477880,anf_arg2487928,anf_fun2447881,if_helper2397866,l1731752,none6355);
++R.GAS;
return $ret79847985;
};
var $Hanf_arg15097989 = function(anf_arg2547988,anf_arg2477880,anf_arg2487928,anf_fun2447881,if_helper2397866,l1731752,none6355) {
var $z79927993 = D;
var $f79987999 = function(_) {
return R.isFunction(anf_fun2447881)?anf_fun2447881.app(l1731752,anf_arg2477880,anf_arg2487928,(""),anf_arg2547988,none6355):R.ffi.throwNonFunApp(L[967],anf_fun2447881,[l1731752,anf_arg2477880,anf_arg2487928,(""),anf_arg2547988,none6355]);
};
try {
if(--R.GAS > 0) {
$z79927993 = $f79987999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79987999,
"from":L[967]});
}
} catch($e79907991) {
if(R.isCont($e79907991)) {
var $ss79947995 = {"from":L[967],
"go":function(cont_tail_arg2558000) {
return $Hcont_tail_arg15088001(cont_tail_arg2558000,if_helper2397866);
}};
$e79907991.stack[R.EXN_STACKHEIGHT++] = $ss79947995;
}
if(R.isPyretException($e79907991)) {
$e79907991.pyretStack.push(L[967]);
}
throw $e79907991;
}
var $ret79967997 = $Hcont_tail_arg15088001($z79927993,if_helper2397866);
++R.GAS;
return $ret79967997;
};
var $Hcont_tail_arg15088001 = function(cont_tail_arg2558000,if_helper2397866) {
if(--R.GAS > 0) {
$z80028003 = R.isFunction(if_helper2397866)?if_helper2397866.app(cont_tail_arg2558000):R.ffi.throwNonFunApp(L[967],if_helper2397866,[cont_tail_arg2558000]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper2397866)?if_helper2397866.app(cont_tail_arg2558000):R.ffi.throwNonFunApp(L[967],if_helper2397866,[cont_tail_arg2558000]);
},
"from":L[967]});
}
++R.GAS;
return $z80028003;
};
var $Hanf_arg15047781 = function(anf_arg2347778,anf_arg2337779,anf_fun2287780) {
var $z80068007 = D;
var $f80128013 = function(_) {
return R.isFunction(anf_fun2287780)?anf_fun2287780.app(anf_arg2337779,anf_arg2347778):R.ffi.throwNonFunApp(L[937],anf_fun2287780,[anf_arg2337779,anf_arg2347778]);
};
try {
if(--R.GAS > 0) {
$z80068007 = $f80128013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80128013,
"from":L[937]});
}
} catch($e80048005) {
if(R.isCont($e80048005)) {
var $ss80088009 = {"from":L[937],
"go":function(ann_DASH_check_DASH_temp2278014) {
return $Hann_DASH_check_DASH_temp15038015(ann_DASH_check_DASH_temp2278014);
}};
$e80048005.stack[R.EXN_STACKHEIGHT++] = $ss80088009;
}
if(R.isPyretException($e80048005)) {
$e80048005.pyretStack.push(L[937]);
}
throw $e80048005;
}
var $ret80108011 = $Hann_DASH_check_DASH_temp15038015($z80068007);
++R.GAS;
return $ret80108011;
};
var $Hann_DASH_check_DASH_temp15038015 = function(ann_DASH_check_DASH_temp2278014) {
return ann_DASH_check_DASH_temp2278014;
};
var $Hanf_arg15027795 = function(anf_arg2307794,acc1897783,call_DASH_torepr1797744,concat1807746,val1887782) {
var $z80188019 = D;
var $f80248025 = function(_) {
return R.isFunction(call_DASH_torepr1797744.$var)?call_DASH_torepr1797744.$var.app(val1887782):R.ffi.throwNonFunApp(L[968],call_DASH_torepr1797744.$var,[val1887782]);
};
try {
if(--R.GAS > 0) {
$z80188019 = $f80248025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80248025,
"from":L[968]});
}
} catch($e80168017) {
if(R.isCont($e80168017)) {
var $ss80208021 = {"from":L[968],
"go":function(anf_arg2318026) {
return $Hanf_arg15018027(anf_arg2318026,acc1897783,anf_arg2307794,concat1807746);
}};
$e80168017.stack[R.EXN_STACKHEIGHT++] = $ss80208021;
}
if(R.isPyretException($e80168017)) {
$e80168017.pyretStack.push(L[968]);
}
throw $e80168017;
}
var $ret80228023 = $Hanf_arg15018027($z80188019,acc1897783,anf_arg2307794,concat1807746);
++R.GAS;
return $ret80228023;
};
var $Hanf_arg15018027 = function(anf_arg2318026,acc1897783,anf_arg2307794,concat1807746) {
var $z80308031 = D;
var $f80368037 = function(_) {
return R.isFunction(concat1807746.$var)?concat1807746.$var.app(anf_arg2307794,anf_arg2318026):R.ffi.throwNonFunApp(L[969],concat1807746.$var,[anf_arg2307794,anf_arg2318026]);
};
try {
if(--R.GAS > 0) {
$z80308031 = $f80368037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80368037,
"from":L[969]});
}
} catch($e80288029) {
if(R.isCont($e80288029)) {
var $ss80328033 = {"from":L[969],
"go":function(anf_arg2328038) {
return $Hanf_arg15008039(anf_arg2328038,acc1897783,concat1807746);
}};
$e80288029.stack[R.EXN_STACKHEIGHT++] = $ss80328033;
}
if(R.isPyretException($e80288029)) {
$e80288029.pyretStack.push(L[969]);
}
throw $e80288029;
}
var $ret80348035 = $Hanf_arg15008039($z80308031,acc1897783,concat1807746);
++R.GAS;
return $ret80348035;
};
var $Hanf_arg15008039 = function(anf_arg2328038,acc1897783,concat1807746) {
var $z80428043 = D;
var $f80488049 = function(_) {
return R.isFunction(concat1807746.$var)?concat1807746.$var.app(acc1897783,anf_arg2328038):R.ffi.throwNonFunApp(L[939],concat1807746.$var,[acc1897783,anf_arg2328038]);
};
try {
if(--R.GAS > 0) {
$z80428043 = $f80488049();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80488049,
"from":L[939]});
}
} catch($e80408041) {
if(R.isCont($e80408041)) {
var $ss80448045 = {"from":L[939],
"go":function(ann_DASH_check_DASH_temp2298050) {
return $Hann_DASH_check_DASH_temp14998051(ann_DASH_check_DASH_temp2298050);
}};
$e80408041.stack[R.EXN_STACKHEIGHT++] = $ss80448045;
}
if(R.isPyretException($e80408041)) {
$e80408041.pyretStack.push(L[939]);
}
throw $e80408041;
}
var $ret80468047 = $Hann_DASH_check_DASH_temp14998051($z80428043);
++R.GAS;
return $ret80468047;
};
var $Hann_DASH_check_DASH_temp14998051 = function(ann_DASH_check_DASH_temp2298050) {
return ann_DASH_check_DASH_temp2298050;
};
var $Hann_DASH_check_DASH_temp14987807 = function(ann_DASH_check_DASH_temp2257806) {
return ann_DASH_check_DASH_temp2257806;
};
var $Hann_DASH_check_DASH_temp14977823 = function(ann_DASH_check_DASH_temp2217822) {
return ann_DASH_check_DASH_temp2217822;
};
var $Hanf_arg14967837 = function(anf_arg2107835,A113,anf_fun2097836,l1731752,list2753,self1771766,val1827824) {
var anf_fun2118065 = G(list2753,"make",L[976]);
var anf_fun2128066 = G(A113,"s-dot",L[975]);
var anf_arg2138064 = G(self1771766,"id-e",L[974]);
var anf_bracket2148069 = G(val1827824,"bind",L[973]);
var anf_bracket2158068 = G(anf_bracket2148069,"id",L[972]);
var anf_fun2168062 = G(anf_bracket2158068,"toname",L[971]);
var $z80548055 = D;
var $f80608061 = function(_) {
return R.isFunction(anf_fun2168062)?anf_fun2168062.app():R.ffi.throwNonFunApp(L[970],anf_fun2168062,[]);
};
try {
if(--R.GAS > 0) {
$z80548055 = $f80608061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80608061,
"from":L[970]});
}
} catch($e80528053) {
if(R.isCont($e80528053)) {
var $ss80568057 = {"from":L[970],
"go":function(anf_arg2178063) {
return $Hanf_arg14958067(anf_arg2178063,anf_arg2107835,anf_arg2138064,anf_fun2097836,anf_fun2118065,anf_fun2128066,l1731752);
}};
$e80528053.stack[R.EXN_STACKHEIGHT++] = $ss80568057;
}
if(R.isPyretException($e80528053)) {
$e80528053.pyretStack.push(L[970]);
}
throw $e80528053;
}
var $ret80588059 = $Hanf_arg14958067($z80548055,anf_arg2107835,anf_arg2138064,anf_fun2097836,anf_fun2118065,anf_fun2128066,l1731752);
++R.GAS;
return $ret80588059;
};
var $Hanf_arg14958067 = function(anf_arg2178063,anf_arg2107835,anf_arg2138064,anf_fun2097836,anf_fun2118065,anf_fun2128066,l1731752) {
var $z80728073 = D;
var $f80788079 = function(_) {
return R.isFunction(anf_fun2128066)?anf_fun2128066.app(l1731752,anf_arg2138064,anf_arg2178063):R.ffi.throwNonFunApp(L[977],anf_fun2128066,[l1731752,anf_arg2138064,anf_arg2178063]);
};
try {
if(--R.GAS > 0) {
$z80728073 = $f80788079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80788079,
"from":L[977]});
}
} catch($e80708071) {
if(R.isCont($e80708071)) {
var $ss80748075 = {"from":L[977],
"go":function(anf_array_val2188080) {
return $Hanf_array_val14948081(anf_array_val2188080,anf_arg2107835,anf_fun2097836,anf_fun2118065,l1731752);
}};
$e80708071.stack[R.EXN_STACKHEIGHT++] = $ss80748075;
}
if(R.isPyretException($e80708071)) {
$e80708071.pyretStack.push(L[977]);
}
throw $e80708071;
}
var $ret80768077 = $Hanf_array_val14948081($z80728073,anf_arg2107835,anf_fun2097836,anf_fun2118065,l1731752);
++R.GAS;
return $ret80768077;
};
var $Hanf_array_val14948081 = function(anf_array_val2188080,anf_arg2107835,anf_fun2097836,anf_fun2118065,l1731752) {
var $z80848085 = D;
var $f80908091 = function(_) {
return R.isFunction(anf_fun2118065)?anf_fun2118065.app([anf_array_val2188080]):R.ffi.throwNonFunApp(L[976],anf_fun2118065,[[anf_array_val2188080]]);
};
try {
if(--R.GAS > 0) {
$z80848085 = $f80908091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80908091,
"from":L[976]});
}
} catch($e80828083) {
if(R.isCont($e80828083)) {
var $ss80868087 = {"from":L[976],
"go":function(anf_arg2198092) {
return $Hanf_arg14938093(anf_arg2198092,anf_arg2107835,anf_fun2097836,l1731752);
}};
$e80828083.stack[R.EXN_STACKHEIGHT++] = $ss80868087;
}
if(R.isPyretException($e80828083)) {
$e80828083.pyretStack.push(L[976]);
}
throw $e80828083;
}
var $ret80888089 = $Hanf_arg14938093($z80848085,anf_arg2107835,anf_fun2097836,l1731752);
++R.GAS;
return $ret80888089;
};
var $Hanf_arg14938093 = function(anf_arg2198092,anf_arg2107835,anf_fun2097836,l1731752) {
var $z80968097 = D;
var $f81028103 = function(_) {
return R.isFunction(anf_fun2097836)?anf_fun2097836.app(l1731752,anf_arg2107835,anf_arg2198092):R.ffi.throwNonFunApp(L[945],anf_fun2097836,[l1731752,anf_arg2107835,anf_arg2198092]);
};
try {
if(--R.GAS > 0) {
$z80968097 = $f81028103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81028103,
"from":L[945]});
}
} catch($e80948095) {
if(R.isCont($e80948095)) {
var $ss80988099 = {"from":L[945],
"go":function(ann_DASH_check_DASH_temp2088104) {
return $Hann_DASH_check_DASH_temp14928105(ann_DASH_check_DASH_temp2088104);
}};
$e80948095.stack[R.EXN_STACKHEIGHT++] = $ss80988099;
}
if(R.isPyretException($e80948095)) {
$e80948095.pyretStack.push(L[945]);
}
throw $e80948095;
}
var $ret81008101 = $Hann_DASH_check_DASH_temp14928105($z80968097);
++R.GAS;
return $ret81008101;
};
var $Hann_DASH_check_DASH_temp14928105 = function(ann_DASH_check_DASH_temp2088104) {
return ann_DASH_check_DASH_temp2088104;
};
var $Hann_DASH_check_DASH_temp14917851 = function(ann_DASH_check_DASH_temp2057850) {
return ann_DASH_check_DASH_temp2057850;
};
var $Ha14901782 = function(a1721781,A113,loc1701768,mk_DASH_bind100276) {
var $z81088109 = D;
var $f81148115 = function(_) {
return R.isFunction(mk_DASH_bind100276.$var)?mk_DASH_bind100276.$var.app(loc1701768,a1721781):R.ffi.throwNonFunApp(L[978],mk_DASH_bind100276.$var,[loc1701768,a1721781]);
};
try {
if(--R.GAS > 0) {
$z81088109 = $f81148115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81148115,
"from":L[978]});
}
} catch($e81068107) {
if(R.isCont($e81068107)) {
var $ss81108111 = {"from":L[978],
"go":function(anf_obj2008116) {
return $Hanf_obj14898117(anf_obj2008116,A113,a1721781,loc1701768);
}};
$e81068107.stack[R.EXN_STACKHEIGHT++] = $ss81108111;
}
if(R.isPyretException($e81068107)) {
$e81068107.pyretStack.push(L[978]);
}
throw $e81068107;
}
var $ret81128113 = $Hanf_obj14898117($z81088109,A113,a1721781,loc1701768);
++R.GAS;
return $ret81128113;
};
var $Hanf_obj14898117 = function(anf_obj2008116,A113,a1721781,loc1701768) {
var anf_fun2018128 = G(A113,"s-id",L[980]);
var $z81208121 = D;
var $f81268127 = function(_) {
return R.isFunction(anf_fun2018128)?anf_fun2018128.app(loc1701768,a1721781):R.ffi.throwNonFunApp(L[979],anf_fun2018128,[loc1701768,a1721781]);
};
try {
if(--R.GAS > 0) {
$z81208121 = $f81268127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81268127,
"from":L[979]});
}
} catch($e81188119) {
if(R.isCont($e81188119)) {
var $ss81228123 = {"from":L[979],
"go":function(anf_obj2028129) {
return $Hanf_obj14888130(anf_obj2028129,a1721781,anf_obj2008116);
}};
$e81188119.stack[R.EXN_STACKHEIGHT++] = $ss81228123;
}
if(R.isPyretException($e81188119)) {
$e81188119.pyretStack.push(L[979]);
}
throw $e81188119;
}
var $ret81248125 = $Hanf_obj14888130($z81208121,a1721781,anf_obj2008116);
++R.GAS;
return $ret81248125;
};
var $Hanf_obj14888130 = function(anf_obj2028129,a1721781,anf_obj2008116) {
var ann_DASH_check_DASH_temp1988131 = R.makeObject({"id":a1721781,
"id-b":anf_obj2008116,
"id-e":anf_obj2028129});
return ann_DASH_check_DASH_temp1988131;
};
var $Hann_DASH_check_DASH_temp14871798 = function(ann_DASH_check_DASH_temp1941797) {
return ann_DASH_check_DASH_temp1941797;
};
var $Hann_DASH_check_DASH_temp14861815 = function(ann_DASH_check_DASH_temp1821814) {
return ann_DASH_check_DASH_temp1821814;
};
var $Hanf_arg14851827 = function(anf_arg1901826,_plus7,raise10) {
var $z81348135 = D;
var $f81408141 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("Attempt to desugar non-program: "),anf_arg1901826):R.ffi.throwNonFunApp(L[981],_plus7,[("Attempt to desugar non-program: "),anf_arg1901826]);
};
try {
if(--R.GAS > 0) {
$z81348135 = $f81408141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81408141,
"from":L[981]});
}
} catch($e81328133) {
if(R.isCont($e81328133)) {
var $ss81368137 = {"from":L[981],
"go":function(anf_arg1918142) {
return $Hanf_arg14848143(anf_arg1918142,raise10);
}};
$e81328133.stack[R.EXN_STACKHEIGHT++] = $ss81368137;
}
if(R.isPyretException($e81328133)) {
$e81328133.pyretStack.push(L[981]);
}
throw $e81328133;
}
var $ret81388139 = $Hanf_arg14848143($z81348135,raise10);
++R.GAS;
return $ret81388139;
};
var $Hanf_arg14848143 = function(anf_arg1918142,raise10) {
var $z81468147 = D;
var $f81528153 = function(_) {
return R.isFunction(raise10)?raise10.app(anf_arg1918142):R.ffi.throwNonFunApp(L[245],raise10,[anf_arg1918142]);
};
try {
if(--R.GAS > 0) {
$z81468147 = $f81528153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81528153,
"from":L[245]});
}
} catch($e81448145) {
if(R.isCont($e81448145)) {
var $ss81488149 = {"from":L[245],
"go":function(ann_DASH_check_DASH_temp1898154) {
return $Hann_DASH_check_DASH_temp14838155(ann_DASH_check_DASH_temp1898154);
}};
$e81448145.stack[R.EXN_STACKHEIGHT++] = $ss81488149;
}
if(R.isPyretException($e81448145)) {
$e81448145.pyretStack.push(L[245]);
}
throw $e81448145;
}
var $ret81508151 = $Hann_DASH_check_DASH_temp14838155($z81468147);
++R.GAS;
return $ret81508151;
};
var $Hann_DASH_check_DASH_temp14838155 = function(ann_DASH_check_DASH_temp1898154) {
return ann_DASH_check_DASH_temp1898154;
};
var $Hanf_arg14821846 = function(anf_arg1861844,_provide1641830,anf_fun1851845,imports1661832,l1631829,provided_DASH_types1651831) {
var $z81588159 = D;
var $f81648165 = function(_) {
return R.isFunction(anf_fun1851845)?anf_fun1851845.app(l1631829,_provide1641830,provided_DASH_types1651831,imports1661832,anf_arg1861844):R.ffi.throwNonFunApp(L[247],anf_fun1851845,[l1631829,_provide1641830,provided_DASH_types1651831,imports1661832,anf_arg1861844]);
};
try {
if(--R.GAS > 0) {
$z81588159 = $f81648165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81648165,
"from":L[247]});
}
} catch($e81568157) {
if(R.isCont($e81568157)) {
var $ss81608161 = {"from":L[247],
"go":function(ann_DASH_check_DASH_temp1848166) {
return $Hann_DASH_check_DASH_temp14818167(ann_DASH_check_DASH_temp1848166);
}};
$e81568157.stack[R.EXN_STACKHEIGHT++] = $ss81608161;
}
if(R.isPyretException($e81568157)) {
$e81568157.pyretStack.push(L[247]);
}
throw $e81568157;
}
var $ret81628163 = $Hann_DASH_check_DASH_temp14818167($z81588159);
++R.GAS;
return $ret81628163;
};
var $Hann_DASH_check_DASH_temp14818167 = function(ann_DASH_check_DASH_temp1848166) {
return ann_DASH_check_DASH_temp1848166;
};
var $Hann_DASH_check_DASH_temp14801863 = function(ann_DASH_check_DASH_temp1401862,A222) {
return ann_DASH_check_DASH_temp1401862;
};
var $Hanf_arg14791889 = function(anf_arg1751887,anf_fun1741888,desugar_DASH_expr117310,exp1601876,l1581874) {
var $z81708171 = D;
var $f81768177 = function(_) {
return R.isFunction(desugar_DASH_expr117310.$var === D?U(L[982],"desugar-expr"):desugar_DASH_expr117310.$var)?desugar_DASH_expr117310.$var === D?U(L[982],"desugar-expr"):desugar_DASH_expr117310.$var.app(exp1601876):R.ffi.throwNonFunApp(L[983],desugar_DASH_expr117310.$var === D?U(L[982],"desugar-expr"):desugar_DASH_expr117310.$var,[exp1601876]);
};
try {
if(--R.GAS > 0) {
$z81708171 = $f81768177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81768177,
"from":L[983]});
}
} catch($e81688169) {
if(R.isCont($e81688169)) {
var $ss81728173 = {"from":L[983],
"go":function(anf_arg1768178) {
return $Hanf_arg14788179(anf_arg1768178,anf_arg1751887,anf_fun1741888,l1581874);
}};
$e81688169.stack[R.EXN_STACKHEIGHT++] = $ss81728173;
}
if(R.isPyretException($e81688169)) {
$e81688169.pyretStack.push(L[983]);
}
throw $e81688169;
}
var $ret81748175 = $Hanf_arg14788179($z81708171,anf_arg1751887,anf_fun1741888,l1581874);
++R.GAS;
return $ret81748175;
};
var $Hanf_arg14788179 = function(anf_arg1768178,anf_arg1751887,anf_fun1741888,l1581874) {
var $z81828183 = D;
var $f81888189 = function(_) {
return R.isFunction(anf_fun1741888)?anf_fun1741888.app(l1581874,anf_arg1751887,anf_arg1768178):R.ffi.throwNonFunApp(L[255],anf_fun1741888,[l1581874,anf_arg1751887,anf_arg1768178]);
};
try {
if(--R.GAS > 0) {
$z81828183 = $f81888189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81888189,
"from":L[255]});
}
} catch($e81808181) {
if(R.isCont($e81808181)) {
var $ss81848185 = {"from":L[255],
"go":function(ann_DASH_check_DASH_temp1738190) {
return $Hann_DASH_check_DASH_temp14778191(ann_DASH_check_DASH_temp1738190);
}};
$e81808181.stack[R.EXN_STACKHEIGHT++] = $ss81848185;
}
if(R.isPyretException($e81808181)) {
$e81808181.pyretStack.push(L[255]);
}
throw $e81808181;
}
var $ret81868187 = $Hann_DASH_check_DASH_temp14778191($z81828183);
++R.GAS;
return $ret81868187;
};
var $Hann_DASH_check_DASH_temp14778191 = function(ann_DASH_check_DASH_temp1738190) {
return ann_DASH_check_DASH_temp1738190;
};
var $Hanf_arg14761905 = function(anf_arg1711903,anf_fun1691904,l1561890) {
var $z81948195 = D;
var $f82008201 = function(_) {
return R.isFunction(anf_fun1691904)?anf_fun1691904.app(l1561890,anf_arg1711903):R.ffi.throwNonFunApp(L[258],anf_fun1691904,[l1561890,anf_arg1711903]);
};
try {
if(--R.GAS > 0) {
$z81948195 = $f82008201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82008201,
"from":L[258]});
}
} catch($e81928193) {
if(R.isCont($e81928193)) {
var $ss81968197 = {"from":L[258],
"go":function(ann_DASH_check_DASH_temp1688202) {
return $Hann_DASH_check_DASH_temp14758203(ann_DASH_check_DASH_temp1688202);
}};
$e81928193.stack[R.EXN_STACKHEIGHT++] = $ss81968197;
}
if(R.isPyretException($e81928193)) {
$e81928193.pyretStack.push(L[258]);
}
throw $e81928193;
}
var $ret81988199 = $Hann_DASH_check_DASH_temp14758203($z81948195);
++R.GAS;
return $ret81988199;
};
var $Hann_DASH_check_DASH_temp14758203 = function(ann_DASH_check_DASH_temp1688202) {
return ann_DASH_check_DASH_temp1688202;
};
var $Hanf_arg14741921 = function(anf_arg1641919,anf_fun1631920,args1551908,desugar_DASH_ann98272,l1531906) {
var anf_fun1658214 = G(args1551908,"map",L[985]);
var $z82068207 = D;
var $f82128213 = function(_) {
return R.isFunction(anf_fun1658214)?anf_fun1658214.app(desugar_DASH_ann98272.$var):R.ffi.throwNonFunApp(L[984],anf_fun1658214,[desugar_DASH_ann98272.$var]);
};
try {
if(--R.GAS > 0) {
$z82068207 = $f82128213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82128213,
"from":L[984]});
}
} catch($e82048205) {
if(R.isCont($e82048205)) {
var $ss82088209 = {"from":L[984],
"go":function(anf_arg1668215) {
return $Hanf_arg14738216(anf_arg1668215,anf_arg1641919,anf_fun1631920,l1531906);
}};
$e82048205.stack[R.EXN_STACKHEIGHT++] = $ss82088209;
}
if(R.isPyretException($e82048205)) {
$e82048205.pyretStack.push(L[984]);
}
throw $e82048205;
}
var $ret82108211 = $Hanf_arg14738216($z82068207,anf_arg1641919,anf_fun1631920,l1531906);
++R.GAS;
return $ret82108211;
};
var $Hanf_arg14738216 = function(anf_arg1668215,anf_arg1641919,anf_fun1631920,l1531906) {
var $z82198220 = D;
var $f82258226 = function(_) {
return R.isFunction(anf_fun1631920)?anf_fun1631920.app(l1531906,anf_arg1641919,anf_arg1668215):R.ffi.throwNonFunApp(L[262],anf_fun1631920,[l1531906,anf_arg1641919,anf_arg1668215]);
};
try {
if(--R.GAS > 0) {
$z82198220 = $f82258226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82258226,
"from":L[262]});
}
} catch($e82178218) {
if(R.isCont($e82178218)) {
var $ss82218222 = {"from":L[262],
"go":function(ann_DASH_check_DASH_temp1628227) {
return $Hann_DASH_check_DASH_temp14728228(ann_DASH_check_DASH_temp1628227);
}};
$e82178218.stack[R.EXN_STACKHEIGHT++] = $ss82218222;
}
if(R.isPyretException($e82178218)) {
$e82178218.pyretStack.push(L[262]);
}
throw $e82178218;
}
var $ret82238224 = $Hann_DASH_check_DASH_temp14728228($z82198220);
++R.GAS;
return $ret82238224;
};
var $Hann_DASH_check_DASH_temp14728228 = function(ann_DASH_check_DASH_temp1628227) {
return ann_DASH_check_DASH_temp1628227;
};
var $Hanf_arg14711938 = function(anf_arg1591936,anf_fun1571937,desugar_DASH_ann98272,l1501922,ret1521924) {
var $z82318232 = D;
var $f82378238 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ret1521924):R.ffi.throwNonFunApp(L[986],desugar_DASH_ann98272.$var,[ret1521924]);
};
try {
if(--R.GAS > 0) {
$z82318232 = $f82378238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82378238,
"from":L[986]});
}
} catch($e82298230) {
if(R.isCont($e82298230)) {
var $ss82338234 = {"from":L[986],
"go":function(anf_arg1608239) {
return $Hanf_arg14708240(anf_arg1608239,anf_arg1591936,anf_fun1571937,l1501922);
}};
$e82298230.stack[R.EXN_STACKHEIGHT++] = $ss82338234;
}
if(R.isPyretException($e82298230)) {
$e82298230.pyretStack.push(L[986]);
}
throw $e82298230;
}
var $ret82358236 = $Hanf_arg14708240($z82318232,anf_arg1591936,anf_fun1571937,l1501922);
++R.GAS;
return $ret82358236;
};
var $Hanf_arg14708240 = function(anf_arg1608239,anf_arg1591936,anf_fun1571937,l1501922) {
var $z82438244 = D;
var $f82498250 = function(_) {
return R.isFunction(anf_fun1571937)?anf_fun1571937.app(l1501922,anf_arg1591936,anf_arg1608239,(true)):R.ffi.throwNonFunApp(L[265],anf_fun1571937,[l1501922,anf_arg1591936,anf_arg1608239,(true)]);
};
try {
if(--R.GAS > 0) {
$z82438244 = $f82498250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82498250,
"from":L[265]});
}
} catch($e82418242) {
if(R.isCont($e82418242)) {
var $ss82458246 = {"from":L[265],
"go":function(ann_DASH_check_DASH_temp1568251) {
return $Hann_DASH_check_DASH_temp14698252(ann_DASH_check_DASH_temp1568251);
}};
$e82418242.stack[R.EXN_STACKHEIGHT++] = $ss82458246;
}
if(R.isPyretException($e82418242)) {
$e82418242.pyretStack.push(L[265]);
}
throw $e82418242;
}
var $ret82478248 = $Hann_DASH_check_DASH_temp14698252($z82438244);
++R.GAS;
return $ret82478248;
};
var $Hann_DASH_check_DASH_temp14698252 = function(ann_DASH_check_DASH_temp1568251) {
return ann_DASH_check_DASH_temp1568251;
};
var $Hanf_arg14681956 = function(anf_arg1531954,anf_fun1511955,desugar_DASH_ann98272,l1461939,ret1481941,use_DASH_parens1491942) {
var $z82558256 = D;
var $f82618262 = function(_) {
return R.isFunction(desugar_DASH_ann98272.$var)?desugar_DASH_ann98272.$var.app(ret1481941):R.ffi.throwNonFunApp(L[987],desugar_DASH_ann98272.$var,[ret1481941]);
};
try {
if(--R.GAS > 0) {
$z82558256 = $f82618262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82618262,
"from":L[987]});
}
} catch($e82538254) {
if(R.isCont($e82538254)) {
var $ss82578258 = {"from":L[987],
"go":function(anf_arg1548263) {
return $Hanf_arg14678264(anf_arg1548263,anf_arg1531954,anf_fun1511955,l1461939,use_DASH_parens1491942);
}};
$e82538254.stack[R.EXN_STACKHEIGHT++] = $ss82578258;
}
if(R.isPyretException($e82538254)) {
$e82538254.pyretStack.push(L[987]);
}
throw $e82538254;
}
var $ret82598260 = $Hanf_arg14678264($z82558256,anf_arg1531954,anf_fun1511955,l1461939,use_DASH_parens1491942);
++R.GAS;
return $ret82598260;
};
var $Hanf_arg14678264 = function(anf_arg1548263,anf_arg1531954,anf_fun1511955,l1461939,use_DASH_parens1491942) {
var $z82678268 = D;
var $f82738274 = function(_) {
return R.isFunction(anf_fun1511955)?anf_fun1511955.app(l1461939,anf_arg1531954,anf_arg1548263,use_DASH_parens1491942):R.ffi.throwNonFunApp(L[269],anf_fun1511955,[l1461939,anf_arg1531954,anf_arg1548263,use_DASH_parens1491942]);
};
try {
if(--R.GAS > 0) {
$z82678268 = $f82738274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82738274,
"from":L[269]});
}
} catch($e82658266) {
if(R.isCont($e82658266)) {
var $ss82698270 = {"from":L[269],
"go":function(ann_DASH_check_DASH_temp1508275) {
return $Hann_DASH_check_DASH_temp14668276(ann_DASH_check_DASH_temp1508275);
}};
$e82658266.stack[R.EXN_STACKHEIGHT++] = $ss82698270;
}
if(R.isPyretException($e82658266)) {
$e82658266.pyretStack.push(L[269]);
}
throw $e82658266;
}
var $ret82718272 = $Hann_DASH_check_DASH_temp14668276($z82678268);
++R.GAS;
return $ret82718272;
};
var $Hann_DASH_check_DASH_temp14668276 = function(ann_DASH_check_DASH_temp1508275) {
return ann_DASH_check_DASH_temp1508275;
};
var $Hanf_arg14651983 = function(anf_arg1381979,A222,anf_arg1351980,anf_arg1361981,anf_fun1341982) {
var $z82798280 = D;
var $f82858286 = function(_) {
return R.isFunction(anf_fun1341982)?anf_fun1341982.app(anf_arg1351980,anf_arg1361981,anf_arg1381979):R.ffi.throwNonFunApp(L[278],anf_fun1341982,[anf_arg1351980,anf_arg1361981,anf_arg1381979]);
};
try {
if(--R.GAS > 0) {
$z82798280 = $f82858286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82858286,
"from":L[278]});
}
} catch($e82778278) {
if(R.isCont($e82778278)) {
var $ss82818282 = {"from":L[278],
"go":function(ann_DASH_check_DASH_temp1338287) {
return $Hann_DASH_check_DASH_temp14648288(ann_DASH_check_DASH_temp1338287,A222);
}};
$e82778278.stack[R.EXN_STACKHEIGHT++] = $ss82818282;
}
if(R.isPyretException($e82778278)) {
$e82778278.pyretStack.push(L[278]);
}
throw $e82778278;
}
var $ret82838284 = $Hann_DASH_check_DASH_temp14648288($z82798280,A222);
++R.GAS;
return $ret82838284;
};
var $Hann_DASH_check_DASH_temp14648288 = function(ann_DASH_check_DASH_temp1338287,A222) {
return ann_DASH_check_DASH_temp1338287;
};
var $Hanf_array_val14632002 = function(anf_array_val1261999,A113,anf_fun1232000,anf_fun1242001,l1351984,position1361985,typ1371986,val1381987) {
var anf_fun1278299 = G(A113,"s-str",L[989]);
var $z82918292 = D;
var $f82978298 = function(_) {
return R.isFunction(anf_fun1278299)?anf_fun1278299.app(l1351984,position1361985):R.ffi.throwNonFunApp(L[988],anf_fun1278299,[l1351984,position1361985]);
};
try {
if(--R.GAS > 0) {
$z82918292 = $f82978298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82978298,
"from":L[988]});
}
} catch($e82898290) {
if(R.isCont($e82898290)) {
var $ss82938294 = {"from":L[988],
"go":function(anf_array_val1288300) {
return $Hanf_array_val14628301(anf_array_val1288300,A113,anf_array_val1261999,anf_fun1232000,anf_fun1242001,l1351984,typ1371986,val1381987);
}};
$e82898290.stack[R.EXN_STACKHEIGHT++] = $ss82938294;
}
if(R.isPyretException($e82898290)) {
$e82898290.pyretStack.push(L[988]);
}
throw $e82898290;
}
var $ret82958296 = $Hanf_array_val14628301($z82918292,A113,anf_array_val1261999,anf_fun1232000,anf_fun1242001,l1351984,typ1371986,val1381987);
++R.GAS;
return $ret82958296;
};
var $Hanf_array_val14628301 = function(anf_array_val1288300,A113,anf_array_val1261999,anf_fun1232000,anf_fun1242001,l1351984,typ1371986,val1381987) {
var anf_fun1298312 = G(A113,"s-str",L[991]);
var $z83048305 = D;
var $f83108311 = function(_) {
return R.isFunction(anf_fun1298312)?anf_fun1298312.app(l1351984,typ1371986):R.ffi.throwNonFunApp(L[990],anf_fun1298312,[l1351984,typ1371986]);
};
try {
if(--R.GAS > 0) {
$z83048305 = $f83108311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83108311,
"from":L[990]});
}
} catch($e83028303) {
if(R.isCont($e83028303)) {
var $ss83068307 = {"from":L[990],
"go":function(anf_array_val1308313) {
return $Hanf_array_val14618314(anf_array_val1308313,anf_array_val1261999,anf_array_val1288300,anf_fun1232000,anf_fun1242001,l1351984,val1381987);
}};
$e83028303.stack[R.EXN_STACKHEIGHT++] = $ss83068307;
}
if(R.isPyretException($e83028303)) {
$e83028303.pyretStack.push(L[990]);
}
throw $e83028303;
}
var $ret83088309 = $Hanf_array_val14618314($z83048305,anf_array_val1261999,anf_array_val1288300,anf_fun1232000,anf_fun1242001,l1351984,val1381987);
++R.GAS;
return $ret83088309;
};
var $Hanf_array_val14618314 = function(anf_array_val1308313,anf_array_val1261999,anf_array_val1288300,anf_fun1232000,anf_fun1242001,l1351984,val1381987) {
var $z83178318 = D;
var $f83238324 = function(_) {
return R.isFunction(anf_fun1242001)?anf_fun1242001.app([anf_array_val1261999,anf_array_val1288300,anf_array_val1308313,val1381987]):R.ffi.throwNonFunApp(L[289],anf_fun1242001,[[anf_array_val1261999,anf_array_val1288300,anf_array_val1308313,val1381987]]);
};
try {
if(--R.GAS > 0) {
$z83178318 = $f83238324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83238324,
"from":L[289]});
}
} catch($e83158316) {
if(R.isCont($e83158316)) {
var $ss83198320 = {"from":L[289],
"go":function(anf_arg1318325) {
return $Hanf_arg14608326(anf_arg1318325,anf_fun1232000,l1351984);
}};
$e83158316.stack[R.EXN_STACKHEIGHT++] = $ss83198320;
}
if(R.isPyretException($e83158316)) {
$e83158316.pyretStack.push(L[289]);
}
throw $e83158316;
}
var $ret83218322 = $Hanf_arg14608326($z83178318,anf_fun1232000,l1351984);
++R.GAS;
return $ret83218322;
};
var $Hanf_arg14608326 = function(anf_arg1318325,anf_fun1232000,l1351984) {
var $z83298330 = D;
var $f83358336 = function(_) {
return R.isFunction(anf_fun1232000)?anf_fun1232000.app(l1351984,("throwNonBooleanOp"),anf_arg1318325):R.ffi.throwNonFunApp(L[286],anf_fun1232000,[l1351984,("throwNonBooleanOp"),anf_arg1318325]);
};
try {
if(--R.GAS > 0) {
$z83298330 = $f83358336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83358336,
"from":L[286]});
}
} catch($e83278328) {
if(R.isCont($e83278328)) {
var $ss83318332 = {"from":L[286],
"go":function(ann_DASH_check_DASH_temp1228337) {
return $Hann_DASH_check_DASH_temp14598338(ann_DASH_check_DASH_temp1228337);
}};
$e83278328.stack[R.EXN_STACKHEIGHT++] = $ss83318332;
}
if(R.isPyretException($e83278328)) {
$e83278328.pyretStack.push(L[286]);
}
throw $e83278328;
}
var $ret83338334 = $Hann_DASH_check_DASH_temp14598338($z83298330);
++R.GAS;
return $ret83338334;
};
var $Hann_DASH_check_DASH_temp14598338 = function(ann_DASH_check_DASH_temp1228337) {
return ann_DASH_check_DASH_temp1228337;
};
var $Hanf_array_val14582020 = function(anf_array_val1172017,A113,anf_fun1142018,anf_fun1152019,l1322003,typ1332004,val1342005) {
var anf_fun1188349 = G(A113,"s-str",L[993]);
var $z83418342 = D;
var $f83478348 = function(_) {
return R.isFunction(anf_fun1188349)?anf_fun1188349.app(l1322003,typ1332004):R.ffi.throwNonFunApp(L[992],anf_fun1188349,[l1322003,typ1332004]);
};
try {
if(--R.GAS > 0) {
$z83418342 = $f83478348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83478348,
"from":L[992]});
}
} catch($e83398340) {
if(R.isCont($e83398340)) {
var $ss83438344 = {"from":L[992],
"go":function(anf_array_val1198350) {
return $Hanf_array_val14578351(anf_array_val1198350,anf_array_val1172017,anf_fun1142018,anf_fun1152019,l1322003,val1342005);
}};
$e83398340.stack[R.EXN_STACKHEIGHT++] = $ss83438344;
}
if(R.isPyretException($e83398340)) {
$e83398340.pyretStack.push(L[992]);
}
throw $e83398340;
}
var $ret83458346 = $Hanf_array_val14578351($z83418342,anf_array_val1172017,anf_fun1142018,anf_fun1152019,l1322003,val1342005);
++R.GAS;
return $ret83458346;
};
var $Hanf_array_val14578351 = function(anf_array_val1198350,anf_array_val1172017,anf_fun1142018,anf_fun1152019,l1322003,val1342005) {
var $z83548355 = D;
var $f83608361 = function(_) {
return R.isFunction(anf_fun1152019)?anf_fun1152019.app([anf_array_val1172017,anf_array_val1198350,val1342005]):R.ffi.throwNonFunApp(L[294],anf_fun1152019,[[anf_array_val1172017,anf_array_val1198350,val1342005]]);
};
try {
if(--R.GAS > 0) {
$z83548355 = $f83608361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83608361,
"from":L[294]});
}
} catch($e83528353) {
if(R.isCont($e83528353)) {
var $ss83568357 = {"from":L[294],
"go":function(anf_arg1208362) {
return $Hanf_arg14568363(anf_arg1208362,anf_fun1142018,l1322003);
}};
$e83528353.stack[R.EXN_STACKHEIGHT++] = $ss83568357;
}
if(R.isPyretException($e83528353)) {
$e83528353.pyretStack.push(L[294]);
}
throw $e83528353;
}
var $ret83588359 = $Hanf_arg14568363($z83548355,anf_fun1142018,l1322003);
++R.GAS;
return $ret83588359;
};
var $Hanf_arg14568363 = function(anf_arg1208362,anf_fun1142018,l1322003) {
var $z83668367 = D;
var $f83728373 = function(_) {
return R.isFunction(anf_fun1142018)?anf_fun1142018.app(l1322003,("throwNonBooleanCondition"),anf_arg1208362):R.ffi.throwNonFunApp(L[291],anf_fun1142018,[l1322003,("throwNonBooleanCondition"),anf_arg1208362]);
};
try {
if(--R.GAS > 0) {
$z83668367 = $f83728373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83728373,
"from":L[291]});
}
} catch($e83648365) {
if(R.isCont($e83648365)) {
var $ss83688369 = {"from":L[291],
"go":function(ann_DASH_check_DASH_temp1138374) {
return $Hann_DASH_check_DASH_temp14558375(ann_DASH_check_DASH_temp1138374);
}};
$e83648365.stack[R.EXN_STACKHEIGHT++] = $ss83688369;
}
if(R.isPyretException($e83648365)) {
$e83648365.pyretStack.push(L[291]);
}
throw $e83648365;
}
var $ret83708371 = $Hann_DASH_check_DASH_temp14558375($z83668367);
++R.GAS;
return $ret83708371;
};
var $Hann_DASH_check_DASH_temp14558375 = function(ann_DASH_check_DASH_temp1138374) {
return ann_DASH_check_DASH_temp1138374;
};
var $Hanf_arg14542036 = function(anf_arg1112034,anf_fun1092035,l1302021) {
var $z83788379 = D;
var $f83848385 = function(_) {
return R.isFunction(anf_fun1092035)?anf_fun1092035.app(l1302021,("throwMessageException"),anf_arg1112034):R.ffi.throwNonFunApp(L[296],anf_fun1092035,[l1302021,("throwMessageException"),anf_arg1112034]);
};
try {
if(--R.GAS > 0) {
$z83788379 = $f83848385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83848385,
"from":L[296]});
}
} catch($e83768377) {
if(R.isCont($e83768377)) {
var $ss83808381 = {"from":L[296],
"go":function(ann_DASH_check_DASH_temp1088386) {
return $Hann_DASH_check_DASH_temp14538387(ann_DASH_check_DASH_temp1088386);
}};
$e83768377.stack[R.EXN_STACKHEIGHT++] = $ss83808381;
}
if(R.isPyretException($e83768377)) {
$e83768377.pyretStack.push(L[296]);
}
throw $e83768377;
}
var $ret83828383 = $Hann_DASH_check_DASH_temp14538387($z83788379);
++R.GAS;
return $ret83828383;
};
var $Hann_DASH_check_DASH_temp14538387 = function(ann_DASH_check_DASH_temp1088386) {
return ann_DASH_check_DASH_temp1088386;
};
var $Hanf_arg14522051 = function(anf_arg1062050,l1282037,make_DASH_message_DASH_exception_DASH_e94264) {
var $z83908391 = D;
var $f83968397 = function(_) {
return R.isFunction(make_DASH_message_DASH_exception_DASH_e94264.$var === D?U(L[994],"make-message-exception-e"):make_DASH_message_DASH_exception_DASH_e94264.$var)?make_DASH_message_DASH_exception_DASH_e94264.$var === D?U(L[994],"make-message-exception-e"):make_DASH_message_DASH_exception_DASH_e94264.$var.app(l1282037,anf_arg1062050):R.ffi.throwNonFunApp(L[299],make_DASH_message_DASH_exception_DASH_e94264.$var === D?U(L[994],"make-message-exception-e"):make_DASH_message_DASH_exception_DASH_e94264.$var,[l1282037,anf_arg1062050]);
};
try {
if(--R.GAS > 0) {
$z83908391 = $f83968397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83968397,
"from":L[299]});
}
} catch($e83888389) {
if(R.isCont($e83888389)) {
var $ss83928393 = {"from":L[299],
"go":function(ann_DASH_check_DASH_temp1048398) {
return $Hann_DASH_check_DASH_temp14518399(ann_DASH_check_DASH_temp1048398);
}};
$e83888389.stack[R.EXN_STACKHEIGHT++] = $ss83928393;
}
if(R.isPyretException($e83888389)) {
$e83888389.pyretStack.push(L[299]);
}
throw $e83888389;
}
var $ret83948395 = $Hann_DASH_check_DASH_temp14518399($z83908391);
++R.GAS;
return $ret83948395;
};
var $Hann_DASH_check_DASH_temp14518399 = function(ann_DASH_check_DASH_temp1048398) {
return ann_DASH_check_DASH_temp1048398;
};
var $Hanf_array_val14502068 = function(anf_array_val992065,A113,anf_fun962066,anf_fun972067,l1262052,typ1272053) {
var anf_fun1008410 = G(A113,"s-str",L[996]);
var $z84028403 = D;
var $f84088409 = function(_) {
return R.isFunction(anf_fun1008410)?anf_fun1008410.app(l1262052,typ1272053):R.ffi.throwNonFunApp(L[995],anf_fun1008410,[l1262052,typ1272053]);
};
try {
if(--R.GAS > 0) {
$z84028403 = $f84088409();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84088409,
"from":L[995]});
}
} catch($e84008401) {
if(R.isCont($e84008401)) {
var $ss84048405 = {"from":L[995],
"go":function(anf_array_val1018411) {
return $Hanf_array_val14498412(anf_array_val1018411,anf_array_val992065,anf_fun962066,anf_fun972067,l1262052);
}};
$e84008401.stack[R.EXN_STACKHEIGHT++] = $ss84048405;
}
if(R.isPyretException($e84008401)) {
$e84008401.pyretStack.push(L[995]);
}
throw $e84008401;
}
var $ret84068407 = $Hanf_array_val14498412($z84028403,anf_array_val992065,anf_fun962066,anf_fun972067,l1262052);
++R.GAS;
return $ret84068407;
};
var $Hanf_array_val14498412 = function(anf_array_val1018411,anf_array_val992065,anf_fun962066,anf_fun972067,l1262052) {
var $z84158416 = D;
var $f84218422 = function(_) {
return R.isFunction(anf_fun972067)?anf_fun972067.app([anf_array_val992065,anf_array_val1018411]):R.ffi.throwNonFunApp(L[305],anf_fun972067,[[anf_array_val992065,anf_array_val1018411]]);
};
try {
if(--R.GAS > 0) {
$z84158416 = $f84218422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84218422,
"from":L[305]});
}
} catch($e84138414) {
if(R.isCont($e84138414)) {
var $ss84178418 = {"from":L[305],
"go":function(anf_arg1028423) {
return $Hanf_arg14488424(anf_arg1028423,anf_fun962066,l1262052);
}};
$e84138414.stack[R.EXN_STACKHEIGHT++] = $ss84178418;
}
if(R.isPyretException($e84138414)) {
$e84138414.pyretStack.push(L[305]);
}
throw $e84138414;
}
var $ret84198420 = $Hanf_arg14488424($z84158416,anf_fun962066,l1262052);
++R.GAS;
return $ret84198420;
};
var $Hanf_arg14488424 = function(anf_arg1028423,anf_fun962066,l1262052) {
var $z84278428 = D;
var $f84338434 = function(_) {
return R.isFunction(anf_fun962066)?anf_fun962066.app(l1262052,("throwNoBranchesMatched"),anf_arg1028423):R.ffi.throwNonFunApp(L[302],anf_fun962066,[l1262052,("throwNoBranchesMatched"),anf_arg1028423]);
};
try {
if(--R.GAS > 0) {
$z84278428 = $f84338434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84338434,
"from":L[302]});
}
} catch($e84258426) {
if(R.isCont($e84258426)) {
var $ss84298430 = {"from":L[302],
"go":function(ann_DASH_check_DASH_temp958435) {
return $Hann_DASH_check_DASH_temp14478436(ann_DASH_check_DASH_temp958435);
}};
$e84258426.stack[R.EXN_STACKHEIGHT++] = $ss84298430;
}
if(R.isPyretException($e84258426)) {
$e84258426.pyretStack.push(L[302]);
}
throw $e84258426;
}
var $ret84318432 = $Hann_DASH_check_DASH_temp14478436($z84278428);
++R.GAS;
return $ret84318432;
};
var $Hann_DASH_check_DASH_temp14478436 = function(ann_DASH_check_DASH_temp958435) {
return ann_DASH_check_DASH_temp958435;
};
var $Hanf_array_val14462089 = function(anf_array_val812086,A113,anf_fun772087,anf_fun782088,err1252073,id1222070,l1212069,list2753,then1242072) {
var $z84398440 = D;
var $f84458446 = function(_) {
return R.isFunction(anf_fun782088)?anf_fun782088.app([anf_array_val812086]):R.ffi.throwNonFunApp(L[311],anf_fun782088,[[anf_array_val812086]]);
};
try {
if(--R.GAS > 0) {
$z84398440 = $f84458446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84458446,
"from":L[311]});
}
} catch($e84378438) {
if(R.isCont($e84378438)) {
var $ss84418442 = {"from":L[311],
"go":function(anf_arg828447) {
return $Hanf_arg14458448(anf_arg828447,A113,anf_fun772087,err1252073,id1222070,l1212069,list2753,then1242072);
}};
$e84378438.stack[R.EXN_STACKHEIGHT++] = $ss84418442;
}
if(R.isPyretException($e84378438)) {
$e84378438.pyretStack.push(L[311]);
}
throw $e84378438;
}
var $ret84438444 = $Hanf_arg14458448($z84398440,A113,anf_fun772087,err1252073,id1222070,l1212069,list2753,then1242072);
++R.GAS;
return $ret84438444;
};
var $Hanf_arg14458448 = function(anf_arg828447,A113,anf_fun772087,err1252073,id1222070,l1212069,list2753,then1242072) {
var anf_fun838462 = G(A113,"s-if-else",L[1002]);
var anf_fun848463 = G(list2753,"make",L[1001]);
var anf_fun858464 = G(A113,"s-if-branch",L[1000]);
var anf_fun868465 = G(A113,"s-prim-app",L[999]);
var anf_fun878459 = G(list2753,"make",L[997]);
var anf_array_val888460 = G(id1222070,"id-e",L[998]);
var $z84518452 = D;
var $f84578458 = function(_) {
return R.isFunction(anf_fun878459)?anf_fun878459.app([anf_array_val888460]):R.ffi.throwNonFunApp(L[997],anf_fun878459,[[anf_array_val888460]]);
};
try {
if(--R.GAS > 0) {
$z84518452 = $f84578458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84578458,
"from":L[997]});
}
} catch($e84498450) {
if(R.isCont($e84498450)) {
var $ss84538454 = {"from":L[997],
"go":function(anf_arg898461) {
return $Hanf_arg14448466(anf_arg898461,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,anf_fun858464,anf_fun868465,err1252073,l1212069,then1242072);
}};
$e84498450.stack[R.EXN_STACKHEIGHT++] = $ss84538454;
}
if(R.isPyretException($e84498450)) {
$e84498450.pyretStack.push(L[997]);
}
throw $e84498450;
}
var $ret84558456 = $Hanf_arg14448466($z84518452,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,anf_fun858464,anf_fun868465,err1252073,l1212069,then1242072);
++R.GAS;
return $ret84558456;
};
var $Hanf_arg14448466 = function(anf_arg898461,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,anf_fun858464,anf_fun868465,err1252073,l1212069,then1242072) {
var $z84698470 = D;
var $f84758476 = function(_) {
return R.isFunction(anf_fun868465)?anf_fun868465.app(l1212069,("isBoolean"),anf_arg898461):R.ffi.throwNonFunApp(L[1003],anf_fun868465,[l1212069,("isBoolean"),anf_arg898461]);
};
try {
if(--R.GAS > 0) {
$z84698470 = $f84758476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84758476,
"from":L[1003]});
}
} catch($e84678468) {
if(R.isCont($e84678468)) {
var $ss84718472 = {"from":L[1003],
"go":function(anf_arg908477) {
return $Hanf_arg14438478(anf_arg908477,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,anf_fun858464,err1252073,l1212069,then1242072);
}};
$e84678468.stack[R.EXN_STACKHEIGHT++] = $ss84718472;
}
if(R.isPyretException($e84678468)) {
$e84678468.pyretStack.push(L[1003]);
}
throw $e84678468;
}
var $ret84738474 = $Hanf_arg14438478($z84698470,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,anf_fun858464,err1252073,l1212069,then1242072);
++R.GAS;
return $ret84738474;
};
var $Hanf_arg14438478 = function(anf_arg908477,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,anf_fun858464,err1252073,l1212069,then1242072) {
var $z84818482 = D;
var $f84878488 = function(_) {
return R.isFunction(anf_fun858464)?anf_fun858464.app(l1212069,anf_arg908477,then1242072):R.ffi.throwNonFunApp(L[1004],anf_fun858464,[l1212069,anf_arg908477,then1242072]);
};
try {
if(--R.GAS > 0) {
$z84818482 = $f84878488();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84878488,
"from":L[1004]});
}
} catch($e84798480) {
if(R.isCont($e84798480)) {
var $ss84838484 = {"from":L[1004],
"go":function(anf_array_val918489) {
return $Hanf_array_val14428490(anf_array_val918489,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,err1252073,l1212069);
}};
$e84798480.stack[R.EXN_STACKHEIGHT++] = $ss84838484;
}
if(R.isPyretException($e84798480)) {
$e84798480.pyretStack.push(L[1004]);
}
throw $e84798480;
}
var $ret84858486 = $Hanf_array_val14428490($z84818482,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,err1252073,l1212069);
++R.GAS;
return $ret84858486;
};
var $Hanf_array_val14428490 = function(anf_array_val918489,anf_arg828447,anf_fun772087,anf_fun838462,anf_fun848463,err1252073,l1212069) {
var $z84938494 = D;
var $f84998500 = function(_) {
return R.isFunction(anf_fun848463)?anf_fun848463.app([anf_array_val918489]):R.ffi.throwNonFunApp(L[1001],anf_fun848463,[[anf_array_val918489]]);
};
try {
if(--R.GAS > 0) {
$z84938494 = $f84998500();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84998500,
"from":L[1001]});
}
} catch($e84918492) {
if(R.isCont($e84918492)) {
var $ss84958496 = {"from":L[1001],
"go":function(anf_arg928501) {
return $Hanf_arg14418502(anf_arg928501,anf_arg828447,anf_fun772087,anf_fun838462,err1252073,l1212069);
}};
$e84918492.stack[R.EXN_STACKHEIGHT++] = $ss84958496;
}
if(R.isPyretException($e84918492)) {
$e84918492.pyretStack.push(L[1001]);
}
throw $e84918492;
}
var $ret84978498 = $Hanf_arg14418502($z84938494,anf_arg828447,anf_fun772087,anf_fun838462,err1252073,l1212069);
++R.GAS;
return $ret84978498;
};
var $Hanf_arg14418502 = function(anf_arg928501,anf_arg828447,anf_fun772087,anf_fun838462,err1252073,l1212069) {
var $z85058506 = D;
var $f85118512 = function(_) {
return R.isFunction(anf_fun838462)?anf_fun838462.app(l1212069,anf_arg928501,err1252073):R.ffi.throwNonFunApp(L[1005],anf_fun838462,[l1212069,anf_arg928501,err1252073]);
};
try {
if(--R.GAS > 0) {
$z85058506 = $f85118512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85118512,
"from":L[1005]});
}
} catch($e85038504) {
if(R.isCont($e85038504)) {
var $ss85078508 = {"from":L[1005],
"go":function(anf_arg938513) {
return $Hanf_arg14408514(anf_arg938513,anf_arg828447,anf_fun772087,l1212069);
}};
$e85038504.stack[R.EXN_STACKHEIGHT++] = $ss85078508;
}
if(R.isPyretException($e85038504)) {
$e85038504.pyretStack.push(L[1005]);
}
throw $e85038504;
}
var $ret85098510 = $Hanf_arg14408514($z85058506,anf_arg828447,anf_fun772087,l1212069);
++R.GAS;
return $ret85098510;
};
var $Hanf_arg14408514 = function(anf_arg938513,anf_arg828447,anf_fun772087,l1212069) {
var $z85178518 = D;
var $f85238524 = function(_) {
return R.isFunction(anf_fun772087)?anf_fun772087.app(l1212069,anf_arg828447,anf_arg938513):R.ffi.throwNonFunApp(L[307],anf_fun772087,[l1212069,anf_arg828447,anf_arg938513]);
};
try {
if(--R.GAS > 0) {
$z85178518 = $f85238524();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85238524,
"from":L[307]});
}
} catch($e85158516) {
if(R.isCont($e85158516)) {
var $ss85198520 = {"from":L[307],
"go":function(ann_DASH_check_DASH_temp768525) {
return $Hann_DASH_check_DASH_temp14398526(ann_DASH_check_DASH_temp768525);
}};
$e85158516.stack[R.EXN_STACKHEIGHT++] = $ss85198520;
}
if(R.isPyretException($e85158516)) {
$e85158516.pyretStack.push(L[307]);
}
throw $e85158516;
}
var $ret85218522 = $Hann_DASH_check_DASH_temp14398526($z85178518);
++R.GAS;
return $ret85218522;
};
var $Hann_DASH_check_DASH_temp14398526 = function(ann_DASH_check_DASH_temp768525) {
return ann_DASH_check_DASH_temp768525;
};
var $Hanf_arg14382104 = function(anf_arg742102,anf_fun732103,l1192090) {
var $z85298530 = D;
var $f85358536 = function(_) {
return R.isFunction(anf_fun732103)?anf_fun732103.app(l1192090,anf_arg742102):R.ffi.throwNonFunApp(L[313],anf_fun732103,[l1192090,anf_arg742102]);
};
try {
if(--R.GAS > 0) {
$z85298530 = $f85358536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85358536,
"from":L[313]});
}
} catch($e85278528) {
if(R.isCont($e85278528)) {
var $ss85318532 = {"from":L[313],
"go":function(ann_DASH_check_DASH_temp728537) {
return $Hann_DASH_check_DASH_temp14378538(ann_DASH_check_DASH_temp728537);
}};
$e85278528.stack[R.EXN_STACKHEIGHT++] = $ss85318532;
}
if(R.isPyretException($e85278528)) {
$e85278528.pyretStack.push(L[313]);
}
throw $e85278528;
}
var $ret85338534 = $Hann_DASH_check_DASH_temp14378538($z85298530);
++R.GAS;
return $ret85338534;
};
var $Hann_DASH_check_DASH_temp14378538 = function(ann_DASH_check_DASH_temp728537) {
return ann_DASH_check_DASH_temp728537;
};
var $Hann_DASH_check_DASH_temp14362118 = function(ann_DASH_check_DASH_temp692117) {
return ann_DASH_check_DASH_temp692117;
};
var $Hanf_arg1435113 = function(anf_arg50111,self11112,_plus7,torepr11) {
var anf_arg518549 = G(self11112,"right",L[1]);
var $z85418542 = D;
var $f85478548 = function(_) {
return R.isFunction(torepr11)?torepr11.app(anf_arg518549):R.ffi.throwNonFunApp(L[1],torepr11,[anf_arg518549]);
};
try {
if(--R.GAS > 0) {
$z85418542 = $f85478548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85478548,
"from":L[1]});
}
} catch($e85398540) {
if(R.isCont($e85398540)) {
var $ss85438544 = {"from":L[1],
"go":function(anf_arg528550) {
return $Hanf_arg14348551(anf_arg528550,anf_arg50111,_plus7);
}};
$e85398540.stack[R.EXN_STACKHEIGHT++] = $ss85438544;
}
if(R.isPyretException($e85398540)) {
$e85398540.pyretStack.push(L[1]);
}
throw $e85398540;
}
var $ret85458546 = $Hanf_arg14348551($z85418542,anf_arg50111,_plus7);
++R.GAS;
return $ret85458546;
};
var $Hanf_arg14348551 = function(anf_arg528550,anf_arg50111,_plus7) {
var $z85548555 = D;
var $f85608561 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg528550):R.ffi.throwNonFunApp(L[1],_plus7,[(", "),anf_arg528550]);
};
try {
if(--R.GAS > 0) {
$z85548555 = $f85608561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85608561,
"from":L[1]});
}
} catch($e85528553) {
if(R.isCont($e85528553)) {
var $ss85568557 = {"from":L[1],
"go":function(anf_arg538562) {
return $Hanf_arg14338563(anf_arg538562,anf_arg50111,_plus7);
}};
$e85528553.stack[R.EXN_STACKHEIGHT++] = $ss85568557;
}
if(R.isPyretException($e85528553)) {
$e85528553.pyretStack.push(L[1]);
}
throw $e85528553;
}
var $ret85588559 = $Hanf_arg14338563($z85548555,anf_arg50111,_plus7);
++R.GAS;
return $ret85588559;
};
var $Hanf_arg14338563 = function(anf_arg538562,anf_arg50111,_plus7) {
var $z85668567 = D;
var $f85728573 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg50111,anf_arg538562):R.ffi.throwNonFunApp(L[1],_plus7,[anf_arg50111,anf_arg538562]);
};
try {
if(--R.GAS > 0) {
$z85668567 = $f85728573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85728573,
"from":L[1]});
}
} catch($e85648565) {
if(R.isCont($e85648565)) {
var $ss85688569 = {"from":L[1],
"go":function(anf_arg548574) {
return $Hanf_arg14328575(anf_arg548574,_plus7);
}};
$e85648565.stack[R.EXN_STACKHEIGHT++] = $ss85688569;
}
if(R.isPyretException($e85648565)) {
$e85648565.pyretStack.push(L[1]);
}
throw $e85648565;
}
var $ret85708571 = $Hanf_arg14328575($z85668567,_plus7);
++R.GAS;
return $ret85708571;
};
var $Hanf_arg14328575 = function(anf_arg548574,_plus7) {
var $z85788579 = D;
var $f85848585 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg548574,(")")):R.ffi.throwNonFunApp(L[1],_plus7,[anf_arg548574,(")")]);
};
try {
if(--R.GAS > 0) {
$z85788579 = $f85848585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85848585,
"from":L[1]});
}
} catch($e85768577) {
if(R.isCont($e85768577)) {
var $ss85808581 = {"from":L[1],
"go":function(anf_arg558586) {
return $Hanf_arg14318587(anf_arg558586,_plus7);
}};
$e85768577.stack[R.EXN_STACKHEIGHT++] = $ss85808581;
}
if(R.isPyretException($e85768577)) {
$e85768577.pyretStack.push(L[1]);
}
throw $e85768577;
}
var $ret85828583 = $Hanf_arg14318587($z85788579,_plus7);
++R.GAS;
return $ret85828583;
};
var $Hanf_arg14318587 = function(anf_arg558586,_plus7) {
var $z85908591 = D;
var $f85968597 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg558586):R.ffi.throwNonFunApp(L[1],_plus7,[("("),anf_arg558586]);
};
try {
if(--R.GAS > 0) {
$z85908591 = $f85968597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85968597,
"from":L[1]});
}
} catch($e85888589) {
if(R.isCont($e85888589)) {
var $ss85928593 = {"from":L[1],
"go":function(anf_arg568598) {
return $Hanf_arg14308599(anf_arg568598,_plus7);
}};
$e85888589.stack[R.EXN_STACKHEIGHT++] = $ss85928593;
}
if(R.isPyretException($e85888589)) {
$e85888589.pyretStack.push(L[1]);
}
throw $e85888589;
}
var $ret85948595 = $Hanf_arg14308599($z85908591,_plus7);
++R.GAS;
return $ret85948595;
};
var $Hanf_arg14308599 = function(anf_arg568598,_plus7) {
var $z86028603 = D;
var $f86088609 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("pair"),anf_arg568598):R.ffi.throwNonFunApp(L[1],_plus7,[("pair"),anf_arg568598]);
};
try {
if(--R.GAS > 0) {
$z86028603 = $f86088609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86088609,
"from":L[1]});
}
} catch($e86008601) {
if(R.isCont($e86008601)) {
var $ss86048605 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp488610) {
return $Hann_DASH_check_DASH_temp14298611(ann_DASH_check_DASH_temp488610);
}};
$e86008601.stack[R.EXN_STACKHEIGHT++] = $ss86048605;
}
if(R.isPyretException($e86008601)) {
$e86008601.pyretStack.push(L[1]);
}
throw $e86008601;
}
var $ret86068607 = $Hann_DASH_check_DASH_temp14298611($z86028603);
++R.GAS;
return $ret86068607;
};
var $Hann_DASH_check_DASH_temp14298611 = function(ann_DASH_check_DASH_temp488610) {
return ann_DASH_check_DASH_temp488610;
};
var $Hcont_tail_arg1427129 = function(cont_tail_arg45127,if_helper36128) {
if(--R.GAS > 0) {
$z86128613 = R.isFunction(if_helper36128)?if_helper36128.app(cont_tail_arg45127):R.ffi.throwNonFunApp(L[1],if_helper36128,[cont_tail_arg45127]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper36128)?if_helper36128.app(cont_tail_arg45127):R.ffi.throwNonFunApp(L[1],if_helper36128,[cont_tail_arg45127]);
},
"from":L[1]});
}
++R.GAS;
return $z86128613;
};
var $Hcont_tail_arg1428144 = function(cont_tail_arg41143,if_helper36128) {
if(--R.GAS > 0) {
$z86148615 = R.isFunction(if_helper36128)?if_helper36128.app(cont_tail_arg41143):R.ffi.throwNonFunApp(L[1],if_helper36128,[cont_tail_arg41143]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper36128)?if_helper36128.app(cont_tail_arg41143):R.ffi.throwNonFunApp(L[1],if_helper36128,[cont_tail_arg41143]);
},
"from":L[1]});
}
++R.GAS;
return $z86148615;
};
var $Hanf_arg1426176 = function(anf_arg18174,self5175,_plus7,torepr11) {
var anf_arg198626 = G(self5175,"vars",L[6]);
var $z86188619 = D;
var $f86248625 = function(_) {
return R.isFunction(torepr11)?torepr11.app(anf_arg198626):R.ffi.throwNonFunApp(L[6],torepr11,[anf_arg198626]);
};
try {
if(--R.GAS > 0) {
$z86188619 = $f86248625();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86248625,
"from":L[6]});
}
} catch($e86168617) {
if(R.isCont($e86168617)) {
var $ss86208621 = {"from":L[6],
"go":function(anf_arg208627) {
return $Hanf_arg14258628(anf_arg208627,anf_arg18174,self5175,_plus7,torepr11);
}};
$e86168617.stack[R.EXN_STACKHEIGHT++] = $ss86208621;
}
if(R.isPyretException($e86168617)) {
$e86168617.pyretStack.push(L[6]);
}
throw $e86168617;
}
var $ret86228623 = $Hanf_arg14258628($z86188619,anf_arg18174,self5175,_plus7,torepr11);
++R.GAS;
return $ret86228623;
};
var $Hanf_arg14258628 = function(anf_arg208627,anf_arg18174,self5175,_plus7,torepr11) {
var $z86318632 = D;
var $f86378638 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg208627):R.ffi.throwNonFunApp(L[6],_plus7,[(", "),anf_arg208627]);
};
try {
if(--R.GAS > 0) {
$z86318632 = $f86378638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86378638,
"from":L[6]});
}
} catch($e86298630) {
if(R.isCont($e86298630)) {
var $ss86338634 = {"from":L[6],
"go":function(anf_arg218639) {
return $Hanf_arg14248640(anf_arg218639,anf_arg18174,self5175,_plus7,torepr11);
}};
$e86298630.stack[R.EXN_STACKHEIGHT++] = $ss86338634;
}
if(R.isPyretException($e86298630)) {
$e86298630.pyretStack.push(L[6]);
}
throw $e86298630;
}
var $ret86358636 = $Hanf_arg14248640($z86318632,anf_arg18174,self5175,_plus7,torepr11);
++R.GAS;
return $ret86358636;
};
var $Hanf_arg14248640 = function(anf_arg218639,anf_arg18174,self5175,_plus7,torepr11) {
var $z86438644 = D;
var $f86498650 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg18174,anf_arg218639):R.ffi.throwNonFunApp(L[6],_plus7,[anf_arg18174,anf_arg218639]);
};
try {
if(--R.GAS > 0) {
$z86438644 = $f86498650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86498650,
"from":L[6]});
}
} catch($e86418642) {
if(R.isCont($e86418642)) {
var $ss86458646 = {"from":L[6],
"go":function(anf_arg228651) {
return $Hanf_arg14238652(anf_arg228651,self5175,_plus7,torepr11);
}};
$e86418642.stack[R.EXN_STACKHEIGHT++] = $ss86458646;
}
if(R.isPyretException($e86418642)) {
$e86418642.pyretStack.push(L[6]);
}
throw $e86418642;
}
var $ret86478648 = $Hanf_arg14238652($z86438644,self5175,_plus7,torepr11);
++R.GAS;
return $ret86478648;
};
var $Hanf_arg14238652 = function(anf_arg228651,self5175,_plus7,torepr11) {
var anf_arg238663 = G(self5175,"letrecs",L[6]);
var $z86558656 = D;
var $f86618662 = function(_) {
return R.isFunction(torepr11)?torepr11.app(anf_arg238663):R.ffi.throwNonFunApp(L[6],torepr11,[anf_arg238663]);
};
try {
if(--R.GAS > 0) {
$z86558656 = $f86618662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86618662,
"from":L[6]});
}
} catch($e86538654) {
if(R.isCont($e86538654)) {
var $ss86578658 = {"from":L[6],
"go":function(anf_arg248664) {
return $Hanf_arg14228665(anf_arg248664,anf_arg228651,_plus7);
}};
$e86538654.stack[R.EXN_STACKHEIGHT++] = $ss86578658;
}
if(R.isPyretException($e86538654)) {
$e86538654.pyretStack.push(L[6]);
}
throw $e86538654;
}
var $ret86598660 = $Hanf_arg14228665($z86558656,anf_arg228651,_plus7);
++R.GAS;
return $ret86598660;
};
var $Hanf_arg14228665 = function(anf_arg248664,anf_arg228651,_plus7) {
var $z86688669 = D;
var $f86748675 = function(_) {
return R.isFunction(_plus7)?_plus7.app((", "),anf_arg248664):R.ffi.throwNonFunApp(L[6],_plus7,[(", "),anf_arg248664]);
};
try {
if(--R.GAS > 0) {
$z86688669 = $f86748675();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86748675,
"from":L[6]});
}
} catch($e86668667) {
if(R.isCont($e86668667)) {
var $ss86708671 = {"from":L[6],
"go":function(anf_arg258676) {
return $Hanf_arg14218677(anf_arg258676,anf_arg228651,_plus7);
}};
$e86668667.stack[R.EXN_STACKHEIGHT++] = $ss86708671;
}
if(R.isPyretException($e86668667)) {
$e86668667.pyretStack.push(L[6]);
}
throw $e86668667;
}
var $ret86728673 = $Hanf_arg14218677($z86688669,anf_arg228651,_plus7);
++R.GAS;
return $ret86728673;
};
var $Hanf_arg14218677 = function(anf_arg258676,anf_arg228651,_plus7) {
var $z86808681 = D;
var $f86868687 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg228651,anf_arg258676):R.ffi.throwNonFunApp(L[6],_plus7,[anf_arg228651,anf_arg258676]);
};
try {
if(--R.GAS > 0) {
$z86808681 = $f86868687();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86868687,
"from":L[6]});
}
} catch($e86788679) {
if(R.isCont($e86788679)) {
var $ss86828683 = {"from":L[6],
"go":function(anf_arg268688) {
return $Hanf_arg14208689(anf_arg268688,_plus7);
}};
$e86788679.stack[R.EXN_STACKHEIGHT++] = $ss86828683;
}
if(R.isPyretException($e86788679)) {
$e86788679.pyretStack.push(L[6]);
}
throw $e86788679;
}
var $ret86848685 = $Hanf_arg14208689($z86808681,_plus7);
++R.GAS;
return $ret86848685;
};
var $Hanf_arg14208689 = function(anf_arg268688,_plus7) {
var $z86928693 = D;
var $f86988699 = function(_) {
return R.isFunction(_plus7)?_plus7.app(anf_arg268688,(")")):R.ffi.throwNonFunApp(L[6],_plus7,[anf_arg268688,(")")]);
};
try {
if(--R.GAS > 0) {
$z86928693 = $f86988699();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86988699,
"from":L[6]});
}
} catch($e86908691) {
if(R.isCont($e86908691)) {
var $ss86948695 = {"from":L[6],
"go":function(anf_arg278700) {
return $Hanf_arg14198701(anf_arg278700,_plus7);
}};
$e86908691.stack[R.EXN_STACKHEIGHT++] = $ss86948695;
}
if(R.isPyretException($e86908691)) {
$e86908691.pyretStack.push(L[6]);
}
throw $e86908691;
}
var $ret86968697 = $Hanf_arg14198701($z86928693,_plus7);
++R.GAS;
return $ret86968697;
};
var $Hanf_arg14198701 = function(anf_arg278700,_plus7) {
var $z87048705 = D;
var $f87108711 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("("),anf_arg278700):R.ffi.throwNonFunApp(L[6],_plus7,[("("),anf_arg278700]);
};
try {
if(--R.GAS > 0) {
$z87048705 = $f87108711();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87108711,
"from":L[6]});
}
} catch($e87028703) {
if(R.isCont($e87028703)) {
var $ss87068707 = {"from":L[6],
"go":function(anf_arg288712) {
return $Hanf_arg14188713(anf_arg288712,_plus7);
}};
$e87028703.stack[R.EXN_STACKHEIGHT++] = $ss87068707;
}
if(R.isPyretException($e87028703)) {
$e87028703.pyretStack.push(L[6]);
}
throw $e87028703;
}
var $ret87088709 = $Hanf_arg14188713($z87048705,_plus7);
++R.GAS;
return $ret87088709;
};
var $Hanf_arg14188713 = function(anf_arg288712,_plus7) {
var $z87168717 = D;
var $f87228723 = function(_) {
return R.isFunction(_plus7)?_plus7.app(("d-env"),anf_arg288712):R.ffi.throwNonFunApp(L[6],_plus7,[("d-env"),anf_arg288712]);
};
try {
if(--R.GAS > 0) {
$z87168717 = $f87228723();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87228723,
"from":L[6]});
}
} catch($e87148715) {
if(R.isCont($e87148715)) {
var $ss87188719 = {"from":L[6],
"go":function(ann_DASH_check_DASH_temp168724) {
return $Hann_DASH_check_DASH_temp14178725(ann_DASH_check_DASH_temp168724);
}};
$e87148715.stack[R.EXN_STACKHEIGHT++] = $ss87188719;
}
if(R.isPyretException($e87148715)) {
$e87148715.pyretStack.push(L[6]);
}
throw $e87148715;
}
var $ret87208721 = $Hann_DASH_check_DASH_temp14178725($z87168717);
++R.GAS;
return $ret87208721;
};
var $Hann_DASH_check_DASH_temp14178725 = function(ann_DASH_check_DASH_temp168724) {
return ann_DASH_check_DASH_temp168724;
};
var $Hcont_tail_arg1415193 = function(cont_tail_arg13191,if_helper3192) {
if(--R.GAS > 0) {
$z87268727 = R.isFunction(if_helper3192)?if_helper3192.app(cont_tail_arg13191):R.ffi.throwNonFunApp(L[6],if_helper3192,[cont_tail_arg13191]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3192)?if_helper3192.app(cont_tail_arg13191):R.ffi.throwNonFunApp(L[6],if_helper3192,[cont_tail_arg13191]);
},
"from":L[6]});
}
++R.GAS;
return $z87268727;
};
var $Hcont_tail_arg1416208 = function(cont_tail_arg8207,if_helper3192) {
if(--R.GAS > 0) {
$z87288729 = R.isFunction(if_helper3192)?if_helper3192.app(cont_tail_arg8207):R.ffi.throwNonFunApp(L[6],if_helper3192,[cont_tail_arg8207]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored149) {
return R.isFunction(if_helper3192)?if_helper3192.app(cont_tail_arg8207):R.ffi.throwNonFunApp(L[6],if_helper3192,[cont_tail_arg8207]);
},
"from":L[6]});
}
++R.GAS;
return $z87288729;
};
return R.loadModulesNew(NAMESPACE,[$A11332,$PP31433,$C51534,$U71635,$arrays91736,$lists111837,$option131938,$error152039,$sets172140],function($A11332,$PP31433,$C51534,$U71635,$arrays91736,$lists111837,$option131938,$error152039,$sets172140) {
var A113 = R.getField($A11332,"values");
var PP314 = R.getField($PP31433,"values");
var C515 = R.getField($C51534,"values");
var U716 = R.getField($U71635,"values");
var arrays917 = R.getField($arrays91736,"values");
var lists1118 = R.getField($lists111837,"values");
var option1319 = R.getField($option131938,"values");
var error1520 = R.getField($error152039,"values");
var sets1721 = R.getField($sets172140,"values");
var A222 = R.getField($A11332,"types");
var PP423 = R.getField($PP31433,"types");
var C624 = R.getField($C51534,"types");
var U825 = R.getField($U71635,"types");
var arrays1026 = R.getField($arrays91736,"types");
var lists1227 = R.getField($lists111837,"types");
var option1428 = R.getField($option131938,"types");
var error1629 = R.getField($error152039,"types");
var sets1830 = R.getField($sets172140,"types");
return R.safeCall(function() {
var List198730 = R.getDotAnn(L[1006],"lists",lists1227,"List");
var Option2045 = R.getDotAnn(L[1006],"option",option1428,"Option");
var Array218731 = R.getDotAnn(L[1006],"arrays",arrays1026,"Array");
var Set2248 = R.getDotAnn(L[1006],"sets",sets1830,"Set");
var array238778 = G(arrays917,"array",L[1006]);
var build_DASH_array248777 = G(arrays917,"build-array",L[1006]);
var array_DASH_from_DASH_list258776 = G(arrays917,"array-from-list",L[1006]);
var is_DASH_array268775 = G(arrays917,"is-array",L[1006]);
var list2753 = G(lists1118,"list",L[1006]);
var is_DASH_empty2851 = G(lists1118,"is-empty",L[1006]);
var is_DASH_link298774 = G(lists1118,"is-link",L[1006]);
var empty3049 = G(lists1118,"empty",L[1006]);
var link3152 = G(lists1118,"link",L[1006]);
var range328773 = G(lists1118,"range",L[1006]);
var repeat338772 = G(lists1118,"repeat",L[1006]);
var filter348771 = G(lists1118,"filter",L[1006]);
var partition358770 = G(lists1118,"partition",L[1006]);
var split_DASH_at368769 = G(lists1118,"split-at",L[1006]);
var any378768 = G(lists1118,"any",L[1006]);
var find388767 = G(lists1118,"find",L[1006]);
var map3954 = G(lists1118,"map",L[1006]);
var map2408766 = G(lists1118,"map2",L[1006]);
var map3418765 = G(lists1118,"map3",L[1006]);
var map4428764 = G(lists1118,"map4",L[1006]);
var map_n438763 = G(lists1118,"map_n",L[1006]);
var map2_n448762 = G(lists1118,"map2_n",L[1006]);
var map3_n458761 = G(lists1118,"map3_n",L[1006]);
var map4_n468760 = G(lists1118,"map4_n",L[1006]);
var each478759 = G(lists1118,"each",L[1006]);
var each2488758 = G(lists1118,"each2",L[1006]);
var each3498757 = G(lists1118,"each3",L[1006]);
var each4508756 = G(lists1118,"each4",L[1006]);
var each_n518755 = G(lists1118,"each_n",L[1006]);
var each2_n528754 = G(lists1118,"each2_n",L[1006]);
var each3_n538753 = G(lists1118,"each3_n",L[1006]);
var each4_n548752 = G(lists1118,"each4_n",L[1006]);
var fold5550 = G(lists1118,"fold",L[1006]);
var fold2568751 = G(lists1118,"fold2",L[1006]);
var fold3578750 = G(lists1118,"fold3",L[1006]);
var fold4588749 = G(lists1118,"fold4",L[1006]);
var index598748 = G(lists1118,"index",L[1006]);
var Option608747 = G(option1319,"Option",L[1006]);
var is_DASH_none618746 = G(option1319,"is-none",L[1006]);
var is_DASH_some628745 = G(option1319,"is-some",L[1006]);
var none6355 = G(option1319,"none",L[1006]);
var some6456 = G(option1319,"some",L[1006]);
var set658744 = G(sets1721,"set",L[1006]);
var tree_DASH_set6657 = G(sets1721,"tree-set",L[1006]);
var list_DASH_set678743 = G(sets1721,"list-set",L[1006]);
var DesugarEnvT26944 = R.namedBrander("DesugarEnv");
var DesugarEnv6843 = R.makeBranderAnn(DesugarEnvT26944,"DesugarEnv");
var PairT37147 = R.namedBrander("Pair");
var Pair7046 = R.makeBranderAnn(PairT37147,"Pair");
var anf_fun18742 = G(A113,"MakeName",L[1008]);
var $z87348735 = D;
var $f87408741 = function(_) {
return R.isFunction(anf_fun18742)?anf_fun18742.app((0)):R.ffi.throwNonFunApp(L[1007],anf_fun18742,[(0)]);
};
try {
if(--R.GAS > 0) {
$z87348735 = $f87408741();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87408741,
"from":L[1007]});
}
} catch($e87328733) {
if(R.isCont($e87328733)) {
var $ss87368737 = {"from":L[1007],
"go":function(names7242) {
return $Hnames203241(names7242,A113,A222,C624,DesugarEnv6843,DesugarEnvT26944,Option2045,PP314,Pair7046,PairT37147,Set2248,empty3049,fold5550,is_DASH_empty2851,link3152,list2753,lists1118,map3954,none6355,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11,$type$String12);
}};
$e87328733.stack[R.EXN_STACKHEIGHT++] = $ss87368737;
}
if(R.isPyretException($e87328733)) {
$e87328733.pyretStack.push(L[1007]);
}
throw $e87328733;
}
var $ret87388739 = $Hnames203241($z87348735,A113,A222,C624,DesugarEnv6843,DesugarEnvT26944,Option2045,PP314,Pair7046,PairT37147,Set2248,empty3049,fold5550,is_DASH_empty2851,link3152,list2753,lists1118,map3954,none6355,some6456,tree_DASH_set6657,_divide6,_plus7,builtins8,nothing9,raise10,torepr11,$type$String12);
++R.GAS;
return $ret87388739;
},function(moduleVal) {
R.modules["$src/arr/compiler/desugar.arr31"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/js-of-pyret.arr',["compiler/compile-structs.arr",
"trove/ast",
"compiler/anf.arr",
"compiler/ast-split.arr",
"compiler/anf-visitor-compiler.arr",
"compiler/desugar-check.arr",
"compiler/desugar.arr",
"compiler/ast-util.arr",
"compiler/js-ast.arr",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($C1938,$A31039,$N51140,$AS71241,$AV91342,$CH111443,$D131544,$AU151645,$J171746,$arrays191847,$lists211948,$option232049,$error252150,$sets272251) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/js-of-pyret.arr37"]) {
return R.modules["$src/arr/compiler/js-of-pyret.arr37"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/js-of-pyret.arr";
var D = R.undefined;
var L = [[M,15,0,365,29,3,814],
[M,46,9,1308,46,35,1334],
[M,47,26,1361,47,56,1391],
[M,47,26,1361,47,51,1386],
[M,47,14,1349,47,25,1360],
[M,47,2,1337,47,57,1392],
[M,48,45,1438,48,59,1452],
[M,48,9,1402,48,65,1458],
[M,49,2,1461,49,34,1493],
[M,49,23,1482,49,33,1492],
[M,49,10,1469,49,22,1481],
[M,50,9,1503,50,35,1529],
[M,51,25,1555,51,51,1581],
[M,51,25,1555,51,46,1576],
[M,51,13,1543,51,24,1554],
[M,51,2,1532,51,52,1582],
[M,52,24,1607,52,37,1620],
[M,43,0,1181,53,3,1630],
[M,39,25,1128,39,55,1158],
[M,39,25,1128,39,50,1153],
[M,39,13,1116,39,24,1127],
[M,39,2,1105,39,56,1159],
[M,37,0,993,41,3,1179],
[M,33,25,944,33,51,970],
[M,33,25,944,33,46,965],
[M,33,13,932,33,24,943],
[M,33,2,921,33,52,971],
[M,31,0,816,35,3,991],
[M,21,6,570,21,41,605],
[M,21,6,570,21,37,601],
[M,20,4,528,22,7,628],
[M,21,6,570,21,50,614],
[M,16,2,393,28,7,810],
[M,3,0,13,53,3,1630],
[M,45,2,1264,45,36,1298],
[M,45,10,1272,45,23,1285],
[M,38,2,1068,38,36,1102],
[M,38,10,1076,38,23,1089],
[M,32,2,884,32,36,918],
[M,32,10,892,32,23,905],
[M,16,4,395,16,28,419],
[M,16,20,411,16,27,418],
[M,26,4,722,28,7,810],
[M,27,6,762,27,37,793],
[M,27,6,762,27,19,775],
[M,23,4,634,25,7,716],
[M,24,6,678,24,34,706],
[M,24,6,678,24,19,691],
[M,21,6,570,21,30,594],
[M,21,6,570,21,28,592],
[M,21,6,570,21,19,583],
[M,17,4,430,19,7,522],
[M,16,8,399,16,27,418]];
var _plus3 = NAMESPACE.get("_plus");
var builtins4 = NAMESPACE.get("builtins");
var nothing5 = NAMESPACE.get("nothing");
var raise6 = NAMESPACE.get("raise");
var torepr7 = NAMESPACE.get("torepr");
var $type$String8 = NAMESPACE.get("$type$String");
var $Hanf_bracket10852 = function(anf_bracket7253,CompiledCodePrinter7854,provides7055,nothing5) {
var anf_fun7366 = G(anf_bracket7253,"results",L[0]);
var $z5859 = D;
var $f6465 = function(_) {
return R.isFunction(anf_fun7366)?anf_fun7366.app():R.ffi.throwNonFunApp(L[0],anf_fun7366,[]);
};
try {
if(--R.GAS > 0) {
$z5859 = $f6465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6465,
"from":L[0]});
}
} catch($e5657) {
if(R.isCont($e5657)) {
var $ss6061 = {"from":L[0],
"go":function(checks7467) {
return $Hchecks10768(checks7467,CompiledCodePrinter7854,provides7055,nothing5);
}};
$e5657.stack[R.EXN_STACKHEIGHT++] = $ss6061;
}
if(R.isPyretException($e5657)) {
$e5657.pyretStack.push(L[0]);
}
throw $e5657;
}
var $ret6263 = $Hchecks10768($z5859,CompiledCodePrinter7854,provides7055,nothing5);
++R.GAS;
return $ret6263;
};
var $Hchecks10768 = function(checks7467,CompiledCodePrinter7854,provides7055,nothing5) {
return R.makeObject({"answer":nothing5,
"provide-plus-types":R.makeObject({"values":provides7055,
"types":{"CompiledCodePrinter":CompiledCodePrinter7854}}),
"checks":checks7467});
};
var $Hanfed10669 = function(anfed10770,AS712,AV913,ccp8471,env10572,phase10373,ret10674) {
var $z7778 = D;
var $f8384 = function(_) {
return R.isFunction(phase10373)?phase10373.app(("ANFed"),anfed10770,ret10674.$var):R.ffi.throwNonFunApp(L[1],phase10373,[("ANFed"),anfed10770,ret10674.$var]);
};
try {
if(--R.GAS > 0) {
$z7778 = $f8384();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8384,
"from":L[1]});
}
} catch($e7576) {
if(R.isCont($e7576)) {
var $ss7980 = {"from":L[1],
"go":function(anf_assign5685) {
return $Hanf_assign10586(anf_assign5685,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
}};
$e7576.stack[R.EXN_STACKHEIGHT++] = $ss7980;
}
if(R.isPyretException($e7576)) {
$e7576.pyretStack.push(L[1]);
}
throw $e7576;
}
var $ret8182 = $Hanf_assign10586($z7778,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
++R.GAS;
return $ret8182;
};
var $Hanf_assign10586 = function(anf_assign5685,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674) {
ret10674.$var = anf_assign5685;
var anf_fun5799 = G(anfed10770,"visit",L[4]);
var anf_fun5897 = G(AV913,"non-splitting-compiler",L[3]);
var $z8990 = D;
var $f9596 = function(_) {
return R.isFunction(anf_fun5897)?anf_fun5897.app(env10572):R.ffi.throwNonFunApp(L[2],anf_fun5897,[env10572]);
};
try {
if(--R.GAS > 0) {
$z8990 = $f9596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9596,
"from":L[2]});
}
} catch($e8788) {
if(R.isCont($e8788)) {
var $ss9192 = {"from":L[2],
"go":function(anf_arg5998) {
return $Hanf_arg104100(anf_arg5998,AS712,AV913,anf_fun5799,anfed10770,ccp8471,env10572,phase10373,ret10674);
}};
$e8788.stack[R.EXN_STACKHEIGHT++] = $ss9192;
}
if(R.isPyretException($e8788)) {
$e8788.pyretStack.push(L[2]);
}
throw $e8788;
}
var $ret9394 = $Hanf_arg104100($z8990,AS712,AV913,anf_fun5799,anfed10770,ccp8471,env10572,phase10373,ret10674);
++R.GAS;
return $ret9394;
};
var $Hanf_arg104100 = function(anf_arg5998,AS712,AV913,anf_fun5799,anfed10770,ccp8471,env10572,phase10373,ret10674) {
var $z103104 = D;
var $f109110 = function(_) {
return R.isFunction(anf_fun5799)?anf_fun5799.app(anf_arg5998):R.ffi.throwNonFunApp(L[5],anf_fun5799,[anf_arg5998]);
};
try {
if(--R.GAS > 0) {
$z103104 = $f109110();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f109110,
"from":L[5]});
}
} catch($e101102) {
if(R.isCont($e101102)) {
var $ss105106 = {"from":L[5],
"go":function(non_DASH_split108111) {
return $Hnon_DASH_split103112(non_DASH_split108111,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
}};
$e101102.stack[R.EXN_STACKHEIGHT++] = $ss105106;
}
if(R.isPyretException($e101102)) {
$e101102.pyretStack.push(L[5]);
}
throw $e101102;
}
var $ret107108 = $Hnon_DASH_split103112($z103104,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
++R.GAS;
return $ret107108;
};
var $Hnon_DASH_split103112 = function(non_DASH_split108111,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674) {
var $z115116 = D;
var $f121122 = function(_) {
return R.isFunction(ccp8471.$var)?ccp8471.$var.app(non_DASH_split108111):R.ffi.throwNonFunApp(L[6],ccp8471.$var,[non_DASH_split108111]);
};
try {
if(--R.GAS > 0) {
$z115116 = $f121122();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f121122,
"from":L[6]});
}
} catch($e113114) {
if(R.isCont($e113114)) {
var $ss117118 = {"from":L[6],
"go":function(anf_arg60123) {
return $Hanf_arg102124(anf_arg60123,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
}};
$e113114.stack[R.EXN_STACKHEIGHT++] = $ss117118;
}
if(R.isPyretException($e113114)) {
$e113114.pyretStack.push(L[6]);
}
throw $e113114;
}
var $ret119120 = $Hanf_arg102124($z115116,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
++R.GAS;
return $ret119120;
};
var $Hanf_arg102124 = function(anf_arg60123,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674) {
var $z127128 = D;
var $f133134 = function(_) {
return R.isFunction(phase10373)?phase10373.app(("Non-stacksafe generated JS"),anf_arg60123,ret10674.$var):R.ffi.throwNonFunApp(L[7],phase10373,[("Non-stacksafe generated JS"),anf_arg60123,ret10674.$var]);
};
try {
if(--R.GAS > 0) {
$z127128 = $f133134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f133134,
"from":L[7]});
}
} catch($e125126) {
if(R.isCont($e125126)) {
var $ss129130 = {"from":L[7],
"go":function(anf_assign61135) {
return $Hanf_assign101136(anf_assign61135,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
}};
$e125126.stack[R.EXN_STACKHEIGHT++] = $ss129130;
}
if(R.isPyretException($e125126)) {
$e125126.pyretStack.push(L[7]);
}
throw $e125126;
}
var $ret131132 = $Hanf_assign101136($z127128,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
++R.GAS;
return $ret131132;
};
var $Hanf_assign101136 = function(anf_assign61135,AS712,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674) {
ret10674.$var = anf_assign61135;
var anf_fun62147 = G(AS712,"ast-split",L[10]);
var anf_arg63148 = G(anfed10770,"body",L[9]);
var $z139140 = D;
var $f145146 = function(_) {
return R.isFunction(anf_fun62147)?anf_fun62147.app(anf_arg63148):R.ffi.throwNonFunApp(L[8],anf_fun62147,[anf_arg63148]);
};
try {
if(--R.GAS > 0) {
$z139140 = $f145146();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f145146,
"from":L[8]});
}
} catch($e137138) {
if(R.isCont($e137138)) {
var $ss141142 = {"from":L[8],
"go":function(split109149) {
return $Hsplit100150(split109149,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
}};
$e137138.stack[R.EXN_STACKHEIGHT++] = $ss141142;
}
if(R.isPyretException($e137138)) {
$e137138.pyretStack.push(L[8]);
}
throw $e137138;
}
var $ret143144 = $Hsplit100150($z139140,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
++R.GAS;
return $ret143144;
};
var $Hsplit100150 = function(split109149,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674) {
var $z153154 = D;
var $f159160 = function(_) {
return R.isFunction(phase10373)?phase10373.app(("Split"),split109149,ret10674.$var):R.ffi.throwNonFunApp(L[11],phase10373,[("Split"),split109149,ret10674.$var]);
};
try {
if(--R.GAS > 0) {
$z153154 = $f159160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f159160,
"from":L[11]});
}
} catch($e151152) {
if(R.isCont($e151152)) {
var $ss155156 = {"from":L[11],
"go":function(anf_assign64161) {
return $Hanf_assign99162(anf_assign64161,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
}};
$e151152.stack[R.EXN_STACKHEIGHT++] = $ss155156;
}
if(R.isPyretException($e151152)) {
$e151152.pyretStack.push(L[11]);
}
throw $e151152;
}
var $ret157158 = $Hanf_assign99162($z153154,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674);
++R.GAS;
return $ret157158;
};
var $Hanf_assign99162 = function(anf_assign64161,AV913,anfed10770,ccp8471,env10572,phase10373,ret10674) {
ret10674.$var = anf_assign64161;
var anf_fun65175 = G(anfed10770,"visit",L[14]);
var anf_fun66173 = G(AV913,"splitting-compiler",L[13]);
var $z165166 = D;
var $f171172 = function(_) {
return R.isFunction(anf_fun66173)?anf_fun66173.app(env10572):R.ffi.throwNonFunApp(L[12],anf_fun66173,[env10572]);
};
try {
if(--R.GAS > 0) {
$z165166 = $f171172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f171172,
"from":L[12]});
}
} catch($e163164) {
if(R.isCont($e163164)) {
var $ss167168 = {"from":L[12],
"go":function(anf_arg67174) {
return $Hanf_arg98176(anf_arg67174,anf_fun65175,ccp8471,phase10373,ret10674);
}};
$e163164.stack[R.EXN_STACKHEIGHT++] = $ss167168;
}
if(R.isPyretException($e163164)) {
$e163164.pyretStack.push(L[12]);
}
throw $e163164;
}
var $ret169170 = $Hanf_arg98176($z165166,anf_fun65175,ccp8471,phase10373,ret10674);
++R.GAS;
return $ret169170;
};
var $Hanf_arg98176 = function(anf_arg67174,anf_fun65175,ccp8471,phase10373,ret10674) {
var $z179180 = D;
var $f185186 = function(_) {
return R.isFunction(anf_fun65175)?anf_fun65175.app(anf_arg67174):R.ffi.throwNonFunApp(L[15],anf_fun65175,[anf_arg67174]);
};
try {
if(--R.GAS > 0) {
$z179180 = $f185186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f185186,
"from":L[15]});
}
} catch($e177178) {
if(R.isCont($e177178)) {
var $ss181182 = {"from":L[15],
"go":function(compiled110187) {
return $Hcompiled97188(compiled110187,ccp8471,phase10373,ret10674);
}};
$e177178.stack[R.EXN_STACKHEIGHT++] = $ss181182;
}
if(R.isPyretException($e177178)) {
$e177178.pyretStack.push(L[15]);
}
throw $e177178;
}
var $ret183184 = $Hcompiled97188($z179180,ccp8471,phase10373,ret10674);
++R.GAS;
return $ret183184;
};
var $Hcompiled97188 = function(compiled110187,ccp8471,phase10373,ret10674) {
var $z191192 = D;
var $f197198 = function(_) {
return R.isFunction(ccp8471.$var)?ccp8471.$var.app(compiled110187):R.ffi.throwNonFunApp(L[16],ccp8471.$var,[compiled110187]);
};
try {
if(--R.GAS > 0) {
$z191192 = $f197198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f197198,
"from":L[16]});
}
} catch($e189190) {
if(R.isCont($e189190)) {
var $ss193194 = {"from":L[16],
"go":function(anf_arg68199) {
return $Hanf_arg96200(anf_arg68199,phase10373,ret10674);
}};
$e189190.stack[R.EXN_STACKHEIGHT++] = $ss193194;
}
if(R.isPyretException($e189190)) {
$e189190.pyretStack.push(L[16]);
}
throw $e189190;
}
var $ret195196 = $Hanf_arg96200($z191192,phase10373,ret10674);
++R.GAS;
return $ret195196;
};
var $Hanf_arg96200 = function(anf_arg68199,phase10373,ret10674) {
var $z203204 = D;
var $f209210 = function(_) {
return R.isFunction(phase10373)?phase10373.app(("Generated JS"),anf_arg68199,ret10674.$var):R.ffi.throwNonFunApp(L[17],phase10373,[("Generated JS"),anf_arg68199,ret10674.$var]);
};
try {
if(--R.GAS > 0) {
$z203204 = $f209210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f209210,
"from":L[17]});
}
} catch($e201202) {
if(R.isCont($e201202)) {
var $ss205206 = {"from":L[17],
"go":function(ann_DASH_check_DASH_temp54211) {
return $Hann_DASH_check_DASH_temp95212(ann_DASH_check_DASH_temp54211);
}};
$e201202.stack[R.EXN_STACKHEIGHT++] = $ss205206;
}
if(R.isPyretException($e201202)) {
$e201202.pyretStack.push(L[17]);
}
throw $e201202;
}
var $ret207208 = $Hann_DASH_check_DASH_temp95212($z203204);
++R.GAS;
return $ret207208;
};
var $Hann_DASH_check_DASH_temp95212 = function(ann_DASH_check_DASH_temp54211) {
return ann_DASH_check_DASH_temp54211;
};
var $Hanfed94213 = function(anfed100214,AV913,CompiledCodePrinter7854,ccp8471,env99215) {
var anf_fun50228 = G(anfed100214,"visit",L[20]);
var anf_fun51226 = G(AV913,"non-splitting-compiler",L[19]);
var $z218219 = D;
var $f224225 = function(_) {
return R.isFunction(anf_fun51226)?anf_fun51226.app(env99215):R.ffi.throwNonFunApp(L[18],anf_fun51226,[env99215]);
};
try {
if(--R.GAS > 0) {
$z218219 = $f224225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f224225,
"from":L[18]});
}
} catch($e216217) {
if(R.isCont($e216217)) {
var $ss220221 = {"from":L[18],
"go":function(anf_arg52227) {
return $Hanf_arg93229(anf_arg52227,CompiledCodePrinter7854,anf_fun50228,ccp8471);
}};
$e216217.stack[R.EXN_STACKHEIGHT++] = $ss220221;
}
if(R.isPyretException($e216217)) {
$e216217.pyretStack.push(L[18]);
}
throw $e216217;
}
var $ret222223 = $Hanf_arg93229($z218219,CompiledCodePrinter7854,anf_fun50228,ccp8471);
++R.GAS;
return $ret222223;
};
var $Hanf_arg93229 = function(anf_arg52227,CompiledCodePrinter7854,anf_fun50228,ccp8471) {
var $z232233 = D;
var $f238239 = function(_) {
return R.isFunction(anf_fun50228)?anf_fun50228.app(anf_arg52227):R.ffi.throwNonFunApp(L[21],anf_fun50228,[anf_arg52227]);
};
try {
if(--R.GAS > 0) {
$z232233 = $f238239();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f238239,
"from":L[21]});
}
} catch($e230231) {
if(R.isCont($e230231)) {
var $ss234235 = {"from":L[21],
"go":function(compiled101240) {
return $Hcompiled92241(compiled101240,CompiledCodePrinter7854,ccp8471);
}};
$e230231.stack[R.EXN_STACKHEIGHT++] = $ss234235;
}
if(R.isPyretException($e230231)) {
$e230231.pyretStack.push(L[21]);
}
throw $e230231;
}
var $ret236237 = $Hcompiled92241($z232233,CompiledCodePrinter7854,ccp8471);
++R.GAS;
return $ret236237;
};
var $Hcompiled92241 = function(compiled101240,CompiledCodePrinter7854,ccp8471) {
var $z244245 = D;
var $f250251 = function(_) {
return R.isFunction(ccp8471.$var)?ccp8471.$var.app(compiled101240):R.ffi.throwNonFunApp(L[22],ccp8471.$var,[compiled101240]);
};
try {
if(--R.GAS > 0) {
$z244245 = $f250251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f250251,
"from":L[22]});
}
} catch($e242243) {
if(R.isCont($e242243)) {
var $ss246247 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp48252) {
return $Hann_DASH_check_DASH_temp91253(ann_DASH_check_DASH_temp48252,CompiledCodePrinter7854);
}};
$e242243.stack[R.EXN_STACKHEIGHT++] = $ss246247;
}
if(R.isPyretException($e242243)) {
$e242243.pyretStack.push(L[22]);
}
throw $e242243;
}
var $ret248249 = $Hann_DASH_check_DASH_temp91253($z244245,CompiledCodePrinter7854);
++R.GAS;
return $ret248249;
};
var $Hann_DASH_check_DASH_temp91253 = function(ann_DASH_check_DASH_temp48252,CompiledCodePrinter7854) {
return ann_DASH_check_DASH_temp48252;
};
var $Hanfed90254 = function(anfed96255,AV913,CompiledCodePrinter7854,ccp8471,env95256) {
var anf_fun44269 = G(anfed96255,"visit",L[25]);
var anf_fun45267 = G(AV913,"splitting-compiler",L[24]);
var $z259260 = D;
var $f265266 = function(_) {
return R.isFunction(anf_fun45267)?anf_fun45267.app(env95256):R.ffi.throwNonFunApp(L[23],anf_fun45267,[env95256]);
};
try {
if(--R.GAS > 0) {
$z259260 = $f265266();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f265266,
"from":L[23]});
}
} catch($e257258) {
if(R.isCont($e257258)) {
var $ss261262 = {"from":L[23],
"go":function(anf_arg46268) {
return $Hanf_arg89270(anf_arg46268,CompiledCodePrinter7854,anf_fun44269,ccp8471);
}};
$e257258.stack[R.EXN_STACKHEIGHT++] = $ss261262;
}
if(R.isPyretException($e257258)) {
$e257258.pyretStack.push(L[23]);
}
throw $e257258;
}
var $ret263264 = $Hanf_arg89270($z259260,CompiledCodePrinter7854,anf_fun44269,ccp8471);
++R.GAS;
return $ret263264;
};
var $Hanf_arg89270 = function(anf_arg46268,CompiledCodePrinter7854,anf_fun44269,ccp8471) {
var $z273274 = D;
var $f279280 = function(_) {
return R.isFunction(anf_fun44269)?anf_fun44269.app(anf_arg46268):R.ffi.throwNonFunApp(L[26],anf_fun44269,[anf_arg46268]);
};
try {
if(--R.GAS > 0) {
$z273274 = $f279280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f279280,
"from":L[26]});
}
} catch($e271272) {
if(R.isCont($e271272)) {
var $ss275276 = {"from":L[26],
"go":function(compiled97188) {
return $Hcompiled88281(compiled97188,CompiledCodePrinter7854,ccp8471);
}};
$e271272.stack[R.EXN_STACKHEIGHT++] = $ss275276;
}
if(R.isPyretException($e271272)) {
$e271272.pyretStack.push(L[26]);
}
throw $e271272;
}
var $ret277278 = $Hcompiled88281($z273274,CompiledCodePrinter7854,ccp8471);
++R.GAS;
return $ret277278;
};
var $Hcompiled88281 = function(compiled97188,CompiledCodePrinter7854,ccp8471) {
var $z284285 = D;
var $f290291 = function(_) {
return R.isFunction(ccp8471.$var)?ccp8471.$var.app(compiled97188):R.ffi.throwNonFunApp(L[27],ccp8471.$var,[compiled97188]);
};
try {
if(--R.GAS > 0) {
$z284285 = $f290291();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f290291,
"from":L[27]});
}
} catch($e282283) {
if(R.isCont($e282283)) {
var $ss286287 = {"from":L[27],
"go":function(ann_DASH_check_DASH_temp42292) {
return $Hann_DASH_check_DASH_temp87293(ann_DASH_check_DASH_temp42292,CompiledCodePrinter7854);
}};
$e282283.stack[R.EXN_STACKHEIGHT++] = $ss286287;
}
if(R.isPyretException($e282283)) {
$e282283.pyretStack.push(L[27]);
}
throw $e282283;
}
var $ret288289 = $Hann_DASH_check_DASH_temp87293($z284285,CompiledCodePrinter7854);
++R.GAS;
return $ret288289;
};
var $Hann_DASH_check_DASH_temp87293 = function(ann_DASH_check_DASH_temp42292,CompiledCodePrinter7854) {
return ann_DASH_check_DASH_temp42292;
};
var $Hann_DASH_check_DASH_temp86294 = function(ann_DASH_check_DASH_temp33295) {
return ann_DASH_check_DASH_temp33295;
};
var $Hann_DASH_check_DASH_temp85296 = function(ann_DASH_check_DASH_temp29297,$type$String8) {
return ann_DASH_check_DASH_temp29297;
};
var $Hanf_bracket84298 = function(anf_bracket24299,$type$String8) {
var anf_fun25310 = G(anf_bracket24299,"pretty",L[29]);
var $z302303 = D;
var $f308309 = function(_) {
return R.isFunction(anf_fun25310)?anf_fun25310.app((80)):R.ffi.throwNonFunApp(L[28],anf_fun25310,[(80)]);
};
try {
if(--R.GAS > 0) {
$z302303 = $f308309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f308309,
"from":L[28]});
}
} catch($e300301) {
if(R.isCont($e300301)) {
var $ss304305 = {"from":L[28],
"go":function(anf_bracket26311) {
return $Hanf_bracket83312(anf_bracket26311,$type$String8);
}};
$e300301.stack[R.EXN_STACKHEIGHT++] = $ss304305;
}
if(R.isPyretException($e300301)) {
$e300301.pyretStack.push(L[28]);
}
throw $e300301;
}
var $ret306307 = $Hanf_bracket83312($z302303,$type$String8);
++R.GAS;
return $ret306307;
};
var $Hanf_bracket83312 = function(anf_bracket26311,$type$String8) {
var anf_fun27323 = G(anf_bracket26311,"join-str",L[31]);
var $z315316 = D;
var $f321322 = function(_) {
return R.isFunction(anf_fun27323)?anf_fun27323.app(("\n")):R.ffi.throwNonFunApp(L[30],anf_fun27323,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z315316 = $f321322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f321322,
"from":L[30]});
}
} catch($e313314) {
if(R.isCont($e313314)) {
var $ss317318 = {"from":L[30],
"go":function(ann_DASH_check_DASH_temp21324) {
return $Hann_DASH_check_DASH_temp82325(ann_DASH_check_DASH_temp21324,$type$String8);
}};
$e313314.stack[R.EXN_STACKHEIGHT++] = $ss317318;
}
if(R.isPyretException($e313314)) {
$e313314.pyretStack.push(L[30]);
}
throw $e313314;
}
var $ret319320 = $Hann_DASH_check_DASH_temp82325($z315316,$type$String8);
++R.GAS;
return $ret319320;
};
var $Hann_DASH_check_DASH_temp82325 = function(ann_DASH_check_DASH_temp21324,$type$String8) {
return ann_DASH_check_DASH_temp21324;
};
var $Hann_DASH_check_DASH_temp81326 = function(ann_DASH_check_DASH_temp19327,$type$String8) {
return ann_DASH_check_DASH_temp19327;
};
var $Hanf_arg80328 = function(anf_arg15329,_plus3) {
var $z332333 = D;
var $f338339 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg15329,(")")):R.ffi.throwNonFunApp(L[32],_plus3,[anf_arg15329,(")")]);
};
try {
if(--R.GAS > 0) {
$z332333 = $f338339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f338339,
"from":L[32]});
}
} catch($e330331) {
if(R.isCont($e330331)) {
var $ss334335 = {"from":L[32],
"go":function(anf_arg16340) {
return $Hanf_arg79341(anf_arg16340,_plus3);
}};
$e330331.stack[R.EXN_STACKHEIGHT++] = $ss334335;
}
if(R.isPyretException($e330331)) {
$e330331.pyretStack.push(L[32]);
}
throw $e330331;
}
var $ret336337 = $Hanf_arg79341($z332333,_plus3);
++R.GAS;
return $ret336337;
};
var $Hanf_arg79341 = function(anf_arg16340,_plus3) {
var $z344345 = D;
var $f350351 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("("),anf_arg16340):R.ffi.throwNonFunApp(L[32],_plus3,[("("),anf_arg16340]);
};
try {
if(--R.GAS > 0) {
$z344345 = $f350351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f350351,
"from":L[32]});
}
} catch($e342343) {
if(R.isCont($e342343)) {
var $ss346347 = {"from":L[32],
"go":function(anf_arg17352) {
return $Hanf_arg78353(anf_arg17352,_plus3);
}};
$e342343.stack[R.EXN_STACKHEIGHT++] = $ss346347;
}
if(R.isPyretException($e342343)) {
$e342343.pyretStack.push(L[32]);
}
throw $e342343;
}
var $ret348349 = $Hanf_arg78353($z344345,_plus3);
++R.GAS;
return $ret348349;
};
var $Hanf_arg78353 = function(anf_arg17352,_plus3) {
var $z356357 = D;
var $f362363 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("ccp"),anf_arg17352):R.ffi.throwNonFunApp(L[32],_plus3,[("ccp"),anf_arg17352]);
};
try {
if(--R.GAS > 0) {
$z356357 = $f362363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f362363,
"from":L[32]});
}
} catch($e354355) {
if(R.isCont($e354355)) {
var $ss358359 = {"from":L[32],
"go":function(ann_DASH_check_DASH_temp13364) {
return $Hann_DASH_check_DASH_temp77365(ann_DASH_check_DASH_temp13364);
}};
$e354355.stack[R.EXN_STACKHEIGHT++] = $ss358359;
}
if(R.isPyretException($e354355)) {
$e354355.pyretStack.push(L[32]);
}
throw $e354355;
}
var $ret360361 = $Hann_DASH_check_DASH_temp77365($z356357);
++R.GAS;
return $ret360361;
};
var $Hann_DASH_check_DASH_temp77365 = function(ann_DASH_check_DASH_temp13364) {
return ann_DASH_check_DASH_temp13364;
};
var $Hcont_tail_arg75366 = function(cont_tail_arg10367,if_helper2368) {
if(--R.GAS > 0) {
$z369370 = R.isFunction(if_helper2368)?if_helper2368.app(cont_tail_arg10367):R.ffi.throwNonFunApp(L[32],if_helper2368,[cont_tail_arg10367]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored371) {
return R.isFunction(if_helper2368)?if_helper2368.app(cont_tail_arg10367):R.ffi.throwNonFunApp(L[32],if_helper2368,[cont_tail_arg10367]);
},
"from":L[32]});
}
++R.GAS;
return $z369370;
};
var $Hcont_tail_arg76372 = function(cont_tail_arg7373,if_helper2368) {
if(--R.GAS > 0) {
$z374375 = R.isFunction(if_helper2368)?if_helper2368.app(cont_tail_arg7373):R.ffi.throwNonFunApp(L[32],if_helper2368,[cont_tail_arg7373]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored371) {
return R.isFunction(if_helper2368)?if_helper2368.app(cont_tail_arg7373):R.ffi.throwNonFunApp(L[32],if_helper2368,[cont_tail_arg7373]);
},
"from":L[32]});
}
++R.GAS;
return $z374375;
};
return R.loadModulesNew(NAMESPACE,[$C1938,$A31039,$N51140,$AS71241,$AV91342,$CH111443,$D131544,$AU151645,$J171746,$arrays191847,$lists211948,$option232049,$error252150,$sets272251],function($C1938,$A31039,$N51140,$AS71241,$AV91342,$CH111443,$D131544,$AU151645,$J171746,$arrays191847,$lists211948,$option232049,$error252150,$sets272251) {
var C19 = R.getField($C1938,"values");
var A310 = R.getField($A31039,"values");
var N511 = R.getField($N51140,"values");
var AS712 = R.getField($AS71241,"values");
var AV913 = R.getField($AV91342,"values");
var CH1114 = R.getField($CH111443,"values");
var D1315 = R.getField($D131544,"values");
var AU1516 = R.getField($AU151645,"values");
var J1717 = R.getField($J171746,"values");
var arrays1918 = R.getField($arrays191847,"values");
var lists2119 = R.getField($lists211948,"values");
var option2320 = R.getField($option232049,"values");
var error2521 = R.getField($error252150,"values");
var sets2722 = R.getField($sets272251,"values");
var C223 = R.getField($C1938,"types");
var A424 = R.getField($A31039,"types");
var N625 = R.getField($N51140,"types");
var AS826 = R.getField($AS71241,"types");
var AV1027 = R.getField($AV91342,"types");
var CH1228 = R.getField($CH111443,"types");
var D1429 = R.getField($D131544,"types");
var AU1630 = R.getField($AU151645,"types");
var J1831 = R.getField($J171746,"types");
var arrays2032 = R.getField($arrays191847,"types");
var lists2233 = R.getField($lists211948,"types");
var option2434 = R.getField($option232049,"types");
var error2635 = R.getField($error252150,"types");
var sets2836 = R.getField($sets272251,"types");
return R.safeCall(function() {
var List29376 = R.getDotAnn(L[33],"lists",lists2233,"List");
var Option30377 = R.getDotAnn(L[33],"option",option2434,"Option");
var Array31378 = R.getDotAnn(L[33],"arrays",arrays2032,"Array");
var Set32379 = R.getDotAnn(L[33],"sets",sets2836,"Set");
var array33594 = G(arrays1918,"array",L[33]);
var build_DASH_array34593 = G(arrays1918,"build-array",L[33]);
var array_DASH_from_DASH_list35592 = G(arrays1918,"array-from-list",L[33]);
var is_DASH_array36591 = G(arrays1918,"is-array",L[33]);
var list37590 = G(lists2119,"list",L[33]);
var is_DASH_empty38589 = G(lists2119,"is-empty",L[33]);
var is_DASH_link39588 = G(lists2119,"is-link",L[33]);
var empty40587 = G(lists2119,"empty",L[33]);
var link41586 = G(lists2119,"link",L[33]);
var range42585 = G(lists2119,"range",L[33]);
var repeat43584 = G(lists2119,"repeat",L[33]);
var filter44583 = G(lists2119,"filter",L[33]);
var partition45582 = G(lists2119,"partition",L[33]);
var split_DASH_at46581 = G(lists2119,"split-at",L[33]);
var any47580 = G(lists2119,"any",L[33]);
var find48579 = G(lists2119,"find",L[33]);
var map49578 = G(lists2119,"map",L[33]);
var map250577 = G(lists2119,"map2",L[33]);
var map351576 = G(lists2119,"map3",L[33]);
var map452575 = G(lists2119,"map4",L[33]);
var map_n53574 = G(lists2119,"map_n",L[33]);
var map2_n54573 = G(lists2119,"map2_n",L[33]);
var map3_n55572 = G(lists2119,"map3_n",L[33]);
var map4_n56571 = G(lists2119,"map4_n",L[33]);
var each57570 = G(lists2119,"each",L[33]);
var each258569 = G(lists2119,"each2",L[33]);
var each359568 = G(lists2119,"each3",L[33]);
var each460567 = G(lists2119,"each4",L[33]);
var each_n61566 = G(lists2119,"each_n",L[33]);
var each2_n62565 = G(lists2119,"each2_n",L[33]);
var each3_n63564 = G(lists2119,"each3_n",L[33]);
var each4_n64563 = G(lists2119,"each4_n",L[33]);
var fold65562 = G(lists2119,"fold",L[33]);
var fold266561 = G(lists2119,"fold2",L[33]);
var fold367560 = G(lists2119,"fold3",L[33]);
var fold468559 = G(lists2119,"fold4",L[33]);
var index69558 = G(lists2119,"index",L[33]);
var Option70557 = G(option2320,"Option",L[33]);
var is_DASH_none71556 = G(option2320,"is-none",L[33]);
var is_DASH_some72555 = G(option2320,"is-some",L[33]);
var none73554 = G(option2320,"none",L[33]);
var some74553 = G(option2320,"some",L[33]);
var set75552 = G(sets2722,"set",L[33]);
var tree_DASH_set76551 = G(sets2722,"tree-set",L[33]);
var list_DASH_set77550 = G(sets2722,"list-set",L[33]);
var CompiledCodePrinterT179380 = R.namedBrander("CompiledCodePrinter");
var CompiledCodePrinter7854 = R.makeBranderAnn(CompiledCodePrinterT179380,"CompiledCodePrinter");
var CompiledCodePrinter280381 = {"$var":D,
"$name":"CompiledCodePrinter2"};
var CompiledCodePrinter81383 = {"$var":D,
"$name":"CompiledCodePrinter"};
var is_DASH_CompiledCodePrinter82385 = {"$var":D,
"$name":"is-CompiledCodePrinter"};
var is_DASH_ccp83387 = {"$var":D,
"$name":"is-ccp"};
var ccp8471 = {"$var":D,
"$name":"ccp"};
var make_DASH_compiled_DASH_pyret85390 = {"$var":D,
"$name":"make-compiled-pyret"};
var make_DASH_unsafe_DASH_compiled_DASH_pyret86392 = {"$var":D,
"$name":"make-unsafe-compiled-pyret"};
var trace_DASH_make_DASH_compiled_DASH_pyret87394 = {"$var":D,
"$name":"trace-make-compiled-pyret"};
var anf_variant_member12449 = R.makeMethod(function(self2530) {
return function(cases_DASH_funs3531,else_DASH_clause4542) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[32],2,arguments);
}
var if_DASH_6543 = R.hasField(cases_DASH_funs3531,("ccp"));
var if_helper2368 = R.makeFunction(function(if_helper_arg3548) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[32],1,arguments);
}
var ann_DASH_check_DASH_temp1549 = if_helper_arg3548;
return ann_DASH_check_DASH_temp1549;
});
var anf_if6547 = R.isBoolean(if_DASH_6543);
if(R.isPyretTrue(anf_if6547)) {
if(R.isPyretTrue(if_DASH_6543)) {
var call_DASH_ccp1528 = G(cases_DASH_funs3531,"ccp",L[32]);
var anf_arg9529 = G(self2530,"compiled",L[52]);
var $z520521 = D;
var $f526527 = function(_) {
return R.isFunction(call_DASH_ccp1528)?call_DASH_ccp1528.app(anf_arg9529):R.ffi.throwNonFunApp(L[32],call_DASH_ccp1528,[anf_arg9529]);
};
try {
if(--R.GAS > 0) {
$z520521 = $f526527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f526527,
"from":L[32]});
}
} catch($e518519) {
if(R.isCont($e518519)) {
var $ss522523 = {"from":L[32],
"go":function(cont_tail_arg10367) {
return $Hcont_tail_arg75366(cont_tail_arg10367,if_helper2368);
}};
$e518519.stack[R.EXN_STACKHEIGHT++] = $ss522523;
}
if(R.isPyretException($e518519)) {
$e518519.pyretStack.push(L[32]);
}
throw $e518519;
}
var $ret524525 = $Hcont_tail_arg75366($z520521,if_helper2368);
++R.GAS;
return $ret524525;
} else {
var $z534535 = D;
var $f540541 = function(_) {
return R.isFunction(else_DASH_clause4542)?else_DASH_clause4542.app():R.ffi.throwNonFunApp(L[32],else_DASH_clause4542,[]);
};
try {
if(--R.GAS > 0) {
$z534535 = $f540541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f540541,
"from":L[32]});
}
} catch($e532533) {
if(R.isCont($e532533)) {
var $ss536537 = {"from":L[32],
"go":function(cont_tail_arg7373) {
return $Hcont_tail_arg76372(cont_tail_arg7373,if_helper2368);
}};
$e532533.stack[R.EXN_STACKHEIGHT++] = $ss536537;
}
if(R.isPyretException($e532533)) {
$e532533.pyretStack.push(L[32]);
}
throw $e532533;
}
var $ret538539 = $Hcont_tail_arg76372($z534535,if_helper2368);
++R.GAS;
return $ret538539;
}
} else {
var cont_tail_arg4546 = R.throwNonBooleanCondition(L[32],("if"),if_DASH_6543);
if(--R.GAS > 0) {
$z544545 = R.isFunction(if_helper2368)?if_helper2368.app(cont_tail_arg4546):R.ffi.throwNonFunApp(L[32],if_helper2368,[cont_tail_arg4546]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored371) {
return R.isFunction(if_helper2368)?if_helper2368.app(cont_tail_arg4546):R.ffi.throwNonFunApp(L[32],if_helper2368,[cont_tail_arg4546]);
},
"from":L[32]});
}
++R.GAS;
return $z544545;
}
};
},{"length":3});
var anf_variant_member18450 = R.makeMethod(function(self5517) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[32],0,arguments);
}
var anf_arg14516 = G(self5517,"compiled",L[32]);
var $z508509 = D;
var $f514515 = function(_) {
return R.isFunction(torepr7)?torepr7.app(anf_arg14516):R.ffi.throwNonFunApp(L[32],torepr7,[anf_arg14516]);
};
try {
if(--R.GAS > 0) {
$z508509 = $f514515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f514515,
"from":L[32]});
}
} catch($e506507) {
if(R.isCont($e506507)) {
var $ss510511 = {"from":L[32],
"go":function(anf_arg15329) {
return $Hanf_arg80328(anf_arg15329,_plus3);
}};
$e506507.stack[R.EXN_STACKHEIGHT++] = $ss510511;
}
if(R.isPyretException($e506507)) {
$e506507.pyretStack.push(L[32]);
}
throw $e506507;
}
var $ret512513 = $Hanf_arg80328($z508509,_plus3);
++R.GAS;
return $ret512513;
};
},{"length":1});
var anf_variant_member20451 = R.makeMethod(function(self89505) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[51],0,arguments);
}
var $z497498 = D;
var $f503504 = function(_) {
return R.isFunction(raise6)?raise6.app(("Cannot generate standalone JS")):R.ffi.throwNonFunApp(L[51],raise6,[("Cannot generate standalone JS")]);
};
try {
if(--R.GAS > 0) {
$z497498 = $f503504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f503504,
"from":L[51]});
}
} catch($e495496) {
if(R.isCont($e495496)) {
var $ss499500 = {"from":L[51],
"go":function(ann_DASH_check_DASH_temp19327) {
return $Hann_DASH_check_DASH_temp81326(ann_DASH_check_DASH_temp19327,$type$String8);
}};
$e495496.stack[R.EXN_STACKHEIGHT++] = $ss499500;
}
if(R.isPyretException($e495496)) {
$e495496.pyretStack.push(L[51]);
}
throw $e495496;
}
var $ret501502 = $Hann_DASH_check_DASH_temp81326($z497498,$type$String8);
++R.GAS;
return $ret501502;
};
},{"length":1});
var anf_variant_member28452 = R.makeMethod(function(self90494) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[30],0,arguments);
}
var anf_bracket22493 = G(self90494,"compiled",L[50]);
var anf_fun23492 = G(anf_bracket22493,"tosource",L[49]);
var $z484485 = D;
var $f490491 = function(_) {
return R.isFunction(anf_fun23492)?anf_fun23492.app():R.ffi.throwNonFunApp(L[48],anf_fun23492,[]);
};
try {
if(--R.GAS > 0) {
$z484485 = $f490491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f490491,
"from":L[48]});
}
} catch($e482483) {
if(R.isCont($e482483)) {
var $ss486487 = {"from":L[48],
"go":function(anf_bracket24299) {
return $Hanf_bracket84298(anf_bracket24299,$type$String8);
}};
$e482483.stack[R.EXN_STACKHEIGHT++] = $ss486487;
}
if(R.isPyretException($e482483)) {
$e482483.pyretStack.push(L[48]);
}
throw $e482483;
}
var $ret488489 = $Hanf_bracket84298($z484485,$type$String8);
++R.GAS;
return $ret488489;
};
},{"length":1});
var anf_variant_member32453 = R.makeMethod(function(self91481) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[45],0,arguments);
}
var anf_bracket30480 = G(self91481,"compiled",L[47]);
var anf_fun31479 = G(anf_bracket30480,"to-ugly-source",L[46]);
var $z471472 = D;
var $f477478 = function(_) {
return R.isFunction(anf_fun31479)?anf_fun31479.app():R.ffi.throwNonFunApp(L[45],anf_fun31479,[]);
};
try {
if(--R.GAS > 0) {
$z471472 = $f477478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f477478,
"from":L[45]});
}
} catch($e469470) {
if(R.isCont($e469470)) {
var $ss473474 = {"from":L[45],
"go":function(ann_DASH_check_DASH_temp29297) {
return $Hann_DASH_check_DASH_temp85296(ann_DASH_check_DASH_temp29297,$type$String8);
}};
$e469470.stack[R.EXN_STACKHEIGHT++] = $ss473474;
}
if(R.isPyretException($e469470)) {
$e469470.pyretStack.push(L[45]);
}
throw $e469470;
}
var $ret475476 = $Hann_DASH_check_DASH_temp85296($z471472,$type$String8);
++R.GAS;
return $ret475476;
};
},{"length":1});
var anf_variant_member36454 = R.makeMethod(function(self92468) {
return function(printer93466) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[42],1,arguments);
}
var anf_bracket34467 = G(self92468,"compiled",L[44]);
var anf_fun35465 = G(anf_bracket34467,"print-ugly-source",L[43]);
var $z457458 = D;
var $f463464 = function(_) {
return R.isFunction(anf_fun35465)?anf_fun35465.app(printer93466):R.ffi.throwNonFunApp(L[42],anf_fun35465,[printer93466]);
};
try {
if(--R.GAS > 0) {
$z457458 = $f463464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f463464,
"from":L[42]});
}
} catch($e455456) {
if(R.isCont($e455456)) {
var $ss459460 = {"from":L[42],
"go":function(ann_DASH_check_DASH_temp33295) {
return $Hann_DASH_check_DASH_temp86294(ann_DASH_check_DASH_temp33295);
}};
$e455456.stack[R.EXN_STACKHEIGHT++] = $ss459460;
}
if(R.isPyretException($e455456)) {
$e455456.pyretStack.push(L[42]);
}
throw $e455456;
}
var $ret461462 = $Hann_DASH_check_DASH_temp86294($z457458);
++R.GAS;
return $ret461462;
};
},{"length":2});
var anf_assign37382 = (function() {
var $ccp_DASH_base444445 = {"_match":anf_variant_member12449,
"_torepr":anf_variant_member18450,
"pyret-to-js-standalone":anf_variant_member20451,
"pyret-to-js-pretty":anf_variant_member28452,
"pyret-to-js-runnable":anf_variant_member32453,
"print-js-runnable":anf_variant_member36454};
var $ccp_DASH_brands447448 = {"$brand-ccp446":true};
$ccp_DASH_brands447448[CompiledCodePrinterT179380._brand] = true
return R.makeObject({"CompiledCodePrinter":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CompiledCodePrinterT179380._brand));
}),
"is-ccp":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[32],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-ccp446"));
}),
"ccp":R.makeFunction(function(compiled88281) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[40],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[41],"J",J1831,"JExpr")],[compiled88281],[L[41]],function() {
var dict = R.create($ccp_DASH_base444445);
dict["compiled"] = compiled88281
return R.makeBrandedObject(dict,$ccp_DASH_brands447448);
});
})});
})();
CompiledCodePrinter280381.$var = anf_assign37382;
var anf_assign38384 = G(CompiledCodePrinter280381.$var,"CompiledCodePrinter",L[0]);
CompiledCodePrinter81383.$var = anf_assign38384;
var anf_assign39386 = G(CompiledCodePrinter280381.$var,"CompiledCodePrinter",L[0]);
is_DASH_CompiledCodePrinter82385.$var = anf_assign39386;
var anf_assign40388 = G(CompiledCodePrinter280381.$var,"is-ccp",L[32]);
is_DASH_ccp83387.$var = anf_assign40388;
var anf_assign41389 = G(CompiledCodePrinter280381.$var,"ccp",L[32]);
ccp8471.$var = anf_assign41389;
var anf_assign47391 = R.makeFunction(function(program_DASH_ast94432,env95256) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[27],2,arguments);
}
var anf_fun43443 = G(N511,"anf-program",L[39]);
var $z435436 = D;
var $f441442 = function(_) {
return R.isFunction(anf_fun43443)?anf_fun43443.app(program_DASH_ast94432):R.ffi.throwNonFunApp(L[38],anf_fun43443,[program_DASH_ast94432]);
};
try {
if(--R.GAS > 0) {
$z435436 = $f441442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f441442,
"from":L[38]});
}
} catch($e433434) {
if(R.isCont($e433434)) {
var $ss437438 = {"from":L[38],
"go":function(anfed96255) {
return $Hanfed90254(anfed96255,AV913,CompiledCodePrinter7854,ccp8471,env95256);
}};
$e433434.stack[R.EXN_STACKHEIGHT++] = $ss437438;
}
if(R.isPyretException($e433434)) {
$e433434.pyretStack.push(L[38]);
}
throw $e433434;
}
var $ret439440 = $Hanfed90254($z435436,AV913,CompiledCodePrinter7854,ccp8471,env95256);
++R.GAS;
return $ret439440;
});
make_DASH_compiled_DASH_pyret85390.$var = anf_assign47391;
var anf_assign53393 = R.makeFunction(function(program_DASH_ast98420,env99215) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[22],2,arguments);
}
var anf_fun49431 = G(N511,"anf-program",L[37]);
var $z423424 = D;
var $f429430 = function(_) {
return R.isFunction(anf_fun49431)?anf_fun49431.app(program_DASH_ast98420):R.ffi.throwNonFunApp(L[36],anf_fun49431,[program_DASH_ast98420]);
};
try {
if(--R.GAS > 0) {
$z423424 = $f429430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f429430,
"from":L[36]});
}
} catch($e421422) {
if(R.isCont($e421422)) {
var $ss425426 = {"from":L[36],
"go":function(anfed100214) {
return $Hanfed94213(anfed100214,AV913,CompiledCodePrinter7854,ccp8471,env99215);
}};
$e421422.stack[R.EXN_STACKHEIGHT++] = $ss425426;
}
if(R.isPyretException($e421422)) {
$e421422.pyretStack.push(L[36]);
}
throw $e421422;
}
var $ret427428 = $Hanfed94213($z423424,AV913,CompiledCodePrinter7854,ccp8471,env99215);
++R.GAS;
return $ret427428;
});
make_DASH_unsafe_DASH_compiled_DASH_pyret86392.$var = anf_assign53393;
var anf_assign69395 = R.makeFunction(function(trace102407,phase10373,program_DASH_ast104408,env10572) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[17],4,arguments);
}
var ret10674 = {"$var":trace102407,
"$name":"ret"};
var anf_fun55419 = G(N511,"anf-program",L[35]);
var $z411412 = D;
var $f417418 = function(_) {
return R.isFunction(anf_fun55419)?anf_fun55419.app(program_DASH_ast104408):R.ffi.throwNonFunApp(L[34],anf_fun55419,[program_DASH_ast104408]);
};
try {
if(--R.GAS > 0) {
$z411412 = $f417418();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f417418,
"from":L[34]});
}
} catch($e409410) {
if(R.isCont($e409410)) {
var $ss413414 = {"from":L[34],
"go":function(anfed10770) {
return $Hanfed10669(anfed10770,AS712,AV913,ccp8471,env10572,phase10373,ret10674);
}};
$e409410.stack[R.EXN_STACKHEIGHT++] = $ss413414;
}
if(R.isPyretException($e409410)) {
$e409410.pyretStack.push(L[34]);
}
throw $e409410;
}
var $ret415416 = $Hanfed10669($z411412,AS712,AV913,ccp8471,env10572,phase10373,ret10674);
++R.GAS;
return $ret415416;
});
trace_DASH_make_DASH_compiled_DASH_pyret87394.$var = anf_assign69395;
var provides7055 = R.makeObject({"CompiledCodePrinter":CompiledCodePrinter81383.$var,
"is-CompiledCodePrinter":is_DASH_CompiledCodePrinter82385.$var,
"ccp":ccp8471.$var,
"is-ccp":is_DASH_ccp83387.$var,
"make-compiled-pyret":make_DASH_compiled_DASH_pyret85390.$var,
"make-unsafe-compiled-pyret":make_DASH_unsafe_DASH_compiled_DASH_pyret86392.$var,
"trace-make-compiled-pyret":trace_DASH_make_DASH_compiled_DASH_pyret87394.$var});
var anf_fun71406 = G(builtins4,"current-checker",L[0]);
var $z398399 = D;
var $f404405 = function(_) {
return R.isFunction(anf_fun71406)?anf_fun71406.app():R.ffi.throwNonFunApp(L[0],anf_fun71406,[]);
};
try {
if(--R.GAS > 0) {
$z398399 = $f404405();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f404405,
"from":L[0]});
}
} catch($e396397) {
if(R.isCont($e396397)) {
var $ss400401 = {"from":L[0],
"go":function(anf_bracket7253) {
return $Hanf_bracket10852(anf_bracket7253,CompiledCodePrinter7854,provides7055,nothing5);
}};
$e396397.stack[R.EXN_STACKHEIGHT++] = $ss400401;
}
if(R.isPyretException($e396397)) {
$e396397.pyretStack.push(L[0]);
}
throw $e396397;
}
var $ret402403 = $Hanf_bracket10852($z398399,CompiledCodePrinter7854,provides7055,nothing5);
++R.GAS;
return $ret402403;
},function(moduleVal) {
R.modules["$src/arr/compiler/js-of-pyret.arr37"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/well-formed.arr',["trove/ast",
"trove/srcloc",
"compiler/compile-structs.arr",
"trove/format",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($A11332,$SL31433,$C51534,$F71635,$arrays91736,$lists111837,$option131938,$error152039,$sets172140) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/well-formed.arr31"]) {
return R.modules["$src/arr/compiler/well-formed.arr31"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/well-formed.arr";
var D = R.undefined;
var L = [[M,13,0,184,651,3,21919],
[M,638,0,21589,651,3,21919],
[M,643,7,21733,643,63,21789],
[M,643,7,21733,643,16,21742],
[M,633,2,21508,635,5,21585],
[M,634,4,21538,634,31,21565],
[M,630,2,21429,632,5,21504],
[M,631,4,21458,631,29,21483],
[M,627,2,21352,629,5,21425],
[M,628,4,21380,628,30,21406],
[M,624,2,21275,626,5,21348],
[M,625,4,21303,625,29,21328],
[M,621,2,21198,623,5,21271],
[M,622,4,21226,622,32,21254],
[M,618,2,21115,620,5,21194],
[M,619,4,21146,619,32,21174],
[M,615,2,21010,617,5,21111],
[M,616,4,21052,616,31,21079],
[M,612,2,20832,614,5,21006],
[M,613,4,20924,613,46,20966],
[M,612,81,20911,612,87,20917],
[M,612,33,20863,612,36,20866],
[M,612,65,20895,612,71,20901],
[M,609,2,20659,611,5,20828],
[M,610,4,20752,610,52,20800],
[M,609,75,20732,609,88,20745],
[M,609,39,20696,609,42,20699],
[M,609,52,20709,609,58,20715],
[M,606,2,20447,608,5,20655],
[M,607,4,20576,607,33,20605],
[M,606,20,20465,606,23,20468],
[M,606,39,20484,606,42,20487],
[M,606,52,20497,606,58,20503],
[M,606,71,20516,606,92,20537],
[M,606,110,20555,606,124,20569],
[M,603,2,20292,605,5,20443],
[M,604,4,20379,604,40,20415],
[M,603,47,20337,603,66,20356],
[M,603,76,20366,603,82,20372],
[M,603,27,20317,603,30,20320],
[M,600,2,20174,602,5,20288],
[M,601,4,20236,601,34,20266],
[M,600,34,20206,600,40,20212],
[M,600,51,20223,600,57,20229],
[M,600,21,20193,600,24,20196],
[M,597,2,19949,599,5,20170],
[M,598,4,20091,598,38,20125],
[M,597,38,19985,597,44,19991],
[M,597,75,20022,597,80,20027],
[M,597,105,20052,597,111,20058],
[M,597,25,19972,597,28,19975],
[M,597,54,20001,597,66,20013],
[M,597,89,20036,597,95,20042],
[M,597,123,20070,597,137,20084],
[M,594,2,19808,596,5,19945],
[M,595,4,19886,595,36,19918],
[M,594,36,19842,594,42,19848],
[M,594,51,19857,594,56,19862],
[M,594,67,19873,594,73,19879],
[M,594,23,19829,594,26,19832],
[M,591,2,19661,593,5,19804],
[M,592,4,19742,592,39,19777],
[M,591,39,19698,591,45,19704],
[M,591,54,19713,591,59,19718],
[M,591,70,19729,591,76,19735],
[M,591,26,19685,591,29,19688],
[M,588,2,19539,590,5,19657],
[M,589,4,19603,589,36,19635],
[M,588,36,19573,588,42,19579],
[M,588,53,19590,588,59,19596],
[M,588,23,19560,588,26,19563],
[M,585,2,19380,587,5,19535],
[M,586,4,19472,586,31,19499],
[M,585,55,19433,585,61,19439],
[M,585,18,19396,585,21,19399],
[M,585,31,19409,585,45,19423],
[M,585,80,19458,585,87,19465],
[M,582,2,19208,584,5,19376],
[M,583,4,19311,583,29,19336],
[M,582,33,19239,582,39,19245],
[M,582,77,19283,582,82,19288],
[M,582,92,19298,582,98,19304],
[M,582,16,19222,582,19,19225],
[M,582,53,19259,582,68,19274],
[M,579,2,19094,581,5,19204],
[M,580,4,19154,580,33,19183],
[M,579,32,19124,579,38,19130],
[M,579,49,19141,579,55,19147],
[M,579,20,19112,579,23,19115],
[M,576,2,18978,578,5,19090],
[M,577,4,19039,577,34,19069],
[M,576,33,19009,576,39,19015],
[M,576,21,18997,576,24,19000],
[M,576,50,19026,576,56,19032],
[M,573,2,18872,575,5,18974],
[M,574,4,18928,574,29,18953],
[M,573,28,18898,573,34,18904],
[M,573,16,18886,573,19,18889],
[M,573,45,18915,573,51,18921],
[M,570,2,18757,572,5,18868],
[M,571,4,18818,571,35,18849],
[M,570,33,18788,570,39,18794],
[M,570,22,18777,570,25,18780],
[M,570,49,18804,570,56,18811],
[M,567,2,18671,569,5,18753],
[M,568,4,18712,568,32,18740],
[M,567,30,18699,567,36,18705],
[M,567,19,18688,567,22,18691],
[M,564,2,18593,566,5,18667],
[M,565,4,18630,565,28,18654],
[M,564,26,18617,564,32,18623],
[M,564,15,18606,564,18,18609],
[M,561,2,18509,563,5,18589],
[M,562,4,18544,562,30,18570],
[M,561,17,18524,561,20,18527],
[M,558,2,18387,560,5,18505],
[M,559,4,18454,559,34,18484],
[M,558,21,18406,558,24,18409],
[M,558,34,18419,558,40,18425],
[M,558,50,18435,558,62,18447],
[M,555,2,18275,557,5,18383],
[M,556,4,18337,556,29,18362],
[M,555,29,18302,555,35,18308],
[M,555,16,18289,555,19,18292],
[M,555,45,18318,555,57,18330],
[M,552,2,18100,554,5,18271],
[M,553,4,18205,553,35,18236],
[M,552,34,18132,552,53,18151],
[M,552,70,18168,552,76,18174],
[M,552,22,18120,552,25,18123],
[M,552,88,18186,552,100,18198],
[M,549,2,17988,551,5,18096],
[M,550,4,18047,550,33,18076],
[M,549,33,18019,549,39,18025],
[M,549,48,18034,549,54,18040],
[M,549,20,18006,549,23,18009],
[M,546,2,17880,548,5,17984],
[M,547,4,17937,547,31,17964],
[M,546,31,17909,546,37,17915],
[M,546,46,17924,546,52,17930],
[M,546,18,17896,546,21,17899],
[M,543,2,17782,545,5,17876],
[M,544,4,17832,544,31,17859],
[M,543,18,17798,543,21,17801],
[M,543,33,17813,543,45,17825],
[M,540,2,17686,542,5,17778],
[M,541,4,17736,541,29,17761],
[M,540,16,17700,540,19,17703],
[M,540,31,17715,540,45,17729],
[M,537,2,17562,539,5,17682],
[M,538,4,17631,538,32,17659],
[M,537,32,17592,537,38,17598],
[M,537,19,17579,537,22,17582],
[M,537,50,17610,537,64,17624],
[M,534,2,17438,536,5,17558],
[M,535,4,17507,535,32,17535],
[M,534,32,17468,534,38,17474],
[M,534,19,17455,534,22,17458],
[M,534,50,17486,534,64,17500],
[M,531,2,17247,533,5,17434],
[M,532,4,17367,532,32,17395],
[M,531,53,17298,531,58,17303],
[M,531,83,17328,531,89,17334],
[M,531,19,17264,531,22,17267],
[M,531,32,17277,531,44,17289],
[M,531,67,17312,531,73,17318],
[M,531,101,17346,531,115,17360],
[M,528,2,17030,530,5,17243],
[M,529,4,17171,529,29,17196],
[M,528,74,17102,528,79,17107],
[M,528,104,17132,528,110,17138],
[M,528,16,17044,528,19,17047],
[M,528,31,17059,528,43,17071],
[M,528,53,17081,528,65,17093],
[M,528,88,17116,528,94,17122],
[M,528,122,17150,528,136,17164],
[M,525,2,16942,527,5,17026],
[M,526,4,16984,526,31,17011],
[M,525,31,16971,525,37,16977],
[M,525,18,16958,525,21,16961],
[M,522,2,16802,524,5,16938],
[M,523,4,16880,523,36,16912],
[M,522,50,16850,522,56,16856],
[M,522,67,16867,522,73,16873],
[M,522,23,16823,522,26,16826],
[M,522,34,16834,522,40,16840],
[M,519,2,16678,521,5,16798],
[M,520,4,16748,520,28,16772],
[M,519,42,16718,519,48,16724],
[M,519,59,16735,519,65,16741],
[M,519,15,16691,519,18,16694],
[M,519,26,16702,519,32,16708],
[M,516,2,16548,518,5,16674],
[M,517,4,16621,517,29,16646],
[M,516,29,16575,516,35,16581],
[M,516,43,16589,516,49,16595],
[M,516,62,16608,516,68,16614],
[M,516,16,16562,516,19,16565],
[M,513,2,16366,515,5,16544],
[M,514,4,16476,514,36,16508],
[M,513,35,16399,513,40,16404],
[M,513,49,16413,513,55,16419],
[M,513,99,16463,513,105,16469],
[M,513,23,16387,513,26,16390],
[M,513,69,16433,513,88,16452],
[M,510,2,16218,512,5,16362],
[M,511,4,16306,511,31,16333],
[M,510,30,16246,510,35,16251],
[M,510,44,16260,510,50,16266],
[M,510,18,16234,510,21,16237],
[M,510,64,16280,510,83,16299],
[M,507,2,16066,509,5,16214],
[M,508,4,16153,508,38,16187],
[M,507,76,16140,507,82,16146],
[M,507,25,16089,507,28,16092],
[M,507,38,16102,507,44,16108],
[M,507,54,16118,507,66,16130],
[M,504,2,15918,506,5,16062],
[M,505,4,16002,505,38,16036],
[M,504,73,15989,504,79,15995],
[M,504,25,15941,504,28,15944],
[M,504,42,15958,504,62,15978],
[M,501,2,15804,503,5,15914],
[M,502,4,15866,502,33,15895],
[M,501,20,15822,501,23,15825],
[M,501,37,15839,501,57,15859],
[M,498,2,15670,500,5,15800],
[M,499,4,15745,499,33,15774],
[M,498,64,15732,498,70,15738],
[M,498,20,15688,498,23,15691],
[M,498,37,15705,498,53,15721],
[M,495,2,15570,497,5,15666],
[M,496,4,15623,496,28,15647],
[M,495,15,15583,495,18,15586],
[M,495,32,15600,495,48,15616],
[M,492,2,15442,494,5,15566],
[M,493,4,15509,493,40,15545],
[M,492,40,15480,492,46,15486],
[M,492,56,15496,492,62,15502],
[M,492,27,15467,492,30,15470],
[M,489,2,15324,491,5,15438],
[M,490,4,15386,490,35,15417],
[M,489,35,15357,489,41,15363],
[M,489,51,15373,489,57,15379],
[M,489,22,15344,489,25,15347],
[M,486,2,15214,488,5,15320],
[M,487,4,15272,487,32,15300],
[M,486,30,15242,486,36,15248],
[M,486,47,15259,486,53,15265],
[M,486,19,15231,486,22,15234],
[M,483,2,15101,485,5,15210],
[M,484,4,15160,484,34,15190],
[M,483,34,15133,483,40,15139],
[M,483,49,15148,483,54,15153],
[M,483,21,15120,483,24,15123],
[M,480,2,14991,482,5,15097],
[M,481,4,15049,481,30,15075],
[M,480,30,15019,480,36,15025],
[M,480,47,15036,480,53,15042],
[M,480,17,15006,480,20,15009],
[M,477,2,14863,479,5,14987],
[M,478,4,14941,478,31,14968],
[M,477,18,14879,477,21,14882],
[M,477,35,14896,477,58,14919],
[M,474,2,14718,476,5,14859],
[M,475,4,14799,475,29,14824],
[M,474,29,14745,474,35,14751],
[M,474,46,14762,474,52,14768],
[M,474,16,14732,474,19,14735],
[M,474,69,14785,474,76,14792],
[M,471,2,14610,473,5,14714],
[M,472,4,14667,472,29,14692],
[M,471,29,14637,471,35,14643],
[M,471,46,14654,471,52,14660],
[M,471,16,14624,471,19,14627],
[M,468,2,14467,470,5,14606],
[M,469,4,14528,469,29,14553],
[M,465,2,14369,467,5,14463],
[M,466,4,14416,466,36,14448],
[M,465,36,14403,465,42,14409],
[M,465,23,14390,465,26,14393],
[M,462,2,14296,464,5,14365],
[M,463,4,14322,463,31,14349],
[M,459,2,14165,461,5,14292],
[M,460,4,14236,460,37,14269],
[M,459,37,14200,459,43,14206],
[M,459,24,14187,459,27,14190],
[M,459,55,14218,459,66,14229],
[M,456,2,14043,458,5,14161],
[M,457,4,14110,457,34,14140],
[M,456,56,14097,456,62,14103],
[M,456,21,14062,456,24,14065],
[M,456,35,14076,456,47,14088],
[M,453,2,13956,455,5,14039],
[M,454,4,13989,454,32,14017],
[M,450,2,13861,452,5,13952],
[M,451,4,13898,451,37,13931],
[M,447,2,13770,449,5,13857],
[M,448,4,13805,448,34,13835],
[M,444,2,13681,446,5,13766],
[M,445,4,13715,445,34,13745],
[M,441,2,13592,443,5,13677],
[M,442,4,13626,442,34,13656],
[M,438,2,13495,440,5,13588],
[M,439,4,13533,439,30,13559],
[M,435,2,13408,437,5,13491],
[M,436,4,13441,436,39,13476],
[M,432,2,13333,434,5,13404],
[M,433,4,13360,433,33,13389],
[M,429,2,13216,431,5,13329],
[M,430,4,13264,430,39,13299],
[M,426,2,13091,428,5,13212],
[M,427,4,13143,427,38,13177],
[M,423,2,12992,425,5,13087],
[M,424,4,13031,424,32,13059],
[M,410,4,12494,410,39,12529],
[M,409,2,12413,419,5,12928],
[M,406,22,12286,406,44,12308],
[M,405,2,12209,408,5,12409],
[M,395,4,11771,395,39,11806],
[M,394,2,11702,404,5,12205],
[M,391,22,11591,391,51,11620],
[M,390,2,11519,393,5,11698],
[M,387,22,11337,387,51,11366],
[M,386,2,11256,389,5,11515],
[M,383,2,11200,385,5,11252],
[M,380,2,11123,382,5,11196],
[M,381,4,11160,381,13,11169],
[M,378,4,11046,378,71,11113],
[M,378,14,11056,378,27,11069],
[M,378,4,11046,378,13,11055],
[M,377,2,11003,379,5,11119],
[M,374,2,10952,376,5,10999],
[M,371,2,10880,373,5,10948],
[M,372,4,10912,372,13,10921],
[M,365,4,10628,368,7,10760],
[M,365,14,10638,368,7,10760],
[M,367,16,10736,367,26,10746],
[M,366,6,10664,366,61,10719],
[M,366,40,10698,366,53,10711],
[M,366,30,10688,366,39,10697],
[M,364,2,10563,370,5,10876],
[M,363,20,10536,363,42,10558],
[M,356,32,10437,356,44,10449],
[M,356,10,10415,356,31,10436],
[M,355,2,10386,360,5,10512],
[M,351,16,10335,351,39,10358],
[M,351,16,10335,351,31,10350],
[M,350,4,10304,352,7,10367],
[M,350,9,10309,350,18,10318],
[M,349,2,10273,354,5,10382],
[M,346,4,10133,346,33,10162],
[M,345,2,10079,348,5,10269],
[M,342,4,9961,342,33,9990],
[M,341,2,9919,344,5,10075],
[M,336,9,9777,336,26,9794],
[M,336,9,9777,336,24,9792],
[M,335,2,9743,340,5,9915],
[M,333,27,9722,333,37,9732],
[M,332,2,9650,334,5,9739],
[M,325,4,9390,327,7,9460],
[M,325,9,9395,325,30,9416],
[M,324,2,9326,331,5,9646],
[M,316,4,9012,316,27,9035],
[M,315,2,8954,323,5,9322],
[M,305,9,8599,305,22,8612],
[M,305,9,8599,305,20,8610],
[M,304,2,8541,314,5,8950],
[M,299,9,8378,299,60,8429],
[M,299,9,8378,299,19,8388],
[M,298,2,8328,303,5,8537],
[M,293,9,8165,293,60,8216],
[M,293,9,8165,293,19,8175],
[M,292,2,8112,297,5,8324],
[M,287,9,7969,287,60,8020],
[M,287,9,7969,287,19,7979],
[M,286,2,7924,291,5,8108],
[M,273,9,7469,273,60,7520],
[M,273,9,7469,273,19,7479],
[M,272,2,7399,285,5,7920],
[M,263,4,7098,269,7,7346],
[M,262,2,7054,271,5,7395],
[M,257,32,6971,257,46,6985],
[M,257,10,6949,257,31,6970],
[M,256,2,6902,261,5,7050],
[M,246,7,6604,246,22,6619],
[M,245,2,6572,255,5,6898],
[M,240,6,6376,240,100,6470],
[M,239,4,6350,241,7,6478],
[M,239,8,6354,239,22,6368],
[M,242,4,6483,242,27,6506],
[M,238,2,6303,244,5,6568],
[M,236,4,6223,236,74,6293],
[M,235,2,6187,237,5,6299],
[M,232,4,6080,232,91,6167],
[M,231,2,6037,234,5,6183],
[M,228,4,5945,228,76,6017],
[M,227,2,5908,230,5,6033],
[M,224,4,5813,224,79,5888],
[M,223,2,5781,226,5,5904],
[M,220,4,5681,220,84,5761],
[M,219,2,5600,222,5,5777],
[M,216,4,5500,216,84,5580],
[M,215,2,5431,218,5,5596],
[M,212,2,5337,214,5,5427],
[M,211,22,5310,211,44,5332],
[M,190,0,4815,205,3,5282],
[M,191,2,4854,204,5,5278],
[M,203,14,5257,203,23,5266],
[M,192,4,4877,202,10,5242],
[M,194,8,4941,194,41,4974],
[M,198,14,5114,198,24,5124],
[M,193,8,4919,193,20,4931],
[M,189,0,4752,189,62,4814],
[M,189,40,4792,189,57,4809],
[M,183,0,4581,187,3,4750],
[M,184,2,4647,186,5,4746],
[M,185,27,4701,185,54,4728],
[M,185,43,4717,185,53,4727],
[M,185,43,4717,185,51,4725],
[M,185,36,4710,185,41,4715],
[M,185,27,4701,185,35,4709],
[M,185,13,4687,185,18,4692],
[M,185,4,4678,185,12,4686],
[M,183,31,4612,183,45,4626],
[M,171,0,3978,181,3,4579],
[M,172,2,4014,180,5,4575],
[M,178,4,4471,178,80,4547],
[M,177,4,4375,177,95,4466],
[M,176,4,4281,176,93,4370],
[M,175,4,4191,175,89,4276],
[M,174,4,4116,174,74,4186],
[M,173,4,4038,173,77,4111],
[M,171,25,4003,171,31,4009],
[M,159,0,3580,168,3,3975],
[M,160,2,3664,167,5,3971],
[M,162,4,3713,166,9,3965],
[M,163,6,3738,166,9,3965],
[M,163,31,3763,163,59,3791],
[M,163,49,3781,163,55,3787],
[M,163,39,3771,163,45,3777],
[M,163,20,3752,163,30,3762],
[M,161,4,3690,161,22,3708],
[M,159,42,3622,159,46,3626],
[M,140,0,3046,156,3,3577],
[M,141,2,3106,155,5,3573],
[M,143,4,3159,154,9,3567],
[M,144,6,3184,154,9,3567],
[M,145,8,3209,153,13,3557],
[M,146,13,3255,146,34,3276],
[M,146,13,3255,146,30,3272],
[M,142,4,3136,142,22,3154],
[M,140,43,3089,140,55,3101],
[M,117,0,2265,135,3,2885],
[M,118,2,2316,134,5,2881],
[M,120,4,2365,133,9,2875],
[M,121,6,2390,133,9,2875],
[M,122,8,2415,132,13,2865],
[M,123,13,2461,123,34,2482],
[M,123,13,2461,123,30,2478],
[M,119,4,2342,119,22,2360],
[M,117,34,2299,117,46,2311],
[M,103,0,1828,115,3,2263],
[M,104,2,1886,114,5,2259],
[M,106,4,1933,113,9,2253],
[M,107,6,1958,113,9,2253],
[M,108,8,1990,112,13,2243],
[M,109,10,2041,112,13,2243],
[M,109,35,2066,109,61,2092],
[M,109,43,2074,109,49,2080],
[M,109,24,2055,109,34,2065],
[M,105,4,1910,105,22,1928],
[M,103,34,1862,103,53,1881],
[M,92,0,1514,101,3,1826],
[M,93,5,1585,93,40,1620],
[M,92,42,1556,92,48,1562],
[M,92,42,1556,92,63,1577],
[M,91,13,1501,91,25,1513],
[M,82,0,1322,88,3,1485],
[M,85,2,1417,85,27,1442],
[M,85,8,1423,85,19,1434],
[M,78,0,1251,80,3,1320],
[M,79,12,1291,79,36,1315],
[M,79,12,1291,79,27,1306],
[M,75,0,1169,77,3,1250],
[M,76,12,1215,76,42,1245],
[M,76,12,1215,76,26,1229],
[M,72,0,1080,74,3,1168],
[M,73,32,1144,73,50,1162],
[M,73,12,1124,73,26,1138],
[M,69,0,1020,71,3,1079],
[M,70,12,1056,70,30,1074],
[M,70,12,1056,70,20,1064],
[M,65,0,952,68,3,1019],
[M,66,18,990,66,33,1005],
[M,643,41,21767,643,56,21782],
[M,643,41,21767,643,54,21780],
[M,643,7,21733,643,35,21761],
[M,643,64,21790,643,73,21799],
[M,643,64,21790,643,68,21794],
[M,644,10,21810,644,23,21823],
[M,644,10,21810,644,15,21815],
[M,638,30,21619,638,61,21650],
[M,638,30,21619,638,45,21634],
[M,643,39,21765,643,62,21788],
[M,412,18,12580,412,41,12603],
[M,413,10,12614,416,55,12831],
[M,413,20,12624,413,48,12652],
[M,413,10,12614,413,19,12623],
[M,414,18,12680,414,46,12708],
[M,414,8,12670,414,17,12679],
[M,413,10,12614,413,57,12661],
[M,418,4,12869,418,57,12922],
[M,418,4,12869,418,7,12872],
[M,415,18,12736,415,46,12764],
[M,415,8,12726,415,17,12735],
[M,414,8,12670,414,55,12717],
[M,416,18,12794,416,46,12822],
[M,416,8,12784,416,17,12793],
[M,415,8,12726,415,57,12775],
[M,416,8,12784,416,55,12831],
[M,418,12,12877,418,57,12922],
[M,406,4,12268,406,45,12309],
[M,407,4,12314,407,93,12403],
[M,407,14,12324,407,42,12352],
[M,407,4,12314,407,13,12323],
[M,407,55,12365,407,72,12382],
[M,407,4,12314,407,50,12360],
[M,407,55,12365,407,93,12403],
[M,397,18,11857,397,41,11880],
[M,398,10,11891,401,55,12108],
[M,398,20,11901,398,48,11929],
[M,398,10,11891,398,19,11900],
[M,399,18,11957,399,46,11985],
[M,399,8,11947,399,17,11956],
[M,398,10,11891,398,57,11938],
[M,403,4,12146,403,57,12199],
[M,403,4,12146,403,7,12149],
[M,400,18,12013,400,46,12041],
[M,400,8,12003,400,17,12012],
[M,399,8,11947,399,55,11994],
[M,401,18,12071,401,46,12099],
[M,401,8,12061,401,17,12070],
[M,400,8,12003,400,57,12052],
[M,401,8,12061,401,55,12108],
[M,403,12,12154,403,57,12199],
[M,391,22,11591,391,65,11634],
[M,391,4,11573,391,65,11634],
[M,392,14,11649,392,42,11677],
[M,392,4,11639,392,13,11648],
[M,387,54,11369,387,71,11386],
[M,387,64,11379,387,70,11385],
[M,387,54,11369,387,63,11378],
[M,387,22,11337,387,85,11400],
[M,387,4,11319,387,85,11400],
[M,388,4,11405,388,108,11509],
[M,388,14,11415,388,42,11443],
[M,388,4,11405,388,13,11414],
[M,388,65,11466,388,93,11494],
[M,388,55,11456,388,64,11465],
[M,388,4,11405,388,50,11451],
[M,388,55,11456,388,108,11509],
[M,378,40,11082,378,50,11092],
[M,378,4,11046,378,35,11077],
[M,378,40,11082,378,71,11113],
[M,369,4,10765,369,109,10870],
[M,369,17,10778,369,31,10792],
[M,369,4,10765,369,11,10772],
[M,369,43,10804,369,63,10824],
[M,369,15,10776,369,38,10799],
[M,369,85,10846,369,98,10859],
[M,369,75,10836,369,84,10845],
[M,369,43,10804,369,69,10830],
[M,369,73,10834,369,109,10870],
[M,356,4,10409,358,7,10497],
[M,357,23,10476,357,35,10488],
[M,356,8,10413,356,46,10451],
[M,357,6,10459,357,36,10489],
[M,351,6,10325,351,40,10359],
[M,347,4,10167,347,100,10263],
[M,347,4,10167,347,13,10176],
[M,347,24,10187,347,33,10196],
[M,347,4,10167,347,19,10182],
[M,347,54,10217,347,67,10230],
[M,347,44,10207,347,53,10216],
[M,347,24,10187,347,39,10202],
[M,347,83,10246,347,94,10257],
[M,347,44,10207,347,78,10241],
[M,347,83,10246,347,100,10263],
[M,343,4,9995,343,78,10069],
[M,343,4,9995,343,13,10004],
[M,343,24,10015,343,33,10024],
[M,343,4,9995,343,19,10010],
[M,343,54,10045,343,67,10058],
[M,343,44,10035,343,53,10044],
[M,343,24,10015,343,39,10030],
[M,343,44,10035,343,78,10069],
[M,337,6,9807,337,61,9862],
[M,336,4,9772,338,7,9870],
[M,336,9,9777,336,32,9800],
[M,339,14,9885,339,27,9898],
[M,339,4,9875,339,13,9884],
[M,326,6,9430,326,28,9452],
[M,325,9,9395,325,36,9422],
[M,328,4,9465,328,27,9488],
[M,329,4,9493,330,114,9640],
[M,329,14,9503,329,27,9516],
[M,329,4,9493,329,13,9502],
[M,330,18,9544,330,31,9557],
[M,330,8,9534,330,17,9543],
[M,329,4,9493,329,36,9525],
[M,330,43,9569,330,52,9578],
[M,330,8,9534,330,38,9564],
[M,330,63,9589,330,73,9599],
[M,330,43,9569,330,58,9584],
[M,330,63,9589,330,79,9605],
[M,330,84,9610,330,114,9640],
[M,317,4,9040,320,7,9164],
[M,319,6,9092,319,70,9156],
[M,318,6,9068,318,23,9085],
[M,321,4,9169,322,114,9316],
[M,321,14,9179,321,27,9192],
[M,321,4,9169,321,13,9178],
[M,322,18,9220,322,31,9233],
[M,322,8,9210,322,17,9219],
[M,321,4,9169,321,36,9201],
[M,322,43,9245,322,52,9254],
[M,322,8,9210,322,38,9240],
[M,322,63,9265,322,73,9275],
[M,322,43,9245,322,58,9260],
[M,322,63,9265,322,79,9281],
[M,322,84,9286,322,114,9316],
[M,306,6,8625,306,61,8680],
[M,305,4,8594,307,7,8688],
[M,305,9,8599,305,28,8618],
[M,308,4,8693,308,27,8716],
[M,309,4,8721,312,7,8833],
[M,311,6,8773,311,58,8825],
[M,310,6,8749,310,23,8766],
[M,313,4,8838,313,110,8944],
[M,313,14,8848,313,27,8861],
[M,313,4,8838,313,13,8847],
[M,313,39,8873,313,48,8882],
[M,313,4,8838,313,34,8868],
[M,313,59,8893,313,69,8903],
[M,313,39,8873,313,54,8888],
[M,313,59,8893,313,75,8909],
[M,313,80,8914,313,110,8944],
[M,299,52,8421,299,58,8427],
[M,299,30,8399,299,51,8420],
[M,299,9,8378,299,25,8394],
[M,300,6,8436,300,30,8460],
[M,300,23,8453,300,29,8459],
[M,299,4,8373,301,7,8468],
[M,302,4,8473,302,62,8531],
[M,302,4,8473,302,14,8483],
[M,299,30,8399,299,59,8428],
[M,302,25,8494,302,34,8503],
[M,302,4,8473,302,20,8489],
[M,302,45,8514,302,56,8525],
[M,302,25,8494,302,40,8509],
[M,302,45,8514,302,62,8531],
[M,293,52,8208,293,58,8214],
[M,293,30,8186,293,51,8207],
[M,293,9,8165,293,25,8181],
[M,294,6,8223,294,30,8247],
[M,294,23,8240,294,29,8246],
[M,293,4,8160,295,7,8255],
[M,296,4,8260,296,62,8318],
[M,296,4,8260,296,14,8270],
[M,293,30,8186,293,59,8215],
[M,296,25,8281,296,34,8290],
[M,296,4,8260,296,20,8276],
[M,296,45,8301,296,56,8312],
[M,296,25,8281,296,40,8296],
[M,296,45,8301,296,62,8318],
[M,287,52,8012,287,58,8018],
[M,287,30,7990,287,51,8011],
[M,287,9,7969,287,25,7985],
[M,288,6,8027,288,30,8051],
[M,288,23,8044,288,29,8050],
[M,287,4,7964,289,7,8059],
[M,290,4,8064,290,42,8102],
[M,290,4,8064,290,14,8074],
[M,287,30,7990,287,59,8019],
[M,290,25,8085,290,36,8096],
[M,290,4,8064,290,20,8080],
[M,290,25,8085,290,42,8102],
[M,273,52,7512,273,58,7518],
[M,273,30,7490,273,51,7511],
[M,273,9,7469,273,25,7485],
[M,274,6,7527,274,30,7551],
[M,274,23,7544,274,29,7550],
[M,273,4,7464,275,7,7559],
[M,276,9,7569,276,22,7582],
[M,276,9,7569,276,20,7580],
[M,273,30,7490,273,59,7519],
[M,277,6,7595,277,61,7650],
[M,276,4,7564,278,7,7658],
[M,276,9,7569,276,28,7588],
[M,279,4,7663,279,27,7686],
[M,280,4,7691,283,7,7803],
[M,282,6,7743,282,58,7795],
[M,281,6,7719,281,23,7736],
[M,284,4,7808,284,110,7914],
[M,284,14,7818,284,27,7831],
[M,284,4,7808,284,13,7817],
[M,284,39,7843,284,48,7852],
[M,284,4,7808,284,34,7838],
[M,284,59,7863,284,69,7873],
[M,284,39,7843,284,54,7858],
[M,284,59,7863,284,75,7879],
[M,284,80,7884,284,110,7914],
[M,265,8,7158,265,76,7226],
[M,267,8,7247,267,89,7328],
[M,264,8,7132,264,24,7148],
[M,263,9,7103,263,28,7122],
[M,270,4,7351,270,42,7389],
[M,270,4,7351,270,14,7361],
[M,270,25,7372,270,36,7383],
[M,270,4,7351,270,20,7367],
[M,270,25,7372,270,42,7389],
[M,257,4,6943,259,7,7035],
[M,258,23,7012,258,37,7026],
[M,257,8,6947,257,48,6987],
[M,258,6,6995,258,38,7027],
[M,247,6,6627,247,32,6653],
[M,250,19,6694,250,31,6706],
[M,250,19,6694,250,29,6704],
[M,248,6,6660,248,10,6664],
[M,250,6,6681,250,32,6707],
[M,251,19,6727,251,75,6783],
[M,251,32,6740,251,74,6782],
[M,251,40,6748,251,70,6778],
[M,251,40,6748,251,50,6758],
[M,251,19,6727,251,31,6739],
[M,251,6,6714,251,87,6795],
[M,251,80,6788,251,86,6794],
[M,251,19,6727,251,79,6787],
[M,252,29,6825,252,49,6845],
[M,252,29,6825,252,47,6843],
[M,252,6,6802,252,50,6846],
[M,253,6,6853,253,37,6884],
[M,253,16,6863,253,29,6876],
[M,253,6,6853,253,15,6862],
[M,251,57,6765,251,67,6775],
[M,251,40,6748,251,53,6761],
[M,251,57,6765,251,70,6778],
[M,243,4,6511,243,55,6562],
[M,243,14,6521,243,27,6534],
[M,243,4,6511,243,13,6520],
[M,243,39,6546,243,49,6556],
[M,243,4,6511,243,34,6541],
[M,243,39,6546,243,55,6562],
[M,236,4,6223,236,36,6255],
[M,236,41,6260,236,74,6293],
[M,195,8,4983,195,42,5017],
[M,197,18,5048,199,53,5204],
[M,198,39,5139,198,50,5150],
[M,197,8,5038,200,16,5221],
[M,185,56,4730,185,65,4739],
[M,165,8,3914,165,49,3955],
[M,164,8,3808,164,105,3905],
[M,164,35,3835,164,91,3891],
[M,164,59,3859,164,65,3865],
[M,164,97,3897,164,104,3904],
[M,164,92,3892,164,95,3895],
[M,146,36,3278,146,43,3285],
[M,147,27,3313,147,34,3320],
[M,149,12,3349,152,15,3543],
[M,149,37,3374,149,59,3396],
[M,149,45,3382,149,49,3386],
[M,149,26,3363,149,36,3373],
[M,147,18,3304,147,25,3311],
[M,151,14,3489,151,52,3527],
[M,150,14,3419,150,69,3474],
[M,150,44,3449,150,56,3461],
[M,150,61,3466,150,68,3473],
[M,123,36,2484,123,43,2491],
[M,125,12,2520,125,58,2566],
[M,125,29,2537,125,51,2559],
[M,125,37,2545,125,41,2549],
[M,125,18,2526,125,28,2536],
[M,126,12,2579,131,15,2851],
[M,130,36,2823,130,47,2834],
[M,128,14,2728,128,47,2761],
[M,127,14,2612,127,115,2713],
[M,127,65,2663,127,77,2675],
[M,130,22,2809,130,48,2835],
[M,127,41,2639,127,103,2701],
[M,127,107,2705,127,114,2712],
[M,111,12,2194,111,47,2229],
[M,110,12,2113,110,80,2181],
[M,110,39,2140,110,68,2169],
[M,110,69,2170,110,76,2177],
[M,94,7,1629,94,27,1649],
[M,94,7,1629,94,25,1647],
[M,94,7,1629,94,18,1640],
[M,99,4,1809,99,11,1816],
[M,94,34,1656,94,41,1663],
[M,96,95,1769,96,108,1782],
[M,94,7,1629,94,33,1655],
[M,96,15,1689,96,109,1783],
[M,96,6,1680,96,114,1788],
[M,73,12,1124,73,51,1163],
[M,3,0,13,651,3,21919],
[M,13,11,195,13,20,204],
[M,23,0,477,62,1,949],
[M,23,17,494,62,1,949],
[M,21,11,443,21,21,453]];
var _plus1 = NAMESPACE.get("_plus");
var builtins2 = NAMESPACE.get("builtins");
var not3 = NAMESPACE.get("not");
var nothing4 = NAMESPACE.get("nothing");
var print5 = NAMESPACE.get("print");
var raise6 = NAMESPACE.get("raise");
var string_DASH_length7 = NAMESPACE.get("string-length");
var string_DASH_substring8 = NAMESPACE.get("string-substring");
var torepr9 = NAMESPACE.get("torepr");
var tostring10 = NAMESPACE.get("tostring");
var $type$Boolean11 = NAMESPACE.get("$type$Boolean");
var $type$String12 = NAMESPACE.get("$type$String");
var $Hreserved_DASH_names169241 = function(reserved_DASH_names7442,A113,A222,C515,C624,List1943,Loc6844,Option2045,PARAM_DASH_current_DASH_where_DASH_everywhere7246,cur_DASH_shared7147,empty3048,errors6949,in_DASH_check_DASH_block7050,is_DASH_empty2851,is_DASH_s_DASH_let7352,link3153,list2754,lists1118,map3955,some6456,_plus1,builtins2,not3,nothing4,print5,raise6,string_DASH_length7,string_DASH_substring8,torepr9,tostring10,$type$Boolean11,$type$String12) {
var add_DASH_error7557 = {"$var":D,
"$name":"add-error"};
var wf_DASH_error7659 = {"$var":D,
"$name":"wf-error"};
var wf_DASH_error27761 = {"$var":D,
"$name":"wf-error2"};
var duplicate_DASH_id7863 = {"$var":D,
"$name":"duplicate-id"};
var reserved_DASH_name7965 = {"$var":D,
"$name":"reserved-name"};
var wrap_DASH_visit_DASH_check8067 = {"$var":D,
"$name":"wrap-visit-check"};
var anf_assign658 = R.makeFunction(function(err812725) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[493],1,arguments);
}
var anf_fun42736 = R.makeFunction(function(arg_DASH_12739) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[494],1,arguments);
}
var $z27422743 = D;
var $f27482749 = function(_) {
return R.isFunction(link3153)?link3153.app(arg_DASH_12739,errors6949.$var):R.ffi.throwNonFunApp(L[494],link3153,[arg_DASH_12739,errors6949.$var]);
};
try {
if(--R.GAS > 0) {
$z27422743 = $f27482749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27482749,
"from":L[494]});
}
} catch($e27402741) {
if(R.isCont($e27402741)) {
var $ss27442745 = {"from":L[494],
"go":function(ann_DASH_check_DASH_temp32750) {
return $Hann_DASH_check_DASH_temp12282751(ann_DASH_check_DASH_temp32750);
}};
$e27402741.stack[R.EXN_STACKHEIGHT++] = $ss27442745;
}
if(R.isPyretException($e27402741)) {
$e27402741.pyretStack.push(L[494]);
}
throw $e27402741;
}
var $ret27462747 = $Hann_DASH_check_DASH_temp12282751($z27422743);
++R.GAS;
return $ret27462747;
});
var $z27282729 = D;
var $f27342735 = function(_) {
return R.isFunction(anf_fun42736)?anf_fun42736.app(err812725):R.ffi.throwNonFunApp(L[494],anf_fun42736,[err812725]);
};
try {
if(--R.GAS > 0) {
$z27282729 = $f27342735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27342735,
"from":L[494]});
}
} catch($e27262727) {
if(R.isCont($e27262727)) {
var $ss27302731 = {"from":L[494],
"go":function(anf_assign52737) {
return $Hanf_assign12292738(anf_assign52737,errors6949,nothing4);
}};
$e27262727.stack[R.EXN_STACKHEIGHT++] = $ss27302731;
}
if(R.isPyretException($e27262727)) {
$e27262727.pyretStack.push(L[494]);
}
throw $e27262727;
}
var $ret27322733 = $Hanf_assign12292738($z27282729,errors6949,nothing4);
++R.GAS;
return $ret27322733;
});
add_DASH_error7557.$var = anf_assign658;
var anf_assign1060 = R.makeFunction(function(msg822710,loc832711) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[490],2,arguments);
}
var anf_fun82722 = G(C515,"wf-err",L[492]);
var $z27142715 = D;
var $f27202721 = function(_) {
return R.isFunction(anf_fun82722)?anf_fun82722.app(msg822710,loc832711):R.ffi.throwNonFunApp(L[491],anf_fun82722,[msg822710,loc832711]);
};
try {
if(--R.GAS > 0) {
$z27142715 = $f27202721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27202721,
"from":L[491]});
}
} catch($e27122713) {
if(R.isCont($e27122713)) {
var $ss27162717 = {"from":L[491],
"go":function(anf_arg92723) {
return $Hanf_arg12312724(anf_arg92723,add_DASH_error7557);
}};
$e27122713.stack[R.EXN_STACKHEIGHT++] = $ss27162717;
}
if(R.isPyretException($e27122713)) {
$e27122713.pyretStack.push(L[491]);
}
throw $e27122713;
}
var $ret27182719 = $Hanf_arg12312724($z27142715,add_DASH_error7557);
++R.GAS;
return $ret27182719;
});
wf_DASH_error7659.$var = anf_assign1060;
var anf_assign1662 = R.makeFunction(function(msg842693,loc1852694,loc2862695) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[487],3,arguments);
}
var anf_fun122708 = G(C515,"wf-err-split",L[489]);
var anf_fun132706 = G(list2754,"make",L[488]);
var $z26982699 = D;
var $f27042705 = function(_) {
return R.isFunction(anf_fun132706)?anf_fun132706.app([loc1852694,loc2862695]):R.ffi.throwNonFunApp(L[488],anf_fun132706,[[loc1852694,loc2862695]]);
};
try {
if(--R.GAS > 0) {
$z26982699 = $f27042705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27042705,
"from":L[488]});
}
} catch($e26962697) {
if(R.isCont($e26962697)) {
var $ss27002701 = {"from":L[488],
"go":function(anf_arg142707) {
return $Hanf_arg12342709(anf_arg142707,add_DASH_error7557,anf_fun122708,msg842693);
}};
$e26962697.stack[R.EXN_STACKHEIGHT++] = $ss27002701;
}
if(R.isPyretException($e26962697)) {
$e26962697.pyretStack.push(L[488]);
}
throw $e26962697;
}
var $ret27022703 = $Hanf_arg12342709($z26982699,add_DASH_error7557,anf_fun122708,msg842693);
++R.GAS;
return $ret27022703;
});
wf_DASH_error27761.$var = anf_assign1662;
var anf_assign2064 = R.makeFunction(function(id872677,loc1882678,loc2892679) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[484],3,arguments);
}
var anf_fun182690 = G(C515,"duplicate-id",L[486]);
var $z26822683 = D;
var $f26882689 = function(_) {
return R.isFunction(anf_fun182690)?anf_fun182690.app(id872677,loc1882678,loc2892679):R.ffi.throwNonFunApp(L[485],anf_fun182690,[id872677,loc1882678,loc2892679]);
};
try {
if(--R.GAS > 0) {
$z26822683 = $f26882689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26882689,
"from":L[485]});
}
} catch($e26802681) {
if(R.isCont($e26802681)) {
var $ss26842685 = {"from":L[485],
"go":function(anf_arg192691) {
return $Hanf_arg12362692(anf_arg192691,add_DASH_error7557);
}};
$e26802681.stack[R.EXN_STACKHEIGHT++] = $ss26842685;
}
if(R.isPyretException($e26802681)) {
$e26802681.pyretStack.push(L[485]);
}
throw $e26802681;
}
var $ret26862687 = $Hanf_arg12362692($z26822683,add_DASH_error7557);
++R.GAS;
return $ret26862687;
});
duplicate_DASH_id7863.$var = anf_assign2064;
var anf_assign2466 = R.makeFunction(function(loc902662,id912663) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[481],2,arguments);
}
var anf_fun222674 = G(C515,"reserved-name",L[483]);
var $z26662667 = D;
var $f26722673 = function(_) {
return R.isFunction(anf_fun222674)?anf_fun222674.app(loc902662,id912663):R.ffi.throwNonFunApp(L[482],anf_fun222674,[loc902662,id912663]);
};
try {
if(--R.GAS > 0) {
$z26662667 = $f26722673();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26722673,
"from":L[482]});
}
} catch($e26642665) {
if(R.isCont($e26642665)) {
var $ss26682669 = {"from":L[482],
"go":function(anf_arg232675) {
return $Hanf_arg12382676(anf_arg232675,add_DASH_error7557);
}};
$e26642665.stack[R.EXN_STACKHEIGHT++] = $ss26682669;
}
if(R.isPyretException($e26642665)) {
$e26642665.pyretStack.push(L[482]);
}
throw $e26642665;
}
var $ret26702671 = $Hanf_arg12382676($z26662667,add_DASH_error7557);
++R.GAS;
return $ret26702671;
});
reserved_DASH_name7965.$var = anf_assign2466;
var anf_assign2768 = R.makeFunction(function(self922646,target932647) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[478],2,arguments);
}
var cur_DASH_in_DASH_check942660 = in_DASH_check_DASH_block7050.$var;
in_DASH_check_DASH_block7050.$var = (true);
var anf_fun262658 = G(self922646,"option",L[480]);
var $z26502651 = D;
var $f26562657 = function(_) {
return R.isFunction(anf_fun262658)?anf_fun262658.app(target932647):R.ffi.throwNonFunApp(L[479],anf_fun262658,[target932647]);
};
try {
if(--R.GAS > 0) {
$z26502651 = $f26562657();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26562657,
"from":L[479]});
}
} catch($e26482649) {
if(R.isCont($e26482649)) {
var $ss26522653 = {"from":L[479],
"go":function(ret952659) {
return $Hret12392661(ret952659,cur_DASH_in_DASH_check942660,in_DASH_check_DASH_block7050);
}};
$e26482649.stack[R.EXN_STACKHEIGHT++] = $ss26522653;
}
if(R.isPyretException($e26482649)) {
$e26482649.pyretStack.push(L[479]);
}
throw $e26482649;
}
var $ret26542655 = $Hret12392661($z26502651,cur_DASH_in_DASH_check942660,in_DASH_check_DASH_block7050);
++R.GAS;
return $ret26542655;
});
wrap_DASH_visit_DASH_check8067.$var = anf_assign2768;
var is_DASH_s_DASH_block962645 = G(A113,"is-s-block",L[477]);
var ensure_DASH_empty_DASH_block9769 = {"$var":D,
"$name":"ensure-empty-block"};
var ensure_DASH_unique_DASH_cases9871 = {"$var":D,
"$name":"ensure-unique-cases"};
var ensure_DASH_unique_DASH_ids9973 = {"$var":D,
"$name":"ensure-unique-ids"};
var ensure_DASH_unique_DASH_bindings10075 = {"$var":D,
"$name":"ensure-unique-bindings"};
var ensure_DASH_unique_DASH_variant_DASH_ids10177 = {"$var":D,
"$name":"ensure-unique-variant-ids"};
var wf_DASH_last_DASH_stmt10279 = {"$var":D,
"$name":"wf-last-stmt"};
var fields_DASH_to_DASH_binds10381 = {"$var":D,
"$name":"fields-to-binds"};
var opname10483 = {"$var":D,
"$name":"opname"};
var reachable_DASH_ops10585 = {"$var":D,
"$name":"reachable-ops"};
var anf_assign4670 = R.makeFunction(function(loc1062630,typ1072631,block1082632) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[473],3,arguments);
}
return R.checkAnnArgs([R.makePredAnn(R.getDotAnn(L[475],"A",A222,"Expr"),is_DASH_s_DASH_block962645,"is-s-block")],[block1082632],[L[476]],function() {
var $z26352636 = D;
var $f26412642 = function(_) {
return R.isFunction(not3)?not3.app(PARAM_DASH_current_DASH_where_DASH_everywhere7246.$var):R.ffi.throwNonFunApp(L[474],not3,[PARAM_DASH_current_DASH_where_DASH_everywhere7246.$var]);
};
try {
if(--R.GAS > 0) {
$z26352636 = $f26412642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26412642,
"from":L[474]});
}
} catch($e26332634) {
if(R.isCont($e26332634)) {
var $ss26372638 = {"from":L[474],
"go":function(if_DASH_22643) {
return $Hif_DASH_12462644(if_DASH_22643,block1082632,loc1062630,typ1072631,wf_DASH_error7659,_plus1,nothing4,tostring10);
}};
$e26332634.stack[R.EXN_STACKHEIGHT++] = $ss26372638;
}
if(R.isPyretException($e26332634)) {
$e26332634.pyretStack.push(L[474]);
}
throw $e26332634;
}
var $ret26392640 = $Hif_DASH_12462644($z26352636,block1082632,loc1062630,typ1072631,wf_DASH_error7659,_plus1,nothing4,tostring10);
++R.GAS;
return $ret26392640;
});
});
ensure_DASH_empty_DASH_block9769.$var = anf_assign4670;
var anf_assign7672 = R.makeFunction(function(_cases1092568) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[462],1,arguments);
}
return R.checkAnnArgs([List1943],[_cases1092568],[L[472]],function() {
var cases_DASH_val62629 = _cases1092568;
var anf_fun482579 = G(cases_DASH_val62629,"_match",L[463]);
var anf_obj502585 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[471],0,arguments);
}
var ann_DASH_check_DASH_temp492628 = nothing4;
return ann_DASH_check_DASH_temp492628;
});
var anf_obj722586 = R.makeFunction(function(f1102587,rest1112588) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[464],2,arguments);
}
var cases_DASH_val52627 = f1102587;
var anf_fun522599 = G(cases_DASH_val52627,"_match",L[465]);
var anf_obj682605 = R.makeFunction(function(l1122606,name1132607,args1142608,body1152609) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[466],4,arguments);
}
var anf_fun542620 = G(lists1118,"find",L[470]);
var anf_arg572621 = R.makeFunction(function(b1162624) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[468],1,arguments);
}
var anf_arg562626 = G(b1162624,"name",L[469]);
var ann_DASH_check_DASH_temp552625 = R.equiv(anf_arg562626,name1132607);
return ann_DASH_check_DASH_temp552625;
});
var $z26122613 = D;
var $f26182619 = function(_) {
return R.isFunction(anf_fun542620)?anf_fun542620.app(anf_arg572621,rest1112588):R.ffi.throwNonFunApp(L[467],anf_fun542620,[anf_arg572621,rest1112588]);
};
try {
if(--R.GAS > 0) {
$z26122613 = $f26182619();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26182619,
"from":L[467]});
}
} catch($e26102611) {
if(R.isCont($e26102611)) {
var $ss26142615 = {"from":L[467],
"go":function(cases_DASH_val42622) {
return $Hcases_DASH_val12512623(cases_DASH_val42622,ensure_DASH_unique_DASH_cases9871,l1122606,name1132607,rest1112588,wf_DASH_error27761,_plus1);
}};
$e26102611.stack[R.EXN_STACKHEIGHT++] = $ss26142615;
}
if(R.isPyretException($e26102611)) {
$e26102611.pyretStack.push(L[467]);
}
throw $e26102611;
}
var $ret26162617 = $Hcases_DASH_val12512623($z26122613,ensure_DASH_unique_DASH_cases9871,l1122606,name1132607,rest1112588,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret26162617;
});
var anf_arg692600 = R.makeObject({"s-cases-branch":anf_obj682605});
var anf_arg712601 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[465],0,arguments);
}
var ann_DASH_check_DASH_temp702604 = R.throwNoBranchesMatched(L[465],("cases"));
return ann_DASH_check_DASH_temp702604;
});
var $z25912592 = D;
var $f25972598 = function(_) {
return R.isFunction(anf_fun522599)?anf_fun522599.app(anf_arg692600,anf_arg712601):R.ffi.throwNonFunApp(L[464],anf_fun522599,[anf_arg692600,anf_arg712601]);
};
try {
if(--R.GAS > 0) {
$z25912592 = $f25972598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25972598,
"from":L[464]});
}
} catch($e25892590) {
if(R.isCont($e25892590)) {
var $ss25932594 = {"from":L[464],
"go":function(ann_DASH_check_DASH_temp512602) {
return $Hann_DASH_check_DASH_temp12522603(ann_DASH_check_DASH_temp512602);
}};
$e25892590.stack[R.EXN_STACKHEIGHT++] = $ss25932594;
}
if(R.isPyretException($e25892590)) {
$e25892590.pyretStack.push(L[464]);
}
throw $e25892590;
}
var $ret25952596 = $Hann_DASH_check_DASH_temp12522603($z25912592);
++R.GAS;
return $ret25952596;
});
var anf_arg732580 = R.makeObject({"empty":anf_obj502585,
"link":anf_obj722586});
var anf_arg752581 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[463],0,arguments);
}
var ann_DASH_check_DASH_temp742584 = R.throwNoBranchesMatched(L[463],("cases"));
return ann_DASH_check_DASH_temp742584;
});
var $z25712572 = D;
var $f25772578 = function(_) {
return R.isFunction(anf_fun482579)?anf_fun482579.app(anf_arg732580,anf_arg752581):R.ffi.throwNonFunApp(L[462],anf_fun482579,[anf_arg732580,anf_arg752581]);
};
try {
if(--R.GAS > 0) {
$z25712572 = $f25772578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25772578,
"from":L[462]});
}
} catch($e25692570) {
if(R.isCont($e25692570)) {
var $ss25732574 = {"from":L[462],
"go":function(ann_DASH_check_DASH_temp472582) {
return $Hann_DASH_check_DASH_temp12532583(ann_DASH_check_DASH_temp472582);
}};
$e25692570.stack[R.EXN_STACKHEIGHT++] = $ss25732574;
}
if(R.isPyretException($e25692570)) {
$e25692570.pyretStack.push(L[462]);
}
throw $e25692570;
}
var $ret25752576 = $Hann_DASH_check_DASH_temp12532583($z25712572);
++R.GAS;
return $ret25752576;
});
});
ensure_DASH_unique_DASH_cases9871.$var = anf_assign7672;
var anf_assign11974 = R.makeFunction(function(bindings1182510) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[453],1,arguments);
}
return R.checkAnnArgs([List1943],[bindings1182510],[L[461]],function() {
var cases_DASH_val102567 = bindings1182510;
var anf_fun782521 = G(cases_DASH_val102567,"_match",L[454]);
var anf_obj802527 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[460],0,arguments);
}
var ann_DASH_check_DASH_temp792566 = nothing4;
return ann_DASH_check_DASH_temp792566;
});
var anf_obj1152528 = R.makeFunction(function(f1192529,rest1202530) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[455],2,arguments);
}
var cases_DASH_val92565 = f1192529;
var anf_fun822541 = G(cases_DASH_val92565,"_match",L[456]);
var anf_obj1112547 = R.makeFunction(function(l1212548,shadows1222549,id1232550,ann1242551) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[457],4,arguments);
}
var anf_fun842562 = G(A113,"is-s-underscore",L[459]);
var $z25542555 = D;
var $f25602561 = function(_) {
return R.isFunction(anf_fun842562)?anf_fun842562.app(id1232550):R.ffi.throwNonFunApp(L[458],anf_fun842562,[id1232550]);
};
try {
if(--R.GAS > 0) {
$z25542555 = $f25602561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25602561,
"from":L[458]});
}
} catch($e25522553) {
if(R.isCont($e25522553)) {
var $ss25562557 = {"from":L[458],
"go":function(if_DASH_82563) {
return $Hif_DASH_12652564(if_DASH_82563,ensure_DASH_unique_DASH_ids9973,id1232550,l1212548,lists1118,rest1202530,wf_DASH_error27761,_plus1,nothing4,print5,torepr9,tostring10);
}};
$e25522553.stack[R.EXN_STACKHEIGHT++] = $ss25562557;
}
if(R.isPyretException($e25522553)) {
$e25522553.pyretStack.push(L[458]);
}
throw $e25522553;
}
var $ret25582559 = $Hif_DASH_12652564($z25542555,ensure_DASH_unique_DASH_ids9973,id1232550,l1212548,lists1118,rest1202530,wf_DASH_error27761,_plus1,nothing4,print5,torepr9,tostring10);
++R.GAS;
return $ret25582559;
});
var anf_arg1122542 = R.makeObject({"s-bind":anf_obj1112547});
var anf_arg1142543 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[456],0,arguments);
}
var ann_DASH_check_DASH_temp1132546 = R.throwNoBranchesMatched(L[456],("cases"));
return ann_DASH_check_DASH_temp1132546;
});
var $z25332534 = D;
var $f25392540 = function(_) {
return R.isFunction(anf_fun822541)?anf_fun822541.app(anf_arg1122542,anf_arg1142543):R.ffi.throwNonFunApp(L[455],anf_fun822541,[anf_arg1122542,anf_arg1142543]);
};
try {
if(--R.GAS > 0) {
$z25332534 = $f25392540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25392540,
"from":L[455]});
}
} catch($e25312532) {
if(R.isCont($e25312532)) {
var $ss25352536 = {"from":L[455],
"go":function(ann_DASH_check_DASH_temp812544) {
return $Hann_DASH_check_DASH_temp12662545(ann_DASH_check_DASH_temp812544);
}};
$e25312532.stack[R.EXN_STACKHEIGHT++] = $ss25352536;
}
if(R.isPyretException($e25312532)) {
$e25312532.pyretStack.push(L[455]);
}
throw $e25312532;
}
var $ret25372538 = $Hann_DASH_check_DASH_temp12662545($z25332534);
++R.GAS;
return $ret25372538;
});
var anf_arg1162522 = R.makeObject({"empty":anf_obj802527,
"link":anf_obj1152528});
var anf_arg1182523 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[454],0,arguments);
}
var ann_DASH_check_DASH_temp1172526 = R.throwNoBranchesMatched(L[454],("cases"));
return ann_DASH_check_DASH_temp1172526;
});
var $z25132514 = D;
var $f25192520 = function(_) {
return R.isFunction(anf_fun782521)?anf_fun782521.app(anf_arg1162522,anf_arg1182523):R.ffi.throwNonFunApp(L[453],anf_fun782521,[anf_arg1162522,anf_arg1182523]);
};
try {
if(--R.GAS > 0) {
$z25132514 = $f25192520();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25192520,
"from":L[453]});
}
} catch($e25112512) {
if(R.isCont($e25112512)) {
var $ss25152516 = {"from":L[453],
"go":function(ann_DASH_check_DASH_temp772524) {
return $Hann_DASH_check_DASH_temp12672525(ann_DASH_check_DASH_temp772524);
}};
$e25112512.stack[R.EXN_STACKHEIGHT++] = $ss25152516;
}
if(R.isPyretException($e25112512)) {
$e25112512.pyretStack.push(L[453]);
}
throw $e25112512;
}
var $ret25172518 = $Hann_DASH_check_DASH_temp12672525($z25132514);
++R.GAS;
return $ret25172518;
});
});
ensure_DASH_unique_DASH_ids9973.$var = anf_assign11974;
var anf_assign16276 = R.makeFunction(function(rev_DASH_bindings1282452) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[444],1,arguments);
}
return R.checkAnnArgs([List1943],[rev_DASH_bindings1282452],[L[452]],function() {
var cases_DASH_val152509 = rev_DASH_bindings1282452;
var anf_fun1212463 = G(cases_DASH_val152509,"_match",L[445]);
var anf_obj1232469 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[451],0,arguments);
}
var ann_DASH_check_DASH_temp1222508 = nothing4;
return ann_DASH_check_DASH_temp1222508;
});
var anf_obj1582470 = R.makeFunction(function(f1292471,rest1302472) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[446],2,arguments);
}
var cases_DASH_val142507 = f1292471;
var anf_fun1252483 = G(cases_DASH_val142507,"_match",L[447]);
var anf_obj1542489 = R.makeFunction(function(l1312490,shadows1322491,id1332492,ann1342493) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[448],4,arguments);
}
var anf_fun1272504 = G(A113,"is-s-underscore",L[450]);
var $z24962497 = D;
var $f25022503 = function(_) {
return R.isFunction(anf_fun1272504)?anf_fun1272504.app(id1332492):R.ffi.throwNonFunApp(L[449],anf_fun1272504,[id1332492]);
};
try {
if(--R.GAS > 0) {
$z24962497 = $f25022503();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25022503,
"from":L[449]});
}
} catch($e24942495) {
if(R.isCont($e24942495)) {
var $ss24982499 = {"from":L[449],
"go":function(if_DASH_132505) {
return $Hif_DASH_12752506(if_DASH_132505,duplicate_DASH_id7863,ensure_DASH_unique_DASH_bindings10075,id1332492,l1312490,lists1118,rest1302472,shadows1322491,nothing4,tostring10);
}};
$e24942495.stack[R.EXN_STACKHEIGHT++] = $ss24982499;
}
if(R.isPyretException($e24942495)) {
$e24942495.pyretStack.push(L[449]);
}
throw $e24942495;
}
var $ret25002501 = $Hif_DASH_12752506($z24962497,duplicate_DASH_id7863,ensure_DASH_unique_DASH_bindings10075,id1332492,l1312490,lists1118,rest1302472,shadows1322491,nothing4,tostring10);
++R.GAS;
return $ret25002501;
});
var anf_arg1552484 = R.makeObject({"s-bind":anf_obj1542489});
var anf_arg1572485 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[447],0,arguments);
}
var ann_DASH_check_DASH_temp1562488 = R.throwNoBranchesMatched(L[447],("cases"));
return ann_DASH_check_DASH_temp1562488;
});
var $z24752476 = D;
var $f24812482 = function(_) {
return R.isFunction(anf_fun1252483)?anf_fun1252483.app(anf_arg1552484,anf_arg1572485):R.ffi.throwNonFunApp(L[446],anf_fun1252483,[anf_arg1552484,anf_arg1572485]);
};
try {
if(--R.GAS > 0) {
$z24752476 = $f24812482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24812482,
"from":L[446]});
}
} catch($e24732474) {
if(R.isCont($e24732474)) {
var $ss24772478 = {"from":L[446],
"go":function(ann_DASH_check_DASH_temp1242486) {
return $Hann_DASH_check_DASH_temp12762487(ann_DASH_check_DASH_temp1242486);
}};
$e24732474.stack[R.EXN_STACKHEIGHT++] = $ss24772478;
}
if(R.isPyretException($e24732474)) {
$e24732474.pyretStack.push(L[446]);
}
throw $e24732474;
}
var $ret24792480 = $Hann_DASH_check_DASH_temp12762487($z24752476);
++R.GAS;
return $ret24792480;
});
var anf_arg1592464 = R.makeObject({"empty":anf_obj1232469,
"link":anf_obj1582470});
var anf_arg1612465 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[445],0,arguments);
}
var ann_DASH_check_DASH_temp1602468 = R.throwNoBranchesMatched(L[445],("cases"));
return ann_DASH_check_DASH_temp1602468;
});
var $z24552456 = D;
var $f24612462 = function(_) {
return R.isFunction(anf_fun1212463)?anf_fun1212463.app(anf_arg1592464,anf_arg1612465):R.ffi.throwNonFunApp(L[444],anf_fun1212463,[anf_arg1592464,anf_arg1612465]);
};
try {
if(--R.GAS > 0) {
$z24552456 = $f24612462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24612462,
"from":L[444]});
}
} catch($e24532454) {
if(R.isCont($e24532454)) {
var $ss24572458 = {"from":L[444],
"go":function(ann_DASH_check_DASH_temp1202466) {
return $Hann_DASH_check_DASH_temp12772467(ann_DASH_check_DASH_temp1202466);
}};
$e24532454.stack[R.EXN_STACKHEIGHT++] = $ss24572458;
}
if(R.isPyretException($e24532454)) {
$e24532454.pyretStack.push(L[444]);
}
throw $e24532454;
}
var $ret24592460 = $Hann_DASH_check_DASH_temp12772467($z24552456);
++R.GAS;
return $ret24592460;
});
});
ensure_DASH_unique_DASH_bindings10075.$var = anf_assign16276;
var anf_assign19078 = R.makeFunction(function(variants1372411) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[434],1,arguments);
}
return R.checkAnnArgs([List1943],[variants1372411],[L[443]],function() {
var cases_DASH_val172451 = variants1372411;
var anf_fun1642422 = G(cases_DASH_val172451,"_match",L[435]);
var anf_obj1662428 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[442],0,arguments);
}
var ann_DASH_check_DASH_temp1652450 = nothing4;
return ann_DASH_check_DASH_temp1652450;
});
var anf_obj1862429 = R.makeFunction(function(f1382430,rest1392431) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[436],2,arguments);
}
var anf_fun1682442 = G(lists1118,"find",L[441]);
var anf_arg1722443 = R.makeFunction(function(b1402446) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[438],1,arguments);
}
var anf_arg1702448 = G(b1402446,"name",L[440]);
var anf_arg1712449 = G(f1382430,"name",L[439]);
var ann_DASH_check_DASH_temp1692447 = R.equiv(anf_arg1702448,anf_arg1712449);
return ann_DASH_check_DASH_temp1692447;
});
var $z24342435 = D;
var $f24402441 = function(_) {
return R.isFunction(anf_fun1682442)?anf_fun1682442.app(anf_arg1722443,rest1392431):R.ffi.throwNonFunApp(L[437],anf_fun1682442,[anf_arg1722443,rest1392431]);
};
try {
if(--R.GAS > 0) {
$z24342435 = $f24402441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24402441,
"from":L[437]});
}
} catch($e24322433) {
if(R.isCont($e24322433)) {
var $ss24362437 = {"from":L[437],
"go":function(cases_DASH_val162444) {
return $Hcases_DASH_val12832445(cases_DASH_val162444,ensure_DASH_unique_DASH_variant_DASH_ids10177,f1382430,rest1392431,wf_DASH_error27761,_plus1);
}};
$e24322433.stack[R.EXN_STACKHEIGHT++] = $ss24362437;
}
if(R.isPyretException($e24322433)) {
$e24322433.pyretStack.push(L[437]);
}
throw $e24322433;
}
var $ret24382439 = $Hcases_DASH_val12832445($z24342435,ensure_DASH_unique_DASH_variant_DASH_ids10177,f1382430,rest1392431,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret24382439;
});
var anf_arg1872423 = R.makeObject({"empty":anf_obj1662428,
"link":anf_obj1862429});
var anf_arg1892424 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[435],0,arguments);
}
var ann_DASH_check_DASH_temp1882427 = R.throwNoBranchesMatched(L[435],("cases"));
return ann_DASH_check_DASH_temp1882427;
});
var $z24142415 = D;
var $f24202421 = function(_) {
return R.isFunction(anf_fun1642422)?anf_fun1642422.app(anf_arg1872423,anf_arg1892424):R.ffi.throwNonFunApp(L[434],anf_fun1642422,[anf_arg1872423,anf_arg1892424]);
};
try {
if(--R.GAS > 0) {
$z24142415 = $f24202421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24202421,
"from":L[434]});
}
} catch($e24122413) {
if(R.isCont($e24122413)) {
var $ss24162417 = {"from":L[434],
"go":function(ann_DASH_check_DASH_temp1632425) {
return $Hann_DASH_check_DASH_temp12842426(ann_DASH_check_DASH_temp1632425);
}};
$e24122413.stack[R.EXN_STACKHEIGHT++] = $ss24162417;
}
if(R.isPyretException($e24122413)) {
$e24122413.pyretStack.push(L[434]);
}
throw $e24122413;
}
var $ret24182419 = $Hann_DASH_check_DASH_temp12842426($z24142415);
++R.GAS;
return $ret24182419;
});
});
ensure_DASH_unique_DASH_variant_DASH_ids10177.$var = anf_assign19078;
var anf_assign20880 = R.makeFunction(function(stmt1422286) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[425],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[433],"A",A222,"Expr")],[stmt1422286],[L[433]],function() {
var cases_DASH_val182410 = stmt1422286;
var anf_fun1922297 = G(cases_DASH_val182410,"_match",L[426]);
var anf_obj1942303 = R.makeFunction(function(l1432394,$underscore1442395,$underscore1452396,$underscore1462397) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[432],4,arguments);
}
var $z24002401 = D;
var $f24062407 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot end a block in a let-binding"),l1432394):R.ffi.throwNonFunApp(L[432],wf_DASH_error7659.$var,[("Cannot end a block in a let-binding"),l1432394]);
};
try {
if(--R.GAS > 0) {
$z24002401 = $f24062407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24062407,
"from":L[432]});
}
} catch($e23982399) {
if(R.isCont($e23982399)) {
var $ss24022403 = {"from":L[432],
"go":function(ann_DASH_check_DASH_temp1932408) {
return $Hann_DASH_check_DASH_temp12852409(ann_DASH_check_DASH_temp1932408);
}};
$e23982399.stack[R.EXN_STACKHEIGHT++] = $ss24022403;
}
if(R.isPyretException($e23982399)) {
$e23982399.pyretStack.push(L[432]);
}
throw $e23982399;
}
var $ret24042405 = $Hann_DASH_check_DASH_temp12852409($z24002401);
++R.GAS;
return $ret24042405;
});
var anf_obj1962304 = R.makeFunction(function(l1472379,$underscore1482380,$underscore1492381) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[431],3,arguments);
}
var $z23842385 = D;
var $f23902391 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot end a block in a var-binding"),l1472379):R.ffi.throwNonFunApp(L[431],wf_DASH_error7659.$var,[("Cannot end a block in a var-binding"),l1472379]);
};
try {
if(--R.GAS > 0) {
$z23842385 = $f23902391();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23902391,
"from":L[431]});
}
} catch($e23822383) {
if(R.isCont($e23822383)) {
var $ss23862387 = {"from":L[431],
"go":function(ann_DASH_check_DASH_temp1952392) {
return $Hann_DASH_check_DASH_temp12862393(ann_DASH_check_DASH_temp1952392);
}};
$e23822383.stack[R.EXN_STACKHEIGHT++] = $ss23862387;
}
if(R.isPyretException($e23822383)) {
$e23822383.pyretStack.push(L[431]);
}
throw $e23822383;
}
var $ret23882389 = $Hann_DASH_check_DASH_temp12862393($z23842385);
++R.GAS;
return $ret23882389;
});
var anf_obj1982305 = R.makeFunction(function(l1502359,$underscore1512360,$underscore1522361,$underscore1532362,$underscore1542363,$underscore1552364,$underscore1562365,$underscore1572366) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[430],8,arguments);
}
var $z23692370 = D;
var $f23752376 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot end a block in a fun-binding"),l1502359):R.ffi.throwNonFunApp(L[430],wf_DASH_error7659.$var,[("Cannot end a block in a fun-binding"),l1502359]);
};
try {
if(--R.GAS > 0) {
$z23692370 = $f23752376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23752376,
"from":L[430]});
}
} catch($e23672368) {
if(R.isCont($e23672368)) {
var $ss23712372 = {"from":L[430],
"go":function(ann_DASH_check_DASH_temp1972377) {
return $Hann_DASH_check_DASH_temp12872378(ann_DASH_check_DASH_temp1972377);
}};
$e23672368.stack[R.EXN_STACKHEIGHT++] = $ss23712372;
}
if(R.isPyretException($e23672368)) {
$e23672368.pyretStack.push(L[430]);
}
throw $e23672368;
}
var $ret23732374 = $Hann_DASH_check_DASH_temp12872378($z23692370);
++R.GAS;
return $ret23732374;
});
var anf_obj2002306 = R.makeFunction(function(l1582340,$underscore1592341,$underscore1602342,$underscore1612343,$underscore1622344,$underscore1632345,$underscore1642346) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[429],7,arguments);
}
var $z23492350 = D;
var $f23552356 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot end a block with a data definition"),l1582340):R.ffi.throwNonFunApp(L[429],wf_DASH_error7659.$var,[("Cannot end a block with a data definition"),l1582340]);
};
try {
if(--R.GAS > 0) {
$z23492350 = $f23552356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23552356,
"from":L[429]});
}
} catch($e23472348) {
if(R.isCont($e23472348)) {
var $ss23512352 = {"from":L[429],
"go":function(ann_DASH_check_DASH_temp1992357) {
return $Hann_DASH_check_DASH_temp12882358(ann_DASH_check_DASH_temp1992357);
}};
$e23472348.stack[R.EXN_STACKHEIGHT++] = $ss23512352;
}
if(R.isPyretException($e23472348)) {
$e23472348.pyretStack.push(L[429]);
}
throw $e23472348;
}
var $ret23532354 = $Hann_DASH_check_DASH_temp12882358($z23492350);
++R.GAS;
return $ret23532354;
});
var anf_obj2022307 = R.makeFunction(function(l1652323,$underscore1662324,$underscore1672325,$underscore1682326,$underscore1692327) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[428],5,arguments);
}
var $z23302331 = D;
var $f23362337 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot end a block with a datatype definition"),l1652323):R.ffi.throwNonFunApp(L[428],wf_DASH_error7659.$var,[("Cannot end a block with a datatype definition"),l1652323]);
};
try {
if(--R.GAS > 0) {
$z23302331 = $f23362337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23362337,
"from":L[428]});
}
} catch($e23282329) {
if(R.isCont($e23282329)) {
var $ss23322333 = {"from":L[428],
"go":function(ann_DASH_check_DASH_temp2012338) {
return $Hann_DASH_check_DASH_temp12892339(ann_DASH_check_DASH_temp2012338);
}};
$e23282329.stack[R.EXN_STACKHEIGHT++] = $ss23322333;
}
if(R.isPyretException($e23282329)) {
$e23282329.pyretStack.push(L[428]);
}
throw $e23282329;
}
var $ret23342335 = $Hann_DASH_check_DASH_temp12892339($z23302331);
++R.GAS;
return $ret23342335;
});
var anf_obj2042308 = R.makeFunction(function(l1702309,$underscore1712310) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[427],2,arguments);
}
var $z23132314 = D;
var $f23192320 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot end a block with a graph definition"),l1702309):R.ffi.throwNonFunApp(L[427],wf_DASH_error7659.$var,[("Cannot end a block with a graph definition"),l1702309]);
};
try {
if(--R.GAS > 0) {
$z23132314 = $f23192320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23192320,
"from":L[427]});
}
} catch($e23112312) {
if(R.isCont($e23112312)) {
var $ss23152316 = {"from":L[427],
"go":function(ann_DASH_check_DASH_temp2032321) {
return $Hann_DASH_check_DASH_temp12902322(ann_DASH_check_DASH_temp2032321);
}};
$e23112312.stack[R.EXN_STACKHEIGHT++] = $ss23152316;
}
if(R.isPyretException($e23112312)) {
$e23112312.pyretStack.push(L[427]);
}
throw $e23112312;
}
var $ret23172318 = $Hann_DASH_check_DASH_temp12902322($z23132314);
++R.GAS;
return $ret23172318;
});
var anf_arg2052298 = R.makeObject({"s-let":anf_obj1942303,
"s-var":anf_obj1962304,
"s-fun":anf_obj1982305,
"s-data":anf_obj2002306,
"s-datatype":anf_obj2022307,
"s-graph":anf_obj2042308});
var anf_arg2072299 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[426],0,arguments);
}
var ann_DASH_check_DASH_temp2062302 = nothing4;
return ann_DASH_check_DASH_temp2062302;
});
var $z22892290 = D;
var $f22952296 = function(_) {
return R.isFunction(anf_fun1922297)?anf_fun1922297.app(anf_arg2052298,anf_arg2072299):R.ffi.throwNonFunApp(L[425],anf_fun1922297,[anf_arg2052298,anf_arg2072299]);
};
try {
if(--R.GAS > 0) {
$z22892290 = $f22952296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22952296,
"from":L[425]});
}
} catch($e22872288) {
if(R.isCont($e22872288)) {
var $ss22912292 = {"from":L[425],
"go":function(ann_DASH_check_DASH_temp1912300) {
return $Hann_DASH_check_DASH_temp12912301(ann_DASH_check_DASH_temp1912300);
}};
$e22872288.stack[R.EXN_STACKHEIGHT++] = $ss22912292;
}
if(R.isPyretException($e22872288)) {
$e22872288.pyretStack.push(L[425]);
}
throw $e22872288;
}
var $ret22932294 = $Hann_DASH_check_DASH_temp12912301($z22892290);
++R.GAS;
return $ret22932294;
});
});
wf_DASH_last_DASH_stmt10279.$var = anf_assign20880;
var anf_assign22082 = R.makeFunction(function(members1722253) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[415],1,arguments);
}
return R.checkAnnArgs([List1943],[members1722253],[L[424]],function() {
var anf_arg2192264 = R.makeFunction(function(mem1732267) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[416],1,arguments);
}
var anf_fun2112283 = G(A113,"s-bind",L[423]);
var anf_arg2122282 = G(mem1732267,"l",L[422]);
var anf_fun2132278 = G(A113,"s-name",L[421]);
var anf_arg2142279 = G(mem1732267,"l",L[420]);
var anf_bracket2152285 = G(mem1732267,"name",L[419]);
var anf_arg2162280 = G(anf_bracket2152285,"s",L[418]);
var $z22702271 = D;
var $f22762277 = function(_) {
return R.isFunction(anf_fun2132278)?anf_fun2132278.app(anf_arg2142279,anf_arg2162280):R.ffi.throwNonFunApp(L[417],anf_fun2132278,[anf_arg2142279,anf_arg2162280]);
};
try {
if(--R.GAS > 0) {
$z22702271 = $f22762277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22762277,
"from":L[417]});
}
} catch($e22682269) {
if(R.isCont($e22682269)) {
var $ss22722273 = {"from":L[417],
"go":function(anf_arg2172281) {
return $Hanf_arg12932284(anf_arg2172281,A113,anf_arg2122282,anf_fun2112283);
}};
$e22682269.stack[R.EXN_STACKHEIGHT++] = $ss22722273;
}
if(R.isPyretException($e22682269)) {
$e22682269.pyretStack.push(L[417]);
}
throw $e22682269;
}
var $ret22742275 = $Hanf_arg12932284($z22702271,A113,anf_arg2122282,anf_fun2112283);
++R.GAS;
return $ret22742275;
});
var $z22562257 = D;
var $f22622263 = function(_) {
return R.isFunction(map3955)?map3955.app(anf_arg2192264,members1722253):R.ffi.throwNonFunApp(L[415],map3955,[anf_arg2192264,members1722253]);
};
try {
if(--R.GAS > 0) {
$z22562257 = $f22622263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22622263,
"from":L[415]});
}
} catch($e22542255) {
if(R.isCont($e22542255)) {
var $ss22582259 = {"from":L[415],
"go":function(ann_DASH_check_DASH_temp2092265) {
return $Hann_DASH_check_DASH_temp12942266(ann_DASH_check_DASH_temp2092265,A222,List1943);
}};
$e22542255.stack[R.EXN_STACKHEIGHT++] = $ss22582259;
}
if(R.isPyretException($e22542255)) {
$e22542255.pyretStack.push(L[415]);
}
throw $e22542255;
}
var $ret22602261 = $Hann_DASH_check_DASH_temp12942266($z22562257,A222,List1943);
++R.GAS;
return $ret22602261;
});
});
fields_DASH_to_DASH_binds10381.$var = anf_assign22082;
var anf_assign22384 = R.makeFunction(function(op1742240) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[413],1,arguments);
}
var $z22432244 = D;
var $f22492250 = function(_) {
return R.isFunction(string_DASH_length7)?string_DASH_length7.app(op1742240):R.ffi.throwNonFunApp(L[414],string_DASH_length7,[op1742240]);
};
try {
if(--R.GAS > 0) {
$z22432244 = $f22492250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22492250,
"from":L[414]});
}
} catch($e22412242) {
if(R.isCont($e22412242)) {
var $ss22452246 = {"from":L[414],
"go":function(anf_arg2222251) {
return $Hanf_arg12962252(anf_arg2222251,op1742240,string_DASH_substring8);
}};
$e22412242.stack[R.EXN_STACKHEIGHT++] = $ss22452246;
}
if(R.isPyretException($e22412242)) {
$e22412242.pyretStack.push(L[414]);
}
throw $e22412242;
}
var $ret22472248 = $Hanf_arg12962252($z22432244,op1742240,string_DASH_substring8);
++R.GAS;
return $ret22472248;
});
opname10483.$var = anf_assign22384;
var anf_assign24786 = R.makeFunction(function(self1752170,l1762171,op1772172,ast1782173) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[406],4,arguments);
}
var cases_DASH_val202239 = ast1782173;
var anf_fun2252184 = G(cases_DASH_val202239,"_match",L[407]);
var anf_obj2422202 = R.makeFunction(function(l21792203,op21802204,left21812205,right21822206) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[409],4,arguments);
}
var if_DASH_192232 = R.equiv(op1772172,op21802204);
var if_helper2272218 = R.makeFunction(function(if_helper_arg2282237) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[412],1,arguments);
}
if_helper_arg2282237;
var ann_DASH_check_DASH_temp2262238 = (true);
return ann_DASH_check_DASH_temp2262238;
});
var anf_if2312236 = R.isBoolean(if_DASH_192232);
if(R.isPyretTrue(anf_if2312236)) {
if(R.isPyretTrue(if_DASH_192232)) {
var $z22092210 = D;
var $f22152216 = function(_) {
return R.isFunction(reachable_DASH_ops10585.$var)?reachable_DASH_ops10585.$var.app(self1752170,l1762171,op1772172,left21812205):R.ffi.throwNonFunApp(L[410],reachable_DASH_ops10585.$var,[self1752170,l1762171,op1772172,left21812205]);
};
try {
if(--R.GAS > 0) {
$z22092210 = $f22152216();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22152216,
"from":L[410]});
}
} catch($e22072208) {
if(R.isCont($e22072208)) {
var $ss22112212 = {"from":L[410],
"go":function(anf_begin_app_dropped12972217) {
return $Hanf_begin_app_dropped12992219(anf_begin_app_dropped12972217,if_helper2272218,l1762171,op1772172,reachable_DASH_ops10585,right21822206,self1752170);
}};
$e22072208.stack[R.EXN_STACKHEIGHT++] = $ss22112212;
}
if(R.isPyretException($e22072208)) {
$e22072208.pyretStack.push(L[410]);
}
throw $e22072208;
}
var $ret22132214 = $Hanf_begin_app_dropped12992219($z22092210,if_helper2272218,l1762171,op1772172,reachable_DASH_ops10585,right21822206,self1752170);
++R.GAS;
return $ret22132214;
} else {
var $z22222223 = D;
var $f22282229 = function(_) {
return R.isFunction(opname10483.$var)?opname10483.$var.app(op1772172):R.ffi.throwNonFunApp(L[411],opname10483.$var,[op1772172]);
};
try {
if(--R.GAS > 0) {
$z22222223 = $f22282229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22282229,
"from":L[411]});
}
} catch($e22202221) {
if(R.isCont($e22202221)) {
var $ss22242225 = {"from":L[411],
"go":function(anf_arg2322230) {
return $Hanf_arg13062231(anf_arg2322230,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1);
}};
$e22202221.stack[R.EXN_STACKHEIGHT++] = $ss22242225;
}
if(R.isPyretException($e22202221)) {
$e22202221.pyretStack.push(L[411]);
}
throw $e22202221;
}
var $ret22262227 = $Hanf_arg13062231($z22222223,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret22262227;
}
} else {
var cont_tail_arg2292235 = R.throwNonBooleanCondition(L[412],("if"),if_DASH_192232);
if(--R.GAS > 0) {
$z22332234 = R.isFunction(if_helper2272218)?if_helper2272218.app(cont_tail_arg2292235):R.ffi.throwNonFunApp(L[412],if_helper2272218,[cont_tail_arg2292235]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2272218)?if_helper2272218.app(cont_tail_arg2292235):R.ffi.throwNonFunApp(L[412],if_helper2272218,[cont_tail_arg2292235]);
},
"from":L[412]});
}
++R.GAS;
return $z22332234;
}
});
var anf_arg2432185 = R.makeObject({"s-op":anf_obj2422202});
var anf_arg2462186 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[407],0,arguments);
}
var anf_fun2452199 = G(ast1782173,"visit",L[408]);
var $z21912192 = D;
var $f21972198 = function(_) {
return R.isFunction(anf_fun2452199)?anf_fun2452199.app(self1752170):R.ffi.throwNonFunApp(L[407],anf_fun2452199,[self1752170]);
};
try {
if(--R.GAS > 0) {
$z21912192 = $f21972198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21972198,
"from":L[407]});
}
} catch($e21892190) {
if(R.isCont($e21892190)) {
var $ss21932194 = {"from":L[407],
"go":function(ann_DASH_check_DASH_temp2442200) {
return $Hann_DASH_check_DASH_temp13072201(ann_DASH_check_DASH_temp2442200);
}};
$e21892190.stack[R.EXN_STACKHEIGHT++] = $ss21932194;
}
if(R.isPyretException($e21892190)) {
$e21892190.pyretStack.push(L[407]);
}
throw $e21892190;
}
var $ret21952196 = $Hann_DASH_check_DASH_temp13072201($z21912192);
++R.GAS;
return $ret21952196;
});
var $z21762177 = D;
var $f21822183 = function(_) {
return R.isFunction(anf_fun2252184)?anf_fun2252184.app(anf_arg2432185,anf_arg2462186):R.ffi.throwNonFunApp(L[406],anf_fun2252184,[anf_arg2432185,anf_arg2462186]);
};
try {
if(--R.GAS > 0) {
$z21762177 = $f21822183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21822183,
"from":L[406]});
}
} catch($e21742175) {
if(R.isCont($e21742175)) {
var $ss21782179 = {"from":L[406],
"go":function(ann_DASH_check_DASH_temp2242187) {
return $Hann_DASH_check_DASH_temp13082188(ann_DASH_check_DASH_temp2242187);
}};
$e21742175.stack[R.EXN_STACKHEIGHT++] = $ss21782179;
}
if(R.isPyretException($e21742175)) {
$e21742175.pyretStack.push(L[406]);
}
throw $e21742175;
}
var $ret21802181 = $Hann_DASH_check_DASH_temp13082188($z21762177);
++R.GAS;
return $ret21802181;
});
reachable_DASH_ops10585.$var = anf_assign24786;
var anf_extend2481665 = G(A113,"default-iter-visitor",L[405]);
var anf_extend2501666 = R.makeMethod(function(self1842164) {
return function(l1852165,_provide1862166,_provide_DASH_types1872167,imports1882168,body1892169) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[404],5,arguments);
}
var $z21542155 = D;
var $f21602161 = function(_) {
return R.isFunction(raise6)?raise6.app(("Impossible")):R.ffi.throwNonFunApp(L[404],raise6,[("Impossible")]);
};
try {
if(--R.GAS > 0) {
$z21542155 = $f21602161();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21602161,
"from":L[404]});
}
} catch($e21522153) {
if(R.isCont($e21522153)) {
var $ss21562157 = {"from":L[404],
"go":function(ann_DASH_check_DASH_temp2492162) {
return $Hann_DASH_check_DASH_temp13092163(ann_DASH_check_DASH_temp2492162);
}};
$e21522153.stack[R.EXN_STACKHEIGHT++] = $ss21562157;
}
if(R.isPyretException($e21522153)) {
$e21522153.pyretStack.push(L[404]);
}
throw $e21522153;
}
var $ret21582159 = $Hann_DASH_check_DASH_temp13092163($z21542155);
++R.GAS;
return $ret21582159;
};
},{"length":6});
var anf_extend2521667 = R.makeMethod(function(self1902145) {
return function(l1912142,name1922146,params1932147,mixins1942148,variants1952149,shares1962150,_check1972151) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[403],7,arguments);
}
var $z21342135 = D;
var $f21402141 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot define a data expression except at the top level of a file"),l1912142):R.ffi.throwNonFunApp(L[402],wf_DASH_error7659.$var,[("Cannot define a data expression except at the top level of a file"),l1912142]);
};
try {
if(--R.GAS > 0) {
$z21342135 = $f21402141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21402141,
"from":L[402]});
}
} catch($e21322133) {
if(R.isCont($e21322133)) {
var $ss21362137 = {"from":L[402],
"go":function(anf_begin_app_dropped13102143) {
return $Hanf_begin_app_dropped13112144(anf_begin_app_dropped13102143);
}};
$e21322133.stack[R.EXN_STACKHEIGHT++] = $ss21362137;
}
if(R.isPyretException($e21322133)) {
$e21322133.pyretStack.push(L[402]);
}
throw $e21322133;
}
var $ret21382139 = $Hanf_begin_app_dropped13112144($z21342135);
++R.GAS;
return $ret21382139;
};
},{"length":8});
var anf_extend2541668 = R.makeMethod(function(self1982124) {
return function(l1992121,name2002125,namet2012126,params2022127,mixins2032128,variants2042129,shared2052130,_check2062131) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[401],8,arguments);
}
var $z21132114 = D;
var $f21192120 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot define a data expression except at the top level of a file"),l1992121):R.ffi.throwNonFunApp(L[400],wf_DASH_error7659.$var,[("Cannot define a data expression except at the top level of a file"),l1992121]);
};
try {
if(--R.GAS > 0) {
$z21132114 = $f21192120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21192120,
"from":L[400]});
}
} catch($e21112112) {
if(R.isCont($e21112112)) {
var $ss21152116 = {"from":L[400],
"go":function(anf_begin_app_dropped13122122) {
return $Hanf_begin_app_dropped13132123(anf_begin_app_dropped13122122);
}};
$e21112112.stack[R.EXN_STACKHEIGHT++] = $ss21152116;
}
if(R.isPyretException($e21112112)) {
$e21112112.pyretStack.push(L[400]);
}
throw $e21112112;
}
var $ret21172118 = $Hanf_begin_app_dropped13132123($z21132114);
++R.GAS;
return $ret21172118;
};
},{"length":9});
var anf_extend2561669 = R.makeMethod(function(self2072108) {
return function(l2082105,name2092109,ann2102110) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[399],3,arguments);
}
var $z20972098 = D;
var $f21032104 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot define a type alias except at the top level of a file"),l2082105):R.ffi.throwNonFunApp(L[398],wf_DASH_error7659.$var,[("Cannot define a type alias except at the top level of a file"),l2082105]);
};
try {
if(--R.GAS > 0) {
$z20972098 = $f21032104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21032104,
"from":L[398]});
}
} catch($e20952096) {
if(R.isCont($e20952096)) {
var $ss20992100 = {"from":L[398],
"go":function(anf_begin_app_dropped13142106) {
return $Hanf_begin_app_dropped13152107(anf_begin_app_dropped13142106);
}};
$e20952096.stack[R.EXN_STACKHEIGHT++] = $ss20992100;
}
if(R.isPyretException($e20952096)) {
$e20952096.pyretStack.push(L[398]);
}
throw $e20952096;
}
var $ret21012102 = $Hanf_begin_app_dropped13152107($z20972098);
++R.GAS;
return $ret21012102;
};
},{"length":4});
var anf_extend2581670 = R.makeMethod(function(self2112092) {
return function(l2122089,name2132093,namet2142094) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[397],3,arguments);
}
var $z20812082 = D;
var $f20872088 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot define a newtype except at the top level of a file"),l2122089):R.ffi.throwNonFunApp(L[396],wf_DASH_error7659.$var,[("Cannot define a newtype except at the top level of a file"),l2122089]);
};
try {
if(--R.GAS > 0) {
$z20812082 = $f20872088();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20872088,
"from":L[396]});
}
} catch($e20792080) {
if(R.isCont($e20792080)) {
var $ss20832084 = {"from":L[396],
"go":function(anf_begin_app_dropped13162090) {
return $Hanf_begin_app_dropped13172091(anf_begin_app_dropped13162090);
}};
$e20792080.stack[R.EXN_STACKHEIGHT++] = $ss20832084;
}
if(R.isPyretException($e20792080)) {
$e20792080.pyretStack.push(L[396]);
}
throw $e20792080;
}
var $ret20852086 = $Hanf_begin_app_dropped13172091($z20812082);
++R.GAS;
return $ret20852086;
};
},{"length":4});
var anf_extend2601671 = R.makeMethod(function(self2152076) {
return function(l2162073,binds2172077,body2182078) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[395],3,arguments);
}
var $z20652066 = D;
var $f20712072 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot define newtypes or type aliases except at the top level of a file"),l2162073):R.ffi.throwNonFunApp(L[394],wf_DASH_error7659.$var,[("Cannot define newtypes or type aliases except at the top level of a file"),l2162073]);
};
try {
if(--R.GAS > 0) {
$z20652066 = $f20712072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20712072,
"from":L[394]});
}
} catch($e20632064) {
if(R.isCont($e20632064)) {
var $ss20672068 = {"from":L[394],
"go":function(anf_begin_app_dropped13182074) {
return $Hanf_begin_app_dropped13192075(anf_begin_app_dropped13182074);
}};
$e20632064.stack[R.EXN_STACKHEIGHT++] = $ss20672068;
}
if(R.isPyretException($e20632064)) {
$e20632064.pyretStack.push(L[394]);
}
throw $e20632064;
}
var $ret20692070 = $Hanf_begin_app_dropped13192075($z20652066);
++R.GAS;
return $ret20692070;
};
},{"length":4});
var anf_extend2721672 = R.makeMethod(function(self2192056) {
return function(l2202057,op2212058,left2222059,right2232061) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[393],4,arguments);
}
var $z20482049 = D;
var $f20542055 = function(_) {
return R.isFunction(reachable_DASH_ops10585.$var)?reachable_DASH_ops10585.$var.app(self2192056,l2202057,op2212058,left2222059):R.ffi.throwNonFunApp(L[392],reachable_DASH_ops10585.$var,[self2192056,l2202057,op2212058,left2222059]);
};
try {
if(--R.GAS > 0) {
$z20482049 = $f20542055();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20542055,
"from":L[392]});
}
} catch($e20462047) {
if(R.isCont($e20462047)) {
var $ss20502051 = {"from":L[392],
"go":function(and_DASH_oper_DASH_212060) {
return $Hand_DASH_oper_DASH_13232062(and_DASH_oper_DASH_212060,l2202057,op2212058,reachable_DASH_ops10585,right2232061,self2192056);
}};
$e20462047.stack[R.EXN_STACKHEIGHT++] = $ss20502051;
}
if(R.isPyretException($e20462047)) {
$e20462047.pyretStack.push(L[392]);
}
throw $e20462047;
}
var $ret20522053 = $Hand_DASH_oper_DASH_13232062($z20482049,l2202057,op2212058,reachable_DASH_ops10585,right2232061,self2192056);
++R.GAS;
return $ret20522053;
};
},{"length":5});
var anf_extend2961673 = R.makeMethod(function(self2242043) {
return function(l2252008,name2262045,args2272040,body2282042) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[391],4,arguments);
}
var when_DASH_232024 = R.equiv(name2262045,("_"));
var if_helper2742010 = R.makeFunction(function(if_helper_arg2752029) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[388],1,arguments);
}
if_helper_arg2752029;
var $z20322033 = D;
var $f20382039 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(args2272040):R.ffi.throwNonFunApp(L[390],ensure_DASH_unique_DASH_ids9973.$var,[args2272040]);
};
try {
if(--R.GAS > 0) {
$z20322033 = $f20382039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20382039,
"from":L[390]});
}
} catch($e20302031) {
if(R.isCont($e20302031)) {
var $ss20342035 = {"from":L[390],
"go":function(anf_begin_app_dropped13242041) {
return $Hanf_begin_app_dropped13302044(anf_begin_app_dropped13242041,args2272040,body2282042,lists1118,self2242043);
}};
$e20302031.stack[R.EXN_STACKHEIGHT++] = $ss20342035;
}
if(R.isPyretException($e20302031)) {
$e20302031.pyretStack.push(L[390]);
}
throw $e20302031;
}
var $ret20362037 = $Hanf_begin_app_dropped13302044($z20322033,args2272040,body2282042,lists1118,self2242043);
++R.GAS;
return $ret20362037;
});
var anf_if2932028 = R.isBoolean(when_DASH_232024);
if(R.isPyretTrue(anf_if2932028)) {
if(R.isPyretTrue(when_DASH_232024)) {
var $z20002001 = D;
var $f20062007 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Found a cases branch using _ rather than a constructor name; use 'else' instead"),l2252008):R.ffi.throwNonFunApp(L[387],wf_DASH_error7659.$var,[("Found a cases branch using _ rather than a constructor name; use 'else' instead"),l2252008]);
};
try {
if(--R.GAS > 0) {
$z20002001 = $f20062007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20062007,
"from":L[387]});
}
} catch($e19981999) {
if(R.isCont($e19981999)) {
var $ss20022003 = {"from":L[387],
"go":function(anf_begin_app_dropped13312009) {
return $Hanf_begin_app_dropped13332011(anf_begin_app_dropped13312009,if_helper2742010,nothing4);
}};
$e19981999.stack[R.EXN_STACKHEIGHT++] = $ss20022003;
}
if(R.isPyretException($e19981999)) {
$e19981999.pyretStack.push(L[387]);
}
throw $e19981999;
}
var $ret20042005 = $Hanf_begin_app_dropped13332011($z20002001,if_helper2742010,nothing4);
++R.GAS;
return $ret20042005;
} else {
var $z20142015 = D;
var $f20202021 = function(_) {
return R.isFunction(if_helper2742010)?if_helper2742010.app(nothing4):R.ffi.throwNonFunApp(L[388],if_helper2742010,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z20142015 = $f20202021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20202021,
"from":L[388]});
}
} catch($e20122013) {
if(R.isCont($e20122013)) {
var $ss20162017 = {"from":L[388],
"go":function(cont_tail_app2942022) {
return $Hcont_tail_app13342023(cont_tail_app2942022);
}};
$e20122013.stack[R.EXN_STACKHEIGHT++] = $ss20162017;
}
if(R.isPyretException($e20122013)) {
$e20122013.pyretStack.push(L[388]);
}
throw $e20122013;
}
var $ret20182019 = $Hcont_tail_app13342023($z20142015);
++R.GAS;
return $ret20182019;
}
} else {
var cont_tail_arg2912027 = R.throwNonBooleanCondition(L[389],("when"),when_DASH_232024);
if(--R.GAS > 0) {
$z20252026 = R.isFunction(if_helper2742010)?if_helper2742010.app(cont_tail_arg2912027):R.ffi.throwNonFunApp(L[389],if_helper2742010,[cont_tail_arg2912027]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2742010)?if_helper2742010.app(cont_tail_arg2912027):R.ffi.throwNonFunApp(L[389],if_helper2742010,[cont_tail_arg2912027]);
},
"from":L[389]});
}
++R.GAS;
return $z20252026;
}
};
},{"length":5});
var anf_extend3331674 = R.makeMethod(function(self2291996) {
return function(l2301995,stmts2311993) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[386],2,arguments);
}
var $z19851986 = D;
var $f19911992 = function(_) {
return R.isFunction(is_DASH_empty2851)?is_DASH_empty2851.app(stmts2311993):R.ffi.throwNonFunApp(L[385],is_DASH_empty2851,[stmts2311993]);
};
try {
if(--R.GAS > 0) {
$z19851986 = $f19911992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19911992,
"from":L[385]});
}
} catch($e19831984) {
if(R.isCont($e19831984)) {
var $ss19871988 = {"from":L[385],
"go":function(if_DASH_311994) {
return $Hif_DASH_13521997(if_DASH_311994,A113,ensure_DASH_unique_DASH_bindings10075,l2301995,lists1118,self2291996,stmts2311993,wf_DASH_error7659,wf_DASH_last_DASH_stmt10279);
}};
$e19831984.stack[R.EXN_STACKHEIGHT++] = $ss19871988;
}
if(R.isPyretException($e19831984)) {
$e19831984.pyretStack.push(L[385]);
}
throw $e19831984;
}
var $ret19891990 = $Hif_DASH_13521997($z19851986,A113,ensure_DASH_unique_DASH_bindings10075,l2301995,lists1118,self2291996,stmts2311993,wf_DASH_error7659,wf_DASH_last_DASH_stmt10279);
++R.GAS;
return $ret19891990;
};
},{"length":3});
var anf_extend3451675 = R.makeMethod(function(self2341980) {
return function(l2351978,shadows2361981,name2371975,ann2381982) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[384],4,arguments);
}
var anf_fun3351977 = G(reserved_DASH_names7442,"member",L[383]);
var $z19671968 = D;
var $f19731974 = function(_) {
return R.isFunction(tostring10)?tostring10.app(name2371975):R.ffi.throwNonFunApp(L[382],tostring10,[name2371975]);
};
try {
if(--R.GAS > 0) {
$z19671968 = $f19731974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19731974,
"from":L[382]});
}
} catch($e19651966) {
if(R.isCont($e19651966)) {
var $ss19691970 = {"from":L[382],
"go":function(anf_arg3361976) {
return $Hanf_arg13591979(anf_arg3361976,anf_fun3351977,l2351978,name2371975,reserved_DASH_name7965,nothing4,tostring10);
}};
$e19651966.stack[R.EXN_STACKHEIGHT++] = $ss19691970;
}
if(R.isPyretException($e19651966)) {
$e19651966.pyretStack.push(L[382]);
}
throw $e19651966;
}
var $ret19711972 = $Hanf_arg13591979($z19671968,anf_fun3351977,l2351978,name2371975,reserved_DASH_name7965,nothing4,tostring10);
++R.GAS;
return $ret19711972;
};
},{"length":5});
var anf_extend3751676 = R.makeMethod(function(self2391963) {
return function(l2401959,op2411961,left2421960,right2431962) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[381],4,arguments);
}
var $z19501951 = D;
var $f19561957 = function(_) {
return R.isFunction(not3)?not3.app(in_DASH_check_DASH_block7050.$var):R.ffi.throwNonFunApp(L[380],not3,[in_DASH_check_DASH_block7050.$var]);
};
try {
if(--R.GAS > 0) {
$z19501951 = $f19561957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19561957,
"from":L[380]});
}
} catch($e19481949) {
if(R.isCont($e19481949)) {
var $ss19521953 = {"from":L[380],
"go":function(when_DASH_331958) {
return $Hwhen_DASH_13681964(when_DASH_331958,l2401959,left2421960,op2411961,right2431962,self2391963,wf_DASH_error7659,nothing4);
}};
$e19481949.stack[R.EXN_STACKHEIGHT++] = $ss19521953;
}
if(R.isPyretException($e19481949)) {
$e19481949.pyretStack.push(L[380]);
}
throw $e19481949;
}
var $ret19541955 = $Hwhen_DASH_13681964($z19501951,l2401959,left2421960,op2411961,right2431962,self2391963,wf_DASH_error7659,nothing4);
++R.GAS;
return $ret19541955;
};
},{"length":5});
var anf_extend4391677 = R.makeMethod(function(self2441945) {
return function(l2451944,name2461938,args2471942,ann2481941,doc2491947,body2501943,_check2511940) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[379],7,arguments);
}
var anf_fun3771937 = G(A113,"is-s-str",L[378]);
var $z19291930 = D;
var $f19351936 = function(_) {
return R.isFunction(anf_fun3771937)?anf_fun3771937.app(name2461938):R.ffi.throwNonFunApp(L[377],anf_fun3771937,[name2461938]);
};
try {
if(--R.GAS > 0) {
$z19291930 = $f19351936();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19351936,
"from":L[377]});
}
} catch($e19271928) {
if(R.isCont($e19271928)) {
var $ss19311932 = {"from":L[377],
"go":function(and_DASH_oper_DASH_381939) {
return $Hand_DASH_oper_DASH_13951946(and_DASH_oper_DASH_381939,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2451944,lists1118,name2461938,reserved_DASH_name7965,reserved_DASH_names7442,self2441945,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4);
}};
$e19271928.stack[R.EXN_STACKHEIGHT++] = $ss19311932;
}
if(R.isPyretException($e19271928)) {
$e19271928.pyretStack.push(L[377]);
}
throw $e19271928;
}
var $ret19331934 = $Hand_DASH_oper_DASH_13951946($z19291930,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2451944,lists1118,name2461938,reserved_DASH_name7965,reserved_DASH_names7442,self2441945,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4);
++R.GAS;
return $ret19331934;
};
},{"length":8});
var anf_extend4741678 = R.makeMethod(function(self2531924) {
return function(l2541923,name2551921,value2561925) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[376],3,arguments);
}
var anf_fun4411920 = G(A113,"is-s-str",L[375]);
var $z19121913 = D;
var $f19181919 = function(_) {
return R.isFunction(anf_fun4411920)?anf_fun4411920.app(name2551921):R.ffi.throwNonFunApp(L[374],anf_fun4411920,[name2551921]);
};
try {
if(--R.GAS > 0) {
$z19121913 = $f19181919();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19181919,
"from":L[374]});
}
} catch($e19101911) {
if(R.isCont($e19101911)) {
var $ss19141915 = {"from":L[374],
"go":function(and_DASH_oper_DASH_481922) {
return $Hand_DASH_oper_DASH_14071926(and_DASH_oper_DASH_481922,l2541923,name2551921,reserved_DASH_name7965,reserved_DASH_names7442,self2531924,value2561925,nothing4);
}};
$e19101911.stack[R.EXN_STACKHEIGHT++] = $ss19141915;
}
if(R.isPyretException($e19101911)) {
$e19101911.pyretStack.push(L[374]);
}
throw $e19101911;
}
var $ret19161917 = $Hand_DASH_oper_DASH_14071926($z19121913,l2541923,name2551921,reserved_DASH_name7965,reserved_DASH_names7442,self2531924,value2561925,nothing4);
++R.GAS;
return $ret19161917;
};
},{"length":4});
var anf_extend5141679 = R.makeMethod(function(self2571907) {
return function(l2581906,name2591903,ann2601905,value2611908) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[373],4,arguments);
}
var anf_fun4761902 = G(A113,"is-s-str",L[372]);
var $z18941895 = D;
var $f19001901 = function(_) {
return R.isFunction(anf_fun4761902)?anf_fun4761902.app(name2591903):R.ffi.throwNonFunApp(L[371],anf_fun4761902,[name2591903]);
};
try {
if(--R.GAS > 0) {
$z18941895 = $f19001901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19001901,
"from":L[371]});
}
} catch($e18921893) {
if(R.isCont($e18921893)) {
var $ss18961897 = {"from":L[371],
"go":function(and_DASH_oper_DASH_531904) {
return $Hand_DASH_oper_DASH_14211909(and_DASH_oper_DASH_531904,ann2601905,l2581906,name2591903,reserved_DASH_name7965,reserved_DASH_names7442,self2571907,value2611908,nothing4);
}};
$e18921893.stack[R.EXN_STACKHEIGHT++] = $ss18961897;
}
if(R.isPyretException($e18921893)) {
$e18921893.pyretStack.push(L[371]);
}
throw $e18921893;
}
var $ret18981899 = $Hand_DASH_oper_DASH_14211909($z18941895,ann2601905,l2581906,name2591903,reserved_DASH_name7965,reserved_DASH_names7442,self2571907,value2611908,nothing4);
++R.GAS;
return $ret18981899;
};
},{"length":5});
var anf_extend5541680 = R.makeMethod(function(self2621889) {
return function(l2631888,name2641885,ann2651887,value2661890) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[370],4,arguments);
}
var anf_fun5161884 = G(A113,"is-s-str",L[369]);
var $z18761877 = D;
var $f18821883 = function(_) {
return R.isFunction(anf_fun5161884)?anf_fun5161884.app(name2641885):R.ffi.throwNonFunApp(L[368],anf_fun5161884,[name2641885]);
};
try {
if(--R.GAS > 0) {
$z18761877 = $f18821883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18821883,
"from":L[368]});
}
} catch($e18741875) {
if(R.isCont($e18741875)) {
var $ss18781879 = {"from":L[368],
"go":function(and_DASH_oper_DASH_591886) {
return $Hand_DASH_oper_DASH_14351891(and_DASH_oper_DASH_591886,ann2651887,l2631888,name2641885,reserved_DASH_name7965,reserved_DASH_names7442,self2621889,value2661890,nothing4);
}};
$e18741875.stack[R.EXN_STACKHEIGHT++] = $ss18781879;
}
if(R.isPyretException($e18741875)) {
$e18741875.pyretStack.push(L[368]);
}
throw $e18741875;
}
var $ret18801881 = $Hand_DASH_oper_DASH_14351891($z18761877,ann2651887,l2631888,name2641885,reserved_DASH_name7965,reserved_DASH_names7442,self2621889,value2661890,nothing4);
++R.GAS;
return $ret18801881;
};
},{"length":5});
var anf_extend5971681 = R.makeMethod(function(self2671871) {
return function(l2681870,args2691868,ann2701867,doc2711873,body2721869,_check2731866) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[367],6,arguments);
}
var anf_fun5561864 = G(args2691868,"length",L[366]);
var $z18561857 = D;
var $f18621863 = function(_) {
return R.isFunction(anf_fun5561864)?anf_fun5561864.app():R.ffi.throwNonFunApp(L[365],anf_fun5561864,[]);
};
try {
if(--R.GAS > 0) {
$z18561857 = $f18621863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18621863,
"from":L[365]});
}
} catch($e18541855) {
if(R.isCont($e18541855)) {
var $ss18581859 = {"from":L[365],
"go":function(anf_arg5571865) {
return $Hanf_arg14541872(anf_arg5571865,_check2731866,ann2701867,args2691868,body2721869,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2681870,lists1118,self2671871,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4);
}};
$e18541855.stack[R.EXN_STACKHEIGHT++] = $ss18581859;
}
if(R.isPyretException($e18541855)) {
$e18541855.pyretStack.push(L[365]);
}
throw $e18541855;
}
var $ret18601861 = $Hanf_arg14541872($z18561857,_check2731866,ann2701867,args2691868,body2721869,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2681870,lists1118,self2671871,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4);
++R.GAS;
return $ret18601861;
};
},{"length":7});
var anf_extend6391682 = R.makeMethod(function(self2751851) {
return function(l2761849,params2771850,args2781844,ann2791847,doc2801853,body2811848,_check2821846) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[364],7,arguments);
}
var $z18361837 = D;
var $f18421843 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(args2781844):R.ffi.throwNonFunApp(L[363],ensure_DASH_unique_DASH_ids9973.$var,[args2781844]);
};
try {
if(--R.GAS > 0) {
$z18361837 = $f18421843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18421843,
"from":L[363]});
}
} catch($e18341835) {
if(R.isCont($e18341835)) {
var $ss18381839 = {"from":L[363],
"go":function(anf_begin_app_dropped14551845) {
return $Hanf_begin_app_dropped14711852(anf_begin_app_dropped14551845,_check2821846,ann2791847,args2781844,body2811848,ensure_DASH_empty_DASH_block9769,l2761849,lists1118,params2771850,self2751851,wrap_DASH_visit_DASH_check8067,nothing4);
}};
$e18341835.stack[R.EXN_STACKHEIGHT++] = $ss18381839;
}
if(R.isPyretException($e18341835)) {
$e18341835.pyretStack.push(L[363]);
}
throw $e18341835;
}
var $ret18401841 = $Hanf_begin_app_dropped14711852($z18361837,_check2821846,ann2791847,args2781844,body2811848,ensure_DASH_empty_DASH_block9769,l2761849,lists1118,params2771850,self2751851,wrap_DASH_visit_DASH_check8067,nothing4);
++R.GAS;
return $ret18401841;
};
},{"length":8});
var anf_extend6811683 = R.makeMethod(function(self2841831) {
return function(l2851829,name2861823,params2871830,args2881827,ann2891826,doc2901833,body2911828,_check2921825) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[362],8,arguments);
}
var anf_fun6411822 = G(reserved_DASH_names7442,"member",L[361]);
var $z18141815 = D;
var $f18201821 = function(_) {
return R.isFunction(anf_fun6411822)?anf_fun6411822.app(name2861823):R.ffi.throwNonFunApp(L[360],anf_fun6411822,[name2861823]);
};
try {
if(--R.GAS > 0) {
$z18141815 = $f18201821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18201821,
"from":L[360]});
}
} catch($e18121813) {
if(R.isCont($e18121813)) {
var $ss18161817 = {"from":L[360],
"go":function(when_DASH_791824) {
return $Hwhen_DASH_14901832(when_DASH_791824,_check2921825,ann2891826,args2881827,body2911828,ensure_DASH_unique_DASH_ids9973,l2851829,lists1118,name2861823,params2871830,reserved_DASH_name7965,self2841831,wrap_DASH_visit_DASH_check8067,nothing4);
}};
$e18121813.stack[R.EXN_STACKHEIGHT++] = $ss18161817;
}
if(R.isPyretException($e18121813)) {
$e18121813.pyretStack.push(L[360]);
}
throw $e18121813;
}
var $ret18181819 = $Hwhen_DASH_14901832($z18141815,_check2921825,ann2891826,args2881827,body2911828,ensure_DASH_unique_DASH_ids9973,l2851829,lists1118,name2861823,params2871830,reserved_DASH_name7965,self2841831,wrap_DASH_visit_DASH_check8067,nothing4);
++R.GAS;
return $ret18181819;
};
},{"length":9});
var anf_extend6841684 = R.makeMethod(function(self2931807) {
return function(l2941809,name2951810,body2961805,keyword_DASH_check2971811) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[359],4,arguments);
}
var $z17971798 = D;
var $f18031804 = function(_) {
return R.isFunction(some6456)?some6456.app(body2961805):R.ffi.throwNonFunApp(L[358],some6456,[body2961805]);
};
try {
if(--R.GAS > 0) {
$z17971798 = $f18031804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18031804,
"from":L[358]});
}
} catch($e17951796) {
if(R.isCont($e17951796)) {
var $ss17991800 = {"from":L[358],
"go":function(anf_arg6831806) {
return $Hanf_arg14921808(anf_arg6831806,self2931807,wrap_DASH_visit_DASH_check8067);
}};
$e17951796.stack[R.EXN_STACKHEIGHT++] = $ss17991800;
}
if(R.isPyretException($e17951796)) {
$e17951796.pyretStack.push(L[358]);
}
throw $e17951796;
}
var $ret18011802 = $Hanf_arg14921808($z17971798,self2931807,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret18011802;
};
},{"length":5});
var anf_extend6991685 = R.makeMethod(function(self2981793) {
return function(l2991792,branches3001791) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[357],2,arguments);
}
var anf_fun6861789 = G(branches3001791,"length",L[356]);
var $z17811782 = D;
var $f17871788 = function(_) {
return R.isFunction(anf_fun6861789)?anf_fun6861789.app():R.ffi.throwNonFunApp(L[355],anf_fun6861789,[]);
};
try {
if(--R.GAS > 0) {
$z17811782 = $f17871788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17871788,
"from":L[355]});
}
} catch($e17791780) {
if(R.isCont($e17791780)) {
var $ss17831784 = {"from":L[355],
"go":function(anf_arg6871790) {
return $Hanf_arg14991794(anf_arg6871790,branches3001791,l2991792,lists1118,self2981793,wf_DASH_error7659,nothing4);
}};
$e17791780.stack[R.EXN_STACKHEIGHT++] = $ss17831784;
}
if(R.isPyretException($e17791780)) {
$e17791780.pyretStack.push(L[355]);
}
throw $e17791780;
}
var $ret17851786 = $Hanf_arg14991794($z17811782,branches3001791,l2991792,lists1118,self2981793,wf_DASH_error7659,nothing4);
++R.GAS;
return $ret17851786;
};
},{"length":3});
var anf_extend7211686 = R.makeMethod(function(self3011774) {
return function(l3021778,typ3031775,val3041776,branches3051772) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[354],4,arguments);
}
var $z17641765 = D;
var $f17701771 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_cases9871.$var)?ensure_DASH_unique_DASH_cases9871.$var.app(branches3051772):R.ffi.throwNonFunApp(L[353],ensure_DASH_unique_DASH_cases9871.$var,[branches3051772]);
};
try {
if(--R.GAS > 0) {
$z17641765 = $f17701771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17701771,
"from":L[353]});
}
} catch($e17621763) {
if(R.isCont($e17621763)) {
var $ss17661767 = {"from":L[353],
"go":function(anf_begin_app_dropped15001773) {
return $Hanf_begin_app_dropped15081777(anf_begin_app_dropped15001773,branches3051772,lists1118,self3011774,typ3031775,val3041776);
}};
$e17621763.stack[R.EXN_STACKHEIGHT++] = $ss17661767;
}
if(R.isPyretException($e17621763)) {
$e17621763.pyretStack.push(L[353]);
}
throw $e17621763;
}
var $ret17681769 = $Hanf_begin_app_dropped15081777($z17641765,branches3051772,lists1118,self3011774,typ3031775,val3041776);
++R.GAS;
return $ret17681769;
};
},{"length":5});
var anf_extend7481687 = R.makeMethod(function(self3061757) {
return function(l3071761,typ3081758,val3091759,branches3101754,_else3111756) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[352],5,arguments);
}
var $z17461747 = D;
var $f17521753 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_cases9871.$var)?ensure_DASH_unique_DASH_cases9871.$var.app(branches3101754):R.ffi.throwNonFunApp(L[351],ensure_DASH_unique_DASH_cases9871.$var,[branches3101754]);
};
try {
if(--R.GAS > 0) {
$z17461747 = $f17521753();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17521753,
"from":L[351]});
}
} catch($e17441745) {
if(R.isCont($e17441745)) {
var $ss17481749 = {"from":L[351],
"go":function(anf_begin_app_dropped15091755) {
return $Hanf_begin_app_dropped15191760(anf_begin_app_dropped15091755,_else3111756,branches3101754,lists1118,self3061757,typ3081758,val3091759);
}};
$e17441745.stack[R.EXN_STACKHEIGHT++] = $ss17481749;
}
if(R.isPyretException($e17441745)) {
$e17441745.pyretStack.push(L[351]);
}
throw $e17441745;
}
var $ret17501751 = $Hanf_begin_app_dropped15191760($z17461747,_else3111756,branches3101754,lists1118,self3061757,typ3081758,val3091759);
++R.GAS;
return $ret17501751;
};
},{"length":6});
var anf_extend7591688 = R.makeMethod(function(self3121743) {
return function(l3131717,num3141718,den3151742) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[350],3,arguments);
}
var when_DASH_981734 = R.equiv(den3151742,(0));
var if_helper7501720 = R.makeFunction(function(if_helper_arg7511740) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[348],1,arguments);
}
if_helper_arg7511740;
var ann_DASH_check_DASH_temp7491741 = (true);
return ann_DASH_check_DASH_temp7491741;
});
var anf_if7541739 = R.isBoolean(when_DASH_981734);
if(R.isPyretTrue(anf_if7541739)) {
if(R.isPyretTrue(when_DASH_981734)) {
var anf_fun7561716 = G(C515,"zero-fraction",L[347]);
var $z17081709 = D;
var $f17141715 = function(_) {
return R.isFunction(anf_fun7561716)?anf_fun7561716.app(l3131717,num3141718):R.ffi.throwNonFunApp(L[346],anf_fun7561716,[l3131717,num3141718]);
};
try {
if(--R.GAS > 0) {
$z17081709 = $f17141715();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17141715,
"from":L[346]});
}
} catch($e17061707) {
if(R.isCont($e17061707)) {
var $ss17101711 = {"from":L[346],
"go":function(anf_arg7571719) {
return $Hanf_arg15231721(anf_arg7571719,add_DASH_error7557,if_helper7501720,nothing4);
}};
$e17061707.stack[R.EXN_STACKHEIGHT++] = $ss17101711;
}
if(R.isPyretException($e17061707)) {
$e17061707.pyretStack.push(L[346]);
}
throw $e17061707;
}
var $ret17121713 = $Hanf_arg15231721($z17081709,add_DASH_error7557,if_helper7501720,nothing4);
++R.GAS;
return $ret17121713;
} else {
var $z17241725 = D;
var $f17301731 = function(_) {
return R.isFunction(if_helper7501720)?if_helper7501720.app(nothing4):R.ffi.throwNonFunApp(L[348],if_helper7501720,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z17241725 = $f17301731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17301731,
"from":L[348]});
}
} catch($e17221723) {
if(R.isCont($e17221723)) {
var $ss17261727 = {"from":L[348],
"go":function(cont_tail_app7551732) {
return $Hcont_tail_app15241733(cont_tail_app7551732);
}};
$e17221723.stack[R.EXN_STACKHEIGHT++] = $ss17261727;
}
if(R.isPyretException($e17221723)) {
$e17221723.pyretStack.push(L[348]);
}
throw $e17221723;
}
var $ret17281729 = $Hcont_tail_app15241733($z17241725);
++R.GAS;
return $ret17281729;
}
} else {
var cont_tail_arg7521737 = R.throwNonBooleanCondition(L[349],("when"),when_DASH_981734);
if(--R.GAS > 0) {
$z17351736 = R.isFunction(if_helper7501720)?if_helper7501720.app(cont_tail_arg7521737):R.ffi.throwNonFunApp(L[349],if_helper7501720,[cont_tail_arg7521737]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7501720)?if_helper7501720.app(cont_tail_arg7521737):R.ffi.throwNonFunApp(L[349],if_helper7501720,[cont_tail_arg7521737]);
},
"from":L[349]});
}
++R.GAS;
return $z17351736;
}
};
},{"length":4});
var anf_extend7711689 = R.makeMethod(function(self3161705) {
return function(l3171703,id3181700) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[345],2,arguments);
}
var anf_fun7611702 = G(reserved_DASH_names7442,"member",L[344]);
var $z16921693 = D;
var $f16981699 = function(_) {
return R.isFunction(tostring10)?tostring10.app(id3181700):R.ffi.throwNonFunApp(L[343],tostring10,[id3181700]);
};
try {
if(--R.GAS > 0) {
$z16921693 = $f16981699();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16981699,
"from":L[343]});
}
} catch($e16901691) {
if(R.isCont($e16901691)) {
var $ss16941695 = {"from":L[343],
"go":function(anf_arg7621701) {
return $Hanf_arg15311704(anf_arg7621701,anf_fun7611702,id3181700,l3171703,reserved_DASH_name7965,nothing4,tostring10);
}};
$e16901691.stack[R.EXN_STACKHEIGHT++] = $ss16941695;
}
if(R.isPyretException($e16901691)) {
$e16901691.pyretStack.push(L[343]);
}
throw $e16901691;
}
var $ret16961697 = $Hanf_arg15311704($z16921693,anf_fun7611702,id3181700,l3171703,reserved_DASH_name7965,nothing4,tostring10);
++R.GAS;
return $ret16961697;
};
},{"length":3});
var well_DASH_formed_DASH_visitor183217 = anf_extend2481665.extendWith({"s-program":anf_extend2501666,
"s-data":anf_extend2521667,
"s-data-expr":anf_extend2541668,
"s-type":anf_extend2561669,
"s-newtype":anf_extend2581670,
"s-type-let-expr":anf_extend2601671,
"s-op":anf_extend2721672,
"s-cases-branch":anf_extend2961673,
"s-block":anf_extend3331674,
"s-bind":anf_extend3451675,
"s-check-test":anf_extend3751676,
"s-method-field":anf_extend4391677,
"s-data-field":anf_extend4741678,
"s-mutable-field":anf_extend5141679,
"s-once-field":anf_extend5541680,
"s-method":anf_extend5971681,
"s-lam":anf_extend6391682,
"s-fun":anf_extend6811683,
"s-check":anf_extend6841684,
"s-if":anf_extend6991685,
"s-cases":anf_extend7211686,
"s-cases-else":anf_extend7481687,
"s-frac":anf_extend7591688,
"s-id":anf_extend7711689});
var anf_extend772118 = G(A113,"default-iter-visitor",L[342]);
var anf_extend809119 = R.makeMethod(function(self3201616) {
return function(l3211664,_provide3221614,_provide_DASH_types3231613,imports3241615,body3251631) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[341],5,arguments);
}
var cases_DASH_val1011663 = body3251631;
var anf_fun7741609 = G(cases_DASH_val1011663,"_match",L[336]);
var anf_obj7801632 = R.makeFunction(function(l23271633,stmts3281634) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[338],2,arguments);
}
var anf_fun7761645 = G(lists1118,"all",L[340]);
var anf_arg7791646 = R.makeFunction(function(recv_DASH_1001649) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[339],1,arguments);
}
var anf_fun7781660 = G(recv_DASH_1001649,"visit",L[339]);
var $z16521653 = D;
var $f16581659 = function(_) {
return R.isFunction(anf_fun7781660)?anf_fun7781660.app(self3201616):R.ffi.throwNonFunApp(L[339],anf_fun7781660,[self3201616]);
};
try {
if(--R.GAS > 0) {
$z16521653 = $f16581659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16581659,
"from":L[339]});
}
} catch($e16501651) {
if(R.isCont($e16501651)) {
var $ss16541655 = {"from":L[339],
"go":function(ann_DASH_check_DASH_temp7771661) {
return $Hann_DASH_check_DASH_temp15321662(ann_DASH_check_DASH_temp7771661);
}};
$e16501651.stack[R.EXN_STACKHEIGHT++] = $ss16541655;
}
if(R.isPyretException($e16501651)) {
$e16501651.pyretStack.push(L[339]);
}
throw $e16501651;
}
var $ret16561657 = $Hann_DASH_check_DASH_temp15321662($z16521653);
++R.GAS;
return $ret16561657;
});
var $z16371638 = D;
var $f16431644 = function(_) {
return R.isFunction(anf_fun7761645)?anf_fun7761645.app(anf_arg7791646,stmts3281634):R.ffi.throwNonFunApp(L[338],anf_fun7761645,[anf_arg7791646,stmts3281634]);
};
try {
if(--R.GAS > 0) {
$z16371638 = $f16431644();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16431644,
"from":L[338]});
}
} catch($e16351636) {
if(R.isCont($e16351636)) {
var $ss16391640 = {"from":L[338],
"go":function(ann_DASH_check_DASH_temp7751647) {
return $Hann_DASH_check_DASH_temp15331648(ann_DASH_check_DASH_temp7751647);
}};
$e16351636.stack[R.EXN_STACKHEIGHT++] = $ss16391640;
}
if(R.isPyretException($e16351636)) {
$e16351636.pyretStack.push(L[338]);
}
throw $e16351636;
}
var $ret16411642 = $Hann_DASH_check_DASH_temp15331648($z16371638);
++R.GAS;
return $ret16411642;
});
var anf_arg7811610 = R.makeObject({"s-block":anf_obj7801632});
var anf_arg7841611 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[336],0,arguments);
}
var anf_fun7831628 = G(body3251631,"visit",L[337]);
var $z16201621 = D;
var $f16261627 = function(_) {
return R.isFunction(anf_fun7831628)?anf_fun7831628.app(self3201616):R.ffi.throwNonFunApp(L[336],anf_fun7831628,[self3201616]);
};
try {
if(--R.GAS > 0) {
$z16201621 = $f16261627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16261627,
"from":L[336]});
}
} catch($e16181619) {
if(R.isCont($e16181619)) {
var $ss16221623 = {"from":L[336],
"go":function(ann_DASH_check_DASH_temp7821629) {
return $Hann_DASH_check_DASH_temp15341630(ann_DASH_check_DASH_temp7821629);
}};
$e16181619.stack[R.EXN_STACKHEIGHT++] = $ss16221623;
}
if(R.isPyretException($e16181619)) {
$e16181619.pyretStack.push(L[336]);
}
throw $e16181619;
}
var $ret16241625 = $Hann_DASH_check_DASH_temp15341630($z16201621);
++R.GAS;
return $ret16241625;
});
var $z16011602 = D;
var $f16071608 = function(_) {
return R.isFunction(anf_fun7741609)?anf_fun7741609.app(anf_arg7811610,anf_arg7841611):R.ffi.throwNonFunApp(L[335],anf_fun7741609,[anf_arg7811610,anf_arg7841611]);
};
try {
if(--R.GAS > 0) {
$z16011602 = $f16071608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16071608,
"from":L[335]});
}
} catch($e15991600) {
if(R.isCont($e15991600)) {
var $ss16031604 = {"from":L[335],
"go":function(ok_DASH_body3261612) {
return $Hok_DASH_body15431617(ok_DASH_body3261612,_provide_DASH_types3231613,_provide3221614,imports3241615,lists1118,self3201616);
}};
$e15991600.stack[R.EXN_STACKHEIGHT++] = $ss16031604;
}
if(R.isPyretException($e15991600)) {
$e15991600.pyretStack.push(L[335]);
}
throw $e15991600;
}
var $ret16051606 = $Hok_DASH_body15431617($z16011602,_provide_DASH_types3231613,_provide3221614,imports3241615,lists1118,self3201616);
++R.GAS;
return $ret16051606;
};
},{"length":6});
var anf_extend812120 = R.makeMethod(function(self3291596) {
return function(l3301597,name3311598,ann3321595) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[333],3,arguments);
}
var anf_fun8111592 = G(ann3321595,"visit",L[334]);
var $z15841585 = D;
var $f15901591 = function(_) {
return R.isFunction(anf_fun8111592)?anf_fun8111592.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[333],anf_fun8111592,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z15841585 = $f15901591();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15901591,
"from":L[333]});
}
} catch($e15821583) {
if(R.isCont($e15821583)) {
var $ss15861587 = {"from":L[333],
"go":function(ann_DASH_check_DASH_temp8101593) {
return $Hann_DASH_check_DASH_temp15441594(ann_DASH_check_DASH_temp8101593);
}};
$e15821583.stack[R.EXN_STACKHEIGHT++] = $ss15861587;
}
if(R.isPyretException($e15821583)) {
$e15821583.pyretStack.push(L[333]);
}
throw $e15821583;
}
var $ret15881589 = $Hann_DASH_check_DASH_temp15441594($z15841585);
++R.GAS;
return $ret15881589;
};
},{"length":4});
var anf_extend814121 = R.makeMethod(function(self3331578) {
return function(l3341579,name3351580,namet3361581) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[332],3,arguments);
}
var ann_DASH_check_DASH_temp8131577 = (true);
return ann_DASH_check_DASH_temp8131577;
};
},{"length":4});
var anf_extend831122 = R.makeMethod(function(self3371573) {
return function(l3381576,binds3391557,body3401559) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[331],3,arguments);
}
var anf_fun8161555 = G(lists1118,"all",L[330]);
var anf_arg8191556 = R.makeFunction(function(recv_DASH_1081561) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[329],1,arguments);
}
var anf_fun8181572 = G(recv_DASH_1081561,"visit",L[329]);
var $z15641565 = D;
var $f15701571 = function(_) {
return R.isFunction(anf_fun8181572)?anf_fun8181572.app(self3371573):R.ffi.throwNonFunApp(L[329],anf_fun8181572,[self3371573]);
};
try {
if(--R.GAS > 0) {
$z15641565 = $f15701571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15701571,
"from":L[329]});
}
} catch($e15621563) {
if(R.isCont($e15621563)) {
var $ss15661567 = {"from":L[329],
"go":function(ann_DASH_check_DASH_temp8171574) {
return $Hann_DASH_check_DASH_temp15451575(ann_DASH_check_DASH_temp8171574);
}};
$e15621563.stack[R.EXN_STACKHEIGHT++] = $ss15661567;
}
if(R.isPyretException($e15621563)) {
$e15621563.pyretStack.push(L[329]);
}
throw $e15621563;
}
var $ret15681569 = $Hann_DASH_check_DASH_temp15451575($z15641565);
++R.GAS;
return $ret15681569;
});
var $z15471548 = D;
var $f15531554 = function(_) {
return R.isFunction(anf_fun8161555)?anf_fun8161555.app(anf_arg8191556,binds3391557):R.ffi.throwNonFunApp(L[328],anf_fun8161555,[anf_arg8191556,binds3391557]);
};
try {
if(--R.GAS > 0) {
$z15471548 = $f15531554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15531554,
"from":L[328]});
}
} catch($e15451546) {
if(R.isCont($e15451546)) {
var $ss15491550 = {"from":L[328],
"go":function(and_DASH_oper_DASH_1071558) {
return $Hand_DASH_oper_DASH_15491560(and_DASH_oper_DASH_1071558,body3401559,well_DASH_formed_DASH_visitor183217);
}};
$e15451546.stack[R.EXN_STACKHEIGHT++] = $ss15491550;
}
if(R.isPyretException($e15451546)) {
$e15451546.pyretStack.push(L[328]);
}
throw $e15451546;
}
var $ret15511552 = $Hand_DASH_oper_DASH_15491560($z15471548,body3401559,well_DASH_formed_DASH_visitor183217);
++R.GAS;
return $ret15511552;
};
},{"length":4});
var anf_extend834123 = R.makeMethod(function(self3411542) {
return function(l3421543,name3431544,ann3441541) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[326],3,arguments);
}
var anf_fun8331538 = G(ann3441541,"visit",L[327]);
var $z15301531 = D;
var $f15361537 = function(_) {
return R.isFunction(anf_fun8331538)?anf_fun8331538.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[326],anf_fun8331538,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z15301531 = $f15361537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15361537,
"from":L[326]});
}
} catch($e15281529) {
if(R.isCont($e15281529)) {
var $ss15321533 = {"from":L[326],
"go":function(ann_DASH_check_DASH_temp8321539) {
return $Hann_DASH_check_DASH_temp15501540(ann_DASH_check_DASH_temp8321539);
}};
$e15281529.stack[R.EXN_STACKHEIGHT++] = $ss15321533;
}
if(R.isPyretException($e15281529)) {
$e15281529.pyretStack.push(L[326]);
}
throw $e15281529;
}
var $ret15341535 = $Hann_DASH_check_DASH_temp15501540($z15301531);
++R.GAS;
return $ret15341535;
};
},{"length":4});
var anf_extend836124 = R.makeMethod(function(self3451524) {
return function(l3461525,name3471526,namet3481527) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[325],3,arguments);
}
var ann_DASH_check_DASH_temp8351523 = (true);
return ann_DASH_check_DASH_temp8351523;
};
},{"length":4});
var anf_extend863125 = R.makeMethod(function(self3491519) {
return function(l3501520,constr_DASH_loc3511521,name3521522,binds3531517,with_DASH_members3541515) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[324],5,arguments);
}
var $z15071508 = D;
var $f15131514 = function(_) {
return R.isFunction(fields_DASH_to_DASH_binds10381.$var)?fields_DASH_to_DASH_binds10381.$var.app(with_DASH_members3541515):R.ffi.throwNonFunApp(L[323],fields_DASH_to_DASH_binds10381.$var,[with_DASH_members3541515]);
};
try {
if(--R.GAS > 0) {
$z15071508 = $f15131514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15131514,
"from":L[323]});
}
} catch($e15051506) {
if(R.isCont($e15051506)) {
var $ss15091510 = {"from":L[323],
"go":function(anf_arg8381516) {
return $Hanf_arg15621518(anf_arg8381516,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1);
}};
$e15051506.stack[R.EXN_STACKHEIGHT++] = $ss15091510;
}
if(R.isPyretException($e15051506)) {
$e15051506.pyretStack.push(L[323]);
}
throw $e15051506;
}
var $ret15111512 = $Hanf_arg15621518($z15071508,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1);
++R.GAS;
return $ret15111512;
};
},{"length":6});
var anf_extend871126 = R.makeMethod(function(self3551502) {
return function(l3561503,name3571504,with_DASH_members3581499) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[322],3,arguments);
}
var $z14911492 = D;
var $f14971498 = function(_) {
return R.isFunction(fields_DASH_to_DASH_binds10381.$var)?fields_DASH_to_DASH_binds10381.$var.app(with_DASH_members3581499):R.ffi.throwNonFunApp(L[321],fields_DASH_to_DASH_binds10381.$var,[with_DASH_members3581499]);
};
try {
if(--R.GAS > 0) {
$z14911492 = $f14971498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14971498,
"from":L[321]});
}
} catch($e14891490) {
if(R.isCont($e14891490)) {
var $ss14931494 = {"from":L[321],
"go":function(anf_arg8651500) {
return $Hanf_arg15681501(anf_arg8651500,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499,_plus1);
}};
$e14891490.stack[R.EXN_STACKHEIGHT++] = $ss14931494;
}
if(R.isPyretException($e14891490)) {
$e14891490.pyretStack.push(L[321]);
}
throw $e14891490;
}
var $ret14951496 = $Hanf_arg15681501($z14911492,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499,_plus1);
++R.GAS;
return $ret14951496;
};
},{"length":4});
var anf_extend918127 = R.makeMethod(function(self3591486) {
return function(l3601487,name3611488,params3621483,mixins3631482,variants3641479,shares3651484,_check3661481) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[320],7,arguments);
}
var $z14711472 = D;
var $f14771478 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_variant_DASH_ids10177.$var)?ensure_DASH_unique_DASH_variant_DASH_ids10177.$var.app(variants3641479):R.ffi.throwNonFunApp(L[319],ensure_DASH_unique_DASH_variant_DASH_ids10177.$var,[variants3641479]);
};
try {
if(--R.GAS > 0) {
$z14711472 = $f14771478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14771478,
"from":L[319]});
}
} catch($e14691470) {
if(R.isCont($e14691470)) {
var $ss14731474 = {"from":L[319],
"go":function(anf_begin_app_dropped15691480) {
return $Hanf_begin_app_dropped15861485(anf_begin_app_dropped15691480,_check3661481,cur_DASH_shared7147,fields_DASH_to_DASH_binds10381,lists1118,mixins3631482,params3621483,shares3651484,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
}};
$e14691470.stack[R.EXN_STACKHEIGHT++] = $ss14731474;
}
if(R.isPyretException($e14691470)) {
$e14691470.pyretStack.push(L[319]);
}
throw $e14691470;
}
var $ret14751476 = $Hanf_begin_app_dropped15861485($z14711472,_check3661481,cur_DASH_shared7147,fields_DASH_to_DASH_binds10381,lists1118,mixins3631482,params3621483,shares3651484,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret14751476;
};
},{"length":8});
var anf_extend936128 = R.makeMethod(function(self3691466) {
return function(l3701467,name3711468,binds3721462,constructor3731464) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[318],4,arguments);
}
var $z14541455 = D;
var $f14601461 = function(_) {
return R.isFunction(fields_DASH_to_DASH_binds10381.$var)?fields_DASH_to_DASH_binds10381.$var.app(binds3721462):R.ffi.throwNonFunApp(L[317],fields_DASH_to_DASH_binds10381.$var,[binds3721462]);
};
try {
if(--R.GAS > 0) {
$z14541455 = $f14601461();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14601461,
"from":L[317]});
}
} catch($e14521453) {
if(R.isCont($e14521453)) {
var $ss14561457 = {"from":L[317],
"go":function(anf_arg9201463) {
return $Hanf_arg15941465(anf_arg9201463,binds3721462,constructor3731464,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217);
}};
$e14521453.stack[R.EXN_STACKHEIGHT++] = $ss14561457;
}
if(R.isPyretException($e14521453)) {
$e14521453.pyretStack.push(L[317]);
}
throw $e14521453;
}
var $ret14581459 = $Hanf_arg15941465($z14541455,binds3721462,constructor3731464,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217);
++R.GAS;
return $ret14581459;
};
},{"length":5});
var anf_extend983129 = R.makeMethod(function(self3741448) {
return function(l3751449,name3761450,namet3771451,params3781445,mixins3791444,variants3801441,shared3811446,_check3821443) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[316],8,arguments);
}
var $z14331434 = D;
var $f14391440 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_variant_DASH_ids10177.$var)?ensure_DASH_unique_DASH_variant_DASH_ids10177.$var.app(variants3801441):R.ffi.throwNonFunApp(L[315],ensure_DASH_unique_DASH_variant_DASH_ids10177.$var,[variants3801441]);
};
try {
if(--R.GAS > 0) {
$z14331434 = $f14391440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14391440,
"from":L[315]});
}
} catch($e14311432) {
if(R.isCont($e14311432)) {
var $ss14351436 = {"from":L[315],
"go":function(anf_begin_app_dropped15951442) {
return $Hanf_begin_app_dropped16121447(anf_begin_app_dropped15951442,_check3821443,cur_DASH_shared7147,fields_DASH_to_DASH_binds10381,lists1118,mixins3791444,params3781445,shared3811446,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
}};
$e14311432.stack[R.EXN_STACKHEIGHT++] = $ss14351436;
}
if(R.isPyretException($e14311432)) {
$e14311432.pyretStack.push(L[315]);
}
throw $e14311432;
}
var $ret14371438 = $Hanf_begin_app_dropped16121447($z14331434,_check3821443,cur_DASH_shared7147,fields_DASH_to_DASH_binds10381,lists1118,mixins3791444,params3781445,shared3811446,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret14371438;
};
},{"length":9});
var anf_extend986130 = R.makeMethod(function($underscore3851430) {
return function(l3861425,import_DASH_type3871426,name3881427) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[313],3,arguments);
}
var anf_fun9851424 = G(well_DASH_formed_DASH_visitor183217,"s-import",L[314]);
var $z14161417 = D;
var $f14221423 = function(_) {
return R.isFunction(anf_fun9851424)?anf_fun9851424.app(l3861425,import_DASH_type3871426,name3881427):R.ffi.throwNonFunApp(L[313],anf_fun9851424,[l3861425,import_DASH_type3871426,name3881427]);
};
try {
if(--R.GAS > 0) {
$z14161417 = $f14221423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14221423,
"from":L[313]});
}
} catch($e14141415) {
if(R.isCont($e14141415)) {
var $ss14181419 = {"from":L[313],
"go":function(ann_DASH_check_DASH_temp9841428) {
return $Hann_DASH_check_DASH_temp16131429(ann_DASH_check_DASH_temp9841428);
}};
$e14141415.stack[R.EXN_STACKHEIGHT++] = $ss14181419;
}
if(R.isPyretException($e14141415)) {
$e14141415.pyretStack.push(L[313]);
}
throw $e14141415;
}
var $ret14201421 = $Hann_DASH_check_DASH_temp16131429($z14161417);
++R.GAS;
return $ret14201421;
};
},{"length":4});
var anf_extend989131 = R.makeMethod(function($underscore3891413) {
return function(l3901407,import_DASH_type3911408,name3921409,types3931410) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[311],4,arguments);
}
var anf_fun9881406 = G(well_DASH_formed_DASH_visitor183217,"s-import-types",L[312]);
var $z13981399 = D;
var $f14041405 = function(_) {
return R.isFunction(anf_fun9881406)?anf_fun9881406.app(l3901407,import_DASH_type3911408,name3921409,types3931410):R.ffi.throwNonFunApp(L[311],anf_fun9881406,[l3901407,import_DASH_type3911408,name3921409,types3931410]);
};
try {
if(--R.GAS > 0) {
$z13981399 = $f14041405();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14041405,
"from":L[311]});
}
} catch($e13961397) {
if(R.isCont($e13961397)) {
var $ss14001401 = {"from":L[311],
"go":function(ann_DASH_check_DASH_temp9871411) {
return $Hann_DASH_check_DASH_temp16141412(ann_DASH_check_DASH_temp9871411);
}};
$e13961397.stack[R.EXN_STACKHEIGHT++] = $ss14001401;
}
if(R.isPyretException($e13961397)) {
$e13961397.pyretStack.push(L[311]);
}
throw $e13961397;
}
var $ret14021403 = $Hann_DASH_check_DASH_temp16141412($z13981399);
++R.GAS;
return $ret14021403;
};
},{"length":5});
var anf_extend992132 = R.makeMethod(function($underscore3941395) {
return function(l3951390,fields3961391,import_DASH_type3971392) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[309],3,arguments);
}
var anf_fun9911389 = G(well_DASH_formed_DASH_visitor183217,"s-import-fields",L[310]);
var $z13811382 = D;
var $f13871388 = function(_) {
return R.isFunction(anf_fun9911389)?anf_fun9911389.app(l3951390,fields3961391,import_DASH_type3971392):R.ffi.throwNonFunApp(L[309],anf_fun9911389,[l3951390,fields3961391,import_DASH_type3971392]);
};
try {
if(--R.GAS > 0) {
$z13811382 = $f13871388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13871388,
"from":L[309]});
}
} catch($e13791380) {
if(R.isCont($e13791380)) {
var $ss13831384 = {"from":L[309],
"go":function(ann_DASH_check_DASH_temp9901393) {
return $Hann_DASH_check_DASH_temp16151394(ann_DASH_check_DASH_temp9901393);
}};
$e13791380.stack[R.EXN_STACKHEIGHT++] = $ss13831384;
}
if(R.isPyretException($e13791380)) {
$e13791380.pyretStack.push(L[309]);
}
throw $e13791380;
}
var $ret13851386 = $Hann_DASH_check_DASH_temp16151394($z13811382);
++R.GAS;
return $ret13851386;
};
},{"length":4});
var anf_extend995133 = R.makeMethod(function($underscore3981378) {
return function(l3991374,expr4001375) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[307],2,arguments);
}
var anf_fun9941373 = G(well_DASH_formed_DASH_visitor183217,"s-provide",L[308]);
var $z13651366 = D;
var $f13711372 = function(_) {
return R.isFunction(anf_fun9941373)?anf_fun9941373.app(l3991374,expr4001375):R.ffi.throwNonFunApp(L[307],anf_fun9941373,[l3991374,expr4001375]);
};
try {
if(--R.GAS > 0) {
$z13651366 = $f13711372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13711372,
"from":L[307]});
}
} catch($e13631364) {
if(R.isCont($e13631364)) {
var $ss13671368 = {"from":L[307],
"go":function(ann_DASH_check_DASH_temp9931376) {
return $Hann_DASH_check_DASH_temp16161377(ann_DASH_check_DASH_temp9931376);
}};
$e13631364.stack[R.EXN_STACKHEIGHT++] = $ss13671368;
}
if(R.isPyretException($e13631364)) {
$e13631364.pyretStack.push(L[307]);
}
throw $e13631364;
}
var $ret13691370 = $Hann_DASH_check_DASH_temp16161377($z13651366);
++R.GAS;
return $ret13691370;
};
},{"length":3});
var anf_extend998134 = R.makeMethod(function($underscore4011362) {
return function(l4021358,anns4031359) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[305],2,arguments);
}
var anf_fun9971357 = G(well_DASH_formed_DASH_visitor183217,"s-provide-types",L[306]);
var $z13491350 = D;
var $f13551356 = function(_) {
return R.isFunction(anf_fun9971357)?anf_fun9971357.app(l4021358,anns4031359):R.ffi.throwNonFunApp(L[305],anf_fun9971357,[l4021358,anns4031359]);
};
try {
if(--R.GAS > 0) {
$z13491350 = $f13551356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13551356,
"from":L[305]});
}
} catch($e13471348) {
if(R.isCont($e13471348)) {
var $ss13511352 = {"from":L[305],
"go":function(ann_DASH_check_DASH_temp9961360) {
return $Hann_DASH_check_DASH_temp16171361(ann_DASH_check_DASH_temp9961360);
}};
$e13471348.stack[R.EXN_STACKHEIGHT++] = $ss13511352;
}
if(R.isPyretException($e13471348)) {
$e13471348.pyretStack.push(L[305]);
}
throw $e13471348;
}
var $ret13531354 = $Hann_DASH_check_DASH_temp16171361($z13491350);
++R.GAS;
return $ret13531354;
};
},{"length":3});
var anf_extend1001135 = R.makeMethod(function($underscore4041346) {
return function(l4051340,shadows4061341,name4071342,ann4081343) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[303],4,arguments);
}
var anf_fun10001339 = G(well_DASH_formed_DASH_visitor183217,"s-bind",L[304]);
var $z13311332 = D;
var $f13371338 = function(_) {
return R.isFunction(anf_fun10001339)?anf_fun10001339.app(l4051340,shadows4061341,name4071342,ann4081343):R.ffi.throwNonFunApp(L[303],anf_fun10001339,[l4051340,shadows4061341,name4071342,ann4081343]);
};
try {
if(--R.GAS > 0) {
$z13311332 = $f13371338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13371338,
"from":L[303]});
}
} catch($e13291330) {
if(R.isCont($e13291330)) {
var $ss13331334 = {"from":L[303],
"go":function(ann_DASH_check_DASH_temp9991344) {
return $Hann_DASH_check_DASH_temp16181345(ann_DASH_check_DASH_temp9991344);
}};
$e13291330.stack[R.EXN_STACKHEIGHT++] = $ss13331334;
}
if(R.isPyretException($e13291330)) {
$e13291330.pyretStack.push(L[303]);
}
throw $e13291330;
}
var $ret13351336 = $Hann_DASH_check_DASH_temp16181345($z13311332);
++R.GAS;
return $ret13351336;
};
},{"length":5});
var anf_extend1004136 = R.makeMethod(function($underscore4091328) {
return function(l4101323,bind4111324,expr4121325) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[301],3,arguments);
}
var anf_fun10031322 = G(well_DASH_formed_DASH_visitor183217,"s-var-bind",L[302]);
var $z13141315 = D;
var $f13201321 = function(_) {
return R.isFunction(anf_fun10031322)?anf_fun10031322.app(l4101323,bind4111324,expr4121325):R.ffi.throwNonFunApp(L[301],anf_fun10031322,[l4101323,bind4111324,expr4121325]);
};
try {
if(--R.GAS > 0) {
$z13141315 = $f13201321();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13201321,
"from":L[301]});
}
} catch($e13121313) {
if(R.isCont($e13121313)) {
var $ss13161317 = {"from":L[301],
"go":function(ann_DASH_check_DASH_temp10021326) {
return $Hann_DASH_check_DASH_temp16191327(ann_DASH_check_DASH_temp10021326);
}};
$e13121313.stack[R.EXN_STACKHEIGHT++] = $ss13161317;
}
if(R.isPyretException($e13121313)) {
$e13121313.pyretStack.push(L[301]);
}
throw $e13121313;
}
var $ret13181319 = $Hann_DASH_check_DASH_temp16191327($z13141315);
++R.GAS;
return $ret13181319;
};
},{"length":4});
var anf_extend1007137 = R.makeMethod(function($underscore4131311) {
return function(l4141306,bind4151307,expr4161308) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[299],3,arguments);
}
var anf_fun10061305 = G(well_DASH_formed_DASH_visitor183217,"s-let-bind",L[300]);
var $z12971298 = D;
var $f13031304 = function(_) {
return R.isFunction(anf_fun10061305)?anf_fun10061305.app(l4141306,bind4151307,expr4161308):R.ffi.throwNonFunApp(L[299],anf_fun10061305,[l4141306,bind4151307,expr4161308]);
};
try {
if(--R.GAS > 0) {
$z12971298 = $f13031304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13031304,
"from":L[299]});
}
} catch($e12951296) {
if(R.isCont($e12951296)) {
var $ss12991300 = {"from":L[299],
"go":function(ann_DASH_check_DASH_temp10051309) {
return $Hann_DASH_check_DASH_temp16201310(ann_DASH_check_DASH_temp10051309);
}};
$e12951296.stack[R.EXN_STACKHEIGHT++] = $ss12991300;
}
if(R.isPyretException($e12951296)) {
$e12951296.pyretStack.push(L[299]);
}
throw $e12951296;
}
var $ret13011302 = $Hann_DASH_check_DASH_temp16201310($z12971298);
++R.GAS;
return $ret13011302;
};
},{"length":4});
var anf_extend1010138 = R.makeMethod(function($underscore4171294) {
return function(l4181289,binds4191290,body4201291) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[297],3,arguments);
}
var anf_fun10091288 = G(well_DASH_formed_DASH_visitor183217,"s-let-expr",L[298]);
var $z12801281 = D;
var $f12861287 = function(_) {
return R.isFunction(anf_fun10091288)?anf_fun10091288.app(l4181289,binds4191290,body4201291):R.ffi.throwNonFunApp(L[297],anf_fun10091288,[l4181289,binds4191290,body4201291]);
};
try {
if(--R.GAS > 0) {
$z12801281 = $f12861287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12861287,
"from":L[297]});
}
} catch($e12781279) {
if(R.isCont($e12781279)) {
var $ss12821283 = {"from":L[297],
"go":function(ann_DASH_check_DASH_temp10081292) {
return $Hann_DASH_check_DASH_temp16211293(ann_DASH_check_DASH_temp10081292);
}};
$e12781279.stack[R.EXN_STACKHEIGHT++] = $ss12821283;
}
if(R.isPyretException($e12781279)) {
$e12781279.pyretStack.push(L[297]);
}
throw $e12781279;
}
var $ret12841285 = $Hann_DASH_check_DASH_temp16211293($z12801281);
++R.GAS;
return $ret12841285;
};
},{"length":4});
var anf_extend1013139 = R.makeMethod(function($underscore4211277) {
return function(l4221272,bind4231273,expr4241274) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[295],3,arguments);
}
var anf_fun10121271 = G(well_DASH_formed_DASH_visitor183217,"s-letrec-bind",L[296]);
var $z12631264 = D;
var $f12691270 = function(_) {
return R.isFunction(anf_fun10121271)?anf_fun10121271.app(l4221272,bind4231273,expr4241274):R.ffi.throwNonFunApp(L[295],anf_fun10121271,[l4221272,bind4231273,expr4241274]);
};
try {
if(--R.GAS > 0) {
$z12631264 = $f12691270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12691270,
"from":L[295]});
}
} catch($e12611262) {
if(R.isCont($e12611262)) {
var $ss12651266 = {"from":L[295],
"go":function(ann_DASH_check_DASH_temp10111275) {
return $Hann_DASH_check_DASH_temp16221276(ann_DASH_check_DASH_temp10111275);
}};
$e12611262.stack[R.EXN_STACKHEIGHT++] = $ss12651266;
}
if(R.isPyretException($e12611262)) {
$e12611262.pyretStack.push(L[295]);
}
throw $e12611262;
}
var $ret12671268 = $Hann_DASH_check_DASH_temp16221276($z12631264);
++R.GAS;
return $ret12671268;
};
},{"length":4});
var anf_extend1016140 = R.makeMethod(function($underscore4251260) {
return function(l4261255,binds4271256,body4281257) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[293],3,arguments);
}
var anf_fun10151254 = G(well_DASH_formed_DASH_visitor183217,"s-letrec",L[294]);
var $z12461247 = D;
var $f12521253 = function(_) {
return R.isFunction(anf_fun10151254)?anf_fun10151254.app(l4261255,binds4271256,body4281257):R.ffi.throwNonFunApp(L[293],anf_fun10151254,[l4261255,binds4271256,body4281257]);
};
try {
if(--R.GAS > 0) {
$z12461247 = $f12521253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12521253,
"from":L[293]});
}
} catch($e12441245) {
if(R.isCont($e12441245)) {
var $ss12481249 = {"from":L[293],
"go":function(ann_DASH_check_DASH_temp10141258) {
return $Hann_DASH_check_DASH_temp16231259(ann_DASH_check_DASH_temp10141258);
}};
$e12441245.stack[R.EXN_STACKHEIGHT++] = $ss12481249;
}
if(R.isPyretException($e12441245)) {
$e12441245.pyretStack.push(L[293]);
}
throw $e12441245;
}
var $ret12501251 = $Hann_DASH_check_DASH_temp16231259($z12461247);
++R.GAS;
return $ret12501251;
};
},{"length":4});
var anf_extend1019141 = R.makeMethod(function($underscore4291243) {
return function(l4301238,hints4311239,exp4321240) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[288],3,arguments);
}
return R.checkAnnArgs([Loc6844,List1943,R.getDotAnn(L[290],"A",A222,"Expr")],[l4301238,hints4311239,exp4321240],[L[291],L[292],L[290]],function() {
var anf_fun10181237 = G(well_DASH_formed_DASH_visitor183217,"s-hint-exp",L[289]);
var $z12291230 = D;
var $f12351236 = function(_) {
return R.isFunction(anf_fun10181237)?anf_fun10181237.app(l4301238,hints4311239,exp4321240):R.ffi.throwNonFunApp(L[288],anf_fun10181237,[l4301238,hints4311239,exp4321240]);
};
try {
if(--R.GAS > 0) {
$z12291230 = $f12351236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12351236,
"from":L[288]});
}
} catch($e12271228) {
if(R.isCont($e12271228)) {
var $ss12311232 = {"from":L[288],
"go":function(ann_DASH_check_DASH_temp10171241) {
return $Hann_DASH_check_DASH_temp16241242(ann_DASH_check_DASH_temp10171241);
}};
$e12271228.stack[R.EXN_STACKHEIGHT++] = $ss12311232;
}
if(R.isPyretException($e12271228)) {
$e12271228.pyretStack.push(L[288]);
}
throw $e12271228;
}
var $ret12331234 = $Hann_DASH_check_DASH_temp16241242($z12291230);
++R.GAS;
return $ret12331234;
});
};
},{"length":4});
var anf_extend1022142 = R.makeMethod(function($underscore4331226) {
return function(l4341221,expr4351222,params4361223) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[283],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[285],"A",A222,"Expr"),List1943],[l4341221,expr4351222,params4361223],[L[286],L[285],L[287]],function() {
var anf_fun10211220 = G(well_DASH_formed_DASH_visitor183217,"s-instantiate",L[284]);
var $z12121213 = D;
var $f12181219 = function(_) {
return R.isFunction(anf_fun10211220)?anf_fun10211220.app(l4341221,expr4351222,params4361223):R.ffi.throwNonFunApp(L[283],anf_fun10211220,[l4341221,expr4351222,params4361223]);
};
try {
if(--R.GAS > 0) {
$z12121213 = $f12181219();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12181219,
"from":L[283]});
}
} catch($e12101211) {
if(R.isCont($e12101211)) {
var $ss12141215 = {"from":L[283],
"go":function(ann_DASH_check_DASH_temp10201224) {
return $Hann_DASH_check_DASH_temp16251225(ann_DASH_check_DASH_temp10201224);
}};
$e12101211.stack[R.EXN_STACKHEIGHT++] = $ss12141215;
}
if(R.isPyretException($e12101211)) {
$e12101211.pyretStack.push(L[283]);
}
throw $e12101211;
}
var $ret12161217 = $Hann_DASH_check_DASH_temp16251225($z12121213);
++R.GAS;
return $ret12161217;
});
};
},{"length":4});
var anf_extend1025143 = R.makeMethod(function($underscore4371209) {
return function(l4381205,stmts4391206) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[281],2,arguments);
}
var anf_fun10241204 = G(well_DASH_formed_DASH_visitor183217,"s-block",L[282]);
var $z11961197 = D;
var $f12021203 = function(_) {
return R.isFunction(anf_fun10241204)?anf_fun10241204.app(l4381205,stmts4391206):R.ffi.throwNonFunApp(L[281],anf_fun10241204,[l4381205,stmts4391206]);
};
try {
if(--R.GAS > 0) {
$z11961197 = $f12021203();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12021203,
"from":L[281]});
}
} catch($e11941195) {
if(R.isCont($e11941195)) {
var $ss11981199 = {"from":L[281],
"go":function(ann_DASH_check_DASH_temp10231207) {
return $Hann_DASH_check_DASH_temp16261208(ann_DASH_check_DASH_temp10231207);
}};
$e11941195.stack[R.EXN_STACKHEIGHT++] = $ss11981199;
}
if(R.isPyretException($e11941195)) {
$e11941195.pyretStack.push(L[281]);
}
throw $e11941195;
}
var $ret12001201 = $Hann_DASH_check_DASH_temp16261208($z11961197);
++R.GAS;
return $ret12001201;
};
},{"length":3});
var anf_extend1028144 = R.makeMethod(function($underscore4401193) {
return function(l4411189,body4421190) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[277],2,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[279],"A",A222,"Expr")],[l4411189,body4421190],[L[280],L[279]],function() {
var anf_fun10271188 = G(well_DASH_formed_DASH_visitor183217,"s-user-block",L[278]);
var $z11801181 = D;
var $f11861187 = function(_) {
return R.isFunction(anf_fun10271188)?anf_fun10271188.app(l4411189,body4421190):R.ffi.throwNonFunApp(L[277],anf_fun10271188,[l4411189,body4421190]);
};
try {
if(--R.GAS > 0) {
$z11801181 = $f11861187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11861187,
"from":L[277]});
}
} catch($e11781179) {
if(R.isCont($e11781179)) {
var $ss11821183 = {"from":L[277],
"go":function(ann_DASH_check_DASH_temp10261191) {
return $Hann_DASH_check_DASH_temp16271192(ann_DASH_check_DASH_temp10261191);
}};
$e11781179.stack[R.EXN_STACKHEIGHT++] = $ss11821183;
}
if(R.isPyretException($e11781179)) {
$e11781179.pyretStack.push(L[277]);
}
throw $e11781179;
}
var $ret11841185 = $Hann_DASH_check_DASH_temp16271192($z11801181);
++R.GAS;
return $ret11841185;
});
};
},{"length":3});
var anf_extend1031145 = R.makeMethod(function($underscore4431177) {
return function(l4441167,name4451168,params4461169,args4471170,ann4481171,doc4491172,body4501173,_check4511174) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[275],8,arguments);
}
var anf_fun10301166 = G(well_DASH_formed_DASH_visitor183217,"s-fun",L[276]);
var $z11581159 = D;
var $f11641165 = function(_) {
return R.isFunction(anf_fun10301166)?anf_fun10301166.app(l4441167,name4451168,params4461169,args4471170,ann4481171,doc4491172,body4501173,_check4511174):R.ffi.throwNonFunApp(L[275],anf_fun10301166,[l4441167,name4451168,params4461169,args4471170,ann4481171,doc4491172,body4501173,_check4511174]);
};
try {
if(--R.GAS > 0) {
$z11581159 = $f11641165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11641165,
"from":L[275]});
}
} catch($e11561157) {
if(R.isCont($e11561157)) {
var $ss11601161 = {"from":L[275],
"go":function(ann_DASH_check_DASH_temp10291175) {
return $Hann_DASH_check_DASH_temp16281176(ann_DASH_check_DASH_temp10291175);
}};
$e11561157.stack[R.EXN_STACKHEIGHT++] = $ss11601161;
}
if(R.isPyretException($e11561157)) {
$e11561157.pyretStack.push(L[275]);
}
throw $e11561157;
}
var $ret11621163 = $Hann_DASH_check_DASH_temp16281176($z11581159);
++R.GAS;
return $ret11621163;
};
},{"length":9});
var anf_extend1034146 = R.makeMethod(function($underscore4521155) {
return function(l4531150,name4541151,value4551152) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[270],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[272],"A",A222,"Bind"),R.getDotAnn(L[273],"A",A222,"Expr")],[l4531150,name4541151,value4551152],[L[274],L[272],L[273]],function() {
var anf_fun10331149 = G(well_DASH_formed_DASH_visitor183217,"s-var",L[271]);
var $z11411142 = D;
var $f11471148 = function(_) {
return R.isFunction(anf_fun10331149)?anf_fun10331149.app(l4531150,name4541151,value4551152):R.ffi.throwNonFunApp(L[270],anf_fun10331149,[l4531150,name4541151,value4551152]);
};
try {
if(--R.GAS > 0) {
$z11411142 = $f11471148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11471148,
"from":L[270]});
}
} catch($e11391140) {
if(R.isCont($e11391140)) {
var $ss11431144 = {"from":L[270],
"go":function(ann_DASH_check_DASH_temp10321153) {
return $Hann_DASH_check_DASH_temp16291154(ann_DASH_check_DASH_temp10321153);
}};
$e11391140.stack[R.EXN_STACKHEIGHT++] = $ss11431144;
}
if(R.isPyretException($e11391140)) {
$e11391140.pyretStack.push(L[270]);
}
throw $e11391140;
}
var $ret11451146 = $Hann_DASH_check_DASH_temp16291154($z11411142);
++R.GAS;
return $ret11451146;
});
};
},{"length":4});
var anf_extend1037147 = R.makeMethod(function($underscore4561138) {
return function(l4571132,name4581133,value4591134,keyword_DASH_val4601135) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[264],4,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[266],"A",A222,"Bind"),R.getDotAnn(L[267],"A",A222,"Expr"),$type$Boolean11],[l4571132,name4581133,value4591134,keyword_DASH_val4601135],[L[268],L[266],L[267],L[269]],function() {
var anf_fun10361131 = G(well_DASH_formed_DASH_visitor183217,"s-let",L[265]);
var $z11231124 = D;
var $f11291130 = function(_) {
return R.isFunction(anf_fun10361131)?anf_fun10361131.app(l4571132,name4581133,value4591134,keyword_DASH_val4601135):R.ffi.throwNonFunApp(L[264],anf_fun10361131,[l4571132,name4581133,value4591134,keyword_DASH_val4601135]);
};
try {
if(--R.GAS > 0) {
$z11231124 = $f11291130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11291130,
"from":L[264]});
}
} catch($e11211122) {
if(R.isCont($e11211122)) {
var $ss11251126 = {"from":L[264],
"go":function(ann_DASH_check_DASH_temp10351136) {
return $Hann_DASH_check_DASH_temp16301137(ann_DASH_check_DASH_temp10351136);
}};
$e11211122.stack[R.EXN_STACKHEIGHT++] = $ss11251126;
}
if(R.isPyretException($e11211122)) {
$e11211122.pyretStack.push(L[264]);
}
throw $e11211122;
}
var $ret11271128 = $Hann_DASH_check_DASH_temp16301137($z11231124);
++R.GAS;
return $ret11271128;
});
};
},{"length":5});
var anf_extend1040148 = R.makeMethod(function($underscore4611120) {
return function(l4621116,bindings4631117) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[260],2,arguments);
}
return R.checkAnnArgs([Loc6844,List1943],[l4621116,bindings4631117],[L[262],L[263]],function() {
var anf_fun10391115 = G(well_DASH_formed_DASH_visitor183217,"s-graph",L[261]);
var $z11071108 = D;
var $f11131114 = function(_) {
return R.isFunction(anf_fun10391115)?anf_fun10391115.app(l4621116,bindings4631117):R.ffi.throwNonFunApp(L[260],anf_fun10391115,[l4621116,bindings4631117]);
};
try {
if(--R.GAS > 0) {
$z11071108 = $f11131114();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11131114,
"from":L[260]});
}
} catch($e11051106) {
if(R.isCont($e11051106)) {
var $ss11091110 = {"from":L[260],
"go":function(ann_DASH_check_DASH_temp10381118) {
return $Hann_DASH_check_DASH_temp16311119(ann_DASH_check_DASH_temp10381118);
}};
$e11051106.stack[R.EXN_STACKHEIGHT++] = $ss11091110;
}
if(R.isPyretException($e11051106)) {
$e11051106.pyretStack.push(L[260]);
}
throw $e11051106;
}
var $ret11111112 = $Hann_DASH_check_DASH_temp16311119($z11071108);
++R.GAS;
return $ret11111112;
});
};
},{"length":3});
var anf_extend1043149 = R.makeMethod(function($underscore4641104) {
return function(l4651099,test4661100,block4671101) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[255],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[257],"A",A222,"Expr"),R.getDotAnn(L[258],"A",A222,"Expr")],[l4651099,test4661100,block4671101],[L[259],L[257],L[258]],function() {
var anf_fun10421098 = G(well_DASH_formed_DASH_visitor183217,"s-when",L[256]);
var $z10901091 = D;
var $f10961097 = function(_) {
return R.isFunction(anf_fun10421098)?anf_fun10421098.app(l4651099,test4661100,block4671101):R.ffi.throwNonFunApp(L[255],anf_fun10421098,[l4651099,test4661100,block4671101]);
};
try {
if(--R.GAS > 0) {
$z10901091 = $f10961097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10961097,
"from":L[255]});
}
} catch($e10881089) {
if(R.isCont($e10881089)) {
var $ss10921093 = {"from":L[255],
"go":function(ann_DASH_check_DASH_temp10411102) {
return $Hann_DASH_check_DASH_temp16321103(ann_DASH_check_DASH_temp10411102);
}};
$e10881089.stack[R.EXN_STACKHEIGHT++] = $ss10921093;
}
if(R.isPyretException($e10881089)) {
$e10881089.pyretStack.push(L[255]);
}
throw $e10881089;
}
var $ret10941095 = $Hann_DASH_check_DASH_temp16321103($z10901091);
++R.GAS;
return $ret10941095;
});
};
},{"length":4});
var anf_extend1046150 = R.makeMethod(function($underscore4681087) {
return function(l4691082,name4701083,ann4711084) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[250],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[252],"A",A222,"Name"),R.getDotAnn(L[253],"A",A222,"Ann")],[l4691082,name4701083,ann4711084],[L[254],L[252],L[253]],function() {
var anf_fun10451081 = G(well_DASH_formed_DASH_visitor183217,"s-contract",L[251]);
var $z10731074 = D;
var $f10791080 = function(_) {
return R.isFunction(anf_fun10451081)?anf_fun10451081.app(l4691082,name4701083,ann4711084):R.ffi.throwNonFunApp(L[250],anf_fun10451081,[l4691082,name4701083,ann4711084]);
};
try {
if(--R.GAS > 0) {
$z10731074 = $f10791080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10791080,
"from":L[250]});
}
} catch($e10711072) {
if(R.isCont($e10711072)) {
var $ss10751076 = {"from":L[250],
"go":function(ann_DASH_check_DASH_temp10441085) {
return $Hann_DASH_check_DASH_temp16331086(ann_DASH_check_DASH_temp10441085);
}};
$e10711072.stack[R.EXN_STACKHEIGHT++] = $ss10751076;
}
if(R.isPyretException($e10711072)) {
$e10711072.pyretStack.push(L[250]);
}
throw $e10711072;
}
var $ret10771078 = $Hann_DASH_check_DASH_temp16331086($z10731074);
++R.GAS;
return $ret10771078;
});
};
},{"length":4});
var anf_extend1049151 = R.makeMethod(function($underscore4721070) {
return function(l4731065,id4741066,value4751067) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[245],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[247],"A",A222,"Name"),R.getDotAnn(L[248],"A",A222,"Expr")],[l4731065,id4741066,value4751067],[L[249],L[247],L[248]],function() {
var anf_fun10481064 = G(well_DASH_formed_DASH_visitor183217,"s-assign",L[246]);
var $z10561057 = D;
var $f10621063 = function(_) {
return R.isFunction(anf_fun10481064)?anf_fun10481064.app(l4731065,id4741066,value4751067):R.ffi.throwNonFunApp(L[245],anf_fun10481064,[l4731065,id4741066,value4751067]);
};
try {
if(--R.GAS > 0) {
$z10561057 = $f10621063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10621063,
"from":L[245]});
}
} catch($e10541055) {
if(R.isCont($e10541055)) {
var $ss10581059 = {"from":L[245],
"go":function(ann_DASH_check_DASH_temp10471068) {
return $Hann_DASH_check_DASH_temp16341069(ann_DASH_check_DASH_temp10471068);
}};
$e10541055.stack[R.EXN_STACKHEIGHT++] = $ss10581059;
}
if(R.isPyretException($e10541055)) {
$e10541055.pyretStack.push(L[245]);
}
throw $e10541055;
}
var $ret10601061 = $Hann_DASH_check_DASH_temp16341069($z10561057);
++R.GAS;
return $ret10601061;
});
};
},{"length":4});
var anf_extend1052152 = R.makeMethod(function($underscore4761053) {
return function(l4771048,test4781049,body4791050) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[240],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[242],"A",A222,"Expr"),R.getDotAnn(L[243],"A",A222,"Expr")],[l4771048,test4781049,body4791050],[L[244],L[242],L[243]],function() {
var anf_fun10511047 = G(well_DASH_formed_DASH_visitor183217,"s-if-branch",L[241]);
var $z10391040 = D;
var $f10451046 = function(_) {
return R.isFunction(anf_fun10511047)?anf_fun10511047.app(l4771048,test4781049,body4791050):R.ffi.throwNonFunApp(L[240],anf_fun10511047,[l4771048,test4781049,body4791050]);
};
try {
if(--R.GAS > 0) {
$z10391040 = $f10451046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10451046,
"from":L[240]});
}
} catch($e10371038) {
if(R.isCont($e10371038)) {
var $ss10411042 = {"from":L[240],
"go":function(ann_DASH_check_DASH_temp10501051) {
return $Hann_DASH_check_DASH_temp16351052(ann_DASH_check_DASH_temp10501051);
}};
$e10371038.stack[R.EXN_STACKHEIGHT++] = $ss10411042;
}
if(R.isPyretException($e10371038)) {
$e10371038.pyretStack.push(L[240]);
}
throw $e10371038;
}
var $ret10431044 = $Hann_DASH_check_DASH_temp16351052($z10391040);
++R.GAS;
return $ret10431044;
});
};
},{"length":4});
var anf_extend1055153 = R.makeMethod(function($underscore4801036) {
return function(l4811031,test4821032,body4831033) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[235],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[237],"A",A222,"Expr"),R.getDotAnn(L[238],"A",A222,"Expr")],[l4811031,test4821032,body4831033],[L[239],L[237],L[238]],function() {
var anf_fun10541030 = G(well_DASH_formed_DASH_visitor183217,"s-if-pipe-branch",L[236]);
var $z10221023 = D;
var $f10281029 = function(_) {
return R.isFunction(anf_fun10541030)?anf_fun10541030.app(l4811031,test4821032,body4831033):R.ffi.throwNonFunApp(L[235],anf_fun10541030,[l4811031,test4821032,body4831033]);
};
try {
if(--R.GAS > 0) {
$z10221023 = $f10281029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10281029,
"from":L[235]});
}
} catch($e10201021) {
if(R.isCont($e10201021)) {
var $ss10241025 = {"from":L[235],
"go":function(ann_DASH_check_DASH_temp10531034) {
return $Hann_DASH_check_DASH_temp16361035(ann_DASH_check_DASH_temp10531034);
}};
$e10201021.stack[R.EXN_STACKHEIGHT++] = $ss10241025;
}
if(R.isPyretException($e10201021)) {
$e10201021.pyretStack.push(L[235]);
}
throw $e10201021;
}
var $ret10261027 = $Hann_DASH_check_DASH_temp16361035($z10221023);
++R.GAS;
return $ret10261027;
});
};
},{"length":4});
var anf_extend1058154 = R.makeMethod(function($underscore4841019) {
return function(l4851015,branches4861016) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[231],2,arguments);
}
return R.checkAnnArgs([Loc6844,List1943],[l4851015,branches4861016],[L[233],L[234]],function() {
var anf_fun10571014 = G(well_DASH_formed_DASH_visitor183217,"s-if",L[232]);
var $z10061007 = D;
var $f10121013 = function(_) {
return R.isFunction(anf_fun10571014)?anf_fun10571014.app(l4851015,branches4861016):R.ffi.throwNonFunApp(L[231],anf_fun10571014,[l4851015,branches4861016]);
};
try {
if(--R.GAS > 0) {
$z10061007 = $f10121013();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10121013,
"from":L[231]});
}
} catch($e10041005) {
if(R.isCont($e10041005)) {
var $ss10081009 = {"from":L[231],
"go":function(ann_DASH_check_DASH_temp10561017) {
return $Hann_DASH_check_DASH_temp16371018(ann_DASH_check_DASH_temp10561017);
}};
$e10041005.stack[R.EXN_STACKHEIGHT++] = $ss10081009;
}
if(R.isPyretException($e10041005)) {
$e10041005.pyretStack.push(L[231]);
}
throw $e10041005;
}
var $ret10101011 = $Hann_DASH_check_DASH_temp16371018($z10061007);
++R.GAS;
return $ret10101011;
});
};
},{"length":3});
var anf_extend1061155 = R.makeMethod(function($underscore4871003) {
return function(l488998,branches489999,_else4901000) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[226],3,arguments);
}
return R.checkAnnArgs([Loc6844,List1943,R.getDotAnn(L[228],"A",A222,"Expr")],[l488998,branches489999,_else4901000],[L[229],L[230],L[228]],function() {
var anf_fun1060997 = G(well_DASH_formed_DASH_visitor183217,"s-if-else",L[227]);
var $z989990 = D;
var $f995996 = function(_) {
return R.isFunction(anf_fun1060997)?anf_fun1060997.app(l488998,branches489999,_else4901000):R.ffi.throwNonFunApp(L[226],anf_fun1060997,[l488998,branches489999,_else4901000]);
};
try {
if(--R.GAS > 0) {
$z989990 = $f995996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f995996,
"from":L[226]});
}
} catch($e987988) {
if(R.isCont($e987988)) {
var $ss991992 = {"from":L[226],
"go":function(ann_DASH_check_DASH_temp10591001) {
return $Hann_DASH_check_DASH_temp16381002(ann_DASH_check_DASH_temp10591001);
}};
$e987988.stack[R.EXN_STACKHEIGHT++] = $ss991992;
}
if(R.isPyretException($e987988)) {
$e987988.pyretStack.push(L[226]);
}
throw $e987988;
}
var $ret993994 = $Hann_DASH_check_DASH_temp16381002($z989990);
++R.GAS;
return $ret993994;
});
};
},{"length":4});
var anf_extend1064156 = R.makeMethod(function($underscore491986) {
return function(l492982,branches493983) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[222],2,arguments);
}
return R.checkAnnArgs([Loc6844,List1943],[l492982,branches493983],[L[224],L[225]],function() {
var anf_fun1063981 = G(well_DASH_formed_DASH_visitor183217,"s-if-pipe",L[223]);
var $z973974 = D;
var $f979980 = function(_) {
return R.isFunction(anf_fun1063981)?anf_fun1063981.app(l492982,branches493983):R.ffi.throwNonFunApp(L[222],anf_fun1063981,[l492982,branches493983]);
};
try {
if(--R.GAS > 0) {
$z973974 = $f979980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f979980,
"from":L[222]});
}
} catch($e971972) {
if(R.isCont($e971972)) {
var $ss975976 = {"from":L[222],
"go":function(ann_DASH_check_DASH_temp1062984) {
return $Hann_DASH_check_DASH_temp1639985(ann_DASH_check_DASH_temp1062984);
}};
$e971972.stack[R.EXN_STACKHEIGHT++] = $ss975976;
}
if(R.isPyretException($e971972)) {
$e971972.pyretStack.push(L[222]);
}
throw $e971972;
}
var $ret977978 = $Hann_DASH_check_DASH_temp1639985($z973974);
++R.GAS;
return $ret977978;
});
};
},{"length":3});
var anf_extend1067157 = R.makeMethod(function($underscore494970) {
return function(l495965,branches496966,_else497967) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[217],3,arguments);
}
return R.checkAnnArgs([Loc6844,List1943,R.getDotAnn(L[219],"A",A222,"Expr")],[l495965,branches496966,_else497967],[L[220],L[221],L[219]],function() {
var anf_fun1066964 = G(well_DASH_formed_DASH_visitor183217,"s-if-pipe-else",L[218]);
var $z956957 = D;
var $f962963 = function(_) {
return R.isFunction(anf_fun1066964)?anf_fun1066964.app(l495965,branches496966,_else497967):R.ffi.throwNonFunApp(L[217],anf_fun1066964,[l495965,branches496966,_else497967]);
};
try {
if(--R.GAS > 0) {
$z956957 = $f962963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f962963,
"from":L[217]});
}
} catch($e954955) {
if(R.isCont($e954955)) {
var $ss958959 = {"from":L[217],
"go":function(ann_DASH_check_DASH_temp1065968) {
return $Hann_DASH_check_DASH_temp1640969(ann_DASH_check_DASH_temp1065968);
}};
$e954955.stack[R.EXN_STACKHEIGHT++] = $ss958959;
}
if(R.isPyretException($e954955)) {
$e954955.pyretStack.push(L[217]);
}
throw $e954955;
}
var $ret960961 = $Hann_DASH_check_DASH_temp1640969($z956957);
++R.GAS;
return $ret960961;
});
};
},{"length":4});
var anf_extend1070158 = R.makeMethod(function($underscore498953) {
return function(l499947,name500948,args501949,body502950) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[211],4,arguments);
}
return R.checkAnnArgs([Loc6844,$type$String12,List1943,R.getDotAnn(L[213],"A",A222,"Expr")],[l499947,name500948,args501949,body502950],[L[214],L[215],L[216],L[213]],function() {
var anf_fun1069946 = G(well_DASH_formed_DASH_visitor183217,"s-cases-branch",L[212]);
var $z938939 = D;
var $f944945 = function(_) {
return R.isFunction(anf_fun1069946)?anf_fun1069946.app(l499947,name500948,args501949,body502950):R.ffi.throwNonFunApp(L[211],anf_fun1069946,[l499947,name500948,args501949,body502950]);
};
try {
if(--R.GAS > 0) {
$z938939 = $f944945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f944945,
"from":L[211]});
}
} catch($e936937) {
if(R.isCont($e936937)) {
var $ss940941 = {"from":L[211],
"go":function(ann_DASH_check_DASH_temp1068951) {
return $Hann_DASH_check_DASH_temp1641952(ann_DASH_check_DASH_temp1068951);
}};
$e936937.stack[R.EXN_STACKHEIGHT++] = $ss940941;
}
if(R.isPyretException($e936937)) {
$e936937.pyretStack.push(L[211]);
}
throw $e936937;
}
var $ret942943 = $Hann_DASH_check_DASH_temp1641952($z938939);
++R.GAS;
return $ret942943;
});
};
},{"length":5});
var anf_extend1073159 = R.makeMethod(function($underscore503935) {
return function(l504929,typ505930,val506931,branches507932) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[205],4,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[207],"A",A222,"Ann"),R.getDotAnn(L[208],"A",A222,"Expr"),List1943],[l504929,typ505930,val506931,branches507932],[L[209],L[207],L[208],L[210]],function() {
var anf_fun1072928 = G(well_DASH_formed_DASH_visitor183217,"s-cases",L[206]);
var $z920921 = D;
var $f926927 = function(_) {
return R.isFunction(anf_fun1072928)?anf_fun1072928.app(l504929,typ505930,val506931,branches507932):R.ffi.throwNonFunApp(L[205],anf_fun1072928,[l504929,typ505930,val506931,branches507932]);
};
try {
if(--R.GAS > 0) {
$z920921 = $f926927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f926927,
"from":L[205]});
}
} catch($e918919) {
if(R.isCont($e918919)) {
var $ss922923 = {"from":L[205],
"go":function(ann_DASH_check_DASH_temp1071933) {
return $Hann_DASH_check_DASH_temp1642934(ann_DASH_check_DASH_temp1071933);
}};
$e918919.stack[R.EXN_STACKHEIGHT++] = $ss922923;
}
if(R.isPyretException($e918919)) {
$e918919.pyretStack.push(L[205]);
}
throw $e918919;
}
var $ret924925 = $Hann_DASH_check_DASH_temp1642934($z920921);
++R.GAS;
return $ret924925;
});
};
},{"length":5});
var anf_extend1076160 = R.makeMethod(function($underscore508917) {
return function(l509910,typ510911,val511912,branches512913,_else513914) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[198],5,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[200],"A",A222,"Ann"),R.getDotAnn(L[201],"A",A222,"Expr"),List1943,R.getDotAnn(L[202],"A",A222,"Expr")],[l509910,typ510911,val511912,branches512913,_else513914],[L[203],L[200],L[201],L[204],L[202]],function() {
var anf_fun1075909 = G(well_DASH_formed_DASH_visitor183217,"s-cases-else",L[199]);
var $z901902 = D;
var $f907908 = function(_) {
return R.isFunction(anf_fun1075909)?anf_fun1075909.app(l509910,typ510911,val511912,branches512913,_else513914):R.ffi.throwNonFunApp(L[198],anf_fun1075909,[l509910,typ510911,val511912,branches512913,_else513914]);
};
try {
if(--R.GAS > 0) {
$z901902 = $f907908();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f907908,
"from":L[198]});
}
} catch($e899900) {
if(R.isCont($e899900)) {
var $ss903904 = {"from":L[198],
"go":function(ann_DASH_check_DASH_temp1074915) {
return $Hann_DASH_check_DASH_temp1643916(ann_DASH_check_DASH_temp1074915);
}};
$e899900.stack[R.EXN_STACKHEIGHT++] = $ss903904;
}
if(R.isPyretException($e899900)) {
$e899900.pyretStack.push(L[198]);
}
throw $e899900;
}
var $ret905906 = $Hann_DASH_check_DASH_temp1643916($z901902);
++R.GAS;
return $ret905906;
});
};
},{"length":6});
var anf_extend1079161 = R.makeMethod(function($underscore514898) {
return function(l515892,body516893,id517894,_except518895) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[192],4,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[194],"A",A222,"Expr"),R.getDotAnn(L[195],"A",A222,"Bind"),R.getDotAnn(L[196],"A",A222,"Expr")],[l515892,body516893,id517894,_except518895],[L[197],L[194],L[195],L[196]],function() {
var anf_fun1078891 = G(well_DASH_formed_DASH_visitor183217,"s-try",L[193]);
var $z883884 = D;
var $f889890 = function(_) {
return R.isFunction(anf_fun1078891)?anf_fun1078891.app(l515892,body516893,id517894,_except518895):R.ffi.throwNonFunApp(L[192],anf_fun1078891,[l515892,body516893,id517894,_except518895]);
};
try {
if(--R.GAS > 0) {
$z883884 = $f889890();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f889890,
"from":L[192]});
}
} catch($e881882) {
if(R.isCont($e881882)) {
var $ss885886 = {"from":L[192],
"go":function(ann_DASH_check_DASH_temp1077896) {
return $Hann_DASH_check_DASH_temp1644897(ann_DASH_check_DASH_temp1077896);
}};
$e881882.stack[R.EXN_STACKHEIGHT++] = $ss885886;
}
if(R.isPyretException($e881882)) {
$e881882.pyretStack.push(L[192]);
}
throw $e881882;
}
var $ret887888 = $Hann_DASH_check_DASH_temp1644897($z883884);
++R.GAS;
return $ret887888;
});
};
},{"length":5});
var anf_extend1082162 = R.makeMethod(function($underscore519880) {
return function(l520874,op521875,left522876,right523877) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[186],4,arguments);
}
return R.checkAnnArgs([Loc6844,$type$String12,R.getDotAnn(L[188],"A",A222,"Expr"),R.getDotAnn(L[189],"A",A222,"Expr")],[l520874,op521875,left522876,right523877],[L[190],L[191],L[188],L[189]],function() {
var anf_fun1081873 = G(well_DASH_formed_DASH_visitor183217,"s-op",L[187]);
var $z865866 = D;
var $f871872 = function(_) {
return R.isFunction(anf_fun1081873)?anf_fun1081873.app(l520874,op521875,left522876,right523877):R.ffi.throwNonFunApp(L[186],anf_fun1081873,[l520874,op521875,left522876,right523877]);
};
try {
if(--R.GAS > 0) {
$z865866 = $f871872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f871872,
"from":L[186]});
}
} catch($e863864) {
if(R.isCont($e863864)) {
var $ss867868 = {"from":L[186],
"go":function(ann_DASH_check_DASH_temp1080878) {
return $Hann_DASH_check_DASH_temp1645879(ann_DASH_check_DASH_temp1080878);
}};
$e863864.stack[R.EXN_STACKHEIGHT++] = $ss867868;
}
if(R.isPyretException($e863864)) {
$e863864.pyretStack.push(L[186]);
}
throw $e863864;
}
var $ret869870 = $Hann_DASH_check_DASH_temp1645879($z865866);
++R.GAS;
return $ret869870;
});
};
},{"length":5});
var anf_extend1085163 = R.makeMethod(function($underscore524862) {
return function(l525856,op526857,left527858,right528859) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[180],4,arguments);
}
return R.checkAnnArgs([Loc6844,$type$String12,R.getDotAnn(L[182],"A",A222,"Expr"),R.getDotAnn(L[183],"A",A222,"Expr")],[l525856,op526857,left527858,right528859],[L[184],L[185],L[182],L[183]],function() {
var anf_fun1084855 = G(well_DASH_formed_DASH_visitor183217,"s-check-test",L[181]);
var $z847848 = D;
var $f853854 = function(_) {
return R.isFunction(anf_fun1084855)?anf_fun1084855.app(l525856,op526857,left527858,right528859):R.ffi.throwNonFunApp(L[180],anf_fun1084855,[l525856,op526857,left527858,right528859]);
};
try {
if(--R.GAS > 0) {
$z847848 = $f853854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f853854,
"from":L[180]});
}
} catch($e845846) {
if(R.isCont($e845846)) {
var $ss849850 = {"from":L[180],
"go":function(ann_DASH_check_DASH_temp1083860) {
return $Hann_DASH_check_DASH_temp1646861(ann_DASH_check_DASH_temp1083860);
}};
$e845846.stack[R.EXN_STACKHEIGHT++] = $ss849850;
}
if(R.isPyretException($e845846)) {
$e845846.pyretStack.push(L[180]);
}
throw $e845846;
}
var $ret851852 = $Hann_DASH_check_DASH_temp1646861($z847848);
++R.GAS;
return $ret851852;
});
};
},{"length":5});
var anf_extend1088164 = R.makeMethod(function($underscore529844) {
return function(l530840,expr531841) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[176],2,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[178],"A",A222,"Expr")],[l530840,expr531841],[L[179],L[178]],function() {
var anf_fun1087839 = G(well_DASH_formed_DASH_visitor183217,"s-paren",L[177]);
var $z831832 = D;
var $f837838 = function(_) {
return R.isFunction(anf_fun1087839)?anf_fun1087839.app(l530840,expr531841):R.ffi.throwNonFunApp(L[176],anf_fun1087839,[l530840,expr531841]);
};
try {
if(--R.GAS > 0) {
$z831832 = $f837838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f837838,
"from":L[176]});
}
} catch($e829830) {
if(R.isCont($e829830)) {
var $ss833834 = {"from":L[176],
"go":function(ann_DASH_check_DASH_temp1086842) {
return $Hann_DASH_check_DASH_temp1647843(ann_DASH_check_DASH_temp1086842);
}};
$e829830.stack[R.EXN_STACKHEIGHT++] = $ss833834;
}
if(R.isPyretException($e829830)) {
$e829830.pyretStack.push(L[176]);
}
throw $e829830;
}
var $ret835836 = $Hann_DASH_check_DASH_temp1647843($z831832);
++R.GAS;
return $ret835836;
});
};
},{"length":3});
var anf_extend1091165 = R.makeMethod(function($underscore532828) {
return function(l533819,params534820,args535821,ann536822,doc537823,body538824,_check539825) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[167],7,arguments);
}
return R.checkAnnArgs([Loc6844,List1943,List1943,R.getDotAnn(L[169],"A",A222,"Ann"),$type$String12,R.getDotAnn(L[170],"A",A222,"Expr"),Option2045],[l533819,params534820,args535821,ann536822,doc537823,body538824,_check539825],[L[171],L[172],L[173],L[169],L[174],L[170],L[175]],function() {
var anf_fun1090818 = G(well_DASH_formed_DASH_visitor183217,"s-lam",L[168]);
var $z810811 = D;
var $f816817 = function(_) {
return R.isFunction(anf_fun1090818)?anf_fun1090818.app(l533819,params534820,args535821,ann536822,doc537823,body538824,_check539825):R.ffi.throwNonFunApp(L[167],anf_fun1090818,[l533819,params534820,args535821,ann536822,doc537823,body538824,_check539825]);
};
try {
if(--R.GAS > 0) {
$z810811 = $f816817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f816817,
"from":L[167]});
}
} catch($e808809) {
if(R.isCont($e808809)) {
var $ss812813 = {"from":L[167],
"go":function(ann_DASH_check_DASH_temp1089826) {
return $Hann_DASH_check_DASH_temp1648827(ann_DASH_check_DASH_temp1089826);
}};
$e808809.stack[R.EXN_STACKHEIGHT++] = $ss812813;
}
if(R.isPyretException($e808809)) {
$e808809.pyretStack.push(L[167]);
}
throw $e808809;
}
var $ret814815 = $Hann_DASH_check_DASH_temp1648827($z810811);
++R.GAS;
return $ret814815;
});
};
},{"length":8});
var anf_extend1094166 = R.makeMethod(function($underscore540807) {
return function(l541799,args542800,ann543801,doc544802,body545803,_check546804) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[159],6,arguments);
}
return R.checkAnnArgs([Loc6844,List1943,R.getDotAnn(L[161],"A",A222,"Ann"),$type$String12,R.getDotAnn(L[162],"A",A222,"Expr"),Option2045],[l541799,args542800,ann543801,doc544802,body545803,_check546804],[L[163],L[164],L[161],L[165],L[162],L[166]],function() {
var anf_fun1093798 = G(well_DASH_formed_DASH_visitor183217,"s-method",L[160]);
var $z790791 = D;
var $f796797 = function(_) {
return R.isFunction(anf_fun1093798)?anf_fun1093798.app(l541799,args542800,ann543801,doc544802,body545803,_check546804):R.ffi.throwNonFunApp(L[159],anf_fun1093798,[l541799,args542800,ann543801,doc544802,body545803,_check546804]);
};
try {
if(--R.GAS > 0) {
$z790791 = $f796797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f796797,
"from":L[159]});
}
} catch($e788789) {
if(R.isCont($e788789)) {
var $ss792793 = {"from":L[159],
"go":function(ann_DASH_check_DASH_temp1092805) {
return $Hann_DASH_check_DASH_temp1649806(ann_DASH_check_DASH_temp1092805);
}};
$e788789.stack[R.EXN_STACKHEIGHT++] = $ss792793;
}
if(R.isPyretException($e788789)) {
$e788789.pyretStack.push(L[159]);
}
throw $e788789;
}
var $ret794795 = $Hann_DASH_check_DASH_temp1649806($z790791);
++R.GAS;
return $ret794795;
});
};
},{"length":7});
var anf_extend1097167 = R.makeMethod(function($underscore547787) {
return function(l548782,supe549783,fields550784) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[154],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[156],"A",A222,"Expr"),List1943],[l548782,supe549783,fields550784],[L[157],L[156],L[158]],function() {
var anf_fun1096781 = G(well_DASH_formed_DASH_visitor183217,"s-extend",L[155]);
var $z773774 = D;
var $f779780 = function(_) {
return R.isFunction(anf_fun1096781)?anf_fun1096781.app(l548782,supe549783,fields550784):R.ffi.throwNonFunApp(L[154],anf_fun1096781,[l548782,supe549783,fields550784]);
};
try {
if(--R.GAS > 0) {
$z773774 = $f779780();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f779780,
"from":L[154]});
}
} catch($e771772) {
if(R.isCont($e771772)) {
var $ss775776 = {"from":L[154],
"go":function(ann_DASH_check_DASH_temp1095785) {
return $Hann_DASH_check_DASH_temp1650786(ann_DASH_check_DASH_temp1095785);
}};
$e771772.stack[R.EXN_STACKHEIGHT++] = $ss775776;
}
if(R.isPyretException($e771772)) {
$e771772.pyretStack.push(L[154]);
}
throw $e771772;
}
var $ret777778 = $Hann_DASH_check_DASH_temp1650786($z773774);
++R.GAS;
return $ret777778;
});
};
},{"length":4});
var anf_extend1100168 = R.makeMethod(function($underscore551770) {
return function(l552765,supe553766,fields554767) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[149],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[151],"A",A222,"Expr"),List1943],[l552765,supe553766,fields554767],[L[152],L[151],L[153]],function() {
var anf_fun1099764 = G(well_DASH_formed_DASH_visitor183217,"s-update",L[150]);
var $z756757 = D;
var $f762763 = function(_) {
return R.isFunction(anf_fun1099764)?anf_fun1099764.app(l552765,supe553766,fields554767):R.ffi.throwNonFunApp(L[149],anf_fun1099764,[l552765,supe553766,fields554767]);
};
try {
if(--R.GAS > 0) {
$z756757 = $f762763();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f762763,
"from":L[149]});
}
} catch($e754755) {
if(R.isCont($e754755)) {
var $ss758759 = {"from":L[149],
"go":function(ann_DASH_check_DASH_temp1098768) {
return $Hann_DASH_check_DASH_temp1651769(ann_DASH_check_DASH_temp1098768);
}};
$e754755.stack[R.EXN_STACKHEIGHT++] = $ss758759;
}
if(R.isPyretException($e754755)) {
$e754755.pyretStack.push(L[149]);
}
throw $e754755;
}
var $ret760761 = $Hann_DASH_check_DASH_temp1651769($z756757);
++R.GAS;
return $ret760761;
});
};
},{"length":4});
var anf_extend1103169 = R.makeMethod(function($underscore555753) {
return function(l556749,fields557750) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[145],2,arguments);
}
return R.checkAnnArgs([Loc6844,List1943],[l556749,fields557750],[L[147],L[148]],function() {
var anf_fun1102748 = G(well_DASH_formed_DASH_visitor183217,"s-obj",L[146]);
var $z740741 = D;
var $f746747 = function(_) {
return R.isFunction(anf_fun1102748)?anf_fun1102748.app(l556749,fields557750):R.ffi.throwNonFunApp(L[145],anf_fun1102748,[l556749,fields557750]);
};
try {
if(--R.GAS > 0) {
$z740741 = $f746747();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f746747,
"from":L[145]});
}
} catch($e738739) {
if(R.isCont($e738739)) {
var $ss742743 = {"from":L[145],
"go":function(ann_DASH_check_DASH_temp1101751) {
return $Hann_DASH_check_DASH_temp1652752(ann_DASH_check_DASH_temp1101751);
}};
$e738739.stack[R.EXN_STACKHEIGHT++] = $ss742743;
}
if(R.isPyretException($e738739)) {
$e738739.pyretStack.push(L[145]);
}
throw $e738739;
}
var $ret744745 = $Hann_DASH_check_DASH_temp1652752($z740741);
++R.GAS;
return $ret744745;
});
};
},{"length":3});
var anf_extend1106170 = R.makeMethod(function($underscore558737) {
return function(l559733,values560734) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[141],2,arguments);
}
return R.checkAnnArgs([Loc6844,List1943],[l559733,values560734],[L[143],L[144]],function() {
var anf_fun1105732 = G(well_DASH_formed_DASH_visitor183217,"s-array",L[142]);
var $z724725 = D;
var $f730731 = function(_) {
return R.isFunction(anf_fun1105732)?anf_fun1105732.app(l559733,values560734):R.ffi.throwNonFunApp(L[141],anf_fun1105732,[l559733,values560734]);
};
try {
if(--R.GAS > 0) {
$z724725 = $f730731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f730731,
"from":L[141]});
}
} catch($e722723) {
if(R.isCont($e722723)) {
var $ss726727 = {"from":L[141],
"go":function(ann_DASH_check_DASH_temp1104735) {
return $Hann_DASH_check_DASH_temp1653736(ann_DASH_check_DASH_temp1104735);
}};
$e722723.stack[R.EXN_STACKHEIGHT++] = $ss726727;
}
if(R.isPyretException($e722723)) {
$e722723.pyretStack.push(L[141]);
}
throw $e722723;
}
var $ret728729 = $Hann_DASH_check_DASH_temp1653736($z724725);
++R.GAS;
return $ret728729;
});
};
},{"length":3});
var anf_extend1109171 = R.makeMethod(function($underscore561721) {
return function(l562716,expr563717,typ564718) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[136],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[138],"A",A222,"Expr"),R.getDotAnn(L[139],"A",A222,"Name")],[l562716,expr563717,typ564718],[L[140],L[138],L[139]],function() {
var anf_fun1108715 = G(well_DASH_formed_DASH_visitor183217,"s-bless",L[137]);
var $z707708 = D;
var $f713714 = function(_) {
return R.isFunction(anf_fun1108715)?anf_fun1108715.app(l562716,expr563717,typ564718):R.ffi.throwNonFunApp(L[136],anf_fun1108715,[l562716,expr563717,typ564718]);
};
try {
if(--R.GAS > 0) {
$z707708 = $f713714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f713714,
"from":L[136]});
}
} catch($e705706) {
if(R.isCont($e705706)) {
var $ss709710 = {"from":L[136],
"go":function(ann_DASH_check_DASH_temp1107719) {
return $Hann_DASH_check_DASH_temp1654720(ann_DASH_check_DASH_temp1107719);
}};
$e705706.stack[R.EXN_STACKHEIGHT++] = $ss709710;
}
if(R.isPyretException($e705706)) {
$e705706.pyretStack.push(L[136]);
}
throw $e705706;
}
var $ret711712 = $Hann_DASH_check_DASH_temp1654720($z707708);
++R.GAS;
return $ret711712;
});
};
},{"length":4});
var anf_extend1112172 = R.makeMethod(function($underscore565704) {
return function(l566699,expr567700,typ568701) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[131],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[133],"A",A222,"Expr"),R.getDotAnn(L[134],"A",A222,"Name")],[l566699,expr567700,typ568701],[L[135],L[133],L[134]],function() {
var anf_fun1111698 = G(well_DASH_formed_DASH_visitor183217,"s-confirm",L[132]);
var $z690691 = D;
var $f696697 = function(_) {
return R.isFunction(anf_fun1111698)?anf_fun1111698.app(l566699,expr567700,typ568701):R.ffi.throwNonFunApp(L[131],anf_fun1111698,[l566699,expr567700,typ568701]);
};
try {
if(--R.GAS > 0) {
$z690691 = $f696697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f696697,
"from":L[131]});
}
} catch($e688689) {
if(R.isCont($e688689)) {
var $ss692693 = {"from":L[131],
"go":function(ann_DASH_check_DASH_temp1110702) {
return $Hann_DASH_check_DASH_temp1655703(ann_DASH_check_DASH_temp1110702);
}};
$e688689.stack[R.EXN_STACKHEIGHT++] = $ss692693;
}
if(R.isPyretException($e688689)) {
$e688689.pyretStack.push(L[131]);
}
throw $e688689;
}
var $ret694695 = $Hann_DASH_check_DASH_temp1655703($z690691);
++R.GAS;
return $ret694695;
});
};
},{"length":4});
var anf_extend1115173 = R.makeMethod(function($underscore569687) {
return function(l570681,mod571682,constructor572683,values573684) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[125],4,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[127],"A",A222,"ConstructModifier"),R.getDotAnn(L[128],"A",A222,"Expr"),List1943],[l570681,mod571682,constructor572683,values573684],[L[129],L[127],L[128],L[130]],function() {
var anf_fun1114680 = G(well_DASH_formed_DASH_visitor183217,"s-construct",L[126]);
var $z672673 = D;
var $f678679 = function(_) {
return R.isFunction(anf_fun1114680)?anf_fun1114680.app(l570681,mod571682,constructor572683,values573684):R.ffi.throwNonFunApp(L[125],anf_fun1114680,[l570681,mod571682,constructor572683,values573684]);
};
try {
if(--R.GAS > 0) {
$z672673 = $f678679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f678679,
"from":L[125]});
}
} catch($e670671) {
if(R.isCont($e670671)) {
var $ss674675 = {"from":L[125],
"go":function(ann_DASH_check_DASH_temp1113685) {
return $Hann_DASH_check_DASH_temp1656686(ann_DASH_check_DASH_temp1113685);
}};
$e670671.stack[R.EXN_STACKHEIGHT++] = $ss674675;
}
if(R.isPyretException($e670671)) {
$e670671.pyretStack.push(L[125]);
}
throw $e670671;
}
var $ret676677 = $Hann_DASH_check_DASH_temp1656686($z672673);
++R.GAS;
return $ret676677;
});
};
},{"length":5});
var anf_extend1118174 = R.makeMethod(function($underscore574669) {
return function(l575664,_fun576665,args577666) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[120],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[122],"A",A222,"Expr"),List1943],[l575664,_fun576665,args577666],[L[123],L[122],L[124]],function() {
var anf_fun1117663 = G(well_DASH_formed_DASH_visitor183217,"s-app",L[121]);
var $z655656 = D;
var $f661662 = function(_) {
return R.isFunction(anf_fun1117663)?anf_fun1117663.app(l575664,_fun576665,args577666):R.ffi.throwNonFunApp(L[120],anf_fun1117663,[l575664,_fun576665,args577666]);
};
try {
if(--R.GAS > 0) {
$z655656 = $f661662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f661662,
"from":L[120]});
}
} catch($e653654) {
if(R.isCont($e653654)) {
var $ss657658 = {"from":L[120],
"go":function(ann_DASH_check_DASH_temp1116667) {
return $Hann_DASH_check_DASH_temp1657668(ann_DASH_check_DASH_temp1116667);
}};
$e653654.stack[R.EXN_STACKHEIGHT++] = $ss657658;
}
if(R.isPyretException($e653654)) {
$e653654.pyretStack.push(L[120]);
}
throw $e653654;
}
var $ret659660 = $Hann_DASH_check_DASH_temp1657668($z655656);
++R.GAS;
return $ret659660;
});
};
},{"length":4});
var anf_extend1121175 = R.makeMethod(function($underscore578652) {
return function(l579647,_fun580648,args581649) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[115],3,arguments);
}
return R.checkAnnArgs([Loc6844,$type$String12,List1943],[l579647,_fun580648,args581649],[L[117],L[118],L[119]],function() {
var anf_fun1120646 = G(well_DASH_formed_DASH_visitor183217,"s-prim-app",L[116]);
var $z638639 = D;
var $f644645 = function(_) {
return R.isFunction(anf_fun1120646)?anf_fun1120646.app(l579647,_fun580648,args581649):R.ffi.throwNonFunApp(L[115],anf_fun1120646,[l579647,_fun580648,args581649]);
};
try {
if(--R.GAS > 0) {
$z638639 = $f644645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f644645,
"from":L[115]});
}
} catch($e636637) {
if(R.isCont($e636637)) {
var $ss640641 = {"from":L[115],
"go":function(ann_DASH_check_DASH_temp1119650) {
return $Hann_DASH_check_DASH_temp1658651(ann_DASH_check_DASH_temp1119650);
}};
$e636637.stack[R.EXN_STACKHEIGHT++] = $ss640641;
}
if(R.isPyretException($e636637)) {
$e636637.pyretStack.push(L[115]);
}
throw $e636637;
}
var $ret642643 = $Hann_DASH_check_DASH_temp1658651($z638639);
++R.GAS;
return $ret642643;
});
};
},{"length":4});
var anf_extend1124176 = R.makeMethod(function($underscore582635) {
return function(l583630,num584631,den585632) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[112],3,arguments);
}
return R.checkAnnArgs([Loc6844],[l583630],[L[114]],function() {
var anf_fun1123629 = G(well_DASH_formed_DASH_visitor183217,"s-frac",L[113]);
var $z621622 = D;
var $f627628 = function(_) {
return R.isFunction(anf_fun1123629)?anf_fun1123629.app(l583630,num584631,den585632):R.ffi.throwNonFunApp(L[112],anf_fun1123629,[l583630,num584631,den585632]);
};
try {
if(--R.GAS > 0) {
$z621622 = $f627628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f627628,
"from":L[112]});
}
} catch($e619620) {
if(R.isCont($e619620)) {
var $ss623624 = {"from":L[112],
"go":function(ann_DASH_check_DASH_temp1122633) {
return $Hann_DASH_check_DASH_temp1659634(ann_DASH_check_DASH_temp1122633);
}};
$e619620.stack[R.EXN_STACKHEIGHT++] = $ss623624;
}
if(R.isPyretException($e619620)) {
$e619620.pyretStack.push(L[112]);
}
throw $e619620;
}
var $ret625626 = $Hann_DASH_check_DASH_temp1659634($z621622);
++R.GAS;
return $ret625626;
});
};
},{"length":4});
var anf_extend1127177 = R.makeMethod(function($underscore586618) {
return function(l587614,id588615) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[108],2,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[110],"A",A222,"Name")],[l587614,id588615],[L[111],L[110]],function() {
var anf_fun1126613 = G(well_DASH_formed_DASH_visitor183217,"s-id",L[109]);
var $z605606 = D;
var $f611612 = function(_) {
return R.isFunction(anf_fun1126613)?anf_fun1126613.app(l587614,id588615):R.ffi.throwNonFunApp(L[108],anf_fun1126613,[l587614,id588615]);
};
try {
if(--R.GAS > 0) {
$z605606 = $f611612();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f611612,
"from":L[108]});
}
} catch($e603604) {
if(R.isCont($e603604)) {
var $ss607608 = {"from":L[108],
"go":function(ann_DASH_check_DASH_temp1125616) {
return $Hann_DASH_check_DASH_temp1660617(ann_DASH_check_DASH_temp1125616);
}};
$e603604.stack[R.EXN_STACKHEIGHT++] = $ss607608;
}
if(R.isPyretException($e603604)) {
$e603604.pyretStack.push(L[108]);
}
throw $e603604;
}
var $ret609610 = $Hann_DASH_check_DASH_temp1660617($z605606);
++R.GAS;
return $ret609610;
});
};
},{"length":3});
var anf_extend1130178 = R.makeMethod(function($underscore589602) {
return function(l590598,id591599) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[104],2,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[106],"A",A222,"Name")],[l590598,id591599],[L[107],L[106]],function() {
var anf_fun1129597 = G(well_DASH_formed_DASH_visitor183217,"s-id-var",L[105]);
var $z589590 = D;
var $f595596 = function(_) {
return R.isFunction(anf_fun1129597)?anf_fun1129597.app(l590598,id591599):R.ffi.throwNonFunApp(L[104],anf_fun1129597,[l590598,id591599]);
};
try {
if(--R.GAS > 0) {
$z589590 = $f595596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f595596,
"from":L[104]});
}
} catch($e587588) {
if(R.isCont($e587588)) {
var $ss591592 = {"from":L[104],
"go":function(ann_DASH_check_DASH_temp1128600) {
return $Hann_DASH_check_DASH_temp1661601(ann_DASH_check_DASH_temp1128600);
}};
$e587588.stack[R.EXN_STACKHEIGHT++] = $ss591592;
}
if(R.isPyretException($e587588)) {
$e587588.pyretStack.push(L[104]);
}
throw $e587588;
}
var $ret593594 = $Hann_DASH_check_DASH_temp1661601($z589590);
++R.GAS;
return $ret593594;
});
};
},{"length":3});
var anf_extend1133179 = R.makeMethod(function($underscore592586) {
return function(l593581,id594582,safe595583) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[99],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[101],"A",A222,"Name"),$type$Boolean11],[l593581,id594582,safe595583],[L[102],L[101],L[103]],function() {
var anf_fun1132580 = G(well_DASH_formed_DASH_visitor183217,"s-id-letrec",L[100]);
var $z572573 = D;
var $f578579 = function(_) {
return R.isFunction(anf_fun1132580)?anf_fun1132580.app(l593581,id594582,safe595583):R.ffi.throwNonFunApp(L[99],anf_fun1132580,[l593581,id594582,safe595583]);
};
try {
if(--R.GAS > 0) {
$z572573 = $f578579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f578579,
"from":L[99]});
}
} catch($e570571) {
if(R.isCont($e570571)) {
var $ss574575 = {"from":L[99],
"go":function(ann_DASH_check_DASH_temp1131584) {
return $Hann_DASH_check_DASH_temp1662585(ann_DASH_check_DASH_temp1131584);
}};
$e570571.stack[R.EXN_STACKHEIGHT++] = $ss574575;
}
if(R.isPyretException($e570571)) {
$e570571.pyretStack.push(L[99]);
}
throw $e570571;
}
var $ret576577 = $Hann_DASH_check_DASH_temp1662585($z572573);
++R.GAS;
return $ret576577;
});
};
},{"length":4});
var anf_extend1136180 = R.makeMethod(function($underscore596569) {
return function(l597564,obj598565,field599566) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[94],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[96],"A",A222,"Expr"),$type$String12],[l597564,obj598565,field599566],[L[97],L[96],L[98]],function() {
var anf_fun1135563 = G(well_DASH_formed_DASH_visitor183217,"s-dot",L[95]);
var $z555556 = D;
var $f561562 = function(_) {
return R.isFunction(anf_fun1135563)?anf_fun1135563.app(l597564,obj598565,field599566):R.ffi.throwNonFunApp(L[94],anf_fun1135563,[l597564,obj598565,field599566]);
};
try {
if(--R.GAS > 0) {
$z555556 = $f561562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f561562,
"from":L[94]});
}
} catch($e553554) {
if(R.isCont($e553554)) {
var $ss557558 = {"from":L[94],
"go":function(ann_DASH_check_DASH_temp1134567) {
return $Hann_DASH_check_DASH_temp1663568(ann_DASH_check_DASH_temp1134567);
}};
$e553554.stack[R.EXN_STACKHEIGHT++] = $ss557558;
}
if(R.isPyretException($e553554)) {
$e553554.pyretStack.push(L[94]);
}
throw $e553554;
}
var $ret559560 = $Hann_DASH_check_DASH_temp1663568($z555556);
++R.GAS;
return $ret559560;
});
};
},{"length":4});
var anf_extend1139181 = R.makeMethod(function($underscore600552) {
return function(l601547,obj602548,field603549) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[89],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[91],"A",A222,"Expr"),$type$String12],[l601547,obj602548,field603549],[L[92],L[91],L[93]],function() {
var anf_fun1138546 = G(well_DASH_formed_DASH_visitor183217,"s-get-bang",L[90]);
var $z538539 = D;
var $f544545 = function(_) {
return R.isFunction(anf_fun1138546)?anf_fun1138546.app(l601547,obj602548,field603549):R.ffi.throwNonFunApp(L[89],anf_fun1138546,[l601547,obj602548,field603549]);
};
try {
if(--R.GAS > 0) {
$z538539 = $f544545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f544545,
"from":L[89]});
}
} catch($e536537) {
if(R.isCont($e536537)) {
var $ss540541 = {"from":L[89],
"go":function(ann_DASH_check_DASH_temp1137550) {
return $Hann_DASH_check_DASH_temp1664551(ann_DASH_check_DASH_temp1137550);
}};
$e536537.stack[R.EXN_STACKHEIGHT++] = $ss540541;
}
if(R.isPyretException($e536537)) {
$e536537.pyretStack.push(L[89]);
}
throw $e536537;
}
var $ret542543 = $Hann_DASH_check_DASH_temp1664551($z538539);
++R.GAS;
return $ret542543;
});
};
},{"length":4});
var anf_extend1142182 = R.makeMethod(function($underscore604535) {
return function(l605530,obj606531,field607532) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[84],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[86],"A",A222,"Expr"),R.getDotAnn(L[87],"A",A222,"Expr")],[l605530,obj606531,field607532],[L[88],L[86],L[87]],function() {
var anf_fun1141529 = G(well_DASH_formed_DASH_visitor183217,"s-bracket",L[85]);
var $z521522 = D;
var $f527528 = function(_) {
return R.isFunction(anf_fun1141529)?anf_fun1141529.app(l605530,obj606531,field607532):R.ffi.throwNonFunApp(L[84],anf_fun1141529,[l605530,obj606531,field607532]);
};
try {
if(--R.GAS > 0) {
$z521522 = $f527528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f527528,
"from":L[84]});
}
} catch($e519520) {
if(R.isCont($e519520)) {
var $ss523524 = {"from":L[84],
"go":function(ann_DASH_check_DASH_temp1140533) {
return $Hann_DASH_check_DASH_temp1665534(ann_DASH_check_DASH_temp1140533);
}};
$e519520.stack[R.EXN_STACKHEIGHT++] = $ss523524;
}
if(R.isPyretException($e519520)) {
$e519520.pyretStack.push(L[84]);
}
throw $e519520;
}
var $ret525526 = $Hann_DASH_check_DASH_temp1665534($z521522);
++R.GAS;
return $ret525526;
});
};
},{"length":4});
var anf_extend1145183 = R.makeMethod(function($underscore608518) {
return function(l609511,iterator610512,bindings611513,ann612514,body613515) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[77],5,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[79],"A",A222,"Expr"),List1943,R.getDotAnn(L[80],"A",A222,"Ann"),R.getDotAnn(L[81],"A",A222,"Expr")],[l609511,iterator610512,bindings611513,ann612514,body613515],[L[82],L[79],L[83],L[80],L[81]],function() {
var anf_fun1144510 = G(well_DASH_formed_DASH_visitor183217,"s-for",L[78]);
var $z502503 = D;
var $f508509 = function(_) {
return R.isFunction(anf_fun1144510)?anf_fun1144510.app(l609511,iterator610512,bindings611513,ann612514,body613515):R.ffi.throwNonFunApp(L[77],anf_fun1144510,[l609511,iterator610512,bindings611513,ann612514,body613515]);
};
try {
if(--R.GAS > 0) {
$z502503 = $f508509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f508509,
"from":L[77]});
}
} catch($e500501) {
if(R.isCont($e500501)) {
var $ss504505 = {"from":L[77],
"go":function(ann_DASH_check_DASH_temp1143516) {
return $Hann_DASH_check_DASH_temp1666517(ann_DASH_check_DASH_temp1143516);
}};
$e500501.stack[R.EXN_STACKHEIGHT++] = $ss504505;
}
if(R.isPyretException($e500501)) {
$e500501.pyretStack.push(L[77]);
}
throw $e500501;
}
var $ret506507 = $Hann_DASH_check_DASH_temp1666517($z502503);
++R.GAS;
return $ret506507;
});
};
},{"length":6});
var anf_extend1148184 = R.makeMethod(function($underscore614499) {
return function(l615493,name616494,body617495,keyword_DASH_check618496) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[71],4,arguments);
}
return R.checkAnnArgs([Loc6844,Option2045,R.getDotAnn(L[73],"A",A222,"Expr"),$type$Boolean11],[l615493,name616494,body617495,keyword_DASH_check618496],[L[74],L[75],L[73],L[76]],function() {
var anf_fun1147492 = G(well_DASH_formed_DASH_visitor183217,"s-check",L[72]);
var $z484485 = D;
var $f490491 = function(_) {
return R.isFunction(anf_fun1147492)?anf_fun1147492.app(l615493,name616494,body617495,keyword_DASH_check618496):R.ffi.throwNonFunApp(L[71],anf_fun1147492,[l615493,name616494,body617495,keyword_DASH_check618496]);
};
try {
if(--R.GAS > 0) {
$z484485 = $f490491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f490491,
"from":L[71]});
}
} catch($e482483) {
if(R.isCont($e482483)) {
var $ss486487 = {"from":L[71],
"go":function(ann_DASH_check_DASH_temp1146497) {
return $Hann_DASH_check_DASH_temp1667498(ann_DASH_check_DASH_temp1146497);
}};
$e482483.stack[R.EXN_STACKHEIGHT++] = $ss486487;
}
if(R.isPyretException($e482483)) {
$e482483.pyretStack.push(L[71]);
}
throw $e482483;
}
var $ret488489 = $Hann_DASH_check_DASH_temp1667498($z484485);
++R.GAS;
return $ret488489;
});
};
},{"length":5});
var anf_extend1151185 = R.makeMethod(function($underscore619481) {
return function(l620476,name621477,value622478) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[66],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[68],"A",A222,"Expr"),R.getDotAnn(L[69],"A",A222,"Expr")],[l620476,name621477,value622478],[L[70],L[68],L[69]],function() {
var anf_fun1150475 = G(well_DASH_formed_DASH_visitor183217,"s-data-field",L[67]);
var $z467468 = D;
var $f473474 = function(_) {
return R.isFunction(anf_fun1150475)?anf_fun1150475.app(l620476,name621477,value622478):R.ffi.throwNonFunApp(L[66],anf_fun1150475,[l620476,name621477,value622478]);
};
try {
if(--R.GAS > 0) {
$z467468 = $f473474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f473474,
"from":L[66]});
}
} catch($e465466) {
if(R.isCont($e465466)) {
var $ss469470 = {"from":L[66],
"go":function(ann_DASH_check_DASH_temp1149479) {
return $Hann_DASH_check_DASH_temp1668480(ann_DASH_check_DASH_temp1149479);
}};
$e465466.stack[R.EXN_STACKHEIGHT++] = $ss469470;
}
if(R.isPyretException($e465466)) {
$e465466.pyretStack.push(L[66]);
}
throw $e465466;
}
var $ret471472 = $Hann_DASH_check_DASH_temp1668480($z467468);
++R.GAS;
return $ret471472;
});
};
},{"length":4});
var anf_extend1154186 = R.makeMethod(function($underscore623464) {
return function(l624458,name625459,ann626460,value627461) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[60],4,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[62],"A",A222,"Expr"),R.getDotAnn(L[63],"A",A222,"Ann"),R.getDotAnn(L[64],"A",A222,"Expr")],[l624458,name625459,ann626460,value627461],[L[65],L[62],L[63],L[64]],function() {
var anf_fun1153457 = G(well_DASH_formed_DASH_visitor183217,"s-mutable-field",L[61]);
var $z449450 = D;
var $f455456 = function(_) {
return R.isFunction(anf_fun1153457)?anf_fun1153457.app(l624458,name625459,ann626460,value627461):R.ffi.throwNonFunApp(L[60],anf_fun1153457,[l624458,name625459,ann626460,value627461]);
};
try {
if(--R.GAS > 0) {
$z449450 = $f455456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f455456,
"from":L[60]});
}
} catch($e447448) {
if(R.isCont($e447448)) {
var $ss451452 = {"from":L[60],
"go":function(ann_DASH_check_DASH_temp1152462) {
return $Hann_DASH_check_DASH_temp1669463(ann_DASH_check_DASH_temp1152462);
}};
$e447448.stack[R.EXN_STACKHEIGHT++] = $ss451452;
}
if(R.isPyretException($e447448)) {
$e447448.pyretStack.push(L[60]);
}
throw $e447448;
}
var $ret453454 = $Hann_DASH_check_DASH_temp1669463($z449450);
++R.GAS;
return $ret453454;
});
};
},{"length":5});
var anf_extend1157187 = R.makeMethod(function($underscore628446) {
return function(l629440,name630441,ann631442,value632443) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[54],4,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[56],"A",A222,"Expr"),R.getDotAnn(L[57],"A",A222,"Ann"),R.getDotAnn(L[58],"A",A222,"Expr")],[l629440,name630441,ann631442,value632443],[L[59],L[56],L[57],L[58]],function() {
var anf_fun1156439 = G(well_DASH_formed_DASH_visitor183217,"s-once-field",L[55]);
var $z431432 = D;
var $f437438 = function(_) {
return R.isFunction(anf_fun1156439)?anf_fun1156439.app(l629440,name630441,ann631442,value632443):R.ffi.throwNonFunApp(L[54],anf_fun1156439,[l629440,name630441,ann631442,value632443]);
};
try {
if(--R.GAS > 0) {
$z431432 = $f437438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f437438,
"from":L[54]});
}
} catch($e429430) {
if(R.isCont($e429430)) {
var $ss433434 = {"from":L[54],
"go":function(ann_DASH_check_DASH_temp1155444) {
return $Hann_DASH_check_DASH_temp1670445(ann_DASH_check_DASH_temp1155444);
}};
$e429430.stack[R.EXN_STACKHEIGHT++] = $ss433434;
}
if(R.isPyretException($e429430)) {
$e429430.pyretStack.push(L[54]);
}
throw $e429430;
}
var $ret435436 = $Hann_DASH_check_DASH_temp1670445($z431432);
++R.GAS;
return $ret435436;
});
};
},{"length":5});
var anf_extend1160188 = R.makeMethod(function($underscore633428) {
return function(l634419,name635420,args636421,ann637422,doc638423,body639424,_check640425) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[45],7,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[47],"A",A222,"Expr"),List1943,R.getDotAnn(L[48],"A",A222,"Ann"),$type$String12,R.getDotAnn(L[49],"A",A222,"Expr"),Option2045],[l634419,name635420,args636421,ann637422,doc638423,body639424,_check640425],[L[50],L[47],L[51],L[48],L[52],L[49],L[53]],function() {
var anf_fun1159418 = G(well_DASH_formed_DASH_visitor183217,"s-method-field",L[46]);
var $z410411 = D;
var $f416417 = function(_) {
return R.isFunction(anf_fun1159418)?anf_fun1159418.app(l634419,name635420,args636421,ann637422,doc638423,body639424,_check640425):R.ffi.throwNonFunApp(L[45],anf_fun1159418,[l634419,name635420,args636421,ann637422,doc638423,body639424,_check640425]);
};
try {
if(--R.GAS > 0) {
$z410411 = $f416417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f416417,
"from":L[45]});
}
} catch($e408409) {
if(R.isCont($e408409)) {
var $ss412413 = {"from":L[45],
"go":function(ann_DASH_check_DASH_temp1158426) {
return $Hann_DASH_check_DASH_temp1671427(ann_DASH_check_DASH_temp1158426);
}};
$e408409.stack[R.EXN_STACKHEIGHT++] = $ss412413;
}
if(R.isPyretException($e408409)) {
$e408409.pyretStack.push(L[45]);
}
throw $e408409;
}
var $ret414415 = $Hann_DASH_check_DASH_temp1671427($z410411);
++R.GAS;
return $ret414415;
});
};
},{"length":8});
var anf_extend1163189 = R.makeMethod(function($underscore641407) {
return function(l642402,bind643403,value644404) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[40],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[42],"A",A222,"Bind"),R.getDotAnn(L[43],"A",A222,"Expr")],[l642402,bind643403,value644404],[L[44],L[42],L[43]],function() {
var anf_fun1162401 = G(well_DASH_formed_DASH_visitor183217,"s-for-bind",L[41]);
var $z393394 = D;
var $f399400 = function(_) {
return R.isFunction(anf_fun1162401)?anf_fun1162401.app(l642402,bind643403,value644404):R.ffi.throwNonFunApp(L[40],anf_fun1162401,[l642402,bind643403,value644404]);
};
try {
if(--R.GAS > 0) {
$z393394 = $f399400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f399400,
"from":L[40]});
}
} catch($e391392) {
if(R.isCont($e391392)) {
var $ss395396 = {"from":L[40],
"go":function(ann_DASH_check_DASH_temp1161405) {
return $Hann_DASH_check_DASH_temp1672406(ann_DASH_check_DASH_temp1161405);
}};
$e391392.stack[R.EXN_STACKHEIGHT++] = $ss395396;
}
if(R.isPyretException($e391392)) {
$e391392.pyretStack.push(L[40]);
}
throw $e391392;
}
var $ret397398 = $Hann_DASH_check_DASH_temp1672406($z393394);
++R.GAS;
return $ret397398;
});
};
},{"length":4});
var anf_extend1166190 = R.makeMethod(function($underscore645390) {
return function(l646385,member_DASH_type647386,bind648387) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[35],3,arguments);
}
return R.checkAnnArgs([Loc6844,R.getDotAnn(L[37],"A",A222,"VariantMemberType"),R.getDotAnn(L[38],"A",A222,"Bind")],[l646385,member_DASH_type647386,bind648387],[L[39],L[37],L[38]],function() {
var anf_fun1165384 = G(well_DASH_formed_DASH_visitor183217,"s-variant-member",L[36]);
var $z376377 = D;
var $f382383 = function(_) {
return R.isFunction(anf_fun1165384)?anf_fun1165384.app(l646385,member_DASH_type647386,bind648387):R.ffi.throwNonFunApp(L[35],anf_fun1165384,[l646385,member_DASH_type647386,bind648387]);
};
try {
if(--R.GAS > 0) {
$z376377 = $f382383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f382383,
"from":L[35]});
}
} catch($e374375) {
if(R.isCont($e374375)) {
var $ss378379 = {"from":L[35],
"go":function(ann_DASH_check_DASH_temp1164388) {
return $Hann_DASH_check_DASH_temp1673389(ann_DASH_check_DASH_temp1164388);
}};
$e374375.stack[R.EXN_STACKHEIGHT++] = $ss378379;
}
if(R.isPyretException($e374375)) {
$e374375.pyretStack.push(L[35]);
}
throw $e374375;
}
var $ret380381 = $Hann_DASH_check_DASH_temp1673389($z376377);
++R.GAS;
return $ret380381;
});
};
},{"length":4});
var anf_extend1169191 = R.makeMethod(function($underscore649373) {
return function(l650366,constr_DASH_loc651367,name652368,members653369,with_DASH_members654370) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[28],5,arguments);
}
return R.checkAnnArgs([Loc6844,Loc6844,$type$String12,List1943,List1943],[l650366,constr_DASH_loc651367,name652368,members653369,with_DASH_members654370],[L[30],L[31],L[32],L[33],L[34]],function() {
var anf_fun1168365 = G(well_DASH_formed_DASH_visitor183217,"s-variant",L[29]);
var $z357358 = D;
var $f363364 = function(_) {
return R.isFunction(anf_fun1168365)?anf_fun1168365.app(l650366,constr_DASH_loc651367,name652368,members653369,with_DASH_members654370):R.ffi.throwNonFunApp(L[28],anf_fun1168365,[l650366,constr_DASH_loc651367,name652368,members653369,with_DASH_members654370]);
};
try {
if(--R.GAS > 0) {
$z357358 = $f363364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f363364,
"from":L[28]});
}
} catch($e355356) {
if(R.isCont($e355356)) {
var $ss359360 = {"from":L[28],
"go":function(ann_DASH_check_DASH_temp1167371) {
return $Hann_DASH_check_DASH_temp1674372(ann_DASH_check_DASH_temp1167371);
}};
$e355356.stack[R.EXN_STACKHEIGHT++] = $ss359360;
}
if(R.isPyretException($e355356)) {
$e355356.pyretStack.push(L[28]);
}
throw $e355356;
}
var $ret361362 = $Hann_DASH_check_DASH_temp1674372($z357358);
++R.GAS;
return $ret361362;
});
};
},{"length":6});
var anf_extend1172192 = R.makeMethod(function($underscore655354) {
return function(l656349,name657350,constructor658351) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[23],3,arguments);
}
return R.checkAnnArgs([Loc6844,$type$String12,R.getDotAnn(L[25],"A",A222,"Constructor")],[l656349,name657350,constructor658351],[L[26],L[27],L[25]],function() {
var anf_fun1171348 = G(well_DASH_formed_DASH_visitor183217,"s-datatype-singleton-variant",L[24]);
var $z340341 = D;
var $f346347 = function(_) {
return R.isFunction(anf_fun1171348)?anf_fun1171348.app(l656349,name657350,constructor658351):R.ffi.throwNonFunApp(L[23],anf_fun1171348,[l656349,name657350,constructor658351]);
};
try {
if(--R.GAS > 0) {
$z340341 = $f346347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f346347,
"from":L[23]});
}
} catch($e338339) {
if(R.isCont($e338339)) {
var $ss342343 = {"from":L[23],
"go":function(ann_DASH_check_DASH_temp1170352) {
return $Hann_DASH_check_DASH_temp1675353(ann_DASH_check_DASH_temp1170352);
}};
$e338339.stack[R.EXN_STACKHEIGHT++] = $ss342343;
}
if(R.isPyretException($e338339)) {
$e338339.pyretStack.push(L[23]);
}
throw $e338339;
}
var $ret344345 = $Hann_DASH_check_DASH_temp1675353($z340341);
++R.GAS;
return $ret344345;
});
};
},{"length":4});
var anf_extend1175193 = R.makeMethod(function($underscore659337) {
return function(l660332,well_DASH_formed_DASH_visitor_DASH_arg661333,body662334) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[18],3,arguments);
}
return R.checkAnnArgs([Loc6844,$type$String12,R.getDotAnn(L[20],"A",A222,"Expr")],[l660332,well_DASH_formed_DASH_visitor_DASH_arg661333,body662334],[L[21],L[22],L[20]],function() {
var anf_fun1174331 = G(well_DASH_formed_DASH_visitor183217,"s-datatype-constructor",L[19]);
var $z323324 = D;
var $f329330 = function(_) {
return R.isFunction(anf_fun1174331)?anf_fun1174331.app(l660332,well_DASH_formed_DASH_visitor_DASH_arg661333,body662334):R.ffi.throwNonFunApp(L[18],anf_fun1174331,[l660332,well_DASH_formed_DASH_visitor_DASH_arg661333,body662334]);
};
try {
if(--R.GAS > 0) {
$z323324 = $f329330();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f329330,
"from":L[18]});
}
} catch($e321322) {
if(R.isCont($e321322)) {
var $ss325326 = {"from":L[18],
"go":function(ann_DASH_check_DASH_temp1173335) {
return $Hann_DASH_check_DASH_temp1676336(ann_DASH_check_DASH_temp1173335);
}};
$e321322.stack[R.EXN_STACKHEIGHT++] = $ss325326;
}
if(R.isPyretException($e321322)) {
$e321322.pyretStack.push(L[18]);
}
throw $e321322;
}
var $ret327328 = $Hann_DASH_check_DASH_temp1676336($z323324);
++R.GAS;
return $ret327328;
});
};
},{"length":4});
var anf_extend1178194 = R.makeMethod(function($underscore663320) {
return function(l664314,args665315,ret666316,use_DASH_parens667317) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[16],4,arguments);
}
var anf_fun1177313 = G(well_DASH_formed_DASH_visitor183217,"a-arrow",L[17]);
var $z305306 = D;
var $f311312 = function(_) {
return R.isFunction(anf_fun1177313)?anf_fun1177313.app(l664314,args665315,ret666316,use_DASH_parens667317):R.ffi.throwNonFunApp(L[16],anf_fun1177313,[l664314,args665315,ret666316,use_DASH_parens667317]);
};
try {
if(--R.GAS > 0) {
$z305306 = $f311312();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f311312,
"from":L[16]});
}
} catch($e303304) {
if(R.isCont($e303304)) {
var $ss307308 = {"from":L[16],
"go":function(ann_DASH_check_DASH_temp1176318) {
return $Hann_DASH_check_DASH_temp1677319(ann_DASH_check_DASH_temp1176318);
}};
$e303304.stack[R.EXN_STACKHEIGHT++] = $ss307308;
}
if(R.isPyretException($e303304)) {
$e303304.pyretStack.push(L[16]);
}
throw $e303304;
}
var $ret309310 = $Hann_DASH_check_DASH_temp1677319($z305306);
++R.GAS;
return $ret309310;
};
},{"length":5});
var anf_extend1181195 = R.makeMethod(function($underscore668302) {
return function(l669297,args670298,ret671299) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[14],3,arguments);
}
var anf_fun1180296 = G(well_DASH_formed_DASH_visitor183217,"a-method",L[15]);
var $z288289 = D;
var $f294295 = function(_) {
return R.isFunction(anf_fun1180296)?anf_fun1180296.app(l669297,args670298,ret671299):R.ffi.throwNonFunApp(L[14],anf_fun1180296,[l669297,args670298,ret671299]);
};
try {
if(--R.GAS > 0) {
$z288289 = $f294295();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f294295,
"from":L[14]});
}
} catch($e286287) {
if(R.isCont($e286287)) {
var $ss290291 = {"from":L[14],
"go":function(ann_DASH_check_DASH_temp1179300) {
return $Hann_DASH_check_DASH_temp1678301(ann_DASH_check_DASH_temp1179300);
}};
$e286287.stack[R.EXN_STACKHEIGHT++] = $ss290291;
}
if(R.isPyretException($e286287)) {
$e286287.pyretStack.push(L[14]);
}
throw $e286287;
}
var $ret292293 = $Hann_DASH_check_DASH_temp1678301($z288289);
++R.GAS;
return $ret292293;
};
},{"length":4});
var anf_extend1184196 = R.makeMethod(function($underscore672285) {
return function(l673281,fields674282) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[12],2,arguments);
}
var anf_fun1183280 = G(well_DASH_formed_DASH_visitor183217,"a-record",L[13]);
var $z272273 = D;
var $f278279 = function(_) {
return R.isFunction(anf_fun1183280)?anf_fun1183280.app(l673281,fields674282):R.ffi.throwNonFunApp(L[12],anf_fun1183280,[l673281,fields674282]);
};
try {
if(--R.GAS > 0) {
$z272273 = $f278279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f278279,
"from":L[12]});
}
} catch($e270271) {
if(R.isCont($e270271)) {
var $ss274275 = {"from":L[12],
"go":function(ann_DASH_check_DASH_temp1182283) {
return $Hann_DASH_check_DASH_temp1679284(ann_DASH_check_DASH_temp1182283);
}};
$e270271.stack[R.EXN_STACKHEIGHT++] = $ss274275;
}
if(R.isPyretException($e270271)) {
$e270271.pyretStack.push(L[12]);
}
throw $e270271;
}
var $ret276277 = $Hann_DASH_check_DASH_temp1679284($z272273);
++R.GAS;
return $ret276277;
};
},{"length":3});
var anf_extend1187197 = R.makeMethod(function($underscore675269) {
return function(l676264,ann677265,args678266) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[10],3,arguments);
}
var anf_fun1186263 = G(well_DASH_formed_DASH_visitor183217,"a-app",L[11]);
var $z255256 = D;
var $f261262 = function(_) {
return R.isFunction(anf_fun1186263)?anf_fun1186263.app(l676264,ann677265,args678266):R.ffi.throwNonFunApp(L[10],anf_fun1186263,[l676264,ann677265,args678266]);
};
try {
if(--R.GAS > 0) {
$z255256 = $f261262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f261262,
"from":L[10]});
}
} catch($e253254) {
if(R.isCont($e253254)) {
var $ss257258 = {"from":L[10],
"go":function(ann_DASH_check_DASH_temp1185267) {
return $Hann_DASH_check_DASH_temp1680268(ann_DASH_check_DASH_temp1185267);
}};
$e253254.stack[R.EXN_STACKHEIGHT++] = $ss257258;
}
if(R.isPyretException($e253254)) {
$e253254.pyretStack.push(L[10]);
}
throw $e253254;
}
var $ret259260 = $Hann_DASH_check_DASH_temp1680268($z255256);
++R.GAS;
return $ret259260;
};
},{"length":4});
var anf_extend1190198 = R.makeMethod(function($underscore679252) {
return function(l680247,ann681248,exp682249) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[8],3,arguments);
}
var anf_fun1189246 = G(well_DASH_formed_DASH_visitor183217,"a-pred",L[9]);
var $z238239 = D;
var $f244245 = function(_) {
return R.isFunction(anf_fun1189246)?anf_fun1189246.app(l680247,ann681248,exp682249):R.ffi.throwNonFunApp(L[8],anf_fun1189246,[l680247,ann681248,exp682249]);
};
try {
if(--R.GAS > 0) {
$z238239 = $f244245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f244245,
"from":L[8]});
}
} catch($e236237) {
if(R.isCont($e236237)) {
var $ss240241 = {"from":L[8],
"go":function(ann_DASH_check_DASH_temp1188250) {
return $Hann_DASH_check_DASH_temp1681251(ann_DASH_check_DASH_temp1188250);
}};
$e236237.stack[R.EXN_STACKHEIGHT++] = $ss240241;
}
if(R.isPyretException($e236237)) {
$e236237.pyretStack.push(L[8]);
}
throw $e236237;
}
var $ret242243 = $Hann_DASH_check_DASH_temp1681251($z238239);
++R.GAS;
return $ret242243;
};
},{"length":4});
var anf_extend1193199 = R.makeMethod(function($underscore683235) {
return function(l684230,obj685231,field686232) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[6],3,arguments);
}
var anf_fun1192229 = G(well_DASH_formed_DASH_visitor183217,"a-dot",L[7]);
var $z221222 = D;
var $f227228 = function(_) {
return R.isFunction(anf_fun1192229)?anf_fun1192229.app(l684230,obj685231,field686232):R.ffi.throwNonFunApp(L[6],anf_fun1192229,[l684230,obj685231,field686232]);
};
try {
if(--R.GAS > 0) {
$z221222 = $f227228();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f227228,
"from":L[6]});
}
} catch($e219220) {
if(R.isCont($e219220)) {
var $ss223224 = {"from":L[6],
"go":function(ann_DASH_check_DASH_temp1191233) {
return $Hann_DASH_check_DASH_temp1682234(ann_DASH_check_DASH_temp1191233);
}};
$e219220.stack[R.EXN_STACKHEIGHT++] = $ss223224;
}
if(R.isPyretException($e219220)) {
$e219220.pyretStack.push(L[6]);
}
throw $e219220;
}
var $ret225226 = $Hann_DASH_check_DASH_temp1682234($z221222);
++R.GAS;
return $ret225226;
};
},{"length":4});
var anf_extend1196200 = R.makeMethod(function($underscore687218) {
return function(l688212,name689213,ann690214) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[4],3,arguments);
}
var anf_fun1195211 = G(well_DASH_formed_DASH_visitor183217,"a-field",L[5]);
var $z203204 = D;
var $f209210 = function(_) {
return R.isFunction(anf_fun1195211)?anf_fun1195211.app(l688212,name689213,ann690214):R.ffi.throwNonFunApp(L[4],anf_fun1195211,[l688212,name689213,ann690214]);
};
try {
if(--R.GAS > 0) {
$z203204 = $f209210();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f209210,
"from":L[4]});
}
} catch($e201202) {
if(R.isCont($e201202)) {
var $ss205206 = {"from":L[4],
"go":function(ann_DASH_check_DASH_temp1194215) {
return $Hann_DASH_check_DASH_temp1683216(ann_DASH_check_DASH_temp1194215);
}};
$e201202.stack[R.EXN_STACKHEIGHT++] = $ss205206;
}
if(R.isPyretException($e201202)) {
$e201202.pyretStack.push(L[4]);
}
throw $e201202;
}
var $ret207208 = $Hann_DASH_check_DASH_temp1683216($z203204);
++R.GAS;
return $ret207208;
};
},{"length":4});
var top_DASH_level_DASH_visitor319115 = anf_extend772118.extendWith({"s-program":anf_extend809119,
"s-type":anf_extend812120,
"s-newtype":anf_extend814121,
"s-type-let-expr":anf_extend831122,
"s-type-bind":anf_extend834123,
"s-newtype-bind":anf_extend836124,
"s-variant":anf_extend863125,
"s-singleton-variant":anf_extend871126,
"s-data":anf_extend918127,
"s-datatype-variant":anf_extend936128,
"s-data-expr":anf_extend983129,
"s-import":anf_extend986130,
"s-import-types":anf_extend989131,
"s-import-fields":anf_extend992132,
"s-provide":anf_extend995133,
"s-provide-types":anf_extend998134,
"s-bind":anf_extend1001135,
"s-var-bind":anf_extend1004136,
"s-let-bind":anf_extend1007137,
"s-let-expr":anf_extend1010138,
"s-letrec-bind":anf_extend1013139,
"s-letrec":anf_extend1016140,
"s-hint-exp":anf_extend1019141,
"s-instantiate":anf_extend1022142,
"s-block":anf_extend1025143,
"s-user-block":anf_extend1028144,
"s-fun":anf_extend1031145,
"s-var":anf_extend1034146,
"s-let":anf_extend1037147,
"s-graph":anf_extend1040148,
"s-when":anf_extend1043149,
"s-contract":anf_extend1046150,
"s-assign":anf_extend1049151,
"s-if-branch":anf_extend1052152,
"s-if-pipe-branch":anf_extend1055153,
"s-if":anf_extend1058154,
"s-if-else":anf_extend1061155,
"s-if-pipe":anf_extend1064156,
"s-if-pipe-else":anf_extend1067157,
"s-cases-branch":anf_extend1070158,
"s-cases":anf_extend1073159,
"s-cases-else":anf_extend1076160,
"s-try":anf_extend1079161,
"s-op":anf_extend1082162,
"s-check-test":anf_extend1085163,
"s-paren":anf_extend1088164,
"s-lam":anf_extend1091165,
"s-method":anf_extend1094166,
"s-extend":anf_extend1097167,
"s-update":anf_extend1100168,
"s-obj":anf_extend1103169,
"s-array":anf_extend1106170,
"s-bless":anf_extend1109171,
"s-confirm":anf_extend1112172,
"s-construct":anf_extend1115173,
"s-app":anf_extend1118174,
"s-prim-app":anf_extend1121175,
"s-frac":anf_extend1124176,
"s-id":anf_extend1127177,
"s-id-var":anf_extend1130178,
"s-id-letrec":anf_extend1133179,
"s-dot":anf_extend1136180,
"s-get-bang":anf_extend1139181,
"s-bracket":anf_extend1142182,
"s-for":anf_extend1145183,
"s-check":anf_extend1148184,
"s-data-field":anf_extend1151185,
"s-mutable-field":anf_extend1154186,
"s-once-field":anf_extend1157187,
"s-method-field":anf_extend1160188,
"s-for-bind":anf_extend1163189,
"s-variant-member":anf_extend1166190,
"s-variant":anf_extend1169191,
"s-datatype-singleton-variant":anf_extend1172192,
"s-datatype-constructor":anf_extend1175193,
"a-arrow":anf_extend1178194,
"a-method":anf_extend1181195,
"a-record":anf_extend1184196,
"a-app":anf_extend1187197,
"a-pred":anf_extend1190198,
"a-dot":anf_extend1193199,
"a-field":anf_extend1196200});
var check_DASH_well_DASH_formed69187 = {"$var":D,
"$name":"check-well-formed"};
var anf_assign122288 = R.makeFunction(function(ast692103) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1],1,arguments);
}
cur_DASH_shared7147.$var = empty3048;
errors6949.$var = empty3048;
in_DASH_check_DASH_block7050.$var = (false);
var anf_fun1198114 = G(ast692103,"visit",L[3]);
var $z106107 = D;
var $f112113 = function(_) {
return R.isFunction(anf_fun1198114)?anf_fun1198114.app(top_DASH_level_DASH_visitor319115):R.ffi.throwNonFunApp(L[2],anf_fun1198114,[top_DASH_level_DASH_visitor319115]);
};
try {
if(--R.GAS > 0) {
$z106107 = $f112113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f112113,
"from":L[2]});
}
} catch($e104105) {
if(R.isCont($e104105)) {
var $ss108109 = {"from":L[2],
"go":function(and_DASH_oper_DASH_140116) {
return $Hand_DASH_oper_DASH_1689117(and_DASH_oper_DASH_140116,A222,C515,C624,ast692103,cur_DASH_shared7147,empty3048,errors6949,in_DASH_check_DASH_block7050);
}};
$e104105.stack[R.EXN_STACKHEIGHT++] = $ss108109;
}
if(R.isPyretException($e104105)) {
$e104105.pyretStack.push(L[2]);
}
throw $e104105;
}
var $ret110111 = $Hand_DASH_oper_DASH_1689117($z106107,A222,C515,C624,ast692103,cur_DASH_shared7147,empty3048,errors6949,in_DASH_check_DASH_block7050);
++R.GAS;
return $ret110111;
});
check_DASH_well_DASH_formed69187.$var = anf_assign122288;
var provides1223101 = R.makeObject({"check-well-formed":check_DASH_well_DASH_formed69187.$var});
var anf_fun122499 = G(builtins2,"current-checker",L[0]);
var $z9192 = D;
var $f9798 = function(_) {
return R.isFunction(anf_fun122499)?anf_fun122499.app():R.ffi.throwNonFunApp(L[0],anf_fun122499,[]);
};
try {
if(--R.GAS > 0) {
$z9192 = $f9798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9798,
"from":L[0]});
}
} catch($e8990) {
if(R.isCont($e8990)) {
var $ss9394 = {"from":L[0],
"go":function(anf_bracket1225100) {
return $Hanf_bracket1691102(anf_bracket1225100,Loc6844,provides1223101,nothing4);
}};
$e8990.stack[R.EXN_STACKHEIGHT++] = $ss9394;
}
if(R.isPyretException($e8990)) {
$e8990.pyretStack.push(L[0]);
}
throw $e8990;
}
var $ret9596 = $Hanf_bracket1691102($z9192,Loc6844,provides1223101,nothing4);
++R.GAS;
return $ret9596;
};
var $Hanf_bracket1691102 = function(anf_bracket1225100,Loc6844,provides1223101,nothing4) {
var anf_fun12262762 = G(anf_bracket1225100,"results",L[0]);
var $z27542755 = D;
var $f27602761 = function(_) {
return R.isFunction(anf_fun12262762)?anf_fun12262762.app():R.ffi.throwNonFunApp(L[0],anf_fun12262762,[]);
};
try {
if(--R.GAS > 0) {
$z27542755 = $f27602761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27602761,
"from":L[0]});
}
} catch($e27522753) {
if(R.isCont($e27522753)) {
var $ss27562757 = {"from":L[0],
"go":function(checks12272763) {
return $Hchecks16902764(checks12272763,Loc6844,provides1223101,nothing4);
}};
$e27522753.stack[R.EXN_STACKHEIGHT++] = $ss27562757;
}
if(R.isPyretException($e27522753)) {
$e27522753.pyretStack.push(L[0]);
}
throw $e27522753;
}
var $ret27582759 = $Hchecks16902764($z27542755,Loc6844,provides1223101,nothing4);
++R.GAS;
return $ret27582759;
};
var $Hchecks16902764 = function(checks12272763,Loc6844,provides1223101,nothing4) {
return R.makeObject({"answer":nothing4,
"provide-plus-types":R.makeObject({"values":provides1223101,
"types":{"Loc":Loc6844}}),
"checks":checks12272763});
};
var $Hand_DASH_oper_DASH_1689117 = function(and_DASH_oper_DASH_140116,A222,C515,C624,ast692103,cur_DASH_shared7147,empty3048,errors6949,in_DASH_check_DASH_block7050) {
var if_helper11992777 = R.makeFunction(function(if_helper_arg12002795) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
var if_DASH_1392823 = if_helper_arg12002795;
var if_helper12012808 = R.makeFunction(function(if_helper_arg12022828) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[2],1,arguments);
}
var ans6932830 = if_helper_arg12022828;
cur_DASH_shared7147.$var = empty3048;
errors6949.$var = empty3048;
in_DASH_check_DASH_block7050.$var = (false);
var ann_DASH_check_DASH_temp11972829 = ans6932830;
return R.checkAnn(L[502],R.getDotAnn(L[503],"C",C624,"CompileResult"),ann_DASH_check_DASH_temp11972829,function() {
return ann_DASH_check_DASH_temp11972829;
});
});
var anf_if12052827 = R.isBoolean(if_DASH_1392823);
if(R.isPyretTrue(anf_if12052827)) {
if(R.isPyretTrue(if_DASH_1392823)) {
var anf_fun12092806 = G(C515,"ok",L[499]);
var $z27982799 = D;
var $f28042805 = function(_) {
return R.isFunction(anf_fun12092806)?anf_fun12092806.app(ast692103):R.ffi.throwNonFunApp(L[498],anf_fun12092806,[ast692103]);
};
try {
if(--R.GAS > 0) {
$z27982799 = $f28042805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28042805,
"from":L[498]});
}
} catch($e27962797) {
if(R.isCont($e27962797)) {
var $ss28002801 = {"from":L[498],
"go":function(cont_tail_arg12102807) {
return $Hcont_tail_arg16842809(cont_tail_arg12102807,if_helper12012808);
}};
$e27962797.stack[R.EXN_STACKHEIGHT++] = $ss28002801;
}
if(R.isPyretException($e27962797)) {
$e27962797.pyretStack.push(L[498]);
}
throw $e27962797;
}
var $ret28022803 = $Hcont_tail_arg16842809($z27982799,if_helper12012808);
++R.GAS;
return $ret28022803;
} else {
var anf_fun12062820 = G(C515,"err",L[501]);
var $z28122813 = D;
var $f28182819 = function(_) {
return R.isFunction(anf_fun12062820)?anf_fun12062820.app(errors6949.$var):R.ffi.throwNonFunApp(L[500],anf_fun12062820,[errors6949.$var]);
};
try {
if(--R.GAS > 0) {
$z28122813 = $f28182819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28182819,
"from":L[500]});
}
} catch($e28102811) {
if(R.isCont($e28102811)) {
var $ss28142815 = {"from":L[500],
"go":function(cont_tail_arg12072821) {
return $Hcont_tail_arg16852822(cont_tail_arg12072821,if_helper12012808);
}};
$e28102811.stack[R.EXN_STACKHEIGHT++] = $ss28142815;
}
if(R.isPyretException($e28102811)) {
$e28102811.pyretStack.push(L[500]);
}
throw $e28102811;
}
var $ret28162817 = $Hcont_tail_arg16852822($z28122813,if_helper12012808);
++R.GAS;
return $ret28162817;
}
} else {
var cont_tail_arg12032826 = R.throwNonBooleanCondition(L[2],("if"),if_DASH_1392823);
if(--R.GAS > 0) {
$z28242825 = R.isFunction(if_helper12012808)?if_helper12012808.app(cont_tail_arg12032826):R.ffi.throwNonFunApp(L[2],if_helper12012808,[cont_tail_arg12032826]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper12012808)?if_helper12012808.app(cont_tail_arg12032826):R.ffi.throwNonFunApp(L[2],if_helper12012808,[cont_tail_arg12032826]);
},
"from":L[2]});
}
++R.GAS;
return $z28242825;
}
});
var anf_if12142794 = R.isBoolean(and_DASH_oper_DASH_140116);
if(R.isPyretTrue(anf_if12142794)) {
if(R.isPyretTrue(and_DASH_oper_DASH_140116)) {
var anf_fun12162775 = G(errors6949.$var,"length",L[496]);
var $z27672768 = D;
var $f27732774 = function(_) {
return R.isFunction(anf_fun12162775)?anf_fun12162775.app():R.ffi.throwNonFunApp(L[495],anf_fun12162775,[]);
};
try {
if(--R.GAS > 0) {
$z27672768 = $f27732774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27732774,
"from":L[495]});
}
} catch($e27652766) {
if(R.isCont($e27652766)) {
var $ss27692770 = {"from":L[495],
"go":function(anf_arg12172776) {
return $Hanf_arg16872778(anf_arg12172776,if_helper11992777);
}};
$e27652766.stack[R.EXN_STACKHEIGHT++] = $ss27692770;
}
if(R.isPyretException($e27652766)) {
$e27652766.pyretStack.push(L[495]);
}
throw $e27652766;
}
var $ret27712772 = $Hanf_arg16872778($z27672768,if_helper11992777);
++R.GAS;
return $ret27712772;
} else {
var $z27812782 = D;
var $f27872788 = function(_) {
return R.isFunction(if_helper11992777)?if_helper11992777.app((false)):R.ffi.throwNonFunApp(L[2],if_helper11992777,[(false)]);
};
try {
if(--R.GAS > 0) {
$z27812782 = $f27872788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27872788,
"from":L[2]});
}
} catch($e27792780) {
if(R.isCont($e27792780)) {
var $ss27832784 = {"from":L[2],
"go":function(cont_tail_app12152789) {
return $Hcont_tail_app16882790(cont_tail_app12152789);
}};
$e27792780.stack[R.EXN_STACKHEIGHT++] = $ss27832784;
}
if(R.isPyretException($e27792780)) {
$e27792780.pyretStack.push(L[2]);
}
throw $e27792780;
}
var $ret27852786 = $Hcont_tail_app16882790($z27812782);
++R.GAS;
return $ret27852786;
}
} else {
var cont_tail_arg12122793 = R.throwNonBooleanOp(L[497],("first"),("and"),and_DASH_oper_DASH_140116);
if(--R.GAS > 0) {
$z27912792 = R.isFunction(if_helper11992777)?if_helper11992777.app(cont_tail_arg12122793):R.ffi.throwNonFunApp(L[497],if_helper11992777,[cont_tail_arg12122793]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper11992777)?if_helper11992777.app(cont_tail_arg12122793):R.ffi.throwNonFunApp(L[497],if_helper11992777,[cont_tail_arg12122793]);
},
"from":L[497]});
}
++R.GAS;
return $z27912792;
}
};
var $Hanf_arg16872778 = function(anf_arg12172776,if_helper11992777) {
var and_DASH_oper_DASH_1412841 = R.equiv(anf_arg12172776,(0));
var anf_if12202847 = R.isBoolean(and_DASH_oper_DASH_1412841);
if(R.isPyretTrue(anf_if12202847)) {
var $z28332834 = D;
var $f28392840 = function(_) {
return R.isFunction(if_helper11992777)?if_helper11992777.app(and_DASH_oper_DASH_1412841):R.ffi.throwNonFunApp(L[2],if_helper11992777,[and_DASH_oper_DASH_1412841]);
};
try {
if(--R.GAS > 0) {
$z28332834 = $f28392840();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28392840,
"from":L[2]});
}
} catch($e28312832) {
if(R.isCont($e28312832)) {
var $ss28352836 = {"from":L[2],
"go":function(cont_tail_app12212842) {
return $Hcont_tail_app16862843(cont_tail_app12212842);
}};
$e28312832.stack[R.EXN_STACKHEIGHT++] = $ss28352836;
}
if(R.isPyretException($e28312832)) {
$e28312832.pyretStack.push(L[2]);
}
throw $e28312832;
}
var $ret28372838 = $Hcont_tail_app16862843($z28332834);
++R.GAS;
return $ret28372838;
} else {
var cont_tail_arg12182846 = R.throwNonBooleanOp(L[504],("second"),("and"),and_DASH_oper_DASH_1412841);
if(--R.GAS > 0) {
$z28442845 = R.isFunction(if_helper11992777)?if_helper11992777.app(cont_tail_arg12182846):R.ffi.throwNonFunApp(L[504],if_helper11992777,[cont_tail_arg12182846]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper11992777)?if_helper11992777.app(cont_tail_arg12182846):R.ffi.throwNonFunApp(L[504],if_helper11992777,[cont_tail_arg12182846]);
},
"from":L[504]});
}
++R.GAS;
return $z28442845;
}
};
var $Hcont_tail_app16862843 = function(cont_tail_app12212842) {
return cont_tail_app12212842;
};
var $Hcont_tail_app16882790 = function(cont_tail_app12152789) {
return cont_tail_app12152789;
};
var $Hcont_tail_arg16842809 = function(cont_tail_arg12102807,if_helper12012808) {
if(--R.GAS > 0) {
$z28482849 = R.isFunction(if_helper12012808)?if_helper12012808.app(cont_tail_arg12102807):R.ffi.throwNonFunApp(L[498],if_helper12012808,[cont_tail_arg12102807]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper12012808)?if_helper12012808.app(cont_tail_arg12102807):R.ffi.throwNonFunApp(L[498],if_helper12012808,[cont_tail_arg12102807]);
},
"from":L[498]});
}
++R.GAS;
return $z28482849;
};
var $Hcont_tail_arg16852822 = function(cont_tail_arg12072821,if_helper12012808) {
if(--R.GAS > 0) {
$z28502851 = R.isFunction(if_helper12012808)?if_helper12012808.app(cont_tail_arg12072821):R.ffi.throwNonFunApp(L[500],if_helper12012808,[cont_tail_arg12072821]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper12012808)?if_helper12012808.app(cont_tail_arg12072821):R.ffi.throwNonFunApp(L[500],if_helper12012808,[cont_tail_arg12072821]);
},
"from":L[500]});
}
++R.GAS;
return $z28502851;
};
var $Hann_DASH_check_DASH_temp1683216 = function(ann_DASH_check_DASH_temp1194215) {
return ann_DASH_check_DASH_temp1194215;
};
var $Hann_DASH_check_DASH_temp1682234 = function(ann_DASH_check_DASH_temp1191233) {
return ann_DASH_check_DASH_temp1191233;
};
var $Hann_DASH_check_DASH_temp1681251 = function(ann_DASH_check_DASH_temp1188250) {
return ann_DASH_check_DASH_temp1188250;
};
var $Hann_DASH_check_DASH_temp1680268 = function(ann_DASH_check_DASH_temp1185267) {
return ann_DASH_check_DASH_temp1185267;
};
var $Hann_DASH_check_DASH_temp1679284 = function(ann_DASH_check_DASH_temp1182283) {
return ann_DASH_check_DASH_temp1182283;
};
var $Hann_DASH_check_DASH_temp1678301 = function(ann_DASH_check_DASH_temp1179300) {
return ann_DASH_check_DASH_temp1179300;
};
var $Hann_DASH_check_DASH_temp1677319 = function(ann_DASH_check_DASH_temp1176318) {
return ann_DASH_check_DASH_temp1176318;
};
var $Hann_DASH_check_DASH_temp1676336 = function(ann_DASH_check_DASH_temp1173335) {
return ann_DASH_check_DASH_temp1173335;
};
var $Hann_DASH_check_DASH_temp1675353 = function(ann_DASH_check_DASH_temp1170352) {
return ann_DASH_check_DASH_temp1170352;
};
var $Hann_DASH_check_DASH_temp1674372 = function(ann_DASH_check_DASH_temp1167371) {
return ann_DASH_check_DASH_temp1167371;
};
var $Hann_DASH_check_DASH_temp1673389 = function(ann_DASH_check_DASH_temp1164388) {
return ann_DASH_check_DASH_temp1164388;
};
var $Hann_DASH_check_DASH_temp1672406 = function(ann_DASH_check_DASH_temp1161405) {
return ann_DASH_check_DASH_temp1161405;
};
var $Hann_DASH_check_DASH_temp1671427 = function(ann_DASH_check_DASH_temp1158426) {
return ann_DASH_check_DASH_temp1158426;
};
var $Hann_DASH_check_DASH_temp1670445 = function(ann_DASH_check_DASH_temp1155444) {
return ann_DASH_check_DASH_temp1155444;
};
var $Hann_DASH_check_DASH_temp1669463 = function(ann_DASH_check_DASH_temp1152462) {
return ann_DASH_check_DASH_temp1152462;
};
var $Hann_DASH_check_DASH_temp1668480 = function(ann_DASH_check_DASH_temp1149479) {
return ann_DASH_check_DASH_temp1149479;
};
var $Hann_DASH_check_DASH_temp1667498 = function(ann_DASH_check_DASH_temp1146497) {
return ann_DASH_check_DASH_temp1146497;
};
var $Hann_DASH_check_DASH_temp1666517 = function(ann_DASH_check_DASH_temp1143516) {
return ann_DASH_check_DASH_temp1143516;
};
var $Hann_DASH_check_DASH_temp1665534 = function(ann_DASH_check_DASH_temp1140533) {
return ann_DASH_check_DASH_temp1140533;
};
var $Hann_DASH_check_DASH_temp1664551 = function(ann_DASH_check_DASH_temp1137550) {
return ann_DASH_check_DASH_temp1137550;
};
var $Hann_DASH_check_DASH_temp1663568 = function(ann_DASH_check_DASH_temp1134567) {
return ann_DASH_check_DASH_temp1134567;
};
var $Hann_DASH_check_DASH_temp1662585 = function(ann_DASH_check_DASH_temp1131584) {
return ann_DASH_check_DASH_temp1131584;
};
var $Hann_DASH_check_DASH_temp1661601 = function(ann_DASH_check_DASH_temp1128600) {
return ann_DASH_check_DASH_temp1128600;
};
var $Hann_DASH_check_DASH_temp1660617 = function(ann_DASH_check_DASH_temp1125616) {
return ann_DASH_check_DASH_temp1125616;
};
var $Hann_DASH_check_DASH_temp1659634 = function(ann_DASH_check_DASH_temp1122633) {
return ann_DASH_check_DASH_temp1122633;
};
var $Hann_DASH_check_DASH_temp1658651 = function(ann_DASH_check_DASH_temp1119650) {
return ann_DASH_check_DASH_temp1119650;
};
var $Hann_DASH_check_DASH_temp1657668 = function(ann_DASH_check_DASH_temp1116667) {
return ann_DASH_check_DASH_temp1116667;
};
var $Hann_DASH_check_DASH_temp1656686 = function(ann_DASH_check_DASH_temp1113685) {
return ann_DASH_check_DASH_temp1113685;
};
var $Hann_DASH_check_DASH_temp1655703 = function(ann_DASH_check_DASH_temp1110702) {
return ann_DASH_check_DASH_temp1110702;
};
var $Hann_DASH_check_DASH_temp1654720 = function(ann_DASH_check_DASH_temp1107719) {
return ann_DASH_check_DASH_temp1107719;
};
var $Hann_DASH_check_DASH_temp1653736 = function(ann_DASH_check_DASH_temp1104735) {
return ann_DASH_check_DASH_temp1104735;
};
var $Hann_DASH_check_DASH_temp1652752 = function(ann_DASH_check_DASH_temp1101751) {
return ann_DASH_check_DASH_temp1101751;
};
var $Hann_DASH_check_DASH_temp1651769 = function(ann_DASH_check_DASH_temp1098768) {
return ann_DASH_check_DASH_temp1098768;
};
var $Hann_DASH_check_DASH_temp1650786 = function(ann_DASH_check_DASH_temp1095785) {
return ann_DASH_check_DASH_temp1095785;
};
var $Hann_DASH_check_DASH_temp1649806 = function(ann_DASH_check_DASH_temp1092805) {
return ann_DASH_check_DASH_temp1092805;
};
var $Hann_DASH_check_DASH_temp1648827 = function(ann_DASH_check_DASH_temp1089826) {
return ann_DASH_check_DASH_temp1089826;
};
var $Hann_DASH_check_DASH_temp1647843 = function(ann_DASH_check_DASH_temp1086842) {
return ann_DASH_check_DASH_temp1086842;
};
var $Hann_DASH_check_DASH_temp1646861 = function(ann_DASH_check_DASH_temp1083860) {
return ann_DASH_check_DASH_temp1083860;
};
var $Hann_DASH_check_DASH_temp1645879 = function(ann_DASH_check_DASH_temp1080878) {
return ann_DASH_check_DASH_temp1080878;
};
var $Hann_DASH_check_DASH_temp1644897 = function(ann_DASH_check_DASH_temp1077896) {
return ann_DASH_check_DASH_temp1077896;
};
var $Hann_DASH_check_DASH_temp1643916 = function(ann_DASH_check_DASH_temp1074915) {
return ann_DASH_check_DASH_temp1074915;
};
var $Hann_DASH_check_DASH_temp1642934 = function(ann_DASH_check_DASH_temp1071933) {
return ann_DASH_check_DASH_temp1071933;
};
var $Hann_DASH_check_DASH_temp1641952 = function(ann_DASH_check_DASH_temp1068951) {
return ann_DASH_check_DASH_temp1068951;
};
var $Hann_DASH_check_DASH_temp1640969 = function(ann_DASH_check_DASH_temp1065968) {
return ann_DASH_check_DASH_temp1065968;
};
var $Hann_DASH_check_DASH_temp1639985 = function(ann_DASH_check_DASH_temp1062984) {
return ann_DASH_check_DASH_temp1062984;
};
var $Hann_DASH_check_DASH_temp16381002 = function(ann_DASH_check_DASH_temp10591001) {
return ann_DASH_check_DASH_temp10591001;
};
var $Hann_DASH_check_DASH_temp16371018 = function(ann_DASH_check_DASH_temp10561017) {
return ann_DASH_check_DASH_temp10561017;
};
var $Hann_DASH_check_DASH_temp16361035 = function(ann_DASH_check_DASH_temp10531034) {
return ann_DASH_check_DASH_temp10531034;
};
var $Hann_DASH_check_DASH_temp16351052 = function(ann_DASH_check_DASH_temp10501051) {
return ann_DASH_check_DASH_temp10501051;
};
var $Hann_DASH_check_DASH_temp16341069 = function(ann_DASH_check_DASH_temp10471068) {
return ann_DASH_check_DASH_temp10471068;
};
var $Hann_DASH_check_DASH_temp16331086 = function(ann_DASH_check_DASH_temp10441085) {
return ann_DASH_check_DASH_temp10441085;
};
var $Hann_DASH_check_DASH_temp16321103 = function(ann_DASH_check_DASH_temp10411102) {
return ann_DASH_check_DASH_temp10411102;
};
var $Hann_DASH_check_DASH_temp16311119 = function(ann_DASH_check_DASH_temp10381118) {
return ann_DASH_check_DASH_temp10381118;
};
var $Hann_DASH_check_DASH_temp16301137 = function(ann_DASH_check_DASH_temp10351136) {
return ann_DASH_check_DASH_temp10351136;
};
var $Hann_DASH_check_DASH_temp16291154 = function(ann_DASH_check_DASH_temp10321153) {
return ann_DASH_check_DASH_temp10321153;
};
var $Hann_DASH_check_DASH_temp16281176 = function(ann_DASH_check_DASH_temp10291175) {
return ann_DASH_check_DASH_temp10291175;
};
var $Hann_DASH_check_DASH_temp16271192 = function(ann_DASH_check_DASH_temp10261191) {
return ann_DASH_check_DASH_temp10261191;
};
var $Hann_DASH_check_DASH_temp16261208 = function(ann_DASH_check_DASH_temp10231207) {
return ann_DASH_check_DASH_temp10231207;
};
var $Hann_DASH_check_DASH_temp16251225 = function(ann_DASH_check_DASH_temp10201224) {
return ann_DASH_check_DASH_temp10201224;
};
var $Hann_DASH_check_DASH_temp16241242 = function(ann_DASH_check_DASH_temp10171241) {
return ann_DASH_check_DASH_temp10171241;
};
var $Hann_DASH_check_DASH_temp16231259 = function(ann_DASH_check_DASH_temp10141258) {
return ann_DASH_check_DASH_temp10141258;
};
var $Hann_DASH_check_DASH_temp16221276 = function(ann_DASH_check_DASH_temp10111275) {
return ann_DASH_check_DASH_temp10111275;
};
var $Hann_DASH_check_DASH_temp16211293 = function(ann_DASH_check_DASH_temp10081292) {
return ann_DASH_check_DASH_temp10081292;
};
var $Hann_DASH_check_DASH_temp16201310 = function(ann_DASH_check_DASH_temp10051309) {
return ann_DASH_check_DASH_temp10051309;
};
var $Hann_DASH_check_DASH_temp16191327 = function(ann_DASH_check_DASH_temp10021326) {
return ann_DASH_check_DASH_temp10021326;
};
var $Hann_DASH_check_DASH_temp16181345 = function(ann_DASH_check_DASH_temp9991344) {
return ann_DASH_check_DASH_temp9991344;
};
var $Hann_DASH_check_DASH_temp16171361 = function(ann_DASH_check_DASH_temp9961360) {
return ann_DASH_check_DASH_temp9961360;
};
var $Hann_DASH_check_DASH_temp16161377 = function(ann_DASH_check_DASH_temp9931376) {
return ann_DASH_check_DASH_temp9931376;
};
var $Hann_DASH_check_DASH_temp16151394 = function(ann_DASH_check_DASH_temp9901393) {
return ann_DASH_check_DASH_temp9901393;
};
var $Hann_DASH_check_DASH_temp16141412 = function(ann_DASH_check_DASH_temp9871411) {
return ann_DASH_check_DASH_temp9871411;
};
var $Hann_DASH_check_DASH_temp16131429 = function(ann_DASH_check_DASH_temp9841428) {
return ann_DASH_check_DASH_temp9841428;
};
var $Hanf_begin_app_dropped16121447 = function(anf_begin_app_dropped15951442,_check3821443,cur_DASH_shared7147,fields_DASH_to_DASH_binds10381,lists1118,mixins3791444,params3781445,shared3811446,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067) {
var the_DASH_cur_DASH_shared3832863 = cur_DASH_shared7147.$var;
var $z28542855 = D;
var $f28602861 = function(_) {
return R.isFunction(fields_DASH_to_DASH_binds10381.$var)?fields_DASH_to_DASH_binds10381.$var.app(shared3811446):R.ffi.throwNonFunApp(L[505],fields_DASH_to_DASH_binds10381.$var,[shared3811446]);
};
try {
if(--R.GAS > 0) {
$z28542855 = $f28602861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28602861,
"from":L[505]});
}
} catch($e28522853) {
if(R.isCont($e28522853)) {
var $ss28562857 = {"from":L[505],
"go":function(anf_assign9382862) {
return $Hanf_assign16112864(anf_assign9382862,_check3821443,cur_DASH_shared7147,lists1118,mixins3791444,params3781445,shared3811446,the_DASH_cur_DASH_shared3832863,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
}};
$e28522853.stack[R.EXN_STACKHEIGHT++] = $ss28562857;
}
if(R.isPyretException($e28522853)) {
$e28522853.pyretStack.push(L[505]);
}
throw $e28522853;
}
var $ret28582859 = $Hanf_assign16112864($z28542855,_check3821443,cur_DASH_shared7147,lists1118,mixins3791444,params3781445,shared3811446,the_DASH_cur_DASH_shared3832863,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret28582859;
};
var $Hanf_assign16112864 = function(anf_assign9382862,_check3821443,cur_DASH_shared7147,lists1118,mixins3791444,params3781445,shared3811446,the_DASH_cur_DASH_shared3832863,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067) {
cur_DASH_shared7147.$var = anf_assign9382862;
var anf_fun9392875 = G(lists1118,"all",L[508]);
var anf_arg9422876 = R.makeFunction(function(recv_DASH_1302879) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[507],1,arguments);
}
var anf_fun9412890 = G(recv_DASH_1302879,"visit",L[507]);
var $z28822883 = D;
var $f28882889 = function(_) {
return R.isFunction(anf_fun9412890)?anf_fun9412890.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[507],anf_fun9412890,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z28822883 = $f28882889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28882889,
"from":L[507]});
}
} catch($e28802881) {
if(R.isCont($e28802881)) {
var $ss28842885 = {"from":L[507],
"go":function(ann_DASH_check_DASH_temp9402891) {
return $Hann_DASH_check_DASH_temp15962892(ann_DASH_check_DASH_temp9402891);
}};
$e28802881.stack[R.EXN_STACKHEIGHT++] = $ss28842885;
}
if(R.isPyretException($e28802881)) {
$e28802881.pyretStack.push(L[507]);
}
throw $e28802881;
}
var $ret28862887 = $Hann_DASH_check_DASH_temp15962892($z28822883);
++R.GAS;
return $ret28862887;
});
var $z28672868 = D;
var $f28732874 = function(_) {
return R.isFunction(anf_fun9392875)?anf_fun9392875.app(anf_arg9422876,params3781445):R.ffi.throwNonFunApp(L[506],anf_fun9392875,[anf_arg9422876,params3781445]);
};
try {
if(--R.GAS > 0) {
$z28672868 = $f28732874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28732874,
"from":L[506]});
}
} catch($e28652866) {
if(R.isCont($e28652866)) {
var $ss28692870 = {"from":L[506],
"go":function(and_DASH_oper_DASH_1292877) {
return $Hand_DASH_oper_DASH_16102878(and_DASH_oper_DASH_1292877,_check3821443,cur_DASH_shared7147,lists1118,mixins3791444,shared3811446,the_DASH_cur_DASH_shared3832863,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
}};
$e28652866.stack[R.EXN_STACKHEIGHT++] = $ss28692870;
}
if(R.isPyretException($e28652866)) {
$e28652866.pyretStack.push(L[506]);
}
throw $e28652866;
}
var $ret28712872 = $Hand_DASH_oper_DASH_16102878($z28672868,_check3821443,cur_DASH_shared7147,lists1118,mixins3791444,shared3811446,the_DASH_cur_DASH_shared3832863,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret28712872;
};
var $Hand_DASH_oper_DASH_16102878 = function(and_DASH_oper_DASH_1292877,_check3821443,cur_DASH_shared7147,lists1118,mixins3791444,shared3811446,the_DASH_cur_DASH_shared3832863,variants3801441,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067) {
var if_helper9432906 = R.makeFunction(function(if_helper_arg9442938) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[506],1,arguments);
}
var ret3842971 = if_helper_arg9442938;
cur_DASH_shared7147.$var = the_DASH_cur_DASH_shared3832863;
var and_DASH_oper_DASH_1372964 = ret3842971;
var if_helper9452950 = R.makeFunction(function(if_helper_arg9462969) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[512],1,arguments);
}
var ann_DASH_check_DASH_temp9372970 = if_helper_arg9462969;
return ann_DASH_check_DASH_temp9372970;
});
var anf_if9492968 = R.isBoolean(and_DASH_oper_DASH_1372964);
if(R.isPyretTrue(anf_if9492968)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1372964)) {
var $z29412942 = D;
var $f29472948 = function(_) {
return R.isFunction(wrap_DASH_visit_DASH_check8067.$var)?wrap_DASH_visit_DASH_check8067.$var.app(well_DASH_formed_DASH_visitor183217,_check3821443):R.ffi.throwNonFunApp(L[512],wrap_DASH_visit_DASH_check8067.$var,[well_DASH_formed_DASH_visitor183217,_check3821443]);
};
try {
if(--R.GAS > 0) {
$z29412942 = $f29472948();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29472948,
"from":L[512]});
}
} catch($e29392940) {
if(R.isCont($e29392940)) {
var $ss29432944 = {"from":L[512],
"go":function(and_DASH_oper_DASH_1382949) {
return $Hand_DASH_oper_DASH_15982951(and_DASH_oper_DASH_1382949,if_helper9452950);
}};
$e29392940.stack[R.EXN_STACKHEIGHT++] = $ss29432944;
}
if(R.isPyretException($e29392940)) {
$e29392940.pyretStack.push(L[512]);
}
throw $e29392940;
}
var $ret29452946 = $Hand_DASH_oper_DASH_15982951($z29412942,if_helper9452950);
++R.GAS;
return $ret29452946;
} else {
var $z29542955 = D;
var $f29602961 = function(_) {
return R.isFunction(if_helper9452950)?if_helper9452950.app((false)):R.ffi.throwNonFunApp(L[512],if_helper9452950,[(false)]);
};
try {
if(--R.GAS > 0) {
$z29542955 = $f29602961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29602961,
"from":L[512]});
}
} catch($e29522953) {
if(R.isCont($e29522953)) {
var $ss29562957 = {"from":L[512],
"go":function(cont_tail_app9502962) {
return $Hcont_tail_app15992963(cont_tail_app9502962);
}};
$e29522953.stack[R.EXN_STACKHEIGHT++] = $ss29562957;
}
if(R.isPyretException($e29522953)) {
$e29522953.pyretStack.push(L[512]);
}
throw $e29522953;
}
var $ret29582959 = $Hcont_tail_app15992963($z29542955);
++R.GAS;
return $ret29582959;
}
} else {
var cont_tail_arg9472967 = R.throwNonBooleanOp(L[513],("first"),("and"),and_DASH_oper_DASH_1372964);
if(--R.GAS > 0) {
$z29652966 = R.isFunction(if_helper9452950)?if_helper9452950.app(cont_tail_arg9472967):R.ffi.throwNonFunApp(L[513],if_helper9452950,[cont_tail_arg9472967]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper9452950)?if_helper9452950.app(cont_tail_arg9472967):R.ffi.throwNonFunApp(L[513],if_helper9452950,[cont_tail_arg9472967]);
},
"from":L[513]});
}
++R.GAS;
return $z29652966;
}
});
var anf_if9572937 = R.isBoolean(and_DASH_oper_DASH_1292877);
if(R.isPyretTrue(anf_if9572937)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1292877)) {
var anf_fun9592903 = G(lists1118,"all",L[510]);
var anf_arg9622904 = R.makeFunction(function(recv_DASH_1322908) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[509],1,arguments);
}
var anf_fun9612919 = G(recv_DASH_1322908,"visit",L[509]);
var $z29112912 = D;
var $f29172918 = function(_) {
return R.isFunction(anf_fun9612919)?anf_fun9612919.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[509],anf_fun9612919,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z29112912 = $f29172918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29172918,
"from":L[509]});
}
} catch($e29092910) {
if(R.isCont($e29092910)) {
var $ss29132914 = {"from":L[509],
"go":function(ann_DASH_check_DASH_temp9602920) {
return $Hann_DASH_check_DASH_temp16002921(ann_DASH_check_DASH_temp9602920);
}};
$e29092910.stack[R.EXN_STACKHEIGHT++] = $ss29132914;
}
if(R.isPyretException($e29092910)) {
$e29092910.pyretStack.push(L[509]);
}
throw $e29092910;
}
var $ret29152916 = $Hann_DASH_check_DASH_temp16002921($z29112912);
++R.GAS;
return $ret29152916;
});
var $z28952896 = D;
var $f29012902 = function(_) {
return R.isFunction(anf_fun9592903)?anf_fun9592903.app(anf_arg9622904,mixins3791444):R.ffi.throwNonFunApp(L[506],anf_fun9592903,[anf_arg9622904,mixins3791444]);
};
try {
if(--R.GAS > 0) {
$z28952896 = $f29012902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29012902,
"from":L[506]});
}
} catch($e28932894) {
if(R.isCont($e28932894)) {
var $ss28972898 = {"from":L[506],
"go":function(and_DASH_oper_DASH_1312905) {
return $Hand_DASH_oper_DASH_16082907(and_DASH_oper_DASH_1312905,if_helper9432906,lists1118,shared3811446,variants3801441,well_DASH_formed_DASH_visitor183217);
}};
$e28932894.stack[R.EXN_STACKHEIGHT++] = $ss28972898;
}
if(R.isPyretException($e28932894)) {
$e28932894.pyretStack.push(L[506]);
}
throw $e28932894;
}
var $ret28992900 = $Hand_DASH_oper_DASH_16082907($z28952896,if_helper9432906,lists1118,shared3811446,variants3801441,well_DASH_formed_DASH_visitor183217);
++R.GAS;
return $ret28992900;
} else {
var $z29242925 = D;
var $f29302931 = function(_) {
return R.isFunction(if_helper9432906)?if_helper9432906.app((false)):R.ffi.throwNonFunApp(L[506],if_helper9432906,[(false)]);
};
try {
if(--R.GAS > 0) {
$z29242925 = $f29302931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29302931,
"from":L[506]});
}
} catch($e29222923) {
if(R.isCont($e29222923)) {
var $ss29262927 = {"from":L[506],
"go":function(cont_tail_app9582932) {
return $Hcont_tail_app16092933(cont_tail_app9582932);
}};
$e29222923.stack[R.EXN_STACKHEIGHT++] = $ss29262927;
}
if(R.isPyretException($e29222923)) {
$e29222923.pyretStack.push(L[506]);
}
throw $e29222923;
}
var $ret29282929 = $Hcont_tail_app16092933($z29242925);
++R.GAS;
return $ret29282929;
}
} else {
var cont_tail_arg9552936 = R.throwNonBooleanOp(L[511],("first"),("and"),and_DASH_oper_DASH_1292877);
if(--R.GAS > 0) {
$z29342935 = R.isFunction(if_helper9432906)?if_helper9432906.app(cont_tail_arg9552936):R.ffi.throwNonFunApp(L[511],if_helper9432906,[cont_tail_arg9552936]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper9432906)?if_helper9432906.app(cont_tail_arg9552936):R.ffi.throwNonFunApp(L[511],if_helper9432906,[cont_tail_arg9552936]);
},
"from":L[511]});
}
++R.GAS;
return $z29342935;
}
};
var $Hand_DASH_oper_DASH_16082907 = function(and_DASH_oper_DASH_1312905,if_helper9432906,lists1118,shared3811446,variants3801441,well_DASH_formed_DASH_visitor183217) {
var anf_if9653015 = R.isBoolean(and_DASH_oper_DASH_1312905);
if(R.isPyretTrue(anf_if9653015)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1312905)) {
var anf_fun9672982 = G(lists1118,"all",L[515]);
var anf_arg9702983 = R.makeFunction(function(recv_DASH_1342986) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[514],1,arguments);
}
var anf_fun9692997 = G(recv_DASH_1342986,"visit",L[514]);
var $z29892990 = D;
var $f29952996 = function(_) {
return R.isFunction(anf_fun9692997)?anf_fun9692997.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[514],anf_fun9692997,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z29892990 = $f29952996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29952996,
"from":L[514]});
}
} catch($e29872988) {
if(R.isCont($e29872988)) {
var $ss29912992 = {"from":L[514],
"go":function(ann_DASH_check_DASH_temp9682998) {
return $Hann_DASH_check_DASH_temp16012999(ann_DASH_check_DASH_temp9682998);
}};
$e29872988.stack[R.EXN_STACKHEIGHT++] = $ss29912992;
}
if(R.isPyretException($e29872988)) {
$e29872988.pyretStack.push(L[514]);
}
throw $e29872988;
}
var $ret29932994 = $Hann_DASH_check_DASH_temp16012999($z29892990);
++R.GAS;
return $ret29932994;
});
var $z29742975 = D;
var $f29802981 = function(_) {
return R.isFunction(anf_fun9672982)?anf_fun9672982.app(anf_arg9702983,variants3801441):R.ffi.throwNonFunApp(L[506],anf_fun9672982,[anf_arg9702983,variants3801441]);
};
try {
if(--R.GAS > 0) {
$z29742975 = $f29802981();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29802981,
"from":L[506]});
}
} catch($e29722973) {
if(R.isCont($e29722973)) {
var $ss29762977 = {"from":L[506],
"go":function(and_DASH_oper_DASH_1332984) {
return $Hand_DASH_oper_DASH_16062985(and_DASH_oper_DASH_1332984,if_helper9432906,lists1118,shared3811446,well_DASH_formed_DASH_visitor183217);
}};
$e29722973.stack[R.EXN_STACKHEIGHT++] = $ss29762977;
}
if(R.isPyretException($e29722973)) {
$e29722973.pyretStack.push(L[506]);
}
throw $e29722973;
}
var $ret29782979 = $Hand_DASH_oper_DASH_16062985($z29742975,if_helper9432906,lists1118,shared3811446,well_DASH_formed_DASH_visitor183217);
++R.GAS;
return $ret29782979;
} else {
var $z30023003 = D;
var $f30083009 = function(_) {
return R.isFunction(if_helper9432906)?if_helper9432906.app((false)):R.ffi.throwNonFunApp(L[506],if_helper9432906,[(false)]);
};
try {
if(--R.GAS > 0) {
$z30023003 = $f30083009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30083009,
"from":L[506]});
}
} catch($e30003001) {
if(R.isCont($e30003001)) {
var $ss30043005 = {"from":L[506],
"go":function(cont_tail_app9663010) {
return $Hcont_tail_app16073011(cont_tail_app9663010);
}};
$e30003001.stack[R.EXN_STACKHEIGHT++] = $ss30043005;
}
if(R.isPyretException($e30003001)) {
$e30003001.pyretStack.push(L[506]);
}
throw $e30003001;
}
var $ret30063007 = $Hcont_tail_app16073011($z30023003);
++R.GAS;
return $ret30063007;
}
} else {
var cont_tail_arg9633014 = R.throwNonBooleanOp(L[516],("first"),("and"),and_DASH_oper_DASH_1312905);
if(--R.GAS > 0) {
$z30123013 = R.isFunction(if_helper9432906)?if_helper9432906.app(cont_tail_arg9633014):R.ffi.throwNonFunApp(L[516],if_helper9432906,[cont_tail_arg9633014]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper9432906)?if_helper9432906.app(cont_tail_arg9633014):R.ffi.throwNonFunApp(L[516],if_helper9432906,[cont_tail_arg9633014]);
},
"from":L[516]});
}
++R.GAS;
return $z30123013;
}
};
var $Hand_DASH_oper_DASH_16062985 = function(and_DASH_oper_DASH_1332984,if_helper9432906,lists1118,shared3811446,well_DASH_formed_DASH_visitor183217) {
var anf_if9733059 = R.isBoolean(and_DASH_oper_DASH_1332984);
if(R.isPyretTrue(anf_if9733059)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1332984)) {
var anf_fun9753026 = G(lists1118,"all",L[518]);
var anf_arg9783027 = R.makeFunction(function(recv_DASH_1363030) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[517],1,arguments);
}
var anf_fun9773041 = G(recv_DASH_1363030,"visit",L[517]);
var $z30333034 = D;
var $f30393040 = function(_) {
return R.isFunction(anf_fun9773041)?anf_fun9773041.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[517],anf_fun9773041,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z30333034 = $f30393040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30393040,
"from":L[517]});
}
} catch($e30313032) {
if(R.isCont($e30313032)) {
var $ss30353036 = {"from":L[517],
"go":function(ann_DASH_check_DASH_temp9763042) {
return $Hann_DASH_check_DASH_temp16023043(ann_DASH_check_DASH_temp9763042);
}};
$e30313032.stack[R.EXN_STACKHEIGHT++] = $ss30353036;
}
if(R.isPyretException($e30313032)) {
$e30313032.pyretStack.push(L[517]);
}
throw $e30313032;
}
var $ret30373038 = $Hann_DASH_check_DASH_temp16023043($z30333034);
++R.GAS;
return $ret30373038;
});
var $z30183019 = D;
var $f30243025 = function(_) {
return R.isFunction(anf_fun9753026)?anf_fun9753026.app(anf_arg9783027,shared3811446):R.ffi.throwNonFunApp(L[506],anf_fun9753026,[anf_arg9783027,shared3811446]);
};
try {
if(--R.GAS > 0) {
$z30183019 = $f30243025();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30243025,
"from":L[506]});
}
} catch($e30163017) {
if(R.isCont($e30163017)) {
var $ss30203021 = {"from":L[506],
"go":function(and_DASH_oper_DASH_1353028) {
return $Hand_DASH_oper_DASH_16043029(and_DASH_oper_DASH_1353028,if_helper9432906);
}};
$e30163017.stack[R.EXN_STACKHEIGHT++] = $ss30203021;
}
if(R.isPyretException($e30163017)) {
$e30163017.pyretStack.push(L[506]);
}
throw $e30163017;
}
var $ret30223023 = $Hand_DASH_oper_DASH_16043029($z30183019,if_helper9432906);
++R.GAS;
return $ret30223023;
} else {
var $z30463047 = D;
var $f30523053 = function(_) {
return R.isFunction(if_helper9432906)?if_helper9432906.app((false)):R.ffi.throwNonFunApp(L[506],if_helper9432906,[(false)]);
};
try {
if(--R.GAS > 0) {
$z30463047 = $f30523053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30523053,
"from":L[506]});
}
} catch($e30443045) {
if(R.isCont($e30443045)) {
var $ss30483049 = {"from":L[506],
"go":function(cont_tail_app9743054) {
return $Hcont_tail_app16053055(cont_tail_app9743054);
}};
$e30443045.stack[R.EXN_STACKHEIGHT++] = $ss30483049;
}
if(R.isPyretException($e30443045)) {
$e30443045.pyretStack.push(L[506]);
}
throw $e30443045;
}
var $ret30503051 = $Hcont_tail_app16053055($z30463047);
++R.GAS;
return $ret30503051;
}
} else {
var cont_tail_arg9713058 = R.throwNonBooleanOp(L[519],("first"),("and"),and_DASH_oper_DASH_1332984);
if(--R.GAS > 0) {
$z30563057 = R.isFunction(if_helper9432906)?if_helper9432906.app(cont_tail_arg9713058):R.ffi.throwNonFunApp(L[519],if_helper9432906,[cont_tail_arg9713058]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper9432906)?if_helper9432906.app(cont_tail_arg9713058):R.ffi.throwNonFunApp(L[519],if_helper9432906,[cont_tail_arg9713058]);
},
"from":L[519]});
}
++R.GAS;
return $z30563057;
}
};
var $Hand_DASH_oper_DASH_16043029 = function(and_DASH_oper_DASH_1353028,if_helper9432906) {
var anf_if9813075 = R.isBoolean(and_DASH_oper_DASH_1353028);
if(R.isPyretTrue(anf_if9813075)) {
var $z30623063 = D;
var $f30683069 = function(_) {
return R.isFunction(if_helper9432906)?if_helper9432906.app(and_DASH_oper_DASH_1353028):R.ffi.throwNonFunApp(L[506],if_helper9432906,[and_DASH_oper_DASH_1353028]);
};
try {
if(--R.GAS > 0) {
$z30623063 = $f30683069();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30683069,
"from":L[506]});
}
} catch($e30603061) {
if(R.isCont($e30603061)) {
var $ss30643065 = {"from":L[506],
"go":function(cont_tail_app9823070) {
return $Hcont_tail_app16033071(cont_tail_app9823070);
}};
$e30603061.stack[R.EXN_STACKHEIGHT++] = $ss30643065;
}
if(R.isPyretException($e30603061)) {
$e30603061.pyretStack.push(L[506]);
}
throw $e30603061;
}
var $ret30663067 = $Hcont_tail_app16033071($z30623063);
++R.GAS;
return $ret30663067;
} else {
var cont_tail_arg9793074 = R.throwNonBooleanOp(L[520],("second"),("and"),and_DASH_oper_DASH_1353028);
if(--R.GAS > 0) {
$z30723073 = R.isFunction(if_helper9432906)?if_helper9432906.app(cont_tail_arg9793074):R.ffi.throwNonFunApp(L[520],if_helper9432906,[cont_tail_arg9793074]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper9432906)?if_helper9432906.app(cont_tail_arg9793074):R.ffi.throwNonFunApp(L[520],if_helper9432906,[cont_tail_arg9793074]);
},
"from":L[520]});
}
++R.GAS;
return $z30723073;
}
};
var $Hcont_tail_app16033071 = function(cont_tail_app9823070) {
return cont_tail_app9823070;
};
var $Hann_DASH_check_DASH_temp16023043 = function(ann_DASH_check_DASH_temp9763042) {
return ann_DASH_check_DASH_temp9763042;
};
var $Hcont_tail_app16053055 = function(cont_tail_app9743054) {
return cont_tail_app9743054;
};
var $Hann_DASH_check_DASH_temp16012999 = function(ann_DASH_check_DASH_temp9682998) {
return ann_DASH_check_DASH_temp9682998;
};
var $Hcont_tail_app16073011 = function(cont_tail_app9663010) {
return cont_tail_app9663010;
};
var $Hann_DASH_check_DASH_temp16002921 = function(ann_DASH_check_DASH_temp9602920) {
return ann_DASH_check_DASH_temp9602920;
};
var $Hcont_tail_app16092933 = function(cont_tail_app9582932) {
return cont_tail_app9582932;
};
var $Hand_DASH_oper_DASH_15982951 = function(and_DASH_oper_DASH_1382949,if_helper9452950) {
var anf_if9533091 = R.isBoolean(and_DASH_oper_DASH_1382949);
if(R.isPyretTrue(anf_if9533091)) {
var $z30783079 = D;
var $f30843085 = function(_) {
return R.isFunction(if_helper9452950)?if_helper9452950.app(and_DASH_oper_DASH_1382949):R.ffi.throwNonFunApp(L[512],if_helper9452950,[and_DASH_oper_DASH_1382949]);
};
try {
if(--R.GAS > 0) {
$z30783079 = $f30843085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30843085,
"from":L[512]});
}
} catch($e30763077) {
if(R.isCont($e30763077)) {
var $ss30803081 = {"from":L[512],
"go":function(cont_tail_app9543086) {
return $Hcont_tail_app15973087(cont_tail_app9543086);
}};
$e30763077.stack[R.EXN_STACKHEIGHT++] = $ss30803081;
}
if(R.isPyretException($e30763077)) {
$e30763077.pyretStack.push(L[512]);
}
throw $e30763077;
}
var $ret30823083 = $Hcont_tail_app15973087($z30783079);
++R.GAS;
return $ret30823083;
} else {
var cont_tail_arg9513090 = R.throwNonBooleanOp(L[521],("second"),("and"),and_DASH_oper_DASH_1382949);
if(--R.GAS > 0) {
$z30883089 = R.isFunction(if_helper9452950)?if_helper9452950.app(cont_tail_arg9513090):R.ffi.throwNonFunApp(L[521],if_helper9452950,[cont_tail_arg9513090]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper9452950)?if_helper9452950.app(cont_tail_arg9513090):R.ffi.throwNonFunApp(L[521],if_helper9452950,[cont_tail_arg9513090]);
},
"from":L[521]});
}
++R.GAS;
return $z30883089;
}
};
var $Hcont_tail_app15973087 = function(cont_tail_app9543086) {
return cont_tail_app9543086;
};
var $Hcont_tail_app15992963 = function(cont_tail_app9502962) {
return cont_tail_app9502962;
};
var $Hann_DASH_check_DASH_temp15962892 = function(ann_DASH_check_DASH_temp9402891) {
return ann_DASH_check_DASH_temp9402891;
};
var $Hanf_arg15941465 = function(anf_arg9201463,binds3721462,constructor3731464,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217) {
var $z30943095 = D;
var $f31003101 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(anf_arg9201463):R.ffi.throwNonFunApp(L[522],ensure_DASH_unique_DASH_ids9973.$var,[anf_arg9201463]);
};
try {
if(--R.GAS > 0) {
$z30943095 = $f31003101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31003101,
"from":L[522]});
}
} catch($e30923093) {
if(R.isCont($e30923093)) {
var $ss30963097 = {"from":L[522],
"go":function(anf_begin_app_dropped15873102) {
return $Hanf_begin_app_dropped15933103(anf_begin_app_dropped15873102,binds3721462,constructor3731464,lists1118,well_DASH_formed_DASH_visitor183217);
}};
$e30923093.stack[R.EXN_STACKHEIGHT++] = $ss30963097;
}
if(R.isPyretException($e30923093)) {
$e30923093.pyretStack.push(L[522]);
}
throw $e30923093;
}
var $ret30983099 = $Hanf_begin_app_dropped15933103($z30943095,binds3721462,constructor3731464,lists1118,well_DASH_formed_DASH_visitor183217);
++R.GAS;
return $ret30983099;
};
var $Hanf_begin_app_dropped15933103 = function(anf_begin_app_dropped15873102,binds3721462,constructor3731464,lists1118,well_DASH_formed_DASH_visitor183217) {
var anf_fun9213114 = G(lists1118,"all",L[525]);
var anf_arg9243115 = R.makeFunction(function(recv_DASH_1273118) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[524],1,arguments);
}
var anf_fun9233129 = G(recv_DASH_1273118,"visit",L[524]);
var $z31213122 = D;
var $f31273128 = function(_) {
return R.isFunction(anf_fun9233129)?anf_fun9233129.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[524],anf_fun9233129,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z31213122 = $f31273128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31273128,
"from":L[524]});
}
} catch($e31193120) {
if(R.isCont($e31193120)) {
var $ss31233124 = {"from":L[524],
"go":function(ann_DASH_check_DASH_temp9223130) {
return $Hann_DASH_check_DASH_temp15883131(ann_DASH_check_DASH_temp9223130);
}};
$e31193120.stack[R.EXN_STACKHEIGHT++] = $ss31233124;
}
if(R.isPyretException($e31193120)) {
$e31193120.pyretStack.push(L[524]);
}
throw $e31193120;
}
var $ret31253126 = $Hann_DASH_check_DASH_temp15883131($z31213122);
++R.GAS;
return $ret31253126;
});
var $z31063107 = D;
var $f31123113 = function(_) {
return R.isFunction(anf_fun9213114)?anf_fun9213114.app(anf_arg9243115,binds3721462):R.ffi.throwNonFunApp(L[523],anf_fun9213114,[anf_arg9243115,binds3721462]);
};
try {
if(--R.GAS > 0) {
$z31063107 = $f31123113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31123113,
"from":L[523]});
}
} catch($e31043105) {
if(R.isCont($e31043105)) {
var $ss31083109 = {"from":L[523],
"go":function(and_DASH_oper_DASH_1263116) {
return $Hand_DASH_oper_DASH_15923117(and_DASH_oper_DASH_1263116,constructor3731464,well_DASH_formed_DASH_visitor183217);
}};
$e31043105.stack[R.EXN_STACKHEIGHT++] = $ss31083109;
}
if(R.isPyretException($e31043105)) {
$e31043105.pyretStack.push(L[523]);
}
throw $e31043105;
}
var $ret31103111 = $Hand_DASH_oper_DASH_15923117($z31063107,constructor3731464,well_DASH_formed_DASH_visitor183217);
++R.GAS;
return $ret31103111;
};
var $Hand_DASH_oper_DASH_15923117 = function(and_DASH_oper_DASH_1263116,constructor3731464,well_DASH_formed_DASH_visitor183217) {
var if_helper9253144 = R.makeFunction(function(if_helper_arg9263162) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[523],1,arguments);
}
var ann_DASH_check_DASH_temp9193163 = if_helper_arg9263162;
return ann_DASH_check_DASH_temp9193163;
});
var anf_if9293161 = R.isBoolean(and_DASH_oper_DASH_1263116);
if(R.isPyretTrue(anf_if9293161)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1263116)) {
var anf_fun9313142 = G(constructor3731464,"visit",L[526]);
var $z31343135 = D;
var $f31403141 = function(_) {
return R.isFunction(anf_fun9313142)?anf_fun9313142.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[523],anf_fun9313142,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z31343135 = $f31403141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31403141,
"from":L[523]});
}
} catch($e31323133) {
if(R.isCont($e31323133)) {
var $ss31363137 = {"from":L[523],
"go":function(and_DASH_oper_DASH_1283143) {
return $Hand_DASH_oper_DASH_15903145(and_DASH_oper_DASH_1283143,if_helper9253144);
}};
$e31323133.stack[R.EXN_STACKHEIGHT++] = $ss31363137;
}
if(R.isPyretException($e31323133)) {
$e31323133.pyretStack.push(L[523]);
}
throw $e31323133;
}
var $ret31383139 = $Hand_DASH_oper_DASH_15903145($z31343135,if_helper9253144);
++R.GAS;
return $ret31383139;
} else {
var $z31483149 = D;
var $f31543155 = function(_) {
return R.isFunction(if_helper9253144)?if_helper9253144.app((false)):R.ffi.throwNonFunApp(L[523],if_helper9253144,[(false)]);
};
try {
if(--R.GAS > 0) {
$z31483149 = $f31543155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31543155,
"from":L[523]});
}
} catch($e31463147) {
if(R.isCont($e31463147)) {
var $ss31503151 = {"from":L[523],
"go":function(cont_tail_app9303156) {
return $Hcont_tail_app15913157(cont_tail_app9303156);
}};
$e31463147.stack[R.EXN_STACKHEIGHT++] = $ss31503151;
}
if(R.isPyretException($e31463147)) {
$e31463147.pyretStack.push(L[523]);
}
throw $e31463147;
}
var $ret31523153 = $Hcont_tail_app15913157($z31483149);
++R.GAS;
return $ret31523153;
}
} else {
var cont_tail_arg9273160 = R.throwNonBooleanOp(L[527],("first"),("and"),and_DASH_oper_DASH_1263116);
if(--R.GAS > 0) {
$z31583159 = R.isFunction(if_helper9253144)?if_helper9253144.app(cont_tail_arg9273160):R.ffi.throwNonFunApp(L[527],if_helper9253144,[cont_tail_arg9273160]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper9253144)?if_helper9253144.app(cont_tail_arg9273160):R.ffi.throwNonFunApp(L[527],if_helper9253144,[cont_tail_arg9273160]);
},
"from":L[527]});
}
++R.GAS;
return $z31583159;
}
};
var $Hand_DASH_oper_DASH_15903145 = function(and_DASH_oper_DASH_1283143,if_helper9253144) {
var anf_if9343179 = R.isBoolean(and_DASH_oper_DASH_1283143);
if(R.isPyretTrue(anf_if9343179)) {
var $z31663167 = D;
var $f31723173 = function(_) {
return R.isFunction(if_helper9253144)?if_helper9253144.app(and_DASH_oper_DASH_1283143):R.ffi.throwNonFunApp(L[523],if_helper9253144,[and_DASH_oper_DASH_1283143]);
};
try {
if(--R.GAS > 0) {
$z31663167 = $f31723173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31723173,
"from":L[523]});
}
} catch($e31643165) {
if(R.isCont($e31643165)) {
var $ss31683169 = {"from":L[523],
"go":function(cont_tail_app9353174) {
return $Hcont_tail_app15893175(cont_tail_app9353174);
}};
$e31643165.stack[R.EXN_STACKHEIGHT++] = $ss31683169;
}
if(R.isPyretException($e31643165)) {
$e31643165.pyretStack.push(L[523]);
}
throw $e31643165;
}
var $ret31703171 = $Hcont_tail_app15893175($z31663167);
++R.GAS;
return $ret31703171;
} else {
var cont_tail_arg9323178 = R.throwNonBooleanOp(L[528],("second"),("and"),and_DASH_oper_DASH_1283143);
if(--R.GAS > 0) {
$z31763177 = R.isFunction(if_helper9253144)?if_helper9253144.app(cont_tail_arg9323178):R.ffi.throwNonFunApp(L[528],if_helper9253144,[cont_tail_arg9323178]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper9253144)?if_helper9253144.app(cont_tail_arg9323178):R.ffi.throwNonFunApp(L[528],if_helper9253144,[cont_tail_arg9323178]);
},
"from":L[528]});
}
++R.GAS;
return $z31763177;
}
};
var $Hcont_tail_app15893175 = function(cont_tail_app9353174) {
return cont_tail_app9353174;
};
var $Hcont_tail_app15913157 = function(cont_tail_app9303156) {
return cont_tail_app9303156;
};
var $Hann_DASH_check_DASH_temp15883131 = function(ann_DASH_check_DASH_temp9223130) {
return ann_DASH_check_DASH_temp9223130;
};
var $Hanf_begin_app_dropped15861485 = function(anf_begin_app_dropped15691480,_check3661481,cur_DASH_shared7147,fields_DASH_to_DASH_binds10381,lists1118,mixins3631482,params3621483,shares3651484,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067) {
var the_DASH_cur_DASH_shared3673191 = cur_DASH_shared7147.$var;
var $z31823183 = D;
var $f31883189 = function(_) {
return R.isFunction(fields_DASH_to_DASH_binds10381.$var)?fields_DASH_to_DASH_binds10381.$var.app(shares3651484):R.ffi.throwNonFunApp(L[529],fields_DASH_to_DASH_binds10381.$var,[shares3651484]);
};
try {
if(--R.GAS > 0) {
$z31823183 = $f31883189();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31883189,
"from":L[529]});
}
} catch($e31803181) {
if(R.isCont($e31803181)) {
var $ss31843185 = {"from":L[529],
"go":function(anf_assign8733190) {
return $Hanf_assign15853192(anf_assign8733190,_check3661481,cur_DASH_shared7147,lists1118,mixins3631482,params3621483,shares3651484,the_DASH_cur_DASH_shared3673191,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
}};
$e31803181.stack[R.EXN_STACKHEIGHT++] = $ss31843185;
}
if(R.isPyretException($e31803181)) {
$e31803181.pyretStack.push(L[529]);
}
throw $e31803181;
}
var $ret31863187 = $Hanf_assign15853192($z31823183,_check3661481,cur_DASH_shared7147,lists1118,mixins3631482,params3621483,shares3651484,the_DASH_cur_DASH_shared3673191,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret31863187;
};
var $Hanf_assign15853192 = function(anf_assign8733190,_check3661481,cur_DASH_shared7147,lists1118,mixins3631482,params3621483,shares3651484,the_DASH_cur_DASH_shared3673191,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067) {
cur_DASH_shared7147.$var = anf_assign8733190;
var anf_fun8743203 = G(lists1118,"all",L[532]);
var anf_arg8773204 = R.makeFunction(function(recv_DASH_1173207) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[531],1,arguments);
}
var anf_fun8763218 = G(recv_DASH_1173207,"visit",L[531]);
var $z32103211 = D;
var $f32163217 = function(_) {
return R.isFunction(anf_fun8763218)?anf_fun8763218.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[531],anf_fun8763218,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z32103211 = $f32163217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32163217,
"from":L[531]});
}
} catch($e32083209) {
if(R.isCont($e32083209)) {
var $ss32123213 = {"from":L[531],
"go":function(ann_DASH_check_DASH_temp8753219) {
return $Hann_DASH_check_DASH_temp15703220(ann_DASH_check_DASH_temp8753219);
}};
$e32083209.stack[R.EXN_STACKHEIGHT++] = $ss32123213;
}
if(R.isPyretException($e32083209)) {
$e32083209.pyretStack.push(L[531]);
}
throw $e32083209;
}
var $ret32143215 = $Hann_DASH_check_DASH_temp15703220($z32103211);
++R.GAS;
return $ret32143215;
});
var $z31953196 = D;
var $f32013202 = function(_) {
return R.isFunction(anf_fun8743203)?anf_fun8743203.app(anf_arg8773204,params3621483):R.ffi.throwNonFunApp(L[530],anf_fun8743203,[anf_arg8773204,params3621483]);
};
try {
if(--R.GAS > 0) {
$z31953196 = $f32013202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32013202,
"from":L[530]});
}
} catch($e31933194) {
if(R.isCont($e31933194)) {
var $ss31973198 = {"from":L[530],
"go":function(and_DASH_oper_DASH_1163205) {
return $Hand_DASH_oper_DASH_15843206(and_DASH_oper_DASH_1163205,_check3661481,cur_DASH_shared7147,lists1118,mixins3631482,shares3651484,the_DASH_cur_DASH_shared3673191,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
}};
$e31933194.stack[R.EXN_STACKHEIGHT++] = $ss31973198;
}
if(R.isPyretException($e31933194)) {
$e31933194.pyretStack.push(L[530]);
}
throw $e31933194;
}
var $ret31993200 = $Hand_DASH_oper_DASH_15843206($z31953196,_check3661481,cur_DASH_shared7147,lists1118,mixins3631482,shares3651484,the_DASH_cur_DASH_shared3673191,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret31993200;
};
var $Hand_DASH_oper_DASH_15843206 = function(and_DASH_oper_DASH_1163205,_check3661481,cur_DASH_shared7147,lists1118,mixins3631482,shares3651484,the_DASH_cur_DASH_shared3673191,variants3641479,well_DASH_formed_DASH_visitor183217,wrap_DASH_visit_DASH_check8067) {
var if_helper8783234 = R.makeFunction(function(if_helper_arg8793266) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[530],1,arguments);
}
var ret3683299 = if_helper_arg8793266;
cur_DASH_shared7147.$var = the_DASH_cur_DASH_shared3673191;
var and_DASH_oper_DASH_1243292 = ret3683299;
var if_helper8803278 = R.makeFunction(function(if_helper_arg8813297) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[536],1,arguments);
}
var ann_DASH_check_DASH_temp8723298 = if_helper_arg8813297;
return ann_DASH_check_DASH_temp8723298;
});
var anf_if8843296 = R.isBoolean(and_DASH_oper_DASH_1243292);
if(R.isPyretTrue(anf_if8843296)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1243292)) {
var $z32693270 = D;
var $f32753276 = function(_) {
return R.isFunction(wrap_DASH_visit_DASH_check8067.$var)?wrap_DASH_visit_DASH_check8067.$var.app(well_DASH_formed_DASH_visitor183217,_check3661481):R.ffi.throwNonFunApp(L[536],wrap_DASH_visit_DASH_check8067.$var,[well_DASH_formed_DASH_visitor183217,_check3661481]);
};
try {
if(--R.GAS > 0) {
$z32693270 = $f32753276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32753276,
"from":L[536]});
}
} catch($e32673268) {
if(R.isCont($e32673268)) {
var $ss32713272 = {"from":L[536],
"go":function(and_DASH_oper_DASH_1253277) {
return $Hand_DASH_oper_DASH_15723279(and_DASH_oper_DASH_1253277,if_helper8803278);
}};
$e32673268.stack[R.EXN_STACKHEIGHT++] = $ss32713272;
}
if(R.isPyretException($e32673268)) {
$e32673268.pyretStack.push(L[536]);
}
throw $e32673268;
}
var $ret32733274 = $Hand_DASH_oper_DASH_15723279($z32693270,if_helper8803278);
++R.GAS;
return $ret32733274;
} else {
var $z32823283 = D;
var $f32883289 = function(_) {
return R.isFunction(if_helper8803278)?if_helper8803278.app((false)):R.ffi.throwNonFunApp(L[536],if_helper8803278,[(false)]);
};
try {
if(--R.GAS > 0) {
$z32823283 = $f32883289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32883289,
"from":L[536]});
}
} catch($e32803281) {
if(R.isCont($e32803281)) {
var $ss32843285 = {"from":L[536],
"go":function(cont_tail_app8853290) {
return $Hcont_tail_app15733291(cont_tail_app8853290);
}};
$e32803281.stack[R.EXN_STACKHEIGHT++] = $ss32843285;
}
if(R.isPyretException($e32803281)) {
$e32803281.pyretStack.push(L[536]);
}
throw $e32803281;
}
var $ret32863287 = $Hcont_tail_app15733291($z32823283);
++R.GAS;
return $ret32863287;
}
} else {
var cont_tail_arg8823295 = R.throwNonBooleanOp(L[537],("first"),("and"),and_DASH_oper_DASH_1243292);
if(--R.GAS > 0) {
$z32933294 = R.isFunction(if_helper8803278)?if_helper8803278.app(cont_tail_arg8823295):R.ffi.throwNonFunApp(L[537],if_helper8803278,[cont_tail_arg8823295]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8803278)?if_helper8803278.app(cont_tail_arg8823295):R.ffi.throwNonFunApp(L[537],if_helper8803278,[cont_tail_arg8823295]);
},
"from":L[537]});
}
++R.GAS;
return $z32933294;
}
});
var anf_if8923265 = R.isBoolean(and_DASH_oper_DASH_1163205);
if(R.isPyretTrue(anf_if8923265)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1163205)) {
var anf_fun8943231 = G(lists1118,"all",L[534]);
var anf_arg8973232 = R.makeFunction(function(recv_DASH_1193236) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[533],1,arguments);
}
var anf_fun8963247 = G(recv_DASH_1193236,"visit",L[533]);
var $z32393240 = D;
var $f32453246 = function(_) {
return R.isFunction(anf_fun8963247)?anf_fun8963247.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[533],anf_fun8963247,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z32393240 = $f32453246();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32453246,
"from":L[533]});
}
} catch($e32373238) {
if(R.isCont($e32373238)) {
var $ss32413242 = {"from":L[533],
"go":function(ann_DASH_check_DASH_temp8953248) {
return $Hann_DASH_check_DASH_temp15743249(ann_DASH_check_DASH_temp8953248);
}};
$e32373238.stack[R.EXN_STACKHEIGHT++] = $ss32413242;
}
if(R.isPyretException($e32373238)) {
$e32373238.pyretStack.push(L[533]);
}
throw $e32373238;
}
var $ret32433244 = $Hann_DASH_check_DASH_temp15743249($z32393240);
++R.GAS;
return $ret32433244;
});
var $z32233224 = D;
var $f32293230 = function(_) {
return R.isFunction(anf_fun8943231)?anf_fun8943231.app(anf_arg8973232,mixins3631482):R.ffi.throwNonFunApp(L[530],anf_fun8943231,[anf_arg8973232,mixins3631482]);
};
try {
if(--R.GAS > 0) {
$z32233224 = $f32293230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32293230,
"from":L[530]});
}
} catch($e32213222) {
if(R.isCont($e32213222)) {
var $ss32253226 = {"from":L[530],
"go":function(and_DASH_oper_DASH_1183233) {
return $Hand_DASH_oper_DASH_15823235(and_DASH_oper_DASH_1183233,if_helper8783234,lists1118,shares3651484,variants3641479,well_DASH_formed_DASH_visitor183217);
}};
$e32213222.stack[R.EXN_STACKHEIGHT++] = $ss32253226;
}
if(R.isPyretException($e32213222)) {
$e32213222.pyretStack.push(L[530]);
}
throw $e32213222;
}
var $ret32273228 = $Hand_DASH_oper_DASH_15823235($z32233224,if_helper8783234,lists1118,shares3651484,variants3641479,well_DASH_formed_DASH_visitor183217);
++R.GAS;
return $ret32273228;
} else {
var $z32523253 = D;
var $f32583259 = function(_) {
return R.isFunction(if_helper8783234)?if_helper8783234.app((false)):R.ffi.throwNonFunApp(L[530],if_helper8783234,[(false)]);
};
try {
if(--R.GAS > 0) {
$z32523253 = $f32583259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32583259,
"from":L[530]});
}
} catch($e32503251) {
if(R.isCont($e32503251)) {
var $ss32543255 = {"from":L[530],
"go":function(cont_tail_app8933260) {
return $Hcont_tail_app15833261(cont_tail_app8933260);
}};
$e32503251.stack[R.EXN_STACKHEIGHT++] = $ss32543255;
}
if(R.isPyretException($e32503251)) {
$e32503251.pyretStack.push(L[530]);
}
throw $e32503251;
}
var $ret32563257 = $Hcont_tail_app15833261($z32523253);
++R.GAS;
return $ret32563257;
}
} else {
var cont_tail_arg8903264 = R.throwNonBooleanOp(L[535],("first"),("and"),and_DASH_oper_DASH_1163205);
if(--R.GAS > 0) {
$z32623263 = R.isFunction(if_helper8783234)?if_helper8783234.app(cont_tail_arg8903264):R.ffi.throwNonFunApp(L[535],if_helper8783234,[cont_tail_arg8903264]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8783234)?if_helper8783234.app(cont_tail_arg8903264):R.ffi.throwNonFunApp(L[535],if_helper8783234,[cont_tail_arg8903264]);
},
"from":L[535]});
}
++R.GAS;
return $z32623263;
}
};
var $Hand_DASH_oper_DASH_15823235 = function(and_DASH_oper_DASH_1183233,if_helper8783234,lists1118,shares3651484,variants3641479,well_DASH_formed_DASH_visitor183217) {
var anf_if9003343 = R.isBoolean(and_DASH_oper_DASH_1183233);
if(R.isPyretTrue(anf_if9003343)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1183233)) {
var anf_fun9023310 = G(lists1118,"all",L[539]);
var anf_arg9053311 = R.makeFunction(function(recv_DASH_1213314) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[538],1,arguments);
}
var anf_fun9043325 = G(recv_DASH_1213314,"visit",L[538]);
var $z33173318 = D;
var $f33233324 = function(_) {
return R.isFunction(anf_fun9043325)?anf_fun9043325.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[538],anf_fun9043325,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z33173318 = $f33233324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33233324,
"from":L[538]});
}
} catch($e33153316) {
if(R.isCont($e33153316)) {
var $ss33193320 = {"from":L[538],
"go":function(ann_DASH_check_DASH_temp9033326) {
return $Hann_DASH_check_DASH_temp15753327(ann_DASH_check_DASH_temp9033326);
}};
$e33153316.stack[R.EXN_STACKHEIGHT++] = $ss33193320;
}
if(R.isPyretException($e33153316)) {
$e33153316.pyretStack.push(L[538]);
}
throw $e33153316;
}
var $ret33213322 = $Hann_DASH_check_DASH_temp15753327($z33173318);
++R.GAS;
return $ret33213322;
});
var $z33023303 = D;
var $f33083309 = function(_) {
return R.isFunction(anf_fun9023310)?anf_fun9023310.app(anf_arg9053311,variants3641479):R.ffi.throwNonFunApp(L[530],anf_fun9023310,[anf_arg9053311,variants3641479]);
};
try {
if(--R.GAS > 0) {
$z33023303 = $f33083309();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33083309,
"from":L[530]});
}
} catch($e33003301) {
if(R.isCont($e33003301)) {
var $ss33043305 = {"from":L[530],
"go":function(and_DASH_oper_DASH_1203312) {
return $Hand_DASH_oper_DASH_15803313(and_DASH_oper_DASH_1203312,if_helper8783234,lists1118,shares3651484,well_DASH_formed_DASH_visitor183217);
}};
$e33003301.stack[R.EXN_STACKHEIGHT++] = $ss33043305;
}
if(R.isPyretException($e33003301)) {
$e33003301.pyretStack.push(L[530]);
}
throw $e33003301;
}
var $ret33063307 = $Hand_DASH_oper_DASH_15803313($z33023303,if_helper8783234,lists1118,shares3651484,well_DASH_formed_DASH_visitor183217);
++R.GAS;
return $ret33063307;
} else {
var $z33303331 = D;
var $f33363337 = function(_) {
return R.isFunction(if_helper8783234)?if_helper8783234.app((false)):R.ffi.throwNonFunApp(L[530],if_helper8783234,[(false)]);
};
try {
if(--R.GAS > 0) {
$z33303331 = $f33363337();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33363337,
"from":L[530]});
}
} catch($e33283329) {
if(R.isCont($e33283329)) {
var $ss33323333 = {"from":L[530],
"go":function(cont_tail_app9013338) {
return $Hcont_tail_app15813339(cont_tail_app9013338);
}};
$e33283329.stack[R.EXN_STACKHEIGHT++] = $ss33323333;
}
if(R.isPyretException($e33283329)) {
$e33283329.pyretStack.push(L[530]);
}
throw $e33283329;
}
var $ret33343335 = $Hcont_tail_app15813339($z33303331);
++R.GAS;
return $ret33343335;
}
} else {
var cont_tail_arg8983342 = R.throwNonBooleanOp(L[540],("first"),("and"),and_DASH_oper_DASH_1183233);
if(--R.GAS > 0) {
$z33403341 = R.isFunction(if_helper8783234)?if_helper8783234.app(cont_tail_arg8983342):R.ffi.throwNonFunApp(L[540],if_helper8783234,[cont_tail_arg8983342]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8783234)?if_helper8783234.app(cont_tail_arg8983342):R.ffi.throwNonFunApp(L[540],if_helper8783234,[cont_tail_arg8983342]);
},
"from":L[540]});
}
++R.GAS;
return $z33403341;
}
};
var $Hand_DASH_oper_DASH_15803313 = function(and_DASH_oper_DASH_1203312,if_helper8783234,lists1118,shares3651484,well_DASH_formed_DASH_visitor183217) {
var anf_if9083387 = R.isBoolean(and_DASH_oper_DASH_1203312);
if(R.isPyretTrue(anf_if9083387)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1203312)) {
var anf_fun9103354 = G(lists1118,"all",L[542]);
var anf_arg9133355 = R.makeFunction(function(recv_DASH_1233358) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[541],1,arguments);
}
var anf_fun9123369 = G(recv_DASH_1233358,"visit",L[541]);
var $z33613362 = D;
var $f33673368 = function(_) {
return R.isFunction(anf_fun9123369)?anf_fun9123369.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[541],anf_fun9123369,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z33613362 = $f33673368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33673368,
"from":L[541]});
}
} catch($e33593360) {
if(R.isCont($e33593360)) {
var $ss33633364 = {"from":L[541],
"go":function(ann_DASH_check_DASH_temp9113370) {
return $Hann_DASH_check_DASH_temp15763371(ann_DASH_check_DASH_temp9113370);
}};
$e33593360.stack[R.EXN_STACKHEIGHT++] = $ss33633364;
}
if(R.isPyretException($e33593360)) {
$e33593360.pyretStack.push(L[541]);
}
throw $e33593360;
}
var $ret33653366 = $Hann_DASH_check_DASH_temp15763371($z33613362);
++R.GAS;
return $ret33653366;
});
var $z33463347 = D;
var $f33523353 = function(_) {
return R.isFunction(anf_fun9103354)?anf_fun9103354.app(anf_arg9133355,shares3651484):R.ffi.throwNonFunApp(L[530],anf_fun9103354,[anf_arg9133355,shares3651484]);
};
try {
if(--R.GAS > 0) {
$z33463347 = $f33523353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33523353,
"from":L[530]});
}
} catch($e33443345) {
if(R.isCont($e33443345)) {
var $ss33483349 = {"from":L[530],
"go":function(and_DASH_oper_DASH_1223356) {
return $Hand_DASH_oper_DASH_15783357(and_DASH_oper_DASH_1223356,if_helper8783234);
}};
$e33443345.stack[R.EXN_STACKHEIGHT++] = $ss33483349;
}
if(R.isPyretException($e33443345)) {
$e33443345.pyretStack.push(L[530]);
}
throw $e33443345;
}
var $ret33503351 = $Hand_DASH_oper_DASH_15783357($z33463347,if_helper8783234);
++R.GAS;
return $ret33503351;
} else {
var $z33743375 = D;
var $f33803381 = function(_) {
return R.isFunction(if_helper8783234)?if_helper8783234.app((false)):R.ffi.throwNonFunApp(L[530],if_helper8783234,[(false)]);
};
try {
if(--R.GAS > 0) {
$z33743375 = $f33803381();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33803381,
"from":L[530]});
}
} catch($e33723373) {
if(R.isCont($e33723373)) {
var $ss33763377 = {"from":L[530],
"go":function(cont_tail_app9093382) {
return $Hcont_tail_app15793383(cont_tail_app9093382);
}};
$e33723373.stack[R.EXN_STACKHEIGHT++] = $ss33763377;
}
if(R.isPyretException($e33723373)) {
$e33723373.pyretStack.push(L[530]);
}
throw $e33723373;
}
var $ret33783379 = $Hcont_tail_app15793383($z33743375);
++R.GAS;
return $ret33783379;
}
} else {
var cont_tail_arg9063386 = R.throwNonBooleanOp(L[543],("first"),("and"),and_DASH_oper_DASH_1203312);
if(--R.GAS > 0) {
$z33843385 = R.isFunction(if_helper8783234)?if_helper8783234.app(cont_tail_arg9063386):R.ffi.throwNonFunApp(L[543],if_helper8783234,[cont_tail_arg9063386]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8783234)?if_helper8783234.app(cont_tail_arg9063386):R.ffi.throwNonFunApp(L[543],if_helper8783234,[cont_tail_arg9063386]);
},
"from":L[543]});
}
++R.GAS;
return $z33843385;
}
};
var $Hand_DASH_oper_DASH_15783357 = function(and_DASH_oper_DASH_1223356,if_helper8783234) {
var anf_if9163403 = R.isBoolean(and_DASH_oper_DASH_1223356);
if(R.isPyretTrue(anf_if9163403)) {
var $z33903391 = D;
var $f33963397 = function(_) {
return R.isFunction(if_helper8783234)?if_helper8783234.app(and_DASH_oper_DASH_1223356):R.ffi.throwNonFunApp(L[530],if_helper8783234,[and_DASH_oper_DASH_1223356]);
};
try {
if(--R.GAS > 0) {
$z33903391 = $f33963397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33963397,
"from":L[530]});
}
} catch($e33883389) {
if(R.isCont($e33883389)) {
var $ss33923393 = {"from":L[530],
"go":function(cont_tail_app9173398) {
return $Hcont_tail_app15773399(cont_tail_app9173398);
}};
$e33883389.stack[R.EXN_STACKHEIGHT++] = $ss33923393;
}
if(R.isPyretException($e33883389)) {
$e33883389.pyretStack.push(L[530]);
}
throw $e33883389;
}
var $ret33943395 = $Hcont_tail_app15773399($z33903391);
++R.GAS;
return $ret33943395;
} else {
var cont_tail_arg9143402 = R.throwNonBooleanOp(L[544],("second"),("and"),and_DASH_oper_DASH_1223356);
if(--R.GAS > 0) {
$z34003401 = R.isFunction(if_helper8783234)?if_helper8783234.app(cont_tail_arg9143402):R.ffi.throwNonFunApp(L[544],if_helper8783234,[cont_tail_arg9143402]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8783234)?if_helper8783234.app(cont_tail_arg9143402):R.ffi.throwNonFunApp(L[544],if_helper8783234,[cont_tail_arg9143402]);
},
"from":L[544]});
}
++R.GAS;
return $z34003401;
}
};
var $Hcont_tail_app15773399 = function(cont_tail_app9173398) {
return cont_tail_app9173398;
};
var $Hann_DASH_check_DASH_temp15763371 = function(ann_DASH_check_DASH_temp9113370) {
return ann_DASH_check_DASH_temp9113370;
};
var $Hcont_tail_app15793383 = function(cont_tail_app9093382) {
return cont_tail_app9093382;
};
var $Hann_DASH_check_DASH_temp15753327 = function(ann_DASH_check_DASH_temp9033326) {
return ann_DASH_check_DASH_temp9033326;
};
var $Hcont_tail_app15813339 = function(cont_tail_app9013338) {
return cont_tail_app9013338;
};
var $Hann_DASH_check_DASH_temp15743249 = function(ann_DASH_check_DASH_temp8953248) {
return ann_DASH_check_DASH_temp8953248;
};
var $Hcont_tail_app15833261 = function(cont_tail_app8933260) {
return cont_tail_app8933260;
};
var $Hand_DASH_oper_DASH_15723279 = function(and_DASH_oper_DASH_1253277,if_helper8803278) {
var anf_if8883419 = R.isBoolean(and_DASH_oper_DASH_1253277);
if(R.isPyretTrue(anf_if8883419)) {
var $z34063407 = D;
var $f34123413 = function(_) {
return R.isFunction(if_helper8803278)?if_helper8803278.app(and_DASH_oper_DASH_1253277):R.ffi.throwNonFunApp(L[536],if_helper8803278,[and_DASH_oper_DASH_1253277]);
};
try {
if(--R.GAS > 0) {
$z34063407 = $f34123413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34123413,
"from":L[536]});
}
} catch($e34043405) {
if(R.isCont($e34043405)) {
var $ss34083409 = {"from":L[536],
"go":function(cont_tail_app8893414) {
return $Hcont_tail_app15713415(cont_tail_app8893414);
}};
$e34043405.stack[R.EXN_STACKHEIGHT++] = $ss34083409;
}
if(R.isPyretException($e34043405)) {
$e34043405.pyretStack.push(L[536]);
}
throw $e34043405;
}
var $ret34103411 = $Hcont_tail_app15713415($z34063407);
++R.GAS;
return $ret34103411;
} else {
var cont_tail_arg8863418 = R.throwNonBooleanOp(L[545],("second"),("and"),and_DASH_oper_DASH_1253277);
if(--R.GAS > 0) {
$z34163417 = R.isFunction(if_helper8803278)?if_helper8803278.app(cont_tail_arg8863418):R.ffi.throwNonFunApp(L[545],if_helper8803278,[cont_tail_arg8863418]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8803278)?if_helper8803278.app(cont_tail_arg8863418):R.ffi.throwNonFunApp(L[545],if_helper8803278,[cont_tail_arg8863418]);
},
"from":L[545]});
}
++R.GAS;
return $z34163417;
}
};
var $Hcont_tail_app15713415 = function(cont_tail_app8893414) {
return cont_tail_app8893414;
};
var $Hcont_tail_app15733291 = function(cont_tail_app8853290) {
return cont_tail_app8853290;
};
var $Hann_DASH_check_DASH_temp15703220 = function(ann_DASH_check_DASH_temp8753219) {
return ann_DASH_check_DASH_temp8753219;
};
var $Hanf_arg15681501 = function(anf_arg8651500,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499,_plus1) {
var $z34223423 = D;
var $f34283429 = function(_) {
return R.isFunction(_plus1)?_plus1.app(anf_arg8651500,cur_DASH_shared7147.$var):R.ffi.throwNonFunApp(L[546],_plus1,[anf_arg8651500,cur_DASH_shared7147.$var]);
};
try {
if(--R.GAS > 0) {
$z34223423 = $f34283429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34283429,
"from":L[546]});
}
} catch($e34203421) {
if(R.isCont($e34203421)) {
var $ss34243425 = {"from":L[546],
"go":function(anf_arg8663430) {
return $Hanf_arg15673431(anf_arg8663430,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499);
}};
$e34203421.stack[R.EXN_STACKHEIGHT++] = $ss34243425;
}
if(R.isPyretException($e34203421)) {
$e34203421.pyretStack.push(L[546]);
}
throw $e34203421;
}
var $ret34263427 = $Hanf_arg15673431($z34223423,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499);
++R.GAS;
return $ret34263427;
};
var $Hanf_arg15673431 = function(anf_arg8663430,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499) {
var $z34343435 = D;
var $f34403441 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(anf_arg8663430):R.ffi.throwNonFunApp(L[547],ensure_DASH_unique_DASH_ids9973.$var,[anf_arg8663430]);
};
try {
if(--R.GAS > 0) {
$z34343435 = $f34403441();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34403441,
"from":L[547]});
}
} catch($e34323433) {
if(R.isCont($e34323433)) {
var $ss34363437 = {"from":L[547],
"go":function(anf_begin_app_dropped15633442) {
return $Hanf_begin_app_dropped15663443(anf_begin_app_dropped15633442,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499);
}};
$e34323433.stack[R.EXN_STACKHEIGHT++] = $ss34363437;
}
if(R.isPyretException($e34323433)) {
$e34323433.pyretStack.push(L[547]);
}
throw $e34323433;
}
var $ret34383439 = $Hanf_begin_app_dropped15663443($z34343435,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499);
++R.GAS;
return $ret34383439;
};
var $Hanf_begin_app_dropped15663443 = function(anf_begin_app_dropped15633442,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3581499) {
var anf_fun8673454 = G(lists1118,"all",L[549]);
var anf_arg8703455 = R.makeFunction(function(recv_DASH_1153458) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[548],1,arguments);
}
var anf_fun8693469 = G(recv_DASH_1153458,"visit",L[548]);
var $z34613462 = D;
var $f34673468 = function(_) {
return R.isFunction(anf_fun8693469)?anf_fun8693469.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[548],anf_fun8693469,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z34613462 = $f34673468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34673468,
"from":L[548]});
}
} catch($e34593460) {
if(R.isCont($e34593460)) {
var $ss34633464 = {"from":L[548],
"go":function(ann_DASH_check_DASH_temp8683470) {
return $Hann_DASH_check_DASH_temp15643471(ann_DASH_check_DASH_temp8683470);
}};
$e34593460.stack[R.EXN_STACKHEIGHT++] = $ss34633464;
}
if(R.isPyretException($e34593460)) {
$e34593460.pyretStack.push(L[548]);
}
throw $e34593460;
}
var $ret34653466 = $Hann_DASH_check_DASH_temp15643471($z34613462);
++R.GAS;
return $ret34653466;
});
var $z34463447 = D;
var $f34523453 = function(_) {
return R.isFunction(anf_fun8673454)?anf_fun8673454.app(anf_arg8703455,with_DASH_members3581499):R.ffi.throwNonFunApp(L[322],anf_fun8673454,[anf_arg8703455,with_DASH_members3581499]);
};
try {
if(--R.GAS > 0) {
$z34463447 = $f34523453();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34523453,
"from":L[322]});
}
} catch($e34443445) {
if(R.isCont($e34443445)) {
var $ss34483449 = {"from":L[322],
"go":function(ann_DASH_check_DASH_temp8643456) {
return $Hann_DASH_check_DASH_temp15653457(ann_DASH_check_DASH_temp8643456);
}};
$e34443445.stack[R.EXN_STACKHEIGHT++] = $ss34483449;
}
if(R.isPyretException($e34443445)) {
$e34443445.pyretStack.push(L[322]);
}
throw $e34443445;
}
var $ret34503451 = $Hann_DASH_check_DASH_temp15653457($z34463447);
++R.GAS;
return $ret34503451;
};
var $Hann_DASH_check_DASH_temp15653457 = function(ann_DASH_check_DASH_temp8643456) {
return ann_DASH_check_DASH_temp8643456;
};
var $Hann_DASH_check_DASH_temp15643471 = function(ann_DASH_check_DASH_temp8683470) {
return ann_DASH_check_DASH_temp8683470;
};
var $Hanf_arg15621518 = function(anf_arg8381516,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1) {
var anf_fun8393482 = G(binds3531517,"map",L[552]);
var anf_arg8413483 = R.makeFunction(function(recv_DASH_1103486) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[551],1,arguments);
}
var ann_DASH_check_DASH_temp8403487 = G(recv_DASH_1103486,"bind",L[551]);
return ann_DASH_check_DASH_temp8403487;
});
var $z34743475 = D;
var $f34803481 = function(_) {
return R.isFunction(anf_fun8393482)?anf_fun8393482.app(anf_arg8413483):R.ffi.throwNonFunApp(L[550],anf_fun8393482,[anf_arg8413483]);
};
try {
if(--R.GAS > 0) {
$z34743475 = $f34803481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34803481,
"from":L[550]});
}
} catch($e34723473) {
if(R.isCont($e34723473)) {
var $ss34763477 = {"from":L[550],
"go":function(anf_arg8423484) {
return $Hanf_arg15613485(anf_arg8423484,anf_arg8381516,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1);
}};
$e34723473.stack[R.EXN_STACKHEIGHT++] = $ss34763477;
}
if(R.isPyretException($e34723473)) {
$e34723473.pyretStack.push(L[550]);
}
throw $e34723473;
}
var $ret34783479 = $Hanf_arg15613485($z34743475,anf_arg8381516,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1);
++R.GAS;
return $ret34783479;
};
var $Hanf_arg15613485 = function(anf_arg8423484,anf_arg8381516,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1) {
var $z34903491 = D;
var $f34963497 = function(_) {
return R.isFunction(_plus1)?_plus1.app(anf_arg8381516,anf_arg8423484):R.ffi.throwNonFunApp(L[553],_plus1,[anf_arg8381516,anf_arg8423484]);
};
try {
if(--R.GAS > 0) {
$z34903491 = $f34963497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34963497,
"from":L[553]});
}
} catch($e34883489) {
if(R.isCont($e34883489)) {
var $ss34923493 = {"from":L[553],
"go":function(anf_arg8433498) {
return $Hanf_arg15603499(anf_arg8433498,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1);
}};
$e34883489.stack[R.EXN_STACKHEIGHT++] = $ss34923493;
}
if(R.isPyretException($e34883489)) {
$e34883489.pyretStack.push(L[553]);
}
throw $e34883489;
}
var $ret34943495 = $Hanf_arg15603499($z34903491,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1);
++R.GAS;
return $ret34943495;
};
var $Hanf_arg15603499 = function(anf_arg8433498,binds3531517,cur_DASH_shared7147,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515,_plus1) {
var $z35023503 = D;
var $f35083509 = function(_) {
return R.isFunction(_plus1)?_plus1.app(anf_arg8433498,cur_DASH_shared7147.$var):R.ffi.throwNonFunApp(L[553],_plus1,[anf_arg8433498,cur_DASH_shared7147.$var]);
};
try {
if(--R.GAS > 0) {
$z35023503 = $f35083509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35083509,
"from":L[553]});
}
} catch($e35003501) {
if(R.isCont($e35003501)) {
var $ss35043505 = {"from":L[553],
"go":function(anf_arg8443510) {
return $Hanf_arg15593511(anf_arg8443510,binds3531517,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515);
}};
$e35003501.stack[R.EXN_STACKHEIGHT++] = $ss35043505;
}
if(R.isPyretException($e35003501)) {
$e35003501.pyretStack.push(L[553]);
}
throw $e35003501;
}
var $ret35063507 = $Hanf_arg15593511($z35023503,binds3531517,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515);
++R.GAS;
return $ret35063507;
};
var $Hanf_arg15593511 = function(anf_arg8443510,binds3531517,ensure_DASH_unique_DASH_ids9973,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515) {
var $z35143515 = D;
var $f35203521 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(anf_arg8443510):R.ffi.throwNonFunApp(L[554],ensure_DASH_unique_DASH_ids9973.$var,[anf_arg8443510]);
};
try {
if(--R.GAS > 0) {
$z35143515 = $f35203521();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35203521,
"from":L[554]});
}
} catch($e35123513) {
if(R.isCont($e35123513)) {
var $ss35163517 = {"from":L[554],
"go":function(anf_begin_app_dropped15513522) {
return $Hanf_begin_app_dropped15583523(anf_begin_app_dropped15513522,binds3531517,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515);
}};
$e35123513.stack[R.EXN_STACKHEIGHT++] = $ss35163517;
}
if(R.isPyretException($e35123513)) {
$e35123513.pyretStack.push(L[554]);
}
throw $e35123513;
}
var $ret35183519 = $Hanf_begin_app_dropped15583523($z35143515,binds3531517,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515);
++R.GAS;
return $ret35183519;
};
var $Hanf_begin_app_dropped15583523 = function(anf_begin_app_dropped15513522,binds3531517,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515) {
var anf_fun8453534 = G(lists1118,"all",L[557]);
var anf_arg8483535 = R.makeFunction(function(recv_DASH_1123538) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[556],1,arguments);
}
var anf_fun8473549 = G(recv_DASH_1123538,"visit",L[556]);
var $z35413542 = D;
var $f35473548 = function(_) {
return R.isFunction(anf_fun8473549)?anf_fun8473549.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[556],anf_fun8473549,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z35413542 = $f35473548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35473548,
"from":L[556]});
}
} catch($e35393540) {
if(R.isCont($e35393540)) {
var $ss35433544 = {"from":L[556],
"go":function(ann_DASH_check_DASH_temp8463550) {
return $Hann_DASH_check_DASH_temp15523551(ann_DASH_check_DASH_temp8463550);
}};
$e35393540.stack[R.EXN_STACKHEIGHT++] = $ss35433544;
}
if(R.isPyretException($e35393540)) {
$e35393540.pyretStack.push(L[556]);
}
throw $e35393540;
}
var $ret35453546 = $Hann_DASH_check_DASH_temp15523551($z35413542);
++R.GAS;
return $ret35453546;
});
var $z35263527 = D;
var $f35323533 = function(_) {
return R.isFunction(anf_fun8453534)?anf_fun8453534.app(anf_arg8483535,binds3531517):R.ffi.throwNonFunApp(L[555],anf_fun8453534,[anf_arg8483535,binds3531517]);
};
try {
if(--R.GAS > 0) {
$z35263527 = $f35323533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35323533,
"from":L[555]});
}
} catch($e35243525) {
if(R.isCont($e35243525)) {
var $ss35283529 = {"from":L[555],
"go":function(and_DASH_oper_DASH_1113536) {
return $Hand_DASH_oper_DASH_15573537(and_DASH_oper_DASH_1113536,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515);
}};
$e35243525.stack[R.EXN_STACKHEIGHT++] = $ss35283529;
}
if(R.isPyretException($e35243525)) {
$e35243525.pyretStack.push(L[555]);
}
throw $e35243525;
}
var $ret35303531 = $Hand_DASH_oper_DASH_15573537($z35263527,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515);
++R.GAS;
return $ret35303531;
};
var $Hand_DASH_oper_DASH_15573537 = function(and_DASH_oper_DASH_1113536,lists1118,well_DASH_formed_DASH_visitor183217,with_DASH_members3541515) {
var if_helper8493565 = R.makeFunction(function(if_helper_arg8503597) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[555],1,arguments);
}
var ann_DASH_check_DASH_temp8373598 = if_helper_arg8503597;
return ann_DASH_check_DASH_temp8373598;
});
var anf_if8533596 = R.isBoolean(and_DASH_oper_DASH_1113536);
if(R.isPyretTrue(anf_if8533596)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1113536)) {
var anf_fun8553562 = G(lists1118,"all",L[559]);
var anf_arg8583563 = R.makeFunction(function(recv_DASH_1143567) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[558],1,arguments);
}
var anf_fun8573578 = G(recv_DASH_1143567,"visit",L[558]);
var $z35703571 = D;
var $f35763577 = function(_) {
return R.isFunction(anf_fun8573578)?anf_fun8573578.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[558],anf_fun8573578,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z35703571 = $f35763577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35763577,
"from":L[558]});
}
} catch($e35683569) {
if(R.isCont($e35683569)) {
var $ss35723573 = {"from":L[558],
"go":function(ann_DASH_check_DASH_temp8563579) {
return $Hann_DASH_check_DASH_temp15533580(ann_DASH_check_DASH_temp8563579);
}};
$e35683569.stack[R.EXN_STACKHEIGHT++] = $ss35723573;
}
if(R.isPyretException($e35683569)) {
$e35683569.pyretStack.push(L[558]);
}
throw $e35683569;
}
var $ret35743575 = $Hann_DASH_check_DASH_temp15533580($z35703571);
++R.GAS;
return $ret35743575;
});
var $z35543555 = D;
var $f35603561 = function(_) {
return R.isFunction(anf_fun8553562)?anf_fun8553562.app(anf_arg8583563,with_DASH_members3541515):R.ffi.throwNonFunApp(L[555],anf_fun8553562,[anf_arg8583563,with_DASH_members3541515]);
};
try {
if(--R.GAS > 0) {
$z35543555 = $f35603561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35603561,
"from":L[555]});
}
} catch($e35523553) {
if(R.isCont($e35523553)) {
var $ss35563557 = {"from":L[555],
"go":function(and_DASH_oper_DASH_1133564) {
return $Hand_DASH_oper_DASH_15553566(and_DASH_oper_DASH_1133564,if_helper8493565);
}};
$e35523553.stack[R.EXN_STACKHEIGHT++] = $ss35563557;
}
if(R.isPyretException($e35523553)) {
$e35523553.pyretStack.push(L[555]);
}
throw $e35523553;
}
var $ret35583559 = $Hand_DASH_oper_DASH_15553566($z35543555,if_helper8493565);
++R.GAS;
return $ret35583559;
} else {
var $z35833584 = D;
var $f35893590 = function(_) {
return R.isFunction(if_helper8493565)?if_helper8493565.app((false)):R.ffi.throwNonFunApp(L[555],if_helper8493565,[(false)]);
};
try {
if(--R.GAS > 0) {
$z35833584 = $f35893590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35893590,
"from":L[555]});
}
} catch($e35813582) {
if(R.isCont($e35813582)) {
var $ss35853586 = {"from":L[555],
"go":function(cont_tail_app8543591) {
return $Hcont_tail_app15563592(cont_tail_app8543591);
}};
$e35813582.stack[R.EXN_STACKHEIGHT++] = $ss35853586;
}
if(R.isPyretException($e35813582)) {
$e35813582.pyretStack.push(L[555]);
}
throw $e35813582;
}
var $ret35873588 = $Hcont_tail_app15563592($z35833584);
++R.GAS;
return $ret35873588;
}
} else {
var cont_tail_arg8513595 = R.throwNonBooleanOp(L[560],("first"),("and"),and_DASH_oper_DASH_1113536);
if(--R.GAS > 0) {
$z35933594 = R.isFunction(if_helper8493565)?if_helper8493565.app(cont_tail_arg8513595):R.ffi.throwNonFunApp(L[560],if_helper8493565,[cont_tail_arg8513595]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8493565)?if_helper8493565.app(cont_tail_arg8513595):R.ffi.throwNonFunApp(L[560],if_helper8493565,[cont_tail_arg8513595]);
},
"from":L[560]});
}
++R.GAS;
return $z35933594;
}
};
var $Hand_DASH_oper_DASH_15553566 = function(and_DASH_oper_DASH_1133564,if_helper8493565) {
var anf_if8613614 = R.isBoolean(and_DASH_oper_DASH_1133564);
if(R.isPyretTrue(anf_if8613614)) {
var $z36013602 = D;
var $f36073608 = function(_) {
return R.isFunction(if_helper8493565)?if_helper8493565.app(and_DASH_oper_DASH_1133564):R.ffi.throwNonFunApp(L[555],if_helper8493565,[and_DASH_oper_DASH_1133564]);
};
try {
if(--R.GAS > 0) {
$z36013602 = $f36073608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36073608,
"from":L[555]});
}
} catch($e35993600) {
if(R.isCont($e35993600)) {
var $ss36033604 = {"from":L[555],
"go":function(cont_tail_app8623609) {
return $Hcont_tail_app15543610(cont_tail_app8623609);
}};
$e35993600.stack[R.EXN_STACKHEIGHT++] = $ss36033604;
}
if(R.isPyretException($e35993600)) {
$e35993600.pyretStack.push(L[555]);
}
throw $e35993600;
}
var $ret36053606 = $Hcont_tail_app15543610($z36013602);
++R.GAS;
return $ret36053606;
} else {
var cont_tail_arg8593613 = R.throwNonBooleanOp(L[561],("second"),("and"),and_DASH_oper_DASH_1133564);
if(--R.GAS > 0) {
$z36113612 = R.isFunction(if_helper8493565)?if_helper8493565.app(cont_tail_arg8593613):R.ffi.throwNonFunApp(L[561],if_helper8493565,[cont_tail_arg8593613]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8493565)?if_helper8493565.app(cont_tail_arg8593613):R.ffi.throwNonFunApp(L[561],if_helper8493565,[cont_tail_arg8593613]);
},
"from":L[561]});
}
++R.GAS;
return $z36113612;
}
};
var $Hcont_tail_app15543610 = function(cont_tail_app8623609) {
return cont_tail_app8623609;
};
var $Hann_DASH_check_DASH_temp15533580 = function(ann_DASH_check_DASH_temp8563579) {
return ann_DASH_check_DASH_temp8563579;
};
var $Hcont_tail_app15563592 = function(cont_tail_app8543591) {
return cont_tail_app8543591;
};
var $Hann_DASH_check_DASH_temp15523551 = function(ann_DASH_check_DASH_temp8463550) {
return ann_DASH_check_DASH_temp8463550;
};
var $Hann_DASH_check_DASH_temp15501540 = function(ann_DASH_check_DASH_temp8321539) {
return ann_DASH_check_DASH_temp8321539;
};
var $Hand_DASH_oper_DASH_15491560 = function(and_DASH_oper_DASH_1071558,body3401559,well_DASH_formed_DASH_visitor183217) {
var if_helper8203627 = R.makeFunction(function(if_helper_arg8213645) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[328],1,arguments);
}
var ann_DASH_check_DASH_temp8153646 = if_helper_arg8213645;
return ann_DASH_check_DASH_temp8153646;
});
var anf_if8243644 = R.isBoolean(and_DASH_oper_DASH_1071558);
if(R.isPyretTrue(anf_if8243644)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1071558)) {
var anf_fun8263625 = G(body3401559,"visit",L[562]);
var $z36173618 = D;
var $f36233624 = function(_) {
return R.isFunction(anf_fun8263625)?anf_fun8263625.app(well_DASH_formed_DASH_visitor183217):R.ffi.throwNonFunApp(L[328],anf_fun8263625,[well_DASH_formed_DASH_visitor183217]);
};
try {
if(--R.GAS > 0) {
$z36173618 = $f36233624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36233624,
"from":L[328]});
}
} catch($e36153616) {
if(R.isCont($e36153616)) {
var $ss36193620 = {"from":L[328],
"go":function(and_DASH_oper_DASH_1093626) {
return $Hand_DASH_oper_DASH_15473628(and_DASH_oper_DASH_1093626,if_helper8203627);
}};
$e36153616.stack[R.EXN_STACKHEIGHT++] = $ss36193620;
}
if(R.isPyretException($e36153616)) {
$e36153616.pyretStack.push(L[328]);
}
throw $e36153616;
}
var $ret36213622 = $Hand_DASH_oper_DASH_15473628($z36173618,if_helper8203627);
++R.GAS;
return $ret36213622;
} else {
var $z36313632 = D;
var $f36373638 = function(_) {
return R.isFunction(if_helper8203627)?if_helper8203627.app((false)):R.ffi.throwNonFunApp(L[328],if_helper8203627,[(false)]);
};
try {
if(--R.GAS > 0) {
$z36313632 = $f36373638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36373638,
"from":L[328]});
}
} catch($e36293630) {
if(R.isCont($e36293630)) {
var $ss36333634 = {"from":L[328],
"go":function(cont_tail_app8253639) {
return $Hcont_tail_app15483640(cont_tail_app8253639);
}};
$e36293630.stack[R.EXN_STACKHEIGHT++] = $ss36333634;
}
if(R.isPyretException($e36293630)) {
$e36293630.pyretStack.push(L[328]);
}
throw $e36293630;
}
var $ret36353636 = $Hcont_tail_app15483640($z36313632);
++R.GAS;
return $ret36353636;
}
} else {
var cont_tail_arg8223643 = R.throwNonBooleanOp(L[563],("first"),("and"),and_DASH_oper_DASH_1071558);
if(--R.GAS > 0) {
$z36413642 = R.isFunction(if_helper8203627)?if_helper8203627.app(cont_tail_arg8223643):R.ffi.throwNonFunApp(L[563],if_helper8203627,[cont_tail_arg8223643]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8203627)?if_helper8203627.app(cont_tail_arg8223643):R.ffi.throwNonFunApp(L[563],if_helper8203627,[cont_tail_arg8223643]);
},
"from":L[563]});
}
++R.GAS;
return $z36413642;
}
};
var $Hand_DASH_oper_DASH_15473628 = function(and_DASH_oper_DASH_1093626,if_helper8203627) {
var anf_if8293662 = R.isBoolean(and_DASH_oper_DASH_1093626);
if(R.isPyretTrue(anf_if8293662)) {
var $z36493650 = D;
var $f36553656 = function(_) {
return R.isFunction(if_helper8203627)?if_helper8203627.app(and_DASH_oper_DASH_1093626):R.ffi.throwNonFunApp(L[328],if_helper8203627,[and_DASH_oper_DASH_1093626]);
};
try {
if(--R.GAS > 0) {
$z36493650 = $f36553656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36553656,
"from":L[328]});
}
} catch($e36473648) {
if(R.isCont($e36473648)) {
var $ss36513652 = {"from":L[328],
"go":function(cont_tail_app8303657) {
return $Hcont_tail_app15463658(cont_tail_app8303657);
}};
$e36473648.stack[R.EXN_STACKHEIGHT++] = $ss36513652;
}
if(R.isPyretException($e36473648)) {
$e36473648.pyretStack.push(L[328]);
}
throw $e36473648;
}
var $ret36533654 = $Hcont_tail_app15463658($z36493650);
++R.GAS;
return $ret36533654;
} else {
var cont_tail_arg8273661 = R.throwNonBooleanOp(L[564],("second"),("and"),and_DASH_oper_DASH_1093626);
if(--R.GAS > 0) {
$z36593660 = R.isFunction(if_helper8203627)?if_helper8203627.app(cont_tail_arg8273661):R.ffi.throwNonFunApp(L[564],if_helper8203627,[cont_tail_arg8273661]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper8203627)?if_helper8203627.app(cont_tail_arg8273661):R.ffi.throwNonFunApp(L[564],if_helper8203627,[cont_tail_arg8273661]);
},
"from":L[564]});
}
++R.GAS;
return $z36593660;
}
};
var $Hcont_tail_app15463658 = function(cont_tail_app8303657) {
return cont_tail_app8303657;
};
var $Hcont_tail_app15483640 = function(cont_tail_app8253639) {
return cont_tail_app8253639;
};
var $Hann_DASH_check_DASH_temp15451575 = function(ann_DASH_check_DASH_temp8171574) {
return ann_DASH_check_DASH_temp8171574;
};
var $Hann_DASH_check_DASH_temp15441594 = function(ann_DASH_check_DASH_temp8101593) {
return ann_DASH_check_DASH_temp8101593;
};
var $Hok_DASH_body15431617 = function(ok_DASH_body3261612,_provide_DASH_types3231613,_provide3221614,imports3241615,lists1118,self3201616) {
var and_DASH_oper_DASH_1023689 = ok_DASH_body3261612;
var if_helper7853675 = R.makeFunction(function(if_helper_arg7863694) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[565],1,arguments);
}
var ann_DASH_check_DASH_temp7733695 = if_helper_arg7863694;
return ann_DASH_check_DASH_temp7733695;
});
var anf_if7893693 = R.isBoolean(and_DASH_oper_DASH_1023689);
if(R.isPyretTrue(anf_if7893693)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1023689)) {
var anf_fun7913673 = G(_provide3221614,"visit",L[566]);
var $z36653666 = D;
var $f36713672 = function(_) {
return R.isFunction(anf_fun7913673)?anf_fun7913673.app(self3201616):R.ffi.throwNonFunApp(L[565],anf_fun7913673,[self3201616]);
};
try {
if(--R.GAS > 0) {
$z36653666 = $f36713672();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36713672,
"from":L[565]});
}
} catch($e36633664) {
if(R.isCont($e36633664)) {
var $ss36673668 = {"from":L[565],
"go":function(and_DASH_oper_DASH_1033674) {
return $Hand_DASH_oper_DASH_15413676(and_DASH_oper_DASH_1033674,_provide_DASH_types3231613,if_helper7853675,imports3241615,lists1118,self3201616);
}};
$e36633664.stack[R.EXN_STACKHEIGHT++] = $ss36673668;
}
if(R.isPyretException($e36633664)) {
$e36633664.pyretStack.push(L[565]);
}
throw $e36633664;
}
var $ret36693670 = $Hand_DASH_oper_DASH_15413676($z36653666,_provide_DASH_types3231613,if_helper7853675,imports3241615,lists1118,self3201616);
++R.GAS;
return $ret36693670;
} else {
var $z36793680 = D;
var $f36853686 = function(_) {
return R.isFunction(if_helper7853675)?if_helper7853675.app((false)):R.ffi.throwNonFunApp(L[565],if_helper7853675,[(false)]);
};
try {
if(--R.GAS > 0) {
$z36793680 = $f36853686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36853686,
"from":L[565]});
}
} catch($e36773678) {
if(R.isCont($e36773678)) {
var $ss36813682 = {"from":L[565],
"go":function(cont_tail_app7903687) {
return $Hcont_tail_app15423688(cont_tail_app7903687);
}};
$e36773678.stack[R.EXN_STACKHEIGHT++] = $ss36813682;
}
if(R.isPyretException($e36773678)) {
$e36773678.pyretStack.push(L[565]);
}
throw $e36773678;
}
var $ret36833684 = $Hcont_tail_app15423688($z36793680);
++R.GAS;
return $ret36833684;
}
} else {
var cont_tail_arg7873692 = R.throwNonBooleanOp(L[567],("first"),("and"),and_DASH_oper_DASH_1023689);
if(--R.GAS > 0) {
$z36903691 = R.isFunction(if_helper7853675)?if_helper7853675.app(cont_tail_arg7873692):R.ffi.throwNonFunApp(L[567],if_helper7853675,[cont_tail_arg7873692]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7853675)?if_helper7853675.app(cont_tail_arg7873692):R.ffi.throwNonFunApp(L[567],if_helper7853675,[cont_tail_arg7873692]);
},
"from":L[567]});
}
++R.GAS;
return $z36903691;
}
};
var $Hand_DASH_oper_DASH_15413676 = function(and_DASH_oper_DASH_1033674,_provide_DASH_types3231613,if_helper7853675,imports3241615,lists1118,self3201616) {
var anf_if7943724 = R.isBoolean(and_DASH_oper_DASH_1033674);
if(R.isPyretTrue(anf_if7943724)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1033674)) {
var anf_fun7963706 = G(_provide_DASH_types3231613,"visit",L[568]);
var $z36983699 = D;
var $f37043705 = function(_) {
return R.isFunction(anf_fun7963706)?anf_fun7963706.app(self3201616):R.ffi.throwNonFunApp(L[565],anf_fun7963706,[self3201616]);
};
try {
if(--R.GAS > 0) {
$z36983699 = $f37043705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37043705,
"from":L[565]});
}
} catch($e36963697) {
if(R.isCont($e36963697)) {
var $ss37003701 = {"from":L[565],
"go":function(and_DASH_oper_DASH_1043707) {
return $Hand_DASH_oper_DASH_15393708(and_DASH_oper_DASH_1043707,if_helper7853675,imports3241615,lists1118,self3201616);
}};
$e36963697.stack[R.EXN_STACKHEIGHT++] = $ss37003701;
}
if(R.isPyretException($e36963697)) {
$e36963697.pyretStack.push(L[565]);
}
throw $e36963697;
}
var $ret37023703 = $Hand_DASH_oper_DASH_15393708($z36983699,if_helper7853675,imports3241615,lists1118,self3201616);
++R.GAS;
return $ret37023703;
} else {
var $z37113712 = D;
var $f37173718 = function(_) {
return R.isFunction(if_helper7853675)?if_helper7853675.app((false)):R.ffi.throwNonFunApp(L[565],if_helper7853675,[(false)]);
};
try {
if(--R.GAS > 0) {
$z37113712 = $f37173718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37173718,
"from":L[565]});
}
} catch($e37093710) {
if(R.isCont($e37093710)) {
var $ss37133714 = {"from":L[565],
"go":function(cont_tail_app7953719) {
return $Hcont_tail_app15403720(cont_tail_app7953719);
}};
$e37093710.stack[R.EXN_STACKHEIGHT++] = $ss37133714;
}
if(R.isPyretException($e37093710)) {
$e37093710.pyretStack.push(L[565]);
}
throw $e37093710;
}
var $ret37153716 = $Hcont_tail_app15403720($z37113712);
++R.GAS;
return $ret37153716;
}
} else {
var cont_tail_arg7923723 = R.throwNonBooleanOp(L[569],("first"),("and"),and_DASH_oper_DASH_1033674);
if(--R.GAS > 0) {
$z37213722 = R.isFunction(if_helper7853675)?if_helper7853675.app(cont_tail_arg7923723):R.ffi.throwNonFunApp(L[569],if_helper7853675,[cont_tail_arg7923723]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7853675)?if_helper7853675.app(cont_tail_arg7923723):R.ffi.throwNonFunApp(L[569],if_helper7853675,[cont_tail_arg7923723]);
},
"from":L[569]});
}
++R.GAS;
return $z37213722;
}
};
var $Hand_DASH_oper_DASH_15393708 = function(and_DASH_oper_DASH_1043707,if_helper7853675,imports3241615,lists1118,self3201616) {
var anf_if7993768 = R.isBoolean(and_DASH_oper_DASH_1043707);
if(R.isPyretTrue(anf_if7993768)) {
if(R.isPyretTrue(and_DASH_oper_DASH_1043707)) {
var anf_fun8013735 = G(lists1118,"all",L[571]);
var anf_arg8043736 = R.makeFunction(function(recv_DASH_1063739) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[570],1,arguments);
}
var anf_fun8033750 = G(recv_DASH_1063739,"visit",L[570]);
var $z37423743 = D;
var $f37483749 = function(_) {
return R.isFunction(anf_fun8033750)?anf_fun8033750.app(self3201616):R.ffi.throwNonFunApp(L[570],anf_fun8033750,[self3201616]);
};
try {
if(--R.GAS > 0) {
$z37423743 = $f37483749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37483749,
"from":L[570]});
}
} catch($e37403741) {
if(R.isCont($e37403741)) {
var $ss37443745 = {"from":L[570],
"go":function(ann_DASH_check_DASH_temp8023751) {
return $Hann_DASH_check_DASH_temp15353752(ann_DASH_check_DASH_temp8023751);
}};
$e37403741.stack[R.EXN_STACKHEIGHT++] = $ss37443745;
}
if(R.isPyretException($e37403741)) {
$e37403741.pyretStack.push(L[570]);
}
throw $e37403741;
}
var $ret37463747 = $Hann_DASH_check_DASH_temp15353752($z37423743);
++R.GAS;
return $ret37463747;
});
var $z37273728 = D;
var $f37333734 = function(_) {
return R.isFunction(anf_fun8013735)?anf_fun8013735.app(anf_arg8043736,imports3241615):R.ffi.throwNonFunApp(L[565],anf_fun8013735,[anf_arg8043736,imports3241615]);
};
try {
if(--R.GAS > 0) {
$z37273728 = $f37333734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37333734,
"from":L[565]});
}
} catch($e37253726) {
if(R.isCont($e37253726)) {
var $ss37293730 = {"from":L[565],
"go":function(and_DASH_oper_DASH_1053737) {
return $Hand_DASH_oper_DASH_15373738(and_DASH_oper_DASH_1053737,if_helper7853675);
}};
$e37253726.stack[R.EXN_STACKHEIGHT++] = $ss37293730;
}
if(R.isPyretException($e37253726)) {
$e37253726.pyretStack.push(L[565]);
}
throw $e37253726;
}
var $ret37313732 = $Hand_DASH_oper_DASH_15373738($z37273728,if_helper7853675);
++R.GAS;
return $ret37313732;
} else {
var $z37553756 = D;
var $f37613762 = function(_) {
return R.isFunction(if_helper7853675)?if_helper7853675.app((false)):R.ffi.throwNonFunApp(L[565],if_helper7853675,[(false)]);
};
try {
if(--R.GAS > 0) {
$z37553756 = $f37613762();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37613762,
"from":L[565]});
}
} catch($e37533754) {
if(R.isCont($e37533754)) {
var $ss37573758 = {"from":L[565],
"go":function(cont_tail_app8003763) {
return $Hcont_tail_app15383764(cont_tail_app8003763);
}};
$e37533754.stack[R.EXN_STACKHEIGHT++] = $ss37573758;
}
if(R.isPyretException($e37533754)) {
$e37533754.pyretStack.push(L[565]);
}
throw $e37533754;
}
var $ret37593760 = $Hcont_tail_app15383764($z37553756);
++R.GAS;
return $ret37593760;
}
} else {
var cont_tail_arg7973767 = R.throwNonBooleanOp(L[572],("first"),("and"),and_DASH_oper_DASH_1043707);
if(--R.GAS > 0) {
$z37653766 = R.isFunction(if_helper7853675)?if_helper7853675.app(cont_tail_arg7973767):R.ffi.throwNonFunApp(L[572],if_helper7853675,[cont_tail_arg7973767]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7853675)?if_helper7853675.app(cont_tail_arg7973767):R.ffi.throwNonFunApp(L[572],if_helper7853675,[cont_tail_arg7973767]);
},
"from":L[572]});
}
++R.GAS;
return $z37653766;
}
};
var $Hand_DASH_oper_DASH_15373738 = function(and_DASH_oper_DASH_1053737,if_helper7853675) {
var anf_if8073784 = R.isBoolean(and_DASH_oper_DASH_1053737);
if(R.isPyretTrue(anf_if8073784)) {
var $z37713772 = D;
var $f37773778 = function(_) {
return R.isFunction(if_helper7853675)?if_helper7853675.app(and_DASH_oper_DASH_1053737):R.ffi.throwNonFunApp(L[565],if_helper7853675,[and_DASH_oper_DASH_1053737]);
};
try {
if(--R.GAS > 0) {
$z37713772 = $f37773778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37773778,
"from":L[565]});
}
} catch($e37693770) {
if(R.isCont($e37693770)) {
var $ss37733774 = {"from":L[565],
"go":function(cont_tail_app8083779) {
return $Hcont_tail_app15363780(cont_tail_app8083779);
}};
$e37693770.stack[R.EXN_STACKHEIGHT++] = $ss37733774;
}
if(R.isPyretException($e37693770)) {
$e37693770.pyretStack.push(L[565]);
}
throw $e37693770;
}
var $ret37753776 = $Hcont_tail_app15363780($z37713772);
++R.GAS;
return $ret37753776;
} else {
var cont_tail_arg8053783 = R.throwNonBooleanOp(L[573],("second"),("and"),and_DASH_oper_DASH_1053737);
if(--R.GAS > 0) {
$z37813782 = R.isFunction(if_helper7853675)?if_helper7853675.app(cont_tail_arg8053783):R.ffi.throwNonFunApp(L[573],if_helper7853675,[cont_tail_arg8053783]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7853675)?if_helper7853675.app(cont_tail_arg8053783):R.ffi.throwNonFunApp(L[573],if_helper7853675,[cont_tail_arg8053783]);
},
"from":L[573]});
}
++R.GAS;
return $z37813782;
}
};
var $Hcont_tail_app15363780 = function(cont_tail_app8083779) {
return cont_tail_app8083779;
};
var $Hann_DASH_check_DASH_temp15353752 = function(ann_DASH_check_DASH_temp8023751) {
return ann_DASH_check_DASH_temp8023751;
};
var $Hcont_tail_app15383764 = function(cont_tail_app8003763) {
return cont_tail_app8003763;
};
var $Hcont_tail_app15403720 = function(cont_tail_app7953719) {
return cont_tail_app7953719;
};
var $Hcont_tail_app15423688 = function(cont_tail_app7903687) {
return cont_tail_app7903687;
};
var $Hann_DASH_check_DASH_temp15341630 = function(ann_DASH_check_DASH_temp7821629) {
return ann_DASH_check_DASH_temp7821629;
};
var $Hann_DASH_check_DASH_temp15331648 = function(ann_DASH_check_DASH_temp7751647) {
return ann_DASH_check_DASH_temp7751647;
};
var $Hann_DASH_check_DASH_temp15321662 = function(ann_DASH_check_DASH_temp7771661) {
return ann_DASH_check_DASH_temp7771661;
};
var $Hanf_arg15311704 = function(anf_arg7621701,anf_fun7611702,id3181700,l3171703,reserved_DASH_name7965,nothing4,tostring10) {
var $z37873788 = D;
var $f37933794 = function(_) {
return R.isFunction(anf_fun7611702)?anf_fun7611702.app(anf_arg7621701):R.ffi.throwNonFunApp(L[574],anf_fun7611702,[anf_arg7621701]);
};
try {
if(--R.GAS > 0) {
$z37873788 = $f37933794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37933794,
"from":L[574]});
}
} catch($e37853786) {
if(R.isCont($e37853786)) {
var $ss37893790 = {"from":L[574],
"go":function(when_DASH_993795) {
return $Hwhen_DASH_15303796(when_DASH_993795,id3181700,l3171703,reserved_DASH_name7965,nothing4,tostring10);
}};
$e37853786.stack[R.EXN_STACKHEIGHT++] = $ss37893790;
}
if(R.isPyretException($e37853786)) {
$e37853786.pyretStack.push(L[574]);
}
throw $e37853786;
}
var $ret37913792 = $Hwhen_DASH_15303796($z37873788,id3181700,l3171703,reserved_DASH_name7965,nothing4,tostring10);
++R.GAS;
return $ret37913792;
};
var $Hwhen_DASH_15303796 = function(when_DASH_993795,id3181700,l3171703,reserved_DASH_name7965,nothing4,tostring10) {
var if_helper7633808 = R.makeFunction(function(if_helper_arg7643826) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[574],1,arguments);
}
if_helper_arg7643826;
var ann_DASH_check_DASH_temp7603827 = (true);
return ann_DASH_check_DASH_temp7603827;
});
var anf_if7673825 = R.isBoolean(when_DASH_993795);
if(R.isPyretTrue(anf_if7673825)) {
if(R.isPyretTrue(when_DASH_993795)) {
var $z37993800 = D;
var $f38053806 = function(_) {
return R.isFunction(tostring10)?tostring10.app(id3181700):R.ffi.throwNonFunApp(L[575],tostring10,[id3181700]);
};
try {
if(--R.GAS > 0) {
$z37993800 = $f38053806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38053806,
"from":L[575]});
}
} catch($e37973798) {
if(R.isCont($e37973798)) {
var $ss38013802 = {"from":L[575],
"go":function(anf_arg7693807) {
return $Hanf_arg15283809(anf_arg7693807,if_helper7633808,l3171703,reserved_DASH_name7965,nothing4);
}};
$e37973798.stack[R.EXN_STACKHEIGHT++] = $ss38013802;
}
if(R.isPyretException($e37973798)) {
$e37973798.pyretStack.push(L[575]);
}
throw $e37973798;
}
var $ret38033804 = $Hanf_arg15283809($z37993800,if_helper7633808,l3171703,reserved_DASH_name7965,nothing4);
++R.GAS;
return $ret38033804;
} else {
var $z38123813 = D;
var $f38183819 = function(_) {
return R.isFunction(if_helper7633808)?if_helper7633808.app(nothing4):R.ffi.throwNonFunApp(L[574],if_helper7633808,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z38123813 = $f38183819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38183819,
"from":L[574]});
}
} catch($e38103811) {
if(R.isCont($e38103811)) {
var $ss38143815 = {"from":L[574],
"go":function(cont_tail_app7683820) {
return $Hcont_tail_app15293821(cont_tail_app7683820);
}};
$e38103811.stack[R.EXN_STACKHEIGHT++] = $ss38143815;
}
if(R.isPyretException($e38103811)) {
$e38103811.pyretStack.push(L[574]);
}
throw $e38103811;
}
var $ret38163817 = $Hcont_tail_app15293821($z38123813);
++R.GAS;
return $ret38163817;
}
} else {
var cont_tail_arg7653824 = R.throwNonBooleanCondition(L[576],("when"),when_DASH_993795);
if(--R.GAS > 0) {
$z38223823 = R.isFunction(if_helper7633808)?if_helper7633808.app(cont_tail_arg7653824):R.ffi.throwNonFunApp(L[576],if_helper7633808,[cont_tail_arg7653824]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7633808)?if_helper7633808.app(cont_tail_arg7653824):R.ffi.throwNonFunApp(L[576],if_helper7633808,[cont_tail_arg7653824]);
},
"from":L[576]});
}
++R.GAS;
return $z38223823;
}
};
var $Hanf_arg15283809 = function(anf_arg7693807,if_helper7633808,l3171703,reserved_DASH_name7965,nothing4) {
var $z38303831 = D;
var $f38363837 = function(_) {
return R.isFunction(reserved_DASH_name7965.$var)?reserved_DASH_name7965.$var.app(l3171703,anf_arg7693807):R.ffi.throwNonFunApp(L[577],reserved_DASH_name7965.$var,[l3171703,anf_arg7693807]);
};
try {
if(--R.GAS > 0) {
$z38303831 = $f38363837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38363837,
"from":L[577]});
}
} catch($e38283829) {
if(R.isCont($e38283829)) {
var $ss38323833 = {"from":L[577],
"go":function(anf_begin_app_dropped15253838) {
return $Hanf_begin_app_dropped15273839(anf_begin_app_dropped15253838,if_helper7633808,nothing4);
}};
$e38283829.stack[R.EXN_STACKHEIGHT++] = $ss38323833;
}
if(R.isPyretException($e38283829)) {
$e38283829.pyretStack.push(L[577]);
}
throw $e38283829;
}
var $ret38343835 = $Hanf_begin_app_dropped15273839($z38303831,if_helper7633808,nothing4);
++R.GAS;
return $ret38343835;
};
var $Hanf_begin_app_dropped15273839 = function(anf_begin_app_dropped15253838,if_helper7633808,nothing4) {
var $z38423843 = D;
var $f38483849 = function(_) {
return R.isFunction(if_helper7633808)?if_helper7633808.app(nothing4):R.ffi.throwNonFunApp(L[574],if_helper7633808,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z38423843 = $f38483849();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38483849,
"from":L[574]});
}
} catch($e38403841) {
if(R.isCont($e38403841)) {
var $ss38443845 = {"from":L[574],
"go":function(cont_tail_app7703850) {
return $Hcont_tail_app15263851(cont_tail_app7703850);
}};
$e38403841.stack[R.EXN_STACKHEIGHT++] = $ss38443845;
}
if(R.isPyretException($e38403841)) {
$e38403841.pyretStack.push(L[574]);
}
throw $e38403841;
}
var $ret38463847 = $Hcont_tail_app15263851($z38423843);
++R.GAS;
return $ret38463847;
};
var $Hcont_tail_app15263851 = function(cont_tail_app7703850) {
return cont_tail_app7703850;
};
var $Hcont_tail_app15293821 = function(cont_tail_app7683820) {
return cont_tail_app7683820;
};
var $Hanf_arg15231721 = function(anf_arg7571719,add_DASH_error7557,if_helper7501720,nothing4) {
var $z38543855 = D;
var $f38603861 = function(_) {
return R.isFunction(add_DASH_error7557.$var)?add_DASH_error7557.$var.app(anf_arg7571719):R.ffi.throwNonFunApp(L[578],add_DASH_error7557.$var,[anf_arg7571719]);
};
try {
if(--R.GAS > 0) {
$z38543855 = $f38603861();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38603861,
"from":L[578]});
}
} catch($e38523853) {
if(R.isCont($e38523853)) {
var $ss38563857 = {"from":L[578],
"go":function(anf_begin_app_dropped15203862) {
return $Hanf_begin_app_dropped15223863(anf_begin_app_dropped15203862,if_helper7501720,nothing4);
}};
$e38523853.stack[R.EXN_STACKHEIGHT++] = $ss38563857;
}
if(R.isPyretException($e38523853)) {
$e38523853.pyretStack.push(L[578]);
}
throw $e38523853;
}
var $ret38583859 = $Hanf_begin_app_dropped15223863($z38543855,if_helper7501720,nothing4);
++R.GAS;
return $ret38583859;
};
var $Hanf_begin_app_dropped15223863 = function(anf_begin_app_dropped15203862,if_helper7501720,nothing4) {
var $z38663867 = D;
var $f38723873 = function(_) {
return R.isFunction(if_helper7501720)?if_helper7501720.app(nothing4):R.ffi.throwNonFunApp(L[348],if_helper7501720,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z38663867 = $f38723873();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38723873,
"from":L[348]});
}
} catch($e38643865) {
if(R.isCont($e38643865)) {
var $ss38683869 = {"from":L[348],
"go":function(cont_tail_app7583874) {
return $Hcont_tail_app15213875(cont_tail_app7583874);
}};
$e38643865.stack[R.EXN_STACKHEIGHT++] = $ss38683869;
}
if(R.isPyretException($e38643865)) {
$e38643865.pyretStack.push(L[348]);
}
throw $e38643865;
}
var $ret38703871 = $Hcont_tail_app15213875($z38663867);
++R.GAS;
return $ret38703871;
};
var $Hcont_tail_app15213875 = function(cont_tail_app7583874) {
return cont_tail_app7583874;
};
var $Hcont_tail_app15241733 = function(cont_tail_app7551732) {
return cont_tail_app7551732;
};
var $Hanf_begin_app_dropped15191760 = function(anf_begin_app_dropped15091755,_else3111756,branches3101754,lists1118,self3061757,typ3081758,val3091759) {
var anf_fun7233886 = G(typ3081758,"visit",L[580]);
var $z38783879 = D;
var $f38843885 = function(_) {
return R.isFunction(anf_fun7233886)?anf_fun7233886.app(self3061757):R.ffi.throwNonFunApp(L[579],anf_fun7233886,[self3061757]);
};
try {
if(--R.GAS > 0) {
$z38783879 = $f38843885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38843885,
"from":L[579]});
}
} catch($e38763877) {
if(R.isCont($e38763877)) {
var $ss38803881 = {"from":L[579],
"go":function(and_DASH_oper_DASH_933887) {
return $Hand_DASH_oper_DASH_15183888(and_DASH_oper_DASH_933887,_else3111756,branches3101754,lists1118,self3061757,val3091759);
}};
$e38763877.stack[R.EXN_STACKHEIGHT++] = $ss38803881;
}
if(R.isPyretException($e38763877)) {
$e38763877.pyretStack.push(L[579]);
}
throw $e38763877;
}
var $ret38823883 = $Hand_DASH_oper_DASH_15183888($z38783879,_else3111756,branches3101754,lists1118,self3061757,val3091759);
++R.GAS;
return $ret38823883;
};
var $Hand_DASH_oper_DASH_15183888 = function(and_DASH_oper_DASH_933887,_else3111756,branches3101754,lists1118,self3061757,val3091759) {
var if_helper7243901 = R.makeFunction(function(if_helper_arg7253919) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[579],1,arguments);
}
var ann_DASH_check_DASH_temp7223920 = if_helper_arg7253919;
return ann_DASH_check_DASH_temp7223920;
});
var anf_if7283918 = R.isBoolean(and_DASH_oper_DASH_933887);
if(R.isPyretTrue(anf_if7283918)) {
if(R.isPyretTrue(and_DASH_oper_DASH_933887)) {
var anf_fun7303899 = G(val3091759,"visit",L[581]);
var $z38913892 = D;
var $f38973898 = function(_) {
return R.isFunction(anf_fun7303899)?anf_fun7303899.app(self3061757):R.ffi.throwNonFunApp(L[579],anf_fun7303899,[self3061757]);
};
try {
if(--R.GAS > 0) {
$z38913892 = $f38973898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38973898,
"from":L[579]});
}
} catch($e38893890) {
if(R.isCont($e38893890)) {
var $ss38933894 = {"from":L[579],
"go":function(and_DASH_oper_DASH_943900) {
return $Hand_DASH_oper_DASH_15163902(and_DASH_oper_DASH_943900,_else3111756,branches3101754,if_helper7243901,lists1118,self3061757);
}};
$e38893890.stack[R.EXN_STACKHEIGHT++] = $ss38933894;
}
if(R.isPyretException($e38893890)) {
$e38893890.pyretStack.push(L[579]);
}
throw $e38893890;
}
var $ret38953896 = $Hand_DASH_oper_DASH_15163902($z38913892,_else3111756,branches3101754,if_helper7243901,lists1118,self3061757);
++R.GAS;
return $ret38953896;
} else {
var $z39053906 = D;
var $f39113912 = function(_) {
return R.isFunction(if_helper7243901)?if_helper7243901.app((false)):R.ffi.throwNonFunApp(L[579],if_helper7243901,[(false)]);
};
try {
if(--R.GAS > 0) {
$z39053906 = $f39113912();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39113912,
"from":L[579]});
}
} catch($e39033904) {
if(R.isCont($e39033904)) {
var $ss39073908 = {"from":L[579],
"go":function(cont_tail_app7293913) {
return $Hcont_tail_app15173914(cont_tail_app7293913);
}};
$e39033904.stack[R.EXN_STACKHEIGHT++] = $ss39073908;
}
if(R.isPyretException($e39033904)) {
$e39033904.pyretStack.push(L[579]);
}
throw $e39033904;
}
var $ret39093910 = $Hcont_tail_app15173914($z39053906);
++R.GAS;
return $ret39093910;
}
} else {
var cont_tail_arg7263917 = R.throwNonBooleanOp(L[582],("first"),("and"),and_DASH_oper_DASH_933887);
if(--R.GAS > 0) {
$z39153916 = R.isFunction(if_helper7243901)?if_helper7243901.app(cont_tail_arg7263917):R.ffi.throwNonFunApp(L[582],if_helper7243901,[cont_tail_arg7263917]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7243901)?if_helper7243901.app(cont_tail_arg7263917):R.ffi.throwNonFunApp(L[582],if_helper7243901,[cont_tail_arg7263917]);
},
"from":L[582]});
}
++R.GAS;
return $z39153916;
}
};
var $Hand_DASH_oper_DASH_15163902 = function(and_DASH_oper_DASH_943900,_else3111756,branches3101754,if_helper7243901,lists1118,self3061757) {
var anf_if7333964 = R.isBoolean(and_DASH_oper_DASH_943900);
if(R.isPyretTrue(anf_if7333964)) {
if(R.isPyretTrue(and_DASH_oper_DASH_943900)) {
var anf_fun7353931 = G(lists1118,"all",L[584]);
var anf_arg7383932 = R.makeFunction(function(recv_DASH_963935) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[583],1,arguments);
}
var anf_fun7373946 = G(recv_DASH_963935,"visit",L[583]);
var $z39383939 = D;
var $f39443945 = function(_) {
return R.isFunction(anf_fun7373946)?anf_fun7373946.app(self3061757):R.ffi.throwNonFunApp(L[583],anf_fun7373946,[self3061757]);
};
try {
if(--R.GAS > 0) {
$z39383939 = $f39443945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39443945,
"from":L[583]});
}
} catch($e39363937) {
if(R.isCont($e39363937)) {
var $ss39403941 = {"from":L[583],
"go":function(ann_DASH_check_DASH_temp7363947) {
return $Hann_DASH_check_DASH_temp15103948(ann_DASH_check_DASH_temp7363947);
}};
$e39363937.stack[R.EXN_STACKHEIGHT++] = $ss39403941;
}
if(R.isPyretException($e39363937)) {
$e39363937.pyretStack.push(L[583]);
}
throw $e39363937;
}
var $ret39423943 = $Hann_DASH_check_DASH_temp15103948($z39383939);
++R.GAS;
return $ret39423943;
});
var $z39233924 = D;
var $f39293930 = function(_) {
return R.isFunction(anf_fun7353931)?anf_fun7353931.app(anf_arg7383932,branches3101754):R.ffi.throwNonFunApp(L[579],anf_fun7353931,[anf_arg7383932,branches3101754]);
};
try {
if(--R.GAS > 0) {
$z39233924 = $f39293930();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39293930,
"from":L[579]});
}
} catch($e39213922) {
if(R.isCont($e39213922)) {
var $ss39253926 = {"from":L[579],
"go":function(and_DASH_oper_DASH_953933) {
return $Hand_DASH_oper_DASH_15143934(and_DASH_oper_DASH_953933,_else3111756,if_helper7243901,self3061757);
}};
$e39213922.stack[R.EXN_STACKHEIGHT++] = $ss39253926;
}
if(R.isPyretException($e39213922)) {
$e39213922.pyretStack.push(L[579]);
}
throw $e39213922;
}
var $ret39273928 = $Hand_DASH_oper_DASH_15143934($z39233924,_else3111756,if_helper7243901,self3061757);
++R.GAS;
return $ret39273928;
} else {
var $z39513952 = D;
var $f39573958 = function(_) {
return R.isFunction(if_helper7243901)?if_helper7243901.app((false)):R.ffi.throwNonFunApp(L[579],if_helper7243901,[(false)]);
};
try {
if(--R.GAS > 0) {
$z39513952 = $f39573958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39573958,
"from":L[579]});
}
} catch($e39493950) {
if(R.isCont($e39493950)) {
var $ss39533954 = {"from":L[579],
"go":function(cont_tail_app7343959) {
return $Hcont_tail_app15153960(cont_tail_app7343959);
}};
$e39493950.stack[R.EXN_STACKHEIGHT++] = $ss39533954;
}
if(R.isPyretException($e39493950)) {
$e39493950.pyretStack.push(L[579]);
}
throw $e39493950;
}
var $ret39553956 = $Hcont_tail_app15153960($z39513952);
++R.GAS;
return $ret39553956;
}
} else {
var cont_tail_arg7313963 = R.throwNonBooleanOp(L[585],("first"),("and"),and_DASH_oper_DASH_943900);
if(--R.GAS > 0) {
$z39613962 = R.isFunction(if_helper7243901)?if_helper7243901.app(cont_tail_arg7313963):R.ffi.throwNonFunApp(L[585],if_helper7243901,[cont_tail_arg7313963]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7243901)?if_helper7243901.app(cont_tail_arg7313963):R.ffi.throwNonFunApp(L[585],if_helper7243901,[cont_tail_arg7313963]);
},
"from":L[585]});
}
++R.GAS;
return $z39613962;
}
};
var $Hand_DASH_oper_DASH_15143934 = function(and_DASH_oper_DASH_953933,_else3111756,if_helper7243901,self3061757) {
var anf_if7413993 = R.isBoolean(and_DASH_oper_DASH_953933);
if(R.isPyretTrue(anf_if7413993)) {
if(R.isPyretTrue(and_DASH_oper_DASH_953933)) {
var anf_fun7433975 = G(_else3111756,"visit",L[586]);
var $z39673968 = D;
var $f39733974 = function(_) {
return R.isFunction(anf_fun7433975)?anf_fun7433975.app(self3061757):R.ffi.throwNonFunApp(L[579],anf_fun7433975,[self3061757]);
};
try {
if(--R.GAS > 0) {
$z39673968 = $f39733974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39733974,
"from":L[579]});
}
} catch($e39653966) {
if(R.isCont($e39653966)) {
var $ss39693970 = {"from":L[579],
"go":function(and_DASH_oper_DASH_973976) {
return $Hand_DASH_oper_DASH_15123977(and_DASH_oper_DASH_973976,if_helper7243901);
}};
$e39653966.stack[R.EXN_STACKHEIGHT++] = $ss39693970;
}
if(R.isPyretException($e39653966)) {
$e39653966.pyretStack.push(L[579]);
}
throw $e39653966;
}
var $ret39713972 = $Hand_DASH_oper_DASH_15123977($z39673968,if_helper7243901);
++R.GAS;
return $ret39713972;
} else {
var $z39803981 = D;
var $f39863987 = function(_) {
return R.isFunction(if_helper7243901)?if_helper7243901.app((false)):R.ffi.throwNonFunApp(L[579],if_helper7243901,[(false)]);
};
try {
if(--R.GAS > 0) {
$z39803981 = $f39863987();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39863987,
"from":L[579]});
}
} catch($e39783979) {
if(R.isCont($e39783979)) {
var $ss39823983 = {"from":L[579],
"go":function(cont_tail_app7423988) {
return $Hcont_tail_app15133989(cont_tail_app7423988);
}};
$e39783979.stack[R.EXN_STACKHEIGHT++] = $ss39823983;
}
if(R.isPyretException($e39783979)) {
$e39783979.pyretStack.push(L[579]);
}
throw $e39783979;
}
var $ret39843985 = $Hcont_tail_app15133989($z39803981);
++R.GAS;
return $ret39843985;
}
} else {
var cont_tail_arg7393992 = R.throwNonBooleanOp(L[587],("first"),("and"),and_DASH_oper_DASH_953933);
if(--R.GAS > 0) {
$z39903991 = R.isFunction(if_helper7243901)?if_helper7243901.app(cont_tail_arg7393992):R.ffi.throwNonFunApp(L[587],if_helper7243901,[cont_tail_arg7393992]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7243901)?if_helper7243901.app(cont_tail_arg7393992):R.ffi.throwNonFunApp(L[587],if_helper7243901,[cont_tail_arg7393992]);
},
"from":L[587]});
}
++R.GAS;
return $z39903991;
}
};
var $Hand_DASH_oper_DASH_15123977 = function(and_DASH_oper_DASH_973976,if_helper7243901) {
var anf_if7464009 = R.isBoolean(and_DASH_oper_DASH_973976);
if(R.isPyretTrue(anf_if7464009)) {
var $z39963997 = D;
var $f40024003 = function(_) {
return R.isFunction(if_helper7243901)?if_helper7243901.app(and_DASH_oper_DASH_973976):R.ffi.throwNonFunApp(L[579],if_helper7243901,[and_DASH_oper_DASH_973976]);
};
try {
if(--R.GAS > 0) {
$z39963997 = $f40024003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40024003,
"from":L[579]});
}
} catch($e39943995) {
if(R.isCont($e39943995)) {
var $ss39983999 = {"from":L[579],
"go":function(cont_tail_app7474004) {
return $Hcont_tail_app15114005(cont_tail_app7474004);
}};
$e39943995.stack[R.EXN_STACKHEIGHT++] = $ss39983999;
}
if(R.isPyretException($e39943995)) {
$e39943995.pyretStack.push(L[579]);
}
throw $e39943995;
}
var $ret40004001 = $Hcont_tail_app15114005($z39963997);
++R.GAS;
return $ret40004001;
} else {
var cont_tail_arg7444008 = R.throwNonBooleanOp(L[588],("second"),("and"),and_DASH_oper_DASH_973976);
if(--R.GAS > 0) {
$z40064007 = R.isFunction(if_helper7243901)?if_helper7243901.app(cont_tail_arg7444008):R.ffi.throwNonFunApp(L[588],if_helper7243901,[cont_tail_arg7444008]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7243901)?if_helper7243901.app(cont_tail_arg7444008):R.ffi.throwNonFunApp(L[588],if_helper7243901,[cont_tail_arg7444008]);
},
"from":L[588]});
}
++R.GAS;
return $z40064007;
}
};
var $Hcont_tail_app15114005 = function(cont_tail_app7474004) {
return cont_tail_app7474004;
};
var $Hcont_tail_app15133989 = function(cont_tail_app7423988) {
return cont_tail_app7423988;
};
var $Hann_DASH_check_DASH_temp15103948 = function(ann_DASH_check_DASH_temp7363947) {
return ann_DASH_check_DASH_temp7363947;
};
var $Hcont_tail_app15153960 = function(cont_tail_app7343959) {
return cont_tail_app7343959;
};
var $Hcont_tail_app15173914 = function(cont_tail_app7293913) {
return cont_tail_app7293913;
};
var $Hanf_begin_app_dropped15081777 = function(anf_begin_app_dropped15001773,branches3051772,lists1118,self3011774,typ3031775,val3041776) {
var anf_fun7014020 = G(typ3031775,"visit",L[590]);
var $z40124013 = D;
var $f40184019 = function(_) {
return R.isFunction(anf_fun7014020)?anf_fun7014020.app(self3011774):R.ffi.throwNonFunApp(L[589],anf_fun7014020,[self3011774]);
};
try {
if(--R.GAS > 0) {
$z40124013 = $f40184019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40184019,
"from":L[589]});
}
} catch($e40104011) {
if(R.isCont($e40104011)) {
var $ss40144015 = {"from":L[589],
"go":function(and_DASH_oper_DASH_894021) {
return $Hand_DASH_oper_DASH_15074022(and_DASH_oper_DASH_894021,branches3051772,lists1118,self3011774,val3041776);
}};
$e40104011.stack[R.EXN_STACKHEIGHT++] = $ss40144015;
}
if(R.isPyretException($e40104011)) {
$e40104011.pyretStack.push(L[589]);
}
throw $e40104011;
}
var $ret40164017 = $Hand_DASH_oper_DASH_15074022($z40124013,branches3051772,lists1118,self3011774,val3041776);
++R.GAS;
return $ret40164017;
};
var $Hand_DASH_oper_DASH_15074022 = function(and_DASH_oper_DASH_894021,branches3051772,lists1118,self3011774,val3041776) {
var if_helper7024035 = R.makeFunction(function(if_helper_arg7034053) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[589],1,arguments);
}
var ann_DASH_check_DASH_temp7004054 = if_helper_arg7034053;
return ann_DASH_check_DASH_temp7004054;
});
var anf_if7064052 = R.isBoolean(and_DASH_oper_DASH_894021);
if(R.isPyretTrue(anf_if7064052)) {
if(R.isPyretTrue(and_DASH_oper_DASH_894021)) {
var anf_fun7084033 = G(val3041776,"visit",L[591]);
var $z40254026 = D;
var $f40314032 = function(_) {
return R.isFunction(anf_fun7084033)?anf_fun7084033.app(self3011774):R.ffi.throwNonFunApp(L[589],anf_fun7084033,[self3011774]);
};
try {
if(--R.GAS > 0) {
$z40254026 = $f40314032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40314032,
"from":L[589]});
}
} catch($e40234024) {
if(R.isCont($e40234024)) {
var $ss40274028 = {"from":L[589],
"go":function(and_DASH_oper_DASH_904034) {
return $Hand_DASH_oper_DASH_15054036(and_DASH_oper_DASH_904034,branches3051772,if_helper7024035,lists1118,self3011774);
}};
$e40234024.stack[R.EXN_STACKHEIGHT++] = $ss40274028;
}
if(R.isPyretException($e40234024)) {
$e40234024.pyretStack.push(L[589]);
}
throw $e40234024;
}
var $ret40294030 = $Hand_DASH_oper_DASH_15054036($z40254026,branches3051772,if_helper7024035,lists1118,self3011774);
++R.GAS;
return $ret40294030;
} else {
var $z40394040 = D;
var $f40454046 = function(_) {
return R.isFunction(if_helper7024035)?if_helper7024035.app((false)):R.ffi.throwNonFunApp(L[589],if_helper7024035,[(false)]);
};
try {
if(--R.GAS > 0) {
$z40394040 = $f40454046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40454046,
"from":L[589]});
}
} catch($e40374038) {
if(R.isCont($e40374038)) {
var $ss40414042 = {"from":L[589],
"go":function(cont_tail_app7074047) {
return $Hcont_tail_app15064048(cont_tail_app7074047);
}};
$e40374038.stack[R.EXN_STACKHEIGHT++] = $ss40414042;
}
if(R.isPyretException($e40374038)) {
$e40374038.pyretStack.push(L[589]);
}
throw $e40374038;
}
var $ret40434044 = $Hcont_tail_app15064048($z40394040);
++R.GAS;
return $ret40434044;
}
} else {
var cont_tail_arg7044051 = R.throwNonBooleanOp(L[592],("first"),("and"),and_DASH_oper_DASH_894021);
if(--R.GAS > 0) {
$z40494050 = R.isFunction(if_helper7024035)?if_helper7024035.app(cont_tail_arg7044051):R.ffi.throwNonFunApp(L[592],if_helper7024035,[cont_tail_arg7044051]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7024035)?if_helper7024035.app(cont_tail_arg7044051):R.ffi.throwNonFunApp(L[592],if_helper7024035,[cont_tail_arg7044051]);
},
"from":L[592]});
}
++R.GAS;
return $z40494050;
}
};
var $Hand_DASH_oper_DASH_15054036 = function(and_DASH_oper_DASH_904034,branches3051772,if_helper7024035,lists1118,self3011774) {
var anf_if7114098 = R.isBoolean(and_DASH_oper_DASH_904034);
if(R.isPyretTrue(anf_if7114098)) {
if(R.isPyretTrue(and_DASH_oper_DASH_904034)) {
var anf_fun7134065 = G(lists1118,"all",L[594]);
var anf_arg7164066 = R.makeFunction(function(recv_DASH_924069) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[593],1,arguments);
}
var anf_fun7154080 = G(recv_DASH_924069,"visit",L[593]);
var $z40724073 = D;
var $f40784079 = function(_) {
return R.isFunction(anf_fun7154080)?anf_fun7154080.app(self3011774):R.ffi.throwNonFunApp(L[593],anf_fun7154080,[self3011774]);
};
try {
if(--R.GAS > 0) {
$z40724073 = $f40784079();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40784079,
"from":L[593]});
}
} catch($e40704071) {
if(R.isCont($e40704071)) {
var $ss40744075 = {"from":L[593],
"go":function(ann_DASH_check_DASH_temp7144081) {
return $Hann_DASH_check_DASH_temp15014082(ann_DASH_check_DASH_temp7144081);
}};
$e40704071.stack[R.EXN_STACKHEIGHT++] = $ss40744075;
}
if(R.isPyretException($e40704071)) {
$e40704071.pyretStack.push(L[593]);
}
throw $e40704071;
}
var $ret40764077 = $Hann_DASH_check_DASH_temp15014082($z40724073);
++R.GAS;
return $ret40764077;
});
var $z40574058 = D;
var $f40634064 = function(_) {
return R.isFunction(anf_fun7134065)?anf_fun7134065.app(anf_arg7164066,branches3051772):R.ffi.throwNonFunApp(L[589],anf_fun7134065,[anf_arg7164066,branches3051772]);
};
try {
if(--R.GAS > 0) {
$z40574058 = $f40634064();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40634064,
"from":L[589]});
}
} catch($e40554056) {
if(R.isCont($e40554056)) {
var $ss40594060 = {"from":L[589],
"go":function(and_DASH_oper_DASH_914067) {
return $Hand_DASH_oper_DASH_15034068(and_DASH_oper_DASH_914067,if_helper7024035);
}};
$e40554056.stack[R.EXN_STACKHEIGHT++] = $ss40594060;
}
if(R.isPyretException($e40554056)) {
$e40554056.pyretStack.push(L[589]);
}
throw $e40554056;
}
var $ret40614062 = $Hand_DASH_oper_DASH_15034068($z40574058,if_helper7024035);
++R.GAS;
return $ret40614062;
} else {
var $z40854086 = D;
var $f40914092 = function(_) {
return R.isFunction(if_helper7024035)?if_helper7024035.app((false)):R.ffi.throwNonFunApp(L[589],if_helper7024035,[(false)]);
};
try {
if(--R.GAS > 0) {
$z40854086 = $f40914092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40914092,
"from":L[589]});
}
} catch($e40834084) {
if(R.isCont($e40834084)) {
var $ss40874088 = {"from":L[589],
"go":function(cont_tail_app7124093) {
return $Hcont_tail_app15044094(cont_tail_app7124093);
}};
$e40834084.stack[R.EXN_STACKHEIGHT++] = $ss40874088;
}
if(R.isPyretException($e40834084)) {
$e40834084.pyretStack.push(L[589]);
}
throw $e40834084;
}
var $ret40894090 = $Hcont_tail_app15044094($z40854086);
++R.GAS;
return $ret40894090;
}
} else {
var cont_tail_arg7094097 = R.throwNonBooleanOp(L[595],("first"),("and"),and_DASH_oper_DASH_904034);
if(--R.GAS > 0) {
$z40954096 = R.isFunction(if_helper7024035)?if_helper7024035.app(cont_tail_arg7094097):R.ffi.throwNonFunApp(L[595],if_helper7024035,[cont_tail_arg7094097]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7024035)?if_helper7024035.app(cont_tail_arg7094097):R.ffi.throwNonFunApp(L[595],if_helper7024035,[cont_tail_arg7094097]);
},
"from":L[595]});
}
++R.GAS;
return $z40954096;
}
};
var $Hand_DASH_oper_DASH_15034068 = function(and_DASH_oper_DASH_914067,if_helper7024035) {
var anf_if7194114 = R.isBoolean(and_DASH_oper_DASH_914067);
if(R.isPyretTrue(anf_if7194114)) {
var $z41014102 = D;
var $f41074108 = function(_) {
return R.isFunction(if_helper7024035)?if_helper7024035.app(and_DASH_oper_DASH_914067):R.ffi.throwNonFunApp(L[589],if_helper7024035,[and_DASH_oper_DASH_914067]);
};
try {
if(--R.GAS > 0) {
$z41014102 = $f41074108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41074108,
"from":L[589]});
}
} catch($e40994100) {
if(R.isCont($e40994100)) {
var $ss41034104 = {"from":L[589],
"go":function(cont_tail_app7204109) {
return $Hcont_tail_app15024110(cont_tail_app7204109);
}};
$e40994100.stack[R.EXN_STACKHEIGHT++] = $ss41034104;
}
if(R.isPyretException($e40994100)) {
$e40994100.pyretStack.push(L[589]);
}
throw $e40994100;
}
var $ret41054106 = $Hcont_tail_app15024110($z41014102);
++R.GAS;
return $ret41054106;
} else {
var cont_tail_arg7174113 = R.throwNonBooleanOp(L[596],("second"),("and"),and_DASH_oper_DASH_914067);
if(--R.GAS > 0) {
$z41114112 = R.isFunction(if_helper7024035)?if_helper7024035.app(cont_tail_arg7174113):R.ffi.throwNonFunApp(L[596],if_helper7024035,[cont_tail_arg7174113]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper7024035)?if_helper7024035.app(cont_tail_arg7174113):R.ffi.throwNonFunApp(L[596],if_helper7024035,[cont_tail_arg7174113]);
},
"from":L[596]});
}
++R.GAS;
return $z41114112;
}
};
var $Hcont_tail_app15024110 = function(cont_tail_app7204109) {
return cont_tail_app7204109;
};
var $Hann_DASH_check_DASH_temp15014082 = function(ann_DASH_check_DASH_temp7144081) {
return ann_DASH_check_DASH_temp7144081;
};
var $Hcont_tail_app15044094 = function(cont_tail_app7124093) {
return cont_tail_app7124093;
};
var $Hcont_tail_app15064048 = function(cont_tail_app7074047) {
return cont_tail_app7074047;
};
var $Hanf_arg14991794 = function(anf_arg6871790,branches3001791,l2991792,lists1118,self2981793,wf_DASH_error7659,nothing4) {
var when_DASH_874140 = R.equiv(anf_arg6871790,(1));
var if_helper6884126 = R.makeFunction(function(if_helper_arg6894145) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[598],1,arguments);
}
if_helper_arg6894145;
var anf_fun6904156 = G(lists1118,"all",L[601]);
var anf_arg6934157 = R.makeFunction(function(recv_DASH_884160) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[600],1,arguments);
}
var anf_fun6924171 = G(recv_DASH_884160,"visit",L[600]);
var $z41634164 = D;
var $f41694170 = function(_) {
return R.isFunction(anf_fun6924171)?anf_fun6924171.app(self2981793):R.ffi.throwNonFunApp(L[600],anf_fun6924171,[self2981793]);
};
try {
if(--R.GAS > 0) {
$z41634164 = $f41694170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41694170,
"from":L[600]});
}
} catch($e41614162) {
if(R.isCont($e41614162)) {
var $ss41654166 = {"from":L[600],
"go":function(ann_DASH_check_DASH_temp6914172) {
return $Hann_DASH_check_DASH_temp14934173(ann_DASH_check_DASH_temp6914172);
}};
$e41614162.stack[R.EXN_STACKHEIGHT++] = $ss41654166;
}
if(R.isPyretException($e41614162)) {
$e41614162.pyretStack.push(L[600]);
}
throw $e41614162;
}
var $ret41674168 = $Hann_DASH_check_DASH_temp14934173($z41634164);
++R.GAS;
return $ret41674168;
});
var $z41484149 = D;
var $f41544155 = function(_) {
return R.isFunction(anf_fun6904156)?anf_fun6904156.app(anf_arg6934157,branches3001791):R.ffi.throwNonFunApp(L[357],anf_fun6904156,[anf_arg6934157,branches3001791]);
};
try {
if(--R.GAS > 0) {
$z41484149 = $f41544155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41544155,
"from":L[357]});
}
} catch($e41464147) {
if(R.isCont($e41464147)) {
var $ss41504151 = {"from":L[357],
"go":function(ann_DASH_check_DASH_temp6854158) {
return $Hann_DASH_check_DASH_temp14944159(ann_DASH_check_DASH_temp6854158);
}};
$e41464147.stack[R.EXN_STACKHEIGHT++] = $ss41504151;
}
if(R.isPyretException($e41464147)) {
$e41464147.pyretStack.push(L[357]);
}
throw $e41464147;
}
var $ret41524153 = $Hann_DASH_check_DASH_temp14944159($z41484149);
++R.GAS;
return $ret41524153;
});
var anf_if6964144 = R.isBoolean(when_DASH_874140);
if(R.isPyretTrue(anf_if6964144)) {
if(R.isPyretTrue(when_DASH_874140)) {
var $z41174118 = D;
var $f41234124 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot have an `if` with a single branch"),l2991792):R.ffi.throwNonFunApp(L[597],wf_DASH_error7659.$var,[("Cannot have an `if` with a single branch"),l2991792]);
};
try {
if(--R.GAS > 0) {
$z41174118 = $f41234124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41234124,
"from":L[597]});
}
} catch($e41154116) {
if(R.isCont($e41154116)) {
var $ss41194120 = {"from":L[597],
"go":function(anf_begin_app_dropped14954125) {
return $Hanf_begin_app_dropped14974127(anf_begin_app_dropped14954125,if_helper6884126,nothing4);
}};
$e41154116.stack[R.EXN_STACKHEIGHT++] = $ss41194120;
}
if(R.isPyretException($e41154116)) {
$e41154116.pyretStack.push(L[597]);
}
throw $e41154116;
}
var $ret41214122 = $Hanf_begin_app_dropped14974127($z41174118,if_helper6884126,nothing4);
++R.GAS;
return $ret41214122;
} else {
var $z41304131 = D;
var $f41364137 = function(_) {
return R.isFunction(if_helper6884126)?if_helper6884126.app(nothing4):R.ffi.throwNonFunApp(L[598],if_helper6884126,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z41304131 = $f41364137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41364137,
"from":L[598]});
}
} catch($e41284129) {
if(R.isCont($e41284129)) {
var $ss41324133 = {"from":L[598],
"go":function(cont_tail_app6974138) {
return $Hcont_tail_app14984139(cont_tail_app6974138);
}};
$e41284129.stack[R.EXN_STACKHEIGHT++] = $ss41324133;
}
if(R.isPyretException($e41284129)) {
$e41284129.pyretStack.push(L[598]);
}
throw $e41284129;
}
var $ret41344135 = $Hcont_tail_app14984139($z41304131);
++R.GAS;
return $ret41344135;
}
} else {
var cont_tail_arg6944143 = R.throwNonBooleanCondition(L[599],("when"),when_DASH_874140);
if(--R.GAS > 0) {
$z41414142 = R.isFunction(if_helper6884126)?if_helper6884126.app(cont_tail_arg6944143):R.ffi.throwNonFunApp(L[599],if_helper6884126,[cont_tail_arg6944143]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6884126)?if_helper6884126.app(cont_tail_arg6944143):R.ffi.throwNonFunApp(L[599],if_helper6884126,[cont_tail_arg6944143]);
},
"from":L[599]});
}
++R.GAS;
return $z41414142;
}
};
var $Hanf_begin_app_dropped14974127 = function(anf_begin_app_dropped14954125,if_helper6884126,nothing4) {
var $z41764177 = D;
var $f41824183 = function(_) {
return R.isFunction(if_helper6884126)?if_helper6884126.app(nothing4):R.ffi.throwNonFunApp(L[598],if_helper6884126,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z41764177 = $f41824183();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41824183,
"from":L[598]});
}
} catch($e41744175) {
if(R.isCont($e41744175)) {
var $ss41784179 = {"from":L[598],
"go":function(cont_tail_app6984184) {
return $Hcont_tail_app14964185(cont_tail_app6984184);
}};
$e41744175.stack[R.EXN_STACKHEIGHT++] = $ss41784179;
}
if(R.isPyretException($e41744175)) {
$e41744175.pyretStack.push(L[598]);
}
throw $e41744175;
}
var $ret41804181 = $Hcont_tail_app14964185($z41764177);
++R.GAS;
return $ret41804181;
};
var $Hcont_tail_app14964185 = function(cont_tail_app6984184) {
return cont_tail_app6984184;
};
var $Hcont_tail_app14984139 = function(cont_tail_app6974138) {
return cont_tail_app6974138;
};
var $Hann_DASH_check_DASH_temp14944159 = function(ann_DASH_check_DASH_temp6854158) {
return ann_DASH_check_DASH_temp6854158;
};
var $Hann_DASH_check_DASH_temp14934173 = function(ann_DASH_check_DASH_temp6914172) {
return ann_DASH_check_DASH_temp6914172;
};
var $Hanf_arg14921808 = function(anf_arg6831806,self2931807,wrap_DASH_visit_DASH_check8067) {
var $z41884189 = D;
var $f41944195 = function(_) {
return R.isFunction(wrap_DASH_visit_DASH_check8067.$var)?wrap_DASH_visit_DASH_check8067.$var.app(self2931807,anf_arg6831806):R.ffi.throwNonFunApp(L[359],wrap_DASH_visit_DASH_check8067.$var,[self2931807,anf_arg6831806]);
};
try {
if(--R.GAS > 0) {
$z41884189 = $f41944195();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41944195,
"from":L[359]});
}
} catch($e41864187) {
if(R.isCont($e41864187)) {
var $ss41904191 = {"from":L[359],
"go":function(ann_DASH_check_DASH_temp6824196) {
return $Hann_DASH_check_DASH_temp14914197(ann_DASH_check_DASH_temp6824196);
}};
$e41864187.stack[R.EXN_STACKHEIGHT++] = $ss41904191;
}
if(R.isPyretException($e41864187)) {
$e41864187.pyretStack.push(L[359]);
}
throw $e41864187;
}
var $ret41924193 = $Hann_DASH_check_DASH_temp14914197($z41884189);
++R.GAS;
return $ret41924193;
};
var $Hann_DASH_check_DASH_temp14914197 = function(ann_DASH_check_DASH_temp6824196) {
return ann_DASH_check_DASH_temp6824196;
};
var $Hwhen_DASH_14901832 = function(when_DASH_791824,_check2921825,ann2891826,args2881827,body2911828,ensure_DASH_unique_DASH_ids9973,l2851829,lists1118,name2861823,params2871830,reserved_DASH_name7965,self2841831,wrap_DASH_visit_DASH_check8067,nothing4) {
var if_helper6424209 = R.makeFunction(function(if_helper_arg6434227) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[360],1,arguments);
}
if_helper_arg6434227;
var $z42304231 = D;
var $f42364237 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(args2881827):R.ffi.throwNonFunApp(L[604],ensure_DASH_unique_DASH_ids9973.$var,[args2881827]);
};
try {
if(--R.GAS > 0) {
$z42304231 = $f42364237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42364237,
"from":L[604]});
}
} catch($e42284229) {
if(R.isCont($e42284229)) {
var $ss42324233 = {"from":L[604],
"go":function(anf_begin_app_dropped14724238) {
return $Hanf_begin_app_dropped14854239(anf_begin_app_dropped14724238,_check2921825,ann2891826,args2881827,body2911828,lists1118,params2871830,self2841831,wrap_DASH_visit_DASH_check8067);
}};
$e42284229.stack[R.EXN_STACKHEIGHT++] = $ss42324233;
}
if(R.isPyretException($e42284229)) {
$e42284229.pyretStack.push(L[604]);
}
throw $e42284229;
}
var $ret42344235 = $Hanf_begin_app_dropped14854239($z42304231,_check2921825,ann2891826,args2881827,body2911828,lists1118,params2871830,self2841831,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret42344235;
});
var anf_if6784226 = R.isBoolean(when_DASH_791824);
if(R.isPyretTrue(anf_if6784226)) {
if(R.isPyretTrue(when_DASH_791824)) {
var $z42004201 = D;
var $f42064207 = function(_) {
return R.isFunction(reserved_DASH_name7965.$var)?reserved_DASH_name7965.$var.app(l2851829,name2861823):R.ffi.throwNonFunApp(L[602],reserved_DASH_name7965.$var,[l2851829,name2861823]);
};
try {
if(--R.GAS > 0) {
$z42004201 = $f42064207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42064207,
"from":L[602]});
}
} catch($e41984199) {
if(R.isCont($e41984199)) {
var $ss42024203 = {"from":L[602],
"go":function(anf_begin_app_dropped14864208) {
return $Hanf_begin_app_dropped14884210(anf_begin_app_dropped14864208,if_helper6424209,nothing4);
}};
$e41984199.stack[R.EXN_STACKHEIGHT++] = $ss42024203;
}
if(R.isPyretException($e41984199)) {
$e41984199.pyretStack.push(L[602]);
}
throw $e41984199;
}
var $ret42044205 = $Hanf_begin_app_dropped14884210($z42004201,if_helper6424209,nothing4);
++R.GAS;
return $ret42044205;
} else {
var $z42134214 = D;
var $f42194220 = function(_) {
return R.isFunction(if_helper6424209)?if_helper6424209.app(nothing4):R.ffi.throwNonFunApp(L[360],if_helper6424209,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z42134214 = $f42194220();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42194220,
"from":L[360]});
}
} catch($e42114212) {
if(R.isCont($e42114212)) {
var $ss42154216 = {"from":L[360],
"go":function(cont_tail_app6794221) {
return $Hcont_tail_app14894222(cont_tail_app6794221);
}};
$e42114212.stack[R.EXN_STACKHEIGHT++] = $ss42154216;
}
if(R.isPyretException($e42114212)) {
$e42114212.pyretStack.push(L[360]);
}
throw $e42114212;
}
var $ret42174218 = $Hcont_tail_app14894222($z42134214);
++R.GAS;
return $ret42174218;
}
} else {
var cont_tail_arg6764225 = R.throwNonBooleanCondition(L[603],("when"),when_DASH_791824);
if(--R.GAS > 0) {
$z42234224 = R.isFunction(if_helper6424209)?if_helper6424209.app(cont_tail_arg6764225):R.ffi.throwNonFunApp(L[603],if_helper6424209,[cont_tail_arg6764225]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6424209)?if_helper6424209.app(cont_tail_arg6764225):R.ffi.throwNonFunApp(L[603],if_helper6424209,[cont_tail_arg6764225]);
},
"from":L[603]});
}
++R.GAS;
return $z42234224;
}
};
var $Hanf_begin_app_dropped14884210 = function(anf_begin_app_dropped14864208,if_helper6424209,nothing4) {
var $z42424243 = D;
var $f42484249 = function(_) {
return R.isFunction(if_helper6424209)?if_helper6424209.app(nothing4):R.ffi.throwNonFunApp(L[360],if_helper6424209,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z42424243 = $f42484249();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42484249,
"from":L[360]});
}
} catch($e42404241) {
if(R.isCont($e42404241)) {
var $ss42444245 = {"from":L[360],
"go":function(cont_tail_app6804250) {
return $Hcont_tail_app14874251(cont_tail_app6804250);
}};
$e42404241.stack[R.EXN_STACKHEIGHT++] = $ss42444245;
}
if(R.isPyretException($e42404241)) {
$e42404241.pyretStack.push(L[360]);
}
throw $e42404241;
}
var $ret42464247 = $Hcont_tail_app14874251($z42424243);
++R.GAS;
return $ret42464247;
};
var $Hcont_tail_app14874251 = function(cont_tail_app6804250) {
return cont_tail_app6804250;
};
var $Hcont_tail_app14894222 = function(cont_tail_app6794221) {
return cont_tail_app6794221;
};
var $Hanf_begin_app_dropped14854239 = function(anf_begin_app_dropped14724238,_check2921825,ann2891826,args2881827,body2911828,lists1118,params2871830,self2841831,wrap_DASH_visit_DASH_check8067) {
var anf_fun6444262 = G(lists1118,"all",L[607]);
var anf_arg6474263 = R.makeFunction(function(recv_DASH_814266) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[606],1,arguments);
}
var anf_fun6464277 = G(recv_DASH_814266,"visit",L[606]);
var $z42694270 = D;
var $f42754276 = function(_) {
return R.isFunction(anf_fun6464277)?anf_fun6464277.app(self2841831):R.ffi.throwNonFunApp(L[606],anf_fun6464277,[self2841831]);
};
try {
if(--R.GAS > 0) {
$z42694270 = $f42754276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42754276,
"from":L[606]});
}
} catch($e42674268) {
if(R.isCont($e42674268)) {
var $ss42714272 = {"from":L[606],
"go":function(ann_DASH_check_DASH_temp6454278) {
return $Hann_DASH_check_DASH_temp14734279(ann_DASH_check_DASH_temp6454278);
}};
$e42674268.stack[R.EXN_STACKHEIGHT++] = $ss42714272;
}
if(R.isPyretException($e42674268)) {
$e42674268.pyretStack.push(L[606]);
}
throw $e42674268;
}
var $ret42734274 = $Hann_DASH_check_DASH_temp14734279($z42694270);
++R.GAS;
return $ret42734274;
});
var $z42544255 = D;
var $f42604261 = function(_) {
return R.isFunction(anf_fun6444262)?anf_fun6444262.app(anf_arg6474263,params2871830):R.ffi.throwNonFunApp(L[605],anf_fun6444262,[anf_arg6474263,params2871830]);
};
try {
if(--R.GAS > 0) {
$z42544255 = $f42604261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42604261,
"from":L[605]});
}
} catch($e42524253) {
if(R.isCont($e42524253)) {
var $ss42564257 = {"from":L[605],
"go":function(and_DASH_oper_DASH_804264) {
return $Hand_DASH_oper_DASH_14844265(and_DASH_oper_DASH_804264,_check2921825,ann2891826,args2881827,body2911828,lists1118,self2841831,wrap_DASH_visit_DASH_check8067);
}};
$e42524253.stack[R.EXN_STACKHEIGHT++] = $ss42564257;
}
if(R.isPyretException($e42524253)) {
$e42524253.pyretStack.push(L[605]);
}
throw $e42524253;
}
var $ret42584259 = $Hand_DASH_oper_DASH_14844265($z42544255,_check2921825,ann2891826,args2881827,body2911828,lists1118,self2841831,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret42584259;
};
var $Hand_DASH_oper_DASH_14844265 = function(and_DASH_oper_DASH_804264,_check2921825,ann2891826,args2881827,body2911828,lists1118,self2841831,wrap_DASH_visit_DASH_check8067) {
var if_helper6484293 = R.makeFunction(function(if_helper_arg6494325) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[605],1,arguments);
}
var ann_DASH_check_DASH_temp6404326 = if_helper_arg6494325;
return ann_DASH_check_DASH_temp6404326;
});
var anf_if6524324 = R.isBoolean(and_DASH_oper_DASH_804264);
if(R.isPyretTrue(anf_if6524324)) {
if(R.isPyretTrue(and_DASH_oper_DASH_804264)) {
var anf_fun6544290 = G(lists1118,"all",L[609]);
var anf_arg6574291 = R.makeFunction(function(recv_DASH_834295) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[608],1,arguments);
}
var anf_fun6564306 = G(recv_DASH_834295,"visit",L[608]);
var $z42984299 = D;
var $f43044305 = function(_) {
return R.isFunction(anf_fun6564306)?anf_fun6564306.app(self2841831):R.ffi.throwNonFunApp(L[608],anf_fun6564306,[self2841831]);
};
try {
if(--R.GAS > 0) {
$z42984299 = $f43044305();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43044305,
"from":L[608]});
}
} catch($e42964297) {
if(R.isCont($e42964297)) {
var $ss43004301 = {"from":L[608],
"go":function(ann_DASH_check_DASH_temp6554307) {
return $Hann_DASH_check_DASH_temp14744308(ann_DASH_check_DASH_temp6554307);
}};
$e42964297.stack[R.EXN_STACKHEIGHT++] = $ss43004301;
}
if(R.isPyretException($e42964297)) {
$e42964297.pyretStack.push(L[608]);
}
throw $e42964297;
}
var $ret43024303 = $Hann_DASH_check_DASH_temp14744308($z42984299);
++R.GAS;
return $ret43024303;
});
var $z42824283 = D;
var $f42884289 = function(_) {
return R.isFunction(anf_fun6544290)?anf_fun6544290.app(anf_arg6574291,args2881827):R.ffi.throwNonFunApp(L[605],anf_fun6544290,[anf_arg6574291,args2881827]);
};
try {
if(--R.GAS > 0) {
$z42824283 = $f42884289();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42884289,
"from":L[605]});
}
} catch($e42804281) {
if(R.isCont($e42804281)) {
var $ss42844285 = {"from":L[605],
"go":function(and_DASH_oper_DASH_824292) {
return $Hand_DASH_oper_DASH_14824294(and_DASH_oper_DASH_824292,_check2921825,ann2891826,body2911828,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067);
}};
$e42804281.stack[R.EXN_STACKHEIGHT++] = $ss42844285;
}
if(R.isPyretException($e42804281)) {
$e42804281.pyretStack.push(L[605]);
}
throw $e42804281;
}
var $ret42864287 = $Hand_DASH_oper_DASH_14824294($z42824283,_check2921825,ann2891826,body2911828,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret42864287;
} else {
var $z43114312 = D;
var $f43174318 = function(_) {
return R.isFunction(if_helper6484293)?if_helper6484293.app((false)):R.ffi.throwNonFunApp(L[605],if_helper6484293,[(false)]);
};
try {
if(--R.GAS > 0) {
$z43114312 = $f43174318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43174318,
"from":L[605]});
}
} catch($e43094310) {
if(R.isCont($e43094310)) {
var $ss43134314 = {"from":L[605],
"go":function(cont_tail_app6534319) {
return $Hcont_tail_app14834320(cont_tail_app6534319);
}};
$e43094310.stack[R.EXN_STACKHEIGHT++] = $ss43134314;
}
if(R.isPyretException($e43094310)) {
$e43094310.pyretStack.push(L[605]);
}
throw $e43094310;
}
var $ret43154316 = $Hcont_tail_app14834320($z43114312);
++R.GAS;
return $ret43154316;
}
} else {
var cont_tail_arg6504323 = R.throwNonBooleanOp(L[610],("first"),("and"),and_DASH_oper_DASH_804264);
if(--R.GAS > 0) {
$z43214322 = R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6504323):R.ffi.throwNonFunApp(L[610],if_helper6484293,[cont_tail_arg6504323]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6504323):R.ffi.throwNonFunApp(L[610],if_helper6484293,[cont_tail_arg6504323]);
},
"from":L[610]});
}
++R.GAS;
return $z43214322;
}
};
var $Hand_DASH_oper_DASH_14824294 = function(and_DASH_oper_DASH_824292,_check2921825,ann2891826,body2911828,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067) {
var anf_if6604355 = R.isBoolean(and_DASH_oper_DASH_824292);
if(R.isPyretTrue(anf_if6604355)) {
if(R.isPyretTrue(and_DASH_oper_DASH_824292)) {
var anf_fun6624337 = G(ann2891826,"visit",L[611]);
var $z43294330 = D;
var $f43354336 = function(_) {
return R.isFunction(anf_fun6624337)?anf_fun6624337.app(self2841831):R.ffi.throwNonFunApp(L[605],anf_fun6624337,[self2841831]);
};
try {
if(--R.GAS > 0) {
$z43294330 = $f43354336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43354336,
"from":L[605]});
}
} catch($e43274328) {
if(R.isCont($e43274328)) {
var $ss43314332 = {"from":L[605],
"go":function(and_DASH_oper_DASH_844338) {
return $Hand_DASH_oper_DASH_14804339(and_DASH_oper_DASH_844338,_check2921825,body2911828,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067);
}};
$e43274328.stack[R.EXN_STACKHEIGHT++] = $ss43314332;
}
if(R.isPyretException($e43274328)) {
$e43274328.pyretStack.push(L[605]);
}
throw $e43274328;
}
var $ret43334334 = $Hand_DASH_oper_DASH_14804339($z43294330,_check2921825,body2911828,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret43334334;
} else {
var $z43424343 = D;
var $f43484349 = function(_) {
return R.isFunction(if_helper6484293)?if_helper6484293.app((false)):R.ffi.throwNonFunApp(L[605],if_helper6484293,[(false)]);
};
try {
if(--R.GAS > 0) {
$z43424343 = $f43484349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43484349,
"from":L[605]});
}
} catch($e43404341) {
if(R.isCont($e43404341)) {
var $ss43444345 = {"from":L[605],
"go":function(cont_tail_app6614350) {
return $Hcont_tail_app14814351(cont_tail_app6614350);
}};
$e43404341.stack[R.EXN_STACKHEIGHT++] = $ss43444345;
}
if(R.isPyretException($e43404341)) {
$e43404341.pyretStack.push(L[605]);
}
throw $e43404341;
}
var $ret43464347 = $Hcont_tail_app14814351($z43424343);
++R.GAS;
return $ret43464347;
}
} else {
var cont_tail_arg6584354 = R.throwNonBooleanOp(L[612],("first"),("and"),and_DASH_oper_DASH_824292);
if(--R.GAS > 0) {
$z43524353 = R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6584354):R.ffi.throwNonFunApp(L[612],if_helper6484293,[cont_tail_arg6584354]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6584354):R.ffi.throwNonFunApp(L[612],if_helper6484293,[cont_tail_arg6584354]);
},
"from":L[612]});
}
++R.GAS;
return $z43524353;
}
};
var $Hand_DASH_oper_DASH_14804339 = function(and_DASH_oper_DASH_844338,_check2921825,body2911828,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067) {
var anf_if6654384 = R.isBoolean(and_DASH_oper_DASH_844338);
if(R.isPyretTrue(anf_if6654384)) {
if(R.isPyretTrue(and_DASH_oper_DASH_844338)) {
var anf_fun6674366 = G(body2911828,"visit",L[613]);
var $z43584359 = D;
var $f43644365 = function(_) {
return R.isFunction(anf_fun6674366)?anf_fun6674366.app(self2841831):R.ffi.throwNonFunApp(L[605],anf_fun6674366,[self2841831]);
};
try {
if(--R.GAS > 0) {
$z43584359 = $f43644365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43644365,
"from":L[605]});
}
} catch($e43564357) {
if(R.isCont($e43564357)) {
var $ss43604361 = {"from":L[605],
"go":function(and_DASH_oper_DASH_854367) {
return $Hand_DASH_oper_DASH_14784368(and_DASH_oper_DASH_854367,_check2921825,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067);
}};
$e43564357.stack[R.EXN_STACKHEIGHT++] = $ss43604361;
}
if(R.isPyretException($e43564357)) {
$e43564357.pyretStack.push(L[605]);
}
throw $e43564357;
}
var $ret43624363 = $Hand_DASH_oper_DASH_14784368($z43584359,_check2921825,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret43624363;
} else {
var $z43714372 = D;
var $f43774378 = function(_) {
return R.isFunction(if_helper6484293)?if_helper6484293.app((false)):R.ffi.throwNonFunApp(L[605],if_helper6484293,[(false)]);
};
try {
if(--R.GAS > 0) {
$z43714372 = $f43774378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43774378,
"from":L[605]});
}
} catch($e43694370) {
if(R.isCont($e43694370)) {
var $ss43734374 = {"from":L[605],
"go":function(cont_tail_app6664379) {
return $Hcont_tail_app14794380(cont_tail_app6664379);
}};
$e43694370.stack[R.EXN_STACKHEIGHT++] = $ss43734374;
}
if(R.isPyretException($e43694370)) {
$e43694370.pyretStack.push(L[605]);
}
throw $e43694370;
}
var $ret43754376 = $Hcont_tail_app14794380($z43714372);
++R.GAS;
return $ret43754376;
}
} else {
var cont_tail_arg6634383 = R.throwNonBooleanOp(L[614],("first"),("and"),and_DASH_oper_DASH_844338);
if(--R.GAS > 0) {
$z43814382 = R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6634383):R.ffi.throwNonFunApp(L[614],if_helper6484293,[cont_tail_arg6634383]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6634383):R.ffi.throwNonFunApp(L[614],if_helper6484293,[cont_tail_arg6634383]);
},
"from":L[614]});
}
++R.GAS;
return $z43814382;
}
};
var $Hand_DASH_oper_DASH_14784368 = function(and_DASH_oper_DASH_854367,_check2921825,if_helper6484293,self2841831,wrap_DASH_visit_DASH_check8067) {
var anf_if6704412 = R.isBoolean(and_DASH_oper_DASH_854367);
if(R.isPyretTrue(anf_if6704412)) {
if(R.isPyretTrue(and_DASH_oper_DASH_854367)) {
var $z43874388 = D;
var $f43934394 = function(_) {
return R.isFunction(wrap_DASH_visit_DASH_check8067.$var)?wrap_DASH_visit_DASH_check8067.$var.app(self2841831,_check2921825):R.ffi.throwNonFunApp(L[605],wrap_DASH_visit_DASH_check8067.$var,[self2841831,_check2921825]);
};
try {
if(--R.GAS > 0) {
$z43874388 = $f43934394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43934394,
"from":L[605]});
}
} catch($e43854386) {
if(R.isCont($e43854386)) {
var $ss43894390 = {"from":L[605],
"go":function(and_DASH_oper_DASH_864395) {
return $Hand_DASH_oper_DASH_14764396(and_DASH_oper_DASH_864395,if_helper6484293);
}};
$e43854386.stack[R.EXN_STACKHEIGHT++] = $ss43894390;
}
if(R.isPyretException($e43854386)) {
$e43854386.pyretStack.push(L[605]);
}
throw $e43854386;
}
var $ret43914392 = $Hand_DASH_oper_DASH_14764396($z43874388,if_helper6484293);
++R.GAS;
return $ret43914392;
} else {
var $z43994400 = D;
var $f44054406 = function(_) {
return R.isFunction(if_helper6484293)?if_helper6484293.app((false)):R.ffi.throwNonFunApp(L[605],if_helper6484293,[(false)]);
};
try {
if(--R.GAS > 0) {
$z43994400 = $f44054406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44054406,
"from":L[605]});
}
} catch($e43974398) {
if(R.isCont($e43974398)) {
var $ss44014402 = {"from":L[605],
"go":function(cont_tail_app6714407) {
return $Hcont_tail_app14774408(cont_tail_app6714407);
}};
$e43974398.stack[R.EXN_STACKHEIGHT++] = $ss44014402;
}
if(R.isPyretException($e43974398)) {
$e43974398.pyretStack.push(L[605]);
}
throw $e43974398;
}
var $ret44034404 = $Hcont_tail_app14774408($z43994400);
++R.GAS;
return $ret44034404;
}
} else {
var cont_tail_arg6684411 = R.throwNonBooleanOp(L[615],("first"),("and"),and_DASH_oper_DASH_854367);
if(--R.GAS > 0) {
$z44094410 = R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6684411):R.ffi.throwNonFunApp(L[615],if_helper6484293,[cont_tail_arg6684411]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6684411):R.ffi.throwNonFunApp(L[615],if_helper6484293,[cont_tail_arg6684411]);
},
"from":L[615]});
}
++R.GAS;
return $z44094410;
}
};
var $Hand_DASH_oper_DASH_14764396 = function(and_DASH_oper_DASH_864395,if_helper6484293) {
var anf_if6744428 = R.isBoolean(and_DASH_oper_DASH_864395);
if(R.isPyretTrue(anf_if6744428)) {
var $z44154416 = D;
var $f44214422 = function(_) {
return R.isFunction(if_helper6484293)?if_helper6484293.app(and_DASH_oper_DASH_864395):R.ffi.throwNonFunApp(L[605],if_helper6484293,[and_DASH_oper_DASH_864395]);
};
try {
if(--R.GAS > 0) {
$z44154416 = $f44214422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44214422,
"from":L[605]});
}
} catch($e44134414) {
if(R.isCont($e44134414)) {
var $ss44174418 = {"from":L[605],
"go":function(cont_tail_app6754423) {
return $Hcont_tail_app14754424(cont_tail_app6754423);
}};
$e44134414.stack[R.EXN_STACKHEIGHT++] = $ss44174418;
}
if(R.isPyretException($e44134414)) {
$e44134414.pyretStack.push(L[605]);
}
throw $e44134414;
}
var $ret44194420 = $Hcont_tail_app14754424($z44154416);
++R.GAS;
return $ret44194420;
} else {
var cont_tail_arg6724427 = R.throwNonBooleanOp(L[616],("second"),("and"),and_DASH_oper_DASH_864395);
if(--R.GAS > 0) {
$z44254426 = R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6724427):R.ffi.throwNonFunApp(L[616],if_helper6484293,[cont_tail_arg6724427]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6484293)?if_helper6484293.app(cont_tail_arg6724427):R.ffi.throwNonFunApp(L[616],if_helper6484293,[cont_tail_arg6724427]);
},
"from":L[616]});
}
++R.GAS;
return $z44254426;
}
};
var $Hcont_tail_app14754424 = function(cont_tail_app6754423) {
return cont_tail_app6754423;
};
var $Hcont_tail_app14774408 = function(cont_tail_app6714407) {
return cont_tail_app6714407;
};
var $Hcont_tail_app14794380 = function(cont_tail_app6664379) {
return cont_tail_app6664379;
};
var $Hcont_tail_app14814351 = function(cont_tail_app6614350) {
return cont_tail_app6614350;
};
var $Hann_DASH_check_DASH_temp14744308 = function(ann_DASH_check_DASH_temp6554307) {
return ann_DASH_check_DASH_temp6554307;
};
var $Hcont_tail_app14834320 = function(cont_tail_app6534319) {
return cont_tail_app6534319;
};
var $Hann_DASH_check_DASH_temp14734279 = function(ann_DASH_check_DASH_temp6454278) {
return ann_DASH_check_DASH_temp6454278;
};
var $Hanf_begin_app_dropped14711852 = function(anf_begin_app_dropped14551845,_check2821846,ann2791847,args2781844,body2811848,ensure_DASH_empty_DASH_block9769,l2761849,lists1118,params2771850,self2751851,wrap_DASH_visit_DASH_check8067,nothing4) {
var cases_DASH_val714461 = _check2821846;
var anf_fun5994439 = G(cases_DASH_val714461,"_match",L[617]);
var anf_obj6014445 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[619],0,arguments);
}
var ann_DASH_check_DASH_temp6004460 = nothing4;
return ann_DASH_check_DASH_temp6004460;
});
var anf_obj6034446 = R.makeFunction(function(chk2834447) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[618],1,arguments);
}
var $z44504451 = D;
var $f44564457 = function(_) {
return R.isFunction(ensure_DASH_empty_DASH_block9769.$var)?ensure_DASH_empty_DASH_block9769.$var.app(l2761849,("anonymous functions"),chk2834447):R.ffi.throwNonFunApp(L[618],ensure_DASH_empty_DASH_block9769.$var,[l2761849,("anonymous functions"),chk2834447]);
};
try {
if(--R.GAS > 0) {
$z44504451 = $f44564457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44564457,
"from":L[618]});
}
} catch($e44484449) {
if(R.isCont($e44484449)) {
var $ss44524453 = {"from":L[618],
"go":function(ann_DASH_check_DASH_temp6024458) {
return $Hann_DASH_check_DASH_temp14564459(ann_DASH_check_DASH_temp6024458);
}};
$e44484449.stack[R.EXN_STACKHEIGHT++] = $ss44524453;
}
if(R.isPyretException($e44484449)) {
$e44484449.pyretStack.push(L[618]);
}
throw $e44484449;
}
var $ret44544455 = $Hann_DASH_check_DASH_temp14564459($z44504451);
++R.GAS;
return $ret44544455;
});
var anf_arg6044440 = R.makeObject({"none":anf_obj6014445,
"some":anf_obj6034446});
var anf_arg6064441 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[617],0,arguments);
}
var ann_DASH_check_DASH_temp6054444 = R.throwNoBranchesMatched(L[617],("cases"));
return ann_DASH_check_DASH_temp6054444;
});
var $z44314432 = D;
var $f44374438 = function(_) {
return R.isFunction(anf_fun5994439)?anf_fun5994439.app(anf_arg6044440,anf_arg6064441):R.ffi.throwNonFunApp(L[617],anf_fun5994439,[anf_arg6044440,anf_arg6064441]);
};
try {
if(--R.GAS > 0) {
$z44314432 = $f44374438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44374438,
"from":L[617]});
}
} catch($e44294430) {
if(R.isCont($e44294430)) {
var $ss44334434 = {"from":L[617],
"go":function(anf_begin_app_dropped14574442) {
return $Hanf_begin_app_dropped14704443(anf_begin_app_dropped14574442,_check2821846,ann2791847,args2781844,body2811848,lists1118,params2771850,self2751851,wrap_DASH_visit_DASH_check8067);
}};
$e44294430.stack[R.EXN_STACKHEIGHT++] = $ss44334434;
}
if(R.isPyretException($e44294430)) {
$e44294430.pyretStack.push(L[617]);
}
throw $e44294430;
}
var $ret44354436 = $Hanf_begin_app_dropped14704443($z44314432,_check2821846,ann2791847,args2781844,body2811848,lists1118,params2771850,self2751851,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret44354436;
};
var $Hanf_begin_app_dropped14704443 = function(anf_begin_app_dropped14574442,_check2821846,ann2791847,args2781844,body2811848,lists1118,params2771850,self2751851,wrap_DASH_visit_DASH_check8067) {
var anf_fun6074472 = G(lists1118,"all",L[622]);
var anf_arg6104473 = R.makeFunction(function(recv_DASH_734476) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[621],1,arguments);
}
var anf_fun6094487 = G(recv_DASH_734476,"visit",L[621]);
var $z44794480 = D;
var $f44854486 = function(_) {
return R.isFunction(anf_fun6094487)?anf_fun6094487.app(self2751851):R.ffi.throwNonFunApp(L[621],anf_fun6094487,[self2751851]);
};
try {
if(--R.GAS > 0) {
$z44794480 = $f44854486();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44854486,
"from":L[621]});
}
} catch($e44774478) {
if(R.isCont($e44774478)) {
var $ss44814482 = {"from":L[621],
"go":function(ann_DASH_check_DASH_temp6084488) {
return $Hann_DASH_check_DASH_temp14584489(ann_DASH_check_DASH_temp6084488);
}};
$e44774478.stack[R.EXN_STACKHEIGHT++] = $ss44814482;
}
if(R.isPyretException($e44774478)) {
$e44774478.pyretStack.push(L[621]);
}
throw $e44774478;
}
var $ret44834484 = $Hann_DASH_check_DASH_temp14584489($z44794480);
++R.GAS;
return $ret44834484;
});
var $z44644465 = D;
var $f44704471 = function(_) {
return R.isFunction(anf_fun6074472)?anf_fun6074472.app(anf_arg6104473,params2771850):R.ffi.throwNonFunApp(L[620],anf_fun6074472,[anf_arg6104473,params2771850]);
};
try {
if(--R.GAS > 0) {
$z44644465 = $f44704471();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44704471,
"from":L[620]});
}
} catch($e44624463) {
if(R.isCont($e44624463)) {
var $ss44664467 = {"from":L[620],
"go":function(and_DASH_oper_DASH_724474) {
return $Hand_DASH_oper_DASH_14694475(and_DASH_oper_DASH_724474,_check2821846,ann2791847,args2781844,body2811848,lists1118,self2751851,wrap_DASH_visit_DASH_check8067);
}};
$e44624463.stack[R.EXN_STACKHEIGHT++] = $ss44664467;
}
if(R.isPyretException($e44624463)) {
$e44624463.pyretStack.push(L[620]);
}
throw $e44624463;
}
var $ret44684469 = $Hand_DASH_oper_DASH_14694475($z44644465,_check2821846,ann2791847,args2781844,body2811848,lists1118,self2751851,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret44684469;
};
var $Hand_DASH_oper_DASH_14694475 = function(and_DASH_oper_DASH_724474,_check2821846,ann2791847,args2781844,body2811848,lists1118,self2751851,wrap_DASH_visit_DASH_check8067) {
var if_helper6114503 = R.makeFunction(function(if_helper_arg6124535) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[620],1,arguments);
}
var ann_DASH_check_DASH_temp5984536 = if_helper_arg6124535;
return ann_DASH_check_DASH_temp5984536;
});
var anf_if6154534 = R.isBoolean(and_DASH_oper_DASH_724474);
if(R.isPyretTrue(anf_if6154534)) {
if(R.isPyretTrue(and_DASH_oper_DASH_724474)) {
var anf_fun6174500 = G(lists1118,"all",L[624]);
var anf_arg6204501 = R.makeFunction(function(recv_DASH_754505) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[623],1,arguments);
}
var anf_fun6194516 = G(recv_DASH_754505,"visit",L[623]);
var $z45084509 = D;
var $f45144515 = function(_) {
return R.isFunction(anf_fun6194516)?anf_fun6194516.app(self2751851):R.ffi.throwNonFunApp(L[623],anf_fun6194516,[self2751851]);
};
try {
if(--R.GAS > 0) {
$z45084509 = $f45144515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45144515,
"from":L[623]});
}
} catch($e45064507) {
if(R.isCont($e45064507)) {
var $ss45104511 = {"from":L[623],
"go":function(ann_DASH_check_DASH_temp6184517) {
return $Hann_DASH_check_DASH_temp14594518(ann_DASH_check_DASH_temp6184517);
}};
$e45064507.stack[R.EXN_STACKHEIGHT++] = $ss45104511;
}
if(R.isPyretException($e45064507)) {
$e45064507.pyretStack.push(L[623]);
}
throw $e45064507;
}
var $ret45124513 = $Hann_DASH_check_DASH_temp14594518($z45084509);
++R.GAS;
return $ret45124513;
});
var $z44924493 = D;
var $f44984499 = function(_) {
return R.isFunction(anf_fun6174500)?anf_fun6174500.app(anf_arg6204501,args2781844):R.ffi.throwNonFunApp(L[620],anf_fun6174500,[anf_arg6204501,args2781844]);
};
try {
if(--R.GAS > 0) {
$z44924493 = $f44984499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44984499,
"from":L[620]});
}
} catch($e44904491) {
if(R.isCont($e44904491)) {
var $ss44944495 = {"from":L[620],
"go":function(and_DASH_oper_DASH_744502) {
return $Hand_DASH_oper_DASH_14674504(and_DASH_oper_DASH_744502,_check2821846,ann2791847,body2811848,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067);
}};
$e44904491.stack[R.EXN_STACKHEIGHT++] = $ss44944495;
}
if(R.isPyretException($e44904491)) {
$e44904491.pyretStack.push(L[620]);
}
throw $e44904491;
}
var $ret44964497 = $Hand_DASH_oper_DASH_14674504($z44924493,_check2821846,ann2791847,body2811848,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret44964497;
} else {
var $z45214522 = D;
var $f45274528 = function(_) {
return R.isFunction(if_helper6114503)?if_helper6114503.app((false)):R.ffi.throwNonFunApp(L[620],if_helper6114503,[(false)]);
};
try {
if(--R.GAS > 0) {
$z45214522 = $f45274528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45274528,
"from":L[620]});
}
} catch($e45194520) {
if(R.isCont($e45194520)) {
var $ss45234524 = {"from":L[620],
"go":function(cont_tail_app6164529) {
return $Hcont_tail_app14684530(cont_tail_app6164529);
}};
$e45194520.stack[R.EXN_STACKHEIGHT++] = $ss45234524;
}
if(R.isPyretException($e45194520)) {
$e45194520.pyretStack.push(L[620]);
}
throw $e45194520;
}
var $ret45254526 = $Hcont_tail_app14684530($z45214522);
++R.GAS;
return $ret45254526;
}
} else {
var cont_tail_arg6134533 = R.throwNonBooleanOp(L[625],("first"),("and"),and_DASH_oper_DASH_724474);
if(--R.GAS > 0) {
$z45314532 = R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6134533):R.ffi.throwNonFunApp(L[625],if_helper6114503,[cont_tail_arg6134533]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6134533):R.ffi.throwNonFunApp(L[625],if_helper6114503,[cont_tail_arg6134533]);
},
"from":L[625]});
}
++R.GAS;
return $z45314532;
}
};
var $Hand_DASH_oper_DASH_14674504 = function(and_DASH_oper_DASH_744502,_check2821846,ann2791847,body2811848,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067) {
var anf_if6234565 = R.isBoolean(and_DASH_oper_DASH_744502);
if(R.isPyretTrue(anf_if6234565)) {
if(R.isPyretTrue(and_DASH_oper_DASH_744502)) {
var anf_fun6254547 = G(ann2791847,"visit",L[626]);
var $z45394540 = D;
var $f45454546 = function(_) {
return R.isFunction(anf_fun6254547)?anf_fun6254547.app(self2751851):R.ffi.throwNonFunApp(L[620],anf_fun6254547,[self2751851]);
};
try {
if(--R.GAS > 0) {
$z45394540 = $f45454546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45454546,
"from":L[620]});
}
} catch($e45374538) {
if(R.isCont($e45374538)) {
var $ss45414542 = {"from":L[620],
"go":function(and_DASH_oper_DASH_764548) {
return $Hand_DASH_oper_DASH_14654549(and_DASH_oper_DASH_764548,_check2821846,body2811848,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067);
}};
$e45374538.stack[R.EXN_STACKHEIGHT++] = $ss45414542;
}
if(R.isPyretException($e45374538)) {
$e45374538.pyretStack.push(L[620]);
}
throw $e45374538;
}
var $ret45434544 = $Hand_DASH_oper_DASH_14654549($z45394540,_check2821846,body2811848,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret45434544;
} else {
var $z45524553 = D;
var $f45584559 = function(_) {
return R.isFunction(if_helper6114503)?if_helper6114503.app((false)):R.ffi.throwNonFunApp(L[620],if_helper6114503,[(false)]);
};
try {
if(--R.GAS > 0) {
$z45524553 = $f45584559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45584559,
"from":L[620]});
}
} catch($e45504551) {
if(R.isCont($e45504551)) {
var $ss45544555 = {"from":L[620],
"go":function(cont_tail_app6244560) {
return $Hcont_tail_app14664561(cont_tail_app6244560);
}};
$e45504551.stack[R.EXN_STACKHEIGHT++] = $ss45544555;
}
if(R.isPyretException($e45504551)) {
$e45504551.pyretStack.push(L[620]);
}
throw $e45504551;
}
var $ret45564557 = $Hcont_tail_app14664561($z45524553);
++R.GAS;
return $ret45564557;
}
} else {
var cont_tail_arg6214564 = R.throwNonBooleanOp(L[627],("first"),("and"),and_DASH_oper_DASH_744502);
if(--R.GAS > 0) {
$z45624563 = R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6214564):R.ffi.throwNonFunApp(L[627],if_helper6114503,[cont_tail_arg6214564]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6214564):R.ffi.throwNonFunApp(L[627],if_helper6114503,[cont_tail_arg6214564]);
},
"from":L[627]});
}
++R.GAS;
return $z45624563;
}
};
var $Hand_DASH_oper_DASH_14654549 = function(and_DASH_oper_DASH_764548,_check2821846,body2811848,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067) {
var anf_if6284594 = R.isBoolean(and_DASH_oper_DASH_764548);
if(R.isPyretTrue(anf_if6284594)) {
if(R.isPyretTrue(and_DASH_oper_DASH_764548)) {
var anf_fun6304576 = G(body2811848,"visit",L[628]);
var $z45684569 = D;
var $f45744575 = function(_) {
return R.isFunction(anf_fun6304576)?anf_fun6304576.app(self2751851):R.ffi.throwNonFunApp(L[620],anf_fun6304576,[self2751851]);
};
try {
if(--R.GAS > 0) {
$z45684569 = $f45744575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45744575,
"from":L[620]});
}
} catch($e45664567) {
if(R.isCont($e45664567)) {
var $ss45704571 = {"from":L[620],
"go":function(and_DASH_oper_DASH_774577) {
return $Hand_DASH_oper_DASH_14634578(and_DASH_oper_DASH_774577,_check2821846,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067);
}};
$e45664567.stack[R.EXN_STACKHEIGHT++] = $ss45704571;
}
if(R.isPyretException($e45664567)) {
$e45664567.pyretStack.push(L[620]);
}
throw $e45664567;
}
var $ret45724573 = $Hand_DASH_oper_DASH_14634578($z45684569,_check2821846,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret45724573;
} else {
var $z45814582 = D;
var $f45874588 = function(_) {
return R.isFunction(if_helper6114503)?if_helper6114503.app((false)):R.ffi.throwNonFunApp(L[620],if_helper6114503,[(false)]);
};
try {
if(--R.GAS > 0) {
$z45814582 = $f45874588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45874588,
"from":L[620]});
}
} catch($e45794580) {
if(R.isCont($e45794580)) {
var $ss45834584 = {"from":L[620],
"go":function(cont_tail_app6294589) {
return $Hcont_tail_app14644590(cont_tail_app6294589);
}};
$e45794580.stack[R.EXN_STACKHEIGHT++] = $ss45834584;
}
if(R.isPyretException($e45794580)) {
$e45794580.pyretStack.push(L[620]);
}
throw $e45794580;
}
var $ret45854586 = $Hcont_tail_app14644590($z45814582);
++R.GAS;
return $ret45854586;
}
} else {
var cont_tail_arg6264593 = R.throwNonBooleanOp(L[629],("first"),("and"),and_DASH_oper_DASH_764548);
if(--R.GAS > 0) {
$z45914592 = R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6264593):R.ffi.throwNonFunApp(L[629],if_helper6114503,[cont_tail_arg6264593]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6264593):R.ffi.throwNonFunApp(L[629],if_helper6114503,[cont_tail_arg6264593]);
},
"from":L[629]});
}
++R.GAS;
return $z45914592;
}
};
var $Hand_DASH_oper_DASH_14634578 = function(and_DASH_oper_DASH_774577,_check2821846,if_helper6114503,self2751851,wrap_DASH_visit_DASH_check8067) {
var anf_if6334622 = R.isBoolean(and_DASH_oper_DASH_774577);
if(R.isPyretTrue(anf_if6334622)) {
if(R.isPyretTrue(and_DASH_oper_DASH_774577)) {
var $z45974598 = D;
var $f46034604 = function(_) {
return R.isFunction(wrap_DASH_visit_DASH_check8067.$var)?wrap_DASH_visit_DASH_check8067.$var.app(self2751851,_check2821846):R.ffi.throwNonFunApp(L[620],wrap_DASH_visit_DASH_check8067.$var,[self2751851,_check2821846]);
};
try {
if(--R.GAS > 0) {
$z45974598 = $f46034604();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46034604,
"from":L[620]});
}
} catch($e45954596) {
if(R.isCont($e45954596)) {
var $ss45994600 = {"from":L[620],
"go":function(and_DASH_oper_DASH_784605) {
return $Hand_DASH_oper_DASH_14614606(and_DASH_oper_DASH_784605,if_helper6114503);
}};
$e45954596.stack[R.EXN_STACKHEIGHT++] = $ss45994600;
}
if(R.isPyretException($e45954596)) {
$e45954596.pyretStack.push(L[620]);
}
throw $e45954596;
}
var $ret46014602 = $Hand_DASH_oper_DASH_14614606($z45974598,if_helper6114503);
++R.GAS;
return $ret46014602;
} else {
var $z46094610 = D;
var $f46154616 = function(_) {
return R.isFunction(if_helper6114503)?if_helper6114503.app((false)):R.ffi.throwNonFunApp(L[620],if_helper6114503,[(false)]);
};
try {
if(--R.GAS > 0) {
$z46094610 = $f46154616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46154616,
"from":L[620]});
}
} catch($e46074608) {
if(R.isCont($e46074608)) {
var $ss46114612 = {"from":L[620],
"go":function(cont_tail_app6344617) {
return $Hcont_tail_app14624618(cont_tail_app6344617);
}};
$e46074608.stack[R.EXN_STACKHEIGHT++] = $ss46114612;
}
if(R.isPyretException($e46074608)) {
$e46074608.pyretStack.push(L[620]);
}
throw $e46074608;
}
var $ret46134614 = $Hcont_tail_app14624618($z46094610);
++R.GAS;
return $ret46134614;
}
} else {
var cont_tail_arg6314621 = R.throwNonBooleanOp(L[630],("first"),("and"),and_DASH_oper_DASH_774577);
if(--R.GAS > 0) {
$z46194620 = R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6314621):R.ffi.throwNonFunApp(L[630],if_helper6114503,[cont_tail_arg6314621]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6314621):R.ffi.throwNonFunApp(L[630],if_helper6114503,[cont_tail_arg6314621]);
},
"from":L[630]});
}
++R.GAS;
return $z46194620;
}
};
var $Hand_DASH_oper_DASH_14614606 = function(and_DASH_oper_DASH_784605,if_helper6114503) {
var anf_if6374638 = R.isBoolean(and_DASH_oper_DASH_784605);
if(R.isPyretTrue(anf_if6374638)) {
var $z46254626 = D;
var $f46314632 = function(_) {
return R.isFunction(if_helper6114503)?if_helper6114503.app(and_DASH_oper_DASH_784605):R.ffi.throwNonFunApp(L[620],if_helper6114503,[and_DASH_oper_DASH_784605]);
};
try {
if(--R.GAS > 0) {
$z46254626 = $f46314632();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46314632,
"from":L[620]});
}
} catch($e46234624) {
if(R.isCont($e46234624)) {
var $ss46274628 = {"from":L[620],
"go":function(cont_tail_app6384633) {
return $Hcont_tail_app14604634(cont_tail_app6384633);
}};
$e46234624.stack[R.EXN_STACKHEIGHT++] = $ss46274628;
}
if(R.isPyretException($e46234624)) {
$e46234624.pyretStack.push(L[620]);
}
throw $e46234624;
}
var $ret46294630 = $Hcont_tail_app14604634($z46254626);
++R.GAS;
return $ret46294630;
} else {
var cont_tail_arg6354637 = R.throwNonBooleanOp(L[631],("second"),("and"),and_DASH_oper_DASH_784605);
if(--R.GAS > 0) {
$z46354636 = R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6354637):R.ffi.throwNonFunApp(L[631],if_helper6114503,[cont_tail_arg6354637]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper6114503)?if_helper6114503.app(cont_tail_arg6354637):R.ffi.throwNonFunApp(L[631],if_helper6114503,[cont_tail_arg6354637]);
},
"from":L[631]});
}
++R.GAS;
return $z46354636;
}
};
var $Hcont_tail_app14604634 = function(cont_tail_app6384633) {
return cont_tail_app6384633;
};
var $Hcont_tail_app14624618 = function(cont_tail_app6344617) {
return cont_tail_app6344617;
};
var $Hcont_tail_app14644590 = function(cont_tail_app6294589) {
return cont_tail_app6294589;
};
var $Hcont_tail_app14664561 = function(cont_tail_app6244560) {
return cont_tail_app6244560;
};
var $Hann_DASH_check_DASH_temp14594518 = function(ann_DASH_check_DASH_temp6184517) {
return ann_DASH_check_DASH_temp6184517;
};
var $Hcont_tail_app14684530 = function(cont_tail_app6164529) {
return cont_tail_app6164529;
};
var $Hann_DASH_check_DASH_temp14584489 = function(ann_DASH_check_DASH_temp6084488) {
return ann_DASH_check_DASH_temp6084488;
};
var $Hann_DASH_check_DASH_temp14564459 = function(ann_DASH_check_DASH_temp6024458) {
return ann_DASH_check_DASH_temp6024458;
};
var $Hanf_arg14541872 = function(anf_arg5571865,_check2731866,ann2701867,args2691868,body2721869,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2681870,lists1118,self2671871,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4) {
var when_DASH_644664 = R.equiv(anf_arg5571865,(0));
var if_helper5584650 = R.makeFunction(function(if_helper_arg5594669) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[633],1,arguments);
}
if_helper_arg5594669;
var $z46724673 = D;
var $f46784679 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(args2691868):R.ffi.throwNonFunApp(L[635],ensure_DASH_unique_DASH_ids9973.$var,[args2691868]);
};
try {
if(--R.GAS > 0) {
$z46724673 = $f46784679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46784679,
"from":L[635]});
}
} catch($e46704671) {
if(R.isCont($e46704671)) {
var $ss46744675 = {"from":L[635],
"go":function(anf_begin_app_dropped14364680) {
return $Hanf_begin_app_dropped14494681(anf_begin_app_dropped14364680,_check2731866,ann2701867,args2691868,body2721869,ensure_DASH_empty_DASH_block9769,l2681870,lists1118,self2671871,wrap_DASH_visit_DASH_check8067,nothing4);
}};
$e46704671.stack[R.EXN_STACKHEIGHT++] = $ss46744675;
}
if(R.isPyretException($e46704671)) {
$e46704671.pyretStack.push(L[635]);
}
throw $e46704671;
}
var $ret46764677 = $Hanf_begin_app_dropped14494681($z46724673,_check2731866,ann2701867,args2691868,body2721869,ensure_DASH_empty_DASH_block9769,l2681870,lists1118,self2671871,wrap_DASH_visit_DASH_check8067,nothing4);
++R.GAS;
return $ret46764677;
});
var anf_if5944668 = R.isBoolean(when_DASH_644664);
if(R.isPyretTrue(anf_if5944668)) {
if(R.isPyretTrue(when_DASH_644664)) {
var $z46414642 = D;
var $f46474648 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot have a method with zero arguments"),l2681870):R.ffi.throwNonFunApp(L[632],wf_DASH_error7659.$var,[("Cannot have a method with zero arguments"),l2681870]);
};
try {
if(--R.GAS > 0) {
$z46414642 = $f46474648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46474648,
"from":L[632]});
}
} catch($e46394640) {
if(R.isCont($e46394640)) {
var $ss46434644 = {"from":L[632],
"go":function(anf_begin_app_dropped14504649) {
return $Hanf_begin_app_dropped14524651(anf_begin_app_dropped14504649,if_helper5584650,nothing4);
}};
$e46394640.stack[R.EXN_STACKHEIGHT++] = $ss46434644;
}
if(R.isPyretException($e46394640)) {
$e46394640.pyretStack.push(L[632]);
}
throw $e46394640;
}
var $ret46454646 = $Hanf_begin_app_dropped14524651($z46414642,if_helper5584650,nothing4);
++R.GAS;
return $ret46454646;
} else {
var $z46544655 = D;
var $f46604661 = function(_) {
return R.isFunction(if_helper5584650)?if_helper5584650.app(nothing4):R.ffi.throwNonFunApp(L[633],if_helper5584650,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z46544655 = $f46604661();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46604661,
"from":L[633]});
}
} catch($e46524653) {
if(R.isCont($e46524653)) {
var $ss46564657 = {"from":L[633],
"go":function(cont_tail_app5954662) {
return $Hcont_tail_app14534663(cont_tail_app5954662);
}};
$e46524653.stack[R.EXN_STACKHEIGHT++] = $ss46564657;
}
if(R.isPyretException($e46524653)) {
$e46524653.pyretStack.push(L[633]);
}
throw $e46524653;
}
var $ret46584659 = $Hcont_tail_app14534663($z46544655);
++R.GAS;
return $ret46584659;
}
} else {
var cont_tail_arg5924667 = R.throwNonBooleanCondition(L[634],("when"),when_DASH_644664);
if(--R.GAS > 0) {
$z46654666 = R.isFunction(if_helper5584650)?if_helper5584650.app(cont_tail_arg5924667):R.ffi.throwNonFunApp(L[634],if_helper5584650,[cont_tail_arg5924667]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5584650)?if_helper5584650.app(cont_tail_arg5924667):R.ffi.throwNonFunApp(L[634],if_helper5584650,[cont_tail_arg5924667]);
},
"from":L[634]});
}
++R.GAS;
return $z46654666;
}
};
var $Hanf_begin_app_dropped14524651 = function(anf_begin_app_dropped14504649,if_helper5584650,nothing4) {
var $z46844685 = D;
var $f46904691 = function(_) {
return R.isFunction(if_helper5584650)?if_helper5584650.app(nothing4):R.ffi.throwNonFunApp(L[633],if_helper5584650,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z46844685 = $f46904691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46904691,
"from":L[633]});
}
} catch($e46824683) {
if(R.isCont($e46824683)) {
var $ss46864687 = {"from":L[633],
"go":function(cont_tail_app5964692) {
return $Hcont_tail_app14514693(cont_tail_app5964692);
}};
$e46824683.stack[R.EXN_STACKHEIGHT++] = $ss46864687;
}
if(R.isPyretException($e46824683)) {
$e46824683.pyretStack.push(L[633]);
}
throw $e46824683;
}
var $ret46884689 = $Hcont_tail_app14514693($z46844685);
++R.GAS;
return $ret46884689;
};
var $Hcont_tail_app14514693 = function(cont_tail_app5964692) {
return cont_tail_app5964692;
};
var $Hcont_tail_app14534663 = function(cont_tail_app5954662) {
return cont_tail_app5954662;
};
var $Hanf_begin_app_dropped14494681 = function(anf_begin_app_dropped14364680,_check2731866,ann2701867,args2691868,body2721869,ensure_DASH_empty_DASH_block9769,l2681870,lists1118,self2671871,wrap_DASH_visit_DASH_check8067,nothing4) {
var cases_DASH_val654726 = _check2731866;
var anf_fun5604704 = G(cases_DASH_val654726,"_match",L[636]);
var anf_obj5624710 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[638],0,arguments);
}
var ann_DASH_check_DASH_temp5614725 = nothing4;
return ann_DASH_check_DASH_temp5614725;
});
var anf_obj5644711 = R.makeFunction(function(chk2744712) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[637],1,arguments);
}
var $z47154716 = D;
var $f47214722 = function(_) {
return R.isFunction(ensure_DASH_empty_DASH_block9769.$var)?ensure_DASH_empty_DASH_block9769.$var.app(l2681870,("methods"),chk2744712):R.ffi.throwNonFunApp(L[637],ensure_DASH_empty_DASH_block9769.$var,[l2681870,("methods"),chk2744712]);
};
try {
if(--R.GAS > 0) {
$z47154716 = $f47214722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47214722,
"from":L[637]});
}
} catch($e47134714) {
if(R.isCont($e47134714)) {
var $ss47174718 = {"from":L[637],
"go":function(ann_DASH_check_DASH_temp5634723) {
return $Hann_DASH_check_DASH_temp14374724(ann_DASH_check_DASH_temp5634723);
}};
$e47134714.stack[R.EXN_STACKHEIGHT++] = $ss47174718;
}
if(R.isPyretException($e47134714)) {
$e47134714.pyretStack.push(L[637]);
}
throw $e47134714;
}
var $ret47194720 = $Hann_DASH_check_DASH_temp14374724($z47154716);
++R.GAS;
return $ret47194720;
});
var anf_arg5654705 = R.makeObject({"none":anf_obj5624710,
"some":anf_obj5644711});
var anf_arg5674706 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[636],0,arguments);
}
var ann_DASH_check_DASH_temp5664709 = R.throwNoBranchesMatched(L[636],("cases"));
return ann_DASH_check_DASH_temp5664709;
});
var $z46964697 = D;
var $f47024703 = function(_) {
return R.isFunction(anf_fun5604704)?anf_fun5604704.app(anf_arg5654705,anf_arg5674706):R.ffi.throwNonFunApp(L[636],anf_fun5604704,[anf_arg5654705,anf_arg5674706]);
};
try {
if(--R.GAS > 0) {
$z46964697 = $f47024703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47024703,
"from":L[636]});
}
} catch($e46944695) {
if(R.isCont($e46944695)) {
var $ss46984699 = {"from":L[636],
"go":function(anf_begin_app_dropped14384707) {
return $Hanf_begin_app_dropped14484708(anf_begin_app_dropped14384707,_check2731866,ann2701867,args2691868,body2721869,lists1118,self2671871,wrap_DASH_visit_DASH_check8067);
}};
$e46944695.stack[R.EXN_STACKHEIGHT++] = $ss46984699;
}
if(R.isPyretException($e46944695)) {
$e46944695.pyretStack.push(L[636]);
}
throw $e46944695;
}
var $ret47004701 = $Hanf_begin_app_dropped14484708($z46964697,_check2731866,ann2701867,args2691868,body2721869,lists1118,self2671871,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret47004701;
};
var $Hanf_begin_app_dropped14484708 = function(anf_begin_app_dropped14384707,_check2731866,ann2701867,args2691868,body2721869,lists1118,self2671871,wrap_DASH_visit_DASH_check8067) {
var anf_fun5684737 = G(lists1118,"all",L[641]);
var anf_arg5714738 = R.makeFunction(function(recv_DASH_674741) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[640],1,arguments);
}
var anf_fun5704752 = G(recv_DASH_674741,"visit",L[640]);
var $z47444745 = D;
var $f47504751 = function(_) {
return R.isFunction(anf_fun5704752)?anf_fun5704752.app(self2671871):R.ffi.throwNonFunApp(L[640],anf_fun5704752,[self2671871]);
};
try {
if(--R.GAS > 0) {
$z47444745 = $f47504751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47504751,
"from":L[640]});
}
} catch($e47424743) {
if(R.isCont($e47424743)) {
var $ss47464747 = {"from":L[640],
"go":function(ann_DASH_check_DASH_temp5694753) {
return $Hann_DASH_check_DASH_temp14394754(ann_DASH_check_DASH_temp5694753);
}};
$e47424743.stack[R.EXN_STACKHEIGHT++] = $ss47464747;
}
if(R.isPyretException($e47424743)) {
$e47424743.pyretStack.push(L[640]);
}
throw $e47424743;
}
var $ret47484749 = $Hann_DASH_check_DASH_temp14394754($z47444745);
++R.GAS;
return $ret47484749;
});
var $z47294730 = D;
var $f47354736 = function(_) {
return R.isFunction(anf_fun5684737)?anf_fun5684737.app(anf_arg5714738,args2691868):R.ffi.throwNonFunApp(L[639],anf_fun5684737,[anf_arg5714738,args2691868]);
};
try {
if(--R.GAS > 0) {
$z47294730 = $f47354736();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47354736,
"from":L[639]});
}
} catch($e47274728) {
if(R.isCont($e47274728)) {
var $ss47314732 = {"from":L[639],
"go":function(and_DASH_oper_DASH_664739) {
return $Hand_DASH_oper_DASH_14474740(and_DASH_oper_DASH_664739,_check2731866,ann2701867,body2721869,self2671871,wrap_DASH_visit_DASH_check8067);
}};
$e47274728.stack[R.EXN_STACKHEIGHT++] = $ss47314732;
}
if(R.isPyretException($e47274728)) {
$e47274728.pyretStack.push(L[639]);
}
throw $e47274728;
}
var $ret47334734 = $Hand_DASH_oper_DASH_14474740($z47294730,_check2731866,ann2701867,body2721869,self2671871,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret47334734;
};
var $Hand_DASH_oper_DASH_14474740 = function(and_DASH_oper_DASH_664739,_check2731866,ann2701867,body2721869,self2671871,wrap_DASH_visit_DASH_check8067) {
var if_helper5724767 = R.makeFunction(function(if_helper_arg5734785) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[639],1,arguments);
}
var ann_DASH_check_DASH_temp5554786 = if_helper_arg5734785;
return ann_DASH_check_DASH_temp5554786;
});
var anf_if5764784 = R.isBoolean(and_DASH_oper_DASH_664739);
if(R.isPyretTrue(anf_if5764784)) {
if(R.isPyretTrue(and_DASH_oper_DASH_664739)) {
var anf_fun5784765 = G(ann2701867,"visit",L[642]);
var $z47574758 = D;
var $f47634764 = function(_) {
return R.isFunction(anf_fun5784765)?anf_fun5784765.app(self2671871):R.ffi.throwNonFunApp(L[639],anf_fun5784765,[self2671871]);
};
try {
if(--R.GAS > 0) {
$z47574758 = $f47634764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47634764,
"from":L[639]});
}
} catch($e47554756) {
if(R.isCont($e47554756)) {
var $ss47594760 = {"from":L[639],
"go":function(and_DASH_oper_DASH_684766) {
return $Hand_DASH_oper_DASH_14454768(and_DASH_oper_DASH_684766,_check2731866,body2721869,if_helper5724767,self2671871,wrap_DASH_visit_DASH_check8067);
}};
$e47554756.stack[R.EXN_STACKHEIGHT++] = $ss47594760;
}
if(R.isPyretException($e47554756)) {
$e47554756.pyretStack.push(L[639]);
}
throw $e47554756;
}
var $ret47614762 = $Hand_DASH_oper_DASH_14454768($z47574758,_check2731866,body2721869,if_helper5724767,self2671871,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret47614762;
} else {
var $z47714772 = D;
var $f47774778 = function(_) {
return R.isFunction(if_helper5724767)?if_helper5724767.app((false)):R.ffi.throwNonFunApp(L[639],if_helper5724767,[(false)]);
};
try {
if(--R.GAS > 0) {
$z47714772 = $f47774778();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47774778,
"from":L[639]});
}
} catch($e47694770) {
if(R.isCont($e47694770)) {
var $ss47734774 = {"from":L[639],
"go":function(cont_tail_app5774779) {
return $Hcont_tail_app14464780(cont_tail_app5774779);
}};
$e47694770.stack[R.EXN_STACKHEIGHT++] = $ss47734774;
}
if(R.isPyretException($e47694770)) {
$e47694770.pyretStack.push(L[639]);
}
throw $e47694770;
}
var $ret47754776 = $Hcont_tail_app14464780($z47714772);
++R.GAS;
return $ret47754776;
}
} else {
var cont_tail_arg5744783 = R.throwNonBooleanOp(L[643],("first"),("and"),and_DASH_oper_DASH_664739);
if(--R.GAS > 0) {
$z47814782 = R.isFunction(if_helper5724767)?if_helper5724767.app(cont_tail_arg5744783):R.ffi.throwNonFunApp(L[643],if_helper5724767,[cont_tail_arg5744783]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5724767)?if_helper5724767.app(cont_tail_arg5744783):R.ffi.throwNonFunApp(L[643],if_helper5724767,[cont_tail_arg5744783]);
},
"from":L[643]});
}
++R.GAS;
return $z47814782;
}
};
var $Hand_DASH_oper_DASH_14454768 = function(and_DASH_oper_DASH_684766,_check2731866,body2721869,if_helper5724767,self2671871,wrap_DASH_visit_DASH_check8067) {
var anf_if5814815 = R.isBoolean(and_DASH_oper_DASH_684766);
if(R.isPyretTrue(anf_if5814815)) {
if(R.isPyretTrue(and_DASH_oper_DASH_684766)) {
var anf_fun5834797 = G(body2721869,"visit",L[644]);
var $z47894790 = D;
var $f47954796 = function(_) {
return R.isFunction(anf_fun5834797)?anf_fun5834797.app(self2671871):R.ffi.throwNonFunApp(L[639],anf_fun5834797,[self2671871]);
};
try {
if(--R.GAS > 0) {
$z47894790 = $f47954796();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47954796,
"from":L[639]});
}
} catch($e47874788) {
if(R.isCont($e47874788)) {
var $ss47914792 = {"from":L[639],
"go":function(and_DASH_oper_DASH_694798) {
return $Hand_DASH_oper_DASH_14434799(and_DASH_oper_DASH_694798,_check2731866,if_helper5724767,self2671871,wrap_DASH_visit_DASH_check8067);
}};
$e47874788.stack[R.EXN_STACKHEIGHT++] = $ss47914792;
}
if(R.isPyretException($e47874788)) {
$e47874788.pyretStack.push(L[639]);
}
throw $e47874788;
}
var $ret47934794 = $Hand_DASH_oper_DASH_14434799($z47894790,_check2731866,if_helper5724767,self2671871,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret47934794;
} else {
var $z48024803 = D;
var $f48084809 = function(_) {
return R.isFunction(if_helper5724767)?if_helper5724767.app((false)):R.ffi.throwNonFunApp(L[639],if_helper5724767,[(false)]);
};
try {
if(--R.GAS > 0) {
$z48024803 = $f48084809();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48084809,
"from":L[639]});
}
} catch($e48004801) {
if(R.isCont($e48004801)) {
var $ss48044805 = {"from":L[639],
"go":function(cont_tail_app5824810) {
return $Hcont_tail_app14444811(cont_tail_app5824810);
}};
$e48004801.stack[R.EXN_STACKHEIGHT++] = $ss48044805;
}
if(R.isPyretException($e48004801)) {
$e48004801.pyretStack.push(L[639]);
}
throw $e48004801;
}
var $ret48064807 = $Hcont_tail_app14444811($z48024803);
++R.GAS;
return $ret48064807;
}
} else {
var cont_tail_arg5794814 = R.throwNonBooleanOp(L[645],("first"),("and"),and_DASH_oper_DASH_684766);
if(--R.GAS > 0) {
$z48124813 = R.isFunction(if_helper5724767)?if_helper5724767.app(cont_tail_arg5794814):R.ffi.throwNonFunApp(L[645],if_helper5724767,[cont_tail_arg5794814]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5724767)?if_helper5724767.app(cont_tail_arg5794814):R.ffi.throwNonFunApp(L[645],if_helper5724767,[cont_tail_arg5794814]);
},
"from":L[645]});
}
++R.GAS;
return $z48124813;
}
};
var $Hand_DASH_oper_DASH_14434799 = function(and_DASH_oper_DASH_694798,_check2731866,if_helper5724767,self2671871,wrap_DASH_visit_DASH_check8067) {
var anf_if5864843 = R.isBoolean(and_DASH_oper_DASH_694798);
if(R.isPyretTrue(anf_if5864843)) {
if(R.isPyretTrue(and_DASH_oper_DASH_694798)) {
var $z48184819 = D;
var $f48244825 = function(_) {
return R.isFunction(wrap_DASH_visit_DASH_check8067.$var)?wrap_DASH_visit_DASH_check8067.$var.app(self2671871,_check2731866):R.ffi.throwNonFunApp(L[639],wrap_DASH_visit_DASH_check8067.$var,[self2671871,_check2731866]);
};
try {
if(--R.GAS > 0) {
$z48184819 = $f48244825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48244825,
"from":L[639]});
}
} catch($e48164817) {
if(R.isCont($e48164817)) {
var $ss48204821 = {"from":L[639],
"go":function(and_DASH_oper_DASH_704826) {
return $Hand_DASH_oper_DASH_14414827(and_DASH_oper_DASH_704826,if_helper5724767);
}};
$e48164817.stack[R.EXN_STACKHEIGHT++] = $ss48204821;
}
if(R.isPyretException($e48164817)) {
$e48164817.pyretStack.push(L[639]);
}
throw $e48164817;
}
var $ret48224823 = $Hand_DASH_oper_DASH_14414827($z48184819,if_helper5724767);
++R.GAS;
return $ret48224823;
} else {
var $z48304831 = D;
var $f48364837 = function(_) {
return R.isFunction(if_helper5724767)?if_helper5724767.app((false)):R.ffi.throwNonFunApp(L[639],if_helper5724767,[(false)]);
};
try {
if(--R.GAS > 0) {
$z48304831 = $f48364837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48364837,
"from":L[639]});
}
} catch($e48284829) {
if(R.isCont($e48284829)) {
var $ss48324833 = {"from":L[639],
"go":function(cont_tail_app5874838) {
return $Hcont_tail_app14424839(cont_tail_app5874838);
}};
$e48284829.stack[R.EXN_STACKHEIGHT++] = $ss48324833;
}
if(R.isPyretException($e48284829)) {
$e48284829.pyretStack.push(L[639]);
}
throw $e48284829;
}
var $ret48344835 = $Hcont_tail_app14424839($z48304831);
++R.GAS;
return $ret48344835;
}
} else {
var cont_tail_arg5844842 = R.throwNonBooleanOp(L[646],("first"),("and"),and_DASH_oper_DASH_694798);
if(--R.GAS > 0) {
$z48404841 = R.isFunction(if_helper5724767)?if_helper5724767.app(cont_tail_arg5844842):R.ffi.throwNonFunApp(L[646],if_helper5724767,[cont_tail_arg5844842]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5724767)?if_helper5724767.app(cont_tail_arg5844842):R.ffi.throwNonFunApp(L[646],if_helper5724767,[cont_tail_arg5844842]);
},
"from":L[646]});
}
++R.GAS;
return $z48404841;
}
};
var $Hand_DASH_oper_DASH_14414827 = function(and_DASH_oper_DASH_704826,if_helper5724767) {
var anf_if5904859 = R.isBoolean(and_DASH_oper_DASH_704826);
if(R.isPyretTrue(anf_if5904859)) {
var $z48464847 = D;
var $f48524853 = function(_) {
return R.isFunction(if_helper5724767)?if_helper5724767.app(and_DASH_oper_DASH_704826):R.ffi.throwNonFunApp(L[639],if_helper5724767,[and_DASH_oper_DASH_704826]);
};
try {
if(--R.GAS > 0) {
$z48464847 = $f48524853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48524853,
"from":L[639]});
}
} catch($e48444845) {
if(R.isCont($e48444845)) {
var $ss48484849 = {"from":L[639],
"go":function(cont_tail_app5914854) {
return $Hcont_tail_app14404855(cont_tail_app5914854);
}};
$e48444845.stack[R.EXN_STACKHEIGHT++] = $ss48484849;
}
if(R.isPyretException($e48444845)) {
$e48444845.pyretStack.push(L[639]);
}
throw $e48444845;
}
var $ret48504851 = $Hcont_tail_app14404855($z48464847);
++R.GAS;
return $ret48504851;
} else {
var cont_tail_arg5884858 = R.throwNonBooleanOp(L[647],("second"),("and"),and_DASH_oper_DASH_704826);
if(--R.GAS > 0) {
$z48564857 = R.isFunction(if_helper5724767)?if_helper5724767.app(cont_tail_arg5884858):R.ffi.throwNonFunApp(L[647],if_helper5724767,[cont_tail_arg5884858]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5724767)?if_helper5724767.app(cont_tail_arg5884858):R.ffi.throwNonFunApp(L[647],if_helper5724767,[cont_tail_arg5884858]);
},
"from":L[647]});
}
++R.GAS;
return $z48564857;
}
};
var $Hcont_tail_app14404855 = function(cont_tail_app5914854) {
return cont_tail_app5914854;
};
var $Hcont_tail_app14424839 = function(cont_tail_app5874838) {
return cont_tail_app5874838;
};
var $Hcont_tail_app14444811 = function(cont_tail_app5824810) {
return cont_tail_app5824810;
};
var $Hcont_tail_app14464780 = function(cont_tail_app5774779) {
return cont_tail_app5774779;
};
var $Hann_DASH_check_DASH_temp14394754 = function(ann_DASH_check_DASH_temp5694753) {
return ann_DASH_check_DASH_temp5694753;
};
var $Hann_DASH_check_DASH_temp14374724 = function(ann_DASH_check_DASH_temp5634723) {
return ann_DASH_check_DASH_temp5634723;
};
var $Hand_DASH_oper_DASH_14351891 = function(and_DASH_oper_DASH_591886,ann2651887,l2631888,name2641885,reserved_DASH_name7965,reserved_DASH_names7442,self2621889,value2661890,nothing4) {
var if_helper5174873 = R.makeFunction(function(if_helper_arg5184891) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[368],1,arguments);
}
var when_DASH_584918 = if_helper_arg5184891;
var if_helper5194904 = R.makeFunction(function(if_helper_arg5204923) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[653],1,arguments);
}
if_helper_arg5204923;
var anf_fun5214934 = G(name2641885,"visit",L[655]);
var $z49264927 = D;
var $f49324933 = function(_) {
return R.isFunction(anf_fun5214934)?anf_fun5214934.app(self2621889):R.ffi.throwNonFunApp(L[654],anf_fun5214934,[self2621889]);
};
try {
if(--R.GAS > 0) {
$z49264927 = $f49324933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49324933,
"from":L[654]});
}
} catch($e49244925) {
if(R.isCont($e49244925)) {
var $ss49284929 = {"from":L[654],
"go":function(and_DASH_oper_DASH_614935) {
return $Hand_DASH_oper_DASH_14274936(and_DASH_oper_DASH_614935,ann2651887,self2621889,value2661890);
}};
$e49244925.stack[R.EXN_STACKHEIGHT++] = $ss49284929;
}
if(R.isPyretException($e49244925)) {
$e49244925.pyretStack.push(L[654]);
}
throw $e49244925;
}
var $ret49304931 = $Hand_DASH_oper_DASH_14274936($z49264927,ann2651887,self2621889,value2661890);
++R.GAS;
return $ret49304931;
});
var anf_if5404922 = R.isBoolean(when_DASH_584918);
if(R.isPyretTrue(anf_if5404922)) {
if(R.isPyretTrue(when_DASH_584918)) {
var anf_arg5424902 = G(name2641885,"s",L[652]);
var $z48944895 = D;
var $f49004901 = function(_) {
return R.isFunction(reserved_DASH_name7965.$var)?reserved_DASH_name7965.$var.app(l2631888,anf_arg5424902):R.ffi.throwNonFunApp(L[651],reserved_DASH_name7965.$var,[l2631888,anf_arg5424902]);
};
try {
if(--R.GAS > 0) {
$z48944895 = $f49004901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49004901,
"from":L[651]});
}
} catch($e48924893) {
if(R.isCont($e48924893)) {
var $ss48964897 = {"from":L[651],
"go":function(anf_begin_app_dropped14284903) {
return $Hanf_begin_app_dropped14304905(anf_begin_app_dropped14284903,if_helper5194904,nothing4);
}};
$e48924893.stack[R.EXN_STACKHEIGHT++] = $ss48964897;
}
if(R.isPyretException($e48924893)) {
$e48924893.pyretStack.push(L[651]);
}
throw $e48924893;
}
var $ret48984899 = $Hanf_begin_app_dropped14304905($z48944895,if_helper5194904,nothing4);
++R.GAS;
return $ret48984899;
} else {
var $z49084909 = D;
var $f49144915 = function(_) {
return R.isFunction(if_helper5194904)?if_helper5194904.app(nothing4):R.ffi.throwNonFunApp(L[653],if_helper5194904,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z49084909 = $f49144915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49144915,
"from":L[653]});
}
} catch($e49064907) {
if(R.isCont($e49064907)) {
var $ss49104911 = {"from":L[653],
"go":function(cont_tail_app5414916) {
return $Hcont_tail_app14314917(cont_tail_app5414916);
}};
$e49064907.stack[R.EXN_STACKHEIGHT++] = $ss49104911;
}
if(R.isPyretException($e49064907)) {
$e49064907.pyretStack.push(L[653]);
}
throw $e49064907;
}
var $ret49124913 = $Hcont_tail_app14314917($z49084909);
++R.GAS;
return $ret49124913;
}
} else {
var cont_tail_arg5384921 = R.throwNonBooleanCondition(L[368],("when"),when_DASH_584918);
if(--R.GAS > 0) {
$z49194920 = R.isFunction(if_helper5194904)?if_helper5194904.app(cont_tail_arg5384921):R.ffi.throwNonFunApp(L[368],if_helper5194904,[cont_tail_arg5384921]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5194904)?if_helper5194904.app(cont_tail_arg5384921):R.ffi.throwNonFunApp(L[368],if_helper5194904,[cont_tail_arg5384921]);
},
"from":L[368]});
}
++R.GAS;
return $z49194920;
}
});
var anf_if5464890 = R.isBoolean(and_DASH_oper_DASH_591886);
if(R.isPyretTrue(anf_if5464890)) {
if(R.isPyretTrue(and_DASH_oper_DASH_591886)) {
var anf_fun5484870 = G(reserved_DASH_names7442,"member",L[649]);
var anf_arg5494871 = G(name2641885,"s",L[648]);
var $z48624863 = D;
var $f48684869 = function(_) {
return R.isFunction(anf_fun5484870)?anf_fun5484870.app(anf_arg5494871):R.ffi.throwNonFunApp(L[368],anf_fun5484870,[anf_arg5494871]);
};
try {
if(--R.GAS > 0) {
$z48624863 = $f48684869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48684869,
"from":L[368]});
}
} catch($e48604861) {
if(R.isCont($e48604861)) {
var $ss48644865 = {"from":L[368],
"go":function(and_DASH_oper_DASH_604872) {
return $Hand_DASH_oper_DASH_14334874(and_DASH_oper_DASH_604872,if_helper5174873);
}};
$e48604861.stack[R.EXN_STACKHEIGHT++] = $ss48644865;
}
if(R.isPyretException($e48604861)) {
$e48604861.pyretStack.push(L[368]);
}
throw $e48604861;
}
var $ret48664867 = $Hand_DASH_oper_DASH_14334874($z48624863,if_helper5174873);
++R.GAS;
return $ret48664867;
} else {
var $z48774878 = D;
var $f48834884 = function(_) {
return R.isFunction(if_helper5174873)?if_helper5174873.app((false)):R.ffi.throwNonFunApp(L[368],if_helper5174873,[(false)]);
};
try {
if(--R.GAS > 0) {
$z48774878 = $f48834884();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48834884,
"from":L[368]});
}
} catch($e48754876) {
if(R.isCont($e48754876)) {
var $ss48794880 = {"from":L[368],
"go":function(cont_tail_app5474885) {
return $Hcont_tail_app14344886(cont_tail_app5474885);
}};
$e48754876.stack[R.EXN_STACKHEIGHT++] = $ss48794880;
}
if(R.isPyretException($e48754876)) {
$e48754876.pyretStack.push(L[368]);
}
throw $e48754876;
}
var $ret48814882 = $Hcont_tail_app14344886($z48774878);
++R.GAS;
return $ret48814882;
}
} else {
var cont_tail_arg5444889 = R.throwNonBooleanOp(L[650],("first"),("and"),and_DASH_oper_DASH_591886);
if(--R.GAS > 0) {
$z48874888 = R.isFunction(if_helper5174873)?if_helper5174873.app(cont_tail_arg5444889):R.ffi.throwNonFunApp(L[650],if_helper5174873,[cont_tail_arg5444889]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5174873)?if_helper5174873.app(cont_tail_arg5444889):R.ffi.throwNonFunApp(L[650],if_helper5174873,[cont_tail_arg5444889]);
},
"from":L[650]});
}
++R.GAS;
return $z48874888;
}
};
var $Hand_DASH_oper_DASH_14334874 = function(and_DASH_oper_DASH_604872,if_helper5174873) {
var anf_if5524952 = R.isBoolean(and_DASH_oper_DASH_604872);
if(R.isPyretTrue(anf_if5524952)) {
var $z49394940 = D;
var $f49454946 = function(_) {
return R.isFunction(if_helper5174873)?if_helper5174873.app(and_DASH_oper_DASH_604872):R.ffi.throwNonFunApp(L[368],if_helper5174873,[and_DASH_oper_DASH_604872]);
};
try {
if(--R.GAS > 0) {
$z49394940 = $f49454946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49454946,
"from":L[368]});
}
} catch($e49374938) {
if(R.isCont($e49374938)) {
var $ss49414942 = {"from":L[368],
"go":function(cont_tail_app5534947) {
return $Hcont_tail_app14324948(cont_tail_app5534947);
}};
$e49374938.stack[R.EXN_STACKHEIGHT++] = $ss49414942;
}
if(R.isPyretException($e49374938)) {
$e49374938.pyretStack.push(L[368]);
}
throw $e49374938;
}
var $ret49434944 = $Hcont_tail_app14324948($z49394940);
++R.GAS;
return $ret49434944;
} else {
var cont_tail_arg5504951 = R.throwNonBooleanOp(L[656],("second"),("and"),and_DASH_oper_DASH_604872);
if(--R.GAS > 0) {
$z49494950 = R.isFunction(if_helper5174873)?if_helper5174873.app(cont_tail_arg5504951):R.ffi.throwNonFunApp(L[656],if_helper5174873,[cont_tail_arg5504951]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5174873)?if_helper5174873.app(cont_tail_arg5504951):R.ffi.throwNonFunApp(L[656],if_helper5174873,[cont_tail_arg5504951]);
},
"from":L[656]});
}
++R.GAS;
return $z49494950;
}
};
var $Hcont_tail_app14324948 = function(cont_tail_app5534947) {
return cont_tail_app5534947;
};
var $Hcont_tail_app14344886 = function(cont_tail_app5474885) {
return cont_tail_app5474885;
};
var $Hanf_begin_app_dropped14304905 = function(anf_begin_app_dropped14284903,if_helper5194904,nothing4) {
var $z49554956 = D;
var $f49614962 = function(_) {
return R.isFunction(if_helper5194904)?if_helper5194904.app(nothing4):R.ffi.throwNonFunApp(L[653],if_helper5194904,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z49554956 = $f49614962();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49614962,
"from":L[653]});
}
} catch($e49534954) {
if(R.isCont($e49534954)) {
var $ss49574958 = {"from":L[653],
"go":function(cont_tail_app5434963) {
return $Hcont_tail_app14294964(cont_tail_app5434963);
}};
$e49534954.stack[R.EXN_STACKHEIGHT++] = $ss49574958;
}
if(R.isPyretException($e49534954)) {
$e49534954.pyretStack.push(L[653]);
}
throw $e49534954;
}
var $ret49594960 = $Hcont_tail_app14294964($z49554956);
++R.GAS;
return $ret49594960;
};
var $Hcont_tail_app14294964 = function(cont_tail_app5434963) {
return cont_tail_app5434963;
};
var $Hcont_tail_app14314917 = function(cont_tail_app5414916) {
return cont_tail_app5414916;
};
var $Hand_DASH_oper_DASH_14274936 = function(and_DASH_oper_DASH_614935,ann2651887,self2621889,value2661890) {
var if_helper5224977 = R.makeFunction(function(if_helper_arg5234995) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[654],1,arguments);
}
var ann_DASH_check_DASH_temp5154996 = if_helper_arg5234995;
return ann_DASH_check_DASH_temp5154996;
});
var anf_if5264994 = R.isBoolean(and_DASH_oper_DASH_614935);
if(R.isPyretTrue(anf_if5264994)) {
if(R.isPyretTrue(and_DASH_oper_DASH_614935)) {
var anf_fun5284975 = G(ann2651887,"visit",L[657]);
var $z49674968 = D;
var $f49734974 = function(_) {
return R.isFunction(anf_fun5284975)?anf_fun5284975.app(self2621889):R.ffi.throwNonFunApp(L[654],anf_fun5284975,[self2621889]);
};
try {
if(--R.GAS > 0) {
$z49674968 = $f49734974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49734974,
"from":L[654]});
}
} catch($e49654966) {
if(R.isCont($e49654966)) {
var $ss49694970 = {"from":L[654],
"go":function(and_DASH_oper_DASH_624976) {
return $Hand_DASH_oper_DASH_14254978(and_DASH_oper_DASH_624976,if_helper5224977,self2621889,value2661890);
}};
$e49654966.stack[R.EXN_STACKHEIGHT++] = $ss49694970;
}
if(R.isPyretException($e49654966)) {
$e49654966.pyretStack.push(L[654]);
}
throw $e49654966;
}
var $ret49714972 = $Hand_DASH_oper_DASH_14254978($z49674968,if_helper5224977,self2621889,value2661890);
++R.GAS;
return $ret49714972;
} else {
var $z49814982 = D;
var $f49874988 = function(_) {
return R.isFunction(if_helper5224977)?if_helper5224977.app((false)):R.ffi.throwNonFunApp(L[654],if_helper5224977,[(false)]);
};
try {
if(--R.GAS > 0) {
$z49814982 = $f49874988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49874988,
"from":L[654]});
}
} catch($e49794980) {
if(R.isCont($e49794980)) {
var $ss49834984 = {"from":L[654],
"go":function(cont_tail_app5274989) {
return $Hcont_tail_app14264990(cont_tail_app5274989);
}};
$e49794980.stack[R.EXN_STACKHEIGHT++] = $ss49834984;
}
if(R.isPyretException($e49794980)) {
$e49794980.pyretStack.push(L[654]);
}
throw $e49794980;
}
var $ret49854986 = $Hcont_tail_app14264990($z49814982);
++R.GAS;
return $ret49854986;
}
} else {
var cont_tail_arg5244993 = R.throwNonBooleanOp(L[658],("first"),("and"),and_DASH_oper_DASH_614935);
if(--R.GAS > 0) {
$z49914992 = R.isFunction(if_helper5224977)?if_helper5224977.app(cont_tail_arg5244993):R.ffi.throwNonFunApp(L[658],if_helper5224977,[cont_tail_arg5244993]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5224977)?if_helper5224977.app(cont_tail_arg5244993):R.ffi.throwNonFunApp(L[658],if_helper5224977,[cont_tail_arg5244993]);
},
"from":L[658]});
}
++R.GAS;
return $z49914992;
}
};
var $Hand_DASH_oper_DASH_14254978 = function(and_DASH_oper_DASH_624976,if_helper5224977,self2621889,value2661890) {
var anf_if5315025 = R.isBoolean(and_DASH_oper_DASH_624976);
if(R.isPyretTrue(anf_if5315025)) {
if(R.isPyretTrue(and_DASH_oper_DASH_624976)) {
var anf_fun5335007 = G(value2661890,"visit",L[659]);
var $z49995000 = D;
var $f50055006 = function(_) {
return R.isFunction(anf_fun5335007)?anf_fun5335007.app(self2621889):R.ffi.throwNonFunApp(L[654],anf_fun5335007,[self2621889]);
};
try {
if(--R.GAS > 0) {
$z49995000 = $f50055006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50055006,
"from":L[654]});
}
} catch($e49974998) {
if(R.isCont($e49974998)) {
var $ss50015002 = {"from":L[654],
"go":function(and_DASH_oper_DASH_635008) {
return $Hand_DASH_oper_DASH_14235009(and_DASH_oper_DASH_635008,if_helper5224977);
}};
$e49974998.stack[R.EXN_STACKHEIGHT++] = $ss50015002;
}
if(R.isPyretException($e49974998)) {
$e49974998.pyretStack.push(L[654]);
}
throw $e49974998;
}
var $ret50035004 = $Hand_DASH_oper_DASH_14235009($z49995000,if_helper5224977);
++R.GAS;
return $ret50035004;
} else {
var $z50125013 = D;
var $f50185019 = function(_) {
return R.isFunction(if_helper5224977)?if_helper5224977.app((false)):R.ffi.throwNonFunApp(L[654],if_helper5224977,[(false)]);
};
try {
if(--R.GAS > 0) {
$z50125013 = $f50185019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50185019,
"from":L[654]});
}
} catch($e50105011) {
if(R.isCont($e50105011)) {
var $ss50145015 = {"from":L[654],
"go":function(cont_tail_app5325020) {
return $Hcont_tail_app14245021(cont_tail_app5325020);
}};
$e50105011.stack[R.EXN_STACKHEIGHT++] = $ss50145015;
}
if(R.isPyretException($e50105011)) {
$e50105011.pyretStack.push(L[654]);
}
throw $e50105011;
}
var $ret50165017 = $Hcont_tail_app14245021($z50125013);
++R.GAS;
return $ret50165017;
}
} else {
var cont_tail_arg5295024 = R.throwNonBooleanOp(L[660],("first"),("and"),and_DASH_oper_DASH_624976);
if(--R.GAS > 0) {
$z50225023 = R.isFunction(if_helper5224977)?if_helper5224977.app(cont_tail_arg5295024):R.ffi.throwNonFunApp(L[660],if_helper5224977,[cont_tail_arg5295024]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5224977)?if_helper5224977.app(cont_tail_arg5295024):R.ffi.throwNonFunApp(L[660],if_helper5224977,[cont_tail_arg5295024]);
},
"from":L[660]});
}
++R.GAS;
return $z50225023;
}
};
var $Hand_DASH_oper_DASH_14235009 = function(and_DASH_oper_DASH_635008,if_helper5224977) {
var anf_if5365041 = R.isBoolean(and_DASH_oper_DASH_635008);
if(R.isPyretTrue(anf_if5365041)) {
var $z50285029 = D;
var $f50345035 = function(_) {
return R.isFunction(if_helper5224977)?if_helper5224977.app(and_DASH_oper_DASH_635008):R.ffi.throwNonFunApp(L[654],if_helper5224977,[and_DASH_oper_DASH_635008]);
};
try {
if(--R.GAS > 0) {
$z50285029 = $f50345035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50345035,
"from":L[654]});
}
} catch($e50265027) {
if(R.isCont($e50265027)) {
var $ss50305031 = {"from":L[654],
"go":function(cont_tail_app5375036) {
return $Hcont_tail_app14225037(cont_tail_app5375036);
}};
$e50265027.stack[R.EXN_STACKHEIGHT++] = $ss50305031;
}
if(R.isPyretException($e50265027)) {
$e50265027.pyretStack.push(L[654]);
}
throw $e50265027;
}
var $ret50325033 = $Hcont_tail_app14225037($z50285029);
++R.GAS;
return $ret50325033;
} else {
var cont_tail_arg5345040 = R.throwNonBooleanOp(L[661],("second"),("and"),and_DASH_oper_DASH_635008);
if(--R.GAS > 0) {
$z50385039 = R.isFunction(if_helper5224977)?if_helper5224977.app(cont_tail_arg5345040):R.ffi.throwNonFunApp(L[661],if_helper5224977,[cont_tail_arg5345040]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper5224977)?if_helper5224977.app(cont_tail_arg5345040):R.ffi.throwNonFunApp(L[661],if_helper5224977,[cont_tail_arg5345040]);
},
"from":L[661]});
}
++R.GAS;
return $z50385039;
}
};
var $Hcont_tail_app14225037 = function(cont_tail_app5375036) {
return cont_tail_app5375036;
};
var $Hcont_tail_app14245021 = function(cont_tail_app5325020) {
return cont_tail_app5325020;
};
var $Hcont_tail_app14264990 = function(cont_tail_app5274989) {
return cont_tail_app5274989;
};
var $Hand_DASH_oper_DASH_14211909 = function(and_DASH_oper_DASH_531904,ann2601905,l2581906,name2591903,reserved_DASH_name7965,reserved_DASH_names7442,self2571907,value2611908,nothing4) {
var if_helper4775055 = R.makeFunction(function(if_helper_arg4785073) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[371],1,arguments);
}
var when_DASH_525100 = if_helper_arg4785073;
var if_helper4795086 = R.makeFunction(function(if_helper_arg4805105) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[667],1,arguments);
}
if_helper_arg4805105;
var anf_fun4815116 = G(name2591903,"visit",L[669]);
var $z51085109 = D;
var $f51145115 = function(_) {
return R.isFunction(anf_fun4815116)?anf_fun4815116.app(self2571907):R.ffi.throwNonFunApp(L[668],anf_fun4815116,[self2571907]);
};
try {
if(--R.GAS > 0) {
$z51085109 = $f51145115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51145115,
"from":L[668]});
}
} catch($e51065107) {
if(R.isCont($e51065107)) {
var $ss51105111 = {"from":L[668],
"go":function(and_DASH_oper_DASH_555117) {
return $Hand_DASH_oper_DASH_14135118(and_DASH_oper_DASH_555117,ann2601905,self2571907,value2611908);
}};
$e51065107.stack[R.EXN_STACKHEIGHT++] = $ss51105111;
}
if(R.isPyretException($e51065107)) {
$e51065107.pyretStack.push(L[668]);
}
throw $e51065107;
}
var $ret51125113 = $Hand_DASH_oper_DASH_14135118($z51085109,ann2601905,self2571907,value2611908);
++R.GAS;
return $ret51125113;
});
var anf_if5005104 = R.isBoolean(when_DASH_525100);
if(R.isPyretTrue(anf_if5005104)) {
if(R.isPyretTrue(when_DASH_525100)) {
var anf_arg5025084 = G(name2591903,"s",L[666]);
var $z50765077 = D;
var $f50825083 = function(_) {
return R.isFunction(reserved_DASH_name7965.$var)?reserved_DASH_name7965.$var.app(l2581906,anf_arg5025084):R.ffi.throwNonFunApp(L[665],reserved_DASH_name7965.$var,[l2581906,anf_arg5025084]);
};
try {
if(--R.GAS > 0) {
$z50765077 = $f50825083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50825083,
"from":L[665]});
}
} catch($e50745075) {
if(R.isCont($e50745075)) {
var $ss50785079 = {"from":L[665],
"go":function(anf_begin_app_dropped14145085) {
return $Hanf_begin_app_dropped14165087(anf_begin_app_dropped14145085,if_helper4795086,nothing4);
}};
$e50745075.stack[R.EXN_STACKHEIGHT++] = $ss50785079;
}
if(R.isPyretException($e50745075)) {
$e50745075.pyretStack.push(L[665]);
}
throw $e50745075;
}
var $ret50805081 = $Hanf_begin_app_dropped14165087($z50765077,if_helper4795086,nothing4);
++R.GAS;
return $ret50805081;
} else {
var $z50905091 = D;
var $f50965097 = function(_) {
return R.isFunction(if_helper4795086)?if_helper4795086.app(nothing4):R.ffi.throwNonFunApp(L[667],if_helper4795086,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z50905091 = $f50965097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50965097,
"from":L[667]});
}
} catch($e50885089) {
if(R.isCont($e50885089)) {
var $ss50925093 = {"from":L[667],
"go":function(cont_tail_app5015098) {
return $Hcont_tail_app14175099(cont_tail_app5015098);
}};
$e50885089.stack[R.EXN_STACKHEIGHT++] = $ss50925093;
}
if(R.isPyretException($e50885089)) {
$e50885089.pyretStack.push(L[667]);
}
throw $e50885089;
}
var $ret50945095 = $Hcont_tail_app14175099($z50905091);
++R.GAS;
return $ret50945095;
}
} else {
var cont_tail_arg4985103 = R.throwNonBooleanCondition(L[371],("when"),when_DASH_525100);
if(--R.GAS > 0) {
$z51015102 = R.isFunction(if_helper4795086)?if_helper4795086.app(cont_tail_arg4985103):R.ffi.throwNonFunApp(L[371],if_helper4795086,[cont_tail_arg4985103]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4795086)?if_helper4795086.app(cont_tail_arg4985103):R.ffi.throwNonFunApp(L[371],if_helper4795086,[cont_tail_arg4985103]);
},
"from":L[371]});
}
++R.GAS;
return $z51015102;
}
});
var anf_if5065072 = R.isBoolean(and_DASH_oper_DASH_531904);
if(R.isPyretTrue(anf_if5065072)) {
if(R.isPyretTrue(and_DASH_oper_DASH_531904)) {
var anf_fun5085052 = G(reserved_DASH_names7442,"member",L[663]);
var anf_arg5095053 = G(name2591903,"s",L[662]);
var $z50445045 = D;
var $f50505051 = function(_) {
return R.isFunction(anf_fun5085052)?anf_fun5085052.app(anf_arg5095053):R.ffi.throwNonFunApp(L[371],anf_fun5085052,[anf_arg5095053]);
};
try {
if(--R.GAS > 0) {
$z50445045 = $f50505051();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50505051,
"from":L[371]});
}
} catch($e50425043) {
if(R.isCont($e50425043)) {
var $ss50465047 = {"from":L[371],
"go":function(and_DASH_oper_DASH_545054) {
return $Hand_DASH_oper_DASH_14195056(and_DASH_oper_DASH_545054,if_helper4775055);
}};
$e50425043.stack[R.EXN_STACKHEIGHT++] = $ss50465047;
}
if(R.isPyretException($e50425043)) {
$e50425043.pyretStack.push(L[371]);
}
throw $e50425043;
}
var $ret50485049 = $Hand_DASH_oper_DASH_14195056($z50445045,if_helper4775055);
++R.GAS;
return $ret50485049;
} else {
var $z50595060 = D;
var $f50655066 = function(_) {
return R.isFunction(if_helper4775055)?if_helper4775055.app((false)):R.ffi.throwNonFunApp(L[371],if_helper4775055,[(false)]);
};
try {
if(--R.GAS > 0) {
$z50595060 = $f50655066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50655066,
"from":L[371]});
}
} catch($e50575058) {
if(R.isCont($e50575058)) {
var $ss50615062 = {"from":L[371],
"go":function(cont_tail_app5075067) {
return $Hcont_tail_app14205068(cont_tail_app5075067);
}};
$e50575058.stack[R.EXN_STACKHEIGHT++] = $ss50615062;
}
if(R.isPyretException($e50575058)) {
$e50575058.pyretStack.push(L[371]);
}
throw $e50575058;
}
var $ret50635064 = $Hcont_tail_app14205068($z50595060);
++R.GAS;
return $ret50635064;
}
} else {
var cont_tail_arg5045071 = R.throwNonBooleanOp(L[664],("first"),("and"),and_DASH_oper_DASH_531904);
if(--R.GAS > 0) {
$z50695070 = R.isFunction(if_helper4775055)?if_helper4775055.app(cont_tail_arg5045071):R.ffi.throwNonFunApp(L[664],if_helper4775055,[cont_tail_arg5045071]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4775055)?if_helper4775055.app(cont_tail_arg5045071):R.ffi.throwNonFunApp(L[664],if_helper4775055,[cont_tail_arg5045071]);
},
"from":L[664]});
}
++R.GAS;
return $z50695070;
}
};
var $Hand_DASH_oper_DASH_14195056 = function(and_DASH_oper_DASH_545054,if_helper4775055) {
var anf_if5125134 = R.isBoolean(and_DASH_oper_DASH_545054);
if(R.isPyretTrue(anf_if5125134)) {
var $z51215122 = D;
var $f51275128 = function(_) {
return R.isFunction(if_helper4775055)?if_helper4775055.app(and_DASH_oper_DASH_545054):R.ffi.throwNonFunApp(L[371],if_helper4775055,[and_DASH_oper_DASH_545054]);
};
try {
if(--R.GAS > 0) {
$z51215122 = $f51275128();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51275128,
"from":L[371]});
}
} catch($e51195120) {
if(R.isCont($e51195120)) {
var $ss51235124 = {"from":L[371],
"go":function(cont_tail_app5135129) {
return $Hcont_tail_app14185130(cont_tail_app5135129);
}};
$e51195120.stack[R.EXN_STACKHEIGHT++] = $ss51235124;
}
if(R.isPyretException($e51195120)) {
$e51195120.pyretStack.push(L[371]);
}
throw $e51195120;
}
var $ret51255126 = $Hcont_tail_app14185130($z51215122);
++R.GAS;
return $ret51255126;
} else {
var cont_tail_arg5105133 = R.throwNonBooleanOp(L[670],("second"),("and"),and_DASH_oper_DASH_545054);
if(--R.GAS > 0) {
$z51315132 = R.isFunction(if_helper4775055)?if_helper4775055.app(cont_tail_arg5105133):R.ffi.throwNonFunApp(L[670],if_helper4775055,[cont_tail_arg5105133]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4775055)?if_helper4775055.app(cont_tail_arg5105133):R.ffi.throwNonFunApp(L[670],if_helper4775055,[cont_tail_arg5105133]);
},
"from":L[670]});
}
++R.GAS;
return $z51315132;
}
};
var $Hcont_tail_app14185130 = function(cont_tail_app5135129) {
return cont_tail_app5135129;
};
var $Hcont_tail_app14205068 = function(cont_tail_app5075067) {
return cont_tail_app5075067;
};
var $Hanf_begin_app_dropped14165087 = function(anf_begin_app_dropped14145085,if_helper4795086,nothing4) {
var $z51375138 = D;
var $f51435144 = function(_) {
return R.isFunction(if_helper4795086)?if_helper4795086.app(nothing4):R.ffi.throwNonFunApp(L[667],if_helper4795086,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z51375138 = $f51435144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51435144,
"from":L[667]});
}
} catch($e51355136) {
if(R.isCont($e51355136)) {
var $ss51395140 = {"from":L[667],
"go":function(cont_tail_app5035145) {
return $Hcont_tail_app14155146(cont_tail_app5035145);
}};
$e51355136.stack[R.EXN_STACKHEIGHT++] = $ss51395140;
}
if(R.isPyretException($e51355136)) {
$e51355136.pyretStack.push(L[667]);
}
throw $e51355136;
}
var $ret51415142 = $Hcont_tail_app14155146($z51375138);
++R.GAS;
return $ret51415142;
};
var $Hcont_tail_app14155146 = function(cont_tail_app5035145) {
return cont_tail_app5035145;
};
var $Hcont_tail_app14175099 = function(cont_tail_app5015098) {
return cont_tail_app5015098;
};
var $Hand_DASH_oper_DASH_14135118 = function(and_DASH_oper_DASH_555117,ann2601905,self2571907,value2611908) {
var if_helper4825159 = R.makeFunction(function(if_helper_arg4835177) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[668],1,arguments);
}
var ann_DASH_check_DASH_temp4755178 = if_helper_arg4835177;
return ann_DASH_check_DASH_temp4755178;
});
var anf_if4865176 = R.isBoolean(and_DASH_oper_DASH_555117);
if(R.isPyretTrue(anf_if4865176)) {
if(R.isPyretTrue(and_DASH_oper_DASH_555117)) {
var anf_fun4885157 = G(ann2601905,"visit",L[671]);
var $z51495150 = D;
var $f51555156 = function(_) {
return R.isFunction(anf_fun4885157)?anf_fun4885157.app(self2571907):R.ffi.throwNonFunApp(L[668],anf_fun4885157,[self2571907]);
};
try {
if(--R.GAS > 0) {
$z51495150 = $f51555156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51555156,
"from":L[668]});
}
} catch($e51475148) {
if(R.isCont($e51475148)) {
var $ss51515152 = {"from":L[668],
"go":function(and_DASH_oper_DASH_565158) {
return $Hand_DASH_oper_DASH_14115160(and_DASH_oper_DASH_565158,if_helper4825159,self2571907,value2611908);
}};
$e51475148.stack[R.EXN_STACKHEIGHT++] = $ss51515152;
}
if(R.isPyretException($e51475148)) {
$e51475148.pyretStack.push(L[668]);
}
throw $e51475148;
}
var $ret51535154 = $Hand_DASH_oper_DASH_14115160($z51495150,if_helper4825159,self2571907,value2611908);
++R.GAS;
return $ret51535154;
} else {
var $z51635164 = D;
var $f51695170 = function(_) {
return R.isFunction(if_helper4825159)?if_helper4825159.app((false)):R.ffi.throwNonFunApp(L[668],if_helper4825159,[(false)]);
};
try {
if(--R.GAS > 0) {
$z51635164 = $f51695170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51695170,
"from":L[668]});
}
} catch($e51615162) {
if(R.isCont($e51615162)) {
var $ss51655166 = {"from":L[668],
"go":function(cont_tail_app4875171) {
return $Hcont_tail_app14125172(cont_tail_app4875171);
}};
$e51615162.stack[R.EXN_STACKHEIGHT++] = $ss51655166;
}
if(R.isPyretException($e51615162)) {
$e51615162.pyretStack.push(L[668]);
}
throw $e51615162;
}
var $ret51675168 = $Hcont_tail_app14125172($z51635164);
++R.GAS;
return $ret51675168;
}
} else {
var cont_tail_arg4845175 = R.throwNonBooleanOp(L[672],("first"),("and"),and_DASH_oper_DASH_555117);
if(--R.GAS > 0) {
$z51735174 = R.isFunction(if_helper4825159)?if_helper4825159.app(cont_tail_arg4845175):R.ffi.throwNonFunApp(L[672],if_helper4825159,[cont_tail_arg4845175]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4825159)?if_helper4825159.app(cont_tail_arg4845175):R.ffi.throwNonFunApp(L[672],if_helper4825159,[cont_tail_arg4845175]);
},
"from":L[672]});
}
++R.GAS;
return $z51735174;
}
};
var $Hand_DASH_oper_DASH_14115160 = function(and_DASH_oper_DASH_565158,if_helper4825159,self2571907,value2611908) {
var anf_if4915207 = R.isBoolean(and_DASH_oper_DASH_565158);
if(R.isPyretTrue(anf_if4915207)) {
if(R.isPyretTrue(and_DASH_oper_DASH_565158)) {
var anf_fun4935189 = G(value2611908,"visit",L[673]);
var $z51815182 = D;
var $f51875188 = function(_) {
return R.isFunction(anf_fun4935189)?anf_fun4935189.app(self2571907):R.ffi.throwNonFunApp(L[668],anf_fun4935189,[self2571907]);
};
try {
if(--R.GAS > 0) {
$z51815182 = $f51875188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51875188,
"from":L[668]});
}
} catch($e51795180) {
if(R.isCont($e51795180)) {
var $ss51835184 = {"from":L[668],
"go":function(and_DASH_oper_DASH_575190) {
return $Hand_DASH_oper_DASH_14095191(and_DASH_oper_DASH_575190,if_helper4825159);
}};
$e51795180.stack[R.EXN_STACKHEIGHT++] = $ss51835184;
}
if(R.isPyretException($e51795180)) {
$e51795180.pyretStack.push(L[668]);
}
throw $e51795180;
}
var $ret51855186 = $Hand_DASH_oper_DASH_14095191($z51815182,if_helper4825159);
++R.GAS;
return $ret51855186;
} else {
var $z51945195 = D;
var $f52005201 = function(_) {
return R.isFunction(if_helper4825159)?if_helper4825159.app((false)):R.ffi.throwNonFunApp(L[668],if_helper4825159,[(false)]);
};
try {
if(--R.GAS > 0) {
$z51945195 = $f52005201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52005201,
"from":L[668]});
}
} catch($e51925193) {
if(R.isCont($e51925193)) {
var $ss51965197 = {"from":L[668],
"go":function(cont_tail_app4925202) {
return $Hcont_tail_app14105203(cont_tail_app4925202);
}};
$e51925193.stack[R.EXN_STACKHEIGHT++] = $ss51965197;
}
if(R.isPyretException($e51925193)) {
$e51925193.pyretStack.push(L[668]);
}
throw $e51925193;
}
var $ret51985199 = $Hcont_tail_app14105203($z51945195);
++R.GAS;
return $ret51985199;
}
} else {
var cont_tail_arg4895206 = R.throwNonBooleanOp(L[674],("first"),("and"),and_DASH_oper_DASH_565158);
if(--R.GAS > 0) {
$z52045205 = R.isFunction(if_helper4825159)?if_helper4825159.app(cont_tail_arg4895206):R.ffi.throwNonFunApp(L[674],if_helper4825159,[cont_tail_arg4895206]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4825159)?if_helper4825159.app(cont_tail_arg4895206):R.ffi.throwNonFunApp(L[674],if_helper4825159,[cont_tail_arg4895206]);
},
"from":L[674]});
}
++R.GAS;
return $z52045205;
}
};
var $Hand_DASH_oper_DASH_14095191 = function(and_DASH_oper_DASH_575190,if_helper4825159) {
var anf_if4965223 = R.isBoolean(and_DASH_oper_DASH_575190);
if(R.isPyretTrue(anf_if4965223)) {
var $z52105211 = D;
var $f52165217 = function(_) {
return R.isFunction(if_helper4825159)?if_helper4825159.app(and_DASH_oper_DASH_575190):R.ffi.throwNonFunApp(L[668],if_helper4825159,[and_DASH_oper_DASH_575190]);
};
try {
if(--R.GAS > 0) {
$z52105211 = $f52165217();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52165217,
"from":L[668]});
}
} catch($e52085209) {
if(R.isCont($e52085209)) {
var $ss52125213 = {"from":L[668],
"go":function(cont_tail_app4975218) {
return $Hcont_tail_app14085219(cont_tail_app4975218);
}};
$e52085209.stack[R.EXN_STACKHEIGHT++] = $ss52125213;
}
if(R.isPyretException($e52085209)) {
$e52085209.pyretStack.push(L[668]);
}
throw $e52085209;
}
var $ret52145215 = $Hcont_tail_app14085219($z52105211);
++R.GAS;
return $ret52145215;
} else {
var cont_tail_arg4945222 = R.throwNonBooleanOp(L[675],("second"),("and"),and_DASH_oper_DASH_575190);
if(--R.GAS > 0) {
$z52205221 = R.isFunction(if_helper4825159)?if_helper4825159.app(cont_tail_arg4945222):R.ffi.throwNonFunApp(L[675],if_helper4825159,[cont_tail_arg4945222]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4825159)?if_helper4825159.app(cont_tail_arg4945222):R.ffi.throwNonFunApp(L[675],if_helper4825159,[cont_tail_arg4945222]);
},
"from":L[675]});
}
++R.GAS;
return $z52205221;
}
};
var $Hcont_tail_app14085219 = function(cont_tail_app4975218) {
return cont_tail_app4975218;
};
var $Hcont_tail_app14105203 = function(cont_tail_app4925202) {
return cont_tail_app4925202;
};
var $Hcont_tail_app14125172 = function(cont_tail_app4875171) {
return cont_tail_app4875171;
};
var $Hand_DASH_oper_DASH_14071926 = function(and_DASH_oper_DASH_481922,l2541923,name2551921,reserved_DASH_name7965,reserved_DASH_names7442,self2531924,value2561925,nothing4) {
var if_helper4425237 = R.makeFunction(function(if_helper_arg4435255) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[374],1,arguments);
}
var when_DASH_475282 = if_helper_arg4435255;
var if_helper4445268 = R.makeFunction(function(if_helper_arg4455287) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[681],1,arguments);
}
if_helper_arg4455287;
var anf_fun4465298 = G(name2551921,"visit",L[683]);
var $z52905291 = D;
var $f52965297 = function(_) {
return R.isFunction(anf_fun4465298)?anf_fun4465298.app(self2531924):R.ffi.throwNonFunApp(L[682],anf_fun4465298,[self2531924]);
};
try {
if(--R.GAS > 0) {
$z52905291 = $f52965297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52965297,
"from":L[682]});
}
} catch($e52885289) {
if(R.isCont($e52885289)) {
var $ss52925293 = {"from":L[682],
"go":function(and_DASH_oper_DASH_505299) {
return $Hand_DASH_oper_DASH_13995300(and_DASH_oper_DASH_505299,self2531924,value2561925);
}};
$e52885289.stack[R.EXN_STACKHEIGHT++] = $ss52925293;
}
if(R.isPyretException($e52885289)) {
$e52885289.pyretStack.push(L[682]);
}
throw $e52885289;
}
var $ret52945295 = $Hand_DASH_oper_DASH_13995300($z52905291,self2531924,value2561925);
++R.GAS;
return $ret52945295;
});
var anf_if4605286 = R.isBoolean(when_DASH_475282);
if(R.isPyretTrue(anf_if4605286)) {
if(R.isPyretTrue(when_DASH_475282)) {
var anf_arg4625266 = G(name2551921,"s",L[680]);
var $z52585259 = D;
var $f52645265 = function(_) {
return R.isFunction(reserved_DASH_name7965.$var)?reserved_DASH_name7965.$var.app(l2541923,anf_arg4625266):R.ffi.throwNonFunApp(L[679],reserved_DASH_name7965.$var,[l2541923,anf_arg4625266]);
};
try {
if(--R.GAS > 0) {
$z52585259 = $f52645265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52645265,
"from":L[679]});
}
} catch($e52565257) {
if(R.isCont($e52565257)) {
var $ss52605261 = {"from":L[679],
"go":function(anf_begin_app_dropped14005267) {
return $Hanf_begin_app_dropped14025269(anf_begin_app_dropped14005267,if_helper4445268,nothing4);
}};
$e52565257.stack[R.EXN_STACKHEIGHT++] = $ss52605261;
}
if(R.isPyretException($e52565257)) {
$e52565257.pyretStack.push(L[679]);
}
throw $e52565257;
}
var $ret52625263 = $Hanf_begin_app_dropped14025269($z52585259,if_helper4445268,nothing4);
++R.GAS;
return $ret52625263;
} else {
var $z52725273 = D;
var $f52785279 = function(_) {
return R.isFunction(if_helper4445268)?if_helper4445268.app(nothing4):R.ffi.throwNonFunApp(L[681],if_helper4445268,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z52725273 = $f52785279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52785279,
"from":L[681]});
}
} catch($e52705271) {
if(R.isCont($e52705271)) {
var $ss52745275 = {"from":L[681],
"go":function(cont_tail_app4615280) {
return $Hcont_tail_app14035281(cont_tail_app4615280);
}};
$e52705271.stack[R.EXN_STACKHEIGHT++] = $ss52745275;
}
if(R.isPyretException($e52705271)) {
$e52705271.pyretStack.push(L[681]);
}
throw $e52705271;
}
var $ret52765277 = $Hcont_tail_app14035281($z52725273);
++R.GAS;
return $ret52765277;
}
} else {
var cont_tail_arg4585285 = R.throwNonBooleanCondition(L[374],("when"),when_DASH_475282);
if(--R.GAS > 0) {
$z52835284 = R.isFunction(if_helper4445268)?if_helper4445268.app(cont_tail_arg4585285):R.ffi.throwNonFunApp(L[374],if_helper4445268,[cont_tail_arg4585285]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4445268)?if_helper4445268.app(cont_tail_arg4585285):R.ffi.throwNonFunApp(L[374],if_helper4445268,[cont_tail_arg4585285]);
},
"from":L[374]});
}
++R.GAS;
return $z52835284;
}
});
var anf_if4665254 = R.isBoolean(and_DASH_oper_DASH_481922);
if(R.isPyretTrue(anf_if4665254)) {
if(R.isPyretTrue(and_DASH_oper_DASH_481922)) {
var anf_fun4685234 = G(reserved_DASH_names7442,"member",L[677]);
var anf_arg4695235 = G(name2551921,"s",L[676]);
var $z52265227 = D;
var $f52325233 = function(_) {
return R.isFunction(anf_fun4685234)?anf_fun4685234.app(anf_arg4695235):R.ffi.throwNonFunApp(L[374],anf_fun4685234,[anf_arg4695235]);
};
try {
if(--R.GAS > 0) {
$z52265227 = $f52325233();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52325233,
"from":L[374]});
}
} catch($e52245225) {
if(R.isCont($e52245225)) {
var $ss52285229 = {"from":L[374],
"go":function(and_DASH_oper_DASH_495236) {
return $Hand_DASH_oper_DASH_14055238(and_DASH_oper_DASH_495236,if_helper4425237);
}};
$e52245225.stack[R.EXN_STACKHEIGHT++] = $ss52285229;
}
if(R.isPyretException($e52245225)) {
$e52245225.pyretStack.push(L[374]);
}
throw $e52245225;
}
var $ret52305231 = $Hand_DASH_oper_DASH_14055238($z52265227,if_helper4425237);
++R.GAS;
return $ret52305231;
} else {
var $z52415242 = D;
var $f52475248 = function(_) {
return R.isFunction(if_helper4425237)?if_helper4425237.app((false)):R.ffi.throwNonFunApp(L[374],if_helper4425237,[(false)]);
};
try {
if(--R.GAS > 0) {
$z52415242 = $f52475248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52475248,
"from":L[374]});
}
} catch($e52395240) {
if(R.isCont($e52395240)) {
var $ss52435244 = {"from":L[374],
"go":function(cont_tail_app4675249) {
return $Hcont_tail_app14065250(cont_tail_app4675249);
}};
$e52395240.stack[R.EXN_STACKHEIGHT++] = $ss52435244;
}
if(R.isPyretException($e52395240)) {
$e52395240.pyretStack.push(L[374]);
}
throw $e52395240;
}
var $ret52455246 = $Hcont_tail_app14065250($z52415242);
++R.GAS;
return $ret52455246;
}
} else {
var cont_tail_arg4645253 = R.throwNonBooleanOp(L[678],("first"),("and"),and_DASH_oper_DASH_481922);
if(--R.GAS > 0) {
$z52515252 = R.isFunction(if_helper4425237)?if_helper4425237.app(cont_tail_arg4645253):R.ffi.throwNonFunApp(L[678],if_helper4425237,[cont_tail_arg4645253]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4425237)?if_helper4425237.app(cont_tail_arg4645253):R.ffi.throwNonFunApp(L[678],if_helper4425237,[cont_tail_arg4645253]);
},
"from":L[678]});
}
++R.GAS;
return $z52515252;
}
};
var $Hand_DASH_oper_DASH_14055238 = function(and_DASH_oper_DASH_495236,if_helper4425237) {
var anf_if4725316 = R.isBoolean(and_DASH_oper_DASH_495236);
if(R.isPyretTrue(anf_if4725316)) {
var $z53035304 = D;
var $f53095310 = function(_) {
return R.isFunction(if_helper4425237)?if_helper4425237.app(and_DASH_oper_DASH_495236):R.ffi.throwNonFunApp(L[374],if_helper4425237,[and_DASH_oper_DASH_495236]);
};
try {
if(--R.GAS > 0) {
$z53035304 = $f53095310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53095310,
"from":L[374]});
}
} catch($e53015302) {
if(R.isCont($e53015302)) {
var $ss53055306 = {"from":L[374],
"go":function(cont_tail_app4735311) {
return $Hcont_tail_app14045312(cont_tail_app4735311);
}};
$e53015302.stack[R.EXN_STACKHEIGHT++] = $ss53055306;
}
if(R.isPyretException($e53015302)) {
$e53015302.pyretStack.push(L[374]);
}
throw $e53015302;
}
var $ret53075308 = $Hcont_tail_app14045312($z53035304);
++R.GAS;
return $ret53075308;
} else {
var cont_tail_arg4705315 = R.throwNonBooleanOp(L[684],("second"),("and"),and_DASH_oper_DASH_495236);
if(--R.GAS > 0) {
$z53135314 = R.isFunction(if_helper4425237)?if_helper4425237.app(cont_tail_arg4705315):R.ffi.throwNonFunApp(L[684],if_helper4425237,[cont_tail_arg4705315]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4425237)?if_helper4425237.app(cont_tail_arg4705315):R.ffi.throwNonFunApp(L[684],if_helper4425237,[cont_tail_arg4705315]);
},
"from":L[684]});
}
++R.GAS;
return $z53135314;
}
};
var $Hcont_tail_app14045312 = function(cont_tail_app4735311) {
return cont_tail_app4735311;
};
var $Hcont_tail_app14065250 = function(cont_tail_app4675249) {
return cont_tail_app4675249;
};
var $Hanf_begin_app_dropped14025269 = function(anf_begin_app_dropped14005267,if_helper4445268,nothing4) {
var $z53195320 = D;
var $f53255326 = function(_) {
return R.isFunction(if_helper4445268)?if_helper4445268.app(nothing4):R.ffi.throwNonFunApp(L[681],if_helper4445268,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z53195320 = $f53255326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53255326,
"from":L[681]});
}
} catch($e53175318) {
if(R.isCont($e53175318)) {
var $ss53215322 = {"from":L[681],
"go":function(cont_tail_app4635327) {
return $Hcont_tail_app14015328(cont_tail_app4635327);
}};
$e53175318.stack[R.EXN_STACKHEIGHT++] = $ss53215322;
}
if(R.isPyretException($e53175318)) {
$e53175318.pyretStack.push(L[681]);
}
throw $e53175318;
}
var $ret53235324 = $Hcont_tail_app14015328($z53195320);
++R.GAS;
return $ret53235324;
};
var $Hcont_tail_app14015328 = function(cont_tail_app4635327) {
return cont_tail_app4635327;
};
var $Hcont_tail_app14035281 = function(cont_tail_app4615280) {
return cont_tail_app4615280;
};
var $Hand_DASH_oper_DASH_13995300 = function(and_DASH_oper_DASH_505299,self2531924,value2561925) {
var if_helper4475341 = R.makeFunction(function(if_helper_arg4485359) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[682],1,arguments);
}
var ann_DASH_check_DASH_temp4405360 = if_helper_arg4485359;
return ann_DASH_check_DASH_temp4405360;
});
var anf_if4515358 = R.isBoolean(and_DASH_oper_DASH_505299);
if(R.isPyretTrue(anf_if4515358)) {
if(R.isPyretTrue(and_DASH_oper_DASH_505299)) {
var anf_fun4535339 = G(value2561925,"visit",L[685]);
var $z53315332 = D;
var $f53375338 = function(_) {
return R.isFunction(anf_fun4535339)?anf_fun4535339.app(self2531924):R.ffi.throwNonFunApp(L[682],anf_fun4535339,[self2531924]);
};
try {
if(--R.GAS > 0) {
$z53315332 = $f53375338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53375338,
"from":L[682]});
}
} catch($e53295330) {
if(R.isCont($e53295330)) {
var $ss53335334 = {"from":L[682],
"go":function(and_DASH_oper_DASH_515340) {
return $Hand_DASH_oper_DASH_13975342(and_DASH_oper_DASH_515340,if_helper4475341);
}};
$e53295330.stack[R.EXN_STACKHEIGHT++] = $ss53335334;
}
if(R.isPyretException($e53295330)) {
$e53295330.pyretStack.push(L[682]);
}
throw $e53295330;
}
var $ret53355336 = $Hand_DASH_oper_DASH_13975342($z53315332,if_helper4475341);
++R.GAS;
return $ret53355336;
} else {
var $z53455346 = D;
var $f53515352 = function(_) {
return R.isFunction(if_helper4475341)?if_helper4475341.app((false)):R.ffi.throwNonFunApp(L[682],if_helper4475341,[(false)]);
};
try {
if(--R.GAS > 0) {
$z53455346 = $f53515352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53515352,
"from":L[682]});
}
} catch($e53435344) {
if(R.isCont($e53435344)) {
var $ss53475348 = {"from":L[682],
"go":function(cont_tail_app4525353) {
return $Hcont_tail_app13985354(cont_tail_app4525353);
}};
$e53435344.stack[R.EXN_STACKHEIGHT++] = $ss53475348;
}
if(R.isPyretException($e53435344)) {
$e53435344.pyretStack.push(L[682]);
}
throw $e53435344;
}
var $ret53495350 = $Hcont_tail_app13985354($z53455346);
++R.GAS;
return $ret53495350;
}
} else {
var cont_tail_arg4495357 = R.throwNonBooleanOp(L[686],("first"),("and"),and_DASH_oper_DASH_505299);
if(--R.GAS > 0) {
$z53555356 = R.isFunction(if_helper4475341)?if_helper4475341.app(cont_tail_arg4495357):R.ffi.throwNonFunApp(L[686],if_helper4475341,[cont_tail_arg4495357]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4475341)?if_helper4475341.app(cont_tail_arg4495357):R.ffi.throwNonFunApp(L[686],if_helper4475341,[cont_tail_arg4495357]);
},
"from":L[686]});
}
++R.GAS;
return $z53555356;
}
};
var $Hand_DASH_oper_DASH_13975342 = function(and_DASH_oper_DASH_515340,if_helper4475341) {
var anf_if4565376 = R.isBoolean(and_DASH_oper_DASH_515340);
if(R.isPyretTrue(anf_if4565376)) {
var $z53635364 = D;
var $f53695370 = function(_) {
return R.isFunction(if_helper4475341)?if_helper4475341.app(and_DASH_oper_DASH_515340):R.ffi.throwNonFunApp(L[682],if_helper4475341,[and_DASH_oper_DASH_515340]);
};
try {
if(--R.GAS > 0) {
$z53635364 = $f53695370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53695370,
"from":L[682]});
}
} catch($e53615362) {
if(R.isCont($e53615362)) {
var $ss53655366 = {"from":L[682],
"go":function(cont_tail_app4575371) {
return $Hcont_tail_app13965372(cont_tail_app4575371);
}};
$e53615362.stack[R.EXN_STACKHEIGHT++] = $ss53655366;
}
if(R.isPyretException($e53615362)) {
$e53615362.pyretStack.push(L[682]);
}
throw $e53615362;
}
var $ret53675368 = $Hcont_tail_app13965372($z53635364);
++R.GAS;
return $ret53675368;
} else {
var cont_tail_arg4545375 = R.throwNonBooleanOp(L[687],("second"),("and"),and_DASH_oper_DASH_515340);
if(--R.GAS > 0) {
$z53735374 = R.isFunction(if_helper4475341)?if_helper4475341.app(cont_tail_arg4545375):R.ffi.throwNonFunApp(L[687],if_helper4475341,[cont_tail_arg4545375]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper4475341)?if_helper4475341.app(cont_tail_arg4545375):R.ffi.throwNonFunApp(L[687],if_helper4475341,[cont_tail_arg4545375]);
},
"from":L[687]});
}
++R.GAS;
return $z53735374;
}
};
var $Hcont_tail_app13965372 = function(cont_tail_app4575371) {
return cont_tail_app4575371;
};
var $Hcont_tail_app13985354 = function(cont_tail_app4525353) {
return cont_tail_app4525353;
};
var $Hand_DASH_oper_DASH_13951946 = function(and_DASH_oper_DASH_381939,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2451944,lists1118,name2461938,reserved_DASH_name7965,reserved_DASH_names7442,self2441945,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4) {
var if_helper3785390 = R.makeFunction(function(if_helper_arg3795408) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[377],1,arguments);
}
var when_DASH_375435 = if_helper_arg3795408;
var if_helper3805421 = R.makeFunction(function(if_helper_arg3815440) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[693],1,arguments);
}
if_helper_arg3815440;
var anf_fun3825451 = G(args2471942,"length",L[695]);
var $z54435444 = D;
var $f54495450 = function(_) {
return R.isFunction(anf_fun3825451)?anf_fun3825451.app():R.ffi.throwNonFunApp(L[694],anf_fun3825451,[]);
};
try {
if(--R.GAS > 0) {
$z54435444 = $f54495450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54495450,
"from":L[694]});
}
} catch($e54415442) {
if(R.isCont($e54415442)) {
var $ss54455446 = {"from":L[694],
"go":function(anf_arg3835452) {
return $Hanf_arg13875453(anf_arg3835452,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2451944,lists1118,self2441945,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4);
}};
$e54415442.stack[R.EXN_STACKHEIGHT++] = $ss54455446;
}
if(R.isPyretException($e54415442)) {
$e54415442.pyretStack.push(L[694]);
}
throw $e54415442;
}
var $ret54475448 = $Hanf_arg13875453($z54435444,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2451944,lists1118,self2441945,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4);
++R.GAS;
return $ret54475448;
});
var anf_if4255439 = R.isBoolean(when_DASH_375435);
if(R.isPyretTrue(anf_if4255439)) {
if(R.isPyretTrue(when_DASH_375435)) {
var anf_arg4275419 = G(name2461938,"s",L[692]);
var $z54115412 = D;
var $f54175418 = function(_) {
return R.isFunction(reserved_DASH_name7965.$var)?reserved_DASH_name7965.$var.app(l2451944,anf_arg4275419):R.ffi.throwNonFunApp(L[691],reserved_DASH_name7965.$var,[l2451944,anf_arg4275419]);
};
try {
if(--R.GAS > 0) {
$z54115412 = $f54175418();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54175418,
"from":L[691]});
}
} catch($e54095410) {
if(R.isCont($e54095410)) {
var $ss54135414 = {"from":L[691],
"go":function(anf_begin_app_dropped13885420) {
return $Hanf_begin_app_dropped13905422(anf_begin_app_dropped13885420,if_helper3805421,nothing4);
}};
$e54095410.stack[R.EXN_STACKHEIGHT++] = $ss54135414;
}
if(R.isPyretException($e54095410)) {
$e54095410.pyretStack.push(L[691]);
}
throw $e54095410;
}
var $ret54155416 = $Hanf_begin_app_dropped13905422($z54115412,if_helper3805421,nothing4);
++R.GAS;
return $ret54155416;
} else {
var $z54255426 = D;
var $f54315432 = function(_) {
return R.isFunction(if_helper3805421)?if_helper3805421.app(nothing4):R.ffi.throwNonFunApp(L[693],if_helper3805421,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z54255426 = $f54315432();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54315432,
"from":L[693]});
}
} catch($e54235424) {
if(R.isCont($e54235424)) {
var $ss54275428 = {"from":L[693],
"go":function(cont_tail_app4265433) {
return $Hcont_tail_app13915434(cont_tail_app4265433);
}};
$e54235424.stack[R.EXN_STACKHEIGHT++] = $ss54275428;
}
if(R.isPyretException($e54235424)) {
$e54235424.pyretStack.push(L[693]);
}
throw $e54235424;
}
var $ret54295430 = $Hcont_tail_app13915434($z54255426);
++R.GAS;
return $ret54295430;
}
} else {
var cont_tail_arg4235438 = R.throwNonBooleanCondition(L[377],("when"),when_DASH_375435);
if(--R.GAS > 0) {
$z54365437 = R.isFunction(if_helper3805421)?if_helper3805421.app(cont_tail_arg4235438):R.ffi.throwNonFunApp(L[377],if_helper3805421,[cont_tail_arg4235438]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3805421)?if_helper3805421.app(cont_tail_arg4235438):R.ffi.throwNonFunApp(L[377],if_helper3805421,[cont_tail_arg4235438]);
},
"from":L[377]});
}
++R.GAS;
return $z54365437;
}
});
var anf_if4315407 = R.isBoolean(and_DASH_oper_DASH_381939);
if(R.isPyretTrue(anf_if4315407)) {
if(R.isPyretTrue(and_DASH_oper_DASH_381939)) {
var anf_fun4335387 = G(reserved_DASH_names7442,"member",L[689]);
var anf_arg4345388 = G(name2461938,"s",L[688]);
var $z53795380 = D;
var $f53855386 = function(_) {
return R.isFunction(anf_fun4335387)?anf_fun4335387.app(anf_arg4345388):R.ffi.throwNonFunApp(L[377],anf_fun4335387,[anf_arg4345388]);
};
try {
if(--R.GAS > 0) {
$z53795380 = $f53855386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53855386,
"from":L[377]});
}
} catch($e53775378) {
if(R.isCont($e53775378)) {
var $ss53815382 = {"from":L[377],
"go":function(and_DASH_oper_DASH_395389) {
return $Hand_DASH_oper_DASH_13935391(and_DASH_oper_DASH_395389,if_helper3785390);
}};
$e53775378.stack[R.EXN_STACKHEIGHT++] = $ss53815382;
}
if(R.isPyretException($e53775378)) {
$e53775378.pyretStack.push(L[377]);
}
throw $e53775378;
}
var $ret53835384 = $Hand_DASH_oper_DASH_13935391($z53795380,if_helper3785390);
++R.GAS;
return $ret53835384;
} else {
var $z53945395 = D;
var $f54005401 = function(_) {
return R.isFunction(if_helper3785390)?if_helper3785390.app((false)):R.ffi.throwNonFunApp(L[377],if_helper3785390,[(false)]);
};
try {
if(--R.GAS > 0) {
$z53945395 = $f54005401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54005401,
"from":L[377]});
}
} catch($e53925393) {
if(R.isCont($e53925393)) {
var $ss53965397 = {"from":L[377],
"go":function(cont_tail_app4325402) {
return $Hcont_tail_app13945403(cont_tail_app4325402);
}};
$e53925393.stack[R.EXN_STACKHEIGHT++] = $ss53965397;
}
if(R.isPyretException($e53925393)) {
$e53925393.pyretStack.push(L[377]);
}
throw $e53925393;
}
var $ret53985399 = $Hcont_tail_app13945403($z53945395);
++R.GAS;
return $ret53985399;
}
} else {
var cont_tail_arg4295406 = R.throwNonBooleanOp(L[690],("first"),("and"),and_DASH_oper_DASH_381939);
if(--R.GAS > 0) {
$z54045405 = R.isFunction(if_helper3785390)?if_helper3785390.app(cont_tail_arg4295406):R.ffi.throwNonFunApp(L[690],if_helper3785390,[cont_tail_arg4295406]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3785390)?if_helper3785390.app(cont_tail_arg4295406):R.ffi.throwNonFunApp(L[690],if_helper3785390,[cont_tail_arg4295406]);
},
"from":L[690]});
}
++R.GAS;
return $z54045405;
}
};
var $Hand_DASH_oper_DASH_13935391 = function(and_DASH_oper_DASH_395389,if_helper3785390) {
var anf_if4375469 = R.isBoolean(and_DASH_oper_DASH_395389);
if(R.isPyretTrue(anf_if4375469)) {
var $z54565457 = D;
var $f54625463 = function(_) {
return R.isFunction(if_helper3785390)?if_helper3785390.app(and_DASH_oper_DASH_395389):R.ffi.throwNonFunApp(L[377],if_helper3785390,[and_DASH_oper_DASH_395389]);
};
try {
if(--R.GAS > 0) {
$z54565457 = $f54625463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54625463,
"from":L[377]});
}
} catch($e54545455) {
if(R.isCont($e54545455)) {
var $ss54585459 = {"from":L[377],
"go":function(cont_tail_app4385464) {
return $Hcont_tail_app13925465(cont_tail_app4385464);
}};
$e54545455.stack[R.EXN_STACKHEIGHT++] = $ss54585459;
}
if(R.isPyretException($e54545455)) {
$e54545455.pyretStack.push(L[377]);
}
throw $e54545455;
}
var $ret54605461 = $Hcont_tail_app13925465($z54565457);
++R.GAS;
return $ret54605461;
} else {
var cont_tail_arg4355468 = R.throwNonBooleanOp(L[696],("second"),("and"),and_DASH_oper_DASH_395389);
if(--R.GAS > 0) {
$z54665467 = R.isFunction(if_helper3785390)?if_helper3785390.app(cont_tail_arg4355468):R.ffi.throwNonFunApp(L[696],if_helper3785390,[cont_tail_arg4355468]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3785390)?if_helper3785390.app(cont_tail_arg4355468):R.ffi.throwNonFunApp(L[696],if_helper3785390,[cont_tail_arg4355468]);
},
"from":L[696]});
}
++R.GAS;
return $z54665467;
}
};
var $Hcont_tail_app13925465 = function(cont_tail_app4385464) {
return cont_tail_app4385464;
};
var $Hcont_tail_app13945403 = function(cont_tail_app4325402) {
return cont_tail_app4325402;
};
var $Hanf_begin_app_dropped13905422 = function(anf_begin_app_dropped13885420,if_helper3805421,nothing4) {
var $z54725473 = D;
var $f54785479 = function(_) {
return R.isFunction(if_helper3805421)?if_helper3805421.app(nothing4):R.ffi.throwNonFunApp(L[693],if_helper3805421,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z54725473 = $f54785479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54785479,
"from":L[693]});
}
} catch($e54705471) {
if(R.isCont($e54705471)) {
var $ss54745475 = {"from":L[693],
"go":function(cont_tail_app4285480) {
return $Hcont_tail_app13895481(cont_tail_app4285480);
}};
$e54705471.stack[R.EXN_STACKHEIGHT++] = $ss54745475;
}
if(R.isPyretException($e54705471)) {
$e54705471.pyretStack.push(L[693]);
}
throw $e54705471;
}
var $ret54765477 = $Hcont_tail_app13895481($z54725473);
++R.GAS;
return $ret54765477;
};
var $Hcont_tail_app13895481 = function(cont_tail_app4285480) {
return cont_tail_app4285480;
};
var $Hcont_tail_app13915434 = function(cont_tail_app4265433) {
return cont_tail_app4265433;
};
var $Hanf_arg13875453 = function(anf_arg3835452,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,ensure_DASH_unique_DASH_ids9973,l2451944,lists1118,self2441945,wf_DASH_error7659,wrap_DASH_visit_DASH_check8067,nothing4) {
var when_DASH_405507 = R.equiv(anf_arg3835452,(0));
var if_helper3845493 = R.makeFunction(function(if_helper_arg3855512) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[698],1,arguments);
}
if_helper_arg3855512;
var $z55155516 = D;
var $f55215522 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(args2471942):R.ffi.throwNonFunApp(L[700],ensure_DASH_unique_DASH_ids9973.$var,[args2471942]);
};
try {
if(--R.GAS > 0) {
$z55155516 = $f55215522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55215522,
"from":L[700]});
}
} catch($e55135514) {
if(R.isCont($e55135514)) {
var $ss55175518 = {"from":L[700],
"go":function(anf_begin_app_dropped13695523) {
return $Hanf_begin_app_dropped13825524(anf_begin_app_dropped13695523,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,l2451944,lists1118,self2441945,wrap_DASH_visit_DASH_check8067,nothing4);
}};
$e55135514.stack[R.EXN_STACKHEIGHT++] = $ss55175518;
}
if(R.isPyretException($e55135514)) {
$e55135514.pyretStack.push(L[700]);
}
throw $e55135514;
}
var $ret55195520 = $Hanf_begin_app_dropped13825524($z55155516,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,l2451944,lists1118,self2441945,wrap_DASH_visit_DASH_check8067,nothing4);
++R.GAS;
return $ret55195520;
});
var anf_if4205511 = R.isBoolean(when_DASH_405507);
if(R.isPyretTrue(anf_if4205511)) {
if(R.isPyretTrue(when_DASH_405507)) {
var $z54845485 = D;
var $f54905491 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot have a method with zero arguments"),l2451944):R.ffi.throwNonFunApp(L[697],wf_DASH_error7659.$var,[("Cannot have a method with zero arguments"),l2451944]);
};
try {
if(--R.GAS > 0) {
$z54845485 = $f54905491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54905491,
"from":L[697]});
}
} catch($e54825483) {
if(R.isCont($e54825483)) {
var $ss54865487 = {"from":L[697],
"go":function(anf_begin_app_dropped13835492) {
return $Hanf_begin_app_dropped13855494(anf_begin_app_dropped13835492,if_helper3845493,nothing4);
}};
$e54825483.stack[R.EXN_STACKHEIGHT++] = $ss54865487;
}
if(R.isPyretException($e54825483)) {
$e54825483.pyretStack.push(L[697]);
}
throw $e54825483;
}
var $ret54885489 = $Hanf_begin_app_dropped13855494($z54845485,if_helper3845493,nothing4);
++R.GAS;
return $ret54885489;
} else {
var $z54975498 = D;
var $f55035504 = function(_) {
return R.isFunction(if_helper3845493)?if_helper3845493.app(nothing4):R.ffi.throwNonFunApp(L[698],if_helper3845493,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z54975498 = $f55035504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55035504,
"from":L[698]});
}
} catch($e54955496) {
if(R.isCont($e54955496)) {
var $ss54995500 = {"from":L[698],
"go":function(cont_tail_app4215505) {
return $Hcont_tail_app13865506(cont_tail_app4215505);
}};
$e54955496.stack[R.EXN_STACKHEIGHT++] = $ss54995500;
}
if(R.isPyretException($e54955496)) {
$e54955496.pyretStack.push(L[698]);
}
throw $e54955496;
}
var $ret55015502 = $Hcont_tail_app13865506($z54975498);
++R.GAS;
return $ret55015502;
}
} else {
var cont_tail_arg4185510 = R.throwNonBooleanCondition(L[699],("when"),when_DASH_405507);
if(--R.GAS > 0) {
$z55085509 = R.isFunction(if_helper3845493)?if_helper3845493.app(cont_tail_arg4185510):R.ffi.throwNonFunApp(L[699],if_helper3845493,[cont_tail_arg4185510]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3845493)?if_helper3845493.app(cont_tail_arg4185510):R.ffi.throwNonFunApp(L[699],if_helper3845493,[cont_tail_arg4185510]);
},
"from":L[699]});
}
++R.GAS;
return $z55085509;
}
};
var $Hanf_begin_app_dropped13855494 = function(anf_begin_app_dropped13835492,if_helper3845493,nothing4) {
var $z55275528 = D;
var $f55335534 = function(_) {
return R.isFunction(if_helper3845493)?if_helper3845493.app(nothing4):R.ffi.throwNonFunApp(L[698],if_helper3845493,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z55275528 = $f55335534();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55335534,
"from":L[698]});
}
} catch($e55255526) {
if(R.isCont($e55255526)) {
var $ss55295530 = {"from":L[698],
"go":function(cont_tail_app4225535) {
return $Hcont_tail_app13845536(cont_tail_app4225535);
}};
$e55255526.stack[R.EXN_STACKHEIGHT++] = $ss55295530;
}
if(R.isPyretException($e55255526)) {
$e55255526.pyretStack.push(L[698]);
}
throw $e55255526;
}
var $ret55315532 = $Hcont_tail_app13845536($z55275528);
++R.GAS;
return $ret55315532;
};
var $Hcont_tail_app13845536 = function(cont_tail_app4225535) {
return cont_tail_app4225535;
};
var $Hcont_tail_app13865506 = function(cont_tail_app4215505) {
return cont_tail_app4215505;
};
var $Hanf_begin_app_dropped13825524 = function(anf_begin_app_dropped13695523,_check2511940,ann2481941,args2471942,body2501943,ensure_DASH_empty_DASH_block9769,l2451944,lists1118,self2441945,wrap_DASH_visit_DASH_check8067,nothing4) {
var cases_DASH_val415569 = _check2511940;
var anf_fun3865547 = G(cases_DASH_val415569,"_match",L[701]);
var anf_obj3885553 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[703],0,arguments);
}
var ann_DASH_check_DASH_temp3875568 = nothing4;
return ann_DASH_check_DASH_temp3875568;
});
var anf_obj3905554 = R.makeFunction(function(chk2525555) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[702],1,arguments);
}
var $z55585559 = D;
var $f55645565 = function(_) {
return R.isFunction(ensure_DASH_empty_DASH_block9769.$var)?ensure_DASH_empty_DASH_block9769.$var.app(l2451944,("methods"),chk2525555):R.ffi.throwNonFunApp(L[702],ensure_DASH_empty_DASH_block9769.$var,[l2451944,("methods"),chk2525555]);
};
try {
if(--R.GAS > 0) {
$z55585559 = $f55645565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55645565,
"from":L[702]});
}
} catch($e55565557) {
if(R.isCont($e55565557)) {
var $ss55605561 = {"from":L[702],
"go":function(ann_DASH_check_DASH_temp3895566) {
return $Hann_DASH_check_DASH_temp13705567(ann_DASH_check_DASH_temp3895566);
}};
$e55565557.stack[R.EXN_STACKHEIGHT++] = $ss55605561;
}
if(R.isPyretException($e55565557)) {
$e55565557.pyretStack.push(L[702]);
}
throw $e55565557;
}
var $ret55625563 = $Hann_DASH_check_DASH_temp13705567($z55585559);
++R.GAS;
return $ret55625563;
});
var anf_arg3915548 = R.makeObject({"none":anf_obj3885553,
"some":anf_obj3905554});
var anf_arg3935549 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[701],0,arguments);
}
var ann_DASH_check_DASH_temp3925552 = R.throwNoBranchesMatched(L[701],("cases"));
return ann_DASH_check_DASH_temp3925552;
});
var $z55395540 = D;
var $f55455546 = function(_) {
return R.isFunction(anf_fun3865547)?anf_fun3865547.app(anf_arg3915548,anf_arg3935549):R.ffi.throwNonFunApp(L[701],anf_fun3865547,[anf_arg3915548,anf_arg3935549]);
};
try {
if(--R.GAS > 0) {
$z55395540 = $f55455546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55455546,
"from":L[701]});
}
} catch($e55375538) {
if(R.isCont($e55375538)) {
var $ss55415542 = {"from":L[701],
"go":function(anf_begin_app_dropped13715550) {
return $Hanf_begin_app_dropped13815551(anf_begin_app_dropped13715550,_check2511940,ann2481941,args2471942,body2501943,lists1118,self2441945,wrap_DASH_visit_DASH_check8067);
}};
$e55375538.stack[R.EXN_STACKHEIGHT++] = $ss55415542;
}
if(R.isPyretException($e55375538)) {
$e55375538.pyretStack.push(L[701]);
}
throw $e55375538;
}
var $ret55435544 = $Hanf_begin_app_dropped13815551($z55395540,_check2511940,ann2481941,args2471942,body2501943,lists1118,self2441945,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret55435544;
};
var $Hanf_begin_app_dropped13815551 = function(anf_begin_app_dropped13715550,_check2511940,ann2481941,args2471942,body2501943,lists1118,self2441945,wrap_DASH_visit_DASH_check8067) {
var anf_fun3945580 = G(lists1118,"all",L[706]);
var anf_arg3975581 = R.makeFunction(function(recv_DASH_435584) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[705],1,arguments);
}
var anf_fun3965595 = G(recv_DASH_435584,"visit",L[705]);
var $z55875588 = D;
var $f55935594 = function(_) {
return R.isFunction(anf_fun3965595)?anf_fun3965595.app(self2441945):R.ffi.throwNonFunApp(L[705],anf_fun3965595,[self2441945]);
};
try {
if(--R.GAS > 0) {
$z55875588 = $f55935594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55935594,
"from":L[705]});
}
} catch($e55855586) {
if(R.isCont($e55855586)) {
var $ss55895590 = {"from":L[705],
"go":function(ann_DASH_check_DASH_temp3955596) {
return $Hann_DASH_check_DASH_temp13725597(ann_DASH_check_DASH_temp3955596);
}};
$e55855586.stack[R.EXN_STACKHEIGHT++] = $ss55895590;
}
if(R.isPyretException($e55855586)) {
$e55855586.pyretStack.push(L[705]);
}
throw $e55855586;
}
var $ret55915592 = $Hann_DASH_check_DASH_temp13725597($z55875588);
++R.GAS;
return $ret55915592;
});
var $z55725573 = D;
var $f55785579 = function(_) {
return R.isFunction(anf_fun3945580)?anf_fun3945580.app(anf_arg3975581,args2471942):R.ffi.throwNonFunApp(L[704],anf_fun3945580,[anf_arg3975581,args2471942]);
};
try {
if(--R.GAS > 0) {
$z55725573 = $f55785579();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55785579,
"from":L[704]});
}
} catch($e55705571) {
if(R.isCont($e55705571)) {
var $ss55745575 = {"from":L[704],
"go":function(and_DASH_oper_DASH_425582) {
return $Hand_DASH_oper_DASH_13805583(and_DASH_oper_DASH_425582,_check2511940,ann2481941,body2501943,self2441945,wrap_DASH_visit_DASH_check8067);
}};
$e55705571.stack[R.EXN_STACKHEIGHT++] = $ss55745575;
}
if(R.isPyretException($e55705571)) {
$e55705571.pyretStack.push(L[704]);
}
throw $e55705571;
}
var $ret55765577 = $Hand_DASH_oper_DASH_13805583($z55725573,_check2511940,ann2481941,body2501943,self2441945,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret55765577;
};
var $Hand_DASH_oper_DASH_13805583 = function(and_DASH_oper_DASH_425582,_check2511940,ann2481941,body2501943,self2441945,wrap_DASH_visit_DASH_check8067) {
var if_helper3985610 = R.makeFunction(function(if_helper_arg3995628) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[704],1,arguments);
}
var ann_DASH_check_DASH_temp3765629 = if_helper_arg3995628;
return ann_DASH_check_DASH_temp3765629;
});
var anf_if4025627 = R.isBoolean(and_DASH_oper_DASH_425582);
if(R.isPyretTrue(anf_if4025627)) {
if(R.isPyretTrue(and_DASH_oper_DASH_425582)) {
var anf_fun4045608 = G(ann2481941,"visit",L[707]);
var $z56005601 = D;
var $f56065607 = function(_) {
return R.isFunction(anf_fun4045608)?anf_fun4045608.app(self2441945):R.ffi.throwNonFunApp(L[704],anf_fun4045608,[self2441945]);
};
try {
if(--R.GAS > 0) {
$z56005601 = $f56065607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56065607,
"from":L[704]});
}
} catch($e55985599) {
if(R.isCont($e55985599)) {
var $ss56025603 = {"from":L[704],
"go":function(and_DASH_oper_DASH_445609) {
return $Hand_DASH_oper_DASH_13785611(and_DASH_oper_DASH_445609,_check2511940,body2501943,if_helper3985610,self2441945,wrap_DASH_visit_DASH_check8067);
}};
$e55985599.stack[R.EXN_STACKHEIGHT++] = $ss56025603;
}
if(R.isPyretException($e55985599)) {
$e55985599.pyretStack.push(L[704]);
}
throw $e55985599;
}
var $ret56045605 = $Hand_DASH_oper_DASH_13785611($z56005601,_check2511940,body2501943,if_helper3985610,self2441945,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret56045605;
} else {
var $z56145615 = D;
var $f56205621 = function(_) {
return R.isFunction(if_helper3985610)?if_helper3985610.app((false)):R.ffi.throwNonFunApp(L[704],if_helper3985610,[(false)]);
};
try {
if(--R.GAS > 0) {
$z56145615 = $f56205621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56205621,
"from":L[704]});
}
} catch($e56125613) {
if(R.isCont($e56125613)) {
var $ss56165617 = {"from":L[704],
"go":function(cont_tail_app4035622) {
return $Hcont_tail_app13795623(cont_tail_app4035622);
}};
$e56125613.stack[R.EXN_STACKHEIGHT++] = $ss56165617;
}
if(R.isPyretException($e56125613)) {
$e56125613.pyretStack.push(L[704]);
}
throw $e56125613;
}
var $ret56185619 = $Hcont_tail_app13795623($z56145615);
++R.GAS;
return $ret56185619;
}
} else {
var cont_tail_arg4005626 = R.throwNonBooleanOp(L[708],("first"),("and"),and_DASH_oper_DASH_425582);
if(--R.GAS > 0) {
$z56245625 = R.isFunction(if_helper3985610)?if_helper3985610.app(cont_tail_arg4005626):R.ffi.throwNonFunApp(L[708],if_helper3985610,[cont_tail_arg4005626]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3985610)?if_helper3985610.app(cont_tail_arg4005626):R.ffi.throwNonFunApp(L[708],if_helper3985610,[cont_tail_arg4005626]);
},
"from":L[708]});
}
++R.GAS;
return $z56245625;
}
};
var $Hand_DASH_oper_DASH_13785611 = function(and_DASH_oper_DASH_445609,_check2511940,body2501943,if_helper3985610,self2441945,wrap_DASH_visit_DASH_check8067) {
var anf_if4075658 = R.isBoolean(and_DASH_oper_DASH_445609);
if(R.isPyretTrue(anf_if4075658)) {
if(R.isPyretTrue(and_DASH_oper_DASH_445609)) {
var anf_fun4095640 = G(body2501943,"visit",L[709]);
var $z56325633 = D;
var $f56385639 = function(_) {
return R.isFunction(anf_fun4095640)?anf_fun4095640.app(self2441945):R.ffi.throwNonFunApp(L[704],anf_fun4095640,[self2441945]);
};
try {
if(--R.GAS > 0) {
$z56325633 = $f56385639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56385639,
"from":L[704]});
}
} catch($e56305631) {
if(R.isCont($e56305631)) {
var $ss56345635 = {"from":L[704],
"go":function(and_DASH_oper_DASH_455641) {
return $Hand_DASH_oper_DASH_13765642(and_DASH_oper_DASH_455641,_check2511940,if_helper3985610,self2441945,wrap_DASH_visit_DASH_check8067);
}};
$e56305631.stack[R.EXN_STACKHEIGHT++] = $ss56345635;
}
if(R.isPyretException($e56305631)) {
$e56305631.pyretStack.push(L[704]);
}
throw $e56305631;
}
var $ret56365637 = $Hand_DASH_oper_DASH_13765642($z56325633,_check2511940,if_helper3985610,self2441945,wrap_DASH_visit_DASH_check8067);
++R.GAS;
return $ret56365637;
} else {
var $z56455646 = D;
var $f56515652 = function(_) {
return R.isFunction(if_helper3985610)?if_helper3985610.app((false)):R.ffi.throwNonFunApp(L[704],if_helper3985610,[(false)]);
};
try {
if(--R.GAS > 0) {
$z56455646 = $f56515652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56515652,
"from":L[704]});
}
} catch($e56435644) {
if(R.isCont($e56435644)) {
var $ss56475648 = {"from":L[704],
"go":function(cont_tail_app4085653) {
return $Hcont_tail_app13775654(cont_tail_app4085653);
}};
$e56435644.stack[R.EXN_STACKHEIGHT++] = $ss56475648;
}
if(R.isPyretException($e56435644)) {
$e56435644.pyretStack.push(L[704]);
}
throw $e56435644;
}
var $ret56495650 = $Hcont_tail_app13775654($z56455646);
++R.GAS;
return $ret56495650;
}
} else {
var cont_tail_arg4055657 = R.throwNonBooleanOp(L[710],("first"),("and"),and_DASH_oper_DASH_445609);
if(--R.GAS > 0) {
$z56555656 = R.isFunction(if_helper3985610)?if_helper3985610.app(cont_tail_arg4055657):R.ffi.throwNonFunApp(L[710],if_helper3985610,[cont_tail_arg4055657]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3985610)?if_helper3985610.app(cont_tail_arg4055657):R.ffi.throwNonFunApp(L[710],if_helper3985610,[cont_tail_arg4055657]);
},
"from":L[710]});
}
++R.GAS;
return $z56555656;
}
};
var $Hand_DASH_oper_DASH_13765642 = function(and_DASH_oper_DASH_455641,_check2511940,if_helper3985610,self2441945,wrap_DASH_visit_DASH_check8067) {
var anf_if4125686 = R.isBoolean(and_DASH_oper_DASH_455641);
if(R.isPyretTrue(anf_if4125686)) {
if(R.isPyretTrue(and_DASH_oper_DASH_455641)) {
var $z56615662 = D;
var $f56675668 = function(_) {
return R.isFunction(wrap_DASH_visit_DASH_check8067.$var)?wrap_DASH_visit_DASH_check8067.$var.app(self2441945,_check2511940):R.ffi.throwNonFunApp(L[704],wrap_DASH_visit_DASH_check8067.$var,[self2441945,_check2511940]);
};
try {
if(--R.GAS > 0) {
$z56615662 = $f56675668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56675668,
"from":L[704]});
}
} catch($e56595660) {
if(R.isCont($e56595660)) {
var $ss56635664 = {"from":L[704],
"go":function(and_DASH_oper_DASH_465669) {
return $Hand_DASH_oper_DASH_13745670(and_DASH_oper_DASH_465669,if_helper3985610);
}};
$e56595660.stack[R.EXN_STACKHEIGHT++] = $ss56635664;
}
if(R.isPyretException($e56595660)) {
$e56595660.pyretStack.push(L[704]);
}
throw $e56595660;
}
var $ret56655666 = $Hand_DASH_oper_DASH_13745670($z56615662,if_helper3985610);
++R.GAS;
return $ret56655666;
} else {
var $z56735674 = D;
var $f56795680 = function(_) {
return R.isFunction(if_helper3985610)?if_helper3985610.app((false)):R.ffi.throwNonFunApp(L[704],if_helper3985610,[(false)]);
};
try {
if(--R.GAS > 0) {
$z56735674 = $f56795680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56795680,
"from":L[704]});
}
} catch($e56715672) {
if(R.isCont($e56715672)) {
var $ss56755676 = {"from":L[704],
"go":function(cont_tail_app4135681) {
return $Hcont_tail_app13755682(cont_tail_app4135681);
}};
$e56715672.stack[R.EXN_STACKHEIGHT++] = $ss56755676;
}
if(R.isPyretException($e56715672)) {
$e56715672.pyretStack.push(L[704]);
}
throw $e56715672;
}
var $ret56775678 = $Hcont_tail_app13755682($z56735674);
++R.GAS;
return $ret56775678;
}
} else {
var cont_tail_arg4105685 = R.throwNonBooleanOp(L[711],("first"),("and"),and_DASH_oper_DASH_455641);
if(--R.GAS > 0) {
$z56835684 = R.isFunction(if_helper3985610)?if_helper3985610.app(cont_tail_arg4105685):R.ffi.throwNonFunApp(L[711],if_helper3985610,[cont_tail_arg4105685]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3985610)?if_helper3985610.app(cont_tail_arg4105685):R.ffi.throwNonFunApp(L[711],if_helper3985610,[cont_tail_arg4105685]);
},
"from":L[711]});
}
++R.GAS;
return $z56835684;
}
};
var $Hand_DASH_oper_DASH_13745670 = function(and_DASH_oper_DASH_465669,if_helper3985610) {
var anf_if4165702 = R.isBoolean(and_DASH_oper_DASH_465669);
if(R.isPyretTrue(anf_if4165702)) {
var $z56895690 = D;
var $f56955696 = function(_) {
return R.isFunction(if_helper3985610)?if_helper3985610.app(and_DASH_oper_DASH_465669):R.ffi.throwNonFunApp(L[704],if_helper3985610,[and_DASH_oper_DASH_465669]);
};
try {
if(--R.GAS > 0) {
$z56895690 = $f56955696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56955696,
"from":L[704]});
}
} catch($e56875688) {
if(R.isCont($e56875688)) {
var $ss56915692 = {"from":L[704],
"go":function(cont_tail_app4175697) {
return $Hcont_tail_app13735698(cont_tail_app4175697);
}};
$e56875688.stack[R.EXN_STACKHEIGHT++] = $ss56915692;
}
if(R.isPyretException($e56875688)) {
$e56875688.pyretStack.push(L[704]);
}
throw $e56875688;
}
var $ret56935694 = $Hcont_tail_app13735698($z56895690);
++R.GAS;
return $ret56935694;
} else {
var cont_tail_arg4145701 = R.throwNonBooleanOp(L[712],("second"),("and"),and_DASH_oper_DASH_465669);
if(--R.GAS > 0) {
$z56995700 = R.isFunction(if_helper3985610)?if_helper3985610.app(cont_tail_arg4145701):R.ffi.throwNonFunApp(L[712],if_helper3985610,[cont_tail_arg4145701]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3985610)?if_helper3985610.app(cont_tail_arg4145701):R.ffi.throwNonFunApp(L[712],if_helper3985610,[cont_tail_arg4145701]);
},
"from":L[712]});
}
++R.GAS;
return $z56995700;
}
};
var $Hcont_tail_app13735698 = function(cont_tail_app4175697) {
return cont_tail_app4175697;
};
var $Hcont_tail_app13755682 = function(cont_tail_app4135681) {
return cont_tail_app4135681;
};
var $Hcont_tail_app13775654 = function(cont_tail_app4085653) {
return cont_tail_app4085653;
};
var $Hcont_tail_app13795623 = function(cont_tail_app4035622) {
return cont_tail_app4035622;
};
var $Hann_DASH_check_DASH_temp13725597 = function(ann_DASH_check_DASH_temp3955596) {
return ann_DASH_check_DASH_temp3955596;
};
var $Hann_DASH_check_DASH_temp13705567 = function(ann_DASH_check_DASH_temp3895566) {
return ann_DASH_check_DASH_temp3895566;
};
var $Hwhen_DASH_13681964 = function(when_DASH_331958,l2401959,left2421960,op2411961,right2431962,self2391963,wf_DASH_error7659,nothing4) {
var if_helper3475744 = R.makeFunction(function(if_helper_arg3485763) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[380],1,arguments);
}
if_helper_arg3485763;
var anf_fun3495774 = G(left2421960,"visit",L[718]);
var $z57665767 = D;
var $f57725773 = function(_) {
return R.isFunction(anf_fun3495774)?anf_fun3495774.app(self2391963):R.ffi.throwNonFunApp(L[717],anf_fun3495774,[self2391963]);
};
try {
if(--R.GAS > 0) {
$z57665767 = $f57725773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57725773,
"from":L[717]});
}
} catch($e57645765) {
if(R.isCont($e57645765)) {
var $ss57685769 = {"from":L[717],
"go":function(and_DASH_oper_DASH_355775) {
return $Hand_DASH_oper_DASH_13635776(and_DASH_oper_DASH_355775,right2431962,self2391963);
}};
$e57645765.stack[R.EXN_STACKHEIGHT++] = $ss57685769;
}
if(R.isPyretException($e57645765)) {
$e57645765.pyretStack.push(L[717]);
}
throw $e57645765;
}
var $ret57705771 = $Hand_DASH_oper_DASH_13635776($z57665767,right2431962,self2391963);
++R.GAS;
return $ret57705771;
});
var anf_if3635762 = R.isBoolean(when_DASH_331958);
if(R.isPyretTrue(anf_if3635762)) {
if(R.isPyretTrue(when_DASH_331958)) {
var if_DASH_345728 = R.equiv(op2411961,("opis"));
var if_helper3655714 = R.makeFunction(function(if_helper_arg3665733) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[715],1,arguments);
}
if_helper_arg3665733;
var $z57365737 = D;
var $f57425743 = function(_) {
return R.isFunction(if_helper3475744)?if_helper3475744.app(nothing4):R.ffi.throwNonFunApp(L[380],if_helper3475744,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z57365737 = $f57425743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57425743,
"from":L[380]});
}
} catch($e57345735) {
if(R.isCont($e57345735)) {
var $ss57385739 = {"from":L[380],
"go":function(cont_tail_app3675745) {
return $Hcont_tail_app13645746(cont_tail_app3675745);
}};
$e57345735.stack[R.EXN_STACKHEIGHT++] = $ss57385739;
}
if(R.isPyretException($e57345735)) {
$e57345735.pyretStack.push(L[380]);
}
throw $e57345735;
}
var $ret57405741 = $Hcont_tail_app13645746($z57365737);
++R.GAS;
return $ret57405741;
});
var anf_if3705732 = R.isBoolean(if_DASH_345728);
if(R.isPyretTrue(anf_if3705732)) {
if(R.isPyretTrue(if_DASH_345728)) {
var $z57055706 = D;
var $f57115712 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot use `is` outside of a `check` or `where` block"),l2401959):R.ffi.throwNonFunApp(L[713],wf_DASH_error7659.$var,[("Cannot use `is` outside of a `check` or `where` block"),l2401959]);
};
try {
if(--R.GAS > 0) {
$z57055706 = $f57115712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57115712,
"from":L[713]});
}
} catch($e57035704) {
if(R.isCont($e57035704)) {
var $ss57075708 = {"from":L[713],
"go":function(cont_tail_arg3735713) {
return $Hcont_tail_arg13655715(cont_tail_arg3735713,if_helper3655714);
}};
$e57035704.stack[R.EXN_STACKHEIGHT++] = $ss57075708;
}
if(R.isPyretException($e57035704)) {
$e57035704.pyretStack.push(L[713]);
}
throw $e57035704;
}
var $ret57095710 = $Hcont_tail_arg13655715($z57055706,if_helper3655714);
++R.GAS;
return $ret57095710;
} else {
var $z57185719 = D;
var $f57245725 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Cannot use a check-test form outside of a `check` or `where` block"),l2401959):R.ffi.throwNonFunApp(L[714],wf_DASH_error7659.$var,[("Cannot use a check-test form outside of a `check` or `where` block"),l2401959]);
};
try {
if(--R.GAS > 0) {
$z57185719 = $f57245725();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57245725,
"from":L[714]});
}
} catch($e57165717) {
if(R.isCont($e57165717)) {
var $ss57205721 = {"from":L[714],
"go":function(cont_tail_arg3715726) {
return $Hcont_tail_arg13665727(cont_tail_arg3715726,if_helper3655714);
}};
$e57165717.stack[R.EXN_STACKHEIGHT++] = $ss57205721;
}
if(R.isPyretException($e57165717)) {
$e57165717.pyretStack.push(L[714]);
}
throw $e57165717;
}
var $ret57225723 = $Hcont_tail_arg13665727($z57185719,if_helper3655714);
++R.GAS;
return $ret57225723;
}
} else {
var cont_tail_arg3685731 = R.throwNonBooleanCondition(L[715],("if"),if_DASH_345728);
if(--R.GAS > 0) {
$z57295730 = R.isFunction(if_helper3655714)?if_helper3655714.app(cont_tail_arg3685731):R.ffi.throwNonFunApp(L[715],if_helper3655714,[cont_tail_arg3685731]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3655714)?if_helper3655714.app(cont_tail_arg3685731):R.ffi.throwNonFunApp(L[715],if_helper3655714,[cont_tail_arg3685731]);
},
"from":L[715]});
}
++R.GAS;
return $z57295730;
}
} else {
var $z57495750 = D;
var $f57555756 = function(_) {
return R.isFunction(if_helper3475744)?if_helper3475744.app(nothing4):R.ffi.throwNonFunApp(L[380],if_helper3475744,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z57495750 = $f57555756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57555756,
"from":L[380]});
}
} catch($e57475748) {
if(R.isCont($e57475748)) {
var $ss57515752 = {"from":L[380],
"go":function(cont_tail_app3645757) {
return $Hcont_tail_app13675758(cont_tail_app3645757);
}};
$e57475748.stack[R.EXN_STACKHEIGHT++] = $ss57515752;
}
if(R.isPyretException($e57475748)) {
$e57475748.pyretStack.push(L[380]);
}
throw $e57475748;
}
var $ret57535754 = $Hcont_tail_app13675758($z57495750);
++R.GAS;
return $ret57535754;
}
} else {
var cont_tail_arg3615761 = R.throwNonBooleanCondition(L[716],("when"),when_DASH_331958);
if(--R.GAS > 0) {
$z57595760 = R.isFunction(if_helper3475744)?if_helper3475744.app(cont_tail_arg3615761):R.ffi.throwNonFunApp(L[716],if_helper3475744,[cont_tail_arg3615761]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3475744)?if_helper3475744.app(cont_tail_arg3615761):R.ffi.throwNonFunApp(L[716],if_helper3475744,[cont_tail_arg3615761]);
},
"from":L[716]});
}
++R.GAS;
return $z57595760;
}
};
var $Hcont_tail_arg13655715 = function(cont_tail_arg3735713,if_helper3655714) {
if(--R.GAS > 0) {
$z57775778 = R.isFunction(if_helper3655714)?if_helper3655714.app(cont_tail_arg3735713):R.ffi.throwNonFunApp(L[713],if_helper3655714,[cont_tail_arg3735713]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3655714)?if_helper3655714.app(cont_tail_arg3735713):R.ffi.throwNonFunApp(L[713],if_helper3655714,[cont_tail_arg3735713]);
},
"from":L[713]});
}
++R.GAS;
return $z57775778;
};
var $Hcont_tail_arg13665727 = function(cont_tail_arg3715726,if_helper3655714) {
if(--R.GAS > 0) {
$z57795780 = R.isFunction(if_helper3655714)?if_helper3655714.app(cont_tail_arg3715726):R.ffi.throwNonFunApp(L[714],if_helper3655714,[cont_tail_arg3715726]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3655714)?if_helper3655714.app(cont_tail_arg3715726):R.ffi.throwNonFunApp(L[714],if_helper3655714,[cont_tail_arg3715726]);
},
"from":L[714]});
}
++R.GAS;
return $z57795780;
};
var $Hcont_tail_app13645746 = function(cont_tail_app3675745) {
return cont_tail_app3675745;
};
var $Hcont_tail_app13675758 = function(cont_tail_app3645757) {
return cont_tail_app3645757;
};
var $Hand_DASH_oper_DASH_13635776 = function(and_DASH_oper_DASH_355775,right2431962,self2391963) {
var if_helper3505793 = R.makeFunction(function(if_helper_arg3515811) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[717],1,arguments);
}
var ann_DASH_check_DASH_temp3465812 = if_helper_arg3515811;
return ann_DASH_check_DASH_temp3465812;
});
var anf_if3545810 = R.isBoolean(and_DASH_oper_DASH_355775);
if(R.isPyretTrue(anf_if3545810)) {
if(R.isPyretTrue(and_DASH_oper_DASH_355775)) {
var anf_fun3565791 = G(right2431962,"visit",L[719]);
var $z57835784 = D;
var $f57895790 = function(_) {
return R.isFunction(anf_fun3565791)?anf_fun3565791.app(self2391963):R.ffi.throwNonFunApp(L[717],anf_fun3565791,[self2391963]);
};
try {
if(--R.GAS > 0) {
$z57835784 = $f57895790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57895790,
"from":L[717]});
}
} catch($e57815782) {
if(R.isCont($e57815782)) {
var $ss57855786 = {"from":L[717],
"go":function(and_DASH_oper_DASH_365792) {
return $Hand_DASH_oper_DASH_13615794(and_DASH_oper_DASH_365792,if_helper3505793);
}};
$e57815782.stack[R.EXN_STACKHEIGHT++] = $ss57855786;
}
if(R.isPyretException($e57815782)) {
$e57815782.pyretStack.push(L[717]);
}
throw $e57815782;
}
var $ret57875788 = $Hand_DASH_oper_DASH_13615794($z57835784,if_helper3505793);
++R.GAS;
return $ret57875788;
} else {
var $z57975798 = D;
var $f58035804 = function(_) {
return R.isFunction(if_helper3505793)?if_helper3505793.app((false)):R.ffi.throwNonFunApp(L[717],if_helper3505793,[(false)]);
};
try {
if(--R.GAS > 0) {
$z57975798 = $f58035804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58035804,
"from":L[717]});
}
} catch($e57955796) {
if(R.isCont($e57955796)) {
var $ss57995800 = {"from":L[717],
"go":function(cont_tail_app3555805) {
return $Hcont_tail_app13625806(cont_tail_app3555805);
}};
$e57955796.stack[R.EXN_STACKHEIGHT++] = $ss57995800;
}
if(R.isPyretException($e57955796)) {
$e57955796.pyretStack.push(L[717]);
}
throw $e57955796;
}
var $ret58015802 = $Hcont_tail_app13625806($z57975798);
++R.GAS;
return $ret58015802;
}
} else {
var cont_tail_arg3525809 = R.throwNonBooleanOp(L[720],("first"),("and"),and_DASH_oper_DASH_355775);
if(--R.GAS > 0) {
$z58075808 = R.isFunction(if_helper3505793)?if_helper3505793.app(cont_tail_arg3525809):R.ffi.throwNonFunApp(L[720],if_helper3505793,[cont_tail_arg3525809]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3505793)?if_helper3505793.app(cont_tail_arg3525809):R.ffi.throwNonFunApp(L[720],if_helper3505793,[cont_tail_arg3525809]);
},
"from":L[720]});
}
++R.GAS;
return $z58075808;
}
};
var $Hand_DASH_oper_DASH_13615794 = function(and_DASH_oper_DASH_365792,if_helper3505793) {
var anf_if3595828 = R.isBoolean(and_DASH_oper_DASH_365792);
if(R.isPyretTrue(anf_if3595828)) {
var $z58155816 = D;
var $f58215822 = function(_) {
return R.isFunction(if_helper3505793)?if_helper3505793.app(and_DASH_oper_DASH_365792):R.ffi.throwNonFunApp(L[717],if_helper3505793,[and_DASH_oper_DASH_365792]);
};
try {
if(--R.GAS > 0) {
$z58155816 = $f58215822();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58215822,
"from":L[717]});
}
} catch($e58135814) {
if(R.isCont($e58135814)) {
var $ss58175818 = {"from":L[717],
"go":function(cont_tail_app3605823) {
return $Hcont_tail_app13605824(cont_tail_app3605823);
}};
$e58135814.stack[R.EXN_STACKHEIGHT++] = $ss58175818;
}
if(R.isPyretException($e58135814)) {
$e58135814.pyretStack.push(L[717]);
}
throw $e58135814;
}
var $ret58195820 = $Hcont_tail_app13605824($z58155816);
++R.GAS;
return $ret58195820;
} else {
var cont_tail_arg3575827 = R.throwNonBooleanOp(L[721],("second"),("and"),and_DASH_oper_DASH_365792);
if(--R.GAS > 0) {
$z58255826 = R.isFunction(if_helper3505793)?if_helper3505793.app(cont_tail_arg3575827):R.ffi.throwNonFunApp(L[721],if_helper3505793,[cont_tail_arg3575827]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3505793)?if_helper3505793.app(cont_tail_arg3575827):R.ffi.throwNonFunApp(L[721],if_helper3505793,[cont_tail_arg3575827]);
},
"from":L[721]});
}
++R.GAS;
return $z58255826;
}
};
var $Hcont_tail_app13605824 = function(cont_tail_app3605823) {
return cont_tail_app3605823;
};
var $Hcont_tail_app13625806 = function(cont_tail_app3555805) {
return cont_tail_app3555805;
};
var $Hanf_arg13591979 = function(anf_arg3361976,anf_fun3351977,l2351978,name2371975,reserved_DASH_name7965,nothing4,tostring10) {
var $z58315832 = D;
var $f58375838 = function(_) {
return R.isFunction(anf_fun3351977)?anf_fun3351977.app(anf_arg3361976):R.ffi.throwNonFunApp(L[722],anf_fun3351977,[anf_arg3361976]);
};
try {
if(--R.GAS > 0) {
$z58315832 = $f58375838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58375838,
"from":L[722]});
}
} catch($e58295830) {
if(R.isCont($e58295830)) {
var $ss58335834 = {"from":L[722],
"go":function(when_DASH_325839) {
return $Hwhen_DASH_13585840(when_DASH_325839,l2351978,name2371975,reserved_DASH_name7965,nothing4,tostring10);
}};
$e58295830.stack[R.EXN_STACKHEIGHT++] = $ss58335834;
}
if(R.isPyretException($e58295830)) {
$e58295830.pyretStack.push(L[722]);
}
throw $e58295830;
}
var $ret58355836 = $Hwhen_DASH_13585840($z58315832,l2351978,name2371975,reserved_DASH_name7965,nothing4,tostring10);
++R.GAS;
return $ret58355836;
};
var $Hwhen_DASH_13585840 = function(when_DASH_325839,l2351978,name2371975,reserved_DASH_name7965,nothing4,tostring10) {
var if_helper3375852 = R.makeFunction(function(if_helper_arg3385870) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[722],1,arguments);
}
if_helper_arg3385870;
var ann_DASH_check_DASH_temp3345871 = (true);
return ann_DASH_check_DASH_temp3345871;
});
var anf_if3415869 = R.isBoolean(when_DASH_325839);
if(R.isPyretTrue(anf_if3415869)) {
if(R.isPyretTrue(when_DASH_325839)) {
var $z58435844 = D;
var $f58495850 = function(_) {
return R.isFunction(tostring10)?tostring10.app(name2371975):R.ffi.throwNonFunApp(L[723],tostring10,[name2371975]);
};
try {
if(--R.GAS > 0) {
$z58435844 = $f58495850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58495850,
"from":L[723]});
}
} catch($e58415842) {
if(R.isCont($e58415842)) {
var $ss58455846 = {"from":L[723],
"go":function(anf_arg3435851) {
return $Hanf_arg13565853(anf_arg3435851,if_helper3375852,l2351978,reserved_DASH_name7965,nothing4);
}};
$e58415842.stack[R.EXN_STACKHEIGHT++] = $ss58455846;
}
if(R.isPyretException($e58415842)) {
$e58415842.pyretStack.push(L[723]);
}
throw $e58415842;
}
var $ret58475848 = $Hanf_arg13565853($z58435844,if_helper3375852,l2351978,reserved_DASH_name7965,nothing4);
++R.GAS;
return $ret58475848;
} else {
var $z58565857 = D;
var $f58625863 = function(_) {
return R.isFunction(if_helper3375852)?if_helper3375852.app(nothing4):R.ffi.throwNonFunApp(L[722],if_helper3375852,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z58565857 = $f58625863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58625863,
"from":L[722]});
}
} catch($e58545855) {
if(R.isCont($e58545855)) {
var $ss58585859 = {"from":L[722],
"go":function(cont_tail_app3425864) {
return $Hcont_tail_app13575865(cont_tail_app3425864);
}};
$e58545855.stack[R.EXN_STACKHEIGHT++] = $ss58585859;
}
if(R.isPyretException($e58545855)) {
$e58545855.pyretStack.push(L[722]);
}
throw $e58545855;
}
var $ret58605861 = $Hcont_tail_app13575865($z58565857);
++R.GAS;
return $ret58605861;
}
} else {
var cont_tail_arg3395868 = R.throwNonBooleanCondition(L[724],("when"),when_DASH_325839);
if(--R.GAS > 0) {
$z58665867 = R.isFunction(if_helper3375852)?if_helper3375852.app(cont_tail_arg3395868):R.ffi.throwNonFunApp(L[724],if_helper3375852,[cont_tail_arg3395868]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3375852)?if_helper3375852.app(cont_tail_arg3395868):R.ffi.throwNonFunApp(L[724],if_helper3375852,[cont_tail_arg3395868]);
},
"from":L[724]});
}
++R.GAS;
return $z58665867;
}
};
var $Hanf_arg13565853 = function(anf_arg3435851,if_helper3375852,l2351978,reserved_DASH_name7965,nothing4) {
var $z58745875 = D;
var $f58805881 = function(_) {
return R.isFunction(reserved_DASH_name7965.$var)?reserved_DASH_name7965.$var.app(l2351978,anf_arg3435851):R.ffi.throwNonFunApp(L[725],reserved_DASH_name7965.$var,[l2351978,anf_arg3435851]);
};
try {
if(--R.GAS > 0) {
$z58745875 = $f58805881();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58805881,
"from":L[725]});
}
} catch($e58725873) {
if(R.isCont($e58725873)) {
var $ss58765877 = {"from":L[725],
"go":function(anf_begin_app_dropped13535882) {
return $Hanf_begin_app_dropped13555883(anf_begin_app_dropped13535882,if_helper3375852,nothing4);
}};
$e58725873.stack[R.EXN_STACKHEIGHT++] = $ss58765877;
}
if(R.isPyretException($e58725873)) {
$e58725873.pyretStack.push(L[725]);
}
throw $e58725873;
}
var $ret58785879 = $Hanf_begin_app_dropped13555883($z58745875,if_helper3375852,nothing4);
++R.GAS;
return $ret58785879;
};
var $Hanf_begin_app_dropped13555883 = function(anf_begin_app_dropped13535882,if_helper3375852,nothing4) {
var $z58865887 = D;
var $f58925893 = function(_) {
return R.isFunction(if_helper3375852)?if_helper3375852.app(nothing4):R.ffi.throwNonFunApp(L[722],if_helper3375852,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z58865887 = $f58925893();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58925893,
"from":L[722]});
}
} catch($e58845885) {
if(R.isCont($e58845885)) {
var $ss58885889 = {"from":L[722],
"go":function(cont_tail_app3445894) {
return $Hcont_tail_app13545895(cont_tail_app3445894);
}};
$e58845885.stack[R.EXN_STACKHEIGHT++] = $ss58885889;
}
if(R.isPyretException($e58845885)) {
$e58845885.pyretStack.push(L[722]);
}
throw $e58845885;
}
var $ret58905891 = $Hcont_tail_app13545895($z58865887);
++R.GAS;
return $ret58905891;
};
var $Hcont_tail_app13545895 = function(cont_tail_app3445894) {
return cont_tail_app3445894;
};
var $Hcont_tail_app13575865 = function(cont_tail_app3425864) {
return cont_tail_app3425864;
};
var $Hif_DASH_13521997 = function(if_DASH_311994,A113,ensure_DASH_unique_DASH_bindings10075,l2301995,lists1118,self2291996,stmts2311993,wf_DASH_error7659,wf_DASH_last_DASH_stmt10279) {
var if_helper2985907 = R.makeFunction(function(if_helper_arg2995926) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[385],1,arguments);
}
var ann_DASH_check_DASH_temp2975927 = if_helper_arg2995926;
return ann_DASH_check_DASH_temp2975927;
});
var anf_if3025925 = R.isBoolean(if_DASH_311994);
if(R.isPyretTrue(anf_if3025925)) {
if(R.isPyretTrue(if_DASH_311994)) {
var $z58985899 = D;
var $f59045905 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(("Empty block"),l2301995):R.ffi.throwNonFunApp(L[726],wf_DASH_error7659.$var,[("Empty block"),l2301995]);
};
try {
if(--R.GAS > 0) {
$z58985899 = $f59045905();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59045905,
"from":L[726]});
}
} catch($e58965897) {
if(R.isCont($e58965897)) {
var $ss59005901 = {"from":L[726],
"go":function(anf_begin_app_dropped13355906) {
return $Hanf_begin_app_dropped13375908(anf_begin_app_dropped13355906,if_helper2985907);
}};
$e58965897.stack[R.EXN_STACKHEIGHT++] = $ss59005901;
}
if(R.isPyretException($e58965897)) {
$e58965897.pyretStack.push(L[726]);
}
throw $e58965897;
}
var $ret59025903 = $Hanf_begin_app_dropped13375908($z58985899,if_helper2985907);
++R.GAS;
return $ret59025903;
} else {
var anf_fun3035919 = G(stmts2311993,"last",L[728]);
var $z59115912 = D;
var $f59175918 = function(_) {
return R.isFunction(anf_fun3035919)?anf_fun3035919.app():R.ffi.throwNonFunApp(L[727],anf_fun3035919,[]);
};
try {
if(--R.GAS > 0) {
$z59115912 = $f59175918();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59175918,
"from":L[727]});
}
} catch($e59095910) {
if(R.isCont($e59095910)) {
var $ss59135914 = {"from":L[727],
"go":function(anf_arg3045920) {
return $Hanf_arg13515921(anf_arg3045920,A113,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993,wf_DASH_last_DASH_stmt10279);
}};
$e59095910.stack[R.EXN_STACKHEIGHT++] = $ss59135914;
}
if(R.isPyretException($e59095910)) {
$e59095910.pyretStack.push(L[727]);
}
throw $e59095910;
}
var $ret59155916 = $Hanf_arg13515921($z59115912,A113,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993,wf_DASH_last_DASH_stmt10279);
++R.GAS;
return $ret59155916;
}
} else {
var cont_tail_arg3005924 = R.throwNonBooleanCondition(L[385],("if"),if_DASH_311994);
if(--R.GAS > 0) {
$z59225923 = R.isFunction(if_helper2985907)?if_helper2985907.app(cont_tail_arg3005924):R.ffi.throwNonFunApp(L[385],if_helper2985907,[cont_tail_arg3005924]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2985907)?if_helper2985907.app(cont_tail_arg3005924):R.ffi.throwNonFunApp(L[385],if_helper2985907,[cont_tail_arg3005924]);
},
"from":L[385]});
}
++R.GAS;
return $z59225923;
}
};
var $Hanf_begin_app_dropped13375908 = function(anf_begin_app_dropped13355906,if_helper2985907) {
var $z59305931 = D;
var $f59365937 = function(_) {
return R.isFunction(if_helper2985907)?if_helper2985907.app((true)):R.ffi.throwNonFunApp(L[729],if_helper2985907,[(true)]);
};
try {
if(--R.GAS > 0) {
$z59305931 = $f59365937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59365937,
"from":L[729]});
}
} catch($e59285929) {
if(R.isCont($e59285929)) {
var $ss59325933 = {"from":L[729],
"go":function(cont_tail_app3325938) {
return $Hcont_tail_app13365939(cont_tail_app3325938);
}};
$e59285929.stack[R.EXN_STACKHEIGHT++] = $ss59325933;
}
if(R.isPyretException($e59285929)) {
$e59285929.pyretStack.push(L[729]);
}
throw $e59285929;
}
var $ret59345935 = $Hcont_tail_app13365939($z59305931);
++R.GAS;
return $ret59345935;
};
var $Hcont_tail_app13365939 = function(cont_tail_app3325938) {
return cont_tail_app3325938;
};
var $Hanf_arg13515921 = function(anf_arg3045920,A113,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993,wf_DASH_last_DASH_stmt10279) {
var $z59425943 = D;
var $f59485949 = function(_) {
return R.isFunction(wf_DASH_last_DASH_stmt10279.$var)?wf_DASH_last_DASH_stmt10279.$var.app(anf_arg3045920):R.ffi.throwNonFunApp(L[730],wf_DASH_last_DASH_stmt10279.$var,[anf_arg3045920]);
};
try {
if(--R.GAS > 0) {
$z59425943 = $f59485949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59485949,
"from":L[730]});
}
} catch($e59405941) {
if(R.isCont($e59405941)) {
var $ss59445945 = {"from":L[730],
"go":function(anf_begin_app_dropped13385950) {
return $Hanf_begin_app_dropped13505951(anf_begin_app_dropped13385950,A113,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993);
}};
$e59405941.stack[R.EXN_STACKHEIGHT++] = $ss59445945;
}
if(R.isPyretException($e59405941)) {
$e59405941.pyretStack.push(L[730]);
}
throw $e59405941;
}
var $ret59465947 = $Hanf_begin_app_dropped13505951($z59425943,A113,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993);
++R.GAS;
return $ret59465947;
};
var $Hanf_begin_app_dropped13505951 = function(anf_begin_app_dropped13385950,A113,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993) {
var anf_fun3055962 = G(stmts2311993,"filter",L[735]);
var anf_arg3195963 = R.makeFunction(function(s2335966) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[732],1,arguments);
}
var anf_fun3075977 = G(A113,"is-s-var",L[734]);
var $z59695970 = D;
var $f59755976 = function(_) {
return R.isFunction(anf_fun3075977)?anf_fun3075977.app(s2335966):R.ffi.throwNonFunApp(L[733],anf_fun3075977,[s2335966]);
};
try {
if(--R.GAS > 0) {
$z59695970 = $f59755976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59755976,
"from":L[733]});
}
} catch($e59675968) {
if(R.isCont($e59675968)) {
var $ss59715972 = {"from":L[733],
"go":function(or_DASH_oper_DASH_285978) {
return $Hor_DASH_oper_DASH_13425979(or_DASH_oper_DASH_285978,A113,s2335966);
}};
$e59675968.stack[R.EXN_STACKHEIGHT++] = $ss59715972;
}
if(R.isPyretException($e59675968)) {
$e59675968.pyretStack.push(L[733]);
}
throw $e59675968;
}
var $ret59735974 = $Hor_DASH_oper_DASH_13425979($z59695970,A113,s2335966);
++R.GAS;
return $ret59735974;
});
var $z59545955 = D;
var $f59605961 = function(_) {
return R.isFunction(anf_fun3055962)?anf_fun3055962.app(anf_arg3195963):R.ffi.throwNonFunApp(L[731],anf_fun3055962,[anf_arg3195963]);
};
try {
if(--R.GAS > 0) {
$z59545955 = $f59605961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59605961,
"from":L[731]});
}
} catch($e59525953) {
if(R.isCont($e59525953)) {
var $ss59565957 = {"from":L[731],
"go":function(anf_bracket3205964) {
return $Hanf_bracket13495965(anf_bracket3205964,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993);
}};
$e59525953.stack[R.EXN_STACKHEIGHT++] = $ss59565957;
}
if(R.isPyretException($e59525953)) {
$e59525953.pyretStack.push(L[731]);
}
throw $e59525953;
}
var $ret59585959 = $Hanf_bracket13495965($z59545955,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993);
++R.GAS;
return $ret59585959;
};
var $Hanf_bracket13495965 = function(anf_bracket3205964,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993) {
var anf_fun3215990 = G(anf_bracket3205964,"map",L[738]);
var anf_arg3235991 = R.makeFunction(function(recv_DASH_275994) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[737],1,arguments);
}
var ann_DASH_check_DASH_temp3225995 = G(recv_DASH_275994,"name",L[737]);
return ann_DASH_check_DASH_temp3225995;
});
var $z59825983 = D;
var $f59885989 = function(_) {
return R.isFunction(anf_fun3215990)?anf_fun3215990.app(anf_arg3235991):R.ffi.throwNonFunApp(L[736],anf_fun3215990,[anf_arg3235991]);
};
try {
if(--R.GAS > 0) {
$z59825983 = $f59885989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59885989,
"from":L[736]});
}
} catch($e59805981) {
if(R.isCont($e59805981)) {
var $ss59845985 = {"from":L[736],
"go":function(bind_DASH_stmts2325992) {
return $Hbind_DASH_stmts13485993(bind_DASH_stmts2325992,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993);
}};
$e59805981.stack[R.EXN_STACKHEIGHT++] = $ss59845985;
}
if(R.isPyretException($e59805981)) {
$e59805981.pyretStack.push(L[736]);
}
throw $e59805981;
}
var $ret59865987 = $Hbind_DASH_stmts13485993($z59825983,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993);
++R.GAS;
return $ret59865987;
};
var $Hbind_DASH_stmts13485993 = function(bind_DASH_stmts2325992,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993) {
var anf_fun3246006 = G(bind_DASH_stmts2325992,"reverse",L[740]);
var $z59985999 = D;
var $f60046005 = function(_) {
return R.isFunction(anf_fun3246006)?anf_fun3246006.app():R.ffi.throwNonFunApp(L[739],anf_fun3246006,[]);
};
try {
if(--R.GAS > 0) {
$z59985999 = $f60046005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60046005,
"from":L[739]});
}
} catch($e59965997) {
if(R.isCont($e59965997)) {
var $ss60006001 = {"from":L[739],
"go":function(anf_arg3256007) {
return $Hanf_arg13476008(anf_arg3256007,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993);
}};
$e59965997.stack[R.EXN_STACKHEIGHT++] = $ss60006001;
}
if(R.isPyretException($e59965997)) {
$e59965997.pyretStack.push(L[739]);
}
throw $e59965997;
}
var $ret60026003 = $Hanf_arg13476008($z59985999,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993);
++R.GAS;
return $ret60026003;
};
var $Hanf_arg13476008 = function(anf_arg3256007,ensure_DASH_unique_DASH_bindings10075,if_helper2985907,lists1118,self2291996,stmts2311993) {
var $z60116012 = D;
var $f60176018 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_bindings10075.$var)?ensure_DASH_unique_DASH_bindings10075.$var.app(anf_arg3256007):R.ffi.throwNonFunApp(L[741],ensure_DASH_unique_DASH_bindings10075.$var,[anf_arg3256007]);
};
try {
if(--R.GAS > 0) {
$z60116012 = $f60176018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60176018,
"from":L[741]});
}
} catch($e60096010) {
if(R.isCont($e60096010)) {
var $ss60136014 = {"from":L[741],
"go":function(anf_begin_app_dropped13436019) {
return $Hanf_begin_app_dropped13466020(anf_begin_app_dropped13436019,if_helper2985907,lists1118,self2291996,stmts2311993);
}};
$e60096010.stack[R.EXN_STACKHEIGHT++] = $ss60136014;
}
if(R.isPyretException($e60096010)) {
$e60096010.pyretStack.push(L[741]);
}
throw $e60096010;
}
var $ret60156016 = $Hanf_begin_app_dropped13466020($z60116012,if_helper2985907,lists1118,self2291996,stmts2311993);
++R.GAS;
return $ret60156016;
};
var $Hanf_begin_app_dropped13466020 = function(anf_begin_app_dropped13436019,if_helper2985907,lists1118,self2291996,stmts2311993) {
var anf_fun3266031 = G(lists1118,"all",L[744]);
var anf_arg3296032 = R.makeFunction(function(recv_DASH_306035) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[743],1,arguments);
}
var anf_fun3286046 = G(recv_DASH_306035,"visit",L[743]);
var $z60386039 = D;
var $f60446045 = function(_) {
return R.isFunction(anf_fun3286046)?anf_fun3286046.app(self2291996):R.ffi.throwNonFunApp(L[743],anf_fun3286046,[self2291996]);
};
try {
if(--R.GAS > 0) {
$z60386039 = $f60446045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60446045,
"from":L[743]});
}
} catch($e60366037) {
if(R.isCont($e60366037)) {
var $ss60406041 = {"from":L[743],
"go":function(ann_DASH_check_DASH_temp3276047) {
return $Hann_DASH_check_DASH_temp13446048(ann_DASH_check_DASH_temp3276047);
}};
$e60366037.stack[R.EXN_STACKHEIGHT++] = $ss60406041;
}
if(R.isPyretException($e60366037)) {
$e60366037.pyretStack.push(L[743]);
}
throw $e60366037;
}
var $ret60426043 = $Hann_DASH_check_DASH_temp13446048($z60386039);
++R.GAS;
return $ret60426043;
});
var $z60236024 = D;
var $f60296030 = function(_) {
return R.isFunction(anf_fun3266031)?anf_fun3266031.app(anf_arg3296032,stmts2311993):R.ffi.throwNonFunApp(L[742],anf_fun3266031,[anf_arg3296032,stmts2311993]);
};
try {
if(--R.GAS > 0) {
$z60236024 = $f60296030();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60296030,
"from":L[742]});
}
} catch($e60216022) {
if(R.isCont($e60216022)) {
var $ss60256026 = {"from":L[742],
"go":function(cont_tail_arg3306033) {
return $Hcont_tail_arg13456034(cont_tail_arg3306033,if_helper2985907);
}};
$e60216022.stack[R.EXN_STACKHEIGHT++] = $ss60256026;
}
if(R.isPyretException($e60216022)) {
$e60216022.pyretStack.push(L[742]);
}
throw $e60216022;
}
var $ret60276028 = $Hcont_tail_arg13456034($z60236024,if_helper2985907);
++R.GAS;
return $ret60276028;
};
var $Hcont_tail_arg13456034 = function(cont_tail_arg3306033,if_helper2985907) {
if(--R.GAS > 0) {
$z60496050 = R.isFunction(if_helper2985907)?if_helper2985907.app(cont_tail_arg3306033):R.ffi.throwNonFunApp(L[742],if_helper2985907,[cont_tail_arg3306033]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2985907)?if_helper2985907.app(cont_tail_arg3306033):R.ffi.throwNonFunApp(L[742],if_helper2985907,[cont_tail_arg3306033]);
},
"from":L[742]});
}
++R.GAS;
return $z60496050;
};
var $Hann_DASH_check_DASH_temp13446048 = function(ann_DASH_check_DASH_temp3276047) {
return ann_DASH_check_DASH_temp3276047;
};
var $Hor_DASH_oper_DASH_13425979 = function(or_DASH_oper_DASH_285978,A113,s2335966) {
var if_helper3086061 = R.makeFunction(function(if_helper_arg3096081) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[733],1,arguments);
}
var ann_DASH_check_DASH_temp3066082 = if_helper_arg3096081;
return ann_DASH_check_DASH_temp3066082;
});
var anf_if3126080 = R.isBoolean(or_DASH_oper_DASH_285978);
if(R.isPyretTrue(anf_if3126080)) {
if(R.isPyretTrue(or_DASH_oper_DASH_285978)) {
var $z60536054 = D;
var $f60596060 = function(_) {
return R.isFunction(if_helper3086061)?if_helper3086061.app((true)):R.ffi.throwNonFunApp(L[733],if_helper3086061,[(true)]);
};
try {
if(--R.GAS > 0) {
$z60536054 = $f60596060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60596060,
"from":L[733]});
}
} catch($e60516052) {
if(R.isCont($e60516052)) {
var $ss60556056 = {"from":L[733],
"go":function(cont_tail_app3186062) {
return $Hcont_tail_app13396063(cont_tail_app3186062);
}};
$e60516052.stack[R.EXN_STACKHEIGHT++] = $ss60556056;
}
if(R.isPyretException($e60516052)) {
$e60516052.pyretStack.push(L[733]);
}
throw $e60516052;
}
var $ret60576058 = $Hcont_tail_app13396063($z60536054);
++R.GAS;
return $ret60576058;
} else {
var anf_fun3136074 = G(A113,"is-s-let",L[745]);
var $z60666067 = D;
var $f60726073 = function(_) {
return R.isFunction(anf_fun3136074)?anf_fun3136074.app(s2335966):R.ffi.throwNonFunApp(L[733],anf_fun3136074,[s2335966]);
};
try {
if(--R.GAS > 0) {
$z60666067 = $f60726073();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60726073,
"from":L[733]});
}
} catch($e60646065) {
if(R.isCont($e60646065)) {
var $ss60686069 = {"from":L[733],
"go":function(or_DASH_oper_DASH_296075) {
return $Hor_DASH_oper_DASH_13416076(or_DASH_oper_DASH_296075,if_helper3086061);
}};
$e60646065.stack[R.EXN_STACKHEIGHT++] = $ss60686069;
}
if(R.isPyretException($e60646065)) {
$e60646065.pyretStack.push(L[733]);
}
throw $e60646065;
}
var $ret60706071 = $Hor_DASH_oper_DASH_13416076($z60666067,if_helper3086061);
++R.GAS;
return $ret60706071;
}
} else {
var cont_tail_arg3106079 = R.throwNonBooleanOp(L[746],("first"),("or"),or_DASH_oper_DASH_285978);
if(--R.GAS > 0) {
$z60776078 = R.isFunction(if_helper3086061)?if_helper3086061.app(cont_tail_arg3106079):R.ffi.throwNonFunApp(L[746],if_helper3086061,[cont_tail_arg3106079]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3086061)?if_helper3086061.app(cont_tail_arg3106079):R.ffi.throwNonFunApp(L[746],if_helper3086061,[cont_tail_arg3106079]);
},
"from":L[746]});
}
++R.GAS;
return $z60776078;
}
};
var $Hcont_tail_app13396063 = function(cont_tail_app3186062) {
return cont_tail_app3186062;
};
var $Hor_DASH_oper_DASH_13416076 = function(or_DASH_oper_DASH_296075,if_helper3086061) {
var anf_if3166098 = R.isBoolean(or_DASH_oper_DASH_296075);
if(R.isPyretTrue(anf_if3166098)) {
var $z60856086 = D;
var $f60916092 = function(_) {
return R.isFunction(if_helper3086061)?if_helper3086061.app(or_DASH_oper_DASH_296075):R.ffi.throwNonFunApp(L[733],if_helper3086061,[or_DASH_oper_DASH_296075]);
};
try {
if(--R.GAS > 0) {
$z60856086 = $f60916092();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60916092,
"from":L[733]});
}
} catch($e60836084) {
if(R.isCont($e60836084)) {
var $ss60876088 = {"from":L[733],
"go":function(cont_tail_app3176093) {
return $Hcont_tail_app13406094(cont_tail_app3176093);
}};
$e60836084.stack[R.EXN_STACKHEIGHT++] = $ss60876088;
}
if(R.isPyretException($e60836084)) {
$e60836084.pyretStack.push(L[733]);
}
throw $e60836084;
}
var $ret60896090 = $Hcont_tail_app13406094($z60856086);
++R.GAS;
return $ret60896090;
} else {
var cont_tail_arg3146097 = R.throwNonBooleanOp(L[747],("second"),("or"),or_DASH_oper_DASH_296075);
if(--R.GAS > 0) {
$z60956096 = R.isFunction(if_helper3086061)?if_helper3086061.app(cont_tail_arg3146097):R.ffi.throwNonFunApp(L[747],if_helper3086061,[cont_tail_arg3146097]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper3086061)?if_helper3086061.app(cont_tail_arg3146097):R.ffi.throwNonFunApp(L[747],if_helper3086061,[cont_tail_arg3146097]);
},
"from":L[747]});
}
++R.GAS;
return $z60956096;
}
};
var $Hcont_tail_app13406094 = function(cont_tail_app3176093) {
return cont_tail_app3176093;
};
var $Hanf_begin_app_dropped13332011 = function(anf_begin_app_dropped13312009,if_helper2742010,nothing4) {
var $z61016102 = D;
var $f61076108 = function(_) {
return R.isFunction(if_helper2742010)?if_helper2742010.app(nothing4):R.ffi.throwNonFunApp(L[388],if_helper2742010,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z61016102 = $f61076108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61076108,
"from":L[388]});
}
} catch($e60996100) {
if(R.isCont($e60996100)) {
var $ss61036104 = {"from":L[388],
"go":function(cont_tail_app2956109) {
return $Hcont_tail_app13326110(cont_tail_app2956109);
}};
$e60996100.stack[R.EXN_STACKHEIGHT++] = $ss61036104;
}
if(R.isPyretException($e60996100)) {
$e60996100.pyretStack.push(L[388]);
}
throw $e60996100;
}
var $ret61056106 = $Hcont_tail_app13326110($z61016102);
++R.GAS;
return $ret61056106;
};
var $Hcont_tail_app13326110 = function(cont_tail_app2956109) {
return cont_tail_app2956109;
};
var $Hcont_tail_app13342023 = function(cont_tail_app2942022) {
return cont_tail_app2942022;
};
var $Hanf_begin_app_dropped13302044 = function(anf_begin_app_dropped13242041,args2272040,body2282042,lists1118,self2242043) {
var anf_fun2766121 = G(lists1118,"all",L[750]);
var anf_arg2796122 = R.makeFunction(function(recv_DASH_256125) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[749],1,arguments);
}
var anf_fun2786136 = G(recv_DASH_256125,"visit",L[749]);
var $z61286129 = D;
var $f61346135 = function(_) {
return R.isFunction(anf_fun2786136)?anf_fun2786136.app(self2242043):R.ffi.throwNonFunApp(L[749],anf_fun2786136,[self2242043]);
};
try {
if(--R.GAS > 0) {
$z61286129 = $f61346135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61346135,
"from":L[749]});
}
} catch($e61266127) {
if(R.isCont($e61266127)) {
var $ss61306131 = {"from":L[749],
"go":function(ann_DASH_check_DASH_temp2776137) {
return $Hann_DASH_check_DASH_temp13256138(ann_DASH_check_DASH_temp2776137);
}};
$e61266127.stack[R.EXN_STACKHEIGHT++] = $ss61306131;
}
if(R.isPyretException($e61266127)) {
$e61266127.pyretStack.push(L[749]);
}
throw $e61266127;
}
var $ret61326133 = $Hann_DASH_check_DASH_temp13256138($z61286129);
++R.GAS;
return $ret61326133;
});
var $z61136114 = D;
var $f61196120 = function(_) {
return R.isFunction(anf_fun2766121)?anf_fun2766121.app(anf_arg2796122,args2272040):R.ffi.throwNonFunApp(L[748],anf_fun2766121,[anf_arg2796122,args2272040]);
};
try {
if(--R.GAS > 0) {
$z61136114 = $f61196120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61196120,
"from":L[748]});
}
} catch($e61116112) {
if(R.isCont($e61116112)) {
var $ss61156116 = {"from":L[748],
"go":function(and_DASH_oper_DASH_246123) {
return $Hand_DASH_oper_DASH_13296124(and_DASH_oper_DASH_246123,body2282042,self2242043);
}};
$e61116112.stack[R.EXN_STACKHEIGHT++] = $ss61156116;
}
if(R.isPyretException($e61116112)) {
$e61116112.pyretStack.push(L[748]);
}
throw $e61116112;
}
var $ret61176118 = $Hand_DASH_oper_DASH_13296124($z61136114,body2282042,self2242043);
++R.GAS;
return $ret61176118;
};
var $Hand_DASH_oper_DASH_13296124 = function(and_DASH_oper_DASH_246123,body2282042,self2242043) {
var if_helper2806151 = R.makeFunction(function(if_helper_arg2816169) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[748],1,arguments);
}
var ann_DASH_check_DASH_temp2736170 = if_helper_arg2816169;
return ann_DASH_check_DASH_temp2736170;
});
var anf_if2846168 = R.isBoolean(and_DASH_oper_DASH_246123);
if(R.isPyretTrue(anf_if2846168)) {
if(R.isPyretTrue(and_DASH_oper_DASH_246123)) {
var anf_fun2866149 = G(body2282042,"visit",L[751]);
var $z61416142 = D;
var $f61476148 = function(_) {
return R.isFunction(anf_fun2866149)?anf_fun2866149.app(self2242043):R.ffi.throwNonFunApp(L[748],anf_fun2866149,[self2242043]);
};
try {
if(--R.GAS > 0) {
$z61416142 = $f61476148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61476148,
"from":L[748]});
}
} catch($e61396140) {
if(R.isCont($e61396140)) {
var $ss61436144 = {"from":L[748],
"go":function(and_DASH_oper_DASH_266150) {
return $Hand_DASH_oper_DASH_13276152(and_DASH_oper_DASH_266150,if_helper2806151);
}};
$e61396140.stack[R.EXN_STACKHEIGHT++] = $ss61436144;
}
if(R.isPyretException($e61396140)) {
$e61396140.pyretStack.push(L[748]);
}
throw $e61396140;
}
var $ret61456146 = $Hand_DASH_oper_DASH_13276152($z61416142,if_helper2806151);
++R.GAS;
return $ret61456146;
} else {
var $z61556156 = D;
var $f61616162 = function(_) {
return R.isFunction(if_helper2806151)?if_helper2806151.app((false)):R.ffi.throwNonFunApp(L[748],if_helper2806151,[(false)]);
};
try {
if(--R.GAS > 0) {
$z61556156 = $f61616162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61616162,
"from":L[748]});
}
} catch($e61536154) {
if(R.isCont($e61536154)) {
var $ss61576158 = {"from":L[748],
"go":function(cont_tail_app2856163) {
return $Hcont_tail_app13286164(cont_tail_app2856163);
}};
$e61536154.stack[R.EXN_STACKHEIGHT++] = $ss61576158;
}
if(R.isPyretException($e61536154)) {
$e61536154.pyretStack.push(L[748]);
}
throw $e61536154;
}
var $ret61596160 = $Hcont_tail_app13286164($z61556156);
++R.GAS;
return $ret61596160;
}
} else {
var cont_tail_arg2826167 = R.throwNonBooleanOp(L[752],("first"),("and"),and_DASH_oper_DASH_246123);
if(--R.GAS > 0) {
$z61656166 = R.isFunction(if_helper2806151)?if_helper2806151.app(cont_tail_arg2826167):R.ffi.throwNonFunApp(L[752],if_helper2806151,[cont_tail_arg2826167]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2806151)?if_helper2806151.app(cont_tail_arg2826167):R.ffi.throwNonFunApp(L[752],if_helper2806151,[cont_tail_arg2826167]);
},
"from":L[752]});
}
++R.GAS;
return $z61656166;
}
};
var $Hand_DASH_oper_DASH_13276152 = function(and_DASH_oper_DASH_266150,if_helper2806151) {
var anf_if2896186 = R.isBoolean(and_DASH_oper_DASH_266150);
if(R.isPyretTrue(anf_if2896186)) {
var $z61736174 = D;
var $f61796180 = function(_) {
return R.isFunction(if_helper2806151)?if_helper2806151.app(and_DASH_oper_DASH_266150):R.ffi.throwNonFunApp(L[748],if_helper2806151,[and_DASH_oper_DASH_266150]);
};
try {
if(--R.GAS > 0) {
$z61736174 = $f61796180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61796180,
"from":L[748]});
}
} catch($e61716172) {
if(R.isCont($e61716172)) {
var $ss61756176 = {"from":L[748],
"go":function(cont_tail_app2906181) {
return $Hcont_tail_app13266182(cont_tail_app2906181);
}};
$e61716172.stack[R.EXN_STACKHEIGHT++] = $ss61756176;
}
if(R.isPyretException($e61716172)) {
$e61716172.pyretStack.push(L[748]);
}
throw $e61716172;
}
var $ret61776178 = $Hcont_tail_app13266182($z61736174);
++R.GAS;
return $ret61776178;
} else {
var cont_tail_arg2876185 = R.throwNonBooleanOp(L[753],("second"),("and"),and_DASH_oper_DASH_266150);
if(--R.GAS > 0) {
$z61836184 = R.isFunction(if_helper2806151)?if_helper2806151.app(cont_tail_arg2876185):R.ffi.throwNonFunApp(L[753],if_helper2806151,[cont_tail_arg2876185]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2806151)?if_helper2806151.app(cont_tail_arg2876185):R.ffi.throwNonFunApp(L[753],if_helper2806151,[cont_tail_arg2876185]);
},
"from":L[753]});
}
++R.GAS;
return $z61836184;
}
};
var $Hcont_tail_app13266182 = function(cont_tail_app2906181) {
return cont_tail_app2906181;
};
var $Hcont_tail_app13286164 = function(cont_tail_app2856163) {
return cont_tail_app2856163;
};
var $Hann_DASH_check_DASH_temp13256138 = function(ann_DASH_check_DASH_temp2776137) {
return ann_DASH_check_DASH_temp2776137;
};
var $Hand_DASH_oper_DASH_13232062 = function(and_DASH_oper_DASH_212060,l2202057,op2212058,reachable_DASH_ops10585,right2232061,self2192056) {
var if_helper2626198 = R.makeFunction(function(if_helper_arg2636216) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[392],1,arguments);
}
var ann_DASH_check_DASH_temp2616217 = if_helper_arg2636216;
return ann_DASH_check_DASH_temp2616217;
});
var anf_if2666215 = R.isBoolean(and_DASH_oper_DASH_212060);
if(R.isPyretTrue(anf_if2666215)) {
if(R.isPyretTrue(and_DASH_oper_DASH_212060)) {
var $z61896190 = D;
var $f61956196 = function(_) {
return R.isFunction(reachable_DASH_ops10585.$var)?reachable_DASH_ops10585.$var.app(self2192056,l2202057,op2212058,right2232061):R.ffi.throwNonFunApp(L[392],reachable_DASH_ops10585.$var,[self2192056,l2202057,op2212058,right2232061]);
};
try {
if(--R.GAS > 0) {
$z61896190 = $f61956196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61956196,
"from":L[392]});
}
} catch($e61876188) {
if(R.isCont($e61876188)) {
var $ss61916192 = {"from":L[392],
"go":function(and_DASH_oper_DASH_226197) {
return $Hand_DASH_oper_DASH_13216199(and_DASH_oper_DASH_226197,if_helper2626198);
}};
$e61876188.stack[R.EXN_STACKHEIGHT++] = $ss61916192;
}
if(R.isPyretException($e61876188)) {
$e61876188.pyretStack.push(L[392]);
}
throw $e61876188;
}
var $ret61936194 = $Hand_DASH_oper_DASH_13216199($z61896190,if_helper2626198);
++R.GAS;
return $ret61936194;
} else {
var $z62026203 = D;
var $f62086209 = function(_) {
return R.isFunction(if_helper2626198)?if_helper2626198.app((false)):R.ffi.throwNonFunApp(L[392],if_helper2626198,[(false)]);
};
try {
if(--R.GAS > 0) {
$z62026203 = $f62086209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62086209,
"from":L[392]});
}
} catch($e62006201) {
if(R.isCont($e62006201)) {
var $ss62046205 = {"from":L[392],
"go":function(cont_tail_app2676210) {
return $Hcont_tail_app13226211(cont_tail_app2676210);
}};
$e62006201.stack[R.EXN_STACKHEIGHT++] = $ss62046205;
}
if(R.isPyretException($e62006201)) {
$e62006201.pyretStack.push(L[392]);
}
throw $e62006201;
}
var $ret62066207 = $Hcont_tail_app13226211($z62026203);
++R.GAS;
return $ret62066207;
}
} else {
var cont_tail_arg2646214 = R.throwNonBooleanOp(L[754],("first"),("and"),and_DASH_oper_DASH_212060);
if(--R.GAS > 0) {
$z62126213 = R.isFunction(if_helper2626198)?if_helper2626198.app(cont_tail_arg2646214):R.ffi.throwNonFunApp(L[754],if_helper2626198,[cont_tail_arg2646214]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2626198)?if_helper2626198.app(cont_tail_arg2646214):R.ffi.throwNonFunApp(L[754],if_helper2626198,[cont_tail_arg2646214]);
},
"from":L[754]});
}
++R.GAS;
return $z62126213;
}
};
var $Hand_DASH_oper_DASH_13216199 = function(and_DASH_oper_DASH_226197,if_helper2626198) {
var anf_if2706233 = R.isBoolean(and_DASH_oper_DASH_226197);
if(R.isPyretTrue(anf_if2706233)) {
var $z62206221 = D;
var $f62266227 = function(_) {
return R.isFunction(if_helper2626198)?if_helper2626198.app(and_DASH_oper_DASH_226197):R.ffi.throwNonFunApp(L[392],if_helper2626198,[and_DASH_oper_DASH_226197]);
};
try {
if(--R.GAS > 0) {
$z62206221 = $f62266227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62266227,
"from":L[392]});
}
} catch($e62186219) {
if(R.isCont($e62186219)) {
var $ss62226223 = {"from":L[392],
"go":function(cont_tail_app2716228) {
return $Hcont_tail_app13206229(cont_tail_app2716228);
}};
$e62186219.stack[R.EXN_STACKHEIGHT++] = $ss62226223;
}
if(R.isPyretException($e62186219)) {
$e62186219.pyretStack.push(L[392]);
}
throw $e62186219;
}
var $ret62246225 = $Hcont_tail_app13206229($z62206221);
++R.GAS;
return $ret62246225;
} else {
var cont_tail_arg2686232 = R.throwNonBooleanOp(L[755],("second"),("and"),and_DASH_oper_DASH_226197);
if(--R.GAS > 0) {
$z62306231 = R.isFunction(if_helper2626198)?if_helper2626198.app(cont_tail_arg2686232):R.ffi.throwNonFunApp(L[755],if_helper2626198,[cont_tail_arg2686232]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2626198)?if_helper2626198.app(cont_tail_arg2686232):R.ffi.throwNonFunApp(L[755],if_helper2626198,[cont_tail_arg2686232]);
},
"from":L[755]});
}
++R.GAS;
return $z62306231;
}
};
var $Hcont_tail_app13206229 = function(cont_tail_app2716228) {
return cont_tail_app2716228;
};
var $Hcont_tail_app13226211 = function(cont_tail_app2676210) {
return cont_tail_app2676210;
};
var $Hanf_begin_app_dropped13192075 = function(anf_begin_app_dropped13182074) {
var ann_DASH_check_DASH_temp2596234 = (false);
return ann_DASH_check_DASH_temp2596234;
};
var $Hanf_begin_app_dropped13172091 = function(anf_begin_app_dropped13162090) {
var ann_DASH_check_DASH_temp2576235 = (false);
return ann_DASH_check_DASH_temp2576235;
};
var $Hanf_begin_app_dropped13152107 = function(anf_begin_app_dropped13142106) {
var ann_DASH_check_DASH_temp2556236 = (false);
return ann_DASH_check_DASH_temp2556236;
};
var $Hanf_begin_app_dropped13132123 = function(anf_begin_app_dropped13122122) {
var ann_DASH_check_DASH_temp2536237 = (false);
return ann_DASH_check_DASH_temp2536237;
};
var $Hanf_begin_app_dropped13112144 = function(anf_begin_app_dropped13102143) {
var ann_DASH_check_DASH_temp2516238 = (false);
return ann_DASH_check_DASH_temp2516238;
};
var $Hann_DASH_check_DASH_temp13092163 = function(ann_DASH_check_DASH_temp2492162) {
return ann_DASH_check_DASH_temp2492162;
};
var $Hann_DASH_check_DASH_temp13082188 = function(ann_DASH_check_DASH_temp2242187) {
return ann_DASH_check_DASH_temp2242187;
};
var $Hann_DASH_check_DASH_temp13072201 = function(ann_DASH_check_DASH_temp2442200) {
return ann_DASH_check_DASH_temp2442200;
};
var $Hanf_begin_app_dropped12992219 = function(anf_begin_app_dropped12972217,if_helper2272218,l1762171,op1772172,reachable_DASH_ops10585,right21822206,self1752170) {
var $z62416242 = D;
var $f62476248 = function(_) {
return R.isFunction(reachable_DASH_ops10585.$var)?reachable_DASH_ops10585.$var.app(self1752170,l1762171,op1772172,right21822206):R.ffi.throwNonFunApp(L[756],reachable_DASH_ops10585.$var,[self1752170,l1762171,op1772172,right21822206]);
};
try {
if(--R.GAS > 0) {
$z62416242 = $f62476248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62476248,
"from":L[756]});
}
} catch($e62396240) {
if(R.isCont($e62396240)) {
var $ss62436244 = {"from":L[756],
"go":function(cont_tail_arg2406249) {
return $Hcont_tail_arg12986250(cont_tail_arg2406249,if_helper2272218);
}};
$e62396240.stack[R.EXN_STACKHEIGHT++] = $ss62436244;
}
if(R.isPyretException($e62396240)) {
$e62396240.pyretStack.push(L[756]);
}
throw $e62396240;
}
var $ret62456246 = $Hcont_tail_arg12986250($z62416242,if_helper2272218);
++R.GAS;
return $ret62456246;
};
var $Hcont_tail_arg12986250 = function(cont_tail_arg2406249,if_helper2272218) {
if(--R.GAS > 0) {
$z62516252 = R.isFunction(if_helper2272218)?if_helper2272218.app(cont_tail_arg2406249):R.ffi.throwNonFunApp(L[756],if_helper2272218,[cont_tail_arg2406249]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2272218)?if_helper2272218.app(cont_tail_arg2406249):R.ffi.throwNonFunApp(L[756],if_helper2272218,[cont_tail_arg2406249]);
},
"from":L[756]});
}
++R.GAS;
return $z62516252;
};
var $Hanf_arg13062231 = function(anf_arg2322230,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1) {
var $z62556256 = D;
var $f62616262 = function(_) {
return R.isFunction(_plus1)?_plus1.app(("Cannot mix binary operators of different types: `"),anf_arg2322230):R.ffi.throwNonFunApp(L[757],_plus1,[("Cannot mix binary operators of different types: `"),anf_arg2322230]);
};
try {
if(--R.GAS > 0) {
$z62556256 = $f62616262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62616262,
"from":L[757]});
}
} catch($e62536254) {
if(R.isCont($e62536254)) {
var $ss62576258 = {"from":L[757],
"go":function(anf_arg2336263) {
return $Hanf_arg13056264(anf_arg2336263,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1);
}};
$e62536254.stack[R.EXN_STACKHEIGHT++] = $ss62576258;
}
if(R.isPyretException($e62536254)) {
$e62536254.pyretStack.push(L[757]);
}
throw $e62536254;
}
var $ret62596260 = $Hanf_arg13056264($z62556256,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret62596260;
};
var $Hanf_arg13056264 = function(anf_arg2336263,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1) {
var $z62676268 = D;
var $f62736274 = function(_) {
return R.isFunction(_plus1)?_plus1.app(anf_arg2336263,("` and `")):R.ffi.throwNonFunApp(L[757],_plus1,[anf_arg2336263,("` and `")]);
};
try {
if(--R.GAS > 0) {
$z62676268 = $f62736274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62736274,
"from":L[757]});
}
} catch($e62656266) {
if(R.isCont($e62656266)) {
var $ss62696270 = {"from":L[757],
"go":function(anf_arg2346275) {
return $Hanf_arg13046276(anf_arg2346275,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1);
}};
$e62656266.stack[R.EXN_STACKHEIGHT++] = $ss62696270;
}
if(R.isPyretException($e62656266)) {
$e62656266.pyretStack.push(L[757]);
}
throw $e62656266;
}
var $ret62716272 = $Hanf_arg13046276($z62676268,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret62716272;
};
var $Hanf_arg13046276 = function(anf_arg2346275,if_helper2272218,l1762171,l21792203,op21802204,opname10483,wf_DASH_error27761,_plus1) {
var $z62796280 = D;
var $f62856286 = function(_) {
return R.isFunction(opname10483.$var)?opname10483.$var.app(op21802204):R.ffi.throwNonFunApp(L[758],opname10483.$var,[op21802204]);
};
try {
if(--R.GAS > 0) {
$z62796280 = $f62856286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62856286,
"from":L[758]});
}
} catch($e62776278) {
if(R.isCont($e62776278)) {
var $ss62816282 = {"from":L[758],
"go":function(anf_arg2356287) {
return $Hanf_arg13036288(anf_arg2356287,anf_arg2346275,if_helper2272218,l1762171,l21792203,wf_DASH_error27761,_plus1);
}};
$e62776278.stack[R.EXN_STACKHEIGHT++] = $ss62816282;
}
if(R.isPyretException($e62776278)) {
$e62776278.pyretStack.push(L[758]);
}
throw $e62776278;
}
var $ret62836284 = $Hanf_arg13036288($z62796280,anf_arg2346275,if_helper2272218,l1762171,l21792203,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret62836284;
};
var $Hanf_arg13036288 = function(anf_arg2356287,anf_arg2346275,if_helper2272218,l1762171,l21792203,wf_DASH_error27761,_plus1) {
var $z62916292 = D;
var $f62976298 = function(_) {
return R.isFunction(_plus1)?_plus1.app(anf_arg2346275,anf_arg2356287):R.ffi.throwNonFunApp(L[757],_plus1,[anf_arg2346275,anf_arg2356287]);
};
try {
if(--R.GAS > 0) {
$z62916292 = $f62976298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62976298,
"from":L[757]});
}
} catch($e62896290) {
if(R.isCont($e62896290)) {
var $ss62936294 = {"from":L[757],
"go":function(anf_arg2366299) {
return $Hanf_arg13026300(anf_arg2366299,if_helper2272218,l1762171,l21792203,wf_DASH_error27761,_plus1);
}};
$e62896290.stack[R.EXN_STACKHEIGHT++] = $ss62936294;
}
if(R.isPyretException($e62896290)) {
$e62896290.pyretStack.push(L[757]);
}
throw $e62896290;
}
var $ret62956296 = $Hanf_arg13026300($z62916292,if_helper2272218,l1762171,l21792203,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret62956296;
};
var $Hanf_arg13026300 = function(anf_arg2366299,if_helper2272218,l1762171,l21792203,wf_DASH_error27761,_plus1) {
var $z63036304 = D;
var $f63096310 = function(_) {
return R.isFunction(_plus1)?_plus1.app(anf_arg2366299,("`.  Use parentheses to disambiguate.")):R.ffi.throwNonFunApp(L[757],_plus1,[anf_arg2366299,("`.  Use parentheses to disambiguate.")]);
};
try {
if(--R.GAS > 0) {
$z63036304 = $f63096310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63096310,
"from":L[757]});
}
} catch($e63016302) {
if(R.isCont($e63016302)) {
var $ss63056306 = {"from":L[757],
"go":function(anf_arg2376311) {
return $Hanf_arg13016312(anf_arg2376311,if_helper2272218,l1762171,l21792203,wf_DASH_error27761);
}};
$e63016302.stack[R.EXN_STACKHEIGHT++] = $ss63056306;
}
if(R.isPyretException($e63016302)) {
$e63016302.pyretStack.push(L[757]);
}
throw $e63016302;
}
var $ret63076308 = $Hanf_arg13016312($z63036304,if_helper2272218,l1762171,l21792203,wf_DASH_error27761);
++R.GAS;
return $ret63076308;
};
var $Hanf_arg13016312 = function(anf_arg2376311,if_helper2272218,l1762171,l21792203,wf_DASH_error27761) {
var $z63156316 = D;
var $f63216322 = function(_) {
return R.isFunction(wf_DASH_error27761.$var)?wf_DASH_error27761.$var.app(anf_arg2376311,l1762171,l21792203):R.ffi.throwNonFunApp(L[759],wf_DASH_error27761.$var,[anf_arg2376311,l1762171,l21792203]);
};
try {
if(--R.GAS > 0) {
$z63156316 = $f63216322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63216322,
"from":L[759]});
}
} catch($e63136314) {
if(R.isCont($e63136314)) {
var $ss63176318 = {"from":L[759],
"go":function(cont_tail_arg2386323) {
return $Hcont_tail_arg13006324(cont_tail_arg2386323,if_helper2272218);
}};
$e63136314.stack[R.EXN_STACKHEIGHT++] = $ss63176318;
}
if(R.isPyretException($e63136314)) {
$e63136314.pyretStack.push(L[759]);
}
throw $e63136314;
}
var $ret63196320 = $Hcont_tail_arg13006324($z63156316,if_helper2272218);
++R.GAS;
return $ret63196320;
};
var $Hcont_tail_arg13006324 = function(cont_tail_arg2386323,if_helper2272218) {
if(--R.GAS > 0) {
$z63256326 = R.isFunction(if_helper2272218)?if_helper2272218.app(cont_tail_arg2386323):R.ffi.throwNonFunApp(L[759],if_helper2272218,[cont_tail_arg2386323]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper2272218)?if_helper2272218.app(cont_tail_arg2386323):R.ffi.throwNonFunApp(L[759],if_helper2272218,[cont_tail_arg2386323]);
},
"from":L[759]});
}
++R.GAS;
return $z63256326;
};
var $Hanf_arg12962252 = function(anf_arg2222251,op1742240,string_DASH_substring8) {
var $z63296330 = D;
var $f63356336 = function(_) {
return R.isFunction(string_DASH_substring8)?string_DASH_substring8.app(op1742240,(2),anf_arg2222251):R.ffi.throwNonFunApp(L[413],string_DASH_substring8,[op1742240,(2),anf_arg2222251]);
};
try {
if(--R.GAS > 0) {
$z63296330 = $f63356336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63356336,
"from":L[413]});
}
} catch($e63276328) {
if(R.isCont($e63276328)) {
var $ss63316332 = {"from":L[413],
"go":function(ann_DASH_check_DASH_temp2216337) {
return $Hann_DASH_check_DASH_temp12956338(ann_DASH_check_DASH_temp2216337);
}};
$e63276328.stack[R.EXN_STACKHEIGHT++] = $ss63316332;
}
if(R.isPyretException($e63276328)) {
$e63276328.pyretStack.push(L[413]);
}
throw $e63276328;
}
var $ret63336334 = $Hann_DASH_check_DASH_temp12956338($z63296330);
++R.GAS;
return $ret63336334;
};
var $Hann_DASH_check_DASH_temp12956338 = function(ann_DASH_check_DASH_temp2216337) {
return ann_DASH_check_DASH_temp2216337;
};
var $Hann_DASH_check_DASH_temp12942266 = function(ann_DASH_check_DASH_temp2092265,A222,List1943) {
return ann_DASH_check_DASH_temp2092265;
};
var $Hanf_arg12932284 = function(anf_arg2172281,A113,anf_arg2122282,anf_fun2112283) {
var anf_arg2186349 = G(A113,"a-blank",L[760]);
var $z63416342 = D;
var $f63476348 = function(_) {
return R.isFunction(anf_fun2112283)?anf_fun2112283.app(anf_arg2122282,(false),anf_arg2172281,anf_arg2186349):R.ffi.throwNonFunApp(L[416],anf_fun2112283,[anf_arg2122282,(false),anf_arg2172281,anf_arg2186349]);
};
try {
if(--R.GAS > 0) {
$z63416342 = $f63476348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63476348,
"from":L[416]});
}
} catch($e63396340) {
if(R.isCont($e63396340)) {
var $ss63436344 = {"from":L[416],
"go":function(ann_DASH_check_DASH_temp2106350) {
return $Hann_DASH_check_DASH_temp12926351(ann_DASH_check_DASH_temp2106350);
}};
$e63396340.stack[R.EXN_STACKHEIGHT++] = $ss63436344;
}
if(R.isPyretException($e63396340)) {
$e63396340.pyretStack.push(L[416]);
}
throw $e63396340;
}
var $ret63456346 = $Hann_DASH_check_DASH_temp12926351($z63416342);
++R.GAS;
return $ret63456346;
};
var $Hann_DASH_check_DASH_temp12926351 = function(ann_DASH_check_DASH_temp2106350) {
return ann_DASH_check_DASH_temp2106350;
};
var $Hann_DASH_check_DASH_temp12912301 = function(ann_DASH_check_DASH_temp1912300) {
return ann_DASH_check_DASH_temp1912300;
};
var $Hann_DASH_check_DASH_temp12902322 = function(ann_DASH_check_DASH_temp2032321) {
return ann_DASH_check_DASH_temp2032321;
};
var $Hann_DASH_check_DASH_temp12892339 = function(ann_DASH_check_DASH_temp2012338) {
return ann_DASH_check_DASH_temp2012338;
};
var $Hann_DASH_check_DASH_temp12882358 = function(ann_DASH_check_DASH_temp1992357) {
return ann_DASH_check_DASH_temp1992357;
};
var $Hann_DASH_check_DASH_temp12872378 = function(ann_DASH_check_DASH_temp1972377) {
return ann_DASH_check_DASH_temp1972377;
};
var $Hann_DASH_check_DASH_temp12862393 = function(ann_DASH_check_DASH_temp1952392) {
return ann_DASH_check_DASH_temp1952392;
};
var $Hann_DASH_check_DASH_temp12852409 = function(ann_DASH_check_DASH_temp1932408) {
return ann_DASH_check_DASH_temp1932408;
};
var $Hann_DASH_check_DASH_temp12842426 = function(ann_DASH_check_DASH_temp1632425) {
return ann_DASH_check_DASH_temp1632425;
};
var $Hcases_DASH_val12832445 = function(cases_DASH_val162444,ensure_DASH_unique_DASH_variant_DASH_ids10177,f1382430,rest1392431,wf_DASH_error27761,_plus1) {
var anf_fun1736362 = G(cases_DASH_val162444,"_match",L[437]);
var anf_obj1806368 = R.makeFunction(function(found1416382) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[762],1,arguments);
}
var anf_arg1756393 = G(f1382430,"name",L[764]);
var $z63856386 = D;
var $f63916392 = function(_) {
return R.isFunction(_plus1)?_plus1.app(("Found duplicate id "),anf_arg1756393):R.ffi.throwNonFunApp(L[763],_plus1,[("Found duplicate id "),anf_arg1756393]);
};
try {
if(--R.GAS > 0) {
$z63856386 = $f63916392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63916392,
"from":L[763]});
}
} catch($e63836384) {
if(R.isCont($e63836384)) {
var $ss63876388 = {"from":L[763],
"go":function(anf_arg1766394) {
return $Hanf_arg12806395(anf_arg1766394,f1382430,found1416382,wf_DASH_error27761,_plus1);
}};
$e63836384.stack[R.EXN_STACKHEIGHT++] = $ss63876388;
}
if(R.isPyretException($e63836384)) {
$e63836384.pyretStack.push(L[763]);
}
throw $e63836384;
}
var $ret63896390 = $Hanf_arg12806395($z63856386,f1382430,found1416382,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret63896390;
});
var anf_obj1826369 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[761],0,arguments);
}
var $z63726373 = D;
var $f63786379 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_variant_DASH_ids10177.$var)?ensure_DASH_unique_DASH_variant_DASH_ids10177.$var.app(rest1392431):R.ffi.throwNonFunApp(L[761],ensure_DASH_unique_DASH_variant_DASH_ids10177.$var,[rest1392431]);
};
try {
if(--R.GAS > 0) {
$z63726373 = $f63786379();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63786379,
"from":L[761]});
}
} catch($e63706371) {
if(R.isCont($e63706371)) {
var $ss63746375 = {"from":L[761],
"go":function(ann_DASH_check_DASH_temp1816380) {
return $Hann_DASH_check_DASH_temp12816381(ann_DASH_check_DASH_temp1816380);
}};
$e63706371.stack[R.EXN_STACKHEIGHT++] = $ss63746375;
}
if(R.isPyretException($e63706371)) {
$e63706371.pyretStack.push(L[761]);
}
throw $e63706371;
}
var $ret63766377 = $Hann_DASH_check_DASH_temp12816381($z63726373);
++R.GAS;
return $ret63766377;
});
var anf_arg1836363 = R.makeObject({"some":anf_obj1806368,
"none":anf_obj1826369});
var anf_arg1856364 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[437],0,arguments);
}
var ann_DASH_check_DASH_temp1846367 = R.throwNoBranchesMatched(L[437],("cases"));
return ann_DASH_check_DASH_temp1846367;
});
var $z63546355 = D;
var $f63606361 = function(_) {
return R.isFunction(anf_fun1736362)?anf_fun1736362.app(anf_arg1836363,anf_arg1856364):R.ffi.throwNonFunApp(L[436],anf_fun1736362,[anf_arg1836363,anf_arg1856364]);
};
try {
if(--R.GAS > 0) {
$z63546355 = $f63606361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63606361,
"from":L[436]});
}
} catch($e63526353) {
if(R.isCont($e63526353)) {
var $ss63566357 = {"from":L[436],
"go":function(ann_DASH_check_DASH_temp1676365) {
return $Hann_DASH_check_DASH_temp12826366(ann_DASH_check_DASH_temp1676365);
}};
$e63526353.stack[R.EXN_STACKHEIGHT++] = $ss63566357;
}
if(R.isPyretException($e63526353)) {
$e63526353.pyretStack.push(L[436]);
}
throw $e63526353;
}
var $ret63586359 = $Hann_DASH_check_DASH_temp12826366($z63546355);
++R.GAS;
return $ret63586359;
};
var $Hann_DASH_check_DASH_temp12826366 = function(ann_DASH_check_DASH_temp1676365) {
return ann_DASH_check_DASH_temp1676365;
};
var $Hann_DASH_check_DASH_temp12816381 = function(ann_DASH_check_DASH_temp1816380) {
return ann_DASH_check_DASH_temp1816380;
};
var $Hanf_arg12806395 = function(anf_arg1766394,f1382430,found1416382,wf_DASH_error27761,_plus1) {
var $z63986399 = D;
var $f64046405 = function(_) {
return R.isFunction(_plus1)?_plus1.app(anf_arg1766394,(" in list of bindings")):R.ffi.throwNonFunApp(L[763],_plus1,[anf_arg1766394,(" in list of bindings")]);
};
try {
if(--R.GAS > 0) {
$z63986399 = $f64046405();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64046405,
"from":L[763]});
}
} catch($e63966397) {
if(R.isCont($e63966397)) {
var $ss64006401 = {"from":L[763],
"go":function(anf_arg1776406) {
return $Hanf_arg12796407(anf_arg1776406,f1382430,found1416382,wf_DASH_error27761);
}};
$e63966397.stack[R.EXN_STACKHEIGHT++] = $ss64006401;
}
if(R.isPyretException($e63966397)) {
$e63966397.pyretStack.push(L[763]);
}
throw $e63966397;
}
var $ret64026403 = $Hanf_arg12796407($z63986399,f1382430,found1416382,wf_DASH_error27761);
++R.GAS;
return $ret64026403;
};
var $Hanf_arg12796407 = function(anf_arg1776406,f1382430,found1416382,wf_DASH_error27761) {
var anf_arg1786418 = G(f1382430,"l",L[766]);
var anf_arg1796419 = G(found1416382,"l",L[765]);
var $z64106411 = D;
var $f64166417 = function(_) {
return R.isFunction(wf_DASH_error27761.$var)?wf_DASH_error27761.$var.app(anf_arg1776406,anf_arg1786418,anf_arg1796419):R.ffi.throwNonFunApp(L[762],wf_DASH_error27761.$var,[anf_arg1776406,anf_arg1786418,anf_arg1796419]);
};
try {
if(--R.GAS > 0) {
$z64106411 = $f64166417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64166417,
"from":L[762]});
}
} catch($e64086409) {
if(R.isCont($e64086409)) {
var $ss64126413 = {"from":L[762],
"go":function(ann_DASH_check_DASH_temp1746420) {
return $Hann_DASH_check_DASH_temp12786421(ann_DASH_check_DASH_temp1746420);
}};
$e64086409.stack[R.EXN_STACKHEIGHT++] = $ss64126413;
}
if(R.isPyretException($e64086409)) {
$e64086409.pyretStack.push(L[762]);
}
throw $e64086409;
}
var $ret64146415 = $Hann_DASH_check_DASH_temp12786421($z64106411);
++R.GAS;
return $ret64146415;
};
var $Hann_DASH_check_DASH_temp12786421 = function(ann_DASH_check_DASH_temp1746420) {
return ann_DASH_check_DASH_temp1746420;
};
var $Hann_DASH_check_DASH_temp12772467 = function(ann_DASH_check_DASH_temp1202466) {
return ann_DASH_check_DASH_temp1202466;
};
var $Hann_DASH_check_DASH_temp12762487 = function(ann_DASH_check_DASH_temp1242486) {
return ann_DASH_check_DASH_temp1242486;
};
var $Hif_DASH_12752506 = function(if_DASH_132505,duplicate_DASH_id7863,ensure_DASH_unique_DASH_bindings10075,id1332492,l1312490,lists1118,rest1302472,shadows1322491,nothing4,tostring10) {
var if_helper1286432 = R.makeFunction(function(if_helper_arg1296473) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[449],1,arguments);
}
var ann_DASH_check_DASH_temp1266474 = if_helper_arg1296473;
return ann_DASH_check_DASH_temp1266474;
});
var anf_if1326472 = R.isBoolean(if_DASH_132505);
if(R.isPyretTrue(anf_if1326472)) {
if(R.isPyretTrue(if_DASH_132505)) {
var $z64246425 = D;
var $f64306431 = function(_) {
return R.isFunction(if_helper1286432)?if_helper1286432.app(nothing4):R.ffi.throwNonFunApp(L[767],if_helper1286432,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z64246425 = $f64306431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64306431,
"from":L[767]});
}
} catch($e64226423) {
if(R.isCont($e64226423)) {
var $ss64266427 = {"from":L[767],
"go":function(cont_tail_app1536433) {
return $Hcont_tail_app12686434(cont_tail_app1536433);
}};
$e64226423.stack[R.EXN_STACKHEIGHT++] = $ss64266427;
}
if(R.isPyretException($e64226423)) {
$e64226423.pyretStack.push(L[767]);
}
throw $e64226423;
}
var $ret64286429 = $Hcont_tail_app12686434($z64246425);
++R.GAS;
return $ret64286429;
} else {
var if_DASH_126464 = shadows1322491;
var anf_if1356468 = R.isBoolean(if_DASH_126464);
if(R.isPyretTrue(anf_if1356468)) {
if(R.isPyretTrue(if_DASH_126464)) {
var $z64376438 = D;
var $f64436444 = function(_) {
return R.isFunction(if_helper1286432)?if_helper1286432.app(nothing4):R.ffi.throwNonFunApp(L[768],if_helper1286432,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z64376438 = $f64436444();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64436444,
"from":L[768]});
}
} catch($e64356436) {
if(R.isCont($e64356436)) {
var $ss64396440 = {"from":L[768],
"go":function(cont_tail_app1526445) {
return $Hcont_tail_app12696446(cont_tail_app1526445);
}};
$e64356436.stack[R.EXN_STACKHEIGHT++] = $ss64396440;
}
if(R.isPyretException($e64356436)) {
$e64356436.pyretStack.push(L[768]);
}
throw $e64356436;
}
var $ret64416442 = $Hcont_tail_app12696446($z64376438);
++R.GAS;
return $ret64416442;
} else {
var anf_fun1366457 = G(lists1118,"find",L[772]);
var anf_arg1396458 = R.makeFunction(function(b1356461) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[770],1,arguments);
}
var anf_arg1386463 = G(b1356461,"id",L[771]);
var ann_DASH_check_DASH_temp1376462 = R.equiv(anf_arg1386463,id1332492);
return ann_DASH_check_DASH_temp1376462;
});
var $z64496450 = D;
var $f64556456 = function(_) {
return R.isFunction(anf_fun1366457)?anf_fun1366457.app(anf_arg1396458,rest1302472):R.ffi.throwNonFunApp(L[769],anf_fun1366457,[anf_arg1396458,rest1302472]);
};
try {
if(--R.GAS > 0) {
$z64496450 = $f64556456();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64556456,
"from":L[769]});
}
} catch($e64476448) {
if(R.isCont($e64476448)) {
var $ss64516452 = {"from":L[769],
"go":function(cases_DASH_val116459) {
return $Hcases_DASH_val12746460(cases_DASH_val116459,duplicate_DASH_id7863,ensure_DASH_unique_DASH_bindings10075,id1332492,if_helper1286432,l1312490,rest1302472,tostring10);
}};
$e64476448.stack[R.EXN_STACKHEIGHT++] = $ss64516452;
}
if(R.isPyretException($e64476448)) {
$e64476448.pyretStack.push(L[769]);
}
throw $e64476448;
}
var $ret64536454 = $Hcases_DASH_val12746460($z64496450,duplicate_DASH_id7863,ensure_DASH_unique_DASH_bindings10075,id1332492,if_helper1286432,l1312490,rest1302472,tostring10);
++R.GAS;
return $ret64536454;
}
} else {
var cont_tail_arg1336467 = R.throwNonBooleanCondition(L[773],("if"),if_DASH_126464);
if(--R.GAS > 0) {
$z64656466 = R.isFunction(if_helper1286432)?if_helper1286432.app(cont_tail_arg1336467):R.ffi.throwNonFunApp(L[773],if_helper1286432,[cont_tail_arg1336467]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper1286432)?if_helper1286432.app(cont_tail_arg1336467):R.ffi.throwNonFunApp(L[773],if_helper1286432,[cont_tail_arg1336467]);
},
"from":L[773]});
}
++R.GAS;
return $z64656466;
}
}
} else {
var cont_tail_arg1306471 = R.throwNonBooleanCondition(L[449],("if"),if_DASH_132505);
if(--R.GAS > 0) {
$z64696470 = R.isFunction(if_helper1286432)?if_helper1286432.app(cont_tail_arg1306471):R.ffi.throwNonFunApp(L[449],if_helper1286432,[cont_tail_arg1306471]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper1286432)?if_helper1286432.app(cont_tail_arg1306471):R.ffi.throwNonFunApp(L[449],if_helper1286432,[cont_tail_arg1306471]);
},
"from":L[449]});
}
++R.GAS;
return $z64696470;
}
};
var $Hcont_tail_app12686434 = function(cont_tail_app1536433) {
return cont_tail_app1536433;
};
var $Hcont_tail_app12696446 = function(cont_tail_app1526445) {
return cont_tail_app1526445;
};
var $Hcases_DASH_val12746460 = function(cases_DASH_val116459,duplicate_DASH_id7863,ensure_DASH_unique_DASH_bindings10075,id1332492,if_helper1286432,l1312490,rest1302472,tostring10) {
var anf_fun1406485 = G(cases_DASH_val116459,"_match",L[769]);
var anf_obj1446491 = R.makeFunction(function(found1366505) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[775],1,arguments);
}
var $z65086509 = D;
var $f65146515 = function(_) {
return R.isFunction(tostring10)?tostring10.app(id1332492):R.ffi.throwNonFunApp(L[776],tostring10,[id1332492]);
};
try {
if(--R.GAS > 0) {
$z65086509 = $f65146515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65146515,
"from":L[776]});
}
} catch($e65066507) {
if(R.isCont($e65066507)) {
var $ss65106511 = {"from":L[776],
"go":function(anf_arg1426516) {
return $Hanf_arg12716517(anf_arg1426516,duplicate_DASH_id7863,found1366505,l1312490);
}};
$e65066507.stack[R.EXN_STACKHEIGHT++] = $ss65106511;
}
if(R.isPyretException($e65066507)) {
$e65066507.pyretStack.push(L[776]);
}
throw $e65066507;
}
var $ret65126513 = $Hanf_arg12716517($z65086509,duplicate_DASH_id7863,found1366505,l1312490);
++R.GAS;
return $ret65126513;
});
var anf_obj1466492 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[774],0,arguments);
}
var $z64956496 = D;
var $f65016502 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_bindings10075.$var)?ensure_DASH_unique_DASH_bindings10075.$var.app(rest1302472):R.ffi.throwNonFunApp(L[774],ensure_DASH_unique_DASH_bindings10075.$var,[rest1302472]);
};
try {
if(--R.GAS > 0) {
$z64956496 = $f65016502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65016502,
"from":L[774]});
}
} catch($e64936494) {
if(R.isCont($e64936494)) {
var $ss64976498 = {"from":L[774],
"go":function(ann_DASH_check_DASH_temp1456503) {
return $Hann_DASH_check_DASH_temp12726504(ann_DASH_check_DASH_temp1456503);
}};
$e64936494.stack[R.EXN_STACKHEIGHT++] = $ss64976498;
}
if(R.isPyretException($e64936494)) {
$e64936494.pyretStack.push(L[774]);
}
throw $e64936494;
}
var $ret64996500 = $Hann_DASH_check_DASH_temp12726504($z64956496);
++R.GAS;
return $ret64996500;
});
var anf_arg1476486 = R.makeObject({"some":anf_obj1446491,
"none":anf_obj1466492});
var anf_arg1496487 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[769],0,arguments);
}
var ann_DASH_check_DASH_temp1486490 = R.throwNoBranchesMatched(L[769],("cases"));
return ann_DASH_check_DASH_temp1486490;
});
var $z64776478 = D;
var $f64836484 = function(_) {
return R.isFunction(anf_fun1406485)?anf_fun1406485.app(anf_arg1476486,anf_arg1496487):R.ffi.throwNonFunApp(L[769],anf_fun1406485,[anf_arg1476486,anf_arg1496487]);
};
try {
if(--R.GAS > 0) {
$z64776478 = $f64836484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64836484,
"from":L[769]});
}
} catch($e64756476) {
if(R.isCont($e64756476)) {
var $ss64796480 = {"from":L[769],
"go":function(cont_tail_arg1506488) {
return $Hcont_tail_arg12736489(cont_tail_arg1506488,if_helper1286432);
}};
$e64756476.stack[R.EXN_STACKHEIGHT++] = $ss64796480;
}
if(R.isPyretException($e64756476)) {
$e64756476.pyretStack.push(L[769]);
}
throw $e64756476;
}
var $ret64816482 = $Hcont_tail_arg12736489($z64776478,if_helper1286432);
++R.GAS;
return $ret64816482;
};
var $Hcont_tail_arg12736489 = function(cont_tail_arg1506488,if_helper1286432) {
if(--R.GAS > 0) {
$z65186519 = R.isFunction(if_helper1286432)?if_helper1286432.app(cont_tail_arg1506488):R.ffi.throwNonFunApp(L[769],if_helper1286432,[cont_tail_arg1506488]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper1286432)?if_helper1286432.app(cont_tail_arg1506488):R.ffi.throwNonFunApp(L[769],if_helper1286432,[cont_tail_arg1506488]);
},
"from":L[769]});
}
++R.GAS;
return $z65186519;
};
var $Hann_DASH_check_DASH_temp12726504 = function(ann_DASH_check_DASH_temp1456503) {
return ann_DASH_check_DASH_temp1456503;
};
var $Hanf_arg12716517 = function(anf_arg1426516,duplicate_DASH_id7863,found1366505,l1312490) {
var anf_arg1436530 = G(found1366505,"l",L[777]);
var $z65226523 = D;
var $f65286529 = function(_) {
return R.isFunction(duplicate_DASH_id7863.$var)?duplicate_DASH_id7863.$var.app(anf_arg1426516,l1312490,anf_arg1436530):R.ffi.throwNonFunApp(L[775],duplicate_DASH_id7863.$var,[anf_arg1426516,l1312490,anf_arg1436530]);
};
try {
if(--R.GAS > 0) {
$z65226523 = $f65286529();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65286529,
"from":L[775]});
}
} catch($e65206521) {
if(R.isCont($e65206521)) {
var $ss65246525 = {"from":L[775],
"go":function(ann_DASH_check_DASH_temp1416531) {
return $Hann_DASH_check_DASH_temp12706532(ann_DASH_check_DASH_temp1416531);
}};
$e65206521.stack[R.EXN_STACKHEIGHT++] = $ss65246525;
}
if(R.isPyretException($e65206521)) {
$e65206521.pyretStack.push(L[775]);
}
throw $e65206521;
}
var $ret65266527 = $Hann_DASH_check_DASH_temp12706532($z65226523);
++R.GAS;
return $ret65266527;
};
var $Hann_DASH_check_DASH_temp12706532 = function(ann_DASH_check_DASH_temp1416531) {
return ann_DASH_check_DASH_temp1416531;
};
var $Hann_DASH_check_DASH_temp12672525 = function(ann_DASH_check_DASH_temp772524) {
return ann_DASH_check_DASH_temp772524;
};
var $Hann_DASH_check_DASH_temp12662545 = function(ann_DASH_check_DASH_temp812544) {
return ann_DASH_check_DASH_temp812544;
};
var $Hif_DASH_12652564 = function(if_DASH_82563,ensure_DASH_unique_DASH_ids9973,id1232550,l1212548,lists1118,rest1202530,wf_DASH_error27761,_plus1,nothing4,print5,torepr9,tostring10) {
var if_helper856543 = R.makeFunction(function(if_helper_arg866567) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[458],1,arguments);
}
var ann_DASH_check_DASH_temp836568 = if_helper_arg866567;
return ann_DASH_check_DASH_temp836568;
});
var anf_if896566 = R.isBoolean(if_DASH_82563);
if(R.isPyretTrue(anf_if896566)) {
if(R.isPyretTrue(if_DASH_82563)) {
var $z65356536 = D;
var $f65416542 = function(_) {
return R.isFunction(if_helper856543)?if_helper856543.app(nothing4):R.ffi.throwNonFunApp(L[778],if_helper856543,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z65356536 = $f65416542();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65416542,
"from":L[778]});
}
} catch($e65336534) {
if(R.isCont($e65336534)) {
var $ss65376538 = {"from":L[778],
"go":function(cont_tail_app1106544) {
return $Hcont_tail_app12546545(cont_tail_app1106544);
}};
$e65336534.stack[R.EXN_STACKHEIGHT++] = $ss65376538;
}
if(R.isPyretException($e65336534)) {
$e65336534.pyretStack.push(L[778]);
}
throw $e65336534;
}
var $ret65396540 = $Hcont_tail_app12546545($z65356536);
++R.GAS;
return $ret65396540;
} else {
var anf_fun906556 = G(lists1118,"find",L[782]);
var anf_arg936557 = R.makeFunction(function(b1266560) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[780],1,arguments);
}
var anf_arg926562 = G(b1266560,"id",L[781]);
var ann_DASH_check_DASH_temp916561 = R.equiv(anf_arg926562,id1232550);
return ann_DASH_check_DASH_temp916561;
});
var $z65486549 = D;
var $f65546555 = function(_) {
return R.isFunction(anf_fun906556)?anf_fun906556.app(anf_arg936557,rest1202530):R.ffi.throwNonFunApp(L[779],anf_fun906556,[anf_arg936557,rest1202530]);
};
try {
if(--R.GAS > 0) {
$z65486549 = $f65546555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65546555,
"from":L[779]});
}
} catch($e65466547) {
if(R.isCont($e65466547)) {
var $ss65506551 = {"from":L[779],
"go":function(elt1256558) {
return $Helt12646559(elt1256558,ensure_DASH_unique_DASH_ids9973,id1232550,if_helper856543,l1212548,rest1202530,wf_DASH_error27761,_plus1,print5,torepr9,tostring10);
}};
$e65466547.stack[R.EXN_STACKHEIGHT++] = $ss65506551;
}
if(R.isPyretException($e65466547)) {
$e65466547.pyretStack.push(L[779]);
}
throw $e65466547;
}
var $ret65526553 = $Helt12646559($z65486549,ensure_DASH_unique_DASH_ids9973,id1232550,if_helper856543,l1212548,rest1202530,wf_DASH_error27761,_plus1,print5,torepr9,tostring10);
++R.GAS;
return $ret65526553;
}
} else {
var cont_tail_arg876565 = R.throwNonBooleanCondition(L[458],("if"),if_DASH_82563);
if(--R.GAS > 0) {
$z65636564 = R.isFunction(if_helper856543)?if_helper856543.app(cont_tail_arg876565):R.ffi.throwNonFunApp(L[458],if_helper856543,[cont_tail_arg876565]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper856543)?if_helper856543.app(cont_tail_arg876565):R.ffi.throwNonFunApp(L[458],if_helper856543,[cont_tail_arg876565]);
},
"from":L[458]});
}
++R.GAS;
return $z65636564;
}
};
var $Hcont_tail_app12546545 = function(cont_tail_app1106544) {
return cont_tail_app1106544;
};
var $Helt12646559 = function(elt1256558,ensure_DASH_unique_DASH_ids9973,id1232550,if_helper856543,l1212548,rest1202530,wf_DASH_error27761,_plus1,print5,torepr9,tostring10) {
var cases_DASH_val76623 = elt1256558;
var anf_fun946579 = G(cases_DASH_val76623,"_match",L[783]);
var anf_obj1006596 = R.makeFunction(function(found1276610) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[786],1,arguments);
}
var $z66136614 = D;
var $f66196620 = function(_) {
return R.isFunction(tostring10)?tostring10.app(id1232550):R.ffi.throwNonFunApp(L[787],tostring10,[id1232550]);
};
try {
if(--R.GAS > 0) {
$z66136614 = $f66196620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66196620,
"from":L[787]});
}
} catch($e66116612) {
if(R.isCont($e66116612)) {
var $ss66156616 = {"from":L[787],
"go":function(anf_arg966621) {
return $Hanf_arg12586622(anf_arg966621,found1276610,l1212548,wf_DASH_error27761,_plus1);
}};
$e66116612.stack[R.EXN_STACKHEIGHT++] = $ss66156616;
}
if(R.isPyretException($e66116612)) {
$e66116612.pyretStack.push(L[787]);
}
throw $e66116612;
}
var $ret66176618 = $Hanf_arg12586622($z66136614,found1276610,l1212548,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret66176618;
});
var anf_obj1026597 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[785],0,arguments);
}
var $z66006601 = D;
var $f66066607 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_ids9973.$var)?ensure_DASH_unique_DASH_ids9973.$var.app(rest1202530):R.ffi.throwNonFunApp(L[785],ensure_DASH_unique_DASH_ids9973.$var,[rest1202530]);
};
try {
if(--R.GAS > 0) {
$z66006601 = $f66066607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66066607,
"from":L[785]});
}
} catch($e65986599) {
if(R.isCont($e65986599)) {
var $ss66026603 = {"from":L[785],
"go":function(ann_DASH_check_DASH_temp1016608) {
return $Hann_DASH_check_DASH_temp12596609(ann_DASH_check_DASH_temp1016608);
}};
$e65986599.stack[R.EXN_STACKHEIGHT++] = $ss66026603;
}
if(R.isPyretException($e65986599)) {
$e65986599.pyretStack.push(L[785]);
}
throw $e65986599;
}
var $ret66046605 = $Hann_DASH_check_DASH_temp12596609($z66006601);
++R.GAS;
return $ret66046605;
});
var anf_arg1036580 = R.makeObject({"some":anf_obj1006596,
"none":anf_obj1026597});
var anf_arg1076581 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[783],0,arguments);
}
var $z65866587 = D;
var $f65926593 = function(_) {
return R.isFunction(torepr9)?torepr9.app(elt1256558):R.ffi.throwNonFunApp(L[784],torepr9,[elt1256558]);
};
try {
if(--R.GAS > 0) {
$z65866587 = $f65926593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65926593,
"from":L[784]});
}
} catch($e65846585) {
if(R.isCont($e65846585)) {
var $ss65886589 = {"from":L[784],
"go":function(anf_arg1056594) {
return $Hanf_arg12626595(anf_arg1056594,_plus1,print5);
}};
$e65846585.stack[R.EXN_STACKHEIGHT++] = $ss65886589;
}
if(R.isPyretException($e65846585)) {
$e65846585.pyretStack.push(L[784]);
}
throw $e65846585;
}
var $ret65906591 = $Hanf_arg12626595($z65866587,_plus1,print5);
++R.GAS;
return $ret65906591;
});
var $z65716572 = D;
var $f65776578 = function(_) {
return R.isFunction(anf_fun946579)?anf_fun946579.app(anf_arg1036580,anf_arg1076581):R.ffi.throwNonFunApp(L[783],anf_fun946579,[anf_arg1036580,anf_arg1076581]);
};
try {
if(--R.GAS > 0) {
$z65716572 = $f65776578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65776578,
"from":L[783]});
}
} catch($e65696570) {
if(R.isCont($e65696570)) {
var $ss65736574 = {"from":L[783],
"go":function(cont_tail_arg1086582) {
return $Hcont_tail_arg12636583(cont_tail_arg1086582,if_helper856543);
}};
$e65696570.stack[R.EXN_STACKHEIGHT++] = $ss65736574;
}
if(R.isPyretException($e65696570)) {
$e65696570.pyretStack.push(L[783]);
}
throw $e65696570;
}
var $ret65756576 = $Hcont_tail_arg12636583($z65716572,if_helper856543);
++R.GAS;
return $ret65756576;
};
var $Hcont_tail_arg12636583 = function(cont_tail_arg1086582,if_helper856543) {
if(--R.GAS > 0) {
$z66246625 = R.isFunction(if_helper856543)?if_helper856543.app(cont_tail_arg1086582):R.ffi.throwNonFunApp(L[783],if_helper856543,[cont_tail_arg1086582]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper856543)?if_helper856543.app(cont_tail_arg1086582):R.ffi.throwNonFunApp(L[783],if_helper856543,[cont_tail_arg1086582]);
},
"from":L[783]});
}
++R.GAS;
return $z66246625;
};
var $Hanf_arg12626595 = function(anf_arg1056594,_plus1,print5) {
var $z66286629 = D;
var $f66346635 = function(_) {
return R.isFunction(_plus1)?_plus1.app(("Elt was: "),anf_arg1056594):R.ffi.throwNonFunApp(L[788],_plus1,[("Elt was: "),anf_arg1056594]);
};
try {
if(--R.GAS > 0) {
$z66286629 = $f66346635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66346635,
"from":L[788]});
}
} catch($e66266627) {
if(R.isCont($e66266627)) {
var $ss66306631 = {"from":L[788],
"go":function(anf_arg1066636) {
return $Hanf_arg12616637(anf_arg1066636,print5);
}};
$e66266627.stack[R.EXN_STACKHEIGHT++] = $ss66306631;
}
if(R.isPyretException($e66266627)) {
$e66266627.pyretStack.push(L[788]);
}
throw $e66266627;
}
var $ret66326633 = $Hanf_arg12616637($z66286629,print5);
++R.GAS;
return $ret66326633;
};
var $Hanf_arg12616637 = function(anf_arg1066636,print5) {
var $z66406641 = D;
var $f66466647 = function(_) {
return R.isFunction(print5)?print5.app(anf_arg1066636):R.ffi.throwNonFunApp(L[783],print5,[anf_arg1066636]);
};
try {
if(--R.GAS > 0) {
$z66406641 = $f66466647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66466647,
"from":L[783]});
}
} catch($e66386639) {
if(R.isCont($e66386639)) {
var $ss66426643 = {"from":L[783],
"go":function(ann_DASH_check_DASH_temp1046648) {
return $Hann_DASH_check_DASH_temp12606649(ann_DASH_check_DASH_temp1046648);
}};
$e66386639.stack[R.EXN_STACKHEIGHT++] = $ss66426643;
}
if(R.isPyretException($e66386639)) {
$e66386639.pyretStack.push(L[783]);
}
throw $e66386639;
}
var $ret66446645 = $Hann_DASH_check_DASH_temp12606649($z66406641);
++R.GAS;
return $ret66446645;
};
var $Hann_DASH_check_DASH_temp12606649 = function(ann_DASH_check_DASH_temp1046648) {
return ann_DASH_check_DASH_temp1046648;
};
var $Hann_DASH_check_DASH_temp12596609 = function(ann_DASH_check_DASH_temp1016608) {
return ann_DASH_check_DASH_temp1016608;
};
var $Hanf_arg12586622 = function(anf_arg966621,found1276610,l1212548,wf_DASH_error27761,_plus1) {
var $z66526653 = D;
var $f66586659 = function(_) {
return R.isFunction(_plus1)?_plus1.app(("Found duplicate id "),anf_arg966621):R.ffi.throwNonFunApp(L[789],_plus1,[("Found duplicate id "),anf_arg966621]);
};
try {
if(--R.GAS > 0) {
$z66526653 = $f66586659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66586659,
"from":L[789]});
}
} catch($e66506651) {
if(R.isCont($e66506651)) {
var $ss66546655 = {"from":L[789],
"go":function(anf_arg976660) {
return $Hanf_arg12576661(anf_arg976660,found1276610,l1212548,wf_DASH_error27761,_plus1);
}};
$e66506651.stack[R.EXN_STACKHEIGHT++] = $ss66546655;
}
if(R.isPyretException($e66506651)) {
$e66506651.pyretStack.push(L[789]);
}
throw $e66506651;
}
var $ret66566657 = $Hanf_arg12576661($z66526653,found1276610,l1212548,wf_DASH_error27761,_plus1);
++R.GAS;
return $ret66566657;
};
var $Hanf_arg12576661 = function(anf_arg976660,found1276610,l1212548,wf_DASH_error27761,_plus1) {
var $z66646665 = D;
var $f66706671 = function(_) {
return R.isFunction(_plus1)?_plus1.app(anf_arg976660,(" in list of bindings")):R.ffi.throwNonFunApp(L[789],_plus1,[anf_arg976660,(" in list of bindings")]);
};
try {
if(--R.GAS > 0) {
$z66646665 = $f66706671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66706671,
"from":L[789]});
}
} catch($e66626663) {
if(R.isCont($e66626663)) {
var $ss66666667 = {"from":L[789],
"go":function(anf_arg986672) {
return $Hanf_arg12566673(anf_arg986672,found1276610,l1212548,wf_DASH_error27761);
}};
$e66626663.stack[R.EXN_STACKHEIGHT++] = $ss66666667;
}
if(R.isPyretException($e66626663)) {
$e66626663.pyretStack.push(L[789]);
}
throw $e66626663;
}
var $ret66686669 = $Hanf_arg12566673($z66646665,found1276610,l1212548,wf_DASH_error27761);
++R.GAS;
return $ret66686669;
};
var $Hanf_arg12566673 = function(anf_arg986672,found1276610,l1212548,wf_DASH_error27761) {
var anf_arg996684 = G(found1276610,"l",L[790]);
var $z66766677 = D;
var $f66826683 = function(_) {
return R.isFunction(wf_DASH_error27761.$var)?wf_DASH_error27761.$var.app(anf_arg986672,l1212548,anf_arg996684):R.ffi.throwNonFunApp(L[786],wf_DASH_error27761.$var,[anf_arg986672,l1212548,anf_arg996684]);
};
try {
if(--R.GAS > 0) {
$z66766677 = $f66826683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66826683,
"from":L[786]});
}
} catch($e66746675) {
if(R.isCont($e66746675)) {
var $ss66786679 = {"from":L[786],
"go":function(ann_DASH_check_DASH_temp956685) {
return $Hann_DASH_check_DASH_temp12556686(ann_DASH_check_DASH_temp956685);
}};
$e66746675.stack[R.EXN_STACKHEIGHT++] = $ss66786679;
}
if(R.isPyretException($e66746675)) {
$e66746675.pyretStack.push(L[786]);
}
throw $e66746675;
}
var $ret66806681 = $Hann_DASH_check_DASH_temp12556686($z66766677);
++R.GAS;
return $ret66806681;
};
var $Hann_DASH_check_DASH_temp12556686 = function(ann_DASH_check_DASH_temp956685) {
return ann_DASH_check_DASH_temp956685;
};
var $Hann_DASH_check_DASH_temp12532583 = function(ann_DASH_check_DASH_temp472582) {
return ann_DASH_check_DASH_temp472582;
};
var $Hann_DASH_check_DASH_temp12522603 = function(ann_DASH_check_DASH_temp512602) {
return ann_DASH_check_DASH_temp512602;
};
var $Hcases_DASH_val12512623 = function(cases_DASH_val42622,ensure_DASH_unique_DASH_cases9871,l1122606,name1132607,rest1112588,wf_DASH_error27761,_plus1) {
var anf_fun586697 = G(cases_DASH_val42622,"_match",L[467]);
var anf_obj626703 = R.makeFunction(function(found1176717) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[792],1,arguments);
}
var $z67206721 = D;
var $f67266727 = function(_) {
return R.isFunction(_plus1)?_plus1.app(("Duplicate case for "),name1132607):R.ffi.throwNonFunApp(L[793],_plus1,[("Duplicate case for "),name1132607]);
};
try {
if(--R.GAS > 0) {
$z67206721 = $f67266727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67266727,
"from":L[793]});
}
} catch($e67186719) {
if(R.isCont($e67186719)) {
var $ss67226723 = {"from":L[793],
"go":function(anf_arg606728) {
return $Hanf_arg12486729(anf_arg606728,found1176717,l1122606,wf_DASH_error27761);
}};
$e67186719.stack[R.EXN_STACKHEIGHT++] = $ss67226723;
}
if(R.isPyretException($e67186719)) {
$e67186719.pyretStack.push(L[793]);
}
throw $e67186719;
}
var $ret67246725 = $Hanf_arg12486729($z67206721,found1176717,l1122606,wf_DASH_error27761);
++R.GAS;
return $ret67246725;
});
var anf_obj646704 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[791],0,arguments);
}
var $z67076708 = D;
var $f67136714 = function(_) {
return R.isFunction(ensure_DASH_unique_DASH_cases9871.$var)?ensure_DASH_unique_DASH_cases9871.$var.app(rest1112588):R.ffi.throwNonFunApp(L[791],ensure_DASH_unique_DASH_cases9871.$var,[rest1112588]);
};
try {
if(--R.GAS > 0) {
$z67076708 = $f67136714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67136714,
"from":L[791]});
}
} catch($e67056706) {
if(R.isCont($e67056706)) {
var $ss67096710 = {"from":L[791],
"go":function(ann_DASH_check_DASH_temp636715) {
return $Hann_DASH_check_DASH_temp12496716(ann_DASH_check_DASH_temp636715);
}};
$e67056706.stack[R.EXN_STACKHEIGHT++] = $ss67096710;
}
if(R.isPyretException($e67056706)) {
$e67056706.pyretStack.push(L[791]);
}
throw $e67056706;
}
var $ret67116712 = $Hann_DASH_check_DASH_temp12496716($z67076708);
++R.GAS;
return $ret67116712;
});
var anf_arg656698 = R.makeObject({"some":anf_obj626703,
"none":anf_obj646704});
var anf_arg676699 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[467],0,arguments);
}
var ann_DASH_check_DASH_temp666702 = R.throwNoBranchesMatched(L[467],("cases"));
return ann_DASH_check_DASH_temp666702;
});
var $z66896690 = D;
var $f66956696 = function(_) {
return R.isFunction(anf_fun586697)?anf_fun586697.app(anf_arg656698,anf_arg676699):R.ffi.throwNonFunApp(L[466],anf_fun586697,[anf_arg656698,anf_arg676699]);
};
try {
if(--R.GAS > 0) {
$z66896690 = $f66956696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66956696,
"from":L[466]});
}
} catch($e66876688) {
if(R.isCont($e66876688)) {
var $ss66916692 = {"from":L[466],
"go":function(ann_DASH_check_DASH_temp536700) {
return $Hann_DASH_check_DASH_temp12506701(ann_DASH_check_DASH_temp536700);
}};
$e66876688.stack[R.EXN_STACKHEIGHT++] = $ss66916692;
}
if(R.isPyretException($e66876688)) {
$e66876688.pyretStack.push(L[466]);
}
throw $e66876688;
}
var $ret66936694 = $Hann_DASH_check_DASH_temp12506701($z66896690);
++R.GAS;
return $ret66936694;
};
var $Hann_DASH_check_DASH_temp12506701 = function(ann_DASH_check_DASH_temp536700) {
return ann_DASH_check_DASH_temp536700;
};
var $Hann_DASH_check_DASH_temp12496716 = function(ann_DASH_check_DASH_temp636715) {
return ann_DASH_check_DASH_temp636715;
};
var $Hanf_arg12486729 = function(anf_arg606728,found1176717,l1122606,wf_DASH_error27761) {
var anf_arg616740 = G(found1176717,"l",L[794]);
var $z67326733 = D;
var $f67386739 = function(_) {
return R.isFunction(wf_DASH_error27761.$var)?wf_DASH_error27761.$var.app(anf_arg606728,anf_arg616740,l1122606):R.ffi.throwNonFunApp(L[792],wf_DASH_error27761.$var,[anf_arg606728,anf_arg616740,l1122606]);
};
try {
if(--R.GAS > 0) {
$z67326733 = $f67386739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67386739,
"from":L[792]});
}
} catch($e67306731) {
if(R.isCont($e67306731)) {
var $ss67346735 = {"from":L[792],
"go":function(ann_DASH_check_DASH_temp596741) {
return $Hann_DASH_check_DASH_temp12476742(ann_DASH_check_DASH_temp596741);
}};
$e67306731.stack[R.EXN_STACKHEIGHT++] = $ss67346735;
}
if(R.isPyretException($e67306731)) {
$e67306731.pyretStack.push(L[792]);
}
throw $e67306731;
}
var $ret67366737 = $Hann_DASH_check_DASH_temp12476742($z67326733);
++R.GAS;
return $ret67366737;
};
var $Hann_DASH_check_DASH_temp12476742 = function(ann_DASH_check_DASH_temp596741) {
return ann_DASH_check_DASH_temp596741;
};
var $Hif_DASH_12462644 = function(if_DASH_22643,block1082632,loc1062630,typ1072631,wf_DASH_error7659,_plus1,nothing4,tostring10) {
var if_helper296755 = R.makeFunction(function(if_helper_arg306774) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[474],1,arguments);
}
var ann_DASH_check_DASH_temp286775 = if_helper_arg306774;
return ann_DASH_check_DASH_temp286775;
});
var anf_if336773 = R.isBoolean(if_DASH_22643);
if(R.isPyretTrue(anf_if336773)) {
if(R.isPyretTrue(if_DASH_22643)) {
var anf_bracket356757 = G(block1082632,"stmts",L[797]);
var anf_fun366753 = G(anf_bracket356757,"length",L[796]);
var $z67456746 = D;
var $f67516752 = function(_) {
return R.isFunction(anf_fun366753)?anf_fun366753.app():R.ffi.throwNonFunApp(L[795],anf_fun366753,[]);
};
try {
if(--R.GAS > 0) {
$z67456746 = $f67516752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67516752,
"from":L[795]});
}
} catch($e67436744) {
if(R.isCont($e67436744)) {
var $ss67476748 = {"from":L[795],
"go":function(anf_arg376754) {
return $Hanf_arg12446756(anf_arg376754,if_helper296755,loc1062630,typ1072631,wf_DASH_error7659,_plus1,nothing4,tostring10);
}};
$e67436744.stack[R.EXN_STACKHEIGHT++] = $ss67476748;
}
if(R.isPyretException($e67436744)) {
$e67436744.pyretStack.push(L[795]);
}
throw $e67436744;
}
var $ret67496750 = $Hanf_arg12446756($z67456746,if_helper296755,loc1062630,typ1072631,wf_DASH_error7659,_plus1,nothing4,tostring10);
++R.GAS;
return $ret67496750;
} else {
var $z67606761 = D;
var $f67666767 = function(_) {
return R.isFunction(if_helper296755)?if_helper296755.app(nothing4):R.ffi.throwNonFunApp(L[798],if_helper296755,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z67606761 = $f67666767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67666767,
"from":L[798]});
}
} catch($e67586759) {
if(R.isCont($e67586759)) {
var $ss67626763 = {"from":L[798],
"go":function(cont_tail_app346768) {
return $Hcont_tail_app12456769(cont_tail_app346768);
}};
$e67586759.stack[R.EXN_STACKHEIGHT++] = $ss67626763;
}
if(R.isPyretException($e67586759)) {
$e67586759.pyretStack.push(L[798]);
}
throw $e67586759;
}
var $ret67646765 = $Hcont_tail_app12456769($z67606761);
++R.GAS;
return $ret67646765;
}
} else {
var cont_tail_arg316772 = R.throwNonBooleanCondition(L[474],("if"),if_DASH_22643);
if(--R.GAS > 0) {
$z67706771 = R.isFunction(if_helper296755)?if_helper296755.app(cont_tail_arg316772):R.ffi.throwNonFunApp(L[474],if_helper296755,[cont_tail_arg316772]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper296755)?if_helper296755.app(cont_tail_arg316772):R.ffi.throwNonFunApp(L[474],if_helper296755,[cont_tail_arg316772]);
},
"from":L[474]});
}
++R.GAS;
return $z67706771;
}
};
var $Hanf_arg12446756 = function(anf_arg376754,if_helper296755,loc1062630,typ1072631,wf_DASH_error7659,_plus1,nothing4,tostring10) {
var if_DASH_36800 = R.equiv(anf_arg376754,(0));
var anf_if406804 = R.isBoolean(if_DASH_36800);
if(R.isPyretTrue(anf_if406804)) {
if(R.isPyretTrue(if_DASH_36800)) {
var $z67786779 = D;
var $f67846785 = function(_) {
return R.isFunction(if_helper296755)?if_helper296755.app(nothing4):R.ffi.throwNonFunApp(L[799],if_helper296755,[nothing4]);
};
try {
if(--R.GAS > 0) {
$z67786779 = $f67846785();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67846785,
"from":L[799]});
}
} catch($e67766777) {
if(R.isCont($e67766777)) {
var $ss67806781 = {"from":L[799],
"go":function(cont_tail_app456786) {
return $Hcont_tail_app12406787(cont_tail_app456786);
}};
$e67766777.stack[R.EXN_STACKHEIGHT++] = $ss67806781;
}
if(R.isPyretException($e67766777)) {
$e67766777.pyretStack.push(L[799]);
}
throw $e67766777;
}
var $ret67826783 = $Hcont_tail_app12406787($z67786779);
++R.GAS;
return $ret67826783;
} else {
var $z67906791 = D;
var $f67966797 = function(_) {
return R.isFunction(tostring10)?tostring10.app(typ1072631):R.ffi.throwNonFunApp(L[800],tostring10,[typ1072631]);
};
try {
if(--R.GAS > 0) {
$z67906791 = $f67966797();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67966797,
"from":L[800]});
}
} catch($e67886789) {
if(R.isCont($e67886789)) {
var $ss67926793 = {"from":L[800],
"go":function(anf_arg416798) {
return $Hanf_arg12436799(anf_arg416798,if_helper296755,loc1062630,wf_DASH_error7659,_plus1);
}};
$e67886789.stack[R.EXN_STACKHEIGHT++] = $ss67926793;
}
if(R.isPyretException($e67886789)) {
$e67886789.pyretStack.push(L[800]);
}
throw $e67886789;
}
var $ret67946795 = $Hanf_arg12436799($z67906791,if_helper296755,loc1062630,wf_DASH_error7659,_plus1);
++R.GAS;
return $ret67946795;
}
} else {
var cont_tail_arg386803 = R.throwNonBooleanCondition(L[801],("if"),if_DASH_36800);
if(--R.GAS > 0) {
$z68016802 = R.isFunction(if_helper296755)?if_helper296755.app(cont_tail_arg386803):R.ffi.throwNonFunApp(L[801],if_helper296755,[cont_tail_arg386803]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper296755)?if_helper296755.app(cont_tail_arg386803):R.ffi.throwNonFunApp(L[801],if_helper296755,[cont_tail_arg386803]);
},
"from":L[801]});
}
++R.GAS;
return $z68016802;
}
};
var $Hcont_tail_app12406787 = function(cont_tail_app456786) {
return cont_tail_app456786;
};
var $Hanf_arg12436799 = function(anf_arg416798,if_helper296755,loc1062630,wf_DASH_error7659,_plus1) {
var $z68076808 = D;
var $f68136814 = function(_) {
return R.isFunction(_plus1)?_plus1.app(("where: blocks only allowed on named function declarations and data, not on "),anf_arg416798):R.ffi.throwNonFunApp(L[802],_plus1,[("where: blocks only allowed on named function declarations and data, not on "),anf_arg416798]);
};
try {
if(--R.GAS > 0) {
$z68076808 = $f68136814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68136814,
"from":L[802]});
}
} catch($e68056806) {
if(R.isCont($e68056806)) {
var $ss68096810 = {"from":L[802],
"go":function(anf_arg426815) {
return $Hanf_arg12426816(anf_arg426815,if_helper296755,loc1062630,wf_DASH_error7659);
}};
$e68056806.stack[R.EXN_STACKHEIGHT++] = $ss68096810;
}
if(R.isPyretException($e68056806)) {
$e68056806.pyretStack.push(L[802]);
}
throw $e68056806;
}
var $ret68116812 = $Hanf_arg12426816($z68076808,if_helper296755,loc1062630,wf_DASH_error7659);
++R.GAS;
return $ret68116812;
};
var $Hanf_arg12426816 = function(anf_arg426815,if_helper296755,loc1062630,wf_DASH_error7659) {
var $z68196820 = D;
var $f68256826 = function(_) {
return R.isFunction(wf_DASH_error7659.$var)?wf_DASH_error7659.$var.app(anf_arg426815,loc1062630):R.ffi.throwNonFunApp(L[803],wf_DASH_error7659.$var,[anf_arg426815,loc1062630]);
};
try {
if(--R.GAS > 0) {
$z68196820 = $f68256826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68256826,
"from":L[803]});
}
} catch($e68176818) {
if(R.isCont($e68176818)) {
var $ss68216822 = {"from":L[803],
"go":function(cont_tail_arg436827) {
return $Hcont_tail_arg12416828(cont_tail_arg436827,if_helper296755);
}};
$e68176818.stack[R.EXN_STACKHEIGHT++] = $ss68216822;
}
if(R.isPyretException($e68176818)) {
$e68176818.pyretStack.push(L[803]);
}
throw $e68176818;
}
var $ret68236824 = $Hcont_tail_arg12416828($z68196820,if_helper296755);
++R.GAS;
return $ret68236824;
};
var $Hcont_tail_arg12416828 = function(cont_tail_arg436827,if_helper296755) {
if(--R.GAS > 0) {
$z68296830 = R.isFunction(if_helper296755)?if_helper296755.app(cont_tail_arg436827):R.ffi.throwNonFunApp(L[803],if_helper296755,[cont_tail_arg436827]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1738) {
return R.isFunction(if_helper296755)?if_helper296755.app(cont_tail_arg436827):R.ffi.throwNonFunApp(L[803],if_helper296755,[cont_tail_arg436827]);
},
"from":L[803]});
}
++R.GAS;
return $z68296830;
};
var $Hcont_tail_app12456769 = function(cont_tail_app346768) {
return cont_tail_app346768;
};
var $Hret12392661 = function(ret952659,cur_DASH_in_DASH_check942660,in_DASH_check_DASH_block7050) {
in_DASH_check_DASH_block7050.$var = cur_DASH_in_DASH_check942660;
var ann_DASH_check_DASH_temp256831 = ret952659;
return ann_DASH_check_DASH_temp256831;
};
var $Hanf_arg12382676 = function(anf_arg232675,add_DASH_error7557) {
var $z68346835 = D;
var $f68406841 = function(_) {
return R.isFunction(add_DASH_error7557.$var)?add_DASH_error7557.$var.app(anf_arg232675):R.ffi.throwNonFunApp(L[481],add_DASH_error7557.$var,[anf_arg232675]);
};
try {
if(--R.GAS > 0) {
$z68346835 = $f68406841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68406841,
"from":L[481]});
}
} catch($e68326833) {
if(R.isCont($e68326833)) {
var $ss68366837 = {"from":L[481],
"go":function(ann_DASH_check_DASH_temp216842) {
return $Hann_DASH_check_DASH_temp12376843(ann_DASH_check_DASH_temp216842);
}};
$e68326833.stack[R.EXN_STACKHEIGHT++] = $ss68366837;
}
if(R.isPyretException($e68326833)) {
$e68326833.pyretStack.push(L[481]);
}
throw $e68326833;
}
var $ret68386839 = $Hann_DASH_check_DASH_temp12376843($z68346835);
++R.GAS;
return $ret68386839;
};
var $Hann_DASH_check_DASH_temp12376843 = function(ann_DASH_check_DASH_temp216842) {
return ann_DASH_check_DASH_temp216842;
};
var $Hanf_arg12362692 = function(anf_arg192691,add_DASH_error7557) {
var $z68466847 = D;
var $f68526853 = function(_) {
return R.isFunction(add_DASH_error7557.$var)?add_DASH_error7557.$var.app(anf_arg192691):R.ffi.throwNonFunApp(L[484],add_DASH_error7557.$var,[anf_arg192691]);
};
try {
if(--R.GAS > 0) {
$z68466847 = $f68526853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68526853,
"from":L[484]});
}
} catch($e68446845) {
if(R.isCont($e68446845)) {
var $ss68486849 = {"from":L[484],
"go":function(ann_DASH_check_DASH_temp176854) {
return $Hann_DASH_check_DASH_temp12356855(ann_DASH_check_DASH_temp176854);
}};
$e68446845.stack[R.EXN_STACKHEIGHT++] = $ss68486849;
}
if(R.isPyretException($e68446845)) {
$e68446845.pyretStack.push(L[484]);
}
throw $e68446845;
}
var $ret68506851 = $Hann_DASH_check_DASH_temp12356855($z68466847);
++R.GAS;
return $ret68506851;
};
var $Hann_DASH_check_DASH_temp12356855 = function(ann_DASH_check_DASH_temp176854) {
return ann_DASH_check_DASH_temp176854;
};
var $Hanf_arg12342709 = function(anf_arg142707,add_DASH_error7557,anf_fun122708,msg842693) {
var $z68586859 = D;
var $f68646865 = function(_) {
return R.isFunction(anf_fun122708)?anf_fun122708.app(msg842693,anf_arg142707):R.ffi.throwNonFunApp(L[804],anf_fun122708,[msg842693,anf_arg142707]);
};
try {
if(--R.GAS > 0) {
$z68586859 = $f68646865();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68646865,
"from":L[804]});
}
} catch($e68566857) {
if(R.isCont($e68566857)) {
var $ss68606861 = {"from":L[804],
"go":function(anf_arg156866) {
return $Hanf_arg12336867(anf_arg156866,add_DASH_error7557);
}};
$e68566857.stack[R.EXN_STACKHEIGHT++] = $ss68606861;
}
if(R.isPyretException($e68566857)) {
$e68566857.pyretStack.push(L[804]);
}
throw $e68566857;
}
var $ret68626863 = $Hanf_arg12336867($z68586859,add_DASH_error7557);
++R.GAS;
return $ret68626863;
};
var $Hanf_arg12336867 = function(anf_arg156866,add_DASH_error7557) {
var $z68706871 = D;
var $f68766877 = function(_) {
return R.isFunction(add_DASH_error7557.$var)?add_DASH_error7557.$var.app(anf_arg156866):R.ffi.throwNonFunApp(L[487],add_DASH_error7557.$var,[anf_arg156866]);
};
try {
if(--R.GAS > 0) {
$z68706871 = $f68766877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68766877,
"from":L[487]});
}
} catch($e68686869) {
if(R.isCont($e68686869)) {
var $ss68726873 = {"from":L[487],
"go":function(ann_DASH_check_DASH_temp116878) {
return $Hann_DASH_check_DASH_temp12326879(ann_DASH_check_DASH_temp116878);
}};
$e68686869.stack[R.EXN_STACKHEIGHT++] = $ss68726873;
}
if(R.isPyretException($e68686869)) {
$e68686869.pyretStack.push(L[487]);
}
throw $e68686869;
}
var $ret68746875 = $Hann_DASH_check_DASH_temp12326879($z68706871);
++R.GAS;
return $ret68746875;
};
var $Hann_DASH_check_DASH_temp12326879 = function(ann_DASH_check_DASH_temp116878) {
return ann_DASH_check_DASH_temp116878;
};
var $Hanf_arg12312724 = function(anf_arg92723,add_DASH_error7557) {
var $z68826883 = D;
var $f68886889 = function(_) {
return R.isFunction(add_DASH_error7557.$var)?add_DASH_error7557.$var.app(anf_arg92723):R.ffi.throwNonFunApp(L[490],add_DASH_error7557.$var,[anf_arg92723]);
};
try {
if(--R.GAS > 0) {
$z68826883 = $f68886889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68886889,
"from":L[490]});
}
} catch($e68806881) {
if(R.isCont($e68806881)) {
var $ss68846885 = {"from":L[490],
"go":function(ann_DASH_check_DASH_temp76890) {
return $Hann_DASH_check_DASH_temp12306891(ann_DASH_check_DASH_temp76890);
}};
$e68806881.stack[R.EXN_STACKHEIGHT++] = $ss68846885;
}
if(R.isPyretException($e68806881)) {
$e68806881.pyretStack.push(L[490]);
}
throw $e68806881;
}
var $ret68866887 = $Hann_DASH_check_DASH_temp12306891($z68826883);
++R.GAS;
return $ret68866887;
};
var $Hann_DASH_check_DASH_temp12306891 = function(ann_DASH_check_DASH_temp76890) {
return ann_DASH_check_DASH_temp76890;
};
var $Hanf_assign12292738 = function(anf_assign52737,errors6949,nothing4) {
errors6949.$var = anf_assign52737;
var ann_DASH_check_DASH_temp26892 = nothing4;
return ann_DASH_check_DASH_temp26892;
};
var $Hann_DASH_check_DASH_temp12282751 = function(ann_DASH_check_DASH_temp32750) {
return ann_DASH_check_DASH_temp32750;
};
return R.loadModulesNew(NAMESPACE,[$A11332,$SL31433,$C51534,$F71635,$arrays91736,$lists111837,$option131938,$error152039,$sets172140],function($A11332,$SL31433,$C51534,$F71635,$arrays91736,$lists111837,$option131938,$error152039,$sets172140) {
var A113 = R.getField($A11332,"values");
var SL314 = R.getField($SL31433,"values");
var C515 = R.getField($C51534,"values");
var F716 = R.getField($F71635,"values");
var arrays917 = R.getField($arrays91736,"values");
var lists1118 = R.getField($lists111837,"values");
var option1319 = R.getField($option131938,"values");
var error1520 = R.getField($error152039,"values");
var sets1721 = R.getField($sets172140,"values");
var A222 = R.getField($A11332,"types");
var SL423 = R.getField($SL31433,"types");
var C624 = R.getField($C51534,"types");
var F825 = R.getField($F71635,"types");
var arrays1026 = R.getField($arrays91736,"types");
var lists1227 = R.getField($lists111837,"types");
var option1428 = R.getField($option131938,"types");
var error1629 = R.getField($error152039,"types");
var sets1830 = R.getField($sets172140,"types");
return R.safeCall(function() {
var List1943 = R.getDotAnn(L[805],"lists",lists1227,"List");
var Option2045 = R.getDotAnn(L[805],"option",option1428,"Option");
var Array216893 = R.getDotAnn(L[805],"arrays",arrays1026,"Array");
var Set226894 = R.getDotAnn(L[805],"sets",sets1830,"Set");
var array236944 = G(arrays917,"array",L[805]);
var build_DASH_array246943 = G(arrays917,"build-array",L[805]);
var array_DASH_from_DASH_list256942 = G(arrays917,"array-from-list",L[805]);
var is_DASH_array266941 = G(arrays917,"is-array",L[805]);
var list2754 = G(lists1118,"list",L[805]);
var is_DASH_empty2851 = G(lists1118,"is-empty",L[805]);
var is_DASH_link296940 = G(lists1118,"is-link",L[805]);
var empty3048 = G(lists1118,"empty",L[805]);
var link3153 = G(lists1118,"link",L[805]);
var range326939 = G(lists1118,"range",L[805]);
var repeat336938 = G(lists1118,"repeat",L[805]);
var filter346937 = G(lists1118,"filter",L[805]);
var partition356936 = G(lists1118,"partition",L[805]);
var split_DASH_at366935 = G(lists1118,"split-at",L[805]);
var any376934 = G(lists1118,"any",L[805]);
var find386933 = G(lists1118,"find",L[805]);
var map3955 = G(lists1118,"map",L[805]);
var map2406932 = G(lists1118,"map2",L[805]);
var map3416931 = G(lists1118,"map3",L[805]);
var map4426930 = G(lists1118,"map4",L[805]);
var map_n436929 = G(lists1118,"map_n",L[805]);
var map2_n446928 = G(lists1118,"map2_n",L[805]);
var map3_n456927 = G(lists1118,"map3_n",L[805]);
var map4_n466926 = G(lists1118,"map4_n",L[805]);
var each476925 = G(lists1118,"each",L[805]);
var each2486924 = G(lists1118,"each2",L[805]);
var each3496923 = G(lists1118,"each3",L[805]);
var each4506922 = G(lists1118,"each4",L[805]);
var each_n516921 = G(lists1118,"each_n",L[805]);
var each2_n526920 = G(lists1118,"each2_n",L[805]);
var each3_n536919 = G(lists1118,"each3_n",L[805]);
var each4_n546918 = G(lists1118,"each4_n",L[805]);
var fold556917 = G(lists1118,"fold",L[805]);
var fold2566916 = G(lists1118,"fold2",L[805]);
var fold3576915 = G(lists1118,"fold3",L[805]);
var fold4586914 = G(lists1118,"fold4",L[805]);
var index596913 = G(lists1118,"index",L[805]);
var Option606912 = G(option1319,"Option",L[805]);
var is_DASH_none616911 = G(option1319,"is-none",L[805]);
var is_DASH_some626910 = G(option1319,"is-some",L[805]);
var none636909 = G(option1319,"none",L[805]);
var some6456 = G(option1319,"some",L[805]);
var set656908 = G(sets1721,"set",L[805]);
var tree_DASH_set666907 = G(sets1721,"tree-set",L[805]);
var list_DASH_set676906 = G(sets1721,"list-set",L[805]);
var Loc6844 = R.getDotAnn(L[806],"SL",SL423,"Srcloc");
var errors6949 = {"$var":empty3048,
"$name":"errors"};
var in_DASH_check_DASH_block7050 = {"$var":(false),
"$name":"in-check-block"};
var cur_DASH_shared7147 = {"$var":empty3048,
"$name":"cur-shared"};
var PARAM_DASH_current_DASH_where_DASH_everywhere7246 = {"$var":(false),
"$name":"PARAM-current-where-everywhere"};
var is_DASH_s_DASH_let7352 = G(A113,"is-s-let",L[809]);
var anf_fun16905 = G(list2754,"make",L[808]);
var $z68976898 = D;
var $f69036904 = function(_) {
return R.isFunction(anf_fun16905)?anf_fun16905.app([("function"),("break"),("return"),("do"),("yield"),("throw"),("continue"),("while"),("class"),("interface"),("type"),("generator"),("alias"),("extends"),("implements"),("module"),("package"),("namespace"),("use"),("public"),("private"),("protected"),("static"),("const"),("enum"),("super"),("export"),("new"),("try"),("finally"),("debug"),("spy"),("switch"),("this"),("match"),("case"),("with"),("__proto__")]):R.ffi.throwNonFunApp(L[807],anf_fun16905,[[("function"),("break"),("return"),("do"),("yield"),("throw"),("continue"),("while"),("class"),("interface"),("type"),("generator"),("alias"),("extends"),("implements"),("module"),("package"),("namespace"),("use"),("public"),("private"),("protected"),("static"),("const"),("enum"),("super"),("export"),("new"),("try"),("finally"),("debug"),("spy"),("switch"),("this"),("match"),("case"),("with"),("__proto__")]]);
};
try {
if(--R.GAS > 0) {
$z68976898 = $f69036904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69036904,
"from":L[807]});
}
} catch($e68956896) {
if(R.isCont($e68956896)) {
var $ss68996900 = {"from":L[807],
"go":function(reserved_DASH_names7442) {
return $Hreserved_DASH_names169241(reserved_DASH_names7442,A113,A222,C515,C624,List1943,Loc6844,Option2045,PARAM_DASH_current_DASH_where_DASH_everywhere7246,cur_DASH_shared7147,empty3048,errors6949,in_DASH_check_DASH_block7050,is_DASH_empty2851,is_DASH_s_DASH_let7352,link3153,list2754,lists1118,map3955,some6456,_plus1,builtins2,not3,nothing4,print5,raise6,string_DASH_length7,string_DASH_substring8,torepr9,tostring10,$type$Boolean11,$type$String12);
}};
$e68956896.stack[R.EXN_STACKHEIGHT++] = $ss68996900;
}
if(R.isPyretException($e68956896)) {
$e68956896.pyretStack.push(L[807]);
}
throw $e68956896;
}
var $ret69016902 = $Hreserved_DASH_names169241($z68976898,A113,A222,C515,C624,List1943,Loc6844,Option2045,PARAM_DASH_current_DASH_where_DASH_everywhere7246,cur_DASH_shared7147,empty3048,errors6949,in_DASH_check_DASH_block7050,is_DASH_empty2851,is_DASH_s_DASH_let7352,link3153,list2754,lists1118,map3955,some6456,_plus1,builtins2,not3,nothing4,print5,raise6,string_DASH_length7,string_DASH_substring8,torepr9,tostring10,$type$Boolean11,$type$String12);
++R.GAS;
return $ret69016902;
},function(moduleVal) {
R.modules["$src/arr/compiler/well-formed.arr31"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/resolve-scope.arr',["trove/ast",
"trove/srcloc",
"trove/parse-pyret",
"trove/string-dict",
"compiler/compile-structs.arr",
"compiler/ast-util.arr",
"compiler/gensym.arr",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($A11944,$S32045,$PP52146,$SD72247,$C92348,$U112449,$G132550,$arrays152651,$lists172752,$option192853,$error212954,$sets233055) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/resolve-scope.arr43"]) {
return R.modules["$src/arr/compiler/resolve-scope.arr43"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/resolve-scope.arr";
var D = R.undefined;
var L = [[M,13,0,238,786,3,33654],
[M,479,0,18728,786,3,33654],
[M,487,2,19048,487,28,19074],
[M,487,20,19066,487,28,19074],
[M,479,23,18751,479,32,18760],
[M,479,49,18777,479,69,18797],
[M,469,0,18373,477,3,18726],
[M,470,20,18449,470,46,18475],
[M,470,20,18449,470,44,18473],
[M,470,2,18431,476,5,18722],
[M,471,4,18504,475,7,18716],
[M,473,6,18584,474,105,18708],
[M,474,39,18642,474,70,18673],
[M,474,39,18642,474,48,18651],
[M,474,8,18611,474,15,18618],
[M,472,6,18537,472,46,18577],
[M,469,33,18406,469,53,18426],
[M,455,0,17867,467,3,18371],
[M,456,20,17944,456,46,17970],
[M,456,20,17944,456,44,17968],
[M,456,2,17926,462,5,18200],
[M,457,4,18002,461,7,18194],
[M,459,6,18077,460,87,18186],
[M,460,31,18130,460,57,18156],
[M,460,31,18130,460,40,18139],
[M,460,8,18107,460,15,18114],
[M,458,6,18035,458,41,18070],
[M,455,34,17901,455,54,17921],
[M,452,2,17803,452,60,17861],
[M,451,2,17742,451,60,17800],
[M,450,2,17678,450,63,17739],
[M,449,0,17658,453,3,17865],
[M,450,4,17680,450,63,17739],
[M,450,34,17710,450,40,17716],
[M,450,49,17725,450,62,17738],
[M,451,4,17744,451,60,17800],
[M,451,31,17771,451,37,17777],
[M,451,46,17786,451,59,17799],
[M,452,4,17805,452,60,17861],
[M,452,31,17832,452,37,17838],
[M,452,46,17847,452,59,17860],
[M,452,39,17840,452,59,17860],
[M,452,23,17824,452,37,17838],
[M,452,18,17819,452,21,17822],
[M,451,39,17779,451,59,17799],
[M,451,23,17763,451,37,17777],
[M,451,18,17758,451,21,17761],
[M,450,42,17718,450,62,17738],
[M,450,26,17702,450,40,17716],
[M,450,21,17697,450,24,17700],
[M,446,2,17594,446,60,17652],
[M,445,2,17536,445,57,17591],
[M,444,2,17478,444,57,17533],
[M,443,2,17417,443,60,17475],
[M,442,0,17396,447,3,17656],
[M,443,4,17419,443,60,17475],
[M,443,29,17444,443,35,17450],
[M,443,45,17460,443,59,17474],
[M,444,4,17480,444,57,17533],
[M,444,26,17502,444,32,17508],
[M,444,42,17518,444,56,17532],
[M,445,4,17538,445,57,17591],
[M,445,26,17560,445,32,17566],
[M,445,42,17576,445,56,17590],
[M,446,4,17596,446,60,17652],
[M,446,29,17621,446,35,17627],
[M,446,45,17637,446,59,17651],
[M,446,37,17629,446,59,17651],
[M,446,21,17613,446,35,17627],
[M,446,16,17608,446,19,17611],
[M,445,34,17568,445,56,17590],
[M,445,18,17552,445,32,17566],
[M,445,13,17547,445,16,17550],
[M,444,34,17510,444,56,17532],
[M,444,18,17494,444,32,17508],
[M,444,13,17489,444,16,17492],
[M,443,37,17452,443,59,17474],
[M,443,21,17436,443,35,17450],
[M,443,16,17431,443,19,17434],
[M,464,2,18210,466,93,18367],
[M,339,0,13134,437,3,17370],
[M,405,33,16058,405,46,16071],
[M,405,33,16058,405,43,16068],
[M,405,22,16047,405,29,16054],
[M,405,11,16036,405,18,16043],
[M,404,7,15990,404,41,16024],
[M,404,25,16008,404,39,16022],
[M,404,25,16008,404,33,16016],
[M,404,15,15998,404,21,16004],
[M,403,6,15928,403,60,15982],
[M,403,33,15955,403,47,15969],
[M,403,33,15955,403,41,15963],
[M,403,14,15936,403,22,15944],
[M,402,6,15910,402,17,15921],
[M,113,0,3717,304,3,11898],
[M,226,52,8812,226,58,8818],
[M,226,36,8796,226,48,8808],
[M,226,29,8789,227,78,8915],
[M,226,13,8773,226,25,8785],
[M,223,10,8690,223,77,8757],
[M,223,29,8709,223,37,8717],
[M,223,18,8698,223,25,8705],
[M,219,7,8544,221,5,8668],
[M,220,37,8591,220,43,8597],
[M,220,4,8558,220,13,8567],
[M,218,7,8501,218,42,8536],
[M,218,28,8522,218,37,8531],
[M,218,15,8509,218,24,8518],
[M,217,7,8459,217,41,8493],
[M,217,25,8477,217,39,8491],
[M,217,25,8477,217,33,8485],
[M,217,15,8467,217,21,8473],
[M,216,6,8397,216,60,8451],
[M,216,33,8424,216,47,8438],
[M,216,33,8424,216,41,8432],
[M,216,14,8405,216,22,8413],
[M,215,6,8379,215,17,8390],
[M,214,6,8326,214,52,8372],
[M,214,16,8336,214,45,8365],
[M,214,16,8336,214,32,8352],
[M,13,0,238,15,3,352],
[M,465,6,18256,465,23,18273],
[M,465,6,18256,465,18,18268],
[M,464,35,18243,466,5,18279],
[M,464,21,18229,464,34,18242],
[M,466,7,18281,466,15,18289],
[M,464,21,18229,466,16,18290],
[M,464,2,18210,466,17,18291],
[M,464,2,18210,466,26,18300],
[M,464,2,18210,466,21,18295],
[M,466,39,18313,466,65,18339],
[M,466,39,18313,466,48,18322],
[M,466,67,18341,466,86,18360],
[M,466,67,18341,466,81,18355],
[M,466,30,18304,466,93,18367],
[M,405,22,16047,405,58,16083],
[M,405,60,16085,405,68,16093],
[M,405,2,16027,405,69,16094],
[M,408,28,16234,408,47,16253],
[M,408,28,16234,408,44,16250],
[M,408,13,16219,408,24,16230],
[M,407,7,16124,407,88,16205],
[M,407,18,16135,407,57,16174],
[M,407,38,16155,407,56,16173],
[M,406,8,16103,406,21,16116],
[M,406,8,16103,406,15,16110],
[M,408,49,16255,408,74,16280],
[M,408,49,16255,408,71,16277],
[M,408,76,16282,408,84,16290],
[M,409,27,16319,409,34,16326],
[M,409,6,16298,409,23,16315],
[M,413,32,16453,413,38,16459],
[M,413,16,16437,413,28,16449],
[M,412,28,16414,414,15,16492],
[M,412,12,16398,412,24,16410],
[M,411,23,16379,416,11,16575],
[M,411,10,16366,411,19,16375],
[M,410,21,16349,417,9,16586],
[M,410,8,16336,410,17,16345],
[M,413,40,16461,413,54,16475],
[M,413,40,16461,413,47,16468],
[M,413,16,16437,413,55,16476],
[M,415,28,16522,415,41,16535],
[M,415,14,16508,415,24,16518],
[M,415,43,16537,415,50,16544],
[M,415,52,16546,415,59,16553],
[M,415,14,16508,415,68,16562],
[M,412,12,16398,415,69,16563],
[M,411,10,16366,416,12,16576],
[M,410,8,16336,417,10,16587],
[M,409,6,16298,418,7,16595],
[M,408,2,16208,421,0,16703],
[M,421,2,16705,421,74,16777],
[M,421,5,16708,421,61,16764],
[M,421,5,16708,421,21,16724],
[M,421,2,16705,421,62,16765],
[M,423,28,16807,423,47,16826],
[M,423,28,16807,423,44,16823],
[M,423,13,16792,423,24,16803],
[M,423,49,16828,423,74,16853],
[M,423,49,16828,423,71,16850],
[M,424,22,16884,424,53,16915],
[M,424,22,16884,424,37,16899],
[M,424,8,16870,424,18,16880],
[M,423,76,16855,425,7,16942],
[M,424,55,16917,424,71,16933],
[M,424,55,16917,424,63,16925],
[M,424,8,16870,424,72,16934],
[M,426,27,16971,426,34,16978],
[M,426,6,16950,426,23,16967],
[M,430,32,17106,430,38,17112],
[M,430,16,17090,430,28,17102],
[M,429,28,17066,431,15,17145],
[M,429,12,17050,429,24,17062],
[M,428,23,17031,433,11,17251],
[M,428,10,17018,428,19,17027],
[M,427,21,17001,434,9,17262],
[M,427,8,16988,427,17,16997],
[M,430,40,17114,430,54,17128],
[M,430,40,17114,430,47,17121],
[M,430,16,17090,430,55,17129],
[M,432,39,17186,432,46,17193],
[M,432,28,17175,432,35,17182],
[M,432,14,17161,432,24,17171],
[M,432,55,17202,432,62,17209],
[M,432,48,17195,432,63,17210],
[M,432,28,17175,432,64,17211],
[M,432,66,17213,432,73,17220],
[M,432,75,17222,432,82,17229],
[M,432,14,17161,432,91,17238],
[M,429,12,17050,432,92,17239],
[M,428,10,17018,433,12,17252],
[M,427,8,16988,434,10,17263],
[M,426,6,16950,435,7,17271],
[M,423,2,16781,435,8,17272],
[M,436,2,17275,436,93,17366],
[M,436,5,17278,436,80,17353],
[M,436,5,17278,436,21,17294],
[M,436,2,17275,436,81,17354],
[M,407,64,16181,407,83,16200],
[M,407,18,16135,407,63,16180],
[M,403,49,15971,403,58,15980],
[M,226,60,8820,226,74,8834],
[M,226,60,8820,226,67,8827],
[M,226,36,8796,226,75,8835],
[M,227,54,8891,227,60,8897],
[M,227,38,8875,227,50,8887],
[M,227,62,8899,227,76,8913],
[M,227,62,8899,227,69,8906],
[M,227,38,8875,227,77,8914],
[M,228,24,8941,228,31,8948],
[M,226,2,8762,228,32,8949],
[M,229,2,8952,230,15,9069],
[M,229,22,8972,229,42,8992],
[M,229,2,8952,229,70,9020],
[M,229,22,8972,229,48,8998],
[M,229,2,8952,229,103,9053],
[M,229,83,9033,229,102,9052],
[M,229,2,8952,229,82,9032],
[M,229,2,8952,229,76,9026],
[M,232,2,9073,234,56,9306],
[M,232,22,9093,232,46,9117],
[M,232,2,9073,232,74,9145],
[M,232,22,9093,232,52,9123],
[M,232,2,9073,232,107,9178],
[M,232,87,9158,232,106,9177],
[M,232,2,9073,232,86,9157],
[M,232,2,9073,232,80,9151],
[M,233,46,9225,233,52,9231],
[M,233,30,9209,233,42,9221],
[M,233,23,9202,234,46,9296],
[M,233,7,9186,233,19,9198],
[M,233,54,9233,233,68,9247],
[M,233,54,9233,233,61,9240],
[M,233,30,9209,233,69,9248],
[M,234,22,9272,234,28,9278],
[M,234,6,9256,234,18,9268],
[M,234,30,9280,234,44,9294],
[M,234,30,9280,234,37,9287],
[M,234,6,9256,234,45,9295],
[M,234,48,9298,234,55,9305],
[M,233,7,9186,234,56,9306],
[M,236,2,9310,242,13,9633],
[M,236,2,9310,236,35,9343],
[M,237,49,9409,237,55,9415],
[M,237,33,9393,237,45,9405],
[M,237,27,9387,237,72,9432],
[M,237,11,9371,237,23,9383],
[M,237,4,9364,242,12,9632],
[M,236,39,9347,236,48,9356],
[M,237,57,9417,237,70,9430],
[M,237,57,9417,237,64,9424],
[M,237,33,9393,237,71,9431],
[M,239,23,9485,239,34,9496],
[M,239,12,9474,239,19,9481],
[M,238,21,9455,242,9,9629],
[M,238,8,9442,238,17,9451],
[M,239,42,9504,239,55,9517],
[M,239,42,9504,239,49,9511],
[M,239,36,9498,239,56,9518],
[M,239,12,9474,239,57,9519],
[M,240,50,9571,240,56,9577],
[M,240,34,9555,240,46,9567],
[M,240,28,9549,240,74,9595],
[M,240,12,9533,240,24,9545],
[M,240,58,9579,240,72,9593],
[M,240,58,9579,240,65,9586],
[M,240,34,9555,240,73,9594],
[M,241,14,9611,241,21,9618],
[M,240,12,9533,241,22,9619],
[M,238,8,9442,242,10,9630],
[M,237,11,9371,242,11,9631],
[M,236,39,9347,242,13,9633],
[M,244,2,9637,244,48,9683],
[M,245,2,9686,251,6,9914],
[M,247,29,9768,247,35,9774],
[M,247,10,9749,247,25,9764],
[M,246,25,9732,249,9,9867],
[M,246,11,9718,246,21,9728],
[M,246,4,9711,251,5,9913],
[M,245,10,9694,245,19,9703],
[M,247,43,9782,247,56,9795],
[M,247,43,9782,247,50,9789],
[M,247,37,9776,247,57,9796],
[M,247,10,9749,247,58,9797],
[M,248,29,9828,248,35,9834],
[M,248,10,9809,248,25,9824],
[M,248,43,9842,248,56,9855],
[M,248,43,9842,248,50,9849],
[M,248,37,9836,248,57,9856],
[M,248,10,9809,248,58,9857],
[M,250,19,9888,250,26,9895],
[M,250,8,9877,250,15,9884],
[M,250,28,9897,250,36,9905],
[M,250,8,9877,250,37,9906],
[M,246,11,9718,250,38,9907],
[M,245,10,9694,251,6,9914],
[M,256,2,10030,256,84,10112],
[M,254,11,9979,254,58,10026],
[M,254,19,9987,254,31,9999],
[M,254,19,9987,254,29,9997],
[M,253,8,9924,253,51,9967],
[M,253,27,9943,253,38,9954],
[M,253,16,9932,253,23,9939],
[M,257,2,10115,266,13,10516],
[M,258,15,10152,258,28,10165],
[M,258,15,10152,258,22,10159],
[M,258,4,10141,266,12,10515],
[M,257,11,10124,257,20,10133],
[M,258,11,10148,258,29,10166],
[M,260,29,10224,260,35,10230],
[M,260,10,10205,260,25,10220],
[M,259,20,10188,263,9,10383],
[M,259,6,10174,259,16,10184],
[M,260,43,10238,260,56,10251],
[M,260,43,10238,260,50,10245],
[M,260,37,10232,260,57,10252],
[M,260,10,10205,260,58,10253],
[M,261,29,10284,261,35,10290],
[M,261,10,10265,261,25,10280],
[M,261,43,10298,261,56,10311],
[M,261,43,10298,261,50,10305],
[M,261,37,10292,261,57,10312],
[M,261,10,10265,261,58,10313],
[M,262,29,10344,262,35,10350],
[M,262,10,10325,262,25,10340],
[M,262,43,10358,262,56,10371],
[M,262,43,10358,262,50,10365],
[M,262,37,10352,262,57,10372],
[M,262,10,10325,262,58,10373],
[M,265,51,10464,265,57,10470],
[M,265,35,10448,265,47,10460],
[M,265,28,10441,265,74,10487],
[M,265,12,10425,265,24,10437],
[M,264,21,10406,266,9,10512],
[M,264,8,10393,264,17,10402],
[M,265,59,10472,265,72,10485],
[M,265,59,10472,265,66,10479],
[M,265,35,10448,265,73,10486],
[M,265,80,10493,265,87,10500],
[M,265,76,10489,265,88,10501],
[M,265,12,10425,265,89,10502],
[M,264,8,10393,266,10,10513],
[M,259,6,10174,266,11,10514],
[M,257,11,10124,266,13,10516],
[M,268,2,10520,268,81,10599],
[M,268,22,10540,268,35,10553],
[M,268,37,10555,268,45,10563],
[M,268,47,10565,268,55,10573],
[M,268,57,10575,268,65,10583],
[M,268,2,10520,268,66,10584],
[M,268,2,10520,268,72,10590],
[M,269,53,10653,269,61,10661],
[M,269,40,10640,269,51,10651],
[M,269,2,10602,271,5,10751],
[M,270,4,10710,270,39,10745],
[M,269,63,10663,269,71,10671],
[M,269,73,10673,269,81,10681],
[M,269,20,10620,269,82,10682],
[M,269,92,10692,269,103,10703],
[M,273,2,10755,273,40,10793],
[M,274,2,10796,279,6,10928],
[M,276,10,10839,276,17,10846],
[M,275,4,10822,279,5,10927],
[M,274,11,10805,274,20,10814],
[M,276,6,10835,276,18,10847],
[M,277,20,10869,277,36,10885],
[M,277,20,10869,277,28,10877],
[M,277,6,10855,277,16,10865],
[M,277,38,10887,277,51,10900],
[M,277,38,10887,277,45,10894],
[M,277,6,10855,277,52,10901],
[M,278,10,10913,278,17,10920],
[M,278,6,10909,278,18,10921],
[M,274,11,10805,279,6,10928],
[M,281,2,10934,281,45,10977],
[M,282,2,10980,303,0,11894],
[M,284,26,11064,284,32,11070],
[M,284,10,11048,284,22,11060],
[M,283,22,11031,285,9,11097],
[M,283,6,11015,283,18,11027],
[M,282,24,11002,291,12,11299],
[M,282,11,10989,282,20,10998],
[M,284,34,11072,284,48,11086],
[M,284,34,11072,284,41,11079],
[M,284,10,11048,284,49,11087],
[M,288,35,11195,288,41,11201],
[M,288,16,11176,288,31,11191],
[M,287,26,11153,289,15,11240],
[M,287,12,11139,287,22,11149],
[M,286,21,11120,291,9,11296],
[M,286,8,11107,286,17,11116],
[M,288,49,11209,288,62,11222],
[M,288,49,11209,288,56,11216],
[M,288,43,11203,288,63,11223],
[M,288,16,11176,288,64,11224],
[M,290,25,11267,290,32,11274],
[M,290,14,11256,290,21,11263],
[M,290,34,11276,290,42,11284],
[M,290,14,11256,290,43,11285],
[M,287,12,11139,290,44,11286],
[M,286,8,11107,291,10,11297],
[M,283,6,11015,291,11,11298],
[M,282,11,10989,291,13,11300],
[M,270,4,10710,270,33,10739],
[M,270,13,10719,270,32,10738],
[M,270,4,10710,270,12,10718],
[M,254,19,9987,254,42,10010],
[M,254,19,9987,254,38,10006],
[M,254,19,9987,254,51,10019],
[M,253,40,9956,253,49,9965],
[M,223,39,8719,223,47,8727],
[M,223,64,8744,223,69,8749],
[M,223,49,8729,223,58,8738],
[M,220,51,8605,220,59,8613],
[M,220,37,8591,220,49,8603],
[M,220,61,8615,220,69,8623],
[M,220,71,8625,220,79,8633],
[M,220,17,8571,220,80,8634],
[M,220,4,8558,220,81,8635],
[M,220,88,8642,220,107,8661],
[M,220,4,8558,220,87,8641],
[M,216,49,8440,216,58,8449],
[M,214,16,8336,214,51,8371],
[M,488,2,19077,488,29,19104],
[M,488,13,19088,488,27,19102],
[M,489,2,19107,489,34,19139],
[M,489,18,19123,489,32,19137],
[M,563,9,21987,563,40,22018],
[M,562,18,21954,562,39,21975],
[M,548,2,21424,561,5,21935],
[M,549,4,21461,560,7,21929],
[M,559,16,21906,559,24,21914],
[M,550,6,21485,558,11,21889],
[M,551,11,21514,551,30,21533],
[M,551,11,21514,551,27,21530],
[M,531,2,20814,547,5,21421],
[M,532,4,20845,546,7,21415],
[M,545,78,21396,545,88,21406],
[M,544,6,21283,544,40,21317],
[M,544,27,21304,544,33,21310],
[M,533,6,20869,543,11,21276],
[M,534,11,20899,534,25,20913],
[M,534,11,20899,534,22,20910],
[M,523,2,20367,530,5,20811],
[M,524,37,20441,524,47,20451],
[M,524,37,20441,524,45,20449],
[M,524,24,20428,524,36,20440],
[M,509,2,19826,522,5,20364],
[M,510,29,19895,510,39,19905],
[M,510,29,19895,510,37,19903],
[M,510,7,19873,510,28,19894],
[M,491,2,19143,508,5,19823],
[M,492,4,19213,507,7,19817],
[M,506,49,19796,506,61,19808],
[M,502,6,19594,505,32,19746],
[M,503,8,19623,503,45,19660],
[M,503,15,19630,503,30,19645],
[M,493,6,19239,501,48,19587],
[M,494,13,19270,494,50,19307],
[M,494,13,19270,494,24,19281],
[M,564,14,22034,564,44,22064],
[M,785,11,33604,785,33,33626],
[M,785,11,33604,785,18,33611],
[M,783,52,33568,783,67,33583],
[M,783,52,33568,783,61,33577],
[M,783,33,33549,783,42,33558],
[M,783,4,33520,783,72,33588],
[M,775,6,33260,775,49,33303],
[M,775,30,33284,775,43,33297],
[M,774,4,33226,782,7,33514],
[M,773,43,33183,773,58,33198],
[M,773,43,33183,773,52,33192],
[M,773,31,33171,773,39,33179],
[M,773,4,33144,773,80,33220],
[M,772,42,33093,772,57,33108],
[M,772,42,33093,772,51,33102],
[M,772,31,33082,772,38,33089],
[M,772,4,33055,772,87,33138],
[M,771,45,33019,771,70,33044],
[M,771,56,33030,771,69,33043],
[M,771,45,33019,771,55,33029],
[M,771,31,33005,771,41,33015],
[M,771,4,32978,771,75,33049],
[M,770,48,32927,770,71,32950],
[M,770,57,32936,770,70,32949],
[M,770,48,32927,770,56,32935],
[M,770,34,32913,770,44,32923],
[M,770,4,32883,770,93,32972],
[M,769,54,32824,769,77,32847],
[M,769,63,32833,769,76,32846],
[M,769,54,32824,769,62,32832],
[M,769,41,32811,769,50,32820],
[M,769,4,32774,769,107,32877],
[M,768,4,32711,768,61,32768],
[M,768,39,32746,768,52,32759],
[M,767,17,32694,767,24,32701],
[M,767,4,32681,767,28,32705],
[M,766,19,32662,766,28,32671],
[M,766,4,32647,766,32,32675],
[M,759,4,32385,765,7,32641],
[M,760,6,32426,764,9,32633],
[M,763,78,32600,763,87,32609],
[M,761,8,32452,761,58,32502],
[M,761,29,32473,761,37,32481],
[M,752,6,32103,756,9,32328],
[M,752,17,32114,756,9,32328],
[M,753,8,32142,755,63,32318],
[M,754,10,32188,754,76,32254],
[M,754,47,32225,754,55,32233],
[M,751,4,32059,758,7,32379],
[M,750,4,32000,750,57,32053],
[M,750,37,32033,750,45,32041],
[M,749,4,31935,749,63,31994],
[M,749,43,31974,749,51,31982],
[M,748,4,31880,748,53,31929],
[M,748,33,31909,748,41,31917],
[M,732,4,31196,747,7,31874],
[M,733,6,31231,746,9,31866],
[M,745,92,31845,745,102,31855],
[M,743,8,31686,744,45,31752],
[M,744,28,31735,744,44,31751],
[M,744,28,31735,744,38,31745],
[M,744,10,31717,744,20,31727],
[M,734,8,31257,742,13,31677],
[M,735,13,31289,735,32,31308],
[M,735,13,31289,735,29,31305],
[M,735,13,31289,735,21,31297],
[M,719,64,30552,719,72,30560],
[M,719,47,30535,719,55,30543],
[M,719,22,30510,722,9,30735],
[M,720,8,30586,720,78,30656],
[M,720,50,30628,720,57,30635],
[M,720,39,30617,720,48,30626],
[M,720,33,30611,720,37,30615],
[M,718,4,30427,731,7,31190],
[M,705,64,29795,705,72,29803],
[M,705,47,29778,705,55,29786],
[M,705,22,29753,708,9,29978],
[M,706,8,29829,706,78,29899],
[M,706,50,29871,706,57,29878],
[M,706,39,29860,706,48,29869],
[M,706,33,29854,706,37,29858],
[M,704,4,29682,717,7,30421],
[M,685,6,28567,688,9,28818],
[M,685,42,28603,685,55,28616],
[M,685,18,28579,688,9,28818],
[M,686,8,28662,686,85,28739],
[M,686,47,28701,686,54,28708],
[M,684,4,28507,703,7,29676],
[M,674,6,27916,677,9,28168],
[M,674,43,27953,674,56,27966],
[M,674,18,27928,677,9,28168],
[M,675,8,28012,675,85,28089],
[M,675,47,28051,675,54,28058],
[M,673,4,27825,683,7,28501],
[M,661,64,27281,661,72,27289],
[M,661,47,27264,661,55,27272],
[M,661,22,27239,664,9,27464],
[M,662,8,27315,662,78,27385],
[M,662,50,27357,662,57,27364],
[M,662,39,27346,662,48,27355],
[M,662,33,27340,662,37,27344],
[M,660,4,27174,672,7,27819],
[M,647,62,26483,647,70,26491],
[M,647,47,26468,647,55,26476],
[M,647,22,26443,657,9,27036],
[M,648,8,26519,656,11,27026],
[M,649,10,26548,655,61,27014],
[M,650,12,26592,650,88,26668],
[M,650,60,26640,650,67,26647],
[M,650,46,26626,650,58,26638],
[M,650,37,26617,650,44,26624],
[M,646,4,26381,659,7,27168],
[M,629,69,25593,629,77,25601],
[M,629,52,25576,629,60,25584],
[M,629,27,25551,632,9,25785],
[M,630,8,25628,630,86,25706],
[M,630,54,25674,630,61,25681],
[M,630,41,25661,630,52,25672],
[M,630,41,25661,630,44,25664],
[M,630,33,25653,630,39,25659],
[M,630,33,25653,630,36,25656],
[M,628,4,25492,645,7,26375],
[M,602,56,24299,602,64,24307],
[M,602,41,24284,602,49,24292],
[M,602,18,24261,623,9,25333],
[M,603,8,24334,622,11,25323],
[M,613,10,24843,621,13,25311],
[M,614,12,24887,614,86,24961],
[M,614,60,24935,614,65,24940],
[M,614,46,24921,614,58,24933],
[M,614,37,24912,614,44,24919],
[M,604,10,24364,612,13,24832],
[M,605,12,24408,605,86,24482],
[M,605,60,24456,605,65,24461],
[M,605,46,24442,605,58,24454],
[M,605,37,24433,605,44,24440],
[M,601,4,24209,627,7,25486],
[M,582,74,23124,582,82,23132],
[M,582,55,23105,582,68,23118],
[M,582,41,23091,582,49,23099],
[M,582,18,23068,597,9,24063],
[M,583,8,23159,596,11,24053],
[M,589,10,23569,595,79,24041],
[M,590,12,23618,590,89,23695],
[M,590,52,23658,590,58,23664],
[M,584,10,23193,588,70,23558],
[M,585,12,23237,585,87,23312],
[M,585,50,23275,585,56,23281],
[M,581,4,23011,600,7,24203],
[M,566,82,22213,566,90,22221],
[M,566,61,22192,566,74,22205],
[M,566,47,22178,566,55,22186],
[M,566,24,22155,577,9,22815],
[M,567,8,22250,576,11,22805],
[M,568,10,22279,574,85,22769],
[M,569,12,22321,569,76,22385],
[M,569,50,22359,569,55,22364],
[M,565,4,22070,580,7,23005],
[M,776,6,33310,781,9,33506],
[M,779,30,33433,779,59,33462],
[M,779,30,33433,779,51,33454],
[M,777,8,33340,777,52,33384],
[M,777,29,33361,777,36,33368],
[M,779,25,33428,779,73,33476],
[M,780,10,33487,780,19,33496],
[M,773,60,33200,773,75,33215],
[M,773,60,33200,773,69,33209],
[M,772,59,33110,772,82,33133],
[M,772,68,33119,772,81,33132],
[M,772,59,33110,772,67,33118],
[M,770,73,32952,770,88,32967],
[M,770,73,32952,770,82,32961],
[M,769,79,32849,769,94,32864],
[M,769,79,32849,769,88,32858],
[M,763,16,32538,763,101,32623],
[M,763,90,32612,763,100,32622],
[M,757,6,32335,757,24,32353],
[M,755,47,32302,755,62,32317],
[M,755,47,32302,755,56,32311],
[M,755,32,32287,755,45,32300],
[M,755,10,32265,755,18,32273],
[M,745,24,31777,745,103,31856],
[M,736,12,31322,736,34,31344],
[M,736,19,31329,736,31,31341],
[M,736,19,31329,736,27,31337],
[M,741,30,31601,741,46,31617],
[M,741,30,31601,741,40,31611],
[M,741,12,31583,741,22,31593],
[M,737,37,31382,737,53,31398],
[M,737,37,31382,737,47,31392],
[M,737,26,31371,737,35,31380],
[M,737,12,31357,737,22,31367],
[M,737,12,31357,737,54,31399],
[M,741,12,31583,741,47,31618],
[M,719,6,30494,722,9,30735],
[M,723,47,30783,723,76,30812],
[M,723,47,30783,723,74,30810],
[M,723,47,30783,723,66,30802],
[M,723,17,30753,727,9,30975],
[M,724,8,30823,726,11,30965],
[M,725,10,30850,725,113,30953],
[M,725,71,30911,725,112,30952],
[M,725,93,30933,725,110,30950],
[M,725,71,30911,725,81,30921],
[M,725,45,30885,725,53,30893],
[M,723,6,30742,727,9,30975],
[M,728,6,30982,728,58,31034],
[M,728,39,31015,728,56,31032],
[M,728,17,30993,728,27,31003],
[M,729,6,31041,729,37,31072],
[M,729,18,31053,729,29,31064],
[M,730,42,31115,730,82,31155],
[M,730,63,31136,730,80,31153],
[M,730,42,31115,730,51,31124],
[M,730,6,31079,730,22,31095],
[M,721,36,30693,721,66,30723],
[M,721,56,30713,721,65,30722],
[M,721,41,30698,721,54,30711],
[M,721,15,30672,721,27,30684],
[M,705,6,29737,708,9,29978],
[M,709,47,30026,709,76,30055],
[M,709,47,30026,709,74,30053],
[M,709,47,30026,709,66,30045],
[M,709,17,29996,713,9,30218],
[M,710,8,30066,712,11,30208],
[M,711,10,30093,711,113,30196],
[M,711,71,30154,711,112,30195],
[M,711,93,30176,711,110,30193],
[M,711,71,30154,711,81,30164],
[M,711,45,30128,711,53,30136],
[M,709,6,29985,713,9,30218],
[M,714,6,30225,714,58,30277],
[M,714,39,30258,714,56,30275],
[M,714,17,30236,714,27,30246],
[M,715,6,30284,715,37,30315],
[M,715,18,30296,715,29,30307],
[M,716,30,30346,716,70,30386],
[M,716,51,30367,716,68,30384],
[M,716,30,30346,716,39,30355],
[M,716,6,30322,716,16,30332],
[M,707,36,29936,707,66,29966],
[M,707,56,29956,707,65,29965],
[M,707,41,29941,707,54,29954],
[M,707,15,29915,707,27,29927],
[M,690,71,28941,690,79,28949],
[M,690,47,28917,690,62,28932],
[M,690,22,28892,693,9,29124],
[M,691,8,28975,691,78,29045],
[M,691,50,29017,691,57,29024],
[M,691,39,29006,691,48,29015],
[M,691,33,29000,691,37,29004],
[M,689,36,28855,689,49,28868],
[M,690,6,28876,693,9,29124],
[M,694,47,29172,694,76,29201],
[M,694,47,29172,694,74,29199],
[M,694,47,29172,694,66,29191],
[M,694,17,29142,698,9,29344],
[M,695,8,29212,697,11,29334],
[M,696,10,29239,696,93,29322],
[M,696,69,29298,696,92,29321],
[M,696,69,29298,696,79,29308],
[M,696,45,29274,696,53,29282],
[M,694,6,29131,698,9,29344],
[M,700,6,29417,700,49,29460],
[M,700,17,29428,700,27,29438],
[M,699,47,29392,699,64,29409],
[M,701,6,29467,702,0,29565],
[M,701,18,29479,701,36,29497],
[M,702,17,29582,702,42,29607],
[M,702,17,29582,702,40,29605],
[M,702,17,29582,702,32,29597],
[M,702,6,29571,702,13,29578],
[M,702,54,29619,702,76,29641],
[M,702,54,29619,702,63,29628],
[M,692,36,29082,692,66,29112],
[M,692,56,29102,692,65,29111],
[M,692,41,29087,692,54,29100],
[M,692,15,29061,692,27,29073],
[M,687,36,28776,687,66,28806],
[M,687,56,28796,687,65,28805],
[M,687,41,28781,687,54,28794],
[M,687,15,28755,687,27,28767],
[M,679,18,28238,679,47,28267],
[M,679,28,28248,679,36,28256],
[M,678,36,28205,678,49,28218],
[M,680,40,28311,680,65,28336],
[M,680,40,28311,680,63,28334],
[M,680,40,28311,680,55,28326],
[M,680,6,28277,680,19,28290],
[M,679,18,28238,679,50,28270],
[M,681,8,28346,681,40,28378],
[M,681,19,28357,681,39,28377],
[M,681,8,28346,681,18,28356],
[M,681,42,28380,681,76,28414],
[M,681,55,28393,681,75,28413],
[M,681,42,28380,681,54,28392],
[M,682,8,28424,682,48,28464],
[M,682,27,28443,682,47,28463],
[M,682,8,28424,682,26,28442],
[M,682,50,28466,682,76,28492],
[M,682,50,28466,682,68,28484],
[M,676,36,28126,676,66,28156],
[M,676,56,28146,676,65,28155],
[M,676,41,28131,676,54,28144],
[M,676,15,28105,676,27,28117],
[M,661,6,27223,664,9,27464],
[M,665,47,27512,665,76,27541],
[M,665,47,27512,665,74,27539],
[M,665,47,27512,665,66,27531],
[M,665,17,27482,669,9,27700],
[M,666,8,27552,668,11,27690],
[M,667,10,27579,667,109,27678],
[M,667,68,27637,667,108,27677],
[M,667,89,27658,667,106,27675],
[M,667,68,27637,667,77,27646],
[M,667,44,27613,667,52,27621],
[M,665,6,27471,669,9,27700],
[M,670,6,27707,670,58,27759],
[M,670,39,27740,670,56,27757],
[M,670,17,27718,670,27,27728],
[M,671,6,27766,671,22,27782],
[M,663,36,27422,663,66,27452],
[M,663,56,27442,663,65,27451],
[M,663,41,27427,663,54,27440],
[M,663,15,27401,663,27,27413],
[M,647,6,26427,657,9,27036],
[M,658,17,27054,658,33,27070],
[M,658,17,27054,658,27,27064],
[M,658,6,27043,658,13,27050],
[M,658,35,27072,658,62,27099],
[M,658,35,27072,658,60,27097],
[M,658,35,27072,658,52,27089],
[M,658,64,27101,658,79,27116],
[M,658,64,27101,658,73,27110],
[M,658,81,27118,658,122,27159],
[M,658,103,27140,658,120,27157],
[M,658,81,27118,658,91,27128],
[M,651,69,26738,651,104,26773],
[M,651,95,26764,651,102,26771],
[M,651,69,26738,651,83,26752],
[M,651,69,26738,651,77,26746],
[M,651,54,26723,651,67,26736],
[M,651,40,26709,651,52,26721],
[M,651,32,26701,651,38,26707],
[M,651,23,26692,651,31,26700],
[M,651,12,26681,651,105,26774],
[M,652,12,26787,652,54,26829],
[M,652,45,26820,652,52,26827],
[M,652,24,26799,652,33,26808],
[M,653,47,26877,653,62,26892],
[M,653,32,26862,653,45,26875],
[M,653,12,26842,653,63,26893],
[M,654,12,26906,654,58,26952],
[M,654,21,26915,654,33,26927],
[M,655,38,26991,655,59,27012],
[M,655,51,27004,655,58,27011],
[M,655,19,26972,655,31,26984],
[M,629,6,25530,632,9,25785],
[M,634,50,25891,634,84,25925],
[M,634,50,25891,634,82,25923],
[M,634,50,25891,634,74,25915],
[M,634,20,25861,642,9,26279],
[M,635,8,25936,641,11,26269],
[M,636,10,25969,640,53,26257],
[M,637,46,26050,637,96,26100],
[M,637,72,26076,637,94,26098],
[M,637,46,26050,637,60,26064],
[M,637,46,26050,637,54,26058],
[M,637,23,26027,637,31,26035],
[M,633,31,25817,633,53,25839],
[M,634,6,25847,642,9,26279],
[M,643,6,26286,643,42,26322],
[M,643,19,26299,643,29,26309],
[M,644,6,26329,644,16,26339],
[M,637,12,26016,637,97,26101],
[M,638,12,26114,638,48,26150],
[M,638,25,26127,638,35,26137],
[M,639,35,26186,639,51,26202],
[M,639,12,26163,639,52,26203],
[M,640,12,26216,640,27,26231],
[M,631,36,25743,631,66,25773],
[M,631,56,25763,631,65,25772],
[M,631,41,25748,631,54,25761],
[M,631,15,25722,631,27,25734],
[M,602,6,24249,623,9,25333],
[M,624,6,25340,624,42,25376],
[M,624,20,25354,624,40,25374],
[M,624,20,25354,624,32,25366],
[M,625,6,25383,625,54,25431],
[M,625,41,25418,625,52,25429],
[M,625,19,25396,625,29,25406],
[M,626,6,25438,626,18,25450],
[M,615,12,24974,615,54,25016],
[M,615,47,25009,615,52,25014],
[M,615,25,24987,615,35,24997],
[M,616,47,25064,616,63,25080],
[M,616,32,25049,616,45,25062],
[M,616,12,25029,616,64,25081],
[M,617,82,25164,617,115,25197],
[M,617,108,25190,617,113,25195],
[M,617,82,25164,617,96,25178],
[M,617,82,25164,617,90,25172],
[M,617,67,25149,617,80,25162],
[M,617,53,25135,617,65,25147],
[M,617,40,25122,617,48,25130],
[M,617,23,25105,617,35,25117],
[M,617,40,25122,617,116,25198],
[M,617,12,25094,617,129,25211],
[M,620,18,25275,620,40,25297],
[M,620,33,25290,620,39,25296],
[M,619,17,25243,619,29,25255],
[M,606,12,24495,606,54,24537],
[M,606,47,24530,606,52,24535],
[M,606,25,24508,606,35,24518],
[M,607,47,24585,607,63,24601],
[M,607,32,24570,607,45,24583],
[M,607,12,24550,607,64,24602],
[M,608,82,24685,608,115,24718],
[M,608,108,24711,608,113,24716],
[M,608,82,24685,608,96,24699],
[M,608,82,24685,608,90,24693],
[M,608,67,24670,608,80,24683],
[M,608,53,24656,608,65,24668],
[M,608,40,24643,608,48,24651],
[M,608,23,24626,608,35,24638],
[M,608,40,24643,608,116,24719],
[M,608,12,24615,608,129,24732],
[M,611,18,24796,611,40,24818],
[M,611,33,24811,611,39,24817],
[M,610,17,24764,610,29,24776],
[M,582,6,23056,597,9,24063],
[M,598,6,24070,598,78,24142],
[M,598,64,24128,598,76,24140],
[M,598,41,24105,598,52,24116],
[M,598,19,24083,598,29,24093],
[M,599,27,24170,599,39,24182],
[M,599,6,24149,599,23,24166],
[M,591,12,23708,591,77,23773],
[M,591,51,23747,591,56,23752],
[M,592,12,23786,592,75,23849],
[M,592,61,23835,592,74,23848],
[M,592,44,23818,592,59,23833],
[M,592,23,23797,592,39,23813],
[M,593,12,23862,593,52,23902],
[M,593,32,23882,593,45,23895],
[M,594,12,23915,594,58,23961],
[M,594,36,23939,594,51,23954],
[M,595,55,24017,595,77,24039],
[M,595,70,24032,595,76,24038],
[M,595,35,23997,595,49,24011],
[M,595,17,23979,595,29,23991],
[M,586,56,23369,586,102,23415],
[M,586,94,23407,586,100,23413],
[M,586,77,23390,586,82,23395],
[M,586,56,23369,586,65,23378],
[M,586,41,23354,586,54,23367],
[M,586,23,23336,586,36,23349],
[M,586,12,23325,586,103,23416],
[M,587,51,23468,587,69,23486],
[M,587,56,23473,587,68,23485],
[M,587,36,23453,587,49,23466],
[M,587,12,23429,587,70,23487],
[M,588,46,23534,588,68,23556],
[M,588,61,23549,588,67,23555],
[M,588,28,23516,588,40,23528],
[M,588,17,23505,588,22,23510],
[M,566,6,22137,577,9,22815],
[M,578,6,22822,578,90,22906],
[M,578,70,22886,578,88,22904],
[M,578,41,22857,578,58,22874],
[M,578,19,22835,578,29,22845],
[M,579,47,22954,579,77,22984],
[M,579,47,22954,579,75,22982],
[M,579,47,22954,579,67,22974],
[M,579,6,22913,579,17,22924],
[M,570,12,22398,570,89,22475],
[M,570,52,22438,570,58,22444],
[M,571,12,22488,571,83,22559],
[M,571,67,22543,571,82,22558],
[M,571,52,22528,571,65,22541],
[M,571,25,22501,571,41,22517],
[M,572,47,22607,572,63,22623],
[M,572,32,22592,572,45,22605],
[M,572,12,22572,572,64,22624],
[M,573,12,22637,573,58,22683],
[M,573,36,22661,573,51,22676],
[M,574,57,22741,574,83,22767],
[M,574,74,22758,574,82,22766],
[M,574,35,22719,574,49,22733],
[M,574,17,22701,574,29,22713],
[M,552,10,21545,556,13,21827],
[M,552,29,21564,552,41,21576],
[M,557,26,21854,557,48,21876],
[M,557,26,21854,557,45,21873],
[M,557,14,21842,557,22,21850],
[M,555,12,21718,556,0,21814],
[M,555,43,21749,555,52,21758],
[M,554,12,21657,554,60,21705],
[M,554,43,21688,554,51,21696],
[M,553,12,21593,553,63,21644],
[M,553,46,21627,553,54,21635],
[M,557,14,21842,557,49,21877],
[M,545,22,21340,545,89,21407],
[M,535,10,20925,540,13,21211],
[M,535,31,20946,535,38,20953],
[M,542,20,21246,542,37,21263],
[M,542,20,21246,542,34,21260],
[M,542,10,21236,542,16,21242],
[M,539,12,21153,539,56,21197],
[M,539,41,21182,539,47,21188],
[M,538,12,21095,538,57,21140],
[M,538,38,21121,538,48,21131],
[M,537,12,21024,537,70,21082],
[M,537,41,21053,537,54,21066],
[M,536,12,20970,536,53,21011],
[M,536,38,20996,536,44,21002],
[M,542,10,21236,542,38,21264],
[M,524,4,20408,529,7,20805],
[M,528,6,20715,528,88,20797],
[M,528,47,20756,528,57,20766],
[M,528,47,20756,528,55,20764],
[M,528,34,20743,528,46,20755],
[M,527,6,20632,527,82,20708],
[M,527,44,20670,527,54,20680],
[M,527,44,20670,527,52,20678],
[M,527,31,20657,527,43,20669],
[M,526,6,20549,526,82,20625],
[M,526,44,20587,526,54,20597],
[M,526,44,20587,526,52,20595],
[M,526,31,20574,526,43,20586],
[M,525,6,20460,525,88,20542],
[M,525,47,20501,525,57,20511],
[M,525,47,20501,525,55,20509],
[M,525,34,20488,525,46,20500],
[M,528,59,20768,528,87,20796],
[M,527,56,20682,527,81,20707],
[M,526,56,20599,526,81,20624],
[M,525,59,20513,525,87,20541],
[M,510,7,19873,510,40,19906],
[M,511,43,19951,511,53,19961],
[M,511,43,19951,511,51,19959],
[M,511,25,19933,511,42,19950],
[M,520,32,20337,520,44,20349],
[M,511,6,19914,518,9,20294],
[M,516,8,20188,517,68,20284],
[M,517,28,20244,517,38,20254],
[M,517,28,20244,517,36,20252],
[M,517,10,20226,517,27,20243],
[M,514,8,20077,515,71,20179],
[M,515,28,20136,515,38,20146],
[M,515,28,20136,515,36,20144],
[M,515,10,20118,515,27,20135],
[M,512,8,19972,513,68,20068],
[M,513,28,20028,513,38,20038],
[M,513,28,20028,513,36,20036],
[M,513,10,20010,513,27,20027],
[M,517,40,20256,517,67,20283],
[M,515,40,20148,515,70,20178],
[M,513,40,20040,513,67,20067],
[M,520,12,20317,520,45,20350],
[M,520,6,20311,520,45,20350],
[M,506,22,19769,506,62,19809],
[M,504,21,19682,504,31,19692],
[M,504,21,19682,504,29,19690],
[M,504,8,19669,504,20,19681],
[M,504,33,19694,504,51,19712],
[M,504,8,19669,504,52,19713],
[M,494,13,19270,494,27,19284],
[M,495,20,19328,495,30,19338],
[M,495,20,19328,495,27,19335],
[M,494,8,19265,497,11,19425],
[M,498,8,19434,498,33,19459],
[M,498,15,19441,498,30,19456],
[M,494,32,19289,494,49,19306],
[M,496,30,19373,496,56,19399],
[M,496,30,19373,496,41,19384],
[M,495,20,19328,495,34,19342],
[M,496,25,19368,496,70,19413],
[M,499,8,19468,499,36,19496],
[M,500,21,19518,500,31,19528],
[M,500,21,19518,500,29,19526],
[M,500,8,19505,500,20,19517],
[M,500,8,19505,500,41,19538],
[M,501,27,19566,501,46,19585],
[M,501,27,19566,501,34,19573],
[M,470,55,18484,470,68,18497],
[M,474,72,18675,474,97,18700],
[M,474,72,18675,474,91,18694],
[M,474,22,18625,474,104,18707],
[M,456,55,17979,456,71,17995],
[M,460,59,18158,460,79,18178],
[M,460,59,18158,460,73,18172],
[M,460,22,18121,460,86,18185],
[M,356,13,13853,360,9,14065],
[M,355,12,13826,355,25,13839],
[M,355,12,13826,355,19,13833],
[M,354,19,13792,354,40,13813],
[M,353,16,13748,353,40,13772],
[M,356,6,13846,360,9,14065],
[M,358,8,13967,358,38,13997],
[M,357,8,13915,357,51,13958],
[M,357,42,13949,357,50,13957],
[M,357,31,13938,357,38,13945],
[M,361,6,14072,361,62,14128],
[M,362,6,14135,368,0,14400],
[M,362,14,14143,366,9,14350],
[M,365,64,14323,365,80,14339],
[M,364,8,14224,364,42,14258],
[M,363,8,14178,363,45,14215],
[M,363,37,14207,363,45,14215],
[M,368,6,14406,372,9,14632],
[M,368,21,14421,372,9,14632],
[M,371,67,14608,371,79,14620],
[M,371,18,14559,371,27,14568],
[M,369,8,14449,370,67,14540],
[M,370,37,14510,370,66,14539],
[M,370,10,14483,370,19,14492],
[M,376,6,14796,391,9,15507],
[M,376,22,14812,391,9,15507],
[M,377,8,14848,389,13,15459],
[M,378,10,14882,378,29,14901],
[M,378,17,14889,378,27,14899],
[M,373,6,14639,375,9,14789],
[M,374,66,14744,374,80,14758],
[M,374,66,14744,374,76,14754],
[M,374,54,14732,374,61,14739],
[M,374,42,14720,374,49,14727],
[M,374,8,14686,374,18,14696],
[M,392,6,15514,392,63,15571],
[M,393,46,15618,393,95,15667],
[M,393,74,15646,393,94,15666],
[M,393,46,15618,393,73,15645],
[M,393,46,15618,393,66,15638],
[M,393,31,15603,395,11,15757],
[M,394,24,15706,394,46,15728],
[M,394,24,15706,394,40,15722],
[M,394,10,15692,394,20,15702],
[M,393,46,15618,393,107,15679],
[M,393,100,15672,393,106,15678],
[M,393,46,15618,393,99,15671],
[M,393,6,15578,395,11,15757],
[M,397,21,15780,397,40,15799],
[M,397,21,15780,397,37,15796],
[M,397,6,15765,397,17,15776],
[M,397,42,15801,397,67,15826],
[M,397,42,15801,397,64,15823],
[M,398,22,15850,398,58,15886],
[M,398,22,15850,398,35,15863],
[M,351,4,13608,398,59,15887],
[M,394,48,15730,394,62,15744],
[M,394,48,15730,394,56,15738],
[M,379,10,14912,389,13,15459],
[M,388,39,15381,388,53,15395],
[M,388,39,15381,388,51,15393],
[M,388,28,15370,388,38,15380],
[M,388,14,15356,388,23,15365],
[M,380,12,14944,386,77,15319],
[M,381,14,14997,381,45,15028],
[M,381,27,15010,381,43,15026],
[M,381,27,15010,381,38,15021],
[M,388,39,15381,388,58,15400],
[M,388,28,15370,388,58,15400],
[M,388,68,15410,388,101,15443],
[M,388,61,15403,388,102,15444],
[M,388,28,15370,388,103,15445],
[M,383,27,15084,383,41,15098],
[M,383,27,15084,383,39,15096],
[M,383,16,15073,383,26,15083],
[M,382,14,15043,382,23,15052],
[M,383,27,15084,383,46,15103],
[M,383,16,15073,383,46,15103],
[M,385,56,15216,385,76,15236],
[M,385,56,15216,385,74,15234],
[M,385,56,15216,385,67,15227],
[M,385,39,15199,385,55,15215],
[M,385,39,15199,385,50,15210],
[M,385,30,15190,385,37,15197],
[M,385,20,15180,385,29,15189],
[M,384,18,15131,384,35,15148],
[M,383,49,15106,386,76,15318],
[M,385,56,15216,385,81,15241],
[M,385,39,15199,385,81,15241],
[M,386,33,15275,386,72,15314],
[M,386,26,15268,386,73,15315],
[M,385,39,15199,386,74,15316],
[M,385,20,15180,386,74,15316],
[M,384,18,15131,386,75,15317],
[M,383,16,15073,386,77,15319],
[M,374,54,14732,374,92,14770],
[M,374,42,14720,374,100,14778],
[M,371,44,14585,371,80,14621],
[M,371,31,14572,371,81,14622],
[M,370,24,14497,370,67,14540],
[M,365,24,14283,365,81,14340],
[M,315,6,12238,324,11,12663],
[M,325,37,12701,325,45,12709],
[M,325,19,12683,334,9,13043],
[M,326,8,12737,333,11,13033],
[M,328,10,12809,332,17,13021],
[M,330,14,12883,332,17,13021],
[M,331,33,12946,331,51,12964],
[M,331,33,12946,331,41,12954],
[M,331,16,12929,331,29,12942],
[M,327,10,12778,327,30,12798],
[M,325,6,12670,334,9,13043],
[M,335,64,13108,335,76,13120],
[M,335,39,13083,335,48,13092],
[M,335,6,13050,335,23,13067],
[M,335,52,13096,335,77,13121],
[M,335,39,13083,335,77,13121],
[M,314,4,12187,335,78,13122],
[M,331,64,12977,331,81,12994],
[M,331,64,12977,331,72,12985],
[M,331,53,12966,331,60,12973],
[M,331,53,12966,331,89,13002],
[M,317,12,12353,321,19,12611],
[M,320,29,12486,320,77,12534],
[M,320,67,12524,320,76,12533],
[M,320,100,12557,320,118,12575],
[M,320,100,12557,320,108,12565],
[M,320,90,12547,320,96,12553],
[M,320,79,12536,320,86,12543],
[M,320,90,12547,320,119,12576],
[M,320,79,12536,320,126,12583],
[M,319,16,12428,321,19,12611],
[M,308,63,12038,308,71,12046],
[M,308,73,12048,308,81,12056],
[M,308,83,12058,308,91,12066],
[M,308,17,11992,308,92,12067],
[M,307,2,11950,309,5,12074],
[M,139,31,4761,139,40,4770],
[M,140,8,4779,140,51,4822],
[M,139,11,4741,139,29,4759],
[M,117,4,3903,211,9,8306],
[M,144,6,4922,211,9,8306],
[M,201,10,7832,210,13,8296],
[M,203,12,7910,209,17,8282],
[M,204,21,7947,204,92,8018],
[M,202,12,7868,202,41,7897],
[M,202,30,7886,202,40,7896],
[M,202,23,7879,202,41,7897],
[M,198,8,7691,199,82,7803],
[M,173,8,6251,197,13,7682],
[M,184,10,6798,184,37,6825],
[M,184,20,6808,184,31,6819],
[M,175,10,6422,183,13,6787],
[M,177,12,6497,177,53,6538],
[M,177,27,6512,177,46,6531],
[M,176,20,6478,176,26,6484],
[M,174,10,6336,174,85,6411],
[M,174,57,6383,174,72,6398],
[M,174,57,6383,174,65,6391],
[M,174,36,6362,174,44,6370],
[M,174,27,6353,174,33,6359],
[M,159,8,5604,172,13,6242],
[M,162,33,5758,162,50,5775],
[M,162,33,5758,162,41,5766],
[M,162,14,5739,162,22,5747],
[M,160,29,5691,160,44,5706],
[M,157,8,5512,158,57,5595],
[M,158,29,5567,158,56,5594],
[M,158,29,5567,158,41,5579],
[M,155,8,5417,156,57,5503],
[M,156,29,5475,156,56,5502],
[M,156,29,5475,156,41,5487],
[M,145,8,4947,154,13,5408],
[M,146,31,5004,146,58,5031],
[M,146,31,5004,146,44,5017],
[M,140,39,4810,140,51,4822],
[M,141,8,4831,141,55,4878],
[M,140,16,4787,140,37,4808],
[M,141,41,4864,141,55,4878],
[M,142,14,4893,142,24,4903],
[M,141,16,4839,141,39,4862],
[M,204,21,7947,204,39,7965],
[M,204,17,7943,204,92,8018],
[M,204,43,7969,204,64,7990],
[M,204,68,7994,204,91,8017],
[M,205,56,8076,205,64,8084],
[M,208,58,8231,208,66,8239],
[M,207,41,8168,207,44,8171],
[M,207,31,8158,207,40,8167],
[M,207,16,8143,208,91,8264],
[M,205,66,8086,205,74,8094],
[M,205,76,8096,205,84,8104],
[M,205,24,8044,205,85,8105],
[M,205,16,8036,205,86,8106],
[M,208,68,8241,208,76,8249],
[M,208,78,8251,208,86,8259],
[M,208,26,8199,208,87,8260],
[M,208,18,8191,208,88,8261],
[M,207,31,8158,208,89,8262],
[M,207,23,8150,208,90,8263],
[M,185,10,6836,185,93,6919],
[M,185,22,6848,185,35,6861],
[M,186,41,6961,186,54,6974],
[M,186,22,6942,186,37,6957],
[M,186,10,6930,186,66,6986],
[M,187,51,7038,187,76,7063],
[M,187,51,7038,187,70,7057],
[M,187,27,7014,187,42,7029],
[M,187,46,7033,187,77,7064],
[M,187,100,7087,187,120,7107],
[M,187,100,7087,187,108,7095],
[M,187,90,7077,187,96,7083],
[M,187,79,7066,187,86,7073],
[M,187,90,7077,187,121,7108],
[M,187,79,7066,187,128,7115],
[M,187,10,6997,187,129,7116],
[M,188,47,7164,188,57,7174],
[M,188,28,7145,188,43,7160],
[M,188,80,7197,188,100,7217],
[M,188,80,7197,188,88,7205],
[M,188,70,7187,188,76,7193],
[M,188,59,7176,188,66,7183],
[M,188,70,7187,188,101,7218],
[M,188,59,7176,188,108,7225],
[M,188,10,7127,188,109,7226],
[M,189,40,7267,189,90,7317],
[M,189,22,7249,191,13,7418],
[M,190,36,7373,190,56,7393],
[M,190,36,7373,190,44,7381],
[M,190,26,7363,190,32,7369],
[M,189,10,7237,191,13,7418],
[M,193,13,7433,193,35,7455],
[M,194,72,7529,194,80,7537],
[M,194,27,7484,194,36,7493],
[M,194,12,7469,194,105,7562],
[M,196,44,7623,196,52,7631],
[M,194,93,7550,194,101,7558],
[M,194,40,7497,194,102,7559],
[M,194,27,7484,194,103,7560],
[M,194,19,7476,194,104,7561],
[M,196,54,7633,196,79,7658],
[M,196,80,7659,196,88,7667],
[M,196,12,7591,196,89,7668],
[M,190,26,7363,190,57,7394],
[M,190,12,7349,190,61,7398],
[M,180,35,6646,180,48,6659],
[M,180,37,6648,180,40,6651],
[M,180,30,6641,180,33,6644],
[M,180,14,6625,180,29,6640],
[M,179,12,6604,182,13,6773],
[M,178,23,6562,178,52,6591],
[M,178,31,6570,178,34,6573],
[M,178,23,6562,178,30,6569],
[M,180,50,6661,180,65,6676],
[M,180,14,6625,180,66,6677],
[M,181,35,6714,181,55,6734],
[M,181,37,6716,181,40,6719],
[M,181,30,6709,181,33,6712],
[M,181,14,6693,181,29,6708],
[M,181,57,6736,181,79,6758],
[M,181,14,6693,181,80,6759],
[M,174,74,6400,174,83,6409],
[M,162,14,5739,162,62,5787],
[M,162,52,5777,162,61,5786],
[M,163,14,5803,163,62,5851],
[M,163,14,5803,163,21,5810],
[M,160,29,5691,164,13,5865],
[M,160,10,5672,164,28,5880],
[M,165,59,5940,165,67,5948],
[M,165,82,5963,165,90,5971],
[M,165,10,5891,165,91,5972],
[M,166,17,5990,166,36,6009],
[M,166,13,5986,166,37,6010],
[M,167,29,6041,167,57,6069],
[M,167,29,6041,167,38,6050],
[M,167,12,6024,167,59,6071],
[M,168,22,6094,168,46,6118],
[M,167,19,6031,167,58,6070],
[M,168,10,6082,169,64,6185],
[M,169,34,6155,169,62,6183],
[M,169,34,6155,169,43,6164],
[M,169,12,6133,169,64,6185],
[M,171,12,6214,171,26,6228],
[M,168,18,6090,168,47,6119],
[M,169,19,6140,169,63,6184],
[M,146,10,4983,146,75,5048],
[M,147,59,5108,147,67,5116],
[M,147,69,5118,147,77,5126],
[M,147,10,5059,147,93,5142],
[M,148,17,5160,148,36,5179],
[M,148,13,5156,148,37,5180],
[M,149,29,5211,149,57,5239],
[M,149,29,5211,149,38,5220],
[M,149,12,5194,149,59,5241],
[M,150,22,5264,150,44,5286],
[M,149,19,5201,149,58,5240],
[M,150,10,5252,151,62,5351],
[M,151,32,5321,151,60,5349],
[M,151,32,5321,151,41,5330],
[M,151,12,5301,151,62,5351],
[M,153,12,5380,153,26,5394],
[M,150,18,5260,150,45,5287],
[M,151,19,5308,151,61,5350],
[M,129,68,4421,129,76,4429],
[M,129,78,4431,129,86,4439],
[M,129,8,4361,129,87,4440],
[M,130,15,4456,130,37,4478],
[M,130,11,4452,130,38,4479],
[M,131,30,4511,131,58,4539],
[M,131,30,4511,131,39,4520],
[M,131,10,4491,131,60,4541],
[M,132,20,4562,132,44,4586],
[M,131,17,4498,131,59,4540],
[M,132,8,4550,133,62,4651],
[M,133,32,4621,133,60,4649],
[M,133,32,4621,133,41,4630],
[M,133,10,4599,133,62,4651],
[M,135,10,4676,135,24,4690],
[M,132,16,4558,132,45,4587],
[M,133,17,4606,133,61,4650],
[M,124,6,4149,126,9,4266],
[M,121,6,4045,123,9,4142],
[M,118,6,3934,120,9,4038],
[M,84,11,2664,84,45,2698],
[M,84,11,2664,84,25,2678],
[M,84,2,2655,86,5,2768],
[M,84,29,2682,84,44,2697],
[M,85,48,2748,85,61,2761],
[M,84,7,2660,84,45,2698],
[M,89,2,2824,102,5,3473],
[M,90,4,2858,101,7,3467],
[M,100,21,3441,100,39,3459],
[M,95,6,3071,98,122,3403],
[M,96,28,3162,96,39,3173],
[M,96,16,3150,96,27,3161],
[M,93,6,2953,94,80,3064],
[M,94,31,3015,94,63,3047],
[M,94,31,3015,94,47,3031],
[M,91,6,2881,92,39,2946],
[M,92,21,2928,92,39,2946],
[M,89,6,2828,89,16,2838],
[M,85,10,2710,85,62,2762],
[M,85,4,2704,85,62,2762],
[M,103,5,3479,103,29,3503],
[M,104,4,3509,104,9,3514],
[M,106,4,3527,106,41,3564],
[M,106,17,3540,106,39,3562],
[M,78,37,2435,78,49,2447],
[M,107,4,3569,107,35,3600],
[M,107,16,3581,107,33,3598],
[M,108,61,3662,108,101,3702],
[M,108,71,3672,108,89,3690],
[M,108,71,3672,108,87,3688],
[M,108,61,3662,108,70,3671],
[M,108,29,3630,108,47,3648],
[M,108,29,3630,108,45,3646],
[M,108,11,3612,108,28,3629],
[M,108,4,3605,108,103,3704],
[M,108,11,3612,108,102,3703],
[M,96,8,3142,96,39,3173],
[M,97,51,3225,97,68,3242],
[M,97,51,3225,97,59,3233],
[M,97,31,3205,97,47,3221],
[M,97,70,3244,97,88,3262],
[M,97,70,3244,97,78,3252],
[M,97,31,3205,97,89,3263],
[M,97,26,3200,97,106,3280],
[M,98,49,3330,98,67,3348],
[M,98,49,3330,98,57,3338],
[M,98,26,3307,98,39,3320],
[M,98,26,3307,98,110,3391],
[M,98,21,3302,98,122,3403],
[M,94,26,3010,94,80,3064],
[M,60,52,1626,60,60,1634],
[M,60,2,1576,74,5,2329],
[M,75,13,2343,75,34,2364],
[M,75,13,2343,75,32,2362],
[M,75,13,2343,75,24,2354],
[M,75,42,2372,75,60,2390],
[M,75,42,2372,75,58,2388],
[M,75,42,2372,75,50,2380],
[M,66,47,1911,66,54,1918],
[M,66,61,1925,66,73,1937],
[M,66,21,1885,66,45,1909],
[M,67,35,1977,67,55,1997],
[M,67,35,1977,67,46,1988],
[M,67,28,1970,67,33,1975],
[M,67,19,1961,67,27,1969],
[M,67,8,1950,67,56,1998],
[M,68,30,2029,68,54,2053],
[M,68,16,2015,68,26,2025],
[M,68,8,2007,68,65,2064],
[M,69,34,2099,69,50,2115],
[M,69,34,2099,69,48,2113],
[M,69,19,2084,71,11,2240],
[M,70,23,2141,70,55,2173],
[M,70,45,2163,70,54,2172],
[M,70,23,2141,70,31,2149],
[M,70,18,2136,70,21,2139],
[M,70,10,2128,70,17,2135],
[M,69,8,2073,71,11,2240],
[M,72,22,2263,72,46,2287],
[M,72,34,2275,72,45,2286],
[M,72,54,2295,72,74,2315],
[M,72,65,2306,72,73,2314],
[M,70,68,2186,70,87,2205],
[M,70,68,2186,70,74,2192],
[M,70,57,2175,70,64,2182],
[M,70,89,2207,70,101,2219],
[M,70,89,2207,70,99,2217],
[M,70,57,2175,70,102,2220],
[M,63,8,1719,63,61,1772],
[M,64,22,1795,64,46,1819],
[M,64,34,1807,64,45,1818],
[M,54,39,1462,54,42,1465],
[M,55,33,1499,55,45,1511],
[M,55,14,1480,55,29,1495],
[M,54,11,1434,54,37,1460],
[M,55,14,1480,55,45,1511],
[M,38,6,964,44,9,1196],
[M,38,20,978,44,9,1196],
[M,40,23,1058,40,39,1074],
[M,40,23,1058,40,37,1072],
[M,40,23,1058,40,30,1065],
[M,40,10,1045,40,19,1054],
[M,42,23,1135,42,39,1151],
[M,42,23,1135,42,37,1149],
[M,42,23,1135,42,30,1142],
[M,42,10,1122,42,19,1131],
[M,39,11,1011,39,34,1034],
[M,39,11,1011,39,23,1023],
[M,36,4,898,45,39,1236],
[M,45,6,1203,45,23,1220],
[M,40,41,1076,40,61,1096],
[M,40,53,1088,40,60,1095],
[M,40,41,1076,40,49,1084],
[M,40,10,1045,40,62,1097],
[M,42,41,1153,42,61,1173],
[M,42,53,1165,42,60,1172],
[M,42,41,1153,42,49,1161],
[M,42,10,1122,42,62,1174],
[M,28,23,668,28,107,752],
[M,28,74,719,28,86,731],
[M,28,63,708,28,70,715],
[M,28,45,690,28,59,704],
[M,28,12,657,28,19,664],
[M,28,6,651,28,108,753],
[M,26,4,596,29,25,779],
[M,29,6,760,29,17,771],
[M,28,63,708,28,87,732],
[M,28,89,734,28,102,747],
[M,28,89,734,28,95,740],
[M,21,17,475,21,32,490],
[M,21,40,498,21,54,512],
[M,21,40,498,21,46,504],
[M,14,2,261,14,89,348],
[M,3,0,13,786,3,33654],
[M,440,0,17373,440,21,17394],
[M,440,8,17381,440,18,17391],
[M,350,2,13581,399,5,15893],
[M,352,6,13684,352,53,13731],
[M,339,26,13160,339,35,13169],
[M,339,51,13185,339,71,13205],
[M,312,0,12078,337,3,13132],
[M,313,2,12150,336,5,13128],
[M,315,36,12268,315,44,12276],
[M,315,18,12250,324,11,12663],
[M,316,10,12314,323,13,12651],
[M,320,48,12505,320,65,12522],
[M,320,48,12505,320,56,12513],
[M,320,29,12486,320,37,12494],
[M,320,18,12475,320,25,12482],
[M,312,32,12110,312,38,12116],
[M,312,47,12125,312,67,12145],
[M,308,37,12012,308,61,12036],
[M,308,47,12022,308,60,12035],
[M,308,37,12012,308,46,12021],
[M,308,4,11979,308,13,11988],
[M,306,24,11924,306,45,11945],
[M,115,2,3859,212,5,8312],
[M,127,6,4273,137,9,4712],
[M,128,8,4315,128,45,4352],
[M,125,50,4225,125,74,4249],
[M,125,50,4225,125,72,4247],
[M,125,26,4201,125,48,4223],
[M,125,26,4201,125,46,4221],
[M,125,8,4183,125,25,4200],
[M,122,40,4106,122,59,4125],
[M,122,40,4106,122,57,4123],
[M,122,21,4087,122,38,4104],
[M,122,21,4087,122,36,4102],
[M,122,8,4074,122,20,4086],
[M,119,41,3999,119,63,4021],
[M,119,41,3999,119,61,4019],
[M,119,19,3977,119,39,3997],
[M,119,19,3977,119,37,3995],
[M,119,8,3966,119,18,3976],
[M,116,4,3882,116,20,3898],
[M,78,0,2398,110,3,3714],
[M,50,0,1264,76,3,2396],
[M,60,36,1610,60,44,1618],
[M,60,8,1582,74,5,2329],
[M,61,4,1658,73,7,2323],
[M,65,6,1827,72,74,2315],
[M,66,21,1885,66,40,1904],
[M,62,6,1683,64,47,1820],
[M,63,30,1741,63,54,1765],
[M,63,16,1727,63,26,1737],
[M,51,2,1314,59,5,1573],
[M,52,4,1364,58,7,1567],
[M,57,6,1530,57,35,1559],
[M,53,6,1395,56,11,1523],
[M,51,33,1345,51,45,1357],
[M,50,31,1295,50,45,1309],
[M,34,0,807,48,3,1262],
[M,35,2,869,47,5,1258],
[M,37,6,932,37,31,957],
[M,37,12,938,37,28,954],
[M,34,30,837,34,44,851],
[M,34,51,858,34,57,864],
[M,24,0,520,32,3,805],
[M,25,2,572,31,5,801],
[M,27,6,624,27,26,644],
[M,27,12,630,27,23,641],
[M,24,25,545,24,34,554],
[M,24,41,561,24,47,567],
[M,19,0,410,22,3,518],
[M,20,2,434,20,25,457],
[M,20,6,438,20,14,446],
[M,17,0,354,17,54,408],
[M,17,43,397,17,52,406],
[M,17,20,374,17,28,382],
[M,14,4,263,14,89,348],
[M,14,20,279,14,29,288],
[M,14,75,334,14,88,347],
[M,14,41,300,14,61,320],
[M,14,63,322,14,88,347],
[M,14,31,290,14,61,320],
[M,14,13,272,14,29,288]];
var _minus8 = NAMESPACE.get("_minus");
var _plus9 = NAMESPACE.get("_plus");
var builtins10 = NAMESPACE.get("builtins");
var not11 = NAMESPACE.get("not");
var nothing12 = NAMESPACE.get("nothing");
var print13 = NAMESPACE.get("print");
var raise14 = NAMESPACE.get("raise");
var string_DASH_contains15 = NAMESPACE.get("string-contains");
var torepr16 = NAMESPACE.get("torepr");
var tostring17 = NAMESPACE.get("tostring");
var $type$String18 = NAMESPACE.get("$type$String");
var $Hnames323856 = function(names28657,A119,A231,C1035,C923,NameResolution7458,NameResolution8159,Option2660,PP521,S320,SD722,ScopeBinding7661,ScopeBindingT37762,TypeBinding7863,TypeBindingT47964,U1124,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,each25469,empty3670,fold6171,is_DASH_NameResolution8272,is_DASH_resolved8373,link3774,list3375,map24676,mk_DASH_bind8577,mk_DASH_id8678,none6979,resolve_DASH_imports8980,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,some7084,wrap_DASH_env_DASH_imports22985,_plus9,builtins10,not11,nothing12,print13,raise14,torepr16) {
var ScopeBinding628786 = {"$var":D,
"$name":"ScopeBinding6"};
var ScopeBinding28888 = {"$var":D,
"$name":"ScopeBinding"};
var is_DASH_ScopeBinding28990 = {"$var":D,
"$name":"is-ScopeBinding"};
var is_DASH_letrec_DASH_bind29092 = {"$var":D,
"$name":"is-letrec-bind"};
var letrec_DASH_bind29194 = {"$var":D,
"$name":"letrec-bind"};
var is_DASH_let_DASH_bind29296 = {"$var":D,
"$name":"is-let-bind"};
var let_DASH_bind29398 = {"$var":D,
"$name":"let-bind"};
var is_DASH_var_DASH_bind294100 = {"$var":D,
"$name":"is-var-bind"};
var var_DASH_bind295102 = {"$var":D,
"$name":"var-bind"};
var is_DASH_global_DASH_bind296104 = {"$var":D,
"$name":"is-global-bind"};
var global_DASH_bind297106 = {"$var":D,
"$name":"global-bind"};
var TypeBinding7298108 = {"$var":D,
"$name":"TypeBinding7"};
var TypeBinding299110 = {"$var":D,
"$name":"TypeBinding"};
var is_DASH_TypeBinding300112 = {"$var":D,
"$name":"is-TypeBinding"};
var is_DASH_global_DASH_type_DASH_bind301114 = {"$var":D,
"$name":"is-global-type-bind"};
var global_DASH_type_DASH_bind302116 = {"$var":D,
"$name":"global-type-bind"};
var is_DASH_let_DASH_type_DASH_bind303118 = {"$var":D,
"$name":"is-let-type-bind"};
var let_DASH_type_DASH_bind304120 = {"$var":D,
"$name":"let-type-bind"};
var is_DASH_type_DASH_var_DASH_bind305122 = {"$var":D,
"$name":"is-type-var-bind"};
var type_DASH_var_DASH_bind306124 = {"$var":D,
"$name":"type-var-bind"};
var scope_DASH_env_DASH_from_DASH_env307126 = {"$var":D,
"$name":"scope-env-from-env"};
var type_DASH_env_DASH_from_DASH_env308128 = {"$var":D,
"$name":"type-env-from-env"};
var resolve_DASH_names309130 = {"$var":D,
"$name":"resolve-names"};
var anf_variant_member766464 = R.makeMethod(function(self50689) {
return function(cases_DASH_funs51690,else_DASH_clause52701) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[53],2,arguments);
}
var if_DASH_54704 = R.hasField(cases_DASH_funs51690,("letrec-bind"));
var if_helper754687 = R.makeFunction(function(if_helper_arg755709) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[53],1,arguments);
}
var ann_DASH_check_DASH_temp753710 = if_helper_arg755709;
return ann_DASH_check_DASH_temp753710;
});
var anf_if758708 = R.isBoolean(if_DASH_54704);
if(R.isPyretTrue(anf_if758708)) {
if(R.isPyretTrue(if_DASH_54704)) {
var call_DASH_letrec_DASH_bind49682 = G(cases_DASH_funs51690,"letrec-bind",L[53]);
var anf_arg761683 = G(self50689,"loc",L[78]);
var anf_arg762684 = G(self50689,"atom",L[77]);
var anf_arg763685 = G(self50689,"expr",L[76]);
var $z674675 = D;
var $f680681 = function(_) {
return R.isFunction(call_DASH_letrec_DASH_bind49682)?call_DASH_letrec_DASH_bind49682.app(anf_arg761683,anf_arg762684,anf_arg763685):R.ffi.throwNonFunApp(L[53],call_DASH_letrec_DASH_bind49682,[anf_arg761683,anf_arg762684,anf_arg763685]);
};
try {
if(--R.GAS > 0) {
$z674675 = $f680681();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f680681,
"from":L[53]});
}
} catch($e672673) {
if(R.isCont($e672673)) {
var $ss676677 = {"from":L[53],
"go":function(cont_tail_arg764686) {
return $Hcont_tail_arg2582688(cont_tail_arg764686,if_helper754687);
}};
$e672673.stack[R.EXN_STACKHEIGHT++] = $ss676677;
}
if(R.isPyretException($e672673)) {
$e672673.pyretStack.push(L[53]);
}
throw $e672673;
}
var $ret678679 = $Hcont_tail_arg2582688($z674675,if_helper754687);
++R.GAS;
return $ret678679;
} else {
var $z693694 = D;
var $f699700 = function(_) {
return R.isFunction(else_DASH_clause52701)?else_DASH_clause52701.app():R.ffi.throwNonFunApp(L[53],else_DASH_clause52701,[]);
};
try {
if(--R.GAS > 0) {
$z693694 = $f699700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f699700,
"from":L[53]});
}
} catch($e691692) {
if(R.isCont($e691692)) {
var $ss695696 = {"from":L[53],
"go":function(cont_tail_arg759702) {
return $Hcont_tail_arg2583703(cont_tail_arg759702,if_helper754687);
}};
$e691692.stack[R.EXN_STACKHEIGHT++] = $ss695696;
}
if(R.isPyretException($e691692)) {
$e691692.pyretStack.push(L[53]);
}
throw $e691692;
}
var $ret697698 = $Hcont_tail_arg2583703($z693694,if_helper754687);
++R.GAS;
return $ret697698;
}
} else {
var cont_tail_arg756707 = R.throwNonBooleanCondition(L[53],("if"),if_DASH_54704);
if(--R.GAS > 0) {
$z705706 = R.isFunction(if_helper754687)?if_helper754687.app(cont_tail_arg756707):R.ffi.throwNonFunApp(L[53],if_helper754687,[cont_tail_arg756707]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper754687)?if_helper754687.app(cont_tail_arg756707):R.ffi.throwNonFunApp(L[53],if_helper754687,[cont_tail_arg756707]);
},
"from":L[53]});
}
++R.GAS;
return $z705706;
}
};
},{"length":3});
var anf_variant_member780465 = R.makeMethod(function(self53670) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[53],0,arguments);
}
var anf_arg768668 = G(self53670,"loc",L[53]);
var $z660661 = D;
var $f666667 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg768668):R.ffi.throwNonFunApp(L[53],torepr16,[anf_arg768668]);
};
try {
if(--R.GAS > 0) {
$z660661 = $f666667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f666667,
"from":L[53]});
}
} catch($e658659) {
if(R.isCont($e658659)) {
var $ss662663 = {"from":L[53],
"go":function(anf_arg769669) {
return $Hanf_arg2593671(anf_arg769669,self53670,_plus9,torepr16);
}};
$e658659.stack[R.EXN_STACKHEIGHT++] = $ss662663;
}
if(R.isPyretException($e658659)) {
$e658659.pyretStack.push(L[53]);
}
throw $e658659;
}
var $ret664665 = $Hanf_arg2593671($z660661,self53670,_plus9,torepr16);
++R.GAS;
return $ret664665;
};
},{"length":1});
var anf_variant_member794474 = R.makeMethod(function(self56636) {
return function(cases_DASH_funs57637,else_DASH_clause58648) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[52],2,arguments);
}
var if_DASH_60651 = R.hasField(cases_DASH_funs57637,("let-bind"));
var if_helper782634 = R.makeFunction(function(if_helper_arg783656) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[52],1,arguments);
}
var ann_DASH_check_DASH_temp781657 = if_helper_arg783656;
return ann_DASH_check_DASH_temp781657;
});
var anf_if786655 = R.isBoolean(if_DASH_60651);
if(R.isPyretTrue(anf_if786655)) {
if(R.isPyretTrue(if_DASH_60651)) {
var call_DASH_let_DASH_bind55629 = G(cases_DASH_funs57637,"let-bind",L[52]);
var anf_arg789630 = G(self56636,"loc",L[75]);
var anf_arg790631 = G(self56636,"atom",L[74]);
var anf_arg791632 = G(self56636,"expr",L[73]);
var $z621622 = D;
var $f627628 = function(_) {
return R.isFunction(call_DASH_let_DASH_bind55629)?call_DASH_let_DASH_bind55629.app(anf_arg789630,anf_arg790631,anf_arg791632):R.ffi.throwNonFunApp(L[52],call_DASH_let_DASH_bind55629,[anf_arg789630,anf_arg790631,anf_arg791632]);
};
try {
if(--R.GAS > 0) {
$z621622 = $f627628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f627628,
"from":L[52]});
}
} catch($e619620) {
if(R.isCont($e619620)) {
var $ss623624 = {"from":L[52],
"go":function(cont_tail_arg792633) {
return $Hcont_tail_arg2594635(cont_tail_arg792633,if_helper782634);
}};
$e619620.stack[R.EXN_STACKHEIGHT++] = $ss623624;
}
if(R.isPyretException($e619620)) {
$e619620.pyretStack.push(L[52]);
}
throw $e619620;
}
var $ret625626 = $Hcont_tail_arg2594635($z621622,if_helper782634);
++R.GAS;
return $ret625626;
} else {
var $z640641 = D;
var $f646647 = function(_) {
return R.isFunction(else_DASH_clause58648)?else_DASH_clause58648.app():R.ffi.throwNonFunApp(L[52],else_DASH_clause58648,[]);
};
try {
if(--R.GAS > 0) {
$z640641 = $f646647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f646647,
"from":L[52]});
}
} catch($e638639) {
if(R.isCont($e638639)) {
var $ss642643 = {"from":L[52],
"go":function(cont_tail_arg787649) {
return $Hcont_tail_arg2595650(cont_tail_arg787649,if_helper782634);
}};
$e638639.stack[R.EXN_STACKHEIGHT++] = $ss642643;
}
if(R.isPyretException($e638639)) {
$e638639.pyretStack.push(L[52]);
}
throw $e638639;
}
var $ret644645 = $Hcont_tail_arg2595650($z640641,if_helper782634);
++R.GAS;
return $ret644645;
}
} else {
var cont_tail_arg784654 = R.throwNonBooleanCondition(L[52],("if"),if_DASH_60651);
if(--R.GAS > 0) {
$z652653 = R.isFunction(if_helper782634)?if_helper782634.app(cont_tail_arg784654):R.ffi.throwNonFunApp(L[52],if_helper782634,[cont_tail_arg784654]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper782634)?if_helper782634.app(cont_tail_arg784654):R.ffi.throwNonFunApp(L[52],if_helper782634,[cont_tail_arg784654]);
},
"from":L[52]});
}
++R.GAS;
return $z652653;
}
};
},{"length":3});
var anf_variant_member808475 = R.makeMethod(function(self59617) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[52],0,arguments);
}
var anf_arg796615 = G(self59617,"loc",L[52]);
var $z607608 = D;
var $f613614 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg796615):R.ffi.throwNonFunApp(L[52],torepr16,[anf_arg796615]);
};
try {
if(--R.GAS > 0) {
$z607608 = $f613614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f613614,
"from":L[52]});
}
} catch($e605606) {
if(R.isCont($e605606)) {
var $ss609610 = {"from":L[52],
"go":function(anf_arg797616) {
return $Hanf_arg2605618(anf_arg797616,self59617,_plus9,torepr16);
}};
$e605606.stack[R.EXN_STACKHEIGHT++] = $ss609610;
}
if(R.isPyretException($e605606)) {
$e605606.pyretStack.push(L[52]);
}
throw $e605606;
}
var $ret611612 = $Hanf_arg2605618($z607608,self59617,_plus9,torepr16);
++R.GAS;
return $ret611612;
};
},{"length":1});
var anf_variant_member822484 = R.makeMethod(function(self62583) {
return function(cases_DASH_funs63584,else_DASH_clause64595) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[51],2,arguments);
}
var if_DASH_66598 = R.hasField(cases_DASH_funs63584,("var-bind"));
var if_helper810581 = R.makeFunction(function(if_helper_arg811603) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[51],1,arguments);
}
var ann_DASH_check_DASH_temp809604 = if_helper_arg811603;
return ann_DASH_check_DASH_temp809604;
});
var anf_if814602 = R.isBoolean(if_DASH_66598);
if(R.isPyretTrue(anf_if814602)) {
if(R.isPyretTrue(if_DASH_66598)) {
var call_DASH_var_DASH_bind61576 = G(cases_DASH_funs63584,"var-bind",L[51]);
var anf_arg817577 = G(self62583,"loc",L[72]);
var anf_arg818578 = G(self62583,"atom",L[71]);
var anf_arg819579 = G(self62583,"expr",L[70]);
var $z568569 = D;
var $f574575 = function(_) {
return R.isFunction(call_DASH_var_DASH_bind61576)?call_DASH_var_DASH_bind61576.app(anf_arg817577,anf_arg818578,anf_arg819579):R.ffi.throwNonFunApp(L[51],call_DASH_var_DASH_bind61576,[anf_arg817577,anf_arg818578,anf_arg819579]);
};
try {
if(--R.GAS > 0) {
$z568569 = $f574575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f574575,
"from":L[51]});
}
} catch($e566567) {
if(R.isCont($e566567)) {
var $ss570571 = {"from":L[51],
"go":function(cont_tail_arg820580) {
return $Hcont_tail_arg2606582(cont_tail_arg820580,if_helper810581);
}};
$e566567.stack[R.EXN_STACKHEIGHT++] = $ss570571;
}
if(R.isPyretException($e566567)) {
$e566567.pyretStack.push(L[51]);
}
throw $e566567;
}
var $ret572573 = $Hcont_tail_arg2606582($z568569,if_helper810581);
++R.GAS;
return $ret572573;
} else {
var $z587588 = D;
var $f593594 = function(_) {
return R.isFunction(else_DASH_clause64595)?else_DASH_clause64595.app():R.ffi.throwNonFunApp(L[51],else_DASH_clause64595,[]);
};
try {
if(--R.GAS > 0) {
$z587588 = $f593594();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f593594,
"from":L[51]});
}
} catch($e585586) {
if(R.isCont($e585586)) {
var $ss589590 = {"from":L[51],
"go":function(cont_tail_arg815596) {
return $Hcont_tail_arg2607597(cont_tail_arg815596,if_helper810581);
}};
$e585586.stack[R.EXN_STACKHEIGHT++] = $ss589590;
}
if(R.isPyretException($e585586)) {
$e585586.pyretStack.push(L[51]);
}
throw $e585586;
}
var $ret591592 = $Hcont_tail_arg2607597($z587588,if_helper810581);
++R.GAS;
return $ret591592;
}
} else {
var cont_tail_arg812601 = R.throwNonBooleanCondition(L[51],("if"),if_DASH_66598);
if(--R.GAS > 0) {
$z599600 = R.isFunction(if_helper810581)?if_helper810581.app(cont_tail_arg812601):R.ffi.throwNonFunApp(L[51],if_helper810581,[cont_tail_arg812601]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper810581)?if_helper810581.app(cont_tail_arg812601):R.ffi.throwNonFunApp(L[51],if_helper810581,[cont_tail_arg812601]);
},
"from":L[51]});
}
++R.GAS;
return $z599600;
}
};
},{"length":3});
var anf_variant_member836485 = R.makeMethod(function(self65564) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[51],0,arguments);
}
var anf_arg824562 = G(self65564,"loc",L[51]);
var $z554555 = D;
var $f560561 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg824562):R.ffi.throwNonFunApp(L[51],torepr16,[anf_arg824562]);
};
try {
if(--R.GAS > 0) {
$z554555 = $f560561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f560561,
"from":L[51]});
}
} catch($e552553) {
if(R.isCont($e552553)) {
var $ss556557 = {"from":L[51],
"go":function(anf_arg825563) {
return $Hanf_arg2617565(anf_arg825563,self65564,_plus9,torepr16);
}};
$e552553.stack[R.EXN_STACKHEIGHT++] = $ss556557;
}
if(R.isPyretException($e552553)) {
$e552553.pyretStack.push(L[51]);
}
throw $e552553;
}
var $ret558559 = $Hanf_arg2617565($z554555,self65564,_plus9,torepr16);
++R.GAS;
return $ret558559;
};
},{"length":1});
var anf_variant_member850494 = R.makeMethod(function(self68530) {
return function(cases_DASH_funs69531,else_DASH_clause70542) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[50],2,arguments);
}
var if_DASH_72545 = R.hasField(cases_DASH_funs69531,("global-bind"));
var if_helper838528 = R.makeFunction(function(if_helper_arg839550) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[50],1,arguments);
}
var ann_DASH_check_DASH_temp837551 = if_helper_arg839550;
return ann_DASH_check_DASH_temp837551;
});
var anf_if842549 = R.isBoolean(if_DASH_72545);
if(R.isPyretTrue(anf_if842549)) {
if(R.isPyretTrue(if_DASH_72545)) {
var call_DASH_global_DASH_bind67523 = G(cases_DASH_funs69531,"global-bind",L[50]);
var anf_arg845524 = G(self68530,"loc",L[69]);
var anf_arg846525 = G(self68530,"atom",L[68]);
var anf_arg847526 = G(self68530,"expr",L[67]);
var $z515516 = D;
var $f521522 = function(_) {
return R.isFunction(call_DASH_global_DASH_bind67523)?call_DASH_global_DASH_bind67523.app(anf_arg845524,anf_arg846525,anf_arg847526):R.ffi.throwNonFunApp(L[50],call_DASH_global_DASH_bind67523,[anf_arg845524,anf_arg846525,anf_arg847526]);
};
try {
if(--R.GAS > 0) {
$z515516 = $f521522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f521522,
"from":L[50]});
}
} catch($e513514) {
if(R.isCont($e513514)) {
var $ss517518 = {"from":L[50],
"go":function(cont_tail_arg848527) {
return $Hcont_tail_arg2618529(cont_tail_arg848527,if_helper838528);
}};
$e513514.stack[R.EXN_STACKHEIGHT++] = $ss517518;
}
if(R.isPyretException($e513514)) {
$e513514.pyretStack.push(L[50]);
}
throw $e513514;
}
var $ret519520 = $Hcont_tail_arg2618529($z515516,if_helper838528);
++R.GAS;
return $ret519520;
} else {
var $z534535 = D;
var $f540541 = function(_) {
return R.isFunction(else_DASH_clause70542)?else_DASH_clause70542.app():R.ffi.throwNonFunApp(L[50],else_DASH_clause70542,[]);
};
try {
if(--R.GAS > 0) {
$z534535 = $f540541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f540541,
"from":L[50]});
}
} catch($e532533) {
if(R.isCont($e532533)) {
var $ss536537 = {"from":L[50],
"go":function(cont_tail_arg843543) {
return $Hcont_tail_arg2619544(cont_tail_arg843543,if_helper838528);
}};
$e532533.stack[R.EXN_STACKHEIGHT++] = $ss536537;
}
if(R.isPyretException($e532533)) {
$e532533.pyretStack.push(L[50]);
}
throw $e532533;
}
var $ret538539 = $Hcont_tail_arg2619544($z534535,if_helper838528);
++R.GAS;
return $ret538539;
}
} else {
var cont_tail_arg840548 = R.throwNonBooleanCondition(L[50],("if"),if_DASH_72545);
if(--R.GAS > 0) {
$z546547 = R.isFunction(if_helper838528)?if_helper838528.app(cont_tail_arg840548):R.ffi.throwNonFunApp(L[50],if_helper838528,[cont_tail_arg840548]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper838528)?if_helper838528.app(cont_tail_arg840548):R.ffi.throwNonFunApp(L[50],if_helper838528,[cont_tail_arg840548]);
},
"from":L[50]});
}
++R.GAS;
return $z546547;
}
};
},{"length":3});
var anf_variant_member864495 = R.makeMethod(function(self71511) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[50],0,arguments);
}
var anf_arg852509 = G(self71511,"loc",L[50]);
var $z501502 = D;
var $f507508 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg852509):R.ffi.throwNonFunApp(L[50],torepr16,[anf_arg852509]);
};
try {
if(--R.GAS > 0) {
$z501502 = $f507508();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f507508,
"from":L[50]});
}
} catch($e499500) {
if(R.isCont($e499500)) {
var $ss503504 = {"from":L[50],
"go":function(anf_arg853510) {
return $Hanf_arg2629512(anf_arg853510,self71511,_plus9,torepr16);
}};
$e499500.stack[R.EXN_STACKHEIGHT++] = $ss503504;
}
if(R.isPyretException($e499500)) {
$e499500.pyretStack.push(L[50]);
}
throw $e499500;
}
var $ret505506 = $Hanf_arg2629512($z501502,self71511,_plus9,torepr16);
++R.GAS;
return $ret505506;
};
},{"length":1});
var anf_assign86587 = (function() {
var $letrec_DASH_bind_DASH_base459460 = {"_match":anf_variant_member766464,
"_torepr":anf_variant_member780465};
var $letrec_DASH_bind_DASH_brands462463 = {"$brand-letrec-bind461":true};
$letrec_DASH_bind_DASH_brands462463[ScopeBindingT37762._brand] = true
var $let_DASH_bind_DASH_base469470 = {"_match":anf_variant_member794474,
"_torepr":anf_variant_member808475};
var $let_DASH_bind_DASH_brands472473 = {"$brand-let-bind471":true};
$let_DASH_bind_DASH_brands472473[ScopeBindingT37762._brand] = true
var $var_DASH_bind_DASH_base479480 = {"_match":anf_variant_member822484,
"_torepr":anf_variant_member836485};
var $var_DASH_bind_DASH_brands482483 = {"$brand-var-bind481":true};
$var_DASH_bind_DASH_brands482483[ScopeBindingT37762._brand] = true
var $global_DASH_bind_DASH_base489490 = {"_match":anf_variant_member850494,
"_torepr":anf_variant_member864495};
var $global_DASH_bind_DASH_brands492493 = {"$brand-global-bind491":true};
$global_DASH_bind_DASH_brands492493[ScopeBindingT37762._brand] = true
return R.makeObject({"ScopeBinding":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[54],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,ScopeBindingT37762._brand));
}),
"is-letrec-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[53],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-letrec-bind461"));
}),
"letrec-bind":R.makeFunction(function(loc310466,atom311467,expr312468) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[55],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[56],"A",A231,"Name"),Option2660],[atom311467,expr312468],[L[56],L[57]],function() {
var dict = R.create($letrec_DASH_bind_DASH_base459460);
dict["loc"] = loc310466
dict["atom"] = atom311467
dict["expr"] = expr312468
return R.makeBrandedObject(dict,$letrec_DASH_bind_DASH_brands462463);
});
}),
"is-let-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[52],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-let-bind471"));
}),
"let-bind":R.makeFunction(function(loc313476,atom314477,expr315478) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[58],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[59],"A",A231,"Name"),Option2660],[atom314477,expr315478],[L[59],L[60]],function() {
var dict = R.create($let_DASH_bind_DASH_base469470);
dict["loc"] = loc313476
dict["atom"] = atom314477
dict["expr"] = expr315478
return R.makeBrandedObject(dict,$let_DASH_bind_DASH_brands472473);
});
}),
"is-var-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[51],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-var-bind481"));
}),
"var-bind":R.makeFunction(function(loc316486,atom317487,expr318488) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[61],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[62],"A",A231,"Name"),Option2660],[atom317487,expr318488],[L[62],L[63]],function() {
var dict = R.create($var_DASH_bind_DASH_base479480);
dict["loc"] = loc316486
dict["atom"] = atom317487
dict["expr"] = expr318488
return R.makeBrandedObject(dict,$var_DASH_bind_DASH_brands482483);
});
}),
"is-global-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[50],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-global-bind491"));
}),
"global-bind":R.makeFunction(function(loc319496,atom320497,expr321498) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[64],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[65],"A",A231,"Name"),Option2660],[atom320497,expr321498],[L[65],L[66]],function() {
var dict = R.create($global_DASH_bind_DASH_base489490);
dict["loc"] = loc319496
dict["atom"] = atom320497
dict["expr"] = expr321498
return R.makeBrandedObject(dict,$global_DASH_bind_DASH_brands492493);
});
})});
})();
ScopeBinding628786.$var = anf_assign86587;
var anf_assign86689 = G(ScopeBinding628786.$var,"ScopeBinding",L[54]);
ScopeBinding28888.$var = anf_assign86689;
var anf_assign86791 = G(ScopeBinding628786.$var,"ScopeBinding",L[54]);
is_DASH_ScopeBinding28990.$var = anf_assign86791;
var anf_assign86893 = G(ScopeBinding628786.$var,"is-letrec-bind",L[53]);
is_DASH_letrec_DASH_bind29092.$var = anf_assign86893;
var anf_assign86995 = G(ScopeBinding628786.$var,"letrec-bind",L[53]);
letrec_DASH_bind29194.$var = anf_assign86995;
var anf_assign87097 = G(ScopeBinding628786.$var,"is-let-bind",L[52]);
is_DASH_let_DASH_bind29296.$var = anf_assign87097;
var anf_assign87199 = G(ScopeBinding628786.$var,"let-bind",L[52]);
let_DASH_bind29398.$var = anf_assign87199;
var anf_assign872101 = G(ScopeBinding628786.$var,"is-var-bind",L[51]);
is_DASH_var_DASH_bind294100.$var = anf_assign872101;
var anf_assign873103 = G(ScopeBinding628786.$var,"var-bind",L[51]);
var_DASH_bind295102.$var = anf_assign873103;
var anf_assign874105 = G(ScopeBinding628786.$var,"is-global-bind",L[50]);
is_DASH_global_DASH_bind296104.$var = anf_assign874105;
var anf_assign875107 = G(ScopeBinding628786.$var,"global-bind",L[50]);
global_DASH_bind297106.$var = anf_assign875107;
var anf_variant_member889274 = R.makeMethod(function(self74437) {
return function(cases_DASH_funs75438,else_DASH_clause76449) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[30],2,arguments);
}
var if_DASH_78452 = R.hasField(cases_DASH_funs75438,("global-type-bind"));
var if_helper877435 = R.makeFunction(function(if_helper_arg878457) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
var ann_DASH_check_DASH_temp876458 = if_helper_arg878457;
return ann_DASH_check_DASH_temp876458;
});
var anf_if881456 = R.isBoolean(if_DASH_78452);
if(R.isPyretTrue(anf_if881456)) {
if(R.isPyretTrue(if_DASH_78452)) {
var call_DASH_global_DASH_type_DASH_bind73430 = G(cases_DASH_funs75438,"global-type-bind",L[30]);
var anf_arg884431 = G(self74437,"loc",L[49]);
var anf_arg885432 = G(self74437,"atom",L[48]);
var anf_arg886433 = G(self74437,"ann",L[47]);
var $z422423 = D;
var $f428429 = function(_) {
return R.isFunction(call_DASH_global_DASH_type_DASH_bind73430)?call_DASH_global_DASH_type_DASH_bind73430.app(anf_arg884431,anf_arg885432,anf_arg886433):R.ffi.throwNonFunApp(L[30],call_DASH_global_DASH_type_DASH_bind73430,[anf_arg884431,anf_arg885432,anf_arg886433]);
};
try {
if(--R.GAS > 0) {
$z422423 = $f428429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f428429,
"from":L[30]});
}
} catch($e420421) {
if(R.isCont($e420421)) {
var $ss424425 = {"from":L[30],
"go":function(cont_tail_arg887434) {
return $Hcont_tail_arg2630436(cont_tail_arg887434,if_helper877435);
}};
$e420421.stack[R.EXN_STACKHEIGHT++] = $ss424425;
}
if(R.isPyretException($e420421)) {
$e420421.pyretStack.push(L[30]);
}
throw $e420421;
}
var $ret426427 = $Hcont_tail_arg2630436($z422423,if_helper877435);
++R.GAS;
return $ret426427;
} else {
var $z441442 = D;
var $f447448 = function(_) {
return R.isFunction(else_DASH_clause76449)?else_DASH_clause76449.app():R.ffi.throwNonFunApp(L[30],else_DASH_clause76449,[]);
};
try {
if(--R.GAS > 0) {
$z441442 = $f447448();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f447448,
"from":L[30]});
}
} catch($e439440) {
if(R.isCont($e439440)) {
var $ss443444 = {"from":L[30],
"go":function(cont_tail_arg882450) {
return $Hcont_tail_arg2631451(cont_tail_arg882450,if_helper877435);
}};
$e439440.stack[R.EXN_STACKHEIGHT++] = $ss443444;
}
if(R.isPyretException($e439440)) {
$e439440.pyretStack.push(L[30]);
}
throw $e439440;
}
var $ret445446 = $Hcont_tail_arg2631451($z441442,if_helper877435);
++R.GAS;
return $ret445446;
}
} else {
var cont_tail_arg879455 = R.throwNonBooleanCondition(L[30],("if"),if_DASH_78452);
if(--R.GAS > 0) {
$z453454 = R.isFunction(if_helper877435)?if_helper877435.app(cont_tail_arg879455):R.ffi.throwNonFunApp(L[30],if_helper877435,[cont_tail_arg879455]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper877435)?if_helper877435.app(cont_tail_arg879455):R.ffi.throwNonFunApp(L[30],if_helper877435,[cont_tail_arg879455]);
},
"from":L[30]});
}
++R.GAS;
return $z453454;
}
};
},{"length":3});
var anf_variant_member903275 = R.makeMethod(function(self77418) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[30],0,arguments);
}
var anf_arg891416 = G(self77418,"loc",L[30]);
var $z408409 = D;
var $f414415 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg891416):R.ffi.throwNonFunApp(L[30],torepr16,[anf_arg891416]);
};
try {
if(--R.GAS > 0) {
$z408409 = $f414415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f414415,
"from":L[30]});
}
} catch($e406407) {
if(R.isCont($e406407)) {
var $ss410411 = {"from":L[30],
"go":function(anf_arg892417) {
return $Hanf_arg2641419(anf_arg892417,self77418,_plus9,torepr16);
}};
$e406407.stack[R.EXN_STACKHEIGHT++] = $ss410411;
}
if(R.isPyretException($e406407)) {
$e406407.pyretStack.push(L[30]);
}
throw $e406407;
}
var $ret412413 = $Hanf_arg2641419($z408409,self77418,_plus9,torepr16);
++R.GAS;
return $ret412413;
};
},{"length":1});
var anf_variant_member917284 = R.makeMethod(function(self80384) {
return function(cases_DASH_funs81385,else_DASH_clause82396) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[29],2,arguments);
}
var if_DASH_84399 = R.hasField(cases_DASH_funs81385,("let-type-bind"));
var if_helper905382 = R.makeFunction(function(if_helper_arg906404) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[29],1,arguments);
}
var ann_DASH_check_DASH_temp904405 = if_helper_arg906404;
return ann_DASH_check_DASH_temp904405;
});
var anf_if909403 = R.isBoolean(if_DASH_84399);
if(R.isPyretTrue(anf_if909403)) {
if(R.isPyretTrue(if_DASH_84399)) {
var call_DASH_let_DASH_type_DASH_bind79377 = G(cases_DASH_funs81385,"let-type-bind",L[29]);
var anf_arg912378 = G(self80384,"loc",L[46]);
var anf_arg913379 = G(self80384,"atom",L[45]);
var anf_arg914380 = G(self80384,"ann",L[44]);
var $z369370 = D;
var $f375376 = function(_) {
return R.isFunction(call_DASH_let_DASH_type_DASH_bind79377)?call_DASH_let_DASH_type_DASH_bind79377.app(anf_arg912378,anf_arg913379,anf_arg914380):R.ffi.throwNonFunApp(L[29],call_DASH_let_DASH_type_DASH_bind79377,[anf_arg912378,anf_arg913379,anf_arg914380]);
};
try {
if(--R.GAS > 0) {
$z369370 = $f375376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f375376,
"from":L[29]});
}
} catch($e367368) {
if(R.isCont($e367368)) {
var $ss371372 = {"from":L[29],
"go":function(cont_tail_arg915381) {
return $Hcont_tail_arg2642383(cont_tail_arg915381,if_helper905382);
}};
$e367368.stack[R.EXN_STACKHEIGHT++] = $ss371372;
}
if(R.isPyretException($e367368)) {
$e367368.pyretStack.push(L[29]);
}
throw $e367368;
}
var $ret373374 = $Hcont_tail_arg2642383($z369370,if_helper905382);
++R.GAS;
return $ret373374;
} else {
var $z388389 = D;
var $f394395 = function(_) {
return R.isFunction(else_DASH_clause82396)?else_DASH_clause82396.app():R.ffi.throwNonFunApp(L[29],else_DASH_clause82396,[]);
};
try {
if(--R.GAS > 0) {
$z388389 = $f394395();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f394395,
"from":L[29]});
}
} catch($e386387) {
if(R.isCont($e386387)) {
var $ss390391 = {"from":L[29],
"go":function(cont_tail_arg910397) {
return $Hcont_tail_arg2643398(cont_tail_arg910397,if_helper905382);
}};
$e386387.stack[R.EXN_STACKHEIGHT++] = $ss390391;
}
if(R.isPyretException($e386387)) {
$e386387.pyretStack.push(L[29]);
}
throw $e386387;
}
var $ret392393 = $Hcont_tail_arg2643398($z388389,if_helper905382);
++R.GAS;
return $ret392393;
}
} else {
var cont_tail_arg907402 = R.throwNonBooleanCondition(L[29],("if"),if_DASH_84399);
if(--R.GAS > 0) {
$z400401 = R.isFunction(if_helper905382)?if_helper905382.app(cont_tail_arg907402):R.ffi.throwNonFunApp(L[29],if_helper905382,[cont_tail_arg907402]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper905382)?if_helper905382.app(cont_tail_arg907402):R.ffi.throwNonFunApp(L[29],if_helper905382,[cont_tail_arg907402]);
},
"from":L[29]});
}
++R.GAS;
return $z400401;
}
};
},{"length":3});
var anf_variant_member931285 = R.makeMethod(function(self83365) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[29],0,arguments);
}
var anf_arg919363 = G(self83365,"loc",L[29]);
var $z355356 = D;
var $f361362 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg919363):R.ffi.throwNonFunApp(L[29],torepr16,[anf_arg919363]);
};
try {
if(--R.GAS > 0) {
$z355356 = $f361362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f361362,
"from":L[29]});
}
} catch($e353354) {
if(R.isCont($e353354)) {
var $ss357358 = {"from":L[29],
"go":function(anf_arg920364) {
return $Hanf_arg2653366(anf_arg920364,self83365,_plus9,torepr16);
}};
$e353354.stack[R.EXN_STACKHEIGHT++] = $ss357358;
}
if(R.isPyretException($e353354)) {
$e353354.pyretStack.push(L[29]);
}
throw $e353354;
}
var $ret359360 = $Hanf_arg2653366($z355356,self83365,_plus9,torepr16);
++R.GAS;
return $ret359360;
};
},{"length":1});
var anf_variant_member945294 = R.makeMethod(function(self86330) {
return function(cases_DASH_funs87331,else_DASH_clause88342) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[28],2,arguments);
}
var if_DASH_90345 = R.hasField(cases_DASH_funs87331,("type-var-bind"));
var if_helper933328 = R.makeFunction(function(if_helper_arg934351) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[28],1,arguments);
}
var ann_DASH_check_DASH_temp932352 = if_helper_arg934351;
return ann_DASH_check_DASH_temp932352;
});
var anf_if937350 = R.isBoolean(if_DASH_90345);
if(R.isPyretTrue(anf_if937350)) {
if(R.isPyretTrue(if_DASH_90345)) {
var call_DASH_type_DASH_var_DASH_bind85323 = G(cases_DASH_funs87331,"type-var-bind",L[28]);
var anf_arg940324 = G(self86330,"loc",L[43]);
var anf_arg941325 = G(self86330,"atom",L[42]);
var anf_arg942326 = G(self86330,"ann",L[41]);
var $z315316 = D;
var $f321322 = function(_) {
return R.isFunction(call_DASH_type_DASH_var_DASH_bind85323)?call_DASH_type_DASH_var_DASH_bind85323.app(anf_arg940324,anf_arg941325,anf_arg942326):R.ffi.throwNonFunApp(L[28],call_DASH_type_DASH_var_DASH_bind85323,[anf_arg940324,anf_arg941325,anf_arg942326]);
};
try {
if(--R.GAS > 0) {
$z315316 = $f321322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f321322,
"from":L[28]});
}
} catch($e313314) {
if(R.isCont($e313314)) {
var $ss317318 = {"from":L[28],
"go":function(cont_tail_arg943327) {
return $Hcont_tail_arg2654329(cont_tail_arg943327,if_helper933328);
}};
$e313314.stack[R.EXN_STACKHEIGHT++] = $ss317318;
}
if(R.isPyretException($e313314)) {
$e313314.pyretStack.push(L[28]);
}
throw $e313314;
}
var $ret319320 = $Hcont_tail_arg2654329($z315316,if_helper933328);
++R.GAS;
return $ret319320;
} else {
var $z334335 = D;
var $f340341 = function(_) {
return R.isFunction(else_DASH_clause88342)?else_DASH_clause88342.app():R.ffi.throwNonFunApp(L[28],else_DASH_clause88342,[]);
};
try {
if(--R.GAS > 0) {
$z334335 = $f340341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f340341,
"from":L[28]});
}
} catch($e332333) {
if(R.isCont($e332333)) {
var $ss336337 = {"from":L[28],
"go":function(cont_tail_arg938343) {
return $Hcont_tail_arg2655344(cont_tail_arg938343,if_helper933328);
}};
$e332333.stack[R.EXN_STACKHEIGHT++] = $ss336337;
}
if(R.isPyretException($e332333)) {
$e332333.pyretStack.push(L[28]);
}
throw $e332333;
}
var $ret338339 = $Hcont_tail_arg2655344($z334335,if_helper933328);
++R.GAS;
return $ret338339;
}
} else {
var cont_tail_arg935348 = R.throwNonBooleanCondition(L[28],("if"),if_DASH_90345);
if(--R.GAS > 0) {
$z346347 = R.isFunction(if_helper933328)?if_helper933328.app(cont_tail_arg935348):R.ffi.throwNonFunApp(L[28],if_helper933328,[cont_tail_arg935348]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper933328)?if_helper933328.app(cont_tail_arg935348):R.ffi.throwNonFunApp(L[28],if_helper933328,[cont_tail_arg935348]);
},
"from":L[28]});
}
++R.GAS;
return $z346347;
}
};
},{"length":3});
var anf_variant_member959295 = R.makeMethod(function(self89311) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[28],0,arguments);
}
var anf_arg947309 = G(self89311,"loc",L[28]);
var $z301302 = D;
var $f307308 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg947309):R.ffi.throwNonFunApp(L[28],torepr16,[anf_arg947309]);
};
try {
if(--R.GAS > 0) {
$z301302 = $f307308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f307308,
"from":L[28]});
}
} catch($e299300) {
if(R.isCont($e299300)) {
var $ss303304 = {"from":L[28],
"go":function(anf_arg948310) {
return $Hanf_arg2665312(anf_arg948310,self89311,_plus9,torepr16);
}};
$e299300.stack[R.EXN_STACKHEIGHT++] = $ss303304;
}
if(R.isPyretException($e299300)) {
$e299300.pyretStack.push(L[28]);
}
throw $e299300;
}
var $ret305306 = $Hanf_arg2665312($z301302,self89311,_plus9,torepr16);
++R.GAS;
return $ret305306;
};
},{"length":1});
var anf_assign960109 = (function() {
var $global_DASH_type_DASH_bind_DASH_base269270 = {"_match":anf_variant_member889274,
"_torepr":anf_variant_member903275};
var $global_DASH_type_DASH_bind_DASH_brands272273 = {"$brand-global-type-bind271":true};
$global_DASH_type_DASH_bind_DASH_brands272273[TypeBindingT47964._brand] = true
var $let_DASH_type_DASH_bind_DASH_base279280 = {"_match":anf_variant_member917284,
"_torepr":anf_variant_member931285};
var $let_DASH_type_DASH_bind_DASH_brands282283 = {"$brand-let-type-bind281":true};
$let_DASH_type_DASH_bind_DASH_brands282283[TypeBindingT47964._brand] = true
var $type_DASH_var_DASH_bind_DASH_base289290 = {"_match":anf_variant_member945294,
"_torepr":anf_variant_member959295};
var $type_DASH_var_DASH_bind_DASH_brands292293 = {"$brand-type-var-bind291":true};
$type_DASH_var_DASH_bind_DASH_brands292293[TypeBindingT47964._brand] = true
return R.makeObject({"TypeBinding":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[31],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,TypeBindingT47964._brand));
}),
"is-global-type-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[30],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-global-type-bind271"));
}),
"global-type-bind":R.makeFunction(function(loc322276,atom323277,ann324278) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[32],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[33],"A",A231,"Name"),Option2660],[atom323277,ann324278],[L[33],L[34]],function() {
var dict = R.create($global_DASH_type_DASH_bind_DASH_base269270);
dict["loc"] = loc322276
dict["atom"] = atom323277
dict["ann"] = ann324278
return R.makeBrandedObject(dict,$global_DASH_type_DASH_bind_DASH_brands272273);
});
}),
"is-let-type-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[29],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-let-type-bind281"));
}),
"let-type-bind":R.makeFunction(function(loc325286,atom326287,ann327288) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[35],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[36],"A",A231,"Name"),Option2660],[atom326287,ann327288],[L[36],L[37]],function() {
var dict = R.create($let_DASH_type_DASH_bind_DASH_base279280);
dict["loc"] = loc325286
dict["atom"] = atom326287
dict["ann"] = ann327288
return R.makeBrandedObject(dict,$let_DASH_type_DASH_bind_DASH_brands282283);
});
}),
"is-type-var-bind":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[28],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-type-var-bind291"));
}),
"type-var-bind":R.makeFunction(function(loc328296,atom329297,ann330298) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[38],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[39],"A",A231,"Name"),Option2660],[atom329297,ann330298],[L[39],L[40]],function() {
var dict = R.create($type_DASH_var_DASH_bind_DASH_base289290);
dict["loc"] = loc328296
dict["atom"] = atom329297
dict["ann"] = ann330298
return R.makeBrandedObject(dict,$type_DASH_var_DASH_bind_DASH_brands292293);
});
})});
})();
TypeBinding7298108.$var = anf_assign960109;
var anf_assign961111 = G(TypeBinding7298108.$var,"TypeBinding",L[31]);
TypeBinding299110.$var = anf_assign961111;
var anf_assign962113 = G(TypeBinding7298108.$var,"TypeBinding",L[31]);
is_DASH_TypeBinding300112.$var = anf_assign962113;
var anf_assign963115 = G(TypeBinding7298108.$var,"is-global-type-bind",L[30]);
is_DASH_global_DASH_type_DASH_bind301114.$var = anf_assign963115;
var anf_assign964117 = G(TypeBinding7298108.$var,"global-type-bind",L[30]);
global_DASH_type_DASH_bind302116.$var = anf_assign964117;
var anf_assign965119 = G(TypeBinding7298108.$var,"is-let-type-bind",L[29]);
is_DASH_let_DASH_type_DASH_bind303118.$var = anf_assign965119;
var anf_assign966121 = G(TypeBinding7298108.$var,"let-type-bind",L[29]);
let_DASH_type_DASH_bind304120.$var = anf_assign966121;
var anf_assign967123 = G(TypeBinding7298108.$var,"is-type-var-bind",L[28]);
is_DASH_type_DASH_var_DASH_bind305122.$var = anf_assign967123;
var anf_assign968125 = G(TypeBinding7298108.$var,"type-var-bind",L[28]);
type_DASH_var_DASH_bind306124.$var = anf_assign968125;
var anf_assign989127 = R.makeFunction(function(initial331215) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[17],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[27],"C",C1035,"CompileEnvironment")],[initial331215],[L[27]],function() {
var anf_arg985228 = R.makeFunction(function(acc332230,b333231) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[20],2,arguments);
}
var cases_DASH_val91268 = b333231;
var anf_fun971242 = G(cases_DASH_val91268,"_match",L[21]);
var anf_obj973248 = R.makeFunction(function(name334265,ids335266) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[26],2,arguments);
}
var ann_DASH_check_DASH_temp972267 = acc332230;
return ann_DASH_check_DASH_temp972267;
});
var anf_obj981249 = R.makeFunction(function(name336250) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[22],1,arguments);
}
var anf_fun975263 = G(acc332230,"set",L[25]);
var anf_fun976261 = G(S320,"builtin",L[24]);
var $z253254 = D;
var $f259260 = function(_) {
return R.isFunction(anf_fun976261)?anf_fun976261.app(("pyret-builtin")):R.ffi.throwNonFunApp(L[23],anf_fun976261,[("pyret-builtin")]);
};
try {
if(--R.GAS > 0) {
$z253254 = $f259260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f259260,
"from":L[23]});
}
} catch($e251252) {
if(R.isCont($e251252)) {
var $ss255256 = {"from":L[23],
"go":function(anf_arg977262) {
return $Hanf_arg2669264(anf_arg977262,anf_fun975263,let_DASH_bind29398,name336250,names28657,none6979);
}};
$e251252.stack[R.EXN_STACKHEIGHT++] = $ss255256;
}
if(R.isPyretException($e251252)) {
$e251252.pyretStack.push(L[23]);
}
throw $e251252;
}
var $ret257258 = $Hanf_arg2669264($z253254,anf_fun975263,let_DASH_bind29398,name336250,names28657,none6979);
++R.GAS;
return $ret257258;
});
var anf_arg982243 = R.makeObject({"module-bindings":anf_obj973248,
"builtin-id":anf_obj981249});
var anf_arg984244 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[21],0,arguments);
}
var ann_DASH_check_DASH_temp983247 = R.throwNoBranchesMatched(L[21],("cases"));
return ann_DASH_check_DASH_temp983247;
});
var $z234235 = D;
var $f240241 = function(_) {
return R.isFunction(anf_fun971242)?anf_fun971242.app(anf_arg982243,anf_arg984244):R.ffi.throwNonFunApp(L[20],anf_fun971242,[anf_arg982243,anf_arg984244]);
};
try {
if(--R.GAS > 0) {
$z234235 = $f240241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f240241,
"from":L[20]});
}
} catch($e232233) {
if(R.isCont($e232233)) {
var $ss236237 = {"from":L[20],
"go":function(ann_DASH_check_DASH_temp970245) {
return $Hann_DASH_check_DASH_temp2670246(ann_DASH_check_DASH_temp970245);
}};
$e232233.stack[R.EXN_STACKHEIGHT++] = $ss236237;
}
if(R.isPyretException($e232233)) {
$e232233.pyretStack.push(L[20]);
}
throw $e232233;
}
var $ret238239 = $Hann_DASH_check_DASH_temp2670246($z234235);
++R.GAS;
return $ret238239;
});
var anf_fun986226 = G(SD722,"immutable-string-dict",L[19]);
var $z218219 = D;
var $f224225 = function(_) {
return R.isFunction(anf_fun986226)?anf_fun986226.app():R.ffi.throwNonFunApp(L[18],anf_fun986226,[]);
};
try {
if(--R.GAS > 0) {
$z218219 = $f224225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f224225,
"from":L[18]});
}
} catch($e216217) {
if(R.isCont($e216217)) {
var $ss220221 = {"from":L[18],
"go":function(anf_arg987227) {
return $Hanf_arg2672229(anf_arg987227,anf_arg985228,fold6171,initial331215);
}};
$e216217.stack[R.EXN_STACKHEIGHT++] = $ss220221;
}
if(R.isPyretException($e216217)) {
$e216217.pyretStack.push(L[18]);
}
throw $e216217;
}
var $ret222223 = $Hanf_arg2672229($z218219,anf_arg985228,fold6171,initial331215);
++R.GAS;
return $ret222223;
});
});
scope_DASH_env_DASH_from_DASH_env307126.$var = anf_assign989127;
var anf_assign1010129 = R.makeFunction(function(initial337161) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[6],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[16],"C",C1035,"CompileEnvironment")],[initial337161],[L[16]],function() {
var anf_arg1006174 = R.makeFunction(function(acc338176,b339177) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[9],2,arguments);
}
var cases_DASH_val92214 = b339177;
var anf_fun992188 = G(cases_DASH_val92214,"_match",L[10]);
var anf_obj994194 = R.makeFunction(function(name340211,ids341212) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[15],2,arguments);
}
var ann_DASH_check_DASH_temp993213 = acc338176;
return ann_DASH_check_DASH_temp993213;
});
var anf_obj1002195 = R.makeFunction(function(name342196) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[11],1,arguments);
}
var anf_fun996209 = G(acc338176,"set",L[14]);
var anf_fun997207 = G(S320,"builtin",L[13]);
var $z199200 = D;
var $f205206 = function(_) {
return R.isFunction(anf_fun997207)?anf_fun997207.app(("pyret-builtin-type")):R.ffi.throwNonFunApp(L[12],anf_fun997207,[("pyret-builtin-type")]);
};
try {
if(--R.GAS > 0) {
$z199200 = $f205206();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f205206,
"from":L[12]});
}
} catch($e197198) {
if(R.isCont($e197198)) {
var $ss201202 = {"from":L[12],
"go":function(anf_arg998208) {
return $Hanf_arg2676210(anf_arg998208,anf_fun996209,global_DASH_type_DASH_bind302116,name342196,names28657,none6979);
}};
$e197198.stack[R.EXN_STACKHEIGHT++] = $ss201202;
}
if(R.isPyretException($e197198)) {
$e197198.pyretStack.push(L[12]);
}
throw $e197198;
}
var $ret203204 = $Hanf_arg2676210($z199200,anf_fun996209,global_DASH_type_DASH_bind302116,name342196,names28657,none6979);
++R.GAS;
return $ret203204;
});
var anf_arg1003189 = R.makeObject({"type-module-bindings":anf_obj994194,
"type-id":anf_obj1002195});
var anf_arg1005190 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[10],0,arguments);
}
var ann_DASH_check_DASH_temp1004193 = R.throwNoBranchesMatched(L[10],("cases"));
return ann_DASH_check_DASH_temp1004193;
});
var $z180181 = D;
var $f186187 = function(_) {
return R.isFunction(anf_fun992188)?anf_fun992188.app(anf_arg1003189,anf_arg1005190):R.ffi.throwNonFunApp(L[9],anf_fun992188,[anf_arg1003189,anf_arg1005190]);
};
try {
if(--R.GAS > 0) {
$z180181 = $f186187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f186187,
"from":L[9]});
}
} catch($e178179) {
if(R.isCont($e178179)) {
var $ss182183 = {"from":L[9],
"go":function(ann_DASH_check_DASH_temp991191) {
return $Hann_DASH_check_DASH_temp2677192(ann_DASH_check_DASH_temp991191);
}};
$e178179.stack[R.EXN_STACKHEIGHT++] = $ss182183;
}
if(R.isPyretException($e178179)) {
$e178179.pyretStack.push(L[9]);
}
throw $e178179;
}
var $ret184185 = $Hann_DASH_check_DASH_temp2677192($z180181);
++R.GAS;
return $ret184185;
});
var anf_fun1007172 = G(SD722,"immutable-string-dict",L[8]);
var $z164165 = D;
var $f170171 = function(_) {
return R.isFunction(anf_fun1007172)?anf_fun1007172.app():R.ffi.throwNonFunApp(L[7],anf_fun1007172,[]);
};
try {
if(--R.GAS > 0) {
$z164165 = $f170171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f170171,
"from":L[7]});
}
} catch($e162163) {
if(R.isCont($e162163)) {
var $ss166167 = {"from":L[7],
"go":function(anf_arg1008173) {
return $Hanf_arg2679175(anf_arg1008173,anf_arg1006174,fold6171,initial337161);
}};
$e162163.stack[R.EXN_STACKHEIGHT++] = $ss166167;
}
if(R.isPyretException($e162163)) {
$e162163.pyretStack.push(L[7]);
}
throw $e162163;
}
var $ret168169 = $Hanf_arg2679175($z164165,anf_arg1006174,fold6171,initial337161);
++R.GAS;
return $ret168169;
});
});
type_DASH_env_DASH_from_DASH_env308128.$var = anf_assign1010129;
var anf_assign1792131 = R.makeFunction(function(p343146,initial_DASH_env344147) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[4],"A",A231,"Program"),R.getDotAnn(L[5],"C",C1035,"CompileEnvironment")],[p343146,initial_DASH_env344147],[L[4],L[5]],function() {
var anf_fun1012158 = G(list3375,"make",L[3]);
var $z150151 = D;
var $f156157 = function(_) {
return R.isFunction(anf_fun1012158)?anf_fun1012158.app([]):R.ffi.throwNonFunApp(L[2],anf_fun1012158,[[]]);
};
try {
if(--R.GAS > 0) {
$z150151 = $f156157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f156157,
"from":L[2]});
}
} catch($e148149) {
if(R.isCont($e148149)) {
var $ss152153 = {"from":L[2],
"go":function(var_DASH_bind2680159) {
return $Hvar_DASH_bind2978160(var_DASH_bind2680159,A119,C923,SD722,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16);
}};
$e148149.stack[R.EXN_STACKHEIGHT++] = $ss152153;
}
if(R.isPyretException($e148149)) {
$e148149.pyretStack.push(L[2]);
}
throw $e148149;
}
var $ret154155 = $Hvar_DASH_bind2978160($z150151,A119,C923,SD722,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16);
++R.GAS;
return $ret154155;
});
});
resolve_DASH_names309130.$var = anf_assign1792131;
var result_DASH_after_DASH_checks1683144 = nothing12;
var anf_fun1793142 = G(builtins10,"current-checker",L[0]);
var $z134135 = D;
var $f140141 = function(_) {
return R.isFunction(anf_fun1793142)?anf_fun1793142.app():R.ffi.throwNonFunApp(L[0],anf_fun1793142,[]);
};
try {
if(--R.GAS > 0) {
$z134135 = $f140141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f140141,
"from":L[0]});
}
} catch($e132133) {
if(R.isCont($e132133)) {
var $ss136137 = {"from":L[0],
"go":function(anf_bracket1794143) {
return $Hanf_bracket3237145(anf_bracket1794143,A119,C923,NameResolution7458,NameResolution8159,PP521,S320,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,U1124,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,each25469,empty3670,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,list3375,mk_DASH_bind8577,mk_DASH_id8678,names28657,none6979,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10);
}};
$e132133.stack[R.EXN_STACKHEIGHT++] = $ss136137;
}
if(R.isPyretException($e132133)) {
$e132133.pyretStack.push(L[0]);
}
throw $e132133;
}
var $ret138139 = $Hanf_bracket3237145($z134135,A119,C923,NameResolution7458,NameResolution8159,PP521,S320,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,U1124,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,each25469,empty3670,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,list3375,mk_DASH_bind8577,mk_DASH_id8678,names28657,none6979,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10);
++R.GAS;
return $ret138139;
};
var $Hanf_bracket3237145 = function(anf_bracket1794143,A119,C923,NameResolution7458,NameResolution8159,PP521,S320,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,U1124,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,each25469,empty3670,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,list3375,mk_DASH_bind8577,mk_DASH_id8678,names28657,none6979,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10) {
var anf_fun1795726 = G(anf_bracket1794143,"run-checks",L[0]);
var anf_fun1796721 = G(list3375,"make",L[0]);
var anf_obj2100793 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[94],0,arguments);
}
var p684813 = R.makeFunction(function(str685892) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
var anf_fun1799903 = G(PP521,"surface-parse",L[119]);
var $z895896 = D;
var $f901902 = function(_) {
return R.isFunction(anf_fun1799903)?anf_fun1799903.app(str685892,("test")):R.ffi.throwNonFunApp(L[118],anf_fun1799903,[str685892,("test")]);
};
try {
if(--R.GAS > 0) {
$z895896 = $f901902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f901902,
"from":L[118]});
}
} catch($e893894) {
if(R.isCont($e893894)) {
var $ss897898 = {"from":L[118],
"go":function(anf_bracket1800904) {
return $Hanf_bracket2979905(anf_bracket1800904);
}};
$e893894.stack[R.EXN_STACKHEIGHT++] = $ss897898;
}
if(R.isPyretException($e893894)) {
$e893894.pyretStack.push(L[118]);
}
throw $e893894;
}
var $ret899900 = $Hanf_bracket2979905($z895896);
++R.GAS;
return $ret899900;
});
var d686811 = G(A119,"dummy-loc",L[116]);
var b687805 = R.makeFunction(function(s688877) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[112],1,arguments);
}
var anf_fun1802890 = G(A119,"s-bind",L[115]);
var anf_fun1803888 = G(A119,"s-name",L[114]);
var $z880881 = D;
var $f886887 = function(_) {
return R.isFunction(anf_fun1803888)?anf_fun1803888.app(d686811,s688877):R.ffi.throwNonFunApp(L[113],anf_fun1803888,[d686811,s688877]);
};
try {
if(--R.GAS > 0) {
$z880881 = $f886887();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f886887,
"from":L[113]});
}
} catch($e878879) {
if(R.isCont($e878879)) {
var $ss882883 = {"from":L[113],
"go":function(anf_arg1804889) {
return $Hanf_arg2981891(anf_arg1804889,A119,anf_fun1802890,d686811);
}};
$e878879.stack[R.EXN_STACKHEIGHT++] = $ss882883;
}
if(R.isPyretException($e878879)) {
$e878879.pyretStack.push(L[113]);
}
throw $e878879;
}
var $ret884885 = $Hanf_arg2981891($z880881,A119,anf_fun1802890,d686811);
++R.GAS;
return $ret884885;
});
var id689812 = R.makeFunction(function(s690862) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[108],1,arguments);
}
var anf_fun1807875 = G(A119,"s-id",L[111]);
var anf_fun1808873 = G(A119,"s-name",L[110]);
var $z865866 = D;
var $f871872 = function(_) {
return R.isFunction(anf_fun1808873)?anf_fun1808873.app(d686811,s690862):R.ffi.throwNonFunApp(L[109],anf_fun1808873,[d686811,s690862]);
};
try {
if(--R.GAS > 0) {
$z865866 = $f871872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f871872,
"from":L[109]});
}
} catch($e863864) {
if(R.isCont($e863864)) {
var $ss867868 = {"from":L[109],
"go":function(anf_arg1809874) {
return $Hanf_arg2983876(anf_arg1809874,anf_fun1807875,d686811);
}};
$e863864.stack[R.EXN_STACKHEIGHT++] = $ss867868;
}
if(R.isPyretException($e863864)) {
$e863864.pyretStack.push(L[109]);
}
throw $e863864;
}
var $ret869870 = $Hanf_arg2983876($z865866,anf_fun1807875,d686811);
++R.GAS;
return $ret869870;
});
var bk691830 = R.makeFunction(function(e692847) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[105],1,arguments);
}
var anf_fun1811860 = G(A119,"s-block",L[107]);
var anf_fun1812858 = G(list3375,"make",L[106]);
var $z850851 = D;
var $f856857 = function(_) {
return R.isFunction(anf_fun1812858)?anf_fun1812858.app([e692847]):R.ffi.throwNonFunApp(L[106],anf_fun1812858,[[e692847]]);
};
try {
if(--R.GAS > 0) {
$z850851 = $f856857();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f856857,
"from":L[106]});
}
} catch($e848849) {
if(R.isCont($e848849)) {
var $ss852853 = {"from":L[106],
"go":function(anf_arg1813859) {
return $Hanf_arg2985861(anf_arg1813859,anf_fun1811860,d686811);
}};
$e848849.stack[R.EXN_STACKHEIGHT++] = $ss852853;
}
if(R.isPyretException($e848849)) {
$e848849.pyretStack.push(L[106]);
}
throw $e848849;
}
var $ret854855 = $Hanf_arg2985861($z850851,anf_fun1811860,d686811);
++R.GAS;
return $ret854855;
});
var bs693810 = R.makeFunction(function(str694833) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[102],1,arguments);
}
var anf_fun1815845 = G(A119,"s-block",L[104]);
var $z836837 = D;
var $f842843 = function(_) {
return R.isFunction(p684813)?p684813.app(str694833):R.ffi.throwNonFunApp(L[103],p684813,[str694833]);
};
try {
if(--R.GAS > 0) {
$z836837 = $f842843();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f842843,
"from":L[103]});
}
} catch($e834835) {
if(R.isCont($e834835)) {
var $ss838839 = {"from":L[103],
"go":function(anf_bracket1816844) {
return $Hanf_bracket2992846(anf_bracket1816844,A119,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375);
}};
$e834835.stack[R.EXN_STACKHEIGHT++] = $ss838839;
}
if(R.isPyretException($e834835)) {
$e834835.pyretStack.push(L[103]);
}
throw $e834835;
}
var $ret840841 = $Hanf_bracket2992846($z836837,A119,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375);
++R.GAS;
return $ret840841;
});
var n695831 = none6979;
var thunk696814 = R.makeFunction(function(e697816) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[99],1,arguments);
}
var anf_fun1829829 = G(A119,"s-lam",L[101]);
var anf_fun1830827 = G(list3375,"make",L[100]);
var $z819820 = D;
var $f825826 = function(_) {
return R.isFunction(anf_fun1830827)?anf_fun1830827.app([]):R.ffi.throwNonFunApp(L[100],anf_fun1830827,[[]]);
};
try {
if(--R.GAS > 0) {
$z819820 = $f825826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f825826,
"from":L[100]});
}
} catch($e817818) {
if(R.isCont($e817818)) {
var $ss821822 = {"from":L[100],
"go":function(anf_arg1831828) {
return $Hanf_arg2996832(anf_arg1831828,A119,anf_fun1829829,bk691830,d686811,e697816,list3375,n695831);
}};
$e817818.stack[R.EXN_STACKHEIGHT++] = $ss821822;
}
if(R.isPyretException($e817818)) {
$e817818.pyretStack.push(L[100]);
}
throw $e817818;
}
var $ret823824 = $Hanf_arg2996832($z819820,A119,anf_fun1829829,bk691830,d686811,e697816,list3375,n695831);
++R.GAS;
return $ret823824;
});
var anf_fun1836807 = G(A119,"s-let-expr",L[98]);
var anf_fun1837808 = G(list3375,"make",L[97]);
var anf_fun1838809 = G(A119,"s-let-bind",L[96]);
var $z797798 = D;
var $f803804 = function(_) {
return R.isFunction(b687805)?b687805.app(("x")):R.ffi.throwNonFunApp(L[95],b687805,[("x")]);
};
try {
if(--R.GAS > 0) {
$z797798 = $f803804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f803804,
"from":L[95]});
}
} catch($e795796) {
if(R.isCont($e795796)) {
var $ss799800 = {"from":L[95],
"go":function(anf_arg1839806) {
return $Hanf_arg3156815(anf_arg1839806,A119,anf_fun1836807,anf_fun1837808,anf_fun1838809,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e795796.stack[R.EXN_STACKHEIGHT++] = $ss799800;
}
if(R.isPyretException($e795796)) {
$e795796.pyretStack.push(L[95]);
}
throw $e795796;
}
var $ret801802 = $Hanf_arg3156815($z797798,A119,anf_fun1836807,anf_fun1837808,anf_fun1838809,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret801802;
});
var anf_obj2101794 = R.makeSrcloc(L[94]);
var anf_array_val2102722 = R.makeObject({"name":("desugar-scope-block"),
"run":anf_obj2100793,
"location":anf_obj2101794});
var anf_obj2220743 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[80],0,arguments);
}
var d709756 = G(A119,"dummy-loc",L[93]);
var b710760 = R.makeFunction(function(s711778) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[89],1,arguments);
}
var anf_fun2105791 = G(A119,"s-bind",L[92]);
var anf_fun2106789 = G(A119,"s-name",L[91]);
var $z781782 = D;
var $f787788 = function(_) {
return R.isFunction(anf_fun2106789)?anf_fun2106789.app(d709756,s711778):R.ffi.throwNonFunApp(L[90],anf_fun2106789,[d709756,s711778]);
};
try {
if(--R.GAS > 0) {
$z781782 = $f787788();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f787788,
"from":L[90]});
}
} catch($e779780) {
if(R.isCont($e779780)) {
var $ss783784 = {"from":L[90],
"go":function(anf_arg2107790) {
return $Hanf_arg3158792(anf_arg2107790,A119,anf_fun2105791,d709756);
}};
$e779780.stack[R.EXN_STACKHEIGHT++] = $ss783784;
}
if(R.isPyretException($e779780)) {
$e779780.pyretStack.push(L[90]);
}
throw $e779780;
}
var $ret785786 = $Hanf_arg3158792($z781782,A119,anf_fun2105791,d709756);
++R.GAS;
return $ret785786;
});
var id712761 = R.makeFunction(function(s713763) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[85],1,arguments);
}
var anf_fun2110776 = G(A119,"s-id",L[88]);
var anf_fun2111774 = G(A119,"s-name",L[87]);
var $z766767 = D;
var $f772773 = function(_) {
return R.isFunction(anf_fun2111774)?anf_fun2111774.app(d709756,s713763):R.ffi.throwNonFunApp(L[86],anf_fun2111774,[d709756,s713763]);
};
try {
if(--R.GAS > 0) {
$z766767 = $f772773();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f772773,
"from":L[86]});
}
} catch($e764765) {
if(R.isCont($e764765)) {
var $ss768769 = {"from":L[86],
"go":function(anf_arg2112775) {
return $Hanf_arg3160777(anf_arg2112775,anf_fun2110776,d709756);
}};
$e764765.stack[R.EXN_STACKHEIGHT++] = $ss768769;
}
if(R.isPyretException($e764765)) {
$e764765.pyretStack.push(L[86]);
}
throw $e764765;
}
var $ret770771 = $Hanf_arg3160777($z766767,anf_fun2110776,d709756);
++R.GAS;
return $ret770771;
});
var anf_fun2113758 = G(A119,"s-app",L[84]);
var anf_fun2114759 = G(A119,"s-dot",L[83]);
var anf_fun2115755 = G(U1124,"checkers",L[82]);
var $z747748 = D;
var $f753754 = function(_) {
return R.isFunction(anf_fun2115755)?anf_fun2115755.app(d709756):R.ffi.throwNonFunApp(L[81],anf_fun2115755,[d709756]);
};
try {
if(--R.GAS > 0) {
$z747748 = $f753754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f753754,
"from":L[81]});
}
} catch($e745746) {
if(R.isCont($e745746)) {
var $ss749750 = {"from":L[81],
"go":function(anf_arg2116757) {
return $Hanf_arg3220762(anf_arg2116757,A119,C923,PP521,anf_fun2113758,anf_fun2114759,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10);
}};
$e745746.stack[R.EXN_STACKHEIGHT++] = $ss749750;
}
if(R.isPyretException($e745746)) {
$e745746.pyretStack.push(L[81]);
}
throw $e745746;
}
var $ret751752 = $Hanf_arg3220762($z747748,A119,C923,PP521,anf_fun2113758,anf_fun2114759,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10);
++R.GAS;
return $ret751752;
});
var anf_obj2221744 = R.makeSrcloc(L[80]);
var anf_array_val2222723 = R.makeObject({"name":("desugar-scope"),
"run":anf_obj2220743,
"location":anf_obj2221744});
var anf_obj2244728 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[17],0,arguments);
}
var anf_fun2224740 = G(builtins10,"current-checker",L[79]);
var $z732733 = D;
var $f738739 = function(_) {
return R.isFunction(anf_fun2224740)?anf_fun2224740.app():R.ffi.throwNonFunApp(L[79],anf_fun2224740,[]);
};
try {
if(--R.GAS > 0) {
$z732733 = $f738739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f738739,
"from":L[79]});
}
} catch($e730731) {
if(R.isCont($e730731)) {
var $ss734735 = {"from":L[79],
"go":function(anf_bracket2225741) {
return $Hanf_bracket3231742(anf_bracket2225741,C923,S320,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
}};
$e730731.stack[R.EXN_STACKHEIGHT++] = $ss734735;
}
if(R.isPyretException($e730731)) {
$e730731.pyretStack.push(L[79]);
}
throw $e730731;
}
var $ret736737 = $Hanf_bracket3231742($z732733,C923,S320,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
++R.GAS;
return $ret736737;
});
var anf_obj2245729 = R.makeSrcloc(L[17]);
var anf_array_val2246724 = R.makeObject({"name":("scope-env-from-env"),
"run":anf_obj2244728,
"location":anf_obj2245729});
var $z713714 = D;
var $f719720 = function(_) {
return R.isFunction(anf_fun1796721)?anf_fun1796721.app([anf_array_val2102722,anf_array_val2222723,anf_array_val2246724]):R.ffi.throwNonFunApp(L[0],anf_fun1796721,[[anf_array_val2102722,anf_array_val2222723,anf_array_val2246724]]);
};
try {
if(--R.GAS > 0) {
$z713714 = $f719720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f719720,
"from":L[0]});
}
} catch($e711712) {
if(R.isCont($e711712)) {
var $ss715716 = {"from":L[0],
"go":function(anf_arg2247725) {
return $Hanf_arg3236727(anf_arg2247725,NameResolution7458,NameResolution8159,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,anf_fun1795726,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,mk_DASH_bind8577,mk_DASH_id8678,names28657,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10);
}};
$e711712.stack[R.EXN_STACKHEIGHT++] = $ss715716;
}
if(R.isPyretException($e711712)) {
$e711712.pyretStack.push(L[0]);
}
throw $e711712;
}
var $ret717718 = $Hanf_arg3236727($z713714,NameResolution7458,NameResolution8159,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,anf_fun1795726,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,mk_DASH_bind8577,mk_DASH_id8678,names28657,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10);
++R.GAS;
return $ret717718;
};
var $Hanf_arg3236727 = function(anf_arg2247725,NameResolution7458,NameResolution8159,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,anf_fun1795726,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,mk_DASH_bind8577,mk_DASH_id8678,names28657,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10) {
var $z908909 = D;
var $f914915 = function(_) {
return R.isFunction(anf_fun1795726)?anf_fun1795726.app(("src/arr/compiler/resolve-scope.arr"),anf_arg2247725):R.ffi.throwNonFunApp(L[0],anf_fun1795726,[("src/arr/compiler/resolve-scope.arr"),anf_arg2247725]);
};
try {
if(--R.GAS > 0) {
$z908909 = $f914915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f914915,
"from":L[0]});
}
} catch($e906907) {
if(R.isCont($e906907)) {
var $ss910911 = {"from":L[0],
"go":function(anf_begin_app_dropped3232916) {
return $Hanf_begin_app_dropped3235917(anf_begin_app_dropped3232916,NameResolution7458,NameResolution8159,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,mk_DASH_bind8577,mk_DASH_id8678,names28657,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10);
}};
$e906907.stack[R.EXN_STACKHEIGHT++] = $ss910911;
}
if(R.isPyretException($e906907)) {
$e906907.pyretStack.push(L[0]);
}
throw $e906907;
}
var $ret912913 = $Hanf_begin_app_dropped3235917($z908909,NameResolution7458,NameResolution8159,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,mk_DASH_bind8577,mk_DASH_id8678,names28657,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10);
++R.GAS;
return $ret912913;
};
var $Hanf_begin_app_dropped3235917 = function(anf_begin_app_dropped3232916,NameResolution7458,NameResolution8159,ScopeBinding28888,ScopeBinding7661,TypeBinding299110,TypeBinding7863,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,global_DASH_bind297106,global_DASH_type_DASH_bind302116,is_DASH_NameResolution8272,is_DASH_ScopeBinding28990,is_DASH_TypeBinding300112,is_DASH_global_DASH_bind296104,is_DASH_global_DASH_type_DASH_bind301114,is_DASH_let_DASH_bind29296,is_DASH_let_DASH_type_DASH_bind303118,is_DASH_letrec_DASH_bind29092,is_DASH_resolved8373,is_DASH_type_DASH_var_DASH_bind305122,is_DASH_var_DASH_bind294100,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,mk_DASH_bind8577,mk_DASH_id8678,names28657,resolve_DASH_imports8980,resolve_DASH_names309130,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,result_DASH_after_DASH_checks1683144,scope_DASH_env_DASH_from_DASH_env307126,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,wrap_DASH_env_DASH_imports22985,builtins10) {
var provides2248930 = R.makeObject({"NameResolution":NameResolution8159.$var,
"is-NameResolution":is_DASH_NameResolution8272.$var,
"resolved":resolved8483.$var,
"is-resolved":is_DASH_resolved8373.$var,
"mk-bind":mk_DASH_bind8577.$var,
"mk-id":mk_DASH_id8678.$var,
"resolve-provide":resolve_DASH_provide8781.$var,
"resolve-type-provide":resolve_DASH_type_DASH_provide8882.$var,
"resolve-imports":resolve_DASH_imports8980.$var,
"desugar-toplevel-types":desugar_DASH_toplevel_DASH_types9068.$var,
"desugar-scope-block":desugar_DASH_scope_DASH_block9165.$var,
"desugar-scope-visitor":desugar_DASH_scope_DASH_visitor22566,
"wrap-env-imports":wrap_DASH_env_DASH_imports22985.$var,
"desugar-scope":desugar_DASH_scope23067.$var,
"names":names28657,
"ScopeBinding":ScopeBinding28888.$var,
"is-ScopeBinding":is_DASH_ScopeBinding28990.$var,
"letrec-bind":letrec_DASH_bind29194.$var,
"is-letrec-bind":is_DASH_letrec_DASH_bind29092.$var,
"let-bind":let_DASH_bind29398.$var,
"is-let-bind":is_DASH_let_DASH_bind29296.$var,
"var-bind":var_DASH_bind295102.$var,
"is-var-bind":is_DASH_var_DASH_bind294100.$var,
"global-bind":global_DASH_bind297106.$var,
"is-global-bind":is_DASH_global_DASH_bind296104.$var,
"TypeBinding":TypeBinding299110.$var,
"is-TypeBinding":is_DASH_TypeBinding300112.$var,
"global-type-bind":global_DASH_type_DASH_bind302116.$var,
"is-global-type-bind":is_DASH_global_DASH_type_DASH_bind301114.$var,
"let-type-bind":let_DASH_type_DASH_bind304120.$var,
"is-let-type-bind":is_DASH_let_DASH_type_DASH_bind303118.$var,
"type-var-bind":type_DASH_var_DASH_bind306124.$var,
"is-type-var-bind":is_DASH_type_DASH_var_DASH_bind305122.$var,
"scope-env-from-env":scope_DASH_env_DASH_from_DASH_env307126.$var,
"type-env-from-env":type_DASH_env_DASH_from_DASH_env308128.$var,
"resolve-names":resolve_DASH_names309130.$var,
"result-after-checks1":result_DASH_after_DASH_checks1683144});
var anf_fun2249928 = G(builtins10,"current-checker",L[120]);
var $z920921 = D;
var $f926927 = function(_) {
return R.isFunction(anf_fun2249928)?anf_fun2249928.app():R.ffi.throwNonFunApp(L[120],anf_fun2249928,[]);
};
try {
if(--R.GAS > 0) {
$z920921 = $f926927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f926927,
"from":L[120]});
}
} catch($e918919) {
if(R.isCont($e918919)) {
var $ss922923 = {"from":L[120],
"go":function(anf_bracket2250929) {
return $Hanf_bracket3234931(anf_bracket2250929,NameResolution7458,ScopeBinding7661,TypeBinding7863,provides2248930,result_DASH_after_DASH_checks1683144);
}};
$e918919.stack[R.EXN_STACKHEIGHT++] = $ss922923;
}
if(R.isPyretException($e918919)) {
$e918919.pyretStack.push(L[120]);
}
throw $e918919;
}
var $ret924925 = $Hanf_bracket3234931($z920921,NameResolution7458,ScopeBinding7661,TypeBinding7863,provides2248930,result_DASH_after_DASH_checks1683144);
++R.GAS;
return $ret924925;
};
var $Hanf_bracket3234931 = function(anf_bracket2250929,NameResolution7458,ScopeBinding7661,TypeBinding7863,provides2248930,result_DASH_after_DASH_checks1683144) {
var anf_fun2251942 = G(anf_bracket2250929,"results",L[120]);
var $z934935 = D;
var $f940941 = function(_) {
return R.isFunction(anf_fun2251942)?anf_fun2251942.app():R.ffi.throwNonFunApp(L[120],anf_fun2251942,[]);
};
try {
if(--R.GAS > 0) {
$z934935 = $f940941();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f940941,
"from":L[120]});
}
} catch($e932933) {
if(R.isCont($e932933)) {
var $ss936937 = {"from":L[120],
"go":function(checks2252943) {
return $Hchecks3233944(checks2252943,NameResolution7458,ScopeBinding7661,TypeBinding7863,provides2248930,result_DASH_after_DASH_checks1683144);
}};
$e932933.stack[R.EXN_STACKHEIGHT++] = $ss936937;
}
if(R.isPyretException($e932933)) {
$e932933.pyretStack.push(L[120]);
}
throw $e932933;
}
var $ret938939 = $Hchecks3233944($z934935,NameResolution7458,ScopeBinding7661,TypeBinding7863,provides2248930,result_DASH_after_DASH_checks1683144);
++R.GAS;
return $ret938939;
};
var $Hchecks3233944 = function(checks2252943,NameResolution7458,ScopeBinding7661,TypeBinding7863,provides2248930,result_DASH_after_DASH_checks1683144) {
return R.makeObject({"answer":result_DASH_after_DASH_checks1683144,
"provide-plus-types":R.makeObject({"values":provides2248930,
"types":{"NameResolution":NameResolution7458,
"ScopeBinding":ScopeBinding7661,
"TypeBinding":TypeBinding7863}}),
"checks":checks2252943});
};
var $Hanf_bracket3231742 = function(anf_bracket2225741,C923,S320,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126) {
var anf_fun2226957 = G(anf_bracket2225741,"check-is",L[79]);
var anf_fun2227958 = G(C923,"compile-env",L[124]);
var anf_fun2228959 = G(list3375,"make",L[123]);
var anf_fun2229955 = G(C923,"builtin-id",L[122]);
var $z947948 = D;
var $f953954 = function(_) {
return R.isFunction(anf_fun2229955)?anf_fun2229955.app(("x")):R.ffi.throwNonFunApp(L[121],anf_fun2229955,[("x")]);
};
try {
if(--R.GAS > 0) {
$z947948 = $f953954();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f953954,
"from":L[121]});
}
} catch($e945946) {
if(R.isCont($e945946)) {
var $ss949950 = {"from":L[121],
"go":function(anf_array_val2230956) {
return $Hanf_array_val3230960(anf_array_val2230956,S320,anf_fun2226957,anf_fun2227958,anf_fun2228959,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
}};
$e945946.stack[R.EXN_STACKHEIGHT++] = $ss949950;
}
if(R.isPyretException($e945946)) {
$e945946.pyretStack.push(L[121]);
}
throw $e945946;
}
var $ret951952 = $Hanf_array_val3230960($z947948,S320,anf_fun2226957,anf_fun2227958,anf_fun2228959,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
++R.GAS;
return $ret951952;
};
var $Hanf_array_val3230960 = function(anf_array_val2230956,S320,anf_fun2226957,anf_fun2227958,anf_fun2228959,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126) {
var $z963964 = D;
var $f969970 = function(_) {
return R.isFunction(anf_fun2228959)?anf_fun2228959.app([anf_array_val2230956]):R.ffi.throwNonFunApp(L[123],anf_fun2228959,[[anf_array_val2230956]]);
};
try {
if(--R.GAS > 0) {
$z963964 = $f969970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f969970,
"from":L[123]});
}
} catch($e961962) {
if(R.isCont($e961962)) {
var $ss965966 = {"from":L[123],
"go":function(anf_arg2231971) {
return $Hanf_arg3229972(anf_arg2231971,S320,anf_fun2226957,anf_fun2227958,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
}};
$e961962.stack[R.EXN_STACKHEIGHT++] = $ss965966;
}
if(R.isPyretException($e961962)) {
$e961962.pyretStack.push(L[123]);
}
throw $e961962;
}
var $ret967968 = $Hanf_arg3229972($z963964,S320,anf_fun2226957,anf_fun2227958,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
++R.GAS;
return $ret967968;
};
var $Hanf_arg3229972 = function(anf_arg2231971,S320,anf_fun2226957,anf_fun2227958,let_DASH_bind29398,list3375,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126) {
var anf_fun2232983 = G(list3375,"make",L[125]);
var $z975976 = D;
var $f981982 = function(_) {
return R.isFunction(anf_fun2232983)?anf_fun2232983.app([]):R.ffi.throwNonFunApp(L[125],anf_fun2232983,[[]]);
};
try {
if(--R.GAS > 0) {
$z975976 = $f981982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f981982,
"from":L[125]});
}
} catch($e973974) {
if(R.isCont($e973974)) {
var $ss977978 = {"from":L[125],
"go":function(anf_arg2233984) {
return $Hanf_arg3228985(anf_arg2233984,S320,anf_arg2231971,anf_fun2226957,anf_fun2227958,let_DASH_bind29398,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
}};
$e973974.stack[R.EXN_STACKHEIGHT++] = $ss977978;
}
if(R.isPyretException($e973974)) {
$e973974.pyretStack.push(L[125]);
}
throw $e973974;
}
var $ret979980 = $Hanf_arg3228985($z975976,S320,anf_arg2231971,anf_fun2226957,anf_fun2227958,let_DASH_bind29398,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
++R.GAS;
return $ret979980;
};
var $Hanf_arg3228985 = function(anf_arg2233984,S320,anf_arg2231971,anf_fun2226957,anf_fun2227958,let_DASH_bind29398,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126) {
var $z988989 = D;
var $f994995 = function(_) {
return R.isFunction(anf_fun2227958)?anf_fun2227958.app(anf_arg2231971,anf_arg2233984):R.ffi.throwNonFunApp(L[126],anf_fun2227958,[anf_arg2231971,anf_arg2233984]);
};
try {
if(--R.GAS > 0) {
$z988989 = $f994995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f994995,
"from":L[126]});
}
} catch($e986987) {
if(R.isCont($e986987)) {
var $ss990991 = {"from":L[126],
"go":function(anf_arg2234996) {
return $Hanf_arg3227997(anf_arg2234996,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
}};
$e986987.stack[R.EXN_STACKHEIGHT++] = $ss990991;
}
if(R.isPyretException($e986987)) {
$e986987.pyretStack.push(L[126]);
}
throw $e986987;
}
var $ret992993 = $Hanf_arg3227997($z988989,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126);
++R.GAS;
return $ret992993;
};
var $Hanf_arg3227997 = function(anf_arg2234996,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979,scope_DASH_env_DASH_from_DASH_env307126) {
var $z10001001 = D;
var $f10061007 = function(_) {
return R.isFunction(scope_DASH_env_DASH_from_DASH_env307126.$var)?scope_DASH_env_DASH_from_DASH_env307126.$var.app(anf_arg2234996):R.ffi.throwNonFunApp(L[127],scope_DASH_env_DASH_from_DASH_env307126.$var,[anf_arg2234996]);
};
try {
if(--R.GAS > 0) {
$z10001001 = $f10061007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10061007,
"from":L[127]});
}
} catch($e998999) {
if(R.isCont($e998999)) {
var $ss10021003 = {"from":L[127],
"go":function(anf_bracket22351008) {
return $Hanf_bracket32261009(anf_bracket22351008,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979);
}};
$e998999.stack[R.EXN_STACKHEIGHT++] = $ss10021003;
}
if(R.isPyretException($e998999)) {
$e998999.pyretStack.push(L[127]);
}
throw $e998999;
}
var $ret10041005 = $Hanf_bracket32261009($z10001001,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979);
++R.GAS;
return $ret10041005;
};
var $Hanf_bracket32261009 = function(anf_bracket22351008,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979) {
var anf_fun22361020 = G(anf_bracket22351008,"get",L[129]);
var $z10121013 = D;
var $f10181019 = function(_) {
return R.isFunction(anf_fun22361020)?anf_fun22361020.app(("x")):R.ffi.throwNonFunApp(L[128],anf_fun22361020,[("x")]);
};
try {
if(--R.GAS > 0) {
$z10121013 = $f10181019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10181019,
"from":L[128]});
}
} catch($e10101011) {
if(R.isCont($e10101011)) {
var $ss10141015 = {"from":L[128],
"go":function(anf_arg22371021) {
return $Hanf_arg32251022(anf_arg22371021,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979);
}};
$e10101011.stack[R.EXN_STACKHEIGHT++] = $ss10141015;
}
if(R.isPyretException($e10101011)) {
$e10101011.pyretStack.push(L[128]);
}
throw $e10101011;
}
var $ret10161017 = $Hanf_arg32251022($z10121013,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979);
++R.GAS;
return $ret10161017;
};
var $Hanf_arg32251022 = function(anf_arg22371021,S320,anf_fun2226957,let_DASH_bind29398,names28657,none6979) {
var anf_fun22381033 = G(S320,"builtin",L[131]);
var $z10251026 = D;
var $f10311032 = function(_) {
return R.isFunction(anf_fun22381033)?anf_fun22381033.app(("pyret-builtin")):R.ffi.throwNonFunApp(L[130],anf_fun22381033,[("pyret-builtin")]);
};
try {
if(--R.GAS > 0) {
$z10251026 = $f10311032();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10311032,
"from":L[130]});
}
} catch($e10231024) {
if(R.isCont($e10231024)) {
var $ss10271028 = {"from":L[130],
"go":function(anf_arg22391034) {
return $Hanf_arg32241035(anf_arg22391034,anf_arg22371021,anf_fun2226957,let_DASH_bind29398,names28657,none6979);
}};
$e10231024.stack[R.EXN_STACKHEIGHT++] = $ss10271028;
}
if(R.isPyretException($e10231024)) {
$e10231024.pyretStack.push(L[130]);
}
throw $e10231024;
}
var $ret10291030 = $Hanf_arg32241035($z10251026,anf_arg22371021,anf_fun2226957,let_DASH_bind29398,names28657,none6979);
++R.GAS;
return $ret10291030;
};
var $Hanf_arg32241035 = function(anf_arg22391034,anf_arg22371021,anf_fun2226957,let_DASH_bind29398,names28657,none6979) {
var anf_fun22401046 = G(names28657,"s-global",L[133]);
var $z10381039 = D;
var $f10441045 = function(_) {
return R.isFunction(anf_fun22401046)?anf_fun22401046.app(("x")):R.ffi.throwNonFunApp(L[132],anf_fun22401046,[("x")]);
};
try {
if(--R.GAS > 0) {
$z10381039 = $f10441045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10441045,
"from":L[132]});
}
} catch($e10361037) {
if(R.isCont($e10361037)) {
var $ss10401041 = {"from":L[132],
"go":function(anf_arg22411047) {
return $Hanf_arg32231048(anf_arg22411047,anf_arg22371021,anf_arg22391034,anf_fun2226957,let_DASH_bind29398,none6979);
}};
$e10361037.stack[R.EXN_STACKHEIGHT++] = $ss10401041;
}
if(R.isPyretException($e10361037)) {
$e10361037.pyretStack.push(L[132]);
}
throw $e10361037;
}
var $ret10421043 = $Hanf_arg32231048($z10381039,anf_arg22371021,anf_arg22391034,anf_fun2226957,let_DASH_bind29398,none6979);
++R.GAS;
return $ret10421043;
};
var $Hanf_arg32231048 = function(anf_arg22411047,anf_arg22371021,anf_arg22391034,anf_fun2226957,let_DASH_bind29398,none6979) {
var $z10511052 = D;
var $f10571058 = function(_) {
return R.isFunction(let_DASH_bind29398.$var)?let_DASH_bind29398.$var.app(anf_arg22391034,anf_arg22411047,none6979):R.ffi.throwNonFunApp(L[134],let_DASH_bind29398.$var,[anf_arg22391034,anf_arg22411047,none6979]);
};
try {
if(--R.GAS > 0) {
$z10511052 = $f10571058();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10571058,
"from":L[134]});
}
} catch($e10491050) {
if(R.isCont($e10491050)) {
var $ss10531054 = {"from":L[134],
"go":function(anf_arg22421059) {
return $Hanf_arg32221060(anf_arg22421059,anf_arg22371021,anf_fun2226957);
}};
$e10491050.stack[R.EXN_STACKHEIGHT++] = $ss10531054;
}
if(R.isPyretException($e10491050)) {
$e10491050.pyretStack.push(L[134]);
}
throw $e10491050;
}
var $ret10551056 = $Hanf_arg32221060($z10511052,anf_arg22371021,anf_fun2226957);
++R.GAS;
return $ret10551056;
};
var $Hanf_arg32221060 = function(anf_arg22421059,anf_arg22371021,anf_fun2226957) {
var anf_arg22431071 = R.makeSrcloc(L[79]);
var $z10631064 = D;
var $f10691070 = function(_) {
return R.isFunction(anf_fun2226957)?anf_fun2226957.app(("scope-env-from-env(C.compile-env([list: C.builtin-id(\"x\")], [list: ])).get(\"x\") is\n  let-bind(S.builtin(\"pyret-builtin\"), names.s-global(\"x\"), none)"),anf_arg22371021,anf_arg22421059,anf_arg22431071):R.ffi.throwNonFunApp(L[17],anf_fun2226957,[("scope-env-from-env(C.compile-env([list: C.builtin-id(\"x\")], [list: ])).get(\"x\") is\n  let-bind(S.builtin(\"pyret-builtin\"), names.s-global(\"x\"), none)"),anf_arg22371021,anf_arg22421059,anf_arg22431071]);
};
try {
if(--R.GAS > 0) {
$z10631064 = $f10691070();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10691070,
"from":L[17]});
}
} catch($e10611062) {
if(R.isCont($e10611062)) {
var $ss10651066 = {"from":L[17],
"go":function(ann_DASH_check_DASH_temp22231072) {
return $Hann_DASH_check_DASH_temp32211073(ann_DASH_check_DASH_temp22231072);
}};
$e10611062.stack[R.EXN_STACKHEIGHT++] = $ss10651066;
}
if(R.isPyretException($e10611062)) {
$e10611062.pyretStack.push(L[17]);
}
throw $e10611062;
}
var $ret10671068 = $Hann_DASH_check_DASH_temp32211073($z10631064);
++R.GAS;
return $ret10671068;
};
var $Hann_DASH_check_DASH_temp32211073 = function(ann_DASH_check_DASH_temp22231072) {
return ann_DASH_check_DASH_temp22231072;
};
var $Hanf_arg3220762 = function(anf_arg2116757,A119,C923,PP521,anf_fun2113758,anf_fun2114759,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10) {
var $z10761077 = D;
var $f10821083 = function(_) {
return R.isFunction(anf_fun2114759)?anf_fun2114759.app(d709756,anf_arg2116757,("results")):R.ffi.throwNonFunApp(L[135],anf_fun2114759,[d709756,anf_arg2116757,("results")]);
};
try {
if(--R.GAS > 0) {
$z10761077 = $f10821083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10821083,
"from":L[135]});
}
} catch($e10741075) {
if(R.isCont($e10741075)) {
var $ss10781079 = {"from":L[135],
"go":function(anf_arg21171084) {
return $Hanf_arg32191085(anf_arg21171084,A119,C923,PP521,anf_fun2113758,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10);
}};
$e10741075.stack[R.EXN_STACKHEIGHT++] = $ss10781079;
}
if(R.isPyretException($e10741075)) {
$e10741075.pyretStack.push(L[135]);
}
throw $e10741075;
}
var $ret10801081 = $Hanf_arg32191085($z10761077,A119,C923,PP521,anf_fun2113758,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10);
++R.GAS;
return $ret10801081;
};
var $Hanf_arg32191085 = function(anf_arg21171084,A119,C923,PP521,anf_fun2113758,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10) {
var anf_fun21181096 = G(list3375,"make",L[136]);
var $z10881089 = D;
var $f10941095 = function(_) {
return R.isFunction(anf_fun21181096)?anf_fun21181096.app([]):R.ffi.throwNonFunApp(L[136],anf_fun21181096,[[]]);
};
try {
if(--R.GAS > 0) {
$z10881089 = $f10941095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10941095,
"from":L[136]});
}
} catch($e10861087) {
if(R.isCont($e10861087)) {
var $ss10901091 = {"from":L[136],
"go":function(anf_arg21191097) {
return $Hanf_arg32181098(anf_arg21191097,A119,C923,PP521,anf_arg21171084,anf_fun2113758,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10);
}};
$e10861087.stack[R.EXN_STACKHEIGHT++] = $ss10901091;
}
if(R.isPyretException($e10861087)) {
$e10861087.pyretStack.push(L[136]);
}
throw $e10861087;
}
var $ret10921093 = $Hanf_arg32181098($z10881089,A119,C923,PP521,anf_arg21171084,anf_fun2113758,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10);
++R.GAS;
return $ret10921093;
};
var $Hanf_arg32181098 = function(anf_arg21191097,A119,C923,PP521,anf_arg21171084,anf_fun2113758,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10) {
var $z11011102 = D;
var $f11071108 = function(_) {
return R.isFunction(anf_fun2113758)?anf_fun2113758.app(d709756,anf_arg21171084,anf_arg21191097):R.ffi.throwNonFunApp(L[137],anf_fun2113758,[d709756,anf_arg21171084,anf_arg21191097]);
};
try {
if(--R.GAS > 0) {
$z11011102 = $f11071108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11071108,
"from":L[137]});
}
} catch($e10991100) {
if(R.isCont($e10991100)) {
var $ss11031104 = {"from":L[137],
"go":function(checks7141109) {
return $Hchecks32171110(checks7141109,A119,C923,PP521,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10);
}};
$e10991100.stack[R.EXN_STACKHEIGHT++] = $ss11031104;
}
if(R.isPyretException($e10991100)) {
$e10991100.pyretStack.push(L[137]);
}
throw $e10991100;
}
var $ret11051106 = $Hchecks32171110($z11011102,A119,C923,PP521,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10);
++R.GAS;
return $ret11051106;
};
var $Hchecks32171110 = function(checks7141109,A119,C923,PP521,b710760,d709756,desugar_DASH_scope23067,id712761,list3375,builtins10) {
var str7151140 = R.makeFunction(function(arg_DASH_1271141) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[144],1,arguments);
}
var anf_fun21211152 = G(A119,"s-str",L[145]);
var $z11441145 = D;
var $f11501151 = function(_) {
return R.isFunction(anf_fun21211152)?anf_fun21211152.app(d709756,arg_DASH_1271141):R.ffi.throwNonFunApp(L[144],anf_fun21211152,[d709756,arg_DASH_1271141]);
};
try {
if(--R.GAS > 0) {
$z11441145 = $f11501151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11501151,
"from":L[144]});
}
} catch($e11421143) {
if(R.isCont($e11421143)) {
var $ss11461147 = {"from":L[144],
"go":function(ann_DASH_check_DASH_temp21201153) {
return $Hann_DASH_check_DASH_temp31611154(ann_DASH_check_DASH_temp21201153);
}};
$e11421143.stack[R.EXN_STACKHEIGHT++] = $ss11461147;
}
if(R.isPyretException($e11421143)) {
$e11421143.pyretStack.push(L[144]);
}
throw $e11421143;
}
var $ret11481149 = $Hann_DASH_check_DASH_temp31611154($z11441145);
++R.GAS;
return $ret11481149;
});
var ds7161124 = R.makeFunction(function(prog7171126) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[141],1,arguments);
}
var anf_arg21231137 = G(C923,"minimal-builtins",L[143]);
var $z11291130 = D;
var $f11351136 = function(_) {
return R.isFunction(desugar_DASH_scope23067.$var)?desugar_DASH_scope23067.$var.app(prog7171126,anf_arg21231137):R.ffi.throwNonFunApp(L[142],desugar_DASH_scope23067.$var,[prog7171126,anf_arg21231137]);
};
try {
if(--R.GAS > 0) {
$z11291130 = $f11351136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11351136,
"from":L[142]});
}
} catch($e11271128) {
if(R.isCont($e11271128)) {
var $ss11311132 = {"from":L[142],
"go":function(anf_bracket21241138) {
return $Hanf_bracket31631139(anf_bracket21241138,A119);
}};
$e11271128.stack[R.EXN_STACKHEIGHT++] = $ss11311132;
}
if(R.isPyretException($e11271128)) {
$e11271128.pyretStack.push(L[142]);
}
throw $e11271128;
}
var $ret11331134 = $Hanf_bracket31631139($z11291130,A119);
++R.GAS;
return $ret11331134;
});
var anf_fun21271123 = G(A119,"s-program",L[140]);
var anf_fun21281121 = G(A119,"s-provide-none",L[139]);
var $z11131114 = D;
var $f11191120 = function(_) {
return R.isFunction(anf_fun21281121)?anf_fun21281121.app(d709756):R.ffi.throwNonFunApp(L[138],anf_fun21281121,[d709756]);
};
try {
if(--R.GAS > 0) {
$z11131114 = $f11191120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11191120,
"from":L[138]});
}
} catch($e11111112) {
if(R.isCont($e11111112)) {
var $ss11151116 = {"from":L[138],
"go":function(anf_arg21291122) {
return $Hanf_arg32161125(anf_arg21291122,A119,PP521,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e11111112.stack[R.EXN_STACKHEIGHT++] = $ss11151116;
}
if(R.isPyretException($e11111112)) {
$e11111112.pyretStack.push(L[138]);
}
throw $e11111112;
}
var $ret11171118 = $Hanf_arg32161125($z11131114,A119,PP521,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret11171118;
};
var $Hanf_arg32161125 = function(anf_arg21291122,A119,PP521,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21301165 = G(A119,"s-provide-types-none",L[147]);
var $z11571158 = D;
var $f11631164 = function(_) {
return R.isFunction(anf_fun21301165)?anf_fun21301165.app(d709756):R.ffi.throwNonFunApp(L[146],anf_fun21301165,[d709756]);
};
try {
if(--R.GAS > 0) {
$z11571158 = $f11631164();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11631164,
"from":L[146]});
}
} catch($e11551156) {
if(R.isCont($e11551156)) {
var $ss11591160 = {"from":L[146],
"go":function(anf_arg21311166) {
return $Hanf_arg32151167(anf_arg21311166,A119,PP521,anf_arg21291122,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e11551156.stack[R.EXN_STACKHEIGHT++] = $ss11591160;
}
if(R.isPyretException($e11551156)) {
$e11551156.pyretStack.push(L[146]);
}
throw $e11551156;
}
var $ret11611162 = $Hanf_arg32151167($z11571158,A119,PP521,anf_arg21291122,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret11611162;
};
var $Hanf_arg32151167 = function(anf_arg21311166,A119,PP521,anf_arg21291122,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21321178 = G(list3375,"make",L[148]);
var $z11701171 = D;
var $f11761177 = function(_) {
return R.isFunction(anf_fun21321178)?anf_fun21321178.app([]):R.ffi.throwNonFunApp(L[148],anf_fun21321178,[[]]);
};
try {
if(--R.GAS > 0) {
$z11701171 = $f11761177();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11761177,
"from":L[148]});
}
} catch($e11681169) {
if(R.isCont($e11681169)) {
var $ss11721173 = {"from":L[148],
"go":function(anf_arg21331179) {
return $Hanf_arg32141180(anf_arg21331179,A119,PP521,anf_arg21291122,anf_arg21311166,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e11681169.stack[R.EXN_STACKHEIGHT++] = $ss11721173;
}
if(R.isPyretException($e11681169)) {
$e11681169.pyretStack.push(L[148]);
}
throw $e11681169;
}
var $ret11741175 = $Hanf_arg32141180($z11701171,A119,PP521,anf_arg21291122,anf_arg21311166,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret11741175;
};
var $Hanf_arg32141180 = function(anf_arg21331179,A119,PP521,anf_arg21291122,anf_arg21311166,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21341193 = G(A119,"s-type-let-expr",L[150]);
var anf_fun21351191 = G(list3375,"make",L[149]);
var $z11831184 = D;
var $f11891190 = function(_) {
return R.isFunction(anf_fun21351191)?anf_fun21351191.app([]):R.ffi.throwNonFunApp(L[149],anf_fun21351191,[[]]);
};
try {
if(--R.GAS > 0) {
$z11831184 = $f11891190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11891190,
"from":L[149]});
}
} catch($e11811182) {
if(R.isCont($e11811182)) {
var $ss11851186 = {"from":L[149],
"go":function(anf_arg21361192) {
return $Hanf_arg32131194(anf_arg21361192,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_fun21271123,anf_fun21341193,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e11811182.stack[R.EXN_STACKHEIGHT++] = $ss11851186;
}
if(R.isPyretException($e11811182)) {
$e11811182.pyretStack.push(L[149]);
}
throw $e11811182;
}
var $ret11871188 = $Hanf_arg32131194($z11831184,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_fun21271123,anf_fun21341193,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret11871188;
};
var $Hanf_arg32131194 = function(anf_arg21361192,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_fun21271123,anf_fun21341193,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21371206 = G(A119,"s-block",L[158]);
var anf_fun21381207 = G(list3375,"make",L[157]);
var anf_fun21391208 = G(A119,"s-block",L[156]);
var anf_fun21401209 = G(list3375,"make",L[155]);
var anf_fun21411210 = G(A119,"s-let-expr",L[154]);
var anf_fun21421211 = G(list3375,"make",L[153]);
var anf_fun21431212 = G(A119,"s-let-bind",L[152]);
var $z11971198 = D;
var $f12031204 = function(_) {
return R.isFunction(b710760)?b710760.app(("x")):R.ffi.throwNonFunApp(L[151],b710760,[("x")]);
};
try {
if(--R.GAS > 0) {
$z11971198 = $f12031204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12031204,
"from":L[151]});
}
} catch($e11951196) {
if(R.isCont($e11951196)) {
var $ss11991200 = {"from":L[151],
"go":function(anf_arg21441205) {
return $Hanf_arg32121213(anf_arg21441205,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,anf_fun21431212,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e11951196.stack[R.EXN_STACKHEIGHT++] = $ss11991200;
}
if(R.isPyretException($e11951196)) {
$e11951196.pyretStack.push(L[151]);
}
throw $e11951196;
}
var $ret12011202 = $Hanf_arg32121213($z11971198,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,anf_fun21431212,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret12011202;
};
var $Hanf_arg32121213 = function(anf_arg21441205,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,anf_fun21431212,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21451224 = G(A119,"s-num",L[160]);
var $z12161217 = D;
var $f12221223 = function(_) {
return R.isFunction(anf_fun21451224)?anf_fun21451224.app(d709756,(10)):R.ffi.throwNonFunApp(L[159],anf_fun21451224,[d709756,(10)]);
};
try {
if(--R.GAS > 0) {
$z12161217 = $f12221223();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12221223,
"from":L[159]});
}
} catch($e12141215) {
if(R.isCont($e12141215)) {
var $ss12181219 = {"from":L[159],
"go":function(anf_arg21461225) {
return $Hanf_arg32111226(anf_arg21461225,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21441205,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,anf_fun21431212,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e12141215.stack[R.EXN_STACKHEIGHT++] = $ss12181219;
}
if(R.isPyretException($e12141215)) {
$e12141215.pyretStack.push(L[159]);
}
throw $e12141215;
}
var $ret12201221 = $Hanf_arg32111226($z12161217,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21441205,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,anf_fun21431212,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret12201221;
};
var $Hanf_arg32111226 = function(anf_arg21461225,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21441205,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,anf_fun21431212,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z12291230 = D;
var $f12351236 = function(_) {
return R.isFunction(anf_fun21431212)?anf_fun21431212.app(d709756,anf_arg21441205,anf_arg21461225):R.ffi.throwNonFunApp(L[161],anf_fun21431212,[d709756,anf_arg21441205,anf_arg21461225]);
};
try {
if(--R.GAS > 0) {
$z12291230 = $f12351236();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12351236,
"from":L[161]});
}
} catch($e12271228) {
if(R.isCont($e12271228)) {
var $ss12311232 = {"from":L[161],
"go":function(anf_array_val21471237) {
return $Hanf_array_val32101238(anf_array_val21471237,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e12271228.stack[R.EXN_STACKHEIGHT++] = $ss12311232;
}
if(R.isPyretException($e12271228)) {
$e12271228.pyretStack.push(L[161]);
}
throw $e12271228;
}
var $ret12331234 = $Hanf_array_val32101238($z12291230,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret12331234;
};
var $Hanf_array_val32101238 = function(anf_array_val21471237,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21421211,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z12411242 = D;
var $f12471248 = function(_) {
return R.isFunction(anf_fun21421211)?anf_fun21421211.app([anf_array_val21471237]):R.ffi.throwNonFunApp(L[153],anf_fun21421211,[[anf_array_val21471237]]);
};
try {
if(--R.GAS > 0) {
$z12411242 = $f12471248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12471248,
"from":L[153]});
}
} catch($e12391240) {
if(R.isCont($e12391240)) {
var $ss12431244 = {"from":L[153],
"go":function(anf_arg21481249) {
return $Hanf_arg32091250(anf_arg21481249,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e12391240.stack[R.EXN_STACKHEIGHT++] = $ss12431244;
}
if(R.isPyretException($e12391240)) {
$e12391240.pyretStack.push(L[153]);
}
throw $e12391240;
}
var $ret12451246 = $Hanf_arg32091250($z12411242,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret12451246;
};
var $Hanf_arg32091250 = function(anf_arg21481249,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21491262 = G(A119,"s-module",L[163]);
var $z12531254 = D;
var $f12591260 = function(_) {
return R.isFunction(id712761)?id712761.app(("nothing")):R.ffi.throwNonFunApp(L[162],id712761,[("nothing")]);
};
try {
if(--R.GAS > 0) {
$z12531254 = $f12591260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12591260,
"from":L[162]});
}
} catch($e12511252) {
if(R.isCont($e12511252)) {
var $ss12551256 = {"from":L[162],
"go":function(anf_arg21501261) {
return $Hanf_arg32081263(anf_arg21501261,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e12511252.stack[R.EXN_STACKHEIGHT++] = $ss12551256;
}
if(R.isPyretException($e12511252)) {
$e12511252.pyretStack.push(L[162]);
}
throw $e12511252;
}
var $ret12571258 = $Hanf_arg32081263($z12531254,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret12571258;
};
var $Hanf_arg32081263 = function(anf_arg21501261,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z12661267 = D;
var $f12721273 = function(_) {
return R.isFunction(id712761)?id712761.app(("x")):R.ffi.throwNonFunApp(L[164],id712761,[("x")]);
};
try {
if(--R.GAS > 0) {
$z12661267 = $f12721273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12721273,
"from":L[164]});
}
} catch($e12641265) {
if(R.isCont($e12641265)) {
var $ss12681269 = {"from":L[164],
"go":function(anf_arg21511274) {
return $Hanf_arg32071275(anf_arg21511274,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_arg21501261,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e12641265.stack[R.EXN_STACKHEIGHT++] = $ss12681269;
}
if(R.isPyretException($e12641265)) {
$e12641265.pyretStack.push(L[164]);
}
throw $e12641265;
}
var $ret12701271 = $Hanf_arg32071275($z12661267,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_arg21501261,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret12701271;
};
var $Hanf_arg32071275 = function(anf_arg21511274,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_arg21501261,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21521286 = G(list3375,"make",L[165]);
var $z12781279 = D;
var $f12841285 = function(_) {
return R.isFunction(anf_fun21521286)?anf_fun21521286.app([]):R.ffi.throwNonFunApp(L[165],anf_fun21521286,[[]]);
};
try {
if(--R.GAS > 0) {
$z12781279 = $f12841285();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12841285,
"from":L[165]});
}
} catch($e12761277) {
if(R.isCont($e12761277)) {
var $ss12801281 = {"from":L[165],
"go":function(anf_arg21531287) {
return $Hanf_arg32061288(anf_arg21531287,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_arg21501261,anf_arg21511274,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e12761277.stack[R.EXN_STACKHEIGHT++] = $ss12801281;
}
if(R.isPyretException($e12761277)) {
$e12761277.pyretStack.push(L[165]);
}
throw $e12761277;
}
var $ret12821283 = $Hanf_arg32061288($z12781279,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_arg21501261,anf_arg21511274,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret12821283;
};
var $Hanf_arg32061288 = function(anf_arg21531287,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_arg21501261,anf_arg21511274,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,anf_fun21491262,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z12911292 = D;
var $f12971298 = function(_) {
return R.isFunction(anf_fun21491262)?anf_fun21491262.app(d709756,anf_arg21501261,anf_arg21511274,anf_arg21531287,checks7141109):R.ffi.throwNonFunApp(L[166],anf_fun21491262,[d709756,anf_arg21501261,anf_arg21511274,anf_arg21531287,checks7141109]);
};
try {
if(--R.GAS > 0) {
$z12911292 = $f12971298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12971298,
"from":L[166]});
}
} catch($e12891290) {
if(R.isCont($e12891290)) {
var $ss12931294 = {"from":L[166],
"go":function(anf_arg21541299) {
return $Hanf_arg32051300(anf_arg21541299,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e12891290.stack[R.EXN_STACKHEIGHT++] = $ss12931294;
}
if(R.isPyretException($e12891290)) {
$e12891290.pyretStack.push(L[166]);
}
throw $e12891290;
}
var $ret12951296 = $Hanf_arg32051300($z12911292,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret12951296;
};
var $Hanf_arg32051300 = function(anf_arg21541299,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_arg21481249,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,anf_fun21411210,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z13031304 = D;
var $f13091310 = function(_) {
return R.isFunction(anf_fun21411210)?anf_fun21411210.app(d709756,anf_arg21481249,anf_arg21541299):R.ffi.throwNonFunApp(L[167],anf_fun21411210,[d709756,anf_arg21481249,anf_arg21541299]);
};
try {
if(--R.GAS > 0) {
$z13031304 = $f13091310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13091310,
"from":L[167]});
}
} catch($e13011302) {
if(R.isCont($e13011302)) {
var $ss13051306 = {"from":L[167],
"go":function(anf_array_val21551311) {
return $Hanf_array_val32041312(anf_array_val21551311,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13011302.stack[R.EXN_STACKHEIGHT++] = $ss13051306;
}
if(R.isPyretException($e13011302)) {
$e13011302.pyretStack.push(L[167]);
}
throw $e13011302;
}
var $ret13071308 = $Hanf_array_val32041312($z13031304,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret13071308;
};
var $Hanf_array_val32041312 = function(anf_array_val21551311,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,anf_fun21401209,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z13151316 = D;
var $f13211322 = function(_) {
return R.isFunction(anf_fun21401209)?anf_fun21401209.app([anf_array_val21551311]):R.ffi.throwNonFunApp(L[155],anf_fun21401209,[[anf_array_val21551311]]);
};
try {
if(--R.GAS > 0) {
$z13151316 = $f13211322();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13211322,
"from":L[155]});
}
} catch($e13131314) {
if(R.isCont($e13131314)) {
var $ss13171318 = {"from":L[155],
"go":function(anf_arg21561323) {
return $Hanf_arg32031324(anf_arg21561323,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13131314.stack[R.EXN_STACKHEIGHT++] = $ss13171318;
}
if(R.isPyretException($e13131314)) {
$e13131314.pyretStack.push(L[155]);
}
throw $e13131314;
}
var $ret13191320 = $Hanf_arg32031324($z13151316,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret13191320;
};
var $Hanf_arg32031324 = function(anf_arg21561323,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,anf_fun21391208,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z13271328 = D;
var $f13331334 = function(_) {
return R.isFunction(anf_fun21391208)?anf_fun21391208.app(d709756,anf_arg21561323):R.ffi.throwNonFunApp(L[168],anf_fun21391208,[d709756,anf_arg21561323]);
};
try {
if(--R.GAS > 0) {
$z13271328 = $f13331334();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13331334,
"from":L[168]});
}
} catch($e13251326) {
if(R.isCont($e13251326)) {
var $ss13291330 = {"from":L[168],
"go":function(anf_array_val21571335) {
return $Hanf_array_val32021336(anf_array_val21571335,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13251326.stack[R.EXN_STACKHEIGHT++] = $ss13291330;
}
if(R.isPyretException($e13251326)) {
$e13251326.pyretStack.push(L[168]);
}
throw $e13251326;
}
var $ret13311332 = $Hanf_array_val32021336($z13271328,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret13311332;
};
var $Hanf_array_val32021336 = function(anf_array_val21571335,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,anf_fun21381207,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z13391340 = D;
var $f13451346 = function(_) {
return R.isFunction(anf_fun21381207)?anf_fun21381207.app([anf_array_val21571335]):R.ffi.throwNonFunApp(L[157],anf_fun21381207,[[anf_array_val21571335]]);
};
try {
if(--R.GAS > 0) {
$z13391340 = $f13451346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13451346,
"from":L[157]});
}
} catch($e13371338) {
if(R.isCont($e13371338)) {
var $ss13411342 = {"from":L[157],
"go":function(anf_arg21581347) {
return $Hanf_arg32011348(anf_arg21581347,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13371338.stack[R.EXN_STACKHEIGHT++] = $ss13411342;
}
if(R.isPyretException($e13371338)) {
$e13371338.pyretStack.push(L[157]);
}
throw $e13371338;
}
var $ret13431344 = $Hanf_arg32011348($z13391340,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret13431344;
};
var $Hanf_arg32011348 = function(anf_arg21581347,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,anf_fun21371206,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z13511352 = D;
var $f13571358 = function(_) {
return R.isFunction(anf_fun21371206)?anf_fun21371206.app(d709756,anf_arg21581347):R.ffi.throwNonFunApp(L[169],anf_fun21371206,[d709756,anf_arg21581347]);
};
try {
if(--R.GAS > 0) {
$z13511352 = $f13571358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13571358,
"from":L[169]});
}
} catch($e13491350) {
if(R.isCont($e13491350)) {
var $ss13531354 = {"from":L[169],
"go":function(anf_arg21591359) {
return $Hanf_arg32001360(anf_arg21591359,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13491350.stack[R.EXN_STACKHEIGHT++] = $ss13531354;
}
if(R.isPyretException($e13491350)) {
$e13491350.pyretStack.push(L[169]);
}
throw $e13491350;
}
var $ret13551356 = $Hanf_arg32001360($z13511352,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret13551356;
};
var $Hanf_arg32001360 = function(anf_arg21591359,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21361192,anf_fun21271123,anf_fun21341193,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z13631364 = D;
var $f13691370 = function(_) {
return R.isFunction(anf_fun21341193)?anf_fun21341193.app(d709756,anf_arg21361192,anf_arg21591359):R.ffi.throwNonFunApp(L[170],anf_fun21341193,[d709756,anf_arg21361192,anf_arg21591359]);
};
try {
if(--R.GAS > 0) {
$z13631364 = $f13691370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13691370,
"from":L[170]});
}
} catch($e13611362) {
if(R.isCont($e13611362)) {
var $ss13651366 = {"from":L[170],
"go":function(anf_arg21601371) {
return $Hanf_arg31991372(anf_arg21601371,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13611362.stack[R.EXN_STACKHEIGHT++] = $ss13651366;
}
if(R.isPyretException($e13611362)) {
$e13611362.pyretStack.push(L[170]);
}
throw $e13611362;
}
var $ret13671368 = $Hanf_arg31991372($z13631364,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret13671368;
};
var $Hanf_arg31991372 = function(anf_arg21601371,A119,PP521,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_fun21271123,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z13751376 = D;
var $f13811382 = function(_) {
return R.isFunction(anf_fun21271123)?anf_fun21271123.app(d709756,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21601371):R.ffi.throwNonFunApp(L[171],anf_fun21271123,[d709756,anf_arg21291122,anf_arg21311166,anf_arg21331179,anf_arg21601371]);
};
try {
if(--R.GAS > 0) {
$z13751376 = $f13811382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13811382,
"from":L[171]});
}
} catch($e13731374) {
if(R.isCont($e13731374)) {
var $ss13771378 = {"from":L[171],
"go":function(compare17181383) {
return $Hcompare131981384(compare17181383,A119,PP521,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13731374.stack[R.EXN_STACKHEIGHT++] = $ss13771378;
}
if(R.isPyretException($e13731374)) {
$e13731374.pyretStack.push(L[171]);
}
throw $e13731374;
}
var $ret13791380 = $Hcompare131981384($z13751376,A119,PP521,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret13791380;
};
var $Hcompare131981384 = function(compare17181383,A119,PP521,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21611395 = G(builtins10,"current-checker",L[172]);
var $z13871388 = D;
var $f13931394 = function(_) {
return R.isFunction(anf_fun21611395)?anf_fun21611395.app():R.ffi.throwNonFunApp(L[172],anf_fun21611395,[]);
};
try {
if(--R.GAS > 0) {
$z13871388 = $f13931394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13931394,
"from":L[172]});
}
} catch($e13851386) {
if(R.isCont($e13851386)) {
var $ss13891390 = {"from":L[172],
"go":function(anf_bracket21621396) {
return $Hanf_bracket31971397(anf_bracket21621396,A119,PP521,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13851386.stack[R.EXN_STACKHEIGHT++] = $ss13891390;
}
if(R.isPyretException($e13851386)) {
$e13851386.pyretStack.push(L[172]);
}
throw $e13851386;
}
var $ret13911392 = $Hanf_bracket31971397($z13871388,A119,PP521,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret13911392;
};
var $Hanf_bracket31971397 = function(anf_bracket21621396,A119,PP521,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21631410 = G(anf_bracket21621396,"check-is",L[172]);
var anf_fun21641408 = G(PP521,"surface-parse",L[174]);
var $z14001401 = D;
var $f14061407 = function(_) {
return R.isFunction(anf_fun21641408)?anf_fun21641408.app(("provide x end x = 10 nothing"),("test")):R.ffi.throwNonFunApp(L[173],anf_fun21641408,[("provide x end x = 10 nothing"),("test")]);
};
try {
if(--R.GAS > 0) {
$z14001401 = $f14061407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14061407,
"from":L[173]});
}
} catch($e13981399) {
if(R.isCont($e13981399)) {
var $ss14021403 = {"from":L[173],
"go":function(anf_arg21651409) {
return $Hanf_arg31961411(anf_arg21651409,A119,PP521,anf_fun21631410,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e13981399.stack[R.EXN_STACKHEIGHT++] = $ss14021403;
}
if(R.isPyretException($e13981399)) {
$e13981399.pyretStack.push(L[173]);
}
throw $e13981399;
}
var $ret14041405 = $Hanf_arg31961411($z14001401,A119,PP521,anf_fun21631410,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret14041405;
};
var $Hanf_arg31961411 = function(anf_arg21651409,A119,PP521,anf_fun21631410,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10) {
var $z14141415 = D;
var $f14201421 = function(_) {
return R.isFunction(ds7161124)?ds7161124.app(anf_arg21651409):R.ffi.throwNonFunApp(L[175],ds7161124,[anf_arg21651409]);
};
try {
if(--R.GAS > 0) {
$z14141415 = $f14201421();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14201421,
"from":L[175]});
}
} catch($e14121413) {
if(R.isCont($e14121413)) {
var $ss14161417 = {"from":L[175],
"go":function(anf_arg21661422) {
return $Hanf_arg31951423(anf_arg21661422,A119,PP521,anf_fun21631410,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e14121413.stack[R.EXN_STACKHEIGHT++] = $ss14161417;
}
if(R.isPyretException($e14121413)) {
$e14121413.pyretStack.push(L[175]);
}
throw $e14121413;
}
var $ret14181419 = $Hanf_arg31951423($z14141415,A119,PP521,anf_fun21631410,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret14181419;
};
var $Hanf_arg31951423 = function(anf_arg21661422,A119,PP521,anf_fun21631410,b710760,checks7141109,compare17181383,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_arg21671434 = R.makeSrcloc(L[172]);
var $z14261427 = D;
var $f14321433 = function(_) {
return R.isFunction(anf_fun21631410)?anf_fun21631410.app(("ds(PP.surface-parse(\"provide x end x = 10 nothing\", \"test\")) is compare1"),anf_arg21661422,compare17181383,anf_arg21671434):R.ffi.throwNonFunApp(L[172],anf_fun21631410,[("ds(PP.surface-parse(\"provide x end x = 10 nothing\", \"test\")) is compare1"),anf_arg21661422,compare17181383,anf_arg21671434]);
};
try {
if(--R.GAS > 0) {
$z14261427 = $f14321433();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14321433,
"from":L[172]});
}
} catch($e14241425) {
if(R.isCont($e14241425)) {
var $ss14281429 = {"from":L[172],
"go":function(anf_begin_app_dropped31641435) {
return $Hanf_begin_app_dropped31941436(anf_begin_app_dropped31641435,A119,PP521,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e14241425.stack[R.EXN_STACKHEIGHT++] = $ss14281429;
}
if(R.isPyretException($e14241425)) {
$e14241425.pyretStack.push(L[172]);
}
throw $e14241425;
}
var $ret14301431 = $Hanf_begin_app_dropped31941436($z14261427,A119,PP521,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret14301431;
};
var $Hanf_begin_app_dropped31941436 = function(anf_begin_app_dropped31641435,A119,PP521,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21681449 = G(A119,"s-program",L[178]);
var anf_fun21691447 = G(A119,"s-provide-none",L[177]);
var $z14391440 = D;
var $f14451446 = function(_) {
return R.isFunction(anf_fun21691447)?anf_fun21691447.app(d709756):R.ffi.throwNonFunApp(L[176],anf_fun21691447,[d709756]);
};
try {
if(--R.GAS > 0) {
$z14391440 = $f14451446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14451446,
"from":L[176]});
}
} catch($e14371438) {
if(R.isCont($e14371438)) {
var $ss14411442 = {"from":L[176],
"go":function(anf_arg21701448) {
return $Hanf_arg31931450(anf_arg21701448,A119,PP521,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e14371438.stack[R.EXN_STACKHEIGHT++] = $ss14411442;
}
if(R.isPyretException($e14371438)) {
$e14371438.pyretStack.push(L[176]);
}
throw $e14371438;
}
var $ret14431444 = $Hanf_arg31931450($z14391440,A119,PP521,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret14431444;
};
var $Hanf_arg31931450 = function(anf_arg21701448,A119,PP521,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21711461 = G(A119,"s-provide-types-none",L[180]);
var $z14531454 = D;
var $f14591460 = function(_) {
return R.isFunction(anf_fun21711461)?anf_fun21711461.app(d709756):R.ffi.throwNonFunApp(L[179],anf_fun21711461,[d709756]);
};
try {
if(--R.GAS > 0) {
$z14531454 = $f14591460();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14591460,
"from":L[179]});
}
} catch($e14511452) {
if(R.isCont($e14511452)) {
var $ss14551456 = {"from":L[179],
"go":function(anf_arg21721462) {
return $Hanf_arg31921463(anf_arg21721462,A119,PP521,anf_arg21701448,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e14511452.stack[R.EXN_STACKHEIGHT++] = $ss14551456;
}
if(R.isPyretException($e14511452)) {
$e14511452.pyretStack.push(L[179]);
}
throw $e14511452;
}
var $ret14571458 = $Hanf_arg31921463($z14531454,A119,PP521,anf_arg21701448,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret14571458;
};
var $Hanf_arg31921463 = function(anf_arg21721462,A119,PP521,anf_arg21701448,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21731476 = G(list3375,"make",L[184]);
var anf_fun21741477 = G(A119,"s-import",L[183]);
var anf_fun21751474 = G(A119,"s-file-import",L[182]);
var $z14661467 = D;
var $f14721473 = function(_) {
return R.isFunction(anf_fun21751474)?anf_fun21751474.app(d709756,("./foo.arr")):R.ffi.throwNonFunApp(L[181],anf_fun21751474,[d709756,("./foo.arr")]);
};
try {
if(--R.GAS > 0) {
$z14661467 = $f14721473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14721473,
"from":L[181]});
}
} catch($e14641465) {
if(R.isCont($e14641465)) {
var $ss14681469 = {"from":L[181],
"go":function(anf_arg21761475) {
return $Hanf_arg31911478(anf_arg21761475,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,anf_fun21731476,anf_fun21741477,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e14641465.stack[R.EXN_STACKHEIGHT++] = $ss14681469;
}
if(R.isPyretException($e14641465)) {
$e14641465.pyretStack.push(L[181]);
}
throw $e14641465;
}
var $ret14701471 = $Hanf_arg31911478($z14661467,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,anf_fun21731476,anf_fun21741477,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret14701471;
};
var $Hanf_arg31911478 = function(anf_arg21761475,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,anf_fun21731476,anf_fun21741477,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21771489 = G(A119,"s-name",L[186]);
var $z14811482 = D;
var $f14871488 = function(_) {
return R.isFunction(anf_fun21771489)?anf_fun21771489.app(d709756,("F")):R.ffi.throwNonFunApp(L[185],anf_fun21771489,[d709756,("F")]);
};
try {
if(--R.GAS > 0) {
$z14811482 = $f14871488();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14871488,
"from":L[185]});
}
} catch($e14791480) {
if(R.isCont($e14791480)) {
var $ss14831484 = {"from":L[185],
"go":function(anf_arg21781490) {
return $Hanf_arg31901491(anf_arg21781490,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21761475,anf_fun21681449,anf_fun21731476,anf_fun21741477,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e14791480.stack[R.EXN_STACKHEIGHT++] = $ss14831484;
}
if(R.isPyretException($e14791480)) {
$e14791480.pyretStack.push(L[185]);
}
throw $e14791480;
}
var $ret14851486 = $Hanf_arg31901491($z14811482,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21761475,anf_fun21681449,anf_fun21731476,anf_fun21741477,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret14851486;
};
var $Hanf_arg31901491 = function(anf_arg21781490,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21761475,anf_fun21681449,anf_fun21731476,anf_fun21741477,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z14941495 = D;
var $f15001501 = function(_) {
return R.isFunction(anf_fun21741477)?anf_fun21741477.app(d709756,anf_arg21761475,anf_arg21781490):R.ffi.throwNonFunApp(L[187],anf_fun21741477,[d709756,anf_arg21761475,anf_arg21781490]);
};
try {
if(--R.GAS > 0) {
$z14941495 = $f15001501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15001501,
"from":L[187]});
}
} catch($e14921493) {
if(R.isCont($e14921493)) {
var $ss14961497 = {"from":L[187],
"go":function(anf_array_val21791502) {
return $Hanf_array_val31891503(anf_array_val21791502,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,anf_fun21731476,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e14921493.stack[R.EXN_STACKHEIGHT++] = $ss14961497;
}
if(R.isPyretException($e14921493)) {
$e14921493.pyretStack.push(L[187]);
}
throw $e14921493;
}
var $ret14981499 = $Hanf_array_val31891503($z14941495,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,anf_fun21731476,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret14981499;
};
var $Hanf_array_val31891503 = function(anf_array_val21791502,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,anf_fun21731476,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z15061507 = D;
var $f15121513 = function(_) {
return R.isFunction(anf_fun21731476)?anf_fun21731476.app([anf_array_val21791502]):R.ffi.throwNonFunApp(L[184],anf_fun21731476,[[anf_array_val21791502]]);
};
try {
if(--R.GAS > 0) {
$z15061507 = $f15121513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15121513,
"from":L[184]});
}
} catch($e15041505) {
if(R.isCont($e15041505)) {
var $ss15081509 = {"from":L[184],
"go":function(anf_arg21801514) {
return $Hanf_arg31881515(anf_arg21801514,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e15041505.stack[R.EXN_STACKHEIGHT++] = $ss15081509;
}
if(R.isPyretException($e15041505)) {
$e15041505.pyretStack.push(L[184]);
}
throw $e15041505;
}
var $ret15101511 = $Hanf_arg31881515($z15061507,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret15101511;
};
var $Hanf_arg31881515 = function(anf_arg21801514,A119,PP521,anf_arg21701448,anf_arg21721462,anf_fun21681449,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21811528 = G(A119,"s-type-let-expr",L[189]);
var anf_fun21821526 = G(list3375,"make",L[188]);
var $z15181519 = D;
var $f15241525 = function(_) {
return R.isFunction(anf_fun21821526)?anf_fun21821526.app([]):R.ffi.throwNonFunApp(L[188],anf_fun21821526,[[]]);
};
try {
if(--R.GAS > 0) {
$z15181519 = $f15241525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15241525,
"from":L[188]});
}
} catch($e15161517) {
if(R.isCont($e15161517)) {
var $ss15201521 = {"from":L[188],
"go":function(anf_arg21831527) {
return $Hanf_arg31871529(anf_arg21831527,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_fun21681449,anf_fun21811528,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e15161517.stack[R.EXN_STACKHEIGHT++] = $ss15201521;
}
if(R.isPyretException($e15161517)) {
$e15161517.pyretStack.push(L[188]);
}
throw $e15161517;
}
var $ret15221523 = $Hanf_arg31871529($z15181519,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_fun21681449,anf_fun21811528,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret15221523;
};
var $Hanf_arg31871529 = function(anf_arg21831527,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_fun21681449,anf_fun21811528,b710760,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21841541 = G(A119,"s-block",L[197]);
var anf_fun21851542 = G(list3375,"make",L[196]);
var anf_fun21861543 = G(A119,"s-block",L[195]);
var anf_fun21871544 = G(list3375,"make",L[194]);
var anf_fun21881545 = G(A119,"s-let-expr",L[193]);
var anf_fun21891546 = G(list3375,"make",L[192]);
var anf_fun21901547 = G(A119,"s-let-bind",L[191]);
var $z15321533 = D;
var $f15381539 = function(_) {
return R.isFunction(b710760)?b710760.app(("x")):R.ffi.throwNonFunApp(L[190],b710760,[("x")]);
};
try {
if(--R.GAS > 0) {
$z15321533 = $f15381539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15381539,
"from":L[190]});
}
} catch($e15301531) {
if(R.isCont($e15301531)) {
var $ss15341535 = {"from":L[190],
"go":function(anf_arg21911540) {
return $Hanf_arg31861548(anf_arg21911540,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,anf_fun21901547,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e15301531.stack[R.EXN_STACKHEIGHT++] = $ss15341535;
}
if(R.isPyretException($e15301531)) {
$e15301531.pyretStack.push(L[190]);
}
throw $e15301531;
}
var $ret15361537 = $Hanf_arg31861548($z15321533,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,anf_fun21901547,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret15361537;
};
var $Hanf_arg31861548 = function(anf_arg21911540,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,anf_fun21901547,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21921559 = G(A119,"s-num",L[199]);
var $z15511552 = D;
var $f15571558 = function(_) {
return R.isFunction(anf_fun21921559)?anf_fun21921559.app(d709756,(10)):R.ffi.throwNonFunApp(L[198],anf_fun21921559,[d709756,(10)]);
};
try {
if(--R.GAS > 0) {
$z15511552 = $f15571558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15571558,
"from":L[198]});
}
} catch($e15491550) {
if(R.isCont($e15491550)) {
var $ss15531554 = {"from":L[198],
"go":function(anf_arg21931560) {
return $Hanf_arg31851561(anf_arg21931560,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21911540,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,anf_fun21901547,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e15491550.stack[R.EXN_STACKHEIGHT++] = $ss15531554;
}
if(R.isPyretException($e15491550)) {
$e15491550.pyretStack.push(L[198]);
}
throw $e15491550;
}
var $ret15551556 = $Hanf_arg31851561($z15511552,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21911540,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,anf_fun21901547,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret15551556;
};
var $Hanf_arg31851561 = function(anf_arg21931560,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21911540,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,anf_fun21901547,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z15641565 = D;
var $f15701571 = function(_) {
return R.isFunction(anf_fun21901547)?anf_fun21901547.app(d709756,anf_arg21911540,anf_arg21931560):R.ffi.throwNonFunApp(L[200],anf_fun21901547,[d709756,anf_arg21911540,anf_arg21931560]);
};
try {
if(--R.GAS > 0) {
$z15641565 = $f15701571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15701571,
"from":L[200]});
}
} catch($e15621563) {
if(R.isCont($e15621563)) {
var $ss15661567 = {"from":L[200],
"go":function(anf_array_val21941572) {
return $Hanf_array_val31841573(anf_array_val21941572,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e15621563.stack[R.EXN_STACKHEIGHT++] = $ss15661567;
}
if(R.isPyretException($e15621563)) {
$e15621563.pyretStack.push(L[200]);
}
throw $e15621563;
}
var $ret15681569 = $Hanf_array_val31841573($z15641565,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret15681569;
};
var $Hanf_array_val31841573 = function(anf_array_val21941572,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21891546,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z15761577 = D;
var $f15821583 = function(_) {
return R.isFunction(anf_fun21891546)?anf_fun21891546.app([anf_array_val21941572]):R.ffi.throwNonFunApp(L[192],anf_fun21891546,[[anf_array_val21941572]]);
};
try {
if(--R.GAS > 0) {
$z15761577 = $f15821583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15821583,
"from":L[192]});
}
} catch($e15741575) {
if(R.isCont($e15741575)) {
var $ss15781579 = {"from":L[192],
"go":function(anf_arg21951584) {
return $Hanf_arg31831585(anf_arg21951584,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e15741575.stack[R.EXN_STACKHEIGHT++] = $ss15781579;
}
if(R.isPyretException($e15741575)) {
$e15741575.pyretStack.push(L[192]);
}
throw $e15741575;
}
var $ret15801581 = $Hanf_arg31831585($z15761577,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret15801581;
};
var $Hanf_arg31831585 = function(anf_arg21951584,A119,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21961597 = G(A119,"s-module",L[203]);
var anf_fun21971598 = G(A119,"s-app",L[202]);
var $z15881589 = D;
var $f15941595 = function(_) {
return R.isFunction(id712761)?id712761.app(("F")):R.ffi.throwNonFunApp(L[201],id712761,[("F")]);
};
try {
if(--R.GAS > 0) {
$z15881589 = $f15941595();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15941595,
"from":L[201]});
}
} catch($e15861587) {
if(R.isCont($e15861587)) {
var $ss15901591 = {"from":L[201],
"go":function(anf_arg21981596) {
return $Hanf_arg31821599(anf_arg21981596,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e15861587.stack[R.EXN_STACKHEIGHT++] = $ss15901591;
}
if(R.isPyretException($e15861587)) {
$e15861587.pyretStack.push(L[201]);
}
throw $e15861587;
}
var $ret15921593 = $Hanf_arg31821599($z15881589,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret15921593;
};
var $Hanf_arg31821599 = function(anf_arg21981596,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var anf_fun21991611 = G(list3375,"make",L[205]);
var $z16021603 = D;
var $f16081609 = function(_) {
return R.isFunction(id712761)?id712761.app(("x")):R.ffi.throwNonFunApp(L[204],id712761,[("x")]);
};
try {
if(--R.GAS > 0) {
$z16021603 = $f16081609();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16081609,
"from":L[204]});
}
} catch($e16001601) {
if(R.isCont($e16001601)) {
var $ss16041605 = {"from":L[204],
"go":function(anf_array_val22001610) {
return $Hanf_array_val31811612(anf_array_val22001610,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg21981596,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,anf_fun21991611,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e16001601.stack[R.EXN_STACKHEIGHT++] = $ss16041605;
}
if(R.isPyretException($e16001601)) {
$e16001601.pyretStack.push(L[204]);
}
throw $e16001601;
}
var $ret16061607 = $Hanf_array_val31811612($z16021603,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg21981596,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,anf_fun21991611,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret16061607;
};
var $Hanf_array_val31811612 = function(anf_array_val22001610,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg21981596,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,anf_fun21991611,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z16151616 = D;
var $f16211622 = function(_) {
return R.isFunction(anf_fun21991611)?anf_fun21991611.app([anf_array_val22001610]):R.ffi.throwNonFunApp(L[205],anf_fun21991611,[[anf_array_val22001610]]);
};
try {
if(--R.GAS > 0) {
$z16151616 = $f16211622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16211622,
"from":L[205]});
}
} catch($e16131614) {
if(R.isCont($e16131614)) {
var $ss16171618 = {"from":L[205],
"go":function(anf_arg22011623) {
return $Hanf_arg31801624(anf_arg22011623,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg21981596,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e16131614.stack[R.EXN_STACKHEIGHT++] = $ss16171618;
}
if(R.isPyretException($e16131614)) {
$e16131614.pyretStack.push(L[205]);
}
throw $e16131614;
}
var $ret16191620 = $Hanf_arg31801624($z16151616,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg21981596,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret16191620;
};
var $Hanf_arg31801624 = function(anf_arg22011623,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg21981596,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,anf_fun21971598,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z16271628 = D;
var $f16331634 = function(_) {
return R.isFunction(anf_fun21971598)?anf_fun21971598.app(d709756,anf_arg21981596,anf_arg22011623):R.ffi.throwNonFunApp(L[206],anf_fun21971598,[d709756,anf_arg21981596,anf_arg22011623]);
};
try {
if(--R.GAS > 0) {
$z16271628 = $f16331634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16331634,
"from":L[206]});
}
} catch($e16251626) {
if(R.isCont($e16251626)) {
var $ss16291630 = {"from":L[206],
"go":function(anf_arg22021635) {
return $Hanf_arg31791636(anf_arg22021635,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
}};
$e16251626.stack[R.EXN_STACKHEIGHT++] = $ss16291630;
}
if(R.isPyretException($e16251626)) {
$e16251626.pyretStack.push(L[206]);
}
throw $e16251626;
}
var $ret16311632 = $Hanf_arg31791636($z16271628,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,id712761,list3375,builtins10);
++R.GAS;
return $ret16311632;
};
var $Hanf_arg31791636 = function(anf_arg22021635,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,id712761,list3375,builtins10) {
var $z16391640 = D;
var $f16451646 = function(_) {
return R.isFunction(id712761)?id712761.app(("x")):R.ffi.throwNonFunApp(L[207],id712761,[("x")]);
};
try {
if(--R.GAS > 0) {
$z16391640 = $f16451646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16451646,
"from":L[207]});
}
} catch($e16371638) {
if(R.isCont($e16371638)) {
var $ss16411642 = {"from":L[207],
"go":function(anf_arg22031647) {
return $Hanf_arg31781648(anf_arg22031647,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg22021635,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,list3375,builtins10);
}};
$e16371638.stack[R.EXN_STACKHEIGHT++] = $ss16411642;
}
if(R.isPyretException($e16371638)) {
$e16371638.pyretStack.push(L[207]);
}
throw $e16371638;
}
var $ret16431644 = $Hanf_arg31781648($z16391640,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg22021635,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,list3375,builtins10);
++R.GAS;
return $ret16431644;
};
var $Hanf_arg31781648 = function(anf_arg22031647,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg22021635,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,list3375,builtins10) {
var anf_fun22041659 = G(list3375,"make",L[208]);
var $z16511652 = D;
var $f16571658 = function(_) {
return R.isFunction(anf_fun22041659)?anf_fun22041659.app([]):R.ffi.throwNonFunApp(L[208],anf_fun22041659,[[]]);
};
try {
if(--R.GAS > 0) {
$z16511652 = $f16571658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16571658,
"from":L[208]});
}
} catch($e16491650) {
if(R.isCont($e16491650)) {
var $ss16531654 = {"from":L[208],
"go":function(anf_arg22051660) {
return $Hanf_arg31771661(anf_arg22051660,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg22021635,anf_arg22031647,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,builtins10);
}};
$e16491650.stack[R.EXN_STACKHEIGHT++] = $ss16531654;
}
if(R.isPyretException($e16491650)) {
$e16491650.pyretStack.push(L[208]);
}
throw $e16491650;
}
var $ret16551656 = $Hanf_arg31771661($z16511652,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg22021635,anf_arg22031647,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,builtins10);
++R.GAS;
return $ret16551656;
};
var $Hanf_arg31771661 = function(anf_arg22051660,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_arg22021635,anf_arg22031647,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,anf_fun21961597,checks7141109,d709756,ds7161124,builtins10) {
var $z16641665 = D;
var $f16701671 = function(_) {
return R.isFunction(anf_fun21961597)?anf_fun21961597.app(d709756,anf_arg22021635,anf_arg22031647,anf_arg22051660,checks7141109):R.ffi.throwNonFunApp(L[209],anf_fun21961597,[d709756,anf_arg22021635,anf_arg22031647,anf_arg22051660,checks7141109]);
};
try {
if(--R.GAS > 0) {
$z16641665 = $f16701671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16701671,
"from":L[209]});
}
} catch($e16621663) {
if(R.isCont($e16621663)) {
var $ss16661667 = {"from":L[209],
"go":function(anf_arg22061672) {
return $Hanf_arg31761673(anf_arg22061672,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,d709756,ds7161124,builtins10);
}};
$e16621663.stack[R.EXN_STACKHEIGHT++] = $ss16661667;
}
if(R.isPyretException($e16621663)) {
$e16621663.pyretStack.push(L[209]);
}
throw $e16621663;
}
var $ret16681669 = $Hanf_arg31761673($z16641665,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,d709756,ds7161124,builtins10);
++R.GAS;
return $ret16681669;
};
var $Hanf_arg31761673 = function(anf_arg22061672,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_arg21951584,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,anf_fun21881545,d709756,ds7161124,builtins10) {
var $z16761677 = D;
var $f16821683 = function(_) {
return R.isFunction(anf_fun21881545)?anf_fun21881545.app(d709756,anf_arg21951584,anf_arg22061672):R.ffi.throwNonFunApp(L[210],anf_fun21881545,[d709756,anf_arg21951584,anf_arg22061672]);
};
try {
if(--R.GAS > 0) {
$z16761677 = $f16821683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16821683,
"from":L[210]});
}
} catch($e16741675) {
if(R.isCont($e16741675)) {
var $ss16781679 = {"from":L[210],
"go":function(anf_array_val22071684) {
return $Hanf_array_val31751685(anf_array_val22071684,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,d709756,ds7161124,builtins10);
}};
$e16741675.stack[R.EXN_STACKHEIGHT++] = $ss16781679;
}
if(R.isPyretException($e16741675)) {
$e16741675.pyretStack.push(L[210]);
}
throw $e16741675;
}
var $ret16801681 = $Hanf_array_val31751685($z16761677,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,d709756,ds7161124,builtins10);
++R.GAS;
return $ret16801681;
};
var $Hanf_array_val31751685 = function(anf_array_val22071684,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,anf_fun21871544,d709756,ds7161124,builtins10) {
var $z16881689 = D;
var $f16941695 = function(_) {
return R.isFunction(anf_fun21871544)?anf_fun21871544.app([anf_array_val22071684]):R.ffi.throwNonFunApp(L[194],anf_fun21871544,[[anf_array_val22071684]]);
};
try {
if(--R.GAS > 0) {
$z16881689 = $f16941695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16941695,
"from":L[194]});
}
} catch($e16861687) {
if(R.isCont($e16861687)) {
var $ss16901691 = {"from":L[194],
"go":function(anf_arg22081696) {
return $Hanf_arg31741697(anf_arg22081696,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,d709756,ds7161124,builtins10);
}};
$e16861687.stack[R.EXN_STACKHEIGHT++] = $ss16901691;
}
if(R.isPyretException($e16861687)) {
$e16861687.pyretStack.push(L[194]);
}
throw $e16861687;
}
var $ret16921693 = $Hanf_arg31741697($z16881689,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,d709756,ds7161124,builtins10);
++R.GAS;
return $ret16921693;
};
var $Hanf_arg31741697 = function(anf_arg22081696,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,anf_fun21861543,d709756,ds7161124,builtins10) {
var $z17001701 = D;
var $f17061707 = function(_) {
return R.isFunction(anf_fun21861543)?anf_fun21861543.app(d709756,anf_arg22081696):R.ffi.throwNonFunApp(L[211],anf_fun21861543,[d709756,anf_arg22081696]);
};
try {
if(--R.GAS > 0) {
$z17001701 = $f17061707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17061707,
"from":L[211]});
}
} catch($e16981699) {
if(R.isCont($e16981699)) {
var $ss17021703 = {"from":L[211],
"go":function(anf_array_val22091708) {
return $Hanf_array_val31731709(anf_array_val22091708,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,d709756,ds7161124,builtins10);
}};
$e16981699.stack[R.EXN_STACKHEIGHT++] = $ss17021703;
}
if(R.isPyretException($e16981699)) {
$e16981699.pyretStack.push(L[211]);
}
throw $e16981699;
}
var $ret17041705 = $Hanf_array_val31731709($z17001701,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,d709756,ds7161124,builtins10);
++R.GAS;
return $ret17041705;
};
var $Hanf_array_val31731709 = function(anf_array_val22091708,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,anf_fun21851542,d709756,ds7161124,builtins10) {
var $z17121713 = D;
var $f17181719 = function(_) {
return R.isFunction(anf_fun21851542)?anf_fun21851542.app([anf_array_val22091708]):R.ffi.throwNonFunApp(L[196],anf_fun21851542,[[anf_array_val22091708]]);
};
try {
if(--R.GAS > 0) {
$z17121713 = $f17181719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17181719,
"from":L[196]});
}
} catch($e17101711) {
if(R.isCont($e17101711)) {
var $ss17141715 = {"from":L[196],
"go":function(anf_arg22101720) {
return $Hanf_arg31721721(anf_arg22101720,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,d709756,ds7161124,builtins10);
}};
$e17101711.stack[R.EXN_STACKHEIGHT++] = $ss17141715;
}
if(R.isPyretException($e17101711)) {
$e17101711.pyretStack.push(L[196]);
}
throw $e17101711;
}
var $ret17161717 = $Hanf_arg31721721($z17121713,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,d709756,ds7161124,builtins10);
++R.GAS;
return $ret17161717;
};
var $Hanf_arg31721721 = function(anf_arg22101720,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,anf_fun21841541,d709756,ds7161124,builtins10) {
var $z17241725 = D;
var $f17301731 = function(_) {
return R.isFunction(anf_fun21841541)?anf_fun21841541.app(d709756,anf_arg22101720):R.ffi.throwNonFunApp(L[212],anf_fun21841541,[d709756,anf_arg22101720]);
};
try {
if(--R.GAS > 0) {
$z17241725 = $f17301731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17301731,
"from":L[212]});
}
} catch($e17221723) {
if(R.isCont($e17221723)) {
var $ss17261727 = {"from":L[212],
"go":function(anf_arg22111732) {
return $Hanf_arg31711733(anf_arg22111732,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,d709756,ds7161124,builtins10);
}};
$e17221723.stack[R.EXN_STACKHEIGHT++] = $ss17261727;
}
if(R.isPyretException($e17221723)) {
$e17221723.pyretStack.push(L[212]);
}
throw $e17221723;
}
var $ret17281729 = $Hanf_arg31711733($z17241725,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,d709756,ds7161124,builtins10);
++R.GAS;
return $ret17281729;
};
var $Hanf_arg31711733 = function(anf_arg22111732,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg21831527,anf_fun21681449,anf_fun21811528,d709756,ds7161124,builtins10) {
var $z17361737 = D;
var $f17421743 = function(_) {
return R.isFunction(anf_fun21811528)?anf_fun21811528.app(d709756,anf_arg21831527,anf_arg22111732):R.ffi.throwNonFunApp(L[213],anf_fun21811528,[d709756,anf_arg21831527,anf_arg22111732]);
};
try {
if(--R.GAS > 0) {
$z17361737 = $f17421743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17421743,
"from":L[213]});
}
} catch($e17341735) {
if(R.isCont($e17341735)) {
var $ss17381739 = {"from":L[213],
"go":function(anf_arg22121744) {
return $Hanf_arg31701745(anf_arg22121744,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_fun21681449,d709756,ds7161124,builtins10);
}};
$e17341735.stack[R.EXN_STACKHEIGHT++] = $ss17381739;
}
if(R.isPyretException($e17341735)) {
$e17341735.pyretStack.push(L[213]);
}
throw $e17341735;
}
var $ret17401741 = $Hanf_arg31701745($z17361737,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_fun21681449,d709756,ds7161124,builtins10);
++R.GAS;
return $ret17401741;
};
var $Hanf_arg31701745 = function(anf_arg22121744,PP521,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_fun21681449,d709756,ds7161124,builtins10) {
var $z17481749 = D;
var $f17541755 = function(_) {
return R.isFunction(anf_fun21681449)?anf_fun21681449.app(d709756,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg22121744):R.ffi.throwNonFunApp(L[214],anf_fun21681449,[d709756,anf_arg21701448,anf_arg21721462,anf_arg21801514,anf_arg22121744]);
};
try {
if(--R.GAS > 0) {
$z17481749 = $f17541755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17541755,
"from":L[214]});
}
} catch($e17461747) {
if(R.isCont($e17461747)) {
var $ss17501751 = {"from":L[214],
"go":function(compare27191756) {
return $Hcompare231691757(compare27191756,PP521,ds7161124,builtins10);
}};
$e17461747.stack[R.EXN_STACKHEIGHT++] = $ss17501751;
}
if(R.isPyretException($e17461747)) {
$e17461747.pyretStack.push(L[214]);
}
throw $e17461747;
}
var $ret17521753 = $Hcompare231691757($z17481749,PP521,ds7161124,builtins10);
++R.GAS;
return $ret17521753;
};
var $Hcompare231691757 = function(compare27191756,PP521,ds7161124,builtins10) {
var anf_fun22131768 = G(builtins10,"current-checker",L[215]);
var $z17601761 = D;
var $f17661767 = function(_) {
return R.isFunction(anf_fun22131768)?anf_fun22131768.app():R.ffi.throwNonFunApp(L[215],anf_fun22131768,[]);
};
try {
if(--R.GAS > 0) {
$z17601761 = $f17661767();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17661767,
"from":L[215]});
}
} catch($e17581759) {
if(R.isCont($e17581759)) {
var $ss17621763 = {"from":L[215],
"go":function(anf_bracket22141769) {
return $Hanf_bracket31681770(anf_bracket22141769,PP521,compare27191756,ds7161124);
}};
$e17581759.stack[R.EXN_STACKHEIGHT++] = $ss17621763;
}
if(R.isPyretException($e17581759)) {
$e17581759.pyretStack.push(L[215]);
}
throw $e17581759;
}
var $ret17641765 = $Hanf_bracket31681770($z17601761,PP521,compare27191756,ds7161124);
++R.GAS;
return $ret17641765;
};
var $Hanf_bracket31681770 = function(anf_bracket22141769,PP521,compare27191756,ds7161124) {
var anf_fun22151783 = G(anf_bracket22141769,"check-is",L[215]);
var anf_fun22161781 = G(PP521,"surface-parse",L[217]);
var $z17731774 = D;
var $f17791780 = function(_) {
return R.isFunction(anf_fun22161781)?anf_fun22161781.app(("provide x end import 'foo.arr' as F x = 10 F(x)"),("test")):R.ffi.throwNonFunApp(L[216],anf_fun22161781,[("provide x end import 'foo.arr' as F x = 10 F(x)"),("test")]);
};
try {
if(--R.GAS > 0) {
$z17731774 = $f17791780();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17791780,
"from":L[216]});
}
} catch($e17711772) {
if(R.isCont($e17711772)) {
var $ss17751776 = {"from":L[216],
"go":function(anf_arg22171782) {
return $Hanf_arg31671784(anf_arg22171782,anf_fun22151783,compare27191756,ds7161124);
}};
$e17711772.stack[R.EXN_STACKHEIGHT++] = $ss17751776;
}
if(R.isPyretException($e17711772)) {
$e17711772.pyretStack.push(L[216]);
}
throw $e17711772;
}
var $ret17771778 = $Hanf_arg31671784($z17731774,anf_fun22151783,compare27191756,ds7161124);
++R.GAS;
return $ret17771778;
};
var $Hanf_arg31671784 = function(anf_arg22171782,anf_fun22151783,compare27191756,ds7161124) {
var $z17871788 = D;
var $f17931794 = function(_) {
return R.isFunction(ds7161124)?ds7161124.app(anf_arg22171782):R.ffi.throwNonFunApp(L[218],ds7161124,[anf_arg22171782]);
};
try {
if(--R.GAS > 0) {
$z17871788 = $f17931794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f17931794,
"from":L[218]});
}
} catch($e17851786) {
if(R.isCont($e17851786)) {
var $ss17891790 = {"from":L[218],
"go":function(anf_arg22181795) {
return $Hanf_arg31661796(anf_arg22181795,anf_fun22151783,compare27191756);
}};
$e17851786.stack[R.EXN_STACKHEIGHT++] = $ss17891790;
}
if(R.isPyretException($e17851786)) {
$e17851786.pyretStack.push(L[218]);
}
throw $e17851786;
}
var $ret17911792 = $Hanf_arg31661796($z17871788,anf_fun22151783,compare27191756);
++R.GAS;
return $ret17911792;
};
var $Hanf_arg31661796 = function(anf_arg22181795,anf_fun22151783,compare27191756) {
var anf_arg22191807 = R.makeSrcloc(L[215]);
var $z17991800 = D;
var $f18051806 = function(_) {
return R.isFunction(anf_fun22151783)?anf_fun22151783.app(("ds(PP.surface-parse(\"provide x end import 'foo.arr' as F x = 10 F(x)\", \"test\")) is\n  compare2"),anf_arg22181795,compare27191756,anf_arg22191807):R.ffi.throwNonFunApp(L[80],anf_fun22151783,[("ds(PP.surface-parse(\"provide x end import 'foo.arr' as F x = 10 F(x)\", \"test\")) is\n  compare2"),anf_arg22181795,compare27191756,anf_arg22191807]);
};
try {
if(--R.GAS > 0) {
$z17991800 = $f18051806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18051806,
"from":L[80]});
}
} catch($e17971798) {
if(R.isCont($e17971798)) {
var $ss18011802 = {"from":L[80],
"go":function(ann_DASH_check_DASH_temp21031808) {
return $Hann_DASH_check_DASH_temp31651809(ann_DASH_check_DASH_temp21031808);
}};
$e17971798.stack[R.EXN_STACKHEIGHT++] = $ss18011802;
}
if(R.isPyretException($e17971798)) {
$e17971798.pyretStack.push(L[80]);
}
throw $e17971798;
}
var $ret18031804 = $Hann_DASH_check_DASH_temp31651809($z17991800);
++R.GAS;
return $ret18031804;
};
var $Hann_DASH_check_DASH_temp31651809 = function(ann_DASH_check_DASH_temp21031808) {
return ann_DASH_check_DASH_temp21031808;
};
var $Hanf_bracket31631139 = function(anf_bracket21241138,A119) {
var anf_fun21251820 = G(anf_bracket21241138,"visit",L[220]);
var anf_arg21261821 = G(A119,"dummy-loc-visitor",L[219]);
var $z18121813 = D;
var $f18181819 = function(_) {
return R.isFunction(anf_fun21251820)?anf_fun21251820.app(anf_arg21261821):R.ffi.throwNonFunApp(L[141],anf_fun21251820,[anf_arg21261821]);
};
try {
if(--R.GAS > 0) {
$z18121813 = $f18181819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18181819,
"from":L[141]});
}
} catch($e18101811) {
if(R.isCont($e18101811)) {
var $ss18141815 = {"from":L[141],
"go":function(ann_DASH_check_DASH_temp21221822) {
return $Hann_DASH_check_DASH_temp31621823(ann_DASH_check_DASH_temp21221822);
}};
$e18101811.stack[R.EXN_STACKHEIGHT++] = $ss18141815;
}
if(R.isPyretException($e18101811)) {
$e18101811.pyretStack.push(L[141]);
}
throw $e18101811;
}
var $ret18161817 = $Hann_DASH_check_DASH_temp31621823($z18121813);
++R.GAS;
return $ret18161817;
};
var $Hann_DASH_check_DASH_temp31621823 = function(ann_DASH_check_DASH_temp21221822) {
return ann_DASH_check_DASH_temp21221822;
};
var $Hann_DASH_check_DASH_temp31611154 = function(ann_DASH_check_DASH_temp21201153) {
return ann_DASH_check_DASH_temp21201153;
};
var $Hanf_arg3160777 = function(anf_arg2112775,anf_fun2110776,d709756) {
var $z18261827 = D;
var $f18321833 = function(_) {
return R.isFunction(anf_fun2110776)?anf_fun2110776.app(d709756,anf_arg2112775):R.ffi.throwNonFunApp(L[85],anf_fun2110776,[d709756,anf_arg2112775]);
};
try {
if(--R.GAS > 0) {
$z18261827 = $f18321833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18321833,
"from":L[85]});
}
} catch($e18241825) {
if(R.isCont($e18241825)) {
var $ss18281829 = {"from":L[85],
"go":function(ann_DASH_check_DASH_temp21091834) {
return $Hann_DASH_check_DASH_temp31591835(ann_DASH_check_DASH_temp21091834);
}};
$e18241825.stack[R.EXN_STACKHEIGHT++] = $ss18281829;
}
if(R.isPyretException($e18241825)) {
$e18241825.pyretStack.push(L[85]);
}
throw $e18241825;
}
var $ret18301831 = $Hann_DASH_check_DASH_temp31591835($z18261827);
++R.GAS;
return $ret18301831;
};
var $Hann_DASH_check_DASH_temp31591835 = function(ann_DASH_check_DASH_temp21091834) {
return ann_DASH_check_DASH_temp21091834;
};
var $Hanf_arg3158792 = function(anf_arg2107790,A119,anf_fun2105791,d709756) {
var anf_arg21081846 = G(A119,"a-blank",L[221]);
var $z18381839 = D;
var $f18441845 = function(_) {
return R.isFunction(anf_fun2105791)?anf_fun2105791.app(d709756,(false),anf_arg2107790,anf_arg21081846):R.ffi.throwNonFunApp(L[89],anf_fun2105791,[d709756,(false),anf_arg2107790,anf_arg21081846]);
};
try {
if(--R.GAS > 0) {
$z18381839 = $f18441845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18441845,
"from":L[89]});
}
} catch($e18361837) {
if(R.isCont($e18361837)) {
var $ss18401841 = {"from":L[89],
"go":function(ann_DASH_check_DASH_temp21041847) {
return $Hann_DASH_check_DASH_temp31571848(ann_DASH_check_DASH_temp21041847);
}};
$e18361837.stack[R.EXN_STACKHEIGHT++] = $ss18401841;
}
if(R.isPyretException($e18361837)) {
$e18361837.pyretStack.push(L[89]);
}
throw $e18361837;
}
var $ret18421843 = $Hann_DASH_check_DASH_temp31571848($z18381839);
++R.GAS;
return $ret18421843;
};
var $Hann_DASH_check_DASH_temp31571848 = function(ann_DASH_check_DASH_temp21041847) {
return ann_DASH_check_DASH_temp21041847;
};
var $Hanf_arg3156815 = function(anf_arg1839806,A119,anf_fun1836807,anf_fun1837808,anf_fun1838809,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_fun18401859 = G(A119,"s-num",L[223]);
var $z18511852 = D;
var $f18571858 = function(_) {
return R.isFunction(anf_fun18401859)?anf_fun18401859.app(d686811,(15)):R.ffi.throwNonFunApp(L[222],anf_fun18401859,[d686811,(15)]);
};
try {
if(--R.GAS > 0) {
$z18511852 = $f18571858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18571858,
"from":L[222]});
}
} catch($e18491850) {
if(R.isCont($e18491850)) {
var $ss18531854 = {"from":L[222],
"go":function(anf_arg18411860) {
return $Hanf_arg31551861(anf_arg18411860,A119,anf_arg1839806,anf_fun1836807,anf_fun1837808,anf_fun1838809,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e18491850.stack[R.EXN_STACKHEIGHT++] = $ss18531854;
}
if(R.isPyretException($e18491850)) {
$e18491850.pyretStack.push(L[222]);
}
throw $e18491850;
}
var $ret18551856 = $Hanf_arg31551861($z18511852,A119,anf_arg1839806,anf_fun1836807,anf_fun1837808,anf_fun1838809,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret18551856;
};
var $Hanf_arg31551861 = function(anf_arg18411860,A119,anf_arg1839806,anf_fun1836807,anf_fun1837808,anf_fun1838809,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var $z18641865 = D;
var $f18701871 = function(_) {
return R.isFunction(anf_fun1838809)?anf_fun1838809.app(d686811,anf_arg1839806,anf_arg18411860):R.ffi.throwNonFunApp(L[224],anf_fun1838809,[d686811,anf_arg1839806,anf_arg18411860]);
};
try {
if(--R.GAS > 0) {
$z18641865 = $f18701871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18701871,
"from":L[224]});
}
} catch($e18621863) {
if(R.isCont($e18621863)) {
var $ss18661867 = {"from":L[224],
"go":function(anf_array_val18421872) {
return $Hanf_array_val31541873(anf_array_val18421872,A119,anf_fun1836807,anf_fun1837808,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e18621863.stack[R.EXN_STACKHEIGHT++] = $ss18661867;
}
if(R.isPyretException($e18621863)) {
$e18621863.pyretStack.push(L[224]);
}
throw $e18621863;
}
var $ret18681869 = $Hanf_array_val31541873($z18641865,A119,anf_fun1836807,anf_fun1837808,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret18681869;
};
var $Hanf_array_val31541873 = function(anf_array_val18421872,A119,anf_fun1836807,anf_fun1837808,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_fun18431885 = G(A119,"s-let-bind",L[226]);
var $z18761877 = D;
var $f18821883 = function(_) {
return R.isFunction(b687805)?b687805.app(("y")):R.ffi.throwNonFunApp(L[225],b687805,[("y")]);
};
try {
if(--R.GAS > 0) {
$z18761877 = $f18821883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18821883,
"from":L[225]});
}
} catch($e18741875) {
if(R.isCont($e18741875)) {
var $ss18781879 = {"from":L[225],
"go":function(anf_arg18441884) {
return $Hanf_arg31531886(anf_arg18441884,A119,anf_array_val18421872,anf_fun1836807,anf_fun1837808,anf_fun18431885,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e18741875.stack[R.EXN_STACKHEIGHT++] = $ss18781879;
}
if(R.isPyretException($e18741875)) {
$e18741875.pyretStack.push(L[225]);
}
throw $e18741875;
}
var $ret18801881 = $Hanf_arg31531886($z18761877,A119,anf_array_val18421872,anf_fun1836807,anf_fun1837808,anf_fun18431885,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret18801881;
};
var $Hanf_arg31531886 = function(anf_arg18441884,A119,anf_array_val18421872,anf_fun1836807,anf_fun1837808,anf_fun18431885,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_fun18451897 = G(A119,"s-num",L[228]);
var $z18891890 = D;
var $f18951896 = function(_) {
return R.isFunction(anf_fun18451897)?anf_fun18451897.app(d686811,(10)):R.ffi.throwNonFunApp(L[227],anf_fun18451897,[d686811,(10)]);
};
try {
if(--R.GAS > 0) {
$z18891890 = $f18951896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f18951896,
"from":L[227]});
}
} catch($e18871888) {
if(R.isCont($e18871888)) {
var $ss18911892 = {"from":L[227],
"go":function(anf_arg18461898) {
return $Hanf_arg31521899(anf_arg18461898,A119,anf_arg18441884,anf_array_val18421872,anf_fun1836807,anf_fun1837808,anf_fun18431885,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e18871888.stack[R.EXN_STACKHEIGHT++] = $ss18911892;
}
if(R.isPyretException($e18871888)) {
$e18871888.pyretStack.push(L[227]);
}
throw $e18871888;
}
var $ret18931894 = $Hanf_arg31521899($z18891890,A119,anf_arg18441884,anf_array_val18421872,anf_fun1836807,anf_fun1837808,anf_fun18431885,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret18931894;
};
var $Hanf_arg31521899 = function(anf_arg18461898,A119,anf_arg18441884,anf_array_val18421872,anf_fun1836807,anf_fun1837808,anf_fun18431885,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var $z19021903 = D;
var $f19081909 = function(_) {
return R.isFunction(anf_fun18431885)?anf_fun18431885.app(d686811,anf_arg18441884,anf_arg18461898):R.ffi.throwNonFunApp(L[229],anf_fun18431885,[d686811,anf_arg18441884,anf_arg18461898]);
};
try {
if(--R.GAS > 0) {
$z19021903 = $f19081909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19081909,
"from":L[229]});
}
} catch($e19001901) {
if(R.isCont($e19001901)) {
var $ss19041905 = {"from":L[229],
"go":function(anf_array_val18471910) {
return $Hanf_array_val31511911(anf_array_val18471910,A119,anf_array_val18421872,anf_fun1836807,anf_fun1837808,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e19001901.stack[R.EXN_STACKHEIGHT++] = $ss19041905;
}
if(R.isPyretException($e19001901)) {
$e19001901.pyretStack.push(L[229]);
}
throw $e19001901;
}
var $ret19061907 = $Hanf_array_val31511911($z19021903,A119,anf_array_val18421872,anf_fun1836807,anf_fun1837808,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret19061907;
};
var $Hanf_array_val31511911 = function(anf_array_val18471910,A119,anf_array_val18421872,anf_fun1836807,anf_fun1837808,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var $z19141915 = D;
var $f19201921 = function(_) {
return R.isFunction(anf_fun1837808)?anf_fun1837808.app([anf_array_val18421872,anf_array_val18471910]):R.ffi.throwNonFunApp(L[97],anf_fun1837808,[[anf_array_val18421872,anf_array_val18471910]]);
};
try {
if(--R.GAS > 0) {
$z19141915 = $f19201921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19201921,
"from":L[97]});
}
} catch($e19121913) {
if(R.isCont($e19121913)) {
var $ss19161917 = {"from":L[97],
"go":function(anf_arg18481922) {
return $Hanf_arg31501923(anf_arg18481922,A119,anf_fun1836807,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e19121913.stack[R.EXN_STACKHEIGHT++] = $ss19161917;
}
if(R.isPyretException($e19121913)) {
$e19121913.pyretStack.push(L[97]);
}
throw $e19121913;
}
var $ret19181919 = $Hanf_arg31501923($z19141915,A119,anf_fun1836807,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret19181919;
};
var $Hanf_arg31501923 = function(anf_arg18481922,A119,anf_fun1836807,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var $z19261927 = D;
var $f19321933 = function(_) {
return R.isFunction(id689812)?id689812.app(("y")):R.ffi.throwNonFunApp(L[230],id689812,[("y")]);
};
try {
if(--R.GAS > 0) {
$z19261927 = $f19321933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19321933,
"from":L[230]});
}
} catch($e19241925) {
if(R.isCont($e19241925)) {
var $ss19281929 = {"from":L[230],
"go":function(anf_arg18491934) {
return $Hanf_arg31491935(anf_arg18491934,A119,anf_arg18481922,anf_fun1836807,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e19241925.stack[R.EXN_STACKHEIGHT++] = $ss19281929;
}
if(R.isPyretException($e19241925)) {
$e19241925.pyretStack.push(L[230]);
}
throw $e19241925;
}
var $ret19301931 = $Hanf_arg31491935($z19261927,A119,anf_arg18481922,anf_fun1836807,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret19301931;
};
var $Hanf_arg31491935 = function(anf_arg18491934,A119,anf_arg18481922,anf_fun1836807,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var $z19381939 = D;
var $f19441945 = function(_) {
return R.isFunction(anf_fun1836807)?anf_fun1836807.app(d686811,anf_arg18481922,anf_arg18491934):R.ffi.throwNonFunApp(L[231],anf_fun1836807,[d686811,anf_arg18481922,anf_arg18491934]);
};
try {
if(--R.GAS > 0) {
$z19381939 = $f19441945();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19441945,
"from":L[231]});
}
} catch($e19361937) {
if(R.isCont($e19361937)) {
var $ss19401941 = {"from":L[231],
"go":function(compare16981946) {
return $Hcompare131481947(compare16981946,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e19361937.stack[R.EXN_STACKHEIGHT++] = $ss19401941;
}
if(R.isPyretException($e19361937)) {
$e19361937.pyretStack.push(L[231]);
}
throw $e19361937;
}
var $ret19421943 = $Hcompare131481947($z19381939,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret19421943;
};
var $Hcompare131481947 = function(compare16981946,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_fun18501958 = G(builtins10,"current-checker",L[232]);
var $z19501951 = D;
var $f19561957 = function(_) {
return R.isFunction(anf_fun18501958)?anf_fun18501958.app():R.ffi.throwNonFunApp(L[232],anf_fun18501958,[]);
};
try {
if(--R.GAS > 0) {
$z19501951 = $f19561957();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19561957,
"from":L[232]});
}
} catch($e19481949) {
if(R.isCont($e19481949)) {
var $ss19521953 = {"from":L[232],
"go":function(anf_bracket18511959) {
return $Hanf_bracket31471960(anf_bracket18511959,A119,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e19481949.stack[R.EXN_STACKHEIGHT++] = $ss19521953;
}
if(R.isPyretException($e19481949)) {
$e19481949.pyretStack.push(L[232]);
}
throw $e19481949;
}
var $ret19541955 = $Hanf_bracket31471960($z19501951,A119,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret19541955;
};
var $Hanf_bracket31471960 = function(anf_bracket18511959,A119,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_fun18521972 = G(anf_bracket18511959,"check-is",L[232]);
var $z19631964 = D;
var $f19691970 = function(_) {
return R.isFunction(p684813)?p684813.app(("x = 15 y = 10 y")):R.ffi.throwNonFunApp(L[233],p684813,[("x = 15 y = 10 y")]);
};
try {
if(--R.GAS > 0) {
$z19631964 = $f19691970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19691970,
"from":L[233]});
}
} catch($e19611962) {
if(R.isCont($e19611962)) {
var $ss19651966 = {"from":L[233],
"go":function(anf_bracket18531971) {
return $Hanf_bracket31461973(anf_bracket18531971,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e19611962.stack[R.EXN_STACKHEIGHT++] = $ss19651966;
}
if(R.isPyretException($e19611962)) {
$e19611962.pyretStack.push(L[233]);
}
throw $e19611962;
}
var $ret19671968 = $Hanf_bracket31461973($z19631964,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret19671968;
};
var $Hanf_bracket31461973 = function(anf_bracket18531971,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_arg18541984 = G(anf_bracket18531971,"stmts",L[235]);
var $z19761977 = D;
var $f19821983 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(anf_arg18541984,empty3670,empty3670,empty3670):R.ffi.throwNonFunApp(L[234],desugar_DASH_scope_DASH_block9165.$var,[anf_arg18541984,empty3670,empty3670,empty3670]);
};
try {
if(--R.GAS > 0) {
$z19761977 = $f19821983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19821983,
"from":L[234]});
}
} catch($e19741975) {
if(R.isCont($e19741975)) {
var $ss19781979 = {"from":L[234],
"go":function(anf_bracket18551985) {
return $Hanf_bracket31451986(anf_bracket18551985,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e19741975.stack[R.EXN_STACKHEIGHT++] = $ss19781979;
}
if(R.isPyretException($e19741975)) {
$e19741975.pyretStack.push(L[234]);
}
throw $e19741975;
}
var $ret19801981 = $Hanf_bracket31451986($z19761977,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret19801981;
};
var $Hanf_bracket31451986 = function(anf_bracket18551985,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_bracket18562001 = G(anf_bracket18551985,"first",L[239]);
var anf_fun18571997 = G(anf_bracket18562001,"visit",L[238]);
var anf_arg18581998 = G(A119,"dummy-loc-visitor",L[237]);
var $z19891990 = D;
var $f19951996 = function(_) {
return R.isFunction(anf_fun18571997)?anf_fun18571997.app(anf_arg18581998):R.ffi.throwNonFunApp(L[236],anf_fun18571997,[anf_arg18581998]);
};
try {
if(--R.GAS > 0) {
$z19891990 = $f19951996();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f19951996,
"from":L[236]});
}
} catch($e19871988) {
if(R.isCont($e19871988)) {
var $ss19911992 = {"from":L[236],
"go":function(anf_arg18591999) {
return $Hanf_arg31442000(anf_arg18591999,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e19871988.stack[R.EXN_STACKHEIGHT++] = $ss19911992;
}
if(R.isPyretException($e19871988)) {
$e19871988.pyretStack.push(L[236]);
}
throw $e19871988;
}
var $ret19931994 = $Hanf_arg31442000($z19891990,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret19931994;
};
var $Hanf_arg31442000 = function(anf_arg18591999,A119,anf_fun18521972,b687805,bs693810,compare16981946,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_arg18602012 = R.makeSrcloc(L[232]);
var $z20042005 = D;
var $f20102011 = function(_) {
return R.isFunction(anf_fun18521972)?anf_fun18521972.app(("desugar-scope-block(p(\"x = 15 y = 10 y\").stmts, empty, empty, empty).first.visit(A\n    .dummy-loc-visitor) is\n  compare1"),anf_arg18591999,compare16981946,anf_arg18602012):R.ffi.throwNonFunApp(L[232],anf_fun18521972,[("desugar-scope-block(p(\"x = 15 y = 10 y\").stmts, empty, empty, empty).first.visit(A\n    .dummy-loc-visitor) is\n  compare1"),anf_arg18591999,compare16981946,anf_arg18602012]);
};
try {
if(--R.GAS > 0) {
$z20042005 = $f20102011();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20102011,
"from":L[232]});
}
} catch($e20022003) {
if(R.isCont($e20022003)) {
var $ss20062007 = {"from":L[232],
"go":function(anf_begin_app_dropped29972013) {
return $Hanf_begin_app_dropped31432014(anf_begin_app_dropped29972013,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e20022003.stack[R.EXN_STACKHEIGHT++] = $ss20062007;
}
if(R.isPyretException($e20022003)) {
$e20022003.pyretStack.push(L[232]);
}
throw $e20022003;
}
var $ret20082009 = $Hanf_begin_app_dropped31432014($z20042005,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret20082009;
};
var $Hanf_begin_app_dropped31432014 = function(anf_begin_app_dropped29972013,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_fun18612025 = G(builtins10,"current-checker",L[240]);
var $z20172018 = D;
var $f20232024 = function(_) {
return R.isFunction(anf_fun18612025)?anf_fun18612025.app():R.ffi.throwNonFunApp(L[240],anf_fun18612025,[]);
};
try {
if(--R.GAS > 0) {
$z20172018 = $f20232024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20232024,
"from":L[240]});
}
} catch($e20152016) {
if(R.isCont($e20152016)) {
var $ss20192020 = {"from":L[240],
"go":function(anf_bracket18622026) {
return $Hanf_bracket31422027(anf_bracket18622026,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
}};
$e20152016.stack[R.EXN_STACKHEIGHT++] = $ss20192020;
}
if(R.isPyretException($e20152016)) {
$e20152016.pyretStack.push(L[240]);
}
throw $e20152016;
}
var $ret20212022 = $Hanf_bracket31422027($z20172018,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10);
++R.GAS;
return $ret20212022;
};
var $Hanf_bracket31422027 = function(anf_bracket18622026,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,p684813,thunk696814,builtins10) {
var anf_fun18632039 = G(anf_bracket18622026,"check-is",L[240]);
var $z20302031 = D;
var $f20362037 = function(_) {
return R.isFunction(p684813)?p684813.app(("x = 55 var y = 10 y")):R.ffi.throwNonFunApp(L[241],p684813,[("x = 55 var y = 10 y")]);
};
try {
if(--R.GAS > 0) {
$z20302031 = $f20362037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20362037,
"from":L[241]});
}
} catch($e20282029) {
if(R.isCont($e20282029)) {
var $ss20322033 = {"from":L[241],
"go":function(anf_bracket18642038) {
return $Hanf_bracket31412040(anf_bracket18642038,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,thunk696814,builtins10);
}};
$e20282029.stack[R.EXN_STACKHEIGHT++] = $ss20322033;
}
if(R.isPyretException($e20282029)) {
$e20282029.pyretStack.push(L[241]);
}
throw $e20282029;
}
var $ret20342035 = $Hanf_bracket31412040($z20302031,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret20342035;
};
var $Hanf_bracket31412040 = function(anf_bracket18642038,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,empty3670,id689812,list3375,thunk696814,builtins10) {
var anf_arg18652051 = G(anf_bracket18642038,"stmts",L[243]);
var $z20432044 = D;
var $f20492050 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(anf_arg18652051,empty3670,empty3670,empty3670):R.ffi.throwNonFunApp(L[242],desugar_DASH_scope_DASH_block9165.$var,[anf_arg18652051,empty3670,empty3670,empty3670]);
};
try {
if(--R.GAS > 0) {
$z20432044 = $f20492050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20492050,
"from":L[242]});
}
} catch($e20412042) {
if(R.isCont($e20412042)) {
var $ss20452046 = {"from":L[242],
"go":function(anf_bracket18662052) {
return $Hanf_bracket31402053(anf_bracket18662052,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e20412042.stack[R.EXN_STACKHEIGHT++] = $ss20452046;
}
if(R.isPyretException($e20412042)) {
$e20412042.pyretStack.push(L[242]);
}
throw $e20412042;
}
var $ret20472048 = $Hanf_bracket31402053($z20432044,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret20472048;
};
var $Hanf_bracket31402053 = function(anf_bracket18662052,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_bracket18672068 = G(anf_bracket18662052,"first",L[247]);
var anf_fun18682064 = G(anf_bracket18672068,"visit",L[246]);
var anf_arg18692065 = G(A119,"dummy-loc-visitor",L[245]);
var $z20562057 = D;
var $f20622063 = function(_) {
return R.isFunction(anf_fun18682064)?anf_fun18682064.app(anf_arg18692065):R.ffi.throwNonFunApp(L[244],anf_fun18682064,[anf_arg18692065]);
};
try {
if(--R.GAS > 0) {
$z20562057 = $f20622063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20622063,
"from":L[244]});
}
} catch($e20542055) {
if(R.isCont($e20542055)) {
var $ss20582059 = {"from":L[244],
"go":function(anf_arg18702066) {
return $Hanf_arg31392067(anf_arg18702066,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e20542055.stack[R.EXN_STACKHEIGHT++] = $ss20582059;
}
if(R.isPyretException($e20542055)) {
$e20542055.pyretStack.push(L[244]);
}
throw $e20542055;
}
var $ret20602061 = $Hanf_arg31392067($z20562057,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret20602061;
};
var $Hanf_arg31392067 = function(anf_arg18702066,A119,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun18712080 = G(A119,"s-let-expr",L[251]);
var anf_fun18722081 = G(list3375,"make",L[250]);
var anf_fun18732082 = G(A119,"s-let-bind",L[249]);
var $z20712072 = D;
var $f20772078 = function(_) {
return R.isFunction(b687805)?b687805.app(("x")):R.ffi.throwNonFunApp(L[248],b687805,[("x")]);
};
try {
if(--R.GAS > 0) {
$z20712072 = $f20772078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20772078,
"from":L[248]});
}
} catch($e20692070) {
if(R.isCont($e20692070)) {
var $ss20732074 = {"from":L[248],
"go":function(anf_arg18742079) {
return $Hanf_arg31382083(anf_arg18742079,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18732082,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e20692070.stack[R.EXN_STACKHEIGHT++] = $ss20732074;
}
if(R.isPyretException($e20692070)) {
$e20692070.pyretStack.push(L[248]);
}
throw $e20692070;
}
var $ret20752076 = $Hanf_arg31382083($z20712072,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18732082,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret20752076;
};
var $Hanf_arg31382083 = function(anf_arg18742079,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18732082,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun18752094 = G(A119,"s-num",L[253]);
var $z20862087 = D;
var $f20922093 = function(_) {
return R.isFunction(anf_fun18752094)?anf_fun18752094.app(d686811,(55)):R.ffi.throwNonFunApp(L[252],anf_fun18752094,[d686811,(55)]);
};
try {
if(--R.GAS > 0) {
$z20862087 = $f20922093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f20922093,
"from":L[252]});
}
} catch($e20842085) {
if(R.isCont($e20842085)) {
var $ss20882089 = {"from":L[252],
"go":function(anf_arg18762095) {
return $Hanf_arg31372096(anf_arg18762095,A119,anf_arg18702066,anf_arg18742079,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18732082,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e20842085.stack[R.EXN_STACKHEIGHT++] = $ss20882089;
}
if(R.isPyretException($e20842085)) {
$e20842085.pyretStack.push(L[252]);
}
throw $e20842085;
}
var $ret20902091 = $Hanf_arg31372096($z20862087,A119,anf_arg18702066,anf_arg18742079,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18732082,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret20902091;
};
var $Hanf_arg31372096 = function(anf_arg18762095,A119,anf_arg18702066,anf_arg18742079,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18732082,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z20992100 = D;
var $f21052106 = function(_) {
return R.isFunction(anf_fun18732082)?anf_fun18732082.app(d686811,anf_arg18742079,anf_arg18762095):R.ffi.throwNonFunApp(L[254],anf_fun18732082,[d686811,anf_arg18742079,anf_arg18762095]);
};
try {
if(--R.GAS > 0) {
$z20992100 = $f21052106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21052106,
"from":L[254]});
}
} catch($e20972098) {
if(R.isCont($e20972098)) {
var $ss21012102 = {"from":L[254],
"go":function(anf_array_val18772107) {
return $Hanf_array_val31362108(anf_array_val18772107,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,anf_fun18722081,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e20972098.stack[R.EXN_STACKHEIGHT++] = $ss21012102;
}
if(R.isPyretException($e20972098)) {
$e20972098.pyretStack.push(L[254]);
}
throw $e20972098;
}
var $ret21032104 = $Hanf_array_val31362108($z20992100,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,anf_fun18722081,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret21032104;
};
var $Hanf_array_val31362108 = function(anf_array_val18772107,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,anf_fun18722081,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun18782120 = G(A119,"s-var-bind",L[256]);
var $z21112112 = D;
var $f21172118 = function(_) {
return R.isFunction(b687805)?b687805.app(("y")):R.ffi.throwNonFunApp(L[255],b687805,[("y")]);
};
try {
if(--R.GAS > 0) {
$z21112112 = $f21172118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21172118,
"from":L[255]});
}
} catch($e21092110) {
if(R.isCont($e21092110)) {
var $ss21132114 = {"from":L[255],
"go":function(anf_arg18792119) {
return $Hanf_arg31352121(anf_arg18792119,A119,anf_arg18702066,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18782120,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e21092110.stack[R.EXN_STACKHEIGHT++] = $ss21132114;
}
if(R.isPyretException($e21092110)) {
$e21092110.pyretStack.push(L[255]);
}
throw $e21092110;
}
var $ret21152116 = $Hanf_arg31352121($z21112112,A119,anf_arg18702066,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18782120,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret21152116;
};
var $Hanf_arg31352121 = function(anf_arg18792119,A119,anf_arg18702066,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18782120,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun18802132 = G(A119,"s-num",L[258]);
var $z21242125 = D;
var $f21302131 = function(_) {
return R.isFunction(anf_fun18802132)?anf_fun18802132.app(d686811,(10)):R.ffi.throwNonFunApp(L[257],anf_fun18802132,[d686811,(10)]);
};
try {
if(--R.GAS > 0) {
$z21242125 = $f21302131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21302131,
"from":L[257]});
}
} catch($e21222123) {
if(R.isCont($e21222123)) {
var $ss21262127 = {"from":L[257],
"go":function(anf_arg18812133) {
return $Hanf_arg31342134(anf_arg18812133,A119,anf_arg18702066,anf_arg18792119,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18782120,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e21222123.stack[R.EXN_STACKHEIGHT++] = $ss21262127;
}
if(R.isPyretException($e21222123)) {
$e21222123.pyretStack.push(L[257]);
}
throw $e21222123;
}
var $ret21282129 = $Hanf_arg31342134($z21242125,A119,anf_arg18702066,anf_arg18792119,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18782120,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret21282129;
};
var $Hanf_arg31342134 = function(anf_arg18812133,A119,anf_arg18702066,anf_arg18792119,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,anf_fun18782120,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z21372138 = D;
var $f21432144 = function(_) {
return R.isFunction(anf_fun18782120)?anf_fun18782120.app(d686811,anf_arg18792119,anf_arg18812133):R.ffi.throwNonFunApp(L[259],anf_fun18782120,[d686811,anf_arg18792119,anf_arg18812133]);
};
try {
if(--R.GAS > 0) {
$z21372138 = $f21432144();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21432144,
"from":L[259]});
}
} catch($e21352136) {
if(R.isCont($e21352136)) {
var $ss21392140 = {"from":L[259],
"go":function(anf_array_val18822145) {
return $Hanf_array_val31332146(anf_array_val18822145,A119,anf_arg18702066,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e21352136.stack[R.EXN_STACKHEIGHT++] = $ss21392140;
}
if(R.isPyretException($e21352136)) {
$e21352136.pyretStack.push(L[259]);
}
throw $e21352136;
}
var $ret21412142 = $Hanf_array_val31332146($z21372138,A119,anf_arg18702066,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret21412142;
};
var $Hanf_array_val31332146 = function(anf_array_val18822145,A119,anf_arg18702066,anf_array_val18772107,anf_fun18632039,anf_fun18712080,anf_fun18722081,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z21492150 = D;
var $f21552156 = function(_) {
return R.isFunction(anf_fun18722081)?anf_fun18722081.app([anf_array_val18772107,anf_array_val18822145]):R.ffi.throwNonFunApp(L[250],anf_fun18722081,[[anf_array_val18772107,anf_array_val18822145]]);
};
try {
if(--R.GAS > 0) {
$z21492150 = $f21552156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21552156,
"from":L[250]});
}
} catch($e21472148) {
if(R.isCont($e21472148)) {
var $ss21512152 = {"from":L[250],
"go":function(anf_arg18832157) {
return $Hanf_arg31322158(anf_arg18832157,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e21472148.stack[R.EXN_STACKHEIGHT++] = $ss21512152;
}
if(R.isPyretException($e21472148)) {
$e21472148.pyretStack.push(L[250]);
}
throw $e21472148;
}
var $ret21532154 = $Hanf_arg31322158($z21492150,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret21532154;
};
var $Hanf_arg31322158 = function(anf_arg18832157,A119,anf_arg18702066,anf_fun18632039,anf_fun18712080,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z21612162 = D;
var $f21672168 = function(_) {
return R.isFunction(id689812)?id689812.app(("y")):R.ffi.throwNonFunApp(L[260],id689812,[("y")]);
};
try {
if(--R.GAS > 0) {
$z21612162 = $f21672168();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21672168,
"from":L[260]});
}
} catch($e21592160) {
if(R.isCont($e21592160)) {
var $ss21632164 = {"from":L[260],
"go":function(anf_arg18842169) {
return $Hanf_arg31312170(anf_arg18842169,A119,anf_arg18702066,anf_arg18832157,anf_fun18632039,anf_fun18712080,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e21592160.stack[R.EXN_STACKHEIGHT++] = $ss21632164;
}
if(R.isPyretException($e21592160)) {
$e21592160.pyretStack.push(L[260]);
}
throw $e21592160;
}
var $ret21652166 = $Hanf_arg31312170($z21612162,A119,anf_arg18702066,anf_arg18832157,anf_fun18632039,anf_fun18712080,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret21652166;
};
var $Hanf_arg31312170 = function(anf_arg18842169,A119,anf_arg18702066,anf_arg18832157,anf_fun18632039,anf_fun18712080,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z21732174 = D;
var $f21792180 = function(_) {
return R.isFunction(anf_fun18712080)?anf_fun18712080.app(d686811,anf_arg18832157,anf_arg18842169):R.ffi.throwNonFunApp(L[261],anf_fun18712080,[d686811,anf_arg18832157,anf_arg18842169]);
};
try {
if(--R.GAS > 0) {
$z21732174 = $f21792180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21792180,
"from":L[261]});
}
} catch($e21712172) {
if(R.isCont($e21712172)) {
var $ss21752176 = {"from":L[261],
"go":function(anf_arg18852181) {
return $Hanf_arg31302182(anf_arg18852181,A119,anf_arg18702066,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e21712172.stack[R.EXN_STACKHEIGHT++] = $ss21752176;
}
if(R.isPyretException($e21712172)) {
$e21712172.pyretStack.push(L[261]);
}
throw $e21712172;
}
var $ret21772178 = $Hanf_arg31302182($z21732174,A119,anf_arg18702066,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret21772178;
};
var $Hanf_arg31302182 = function(anf_arg18852181,A119,anf_arg18702066,anf_fun18632039,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_arg18862193 = R.makeSrcloc(L[240]);
var $z21852186 = D;
var $f21912192 = function(_) {
return R.isFunction(anf_fun18632039)?anf_fun18632039.app(("desugar-scope-block(p(\"x = 55 var y = 10 y\").stmts, empty, empty, empty).first\n  .visit(A.dummy-loc-visitor) is\n  A.s-let-expr(d,\n    [list: \n      A.s-let-bind(d, b(\"x\"), A.s-num(d, 55)),\n      A.s-var-bind(d, b(\"y\"), A.s-num(d, 10))\n    ],\n    id(\"y\"))"),anf_arg18702066,anf_arg18852181,anf_arg18862193):R.ffi.throwNonFunApp(L[240],anf_fun18632039,[("desugar-scope-block(p(\"x = 55 var y = 10 y\").stmts, empty, empty, empty).first\n  .visit(A.dummy-loc-visitor) is\n  A.s-let-expr(d,\n    [list: \n      A.s-let-bind(d, b(\"x\"), A.s-num(d, 55)),\n      A.s-var-bind(d, b(\"y\"), A.s-num(d, 10))\n    ],\n    id(\"y\"))"),anf_arg18702066,anf_arg18852181,anf_arg18862193]);
};
try {
if(--R.GAS > 0) {
$z21852186 = $f21912192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f21912192,
"from":L[240]});
}
} catch($e21832184) {
if(R.isCont($e21832184)) {
var $ss21872188 = {"from":L[240],
"go":function(anf_begin_app_dropped29982194) {
return $Hanf_begin_app_dropped31292195(anf_begin_app_dropped29982194,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e21832184.stack[R.EXN_STACKHEIGHT++] = $ss21872188;
}
if(R.isPyretException($e21832184)) {
$e21832184.pyretStack.push(L[240]);
}
throw $e21832184;
}
var $ret21892190 = $Hanf_begin_app_dropped31292195($z21852186,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret21892190;
};
var $Hanf_begin_app_dropped31292195 = function(anf_begin_app_dropped29982194,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun18872206 = G(builtins10,"current-checker",L[262]);
var $z21982199 = D;
var $f22042205 = function(_) {
return R.isFunction(anf_fun18872206)?anf_fun18872206.app():R.ffi.throwNonFunApp(L[262],anf_fun18872206,[]);
};
try {
if(--R.GAS > 0) {
$z21982199 = $f22042205();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22042205,
"from":L[262]});
}
} catch($e21962197) {
if(R.isCont($e21962197)) {
var $ss22002201 = {"from":L[262],
"go":function(anf_bracket18882207) {
return $Hanf_bracket31282208(anf_bracket18882207,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e21962197.stack[R.EXN_STACKHEIGHT++] = $ss22002201;
}
if(R.isPyretException($e21962197)) {
$e21962197.pyretStack.push(L[262]);
}
throw $e21962197;
}
var $ret22022203 = $Hanf_bracket31282208($z21982199,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret22022203;
};
var $Hanf_bracket31282208 = function(anf_bracket18882207,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun18892220 = G(anf_bracket18882207,"check-is",L[262]);
var $z22112212 = D;
var $f22172218 = function(_) {
return R.isFunction(bs693810)?bs693810.app(("x = 7 print(2) var y = 10 y")):R.ffi.throwNonFunApp(L[263],bs693810,[("x = 7 print(2) var y = 10 y")]);
};
try {
if(--R.GAS > 0) {
$z22112212 = $f22172218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22172218,
"from":L[263]});
}
} catch($e22092210) {
if(R.isCont($e22092210)) {
var $ss22132214 = {"from":L[263],
"go":function(anf_arg18902219) {
return $Hanf_arg31272221(anf_arg18902219,A119,anf_fun18892220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e22092210.stack[R.EXN_STACKHEIGHT++] = $ss22132214;
}
if(R.isPyretException($e22092210)) {
$e22092210.pyretStack.push(L[263]);
}
throw $e22092210;
}
var $ret22152216 = $Hanf_arg31272221($z22112212,A119,anf_fun18892220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret22152216;
};
var $Hanf_arg31272221 = function(anf_arg18902219,A119,anf_fun18892220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun18912233 = G(A119,"s-block",L[269]);
var anf_fun18922234 = G(list3375,"make",L[268]);
var anf_fun18932235 = G(A119,"s-let-expr",L[267]);
var anf_fun18942236 = G(list3375,"make",L[266]);
var anf_fun18952237 = G(A119,"s-let-bind",L[265]);
var $z22242225 = D;
var $f22302231 = function(_) {
return R.isFunction(b687805)?b687805.app(("x")):R.ffi.throwNonFunApp(L[264],b687805,[("x")]);
};
try {
if(--R.GAS > 0) {
$z22242225 = $f22302231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22302231,
"from":L[264]});
}
} catch($e22222223) {
if(R.isCont($e22222223)) {
var $ss22262227 = {"from":L[264],
"go":function(anf_arg18962232) {
return $Hanf_arg31262238(anf_arg18962232,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,anf_fun18952237,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e22222223.stack[R.EXN_STACKHEIGHT++] = $ss22262227;
}
if(R.isPyretException($e22222223)) {
$e22222223.pyretStack.push(L[264]);
}
throw $e22222223;
}
var $ret22282229 = $Hanf_arg31262238($z22242225,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,anf_fun18952237,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret22282229;
};
var $Hanf_arg31262238 = function(anf_arg18962232,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,anf_fun18952237,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun18972249 = G(A119,"s-num",L[271]);
var $z22412242 = D;
var $f22472248 = function(_) {
return R.isFunction(anf_fun18972249)?anf_fun18972249.app(d686811,(7)):R.ffi.throwNonFunApp(L[270],anf_fun18972249,[d686811,(7)]);
};
try {
if(--R.GAS > 0) {
$z22412242 = $f22472248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22472248,
"from":L[270]});
}
} catch($e22392240) {
if(R.isCont($e22392240)) {
var $ss22432244 = {"from":L[270],
"go":function(anf_arg18982250) {
return $Hanf_arg31252251(anf_arg18982250,A119,anf_arg18902219,anf_arg18962232,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,anf_fun18952237,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e22392240.stack[R.EXN_STACKHEIGHT++] = $ss22432244;
}
if(R.isPyretException($e22392240)) {
$e22392240.pyretStack.push(L[270]);
}
throw $e22392240;
}
var $ret22452246 = $Hanf_arg31252251($z22412242,A119,anf_arg18902219,anf_arg18962232,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,anf_fun18952237,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret22452246;
};
var $Hanf_arg31252251 = function(anf_arg18982250,A119,anf_arg18902219,anf_arg18962232,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,anf_fun18952237,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z22542255 = D;
var $f22602261 = function(_) {
return R.isFunction(anf_fun18952237)?anf_fun18952237.app(d686811,anf_arg18962232,anf_arg18982250):R.ffi.throwNonFunApp(L[272],anf_fun18952237,[d686811,anf_arg18962232,anf_arg18982250]);
};
try {
if(--R.GAS > 0) {
$z22542255 = $f22602261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22602261,
"from":L[272]});
}
} catch($e22522253) {
if(R.isCont($e22522253)) {
var $ss22562257 = {"from":L[272],
"go":function(anf_array_val18992262) {
return $Hanf_array_val31242263(anf_array_val18992262,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e22522253.stack[R.EXN_STACKHEIGHT++] = $ss22562257;
}
if(R.isPyretException($e22522253)) {
$e22522253.pyretStack.push(L[272]);
}
throw $e22522253;
}
var $ret22582259 = $Hanf_array_val31242263($z22542255,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret22582259;
};
var $Hanf_array_val31242263 = function(anf_array_val18992262,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun18942236,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z22662267 = D;
var $f22722273 = function(_) {
return R.isFunction(anf_fun18942236)?anf_fun18942236.app([anf_array_val18992262]):R.ffi.throwNonFunApp(L[266],anf_fun18942236,[[anf_array_val18992262]]);
};
try {
if(--R.GAS > 0) {
$z22662267 = $f22722273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22722273,
"from":L[266]});
}
} catch($e22642265) {
if(R.isCont($e22642265)) {
var $ss22682269 = {"from":L[266],
"go":function(anf_arg19002274) {
return $Hanf_arg31232275(anf_arg19002274,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e22642265.stack[R.EXN_STACKHEIGHT++] = $ss22682269;
}
if(R.isPyretException($e22642265)) {
$e22642265.pyretStack.push(L[266]);
}
throw $e22642265;
}
var $ret22702271 = $Hanf_arg31232275($z22662267,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret22702271;
};
var $Hanf_arg31232275 = function(anf_arg19002274,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun19012287 = G(A119,"s-block",L[276]);
var anf_fun19022288 = G(list3375,"make",L[275]);
var anf_fun19032289 = G(A119,"s-app",L[274]);
var $z22782279 = D;
var $f22842285 = function(_) {
return R.isFunction(id689812)?id689812.app(("print")):R.ffi.throwNonFunApp(L[273],id689812,[("print")]);
};
try {
if(--R.GAS > 0) {
$z22782279 = $f22842285();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22842285,
"from":L[273]});
}
} catch($e22762277) {
if(R.isCont($e22762277)) {
var $ss22802281 = {"from":L[273],
"go":function(anf_arg19042286) {
return $Hanf_arg31222290(anf_arg19042286,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e22762277.stack[R.EXN_STACKHEIGHT++] = $ss22802281;
}
if(R.isPyretException($e22762277)) {
$e22762277.pyretStack.push(L[273]);
}
throw $e22762277;
}
var $ret22822283 = $Hanf_arg31222290($z22782279,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret22822283;
};
var $Hanf_arg31222290 = function(anf_arg19042286,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun19052303 = G(list3375,"make",L[279]);
var anf_fun19062301 = G(A119,"s-num",L[278]);
var $z22932294 = D;
var $f22992300 = function(_) {
return R.isFunction(anf_fun19062301)?anf_fun19062301.app(d686811,(2)):R.ffi.throwNonFunApp(L[277],anf_fun19062301,[d686811,(2)]);
};
try {
if(--R.GAS > 0) {
$z22932294 = $f22992300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f22992300,
"from":L[277]});
}
} catch($e22912292) {
if(R.isCont($e22912292)) {
var $ss22952296 = {"from":L[277],
"go":function(anf_array_val19072302) {
return $Hanf_array_val31212304(anf_array_val19072302,A119,anf_arg18902219,anf_arg19002274,anf_arg19042286,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,anf_fun19052303,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e22912292.stack[R.EXN_STACKHEIGHT++] = $ss22952296;
}
if(R.isPyretException($e22912292)) {
$e22912292.pyretStack.push(L[277]);
}
throw $e22912292;
}
var $ret22972298 = $Hanf_array_val31212304($z22932294,A119,anf_arg18902219,anf_arg19002274,anf_arg19042286,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,anf_fun19052303,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret22972298;
};
var $Hanf_array_val31212304 = function(anf_array_val19072302,A119,anf_arg18902219,anf_arg19002274,anf_arg19042286,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,anf_fun19052303,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z23072308 = D;
var $f23132314 = function(_) {
return R.isFunction(anf_fun19052303)?anf_fun19052303.app([anf_array_val19072302]):R.ffi.throwNonFunApp(L[279],anf_fun19052303,[[anf_array_val19072302]]);
};
try {
if(--R.GAS > 0) {
$z23072308 = $f23132314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23132314,
"from":L[279]});
}
} catch($e23052306) {
if(R.isCont($e23052306)) {
var $ss23092310 = {"from":L[279],
"go":function(anf_arg19082315) {
return $Hanf_arg31202316(anf_arg19082315,A119,anf_arg18902219,anf_arg19002274,anf_arg19042286,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e23052306.stack[R.EXN_STACKHEIGHT++] = $ss23092310;
}
if(R.isPyretException($e23052306)) {
$e23052306.pyretStack.push(L[279]);
}
throw $e23052306;
}
var $ret23112312 = $Hanf_arg31202316($z23072308,A119,anf_arg18902219,anf_arg19002274,anf_arg19042286,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret23112312;
};
var $Hanf_arg31202316 = function(anf_arg19082315,A119,anf_arg18902219,anf_arg19002274,anf_arg19042286,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19032289,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z23192320 = D;
var $f23252326 = function(_) {
return R.isFunction(anf_fun19032289)?anf_fun19032289.app(d686811,anf_arg19042286,anf_arg19082315):R.ffi.throwNonFunApp(L[280],anf_fun19032289,[d686811,anf_arg19042286,anf_arg19082315]);
};
try {
if(--R.GAS > 0) {
$z23192320 = $f23252326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23252326,
"from":L[280]});
}
} catch($e23172318) {
if(R.isCont($e23172318)) {
var $ss23212322 = {"from":L[280],
"go":function(anf_array_val19092327) {
return $Hanf_array_val31192328(anf_array_val19092327,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e23172318.stack[R.EXN_STACKHEIGHT++] = $ss23212322;
}
if(R.isPyretException($e23172318)) {
$e23172318.pyretStack.push(L[280]);
}
throw $e23172318;
}
var $ret23232324 = $Hanf_array_val31192328($z23192320,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret23232324;
};
var $Hanf_array_val31192328 = function(anf_array_val19092327,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun19102340 = G(A119,"s-let-expr",L[284]);
var anf_fun19112341 = G(list3375,"make",L[283]);
var anf_fun19122342 = G(A119,"s-var-bind",L[282]);
var $z23312332 = D;
var $f23372338 = function(_) {
return R.isFunction(b687805)?b687805.app(("y")):R.ffi.throwNonFunApp(L[281],b687805,[("y")]);
};
try {
if(--R.GAS > 0) {
$z23312332 = $f23372338();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23372338,
"from":L[281]});
}
} catch($e23292330) {
if(R.isCont($e23292330)) {
var $ss23332334 = {"from":L[281],
"go":function(anf_arg19132339) {
return $Hanf_arg31182343(anf_arg19132339,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,anf_fun19122342,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e23292330.stack[R.EXN_STACKHEIGHT++] = $ss23332334;
}
if(R.isPyretException($e23292330)) {
$e23292330.pyretStack.push(L[281]);
}
throw $e23292330;
}
var $ret23352336 = $Hanf_arg31182343($z23312332,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,anf_fun19122342,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret23352336;
};
var $Hanf_arg31182343 = function(anf_arg19132339,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,anf_fun19122342,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun19142354 = G(A119,"s-num",L[286]);
var $z23462347 = D;
var $f23522353 = function(_) {
return R.isFunction(anf_fun19142354)?anf_fun19142354.app(d686811,(10)):R.ffi.throwNonFunApp(L[285],anf_fun19142354,[d686811,(10)]);
};
try {
if(--R.GAS > 0) {
$z23462347 = $f23522353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23522353,
"from":L[285]});
}
} catch($e23442345) {
if(R.isCont($e23442345)) {
var $ss23482349 = {"from":L[285],
"go":function(anf_arg19152355) {
return $Hanf_arg31172356(anf_arg19152355,A119,anf_arg18902219,anf_arg19002274,anf_arg19132339,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,anf_fun19122342,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e23442345.stack[R.EXN_STACKHEIGHT++] = $ss23482349;
}
if(R.isPyretException($e23442345)) {
$e23442345.pyretStack.push(L[285]);
}
throw $e23442345;
}
var $ret23502351 = $Hanf_arg31172356($z23462347,A119,anf_arg18902219,anf_arg19002274,anf_arg19132339,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,anf_fun19122342,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret23502351;
};
var $Hanf_arg31172356 = function(anf_arg19152355,A119,anf_arg18902219,anf_arg19002274,anf_arg19132339,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,anf_fun19122342,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z23592360 = D;
var $f23652366 = function(_) {
return R.isFunction(anf_fun19122342)?anf_fun19122342.app(d686811,anf_arg19132339,anf_arg19152355):R.ffi.throwNonFunApp(L[287],anf_fun19122342,[d686811,anf_arg19132339,anf_arg19152355]);
};
try {
if(--R.GAS > 0) {
$z23592360 = $f23652366();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23652366,
"from":L[287]});
}
} catch($e23572358) {
if(R.isCont($e23572358)) {
var $ss23612362 = {"from":L[287],
"go":function(anf_array_val19162367) {
return $Hanf_array_val31162368(anf_array_val19162367,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e23572358.stack[R.EXN_STACKHEIGHT++] = $ss23612362;
}
if(R.isPyretException($e23572358)) {
$e23572358.pyretStack.push(L[287]);
}
throw $e23572358;
}
var $ret23632364 = $Hanf_array_val31162368($z23592360,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret23632364;
};
var $Hanf_array_val31162368 = function(anf_array_val19162367,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,anf_fun19112341,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z23712372 = D;
var $f23772378 = function(_) {
return R.isFunction(anf_fun19112341)?anf_fun19112341.app([anf_array_val19162367]):R.ffi.throwNonFunApp(L[283],anf_fun19112341,[[anf_array_val19162367]]);
};
try {
if(--R.GAS > 0) {
$z23712372 = $f23772378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23772378,
"from":L[283]});
}
} catch($e23692370) {
if(R.isCont($e23692370)) {
var $ss23732374 = {"from":L[283],
"go":function(anf_arg19172379) {
return $Hanf_arg31152380(anf_arg19172379,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e23692370.stack[R.EXN_STACKHEIGHT++] = $ss23732374;
}
if(R.isPyretException($e23692370)) {
$e23692370.pyretStack.push(L[283]);
}
throw $e23692370;
}
var $ret23752376 = $Hanf_arg31152380($z23712372,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret23752376;
};
var $Hanf_arg31152380 = function(anf_arg19172379,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z23832384 = D;
var $f23892390 = function(_) {
return R.isFunction(id689812)?id689812.app(("y")):R.ffi.throwNonFunApp(L[288],id689812,[("y")]);
};
try {
if(--R.GAS > 0) {
$z23832384 = $f23892390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f23892390,
"from":L[288]});
}
} catch($e23812382) {
if(R.isCont($e23812382)) {
var $ss23852386 = {"from":L[288],
"go":function(anf_arg19182391) {
return $Hanf_arg31142392(anf_arg19182391,A119,anf_arg18902219,anf_arg19002274,anf_arg19172379,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e23812382.stack[R.EXN_STACKHEIGHT++] = $ss23852386;
}
if(R.isPyretException($e23812382)) {
$e23812382.pyretStack.push(L[288]);
}
throw $e23812382;
}
var $ret23872388 = $Hanf_arg31142392($z23832384,A119,anf_arg18902219,anf_arg19002274,anf_arg19172379,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret23872388;
};
var $Hanf_arg31142392 = function(anf_arg19182391,A119,anf_arg18902219,anf_arg19002274,anf_arg19172379,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,anf_fun19102340,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z23952396 = D;
var $f24012402 = function(_) {
return R.isFunction(anf_fun19102340)?anf_fun19102340.app(d686811,anf_arg19172379,anf_arg19182391):R.ffi.throwNonFunApp(L[289],anf_fun19102340,[d686811,anf_arg19172379,anf_arg19182391]);
};
try {
if(--R.GAS > 0) {
$z23952396 = $f24012402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24012402,
"from":L[289]});
}
} catch($e23932394) {
if(R.isCont($e23932394)) {
var $ss23972398 = {"from":L[289],
"go":function(anf_array_val19192403) {
return $Hanf_array_val31132404(anf_array_val19192403,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e23932394.stack[R.EXN_STACKHEIGHT++] = $ss23972398;
}
if(R.isPyretException($e23932394)) {
$e23932394.pyretStack.push(L[289]);
}
throw $e23932394;
}
var $ret23992400 = $Hanf_array_val31132404($z23952396,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret23992400;
};
var $Hanf_array_val31132404 = function(anf_array_val19192403,A119,anf_arg18902219,anf_arg19002274,anf_array_val19092327,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,anf_fun19022288,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z24072408 = D;
var $f24132414 = function(_) {
return R.isFunction(anf_fun19022288)?anf_fun19022288.app([anf_array_val19092327,anf_array_val19192403]):R.ffi.throwNonFunApp(L[275],anf_fun19022288,[[anf_array_val19092327,anf_array_val19192403]]);
};
try {
if(--R.GAS > 0) {
$z24072408 = $f24132414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24132414,
"from":L[275]});
}
} catch($e24052406) {
if(R.isCont($e24052406)) {
var $ss24092410 = {"from":L[275],
"go":function(anf_arg19202415) {
return $Hanf_arg31122416(anf_arg19202415,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e24052406.stack[R.EXN_STACKHEIGHT++] = $ss24092410;
}
if(R.isPyretException($e24052406)) {
$e24052406.pyretStack.push(L[275]);
}
throw $e24052406;
}
var $ret24112412 = $Hanf_arg31122416($z24072408,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret24112412;
};
var $Hanf_arg31122416 = function(anf_arg19202415,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,anf_fun19012287,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z24192420 = D;
var $f24252426 = function(_) {
return R.isFunction(anf_fun19012287)?anf_fun19012287.app(d686811,anf_arg19202415):R.ffi.throwNonFunApp(L[290],anf_fun19012287,[d686811,anf_arg19202415]);
};
try {
if(--R.GAS > 0) {
$z24192420 = $f24252426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24252426,
"from":L[290]});
}
} catch($e24172418) {
if(R.isCont($e24172418)) {
var $ss24212422 = {"from":L[290],
"go":function(anf_arg19212427) {
return $Hanf_arg31112428(anf_arg19212427,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e24172418.stack[R.EXN_STACKHEIGHT++] = $ss24212422;
}
if(R.isPyretException($e24172418)) {
$e24172418.pyretStack.push(L[290]);
}
throw $e24172418;
}
var $ret24232424 = $Hanf_arg31112428($z24192420,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret24232424;
};
var $Hanf_arg31112428 = function(anf_arg19212427,A119,anf_arg18902219,anf_arg19002274,anf_fun18892220,anf_fun18912233,anf_fun18922234,anf_fun18932235,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z24312432 = D;
var $f24372438 = function(_) {
return R.isFunction(anf_fun18932235)?anf_fun18932235.app(d686811,anf_arg19002274,anf_arg19212427):R.ffi.throwNonFunApp(L[291],anf_fun18932235,[d686811,anf_arg19002274,anf_arg19212427]);
};
try {
if(--R.GAS > 0) {
$z24312432 = $f24372438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24372438,
"from":L[291]});
}
} catch($e24292430) {
if(R.isCont($e24292430)) {
var $ss24332434 = {"from":L[291],
"go":function(anf_array_val19222439) {
return $Hanf_array_val31102440(anf_array_val19222439,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e24292430.stack[R.EXN_STACKHEIGHT++] = $ss24332434;
}
if(R.isPyretException($e24292430)) {
$e24292430.pyretStack.push(L[291]);
}
throw $e24292430;
}
var $ret24352436 = $Hanf_array_val31102440($z24312432,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret24352436;
};
var $Hanf_array_val31102440 = function(anf_array_val19222439,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,anf_fun18922234,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z24432444 = D;
var $f24492450 = function(_) {
return R.isFunction(anf_fun18922234)?anf_fun18922234.app([anf_array_val19222439]):R.ffi.throwNonFunApp(L[268],anf_fun18922234,[[anf_array_val19222439]]);
};
try {
if(--R.GAS > 0) {
$z24432444 = $f24492450();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24492450,
"from":L[268]});
}
} catch($e24412442) {
if(R.isCont($e24412442)) {
var $ss24452446 = {"from":L[268],
"go":function(anf_arg19232451) {
return $Hanf_arg31092452(anf_arg19232451,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e24412442.stack[R.EXN_STACKHEIGHT++] = $ss24452446;
}
if(R.isPyretException($e24412442)) {
$e24412442.pyretStack.push(L[268]);
}
throw $e24412442;
}
var $ret24472448 = $Hanf_arg31092452($z24432444,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret24472448;
};
var $Hanf_arg31092452 = function(anf_arg19232451,A119,anf_arg18902219,anf_fun18892220,anf_fun18912233,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z24552456 = D;
var $f24612462 = function(_) {
return R.isFunction(anf_fun18912233)?anf_fun18912233.app(d686811,anf_arg19232451):R.ffi.throwNonFunApp(L[292],anf_fun18912233,[d686811,anf_arg19232451]);
};
try {
if(--R.GAS > 0) {
$z24552456 = $f24612462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24612462,
"from":L[292]});
}
} catch($e24532454) {
if(R.isCont($e24532454)) {
var $ss24572458 = {"from":L[292],
"go":function(anf_arg19242463) {
return $Hanf_arg31082464(anf_arg19242463,A119,anf_arg18902219,anf_fun18892220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e24532454.stack[R.EXN_STACKHEIGHT++] = $ss24572458;
}
if(R.isPyretException($e24532454)) {
$e24532454.pyretStack.push(L[292]);
}
throw $e24532454;
}
var $ret24592460 = $Hanf_arg31082464($z24552456,A119,anf_arg18902219,anf_fun18892220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret24592460;
};
var $Hanf_arg31082464 = function(anf_arg19242463,A119,anf_arg18902219,anf_fun18892220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_arg19252475 = R.makeSrcloc(L[262]);
var $z24672468 = D;
var $f24732474 = function(_) {
return R.isFunction(anf_fun18892220)?anf_fun18892220.app(("bs(\"x = 7 print(2) var y = 10 y\") is\n  A.s-block(d,\n    [list: \n      A.s-let-expr(d,\n        [list: A.s-let-bind(d, b(\"x\"), A.s-num(d, 7))],\n        A.s-block(d,\n          [list: \n            A.s-app(d, id(\"print\"), [list: A.s-num(d, 2)]),\n            A.s-let-expr(d,\n              [list: A.s-var-bind(d, b(\"y\"), A.s-num(d, 10))],\n              id(\"y\"))\n          ]))\n    ])"),anf_arg18902219,anf_arg19242463,anf_arg19252475):R.ffi.throwNonFunApp(L[262],anf_fun18892220,[("bs(\"x = 7 print(2) var y = 10 y\") is\n  A.s-block(d,\n    [list: \n      A.s-let-expr(d,\n        [list: A.s-let-bind(d, b(\"x\"), A.s-num(d, 7))],\n        A.s-block(d,\n          [list: \n            A.s-app(d, id(\"print\"), [list: A.s-num(d, 2)]),\n            A.s-let-expr(d,\n              [list: A.s-var-bind(d, b(\"y\"), A.s-num(d, 10))],\n              id(\"y\"))\n          ]))\n    ])"),anf_arg18902219,anf_arg19242463,anf_arg19252475]);
};
try {
if(--R.GAS > 0) {
$z24672468 = $f24732474();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24732474,
"from":L[262]});
}
} catch($e24652466) {
if(R.isCont($e24652466)) {
var $ss24692470 = {"from":L[262],
"go":function(anf_begin_app_dropped29992476) {
return $Hanf_begin_app_dropped31072477(anf_begin_app_dropped29992476,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e24652466.stack[R.EXN_STACKHEIGHT++] = $ss24692470;
}
if(R.isPyretException($e24652466)) {
$e24652466.pyretStack.push(L[262]);
}
throw $e24652466;
}
var $ret24712472 = $Hanf_begin_app_dropped31072477($z24672468,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret24712472;
};
var $Hanf_begin_app_dropped31072477 = function(anf_begin_app_dropped29992476,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var $z24802481 = D;
var $f24862487 = function(_) {
return R.isFunction(bs693810)?bs693810.app(("fun f(): 4 end fun g(): 5 end f()")):R.ffi.throwNonFunApp(L[293],bs693810,[("fun f(): 4 end fun g(): 5 end f()")]);
};
try {
if(--R.GAS > 0) {
$z24802481 = $f24862487();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24862487,
"from":L[293]});
}
} catch($e24782479) {
if(R.isCont($e24782479)) {
var $ss24822483 = {"from":L[293],
"go":function(prog6992488) {
return $Hprog31062489(prog6992488,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e24782479.stack[R.EXN_STACKHEIGHT++] = $ss24822483;
}
if(R.isPyretException($e24782479)) {
$e24782479.pyretStack.push(L[293]);
}
throw $e24782479;
}
var $ret24842485 = $Hprog31062489($z24802481,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret24842485;
};
var $Hprog31062489 = function(prog6992488,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var anf_fun19262500 = G(builtins10,"current-checker",L[294]);
var $z24922493 = D;
var $f24982499 = function(_) {
return R.isFunction(anf_fun19262500)?anf_fun19262500.app():R.ffi.throwNonFunApp(L[294],anf_fun19262500,[]);
};
try {
if(--R.GAS > 0) {
$z24922493 = $f24982499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f24982499,
"from":L[294]});
}
} catch($e24902491) {
if(R.isCont($e24902491)) {
var $ss24942495 = {"from":L[294],
"go":function(anf_bracket19272501) {
return $Hanf_bracket31052502(anf_bracket19272501,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e24902491.stack[R.EXN_STACKHEIGHT++] = $ss24942495;
}
if(R.isPyretException($e24902491)) {
$e24902491.pyretStack.push(L[294]);
}
throw $e24902491;
}
var $ret24962497 = $Hanf_bracket31052502($z24922493,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret24962497;
};
var $Hanf_bracket31052502 = function(anf_bracket19272501,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var anf_fun19282514 = G(anf_bracket19272501,"check-is",L[294]);
var anf_fun19292515 = G(A119,"s-block",L[300]);
var anf_fun19302516 = G(list3375,"make",L[299]);
var anf_fun19312517 = G(A119,"s-letrec",L[298]);
var anf_fun19322518 = G(list3375,"make",L[297]);
var anf_fun19332519 = G(A119,"s-letrec-bind",L[296]);
var $z25052506 = D;
var $f25112512 = function(_) {
return R.isFunction(b687805)?b687805.app(("f")):R.ffi.throwNonFunApp(L[295],b687805,[("f")]);
};
try {
if(--R.GAS > 0) {
$z25052506 = $f25112512();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25112512,
"from":L[295]});
}
} catch($e25032504) {
if(R.isCont($e25032504)) {
var $ss25072508 = {"from":L[295],
"go":function(anf_arg19342513) {
return $Hanf_arg31042520(anf_arg19342513,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e25032504.stack[R.EXN_STACKHEIGHT++] = $ss25072508;
}
if(R.isPyretException($e25032504)) {
$e25032504.pyretStack.push(L[295]);
}
throw $e25032504;
}
var $ret25092510 = $Hanf_arg31042520($z25052506,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret25092510;
};
var $Hanf_arg31042520 = function(anf_arg19342513,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var anf_fun19352531 = G(A119,"s-num",L[302]);
var $z25232524 = D;
var $f25292530 = function(_) {
return R.isFunction(anf_fun19352531)?anf_fun19352531.app(d686811,(4)):R.ffi.throwNonFunApp(L[301],anf_fun19352531,[d686811,(4)]);
};
try {
if(--R.GAS > 0) {
$z25232524 = $f25292530();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25292530,
"from":L[301]});
}
} catch($e25212522) {
if(R.isCont($e25212522)) {
var $ss25252526 = {"from":L[301],
"go":function(anf_arg19362532) {
return $Hanf_arg31032533(anf_arg19362532,A119,anf_arg19342513,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e25212522.stack[R.EXN_STACKHEIGHT++] = $ss25252526;
}
if(R.isPyretException($e25212522)) {
$e25212522.pyretStack.push(L[301]);
}
throw $e25212522;
}
var $ret25272528 = $Hanf_arg31032533($z25232524,A119,anf_arg19342513,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret25272528;
};
var $Hanf_arg31032533 = function(anf_arg19362532,A119,anf_arg19342513,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z25362537 = D;
var $f25422543 = function(_) {
return R.isFunction(thunk696814)?thunk696814.app(anf_arg19362532):R.ffi.throwNonFunApp(L[303],thunk696814,[anf_arg19362532]);
};
try {
if(--R.GAS > 0) {
$z25362537 = $f25422543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25422543,
"from":L[303]});
}
} catch($e25342535) {
if(R.isCont($e25342535)) {
var $ss25382539 = {"from":L[303],
"go":function(anf_arg19372544) {
return $Hanf_arg31022545(anf_arg19372544,A119,anf_arg19342513,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e25342535.stack[R.EXN_STACKHEIGHT++] = $ss25382539;
}
if(R.isPyretException($e25342535)) {
$e25342535.pyretStack.push(L[303]);
}
throw $e25342535;
}
var $ret25402541 = $Hanf_arg31022545($z25362537,A119,anf_arg19342513,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret25402541;
};
var $Hanf_arg31022545 = function(anf_arg19372544,A119,anf_arg19342513,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19332519,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z25482549 = D;
var $f25542555 = function(_) {
return R.isFunction(anf_fun19332519)?anf_fun19332519.app(d686811,anf_arg19342513,anf_arg19372544):R.ffi.throwNonFunApp(L[304],anf_fun19332519,[d686811,anf_arg19342513,anf_arg19372544]);
};
try {
if(--R.GAS > 0) {
$z25482549 = $f25542555();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25542555,
"from":L[304]});
}
} catch($e25462547) {
if(R.isCont($e25462547)) {
var $ss25502551 = {"from":L[304],
"go":function(anf_array_val19382556) {
return $Hanf_array_val31012557(anf_array_val19382556,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e25462547.stack[R.EXN_STACKHEIGHT++] = $ss25502551;
}
if(R.isPyretException($e25462547)) {
$e25462547.pyretStack.push(L[304]);
}
throw $e25462547;
}
var $ret25522553 = $Hanf_array_val31012557($z25482549,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret25522553;
};
var $Hanf_array_val31012557 = function(anf_array_val19382556,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var anf_fun19392569 = G(A119,"s-letrec-bind",L[306]);
var $z25602561 = D;
var $f25662567 = function(_) {
return R.isFunction(b687805)?b687805.app(("g")):R.ffi.throwNonFunApp(L[305],b687805,[("g")]);
};
try {
if(--R.GAS > 0) {
$z25602561 = $f25662567();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25662567,
"from":L[305]});
}
} catch($e25582559) {
if(R.isCont($e25582559)) {
var $ss25622563 = {"from":L[305],
"go":function(anf_arg19402568) {
return $Hanf_arg31002570(anf_arg19402568,A119,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e25582559.stack[R.EXN_STACKHEIGHT++] = $ss25622563;
}
if(R.isPyretException($e25582559)) {
$e25582559.pyretStack.push(L[305]);
}
throw $e25582559;
}
var $ret25642565 = $Hanf_arg31002570($z25602561,A119,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret25642565;
};
var $Hanf_arg31002570 = function(anf_arg19402568,A119,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var anf_fun19412581 = G(A119,"s-num",L[308]);
var $z25732574 = D;
var $f25792580 = function(_) {
return R.isFunction(anf_fun19412581)?anf_fun19412581.app(d686811,(5)):R.ffi.throwNonFunApp(L[307],anf_fun19412581,[d686811,(5)]);
};
try {
if(--R.GAS > 0) {
$z25732574 = $f25792580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25792580,
"from":L[307]});
}
} catch($e25712572) {
if(R.isCont($e25712572)) {
var $ss25752576 = {"from":L[307],
"go":function(anf_arg19422582) {
return $Hanf_arg30992583(anf_arg19422582,A119,anf_arg19402568,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e25712572.stack[R.EXN_STACKHEIGHT++] = $ss25752576;
}
if(R.isPyretException($e25712572)) {
$e25712572.pyretStack.push(L[307]);
}
throw $e25712572;
}
var $ret25772578 = $Hanf_arg30992583($z25732574,A119,anf_arg19402568,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret25772578;
};
var $Hanf_arg30992583 = function(anf_arg19422582,A119,anf_arg19402568,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z25862587 = D;
var $f25922593 = function(_) {
return R.isFunction(thunk696814)?thunk696814.app(anf_arg19422582):R.ffi.throwNonFunApp(L[309],thunk696814,[anf_arg19422582]);
};
try {
if(--R.GAS > 0) {
$z25862587 = $f25922593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f25922593,
"from":L[309]});
}
} catch($e25842585) {
if(R.isCont($e25842585)) {
var $ss25882589 = {"from":L[309],
"go":function(anf_arg19432594) {
return $Hanf_arg30982595(anf_arg19432594,A119,anf_arg19402568,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e25842585.stack[R.EXN_STACKHEIGHT++] = $ss25882589;
}
if(R.isPyretException($e25842585)) {
$e25842585.pyretStack.push(L[309]);
}
throw $e25842585;
}
var $ret25902591 = $Hanf_arg30982595($z25862587,A119,anf_arg19402568,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret25902591;
};
var $Hanf_arg30982595 = function(anf_arg19432594,A119,anf_arg19402568,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,anf_fun19392569,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z25982599 = D;
var $f26042605 = function(_) {
return R.isFunction(anf_fun19392569)?anf_fun19392569.app(d686811,anf_arg19402568,anf_arg19432594):R.ffi.throwNonFunApp(L[310],anf_fun19392569,[d686811,anf_arg19402568,anf_arg19432594]);
};
try {
if(--R.GAS > 0) {
$z25982599 = $f26042605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26042605,
"from":L[310]});
}
} catch($e25962597) {
if(R.isCont($e25962597)) {
var $ss26002601 = {"from":L[310],
"go":function(anf_array_val19442606) {
return $Hanf_array_val30972607(anf_array_val19442606,A119,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e25962597.stack[R.EXN_STACKHEIGHT++] = $ss26002601;
}
if(R.isPyretException($e25962597)) {
$e25962597.pyretStack.push(L[310]);
}
throw $e25962597;
}
var $ret26022603 = $Hanf_array_val30972607($z25982599,A119,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret26022603;
};
var $Hanf_array_val30972607 = function(anf_array_val19442606,A119,anf_array_val19382556,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19322518,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z26102611 = D;
var $f26162617 = function(_) {
return R.isFunction(anf_fun19322518)?anf_fun19322518.app([anf_array_val19382556,anf_array_val19442606]):R.ffi.throwNonFunApp(L[297],anf_fun19322518,[[anf_array_val19382556,anf_array_val19442606]]);
};
try {
if(--R.GAS > 0) {
$z26102611 = $f26162617();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26162617,
"from":L[297]});
}
} catch($e26082609) {
if(R.isCont($e26082609)) {
var $ss26122613 = {"from":L[297],
"go":function(anf_arg19452618) {
return $Hanf_arg30962619(anf_arg19452618,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e26082609.stack[R.EXN_STACKHEIGHT++] = $ss26122613;
}
if(R.isPyretException($e26082609)) {
$e26082609.pyretStack.push(L[297]);
}
throw $e26082609;
}
var $ret26142615 = $Hanf_arg30962619($z26102611,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret26142615;
};
var $Hanf_arg30962619 = function(anf_arg19452618,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var anf_fun19462631 = G(A119,"s-app",L[312]);
var $z26222623 = D;
var $f26282629 = function(_) {
return R.isFunction(id689812)?id689812.app(("f")):R.ffi.throwNonFunApp(L[311],id689812,[("f")]);
};
try {
if(--R.GAS > 0) {
$z26222623 = $f26282629();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26282629,
"from":L[311]});
}
} catch($e26202621) {
if(R.isCont($e26202621)) {
var $ss26242625 = {"from":L[311],
"go":function(anf_arg19472630) {
return $Hanf_arg30952632(anf_arg19472630,A119,anf_arg19452618,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19462631,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e26202621.stack[R.EXN_STACKHEIGHT++] = $ss26242625;
}
if(R.isPyretException($e26202621)) {
$e26202621.pyretStack.push(L[311]);
}
throw $e26202621;
}
var $ret26262627 = $Hanf_arg30952632($z26222623,A119,anf_arg19452618,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19462631,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret26262627;
};
var $Hanf_arg30952632 = function(anf_arg19472630,A119,anf_arg19452618,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19462631,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var anf_fun19482643 = G(list3375,"make",L[313]);
var $z26352636 = D;
var $f26412642 = function(_) {
return R.isFunction(anf_fun19482643)?anf_fun19482643.app([]):R.ffi.throwNonFunApp(L[313],anf_fun19482643,[[]]);
};
try {
if(--R.GAS > 0) {
$z26352636 = $f26412642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26412642,
"from":L[313]});
}
} catch($e26332634) {
if(R.isCont($e26332634)) {
var $ss26372638 = {"from":L[313],
"go":function(anf_arg19492644) {
return $Hanf_arg30942645(anf_arg19492644,A119,anf_arg19452618,anf_arg19472630,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19462631,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e26332634.stack[R.EXN_STACKHEIGHT++] = $ss26372638;
}
if(R.isPyretException($e26332634)) {
$e26332634.pyretStack.push(L[313]);
}
throw $e26332634;
}
var $ret26392640 = $Hanf_arg30942645($z26352636,A119,anf_arg19452618,anf_arg19472630,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19462631,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret26392640;
};
var $Hanf_arg30942645 = function(anf_arg19492644,A119,anf_arg19452618,anf_arg19472630,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,anf_fun19462631,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z26482649 = D;
var $f26542655 = function(_) {
return R.isFunction(anf_fun19462631)?anf_fun19462631.app(d686811,anf_arg19472630,anf_arg19492644):R.ffi.throwNonFunApp(L[314],anf_fun19462631,[d686811,anf_arg19472630,anf_arg19492644]);
};
try {
if(--R.GAS > 0) {
$z26482649 = $f26542655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26542655,
"from":L[314]});
}
} catch($e26462647) {
if(R.isCont($e26462647)) {
var $ss26502651 = {"from":L[314],
"go":function(anf_arg19502656) {
return $Hanf_arg30932657(anf_arg19502656,A119,anf_arg19452618,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e26462647.stack[R.EXN_STACKHEIGHT++] = $ss26502651;
}
if(R.isPyretException($e26462647)) {
$e26462647.pyretStack.push(L[314]);
}
throw $e26462647;
}
var $ret26522653 = $Hanf_arg30932657($z26482649,A119,anf_arg19452618,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret26522653;
};
var $Hanf_arg30932657 = function(anf_arg19502656,A119,anf_arg19452618,anf_fun19282514,anf_fun19292515,anf_fun19302516,anf_fun19312517,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z26602661 = D;
var $f26662667 = function(_) {
return R.isFunction(anf_fun19312517)?anf_fun19312517.app(d686811,anf_arg19452618,anf_arg19502656):R.ffi.throwNonFunApp(L[315],anf_fun19312517,[d686811,anf_arg19452618,anf_arg19502656]);
};
try {
if(--R.GAS > 0) {
$z26602661 = $f26662667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26662667,
"from":L[315]});
}
} catch($e26582659) {
if(R.isCont($e26582659)) {
var $ss26622663 = {"from":L[315],
"go":function(anf_array_val19512668) {
return $Hanf_array_val30922669(anf_array_val19512668,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e26582659.stack[R.EXN_STACKHEIGHT++] = $ss26622663;
}
if(R.isPyretException($e26582659)) {
$e26582659.pyretStack.push(L[315]);
}
throw $e26582659;
}
var $ret26642665 = $Hanf_array_val30922669($z26602661,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret26642665;
};
var $Hanf_array_val30922669 = function(anf_array_val19512668,A119,anf_fun19282514,anf_fun19292515,anf_fun19302516,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z26722673 = D;
var $f26782679 = function(_) {
return R.isFunction(anf_fun19302516)?anf_fun19302516.app([anf_array_val19512668]):R.ffi.throwNonFunApp(L[299],anf_fun19302516,[[anf_array_val19512668]]);
};
try {
if(--R.GAS > 0) {
$z26722673 = $f26782679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26782679,
"from":L[299]});
}
} catch($e26702671) {
if(R.isCont($e26702671)) {
var $ss26742675 = {"from":L[299],
"go":function(anf_arg19522680) {
return $Hanf_arg30912681(anf_arg19522680,A119,anf_fun19282514,anf_fun19292515,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e26702671.stack[R.EXN_STACKHEIGHT++] = $ss26742675;
}
if(R.isPyretException($e26702671)) {
$e26702671.pyretStack.push(L[299]);
}
throw $e26702671;
}
var $ret26762677 = $Hanf_arg30912681($z26722673,A119,anf_fun19282514,anf_fun19292515,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret26762677;
};
var $Hanf_arg30912681 = function(anf_arg19522680,A119,anf_fun19282514,anf_fun19292515,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var $z26842685 = D;
var $f26902691 = function(_) {
return R.isFunction(anf_fun19292515)?anf_fun19292515.app(d686811,anf_arg19522680):R.ffi.throwNonFunApp(L[316],anf_fun19292515,[d686811,anf_arg19522680]);
};
try {
if(--R.GAS > 0) {
$z26842685 = $f26902691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f26902691,
"from":L[316]});
}
} catch($e26822683) {
if(R.isCont($e26822683)) {
var $ss26862687 = {"from":L[316],
"go":function(anf_arg19532692) {
return $Hanf_arg30902693(anf_arg19532692,A119,anf_fun19282514,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
}};
$e26822683.stack[R.EXN_STACKHEIGHT++] = $ss26862687;
}
if(R.isPyretException($e26822683)) {
$e26822683.pyretStack.push(L[316]);
}
throw $e26822683;
}
var $ret26882689 = $Hanf_arg30902693($z26842685,A119,anf_fun19282514,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10);
++R.GAS;
return $ret26882689;
};
var $Hanf_arg30902693 = function(anf_arg19532692,A119,anf_fun19282514,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,prog6992488,thunk696814,builtins10) {
var anf_arg19542704 = R.makeSrcloc(L[294]);
var $z26962697 = D;
var $f27022703 = function(_) {
return R.isFunction(anf_fun19282514)?anf_fun19282514.app(("prog is\n  A.s-block(d,\n    [list: \n      A.s-letrec(d,\n        [list: \n          A.s-letrec-bind(d, b(\"f\"), thunk(A.s-num(d, 4))),\n          A.s-letrec-bind(d, b(\"g\"), thunk(A.s-num(d, 5)))\n        ],\n        A.s-app(d, id(\"f\"), [list: ]))\n    ])"),prog6992488,anf_arg19532692,anf_arg19542704):R.ffi.throwNonFunApp(L[294],anf_fun19282514,[("prog is\n  A.s-block(d,\n    [list: \n      A.s-letrec(d,\n        [list: \n          A.s-letrec-bind(d, b(\"f\"), thunk(A.s-num(d, 4))),\n          A.s-letrec-bind(d, b(\"g\"), thunk(A.s-num(d, 5)))\n        ],\n        A.s-app(d, id(\"f\"), [list: ]))\n    ])"),prog6992488,anf_arg19532692,anf_arg19542704]);
};
try {
if(--R.GAS > 0) {
$z26962697 = $f27022703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27022703,
"from":L[294]});
}
} catch($e26942695) {
if(R.isCont($e26942695)) {
var $ss26982699 = {"from":L[294],
"go":function(anf_begin_app_dropped30002705) {
return $Hanf_begin_app_dropped30892706(anf_begin_app_dropped30002705,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
}};
$e26942695.stack[R.EXN_STACKHEIGHT++] = $ss26982699;
}
if(R.isPyretException($e26942695)) {
$e26942695.pyretStack.push(L[294]);
}
throw $e26942695;
}
var $ret27002701 = $Hanf_begin_app_dropped30892706($z26962697,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret27002701;
};
var $Hanf_begin_app_dropped30892706 = function(anf_begin_app_dropped30002705,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,thunk696814,builtins10) {
var p_DASH_s7002718 = R.makeFunction(function(e7012735) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[321],1,arguments);
}
var anf_fun19562747 = G(A119,"s-app",L[323]);
var $z27382739 = D;
var $f27442745 = function(_) {
return R.isFunction(id689812)?id689812.app(("print")):R.ffi.throwNonFunApp(L[322],id689812,[("print")]);
};
try {
if(--R.GAS > 0) {
$z27382739 = $f27442745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27442745,
"from":L[322]});
}
} catch($e27362737) {
if(R.isCont($e27362737)) {
var $ss27402741 = {"from":L[322],
"go":function(anf_arg19572746) {
return $Hanf_arg30032748(anf_arg19572746,anf_fun19562747,d686811,e7012735,list3375);
}};
$e27362737.stack[R.EXN_STACKHEIGHT++] = $ss27402741;
}
if(R.isPyretException($e27362737)) {
$e27362737.pyretStack.push(L[322]);
}
throw $e27362737;
}
var $ret27422743 = $Hanf_arg30032748($z27382739,anf_fun19562747,d686811,e7012735,list3375);
++R.GAS;
return $ret27422743;
});
var pretty7022720 = R.makeFunction(function(e7032721) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[318],1,arguments);
}
var anf_fun19612732 = G(e7032721,"tosource",L[320]);
var $z27242725 = D;
var $f27302731 = function(_) {
return R.isFunction(anf_fun19612732)?anf_fun19612732.app():R.ffi.throwNonFunApp(L[319],anf_fun19612732,[]);
};
try {
if(--R.GAS > 0) {
$z27242725 = $f27302731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27302731,
"from":L[319]});
}
} catch($e27222723) {
if(R.isCont($e27222723)) {
var $ss27262727 = {"from":L[319],
"go":function(anf_bracket19622733) {
return $Hanf_bracket30062734(anf_bracket19622733);
}};
$e27222723.stack[R.EXN_STACKHEIGHT++] = $ss27262727;
}
if(R.isPyretException($e27222723)) {
$e27222723.pyretStack.push(L[319]);
}
throw $e27222723;
}
var $ret27282729 = $Hanf_bracket30062734($z27242725);
++R.GAS;
return $ret27282729;
});
var $z27092710 = D;
var $f27152716 = function(_) {
return R.isFunction(bs693810)?bs693810.app(("print(1) fun f(): 4 end fun g(): 5 end fun h(): 6 end x = 3 print(x)")):R.ffi.throwNonFunApp(L[317],bs693810,[("print(1) fun f(): 4 end fun g(): 5 end fun h(): 6 end x = 3 print(x)")]);
};
try {
if(--R.GAS > 0) {
$z27092710 = $f27152716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27152716,
"from":L[317]});
}
} catch($e27072708) {
if(R.isCont($e27072708)) {
var $ss27112712 = {"from":L[317],
"go":function(prog27042717) {
return $Hprog230882719(prog27042717,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10);
}};
$e27072708.stack[R.EXN_STACKHEIGHT++] = $ss27112712;
}
if(R.isPyretException($e27072708)) {
$e27072708.pyretStack.push(L[317]);
}
throw $e27072708;
}
var $ret27132714 = $Hprog230882719($z27092710,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10);
++R.GAS;
return $ret27132714;
};
var $Hprog230882719 = function(prog27042717,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10) {
var anf_fun19662759 = G(builtins10,"current-checker",L[324]);
var $z27512752 = D;
var $f27572758 = function(_) {
return R.isFunction(anf_fun19662759)?anf_fun19662759.app():R.ffi.throwNonFunApp(L[324],anf_fun19662759,[]);
};
try {
if(--R.GAS > 0) {
$z27512752 = $f27572758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27572758,
"from":L[324]});
}
} catch($e27492750) {
if(R.isCont($e27492750)) {
var $ss27532754 = {"from":L[324],
"go":function(anf_bracket19672760) {
return $Hanf_bracket30872761(anf_bracket19672760,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e27492750.stack[R.EXN_STACKHEIGHT++] = $ss27532754;
}
if(R.isPyretException($e27492750)) {
$e27492750.pyretStack.push(L[324]);
}
throw $e27492750;
}
var $ret27552756 = $Hanf_bracket30872761($z27512752,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret27552756;
};
var $Hanf_bracket30872761 = function(anf_bracket19672760,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun19682774 = G(anf_bracket19672760,"check-is",L[324]);
var anf_fun19692775 = G(A119,"s-block",L[328]);
var anf_fun19702776 = G(list3375,"make",L[327]);
var anf_fun19712772 = G(A119,"s-num",L[326]);
var $z27642765 = D;
var $f27702771 = function(_) {
return R.isFunction(anf_fun19712772)?anf_fun19712772.app(d686811,(1)):R.ffi.throwNonFunApp(L[325],anf_fun19712772,[d686811,(1)]);
};
try {
if(--R.GAS > 0) {
$z27642765 = $f27702771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27702771,
"from":L[325]});
}
} catch($e27622763) {
if(R.isCont($e27622763)) {
var $ss27662767 = {"from":L[325],
"go":function(anf_arg19722773) {
return $Hanf_arg30862777(anf_arg19722773,A119,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e27622763.stack[R.EXN_STACKHEIGHT++] = $ss27662767;
}
if(R.isPyretException($e27622763)) {
$e27622763.pyretStack.push(L[325]);
}
throw $e27622763;
}
var $ret27682769 = $Hanf_arg30862777($z27642765,A119,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret27682769;
};
var $Hanf_arg30862777 = function(anf_arg19722773,A119,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z27802781 = D;
var $f27862787 = function(_) {
return R.isFunction(p_DASH_s7002718)?p_DASH_s7002718.app(anf_arg19722773):R.ffi.throwNonFunApp(L[329],p_DASH_s7002718,[anf_arg19722773]);
};
try {
if(--R.GAS > 0) {
$z27802781 = $f27862787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27862787,
"from":L[329]});
}
} catch($e27782779) {
if(R.isCont($e27782779)) {
var $ss27822783 = {"from":L[329],
"go":function(anf_array_val19732788) {
return $Hanf_array_val30852789(anf_array_val19732788,A119,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e27782779.stack[R.EXN_STACKHEIGHT++] = $ss27822783;
}
if(R.isPyretException($e27782779)) {
$e27782779.pyretStack.push(L[329]);
}
throw $e27782779;
}
var $ret27842785 = $Hanf_array_val30852789($z27802781,A119,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret27842785;
};
var $Hanf_array_val30852789 = function(anf_array_val19732788,A119,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun19742801 = G(A119,"s-letrec",L[333]);
var anf_fun19752802 = G(list3375,"make",L[332]);
var anf_fun19762803 = G(A119,"s-letrec-bind",L[331]);
var $z27922793 = D;
var $f27982799 = function(_) {
return R.isFunction(b687805)?b687805.app(("f")):R.ffi.throwNonFunApp(L[330],b687805,[("f")]);
};
try {
if(--R.GAS > 0) {
$z27922793 = $f27982799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f27982799,
"from":L[330]});
}
} catch($e27902791) {
if(R.isCont($e27902791)) {
var $ss27942795 = {"from":L[330],
"go":function(anf_arg19772800) {
return $Hanf_arg30842804(anf_arg19772800,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e27902791.stack[R.EXN_STACKHEIGHT++] = $ss27942795;
}
if(R.isPyretException($e27902791)) {
$e27902791.pyretStack.push(L[330]);
}
throw $e27902791;
}
var $ret27962797 = $Hanf_arg30842804($z27922793,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret27962797;
};
var $Hanf_arg30842804 = function(anf_arg19772800,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun19782815 = G(A119,"s-num",L[335]);
var $z28072808 = D;
var $f28132814 = function(_) {
return R.isFunction(anf_fun19782815)?anf_fun19782815.app(d686811,(4)):R.ffi.throwNonFunApp(L[334],anf_fun19782815,[d686811,(4)]);
};
try {
if(--R.GAS > 0) {
$z28072808 = $f28132814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28132814,
"from":L[334]});
}
} catch($e28052806) {
if(R.isCont($e28052806)) {
var $ss28092810 = {"from":L[334],
"go":function(anf_arg19792816) {
return $Hanf_arg30832817(anf_arg19792816,A119,anf_arg19772800,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e28052806.stack[R.EXN_STACKHEIGHT++] = $ss28092810;
}
if(R.isPyretException($e28052806)) {
$e28052806.pyretStack.push(L[334]);
}
throw $e28052806;
}
var $ret28112812 = $Hanf_arg30832817($z28072808,A119,anf_arg19772800,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret28112812;
};
var $Hanf_arg30832817 = function(anf_arg19792816,A119,anf_arg19772800,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z28202821 = D;
var $f28262827 = function(_) {
return R.isFunction(thunk696814)?thunk696814.app(anf_arg19792816):R.ffi.throwNonFunApp(L[336],thunk696814,[anf_arg19792816]);
};
try {
if(--R.GAS > 0) {
$z28202821 = $f28262827();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28262827,
"from":L[336]});
}
} catch($e28182819) {
if(R.isCont($e28182819)) {
var $ss28222823 = {"from":L[336],
"go":function(anf_arg19802828) {
return $Hanf_arg30822829(anf_arg19802828,A119,anf_arg19772800,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e28182819.stack[R.EXN_STACKHEIGHT++] = $ss28222823;
}
if(R.isPyretException($e28182819)) {
$e28182819.pyretStack.push(L[336]);
}
throw $e28182819;
}
var $ret28242825 = $Hanf_arg30822829($z28202821,A119,anf_arg19772800,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret28242825;
};
var $Hanf_arg30822829 = function(anf_arg19802828,A119,anf_arg19772800,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19762803,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z28322833 = D;
var $f28382839 = function(_) {
return R.isFunction(anf_fun19762803)?anf_fun19762803.app(d686811,anf_arg19772800,anf_arg19802828):R.ffi.throwNonFunApp(L[337],anf_fun19762803,[d686811,anf_arg19772800,anf_arg19802828]);
};
try {
if(--R.GAS > 0) {
$z28322833 = $f28382839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28382839,
"from":L[337]});
}
} catch($e28302831) {
if(R.isCont($e28302831)) {
var $ss28342835 = {"from":L[337],
"go":function(anf_array_val19812840) {
return $Hanf_array_val30812841(anf_array_val19812840,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e28302831.stack[R.EXN_STACKHEIGHT++] = $ss28342835;
}
if(R.isPyretException($e28302831)) {
$e28302831.pyretStack.push(L[337]);
}
throw $e28302831;
}
var $ret28362837 = $Hanf_array_val30812841($z28322833,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret28362837;
};
var $Hanf_array_val30812841 = function(anf_array_val19812840,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun19822853 = G(A119,"s-letrec-bind",L[339]);
var $z28442845 = D;
var $f28502851 = function(_) {
return R.isFunction(b687805)?b687805.app(("g")):R.ffi.throwNonFunApp(L[338],b687805,[("g")]);
};
try {
if(--R.GAS > 0) {
$z28442845 = $f28502851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28502851,
"from":L[338]});
}
} catch($e28422843) {
if(R.isCont($e28422843)) {
var $ss28462847 = {"from":L[338],
"go":function(anf_arg19832852) {
return $Hanf_arg30802854(anf_arg19832852,A119,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e28422843.stack[R.EXN_STACKHEIGHT++] = $ss28462847;
}
if(R.isPyretException($e28422843)) {
$e28422843.pyretStack.push(L[338]);
}
throw $e28422843;
}
var $ret28482849 = $Hanf_arg30802854($z28442845,A119,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret28482849;
};
var $Hanf_arg30802854 = function(anf_arg19832852,A119,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun19842865 = G(A119,"s-num",L[341]);
var $z28572858 = D;
var $f28632864 = function(_) {
return R.isFunction(anf_fun19842865)?anf_fun19842865.app(d686811,(5)):R.ffi.throwNonFunApp(L[340],anf_fun19842865,[d686811,(5)]);
};
try {
if(--R.GAS > 0) {
$z28572858 = $f28632864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28632864,
"from":L[340]});
}
} catch($e28552856) {
if(R.isCont($e28552856)) {
var $ss28592860 = {"from":L[340],
"go":function(anf_arg19852866) {
return $Hanf_arg30792867(anf_arg19852866,A119,anf_arg19832852,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e28552856.stack[R.EXN_STACKHEIGHT++] = $ss28592860;
}
if(R.isPyretException($e28552856)) {
$e28552856.pyretStack.push(L[340]);
}
throw $e28552856;
}
var $ret28612862 = $Hanf_arg30792867($z28572858,A119,anf_arg19832852,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret28612862;
};
var $Hanf_arg30792867 = function(anf_arg19852866,A119,anf_arg19832852,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z28702871 = D;
var $f28762877 = function(_) {
return R.isFunction(thunk696814)?thunk696814.app(anf_arg19852866):R.ffi.throwNonFunApp(L[342],thunk696814,[anf_arg19852866]);
};
try {
if(--R.GAS > 0) {
$z28702871 = $f28762877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28762877,
"from":L[342]});
}
} catch($e28682869) {
if(R.isCont($e28682869)) {
var $ss28722873 = {"from":L[342],
"go":function(anf_arg19862878) {
return $Hanf_arg30782879(anf_arg19862878,A119,anf_arg19832852,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e28682869.stack[R.EXN_STACKHEIGHT++] = $ss28722873;
}
if(R.isPyretException($e28682869)) {
$e28682869.pyretStack.push(L[342]);
}
throw $e28682869;
}
var $ret28742875 = $Hanf_arg30782879($z28702871,A119,anf_arg19832852,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret28742875;
};
var $Hanf_arg30782879 = function(anf_arg19862878,A119,anf_arg19832852,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19822853,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z28822883 = D;
var $f28882889 = function(_) {
return R.isFunction(anf_fun19822853)?anf_fun19822853.app(d686811,anf_arg19832852,anf_arg19862878):R.ffi.throwNonFunApp(L[343],anf_fun19822853,[d686811,anf_arg19832852,anf_arg19862878]);
};
try {
if(--R.GAS > 0) {
$z28822883 = $f28882889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f28882889,
"from":L[343]});
}
} catch($e28802881) {
if(R.isCont($e28802881)) {
var $ss28842885 = {"from":L[343],
"go":function(anf_array_val19872890) {
return $Hanf_array_val30772891(anf_array_val19872890,A119,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e28802881.stack[R.EXN_STACKHEIGHT++] = $ss28842885;
}
if(R.isPyretException($e28802881)) {
$e28802881.pyretStack.push(L[343]);
}
throw $e28802881;
}
var $ret28862887 = $Hanf_array_val30772891($z28822883,A119,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret28862887;
};
var $Hanf_array_val30772891 = function(anf_array_val19872890,A119,anf_array_val19732788,anf_array_val19812840,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun19882903 = G(A119,"s-letrec-bind",L[345]);
var $z28942895 = D;
var $f29002901 = function(_) {
return R.isFunction(b687805)?b687805.app(("h")):R.ffi.throwNonFunApp(L[344],b687805,[("h")]);
};
try {
if(--R.GAS > 0) {
$z28942895 = $f29002901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29002901,
"from":L[344]});
}
} catch($e28922893) {
if(R.isCont($e28922893)) {
var $ss28962897 = {"from":L[344],
"go":function(anf_arg19892902) {
return $Hanf_arg30762904(anf_arg19892902,A119,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e28922893.stack[R.EXN_STACKHEIGHT++] = $ss28962897;
}
if(R.isPyretException($e28922893)) {
$e28922893.pyretStack.push(L[344]);
}
throw $e28922893;
}
var $ret28982899 = $Hanf_arg30762904($z28942895,A119,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret28982899;
};
var $Hanf_arg30762904 = function(anf_arg19892902,A119,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun19902915 = G(A119,"s-num",L[347]);
var $z29072908 = D;
var $f29132914 = function(_) {
return R.isFunction(anf_fun19902915)?anf_fun19902915.app(d686811,(6)):R.ffi.throwNonFunApp(L[346],anf_fun19902915,[d686811,(6)]);
};
try {
if(--R.GAS > 0) {
$z29072908 = $f29132914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29132914,
"from":L[346]});
}
} catch($e29052906) {
if(R.isCont($e29052906)) {
var $ss29092910 = {"from":L[346],
"go":function(anf_arg19912916) {
return $Hanf_arg30752917(anf_arg19912916,A119,anf_arg19892902,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e29052906.stack[R.EXN_STACKHEIGHT++] = $ss29092910;
}
if(R.isPyretException($e29052906)) {
$e29052906.pyretStack.push(L[346]);
}
throw $e29052906;
}
var $ret29112912 = $Hanf_arg30752917($z29072908,A119,anf_arg19892902,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret29112912;
};
var $Hanf_arg30752917 = function(anf_arg19912916,A119,anf_arg19892902,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z29202921 = D;
var $f29262927 = function(_) {
return R.isFunction(thunk696814)?thunk696814.app(anf_arg19912916):R.ffi.throwNonFunApp(L[348],thunk696814,[anf_arg19912916]);
};
try {
if(--R.GAS > 0) {
$z29202921 = $f29262927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29262927,
"from":L[348]});
}
} catch($e29182919) {
if(R.isCont($e29182919)) {
var $ss29222923 = {"from":L[348],
"go":function(anf_arg19922928) {
return $Hanf_arg30742929(anf_arg19922928,A119,anf_arg19892902,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e29182919.stack[R.EXN_STACKHEIGHT++] = $ss29222923;
}
if(R.isPyretException($e29182919)) {
$e29182919.pyretStack.push(L[348]);
}
throw $e29182919;
}
var $ret29242925 = $Hanf_arg30742929($z29202921,A119,anf_arg19892902,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret29242925;
};
var $Hanf_arg30742929 = function(anf_arg19922928,A119,anf_arg19892902,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,anf_fun19882903,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z29322933 = D;
var $f29382939 = function(_) {
return R.isFunction(anf_fun19882903)?anf_fun19882903.app(d686811,anf_arg19892902,anf_arg19922928):R.ffi.throwNonFunApp(L[349],anf_fun19882903,[d686811,anf_arg19892902,anf_arg19922928]);
};
try {
if(--R.GAS > 0) {
$z29322933 = $f29382939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29382939,
"from":L[349]});
}
} catch($e29302931) {
if(R.isCont($e29302931)) {
var $ss29342935 = {"from":L[349],
"go":function(anf_array_val19932940) {
return $Hanf_array_val30732941(anf_array_val19932940,A119,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e29302931.stack[R.EXN_STACKHEIGHT++] = $ss29342935;
}
if(R.isPyretException($e29302931)) {
$e29302931.pyretStack.push(L[349]);
}
throw $e29302931;
}
var $ret29362937 = $Hanf_array_val30732941($z29322933,A119,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret29362937;
};
var $Hanf_array_val30732941 = function(anf_array_val19932940,A119,anf_array_val19732788,anf_array_val19812840,anf_array_val19872890,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19752802,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z29442945 = D;
var $f29502951 = function(_) {
return R.isFunction(anf_fun19752802)?anf_fun19752802.app([anf_array_val19812840,anf_array_val19872890,anf_array_val19932940]):R.ffi.throwNonFunApp(L[332],anf_fun19752802,[[anf_array_val19812840,anf_array_val19872890,anf_array_val19932940]]);
};
try {
if(--R.GAS > 0) {
$z29442945 = $f29502951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29502951,
"from":L[332]});
}
} catch($e29422943) {
if(R.isCont($e29422943)) {
var $ss29462947 = {"from":L[332],
"go":function(anf_arg19942952) {
return $Hanf_arg30722953(anf_arg19942952,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e29422943.stack[R.EXN_STACKHEIGHT++] = $ss29462947;
}
if(R.isPyretException($e29422943)) {
$e29422943.pyretStack.push(L[332]);
}
throw $e29422943;
}
var $ret29482949 = $Hanf_arg30722953($z29442945,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret29482949;
};
var $Hanf_arg30722953 = function(anf_arg19942952,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun19952965 = G(A119,"s-block",L[355]);
var anf_fun19962966 = G(list3375,"make",L[354]);
var anf_fun19972967 = G(A119,"s-let-expr",L[353]);
var anf_fun19982968 = G(list3375,"make",L[352]);
var anf_fun19992969 = G(A119,"s-let-bind",L[351]);
var $z29562957 = D;
var $f29622963 = function(_) {
return R.isFunction(b687805)?b687805.app(("x")):R.ffi.throwNonFunApp(L[350],b687805,[("x")]);
};
try {
if(--R.GAS > 0) {
$z29562957 = $f29622963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29622963,
"from":L[350]});
}
} catch($e29542955) {
if(R.isCont($e29542955)) {
var $ss29582959 = {"from":L[350],
"go":function(anf_arg20002964) {
return $Hanf_arg30712970(anf_arg20002964,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,anf_fun19992969,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e29542955.stack[R.EXN_STACKHEIGHT++] = $ss29582959;
}
if(R.isPyretException($e29542955)) {
$e29542955.pyretStack.push(L[350]);
}
throw $e29542955;
}
var $ret29602961 = $Hanf_arg30712970($z29562957,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,anf_fun19992969,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret29602961;
};
var $Hanf_arg30712970 = function(anf_arg20002964,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,anf_fun19992969,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun20012981 = G(A119,"s-num",L[357]);
var $z29732974 = D;
var $f29792980 = function(_) {
return R.isFunction(anf_fun20012981)?anf_fun20012981.app(d686811,(3)):R.ffi.throwNonFunApp(L[356],anf_fun20012981,[d686811,(3)]);
};
try {
if(--R.GAS > 0) {
$z29732974 = $f29792980();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29792980,
"from":L[356]});
}
} catch($e29712972) {
if(R.isCont($e29712972)) {
var $ss29752976 = {"from":L[356],
"go":function(anf_arg20022982) {
return $Hanf_arg30702983(anf_arg20022982,A119,anf_arg19942952,anf_arg20002964,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,anf_fun19992969,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e29712972.stack[R.EXN_STACKHEIGHT++] = $ss29752976;
}
if(R.isPyretException($e29712972)) {
$e29712972.pyretStack.push(L[356]);
}
throw $e29712972;
}
var $ret29772978 = $Hanf_arg30702983($z29732974,A119,anf_arg19942952,anf_arg20002964,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,anf_fun19992969,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret29772978;
};
var $Hanf_arg30702983 = function(anf_arg20022982,A119,anf_arg19942952,anf_arg20002964,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,anf_fun19992969,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z29862987 = D;
var $f29922993 = function(_) {
return R.isFunction(anf_fun19992969)?anf_fun19992969.app(d686811,anf_arg20002964,anf_arg20022982):R.ffi.throwNonFunApp(L[358],anf_fun19992969,[d686811,anf_arg20002964,anf_arg20022982]);
};
try {
if(--R.GAS > 0) {
$z29862987 = $f29922993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f29922993,
"from":L[358]});
}
} catch($e29842985) {
if(R.isCont($e29842985)) {
var $ss29882989 = {"from":L[358],
"go":function(anf_array_val20032994) {
return $Hanf_array_val30692995(anf_array_val20032994,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e29842985.stack[R.EXN_STACKHEIGHT++] = $ss29882989;
}
if(R.isPyretException($e29842985)) {
$e29842985.pyretStack.push(L[358]);
}
throw $e29842985;
}
var $ret29902991 = $Hanf_array_val30692995($z29862987,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret29902991;
};
var $Hanf_array_val30692995 = function(anf_array_val20032994,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,anf_fun19982968,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z29982999 = D;
var $f30043005 = function(_) {
return R.isFunction(anf_fun19982968)?anf_fun19982968.app([anf_array_val20032994]):R.ffi.throwNonFunApp(L[352],anf_fun19982968,[[anf_array_val20032994]]);
};
try {
if(--R.GAS > 0) {
$z29982999 = $f30043005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30043005,
"from":L[352]});
}
} catch($e29962997) {
if(R.isCont($e29962997)) {
var $ss30003001 = {"from":L[352],
"go":function(anf_arg20043006) {
return $Hanf_arg30683007(anf_arg20043006,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e29962997.stack[R.EXN_STACKHEIGHT++] = $ss30003001;
}
if(R.isPyretException($e29962997)) {
$e29962997.pyretStack.push(L[352]);
}
throw $e29962997;
}
var $ret30023003 = $Hanf_arg30683007($z29982999,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30023003;
};
var $Hanf_arg30683007 = function(anf_arg20043006,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z30103011 = D;
var $f30163017 = function(_) {
return R.isFunction(id689812)?id689812.app(("x")):R.ffi.throwNonFunApp(L[359],id689812,[("x")]);
};
try {
if(--R.GAS > 0) {
$z30103011 = $f30163017();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30163017,
"from":L[359]});
}
} catch($e30083009) {
if(R.isCont($e30083009)) {
var $ss30123013 = {"from":L[359],
"go":function(anf_arg20053018) {
return $Hanf_arg30673019(anf_arg20053018,A119,anf_arg19942952,anf_arg20043006,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e30083009.stack[R.EXN_STACKHEIGHT++] = $ss30123013;
}
if(R.isPyretException($e30083009)) {
$e30083009.pyretStack.push(L[359]);
}
throw $e30083009;
}
var $ret30143015 = $Hanf_arg30673019($z30103011,A119,anf_arg19942952,anf_arg20043006,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30143015;
};
var $Hanf_arg30673019 = function(anf_arg20053018,A119,anf_arg19942952,anf_arg20043006,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z30223023 = D;
var $f30283029 = function(_) {
return R.isFunction(p_DASH_s7002718)?p_DASH_s7002718.app(anf_arg20053018):R.ffi.throwNonFunApp(L[360],p_DASH_s7002718,[anf_arg20053018]);
};
try {
if(--R.GAS > 0) {
$z30223023 = $f30283029();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30283029,
"from":L[360]});
}
} catch($e30203021) {
if(R.isCont($e30203021)) {
var $ss30243025 = {"from":L[360],
"go":function(anf_arg20063030) {
return $Hanf_arg30663031(anf_arg20063030,A119,anf_arg19942952,anf_arg20043006,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e30203021.stack[R.EXN_STACKHEIGHT++] = $ss30243025;
}
if(R.isPyretException($e30203021)) {
$e30203021.pyretStack.push(L[360]);
}
throw $e30203021;
}
var $ret30263027 = $Hanf_arg30663031($z30223023,A119,anf_arg19942952,anf_arg20043006,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30263027;
};
var $Hanf_arg30663031 = function(anf_arg20063030,A119,anf_arg19942952,anf_arg20043006,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,anf_fun19972967,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z30343035 = D;
var $f30403041 = function(_) {
return R.isFunction(anf_fun19972967)?anf_fun19972967.app(d686811,anf_arg20043006,anf_arg20063030):R.ffi.throwNonFunApp(L[361],anf_fun19972967,[d686811,anf_arg20043006,anf_arg20063030]);
};
try {
if(--R.GAS > 0) {
$z30343035 = $f30403041();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30403041,
"from":L[361]});
}
} catch($e30323033) {
if(R.isCont($e30323033)) {
var $ss30363037 = {"from":L[361],
"go":function(anf_array_val20073042) {
return $Hanf_array_val30653043(anf_array_val20073042,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e30323033.stack[R.EXN_STACKHEIGHT++] = $ss30363037;
}
if(R.isPyretException($e30323033)) {
$e30323033.pyretStack.push(L[361]);
}
throw $e30323033;
}
var $ret30383039 = $Hanf_array_val30653043($z30343035,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30383039;
};
var $Hanf_array_val30653043 = function(anf_array_val20073042,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,anf_fun19962966,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z30463047 = D;
var $f30523053 = function(_) {
return R.isFunction(anf_fun19962966)?anf_fun19962966.app([anf_array_val20073042]):R.ffi.throwNonFunApp(L[354],anf_fun19962966,[[anf_array_val20073042]]);
};
try {
if(--R.GAS > 0) {
$z30463047 = $f30523053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30523053,
"from":L[354]});
}
} catch($e30443045) {
if(R.isCont($e30443045)) {
var $ss30483049 = {"from":L[354],
"go":function(anf_arg20083054) {
return $Hanf_arg30643055(anf_arg20083054,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e30443045.stack[R.EXN_STACKHEIGHT++] = $ss30483049;
}
if(R.isPyretException($e30443045)) {
$e30443045.pyretStack.push(L[354]);
}
throw $e30443045;
}
var $ret30503051 = $Hanf_arg30643055($z30463047,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30503051;
};
var $Hanf_arg30643055 = function(anf_arg20083054,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,anf_fun19952965,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z30583059 = D;
var $f30643065 = function(_) {
return R.isFunction(anf_fun19952965)?anf_fun19952965.app(d686811,anf_arg20083054):R.ffi.throwNonFunApp(L[362],anf_fun19952965,[d686811,anf_arg20083054]);
};
try {
if(--R.GAS > 0) {
$z30583059 = $f30643065();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30643065,
"from":L[362]});
}
} catch($e30563057) {
if(R.isCont($e30563057)) {
var $ss30603061 = {"from":L[362],
"go":function(anf_arg20093066) {
return $Hanf_arg30633067(anf_arg20093066,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e30563057.stack[R.EXN_STACKHEIGHT++] = $ss30603061;
}
if(R.isPyretException($e30563057)) {
$e30563057.pyretStack.push(L[362]);
}
throw $e30563057;
}
var $ret30623063 = $Hanf_arg30633067($z30583059,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30623063;
};
var $Hanf_arg30633067 = function(anf_arg20093066,A119,anf_arg19942952,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,anf_fun19742801,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z30703071 = D;
var $f30763077 = function(_) {
return R.isFunction(anf_fun19742801)?anf_fun19742801.app(d686811,anf_arg19942952,anf_arg20093066):R.ffi.throwNonFunApp(L[363],anf_fun19742801,[d686811,anf_arg19942952,anf_arg20093066]);
};
try {
if(--R.GAS > 0) {
$z30703071 = $f30763077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30763077,
"from":L[363]});
}
} catch($e30683069) {
if(R.isCont($e30683069)) {
var $ss30723073 = {"from":L[363],
"go":function(anf_array_val20103078) {
return $Hanf_array_val30623079(anf_array_val20103078,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e30683069.stack[R.EXN_STACKHEIGHT++] = $ss30723073;
}
if(R.isPyretException($e30683069)) {
$e30683069.pyretStack.push(L[363]);
}
throw $e30683069;
}
var $ret30743075 = $Hanf_array_val30623079($z30703071,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30743075;
};
var $Hanf_array_val30623079 = function(anf_array_val20103078,A119,anf_array_val19732788,anf_fun19682774,anf_fun19692775,anf_fun19702776,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z30823083 = D;
var $f30883089 = function(_) {
return R.isFunction(anf_fun19702776)?anf_fun19702776.app([anf_array_val19732788,anf_array_val20103078]):R.ffi.throwNonFunApp(L[327],anf_fun19702776,[[anf_array_val19732788,anf_array_val20103078]]);
};
try {
if(--R.GAS > 0) {
$z30823083 = $f30883089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f30883089,
"from":L[327]});
}
} catch($e30803081) {
if(R.isCont($e30803081)) {
var $ss30843085 = {"from":L[327],
"go":function(anf_arg20113090) {
return $Hanf_arg30613091(anf_arg20113090,A119,anf_fun19682774,anf_fun19692775,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e30803081.stack[R.EXN_STACKHEIGHT++] = $ss30843085;
}
if(R.isPyretException($e30803081)) {
$e30803081.pyretStack.push(L[327]);
}
throw $e30803081;
}
var $ret30863087 = $Hanf_arg30613091($z30823083,A119,anf_fun19682774,anf_fun19692775,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30863087;
};
var $Hanf_arg30613091 = function(anf_arg20113090,A119,anf_fun19682774,anf_fun19692775,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z30943095 = D;
var $f31003101 = function(_) {
return R.isFunction(anf_fun19692775)?anf_fun19692775.app(d686811,anf_arg20113090):R.ffi.throwNonFunApp(L[364],anf_fun19692775,[d686811,anf_arg20113090]);
};
try {
if(--R.GAS > 0) {
$z30943095 = $f31003101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31003101,
"from":L[364]});
}
} catch($e30923093) {
if(R.isCont($e30923093)) {
var $ss30963097 = {"from":L[364],
"go":function(anf_arg20123102) {
return $Hanf_arg30603103(anf_arg20123102,A119,anf_fun19682774,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e30923093.stack[R.EXN_STACKHEIGHT++] = $ss30963097;
}
if(R.isPyretException($e30923093)) {
$e30923093.pyretStack.push(L[364]);
}
throw $e30923093;
}
var $ret30983099 = $Hanf_arg30603103($z30943095,A119,anf_fun19682774,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret30983099;
};
var $Hanf_arg30603103 = function(anf_arg20123102,A119,anf_fun19682774,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_arg20133114 = R.makeSrcloc(L[324]);
var $z31063107 = D;
var $f31123113 = function(_) {
return R.isFunction(anf_fun19682774)?anf_fun19682774.app(("prog2 is\n  A.s-block(d,\n    [list: \n      p-s(A.s-num(d, 1)),\n      A.s-letrec(d,\n        [list: \n          A.s-letrec-bind(d, b(\"f\"), thunk(A.s-num(d, 4))),\n          A.s-letrec-bind(d, b(\"g\"), thunk(A.s-num(d, 5))),\n          A.s-letrec-bind(d, b(\"h\"), thunk(A.s-num(d, 6)))\n        ],\n        A.s-block(d,\n          [list: \n            A.s-let-expr(d,\n              [list: A.s-let-bind(d, b(\"x\"), A.s-num(d, 3))],\n              p-s(id(\"x\")))\n          ]))\n    ])"),prog27042717,anf_arg20123102,anf_arg20133114):R.ffi.throwNonFunApp(L[324],anf_fun19682774,[("prog2 is\n  A.s-block(d,\n    [list: \n      p-s(A.s-num(d, 1)),\n      A.s-letrec(d,\n        [list: \n          A.s-letrec-bind(d, b(\"f\"), thunk(A.s-num(d, 4))),\n          A.s-letrec-bind(d, b(\"g\"), thunk(A.s-num(d, 5))),\n          A.s-letrec-bind(d, b(\"h\"), thunk(A.s-num(d, 6)))\n        ],\n        A.s-block(d,\n          [list: \n            A.s-let-expr(d,\n              [list: A.s-let-bind(d, b(\"x\"), A.s-num(d, 3))],\n              p-s(id(\"x\")))\n          ]))\n    ])"),prog27042717,anf_arg20123102,anf_arg20133114]);
};
try {
if(--R.GAS > 0) {
$z31063107 = $f31123113();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31123113,
"from":L[324]});
}
} catch($e31043105) {
if(R.isCont($e31043105)) {
var $ss31083109 = {"from":L[324],
"go":function(anf_begin_app_dropped30073115) {
return $Hanf_begin_app_dropped30593116(anf_begin_app_dropped30073115,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e31043105.stack[R.EXN_STACKHEIGHT++] = $ss31083109;
}
if(R.isPyretException($e31043105)) {
$e31043105.pyretStack.push(L[324]);
}
throw $e31043105;
}
var $ret31103111 = $Hanf_begin_app_dropped30593116($z31063107,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret31103111;
};
var $Hanf_begin_app_dropped30593116 = function(anf_begin_app_dropped30073115,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun20143127 = G(builtins10,"current-checker",L[365]);
var $z31193120 = D;
var $f31253126 = function(_) {
return R.isFunction(anf_fun20143127)?anf_fun20143127.app():R.ffi.throwNonFunApp(L[365],anf_fun20143127,[]);
};
try {
if(--R.GAS > 0) {
$z31193120 = $f31253126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31253126,
"from":L[365]});
}
} catch($e31173118) {
if(R.isCont($e31173118)) {
var $ss31213122 = {"from":L[365],
"go":function(anf_bracket20153128) {
return $Hanf_bracket30583129(anf_bracket20153128,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e31173118.stack[R.EXN_STACKHEIGHT++] = $ss31213122;
}
if(R.isPyretException($e31173118)) {
$e31173118.pyretStack.push(L[365]);
}
throw $e31173118;
}
var $ret31233124 = $Hanf_bracket30583129($z31193120,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret31233124;
};
var $Hanf_bracket30583129 = function(anf_bracket20153128,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun20163142 = G(anf_bracket20153128,"check-is",L[365]);
var anf_fun20173140 = G(list3375,"make",L[366]);
var $z31323133 = D;
var $f31383139 = function(_) {
return R.isFunction(anf_fun20173140)?anf_fun20173140.app([prog27042717]):R.ffi.throwNonFunApp(L[366],anf_fun20173140,[[prog27042717]]);
};
try {
if(--R.GAS > 0) {
$z31323133 = $f31383139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31383139,
"from":L[366]});
}
} catch($e31303131) {
if(R.isCont($e31303131)) {
var $ss31343135 = {"from":L[366],
"go":function(anf_arg20183141) {
return $Hanf_arg30573143(anf_arg20183141,A119,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e31303131.stack[R.EXN_STACKHEIGHT++] = $ss31343135;
}
if(R.isPyretException($e31303131)) {
$e31303131.pyretStack.push(L[366]);
}
throw $e31303131;
}
var $ret31363137 = $Hanf_arg30573143($z31323133,A119,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret31363137;
};
var $Hanf_arg30573143 = function(anf_arg20183141,A119,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun20193154 = G(list3375,"make",L[367]);
var $z31463147 = D;
var $f31523153 = function(_) {
return R.isFunction(anf_fun20193154)?anf_fun20193154.app([]):R.ffi.throwNonFunApp(L[367],anf_fun20193154,[[]]);
};
try {
if(--R.GAS > 0) {
$z31463147 = $f31523153();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31523153,
"from":L[367]});
}
} catch($e31443145) {
if(R.isCont($e31443145)) {
var $ss31483149 = {"from":L[367],
"go":function(anf_arg20203155) {
return $Hanf_arg30563156(anf_arg20203155,A119,anf_arg20183141,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e31443145.stack[R.EXN_STACKHEIGHT++] = $ss31483149;
}
if(R.isPyretException($e31443145)) {
$e31443145.pyretStack.push(L[367]);
}
throw $e31443145;
}
var $ret31503151 = $Hanf_arg30563156($z31463147,A119,anf_arg20183141,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret31503151;
};
var $Hanf_arg30563156 = function(anf_arg20203155,A119,anf_arg20183141,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun20213167 = G(list3375,"make",L[368]);
var $z31593160 = D;
var $f31653166 = function(_) {
return R.isFunction(anf_fun20213167)?anf_fun20213167.app([]):R.ffi.throwNonFunApp(L[368],anf_fun20213167,[[]]);
};
try {
if(--R.GAS > 0) {
$z31593160 = $f31653166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31653166,
"from":L[368]});
}
} catch($e31573158) {
if(R.isCont($e31573158)) {
var $ss31613162 = {"from":L[368],
"go":function(anf_arg20223168) {
return $Hanf_arg30553169(anf_arg20223168,A119,anf_arg20183141,anf_arg20203155,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e31573158.stack[R.EXN_STACKHEIGHT++] = $ss31613162;
}
if(R.isPyretException($e31573158)) {
$e31573158.pyretStack.push(L[368]);
}
throw $e31573158;
}
var $ret31633164 = $Hanf_arg30553169($z31593160,A119,anf_arg20183141,anf_arg20203155,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret31633164;
};
var $Hanf_arg30553169 = function(anf_arg20223168,A119,anf_arg20183141,anf_arg20203155,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun20233180 = G(list3375,"make",L[369]);
var $z31723173 = D;
var $f31783179 = function(_) {
return R.isFunction(anf_fun20233180)?anf_fun20233180.app([]):R.ffi.throwNonFunApp(L[369],anf_fun20233180,[[]]);
};
try {
if(--R.GAS > 0) {
$z31723173 = $f31783179();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31783179,
"from":L[369]});
}
} catch($e31703171) {
if(R.isCont($e31703171)) {
var $ss31743175 = {"from":L[369],
"go":function(anf_arg20243181) {
return $Hanf_arg30543182(anf_arg20243181,A119,anf_arg20183141,anf_arg20203155,anf_arg20223168,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e31703171.stack[R.EXN_STACKHEIGHT++] = $ss31743175;
}
if(R.isPyretException($e31703171)) {
$e31703171.pyretStack.push(L[369]);
}
throw $e31703171;
}
var $ret31763177 = $Hanf_arg30543182($z31723173,A119,anf_arg20183141,anf_arg20203155,anf_arg20223168,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret31763177;
};
var $Hanf_arg30543182 = function(anf_arg20243181,A119,anf_arg20183141,anf_arg20203155,anf_arg20223168,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z31853186 = D;
var $f31913192 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(anf_arg20183141,anf_arg20203155,anf_arg20223168,anf_arg20243181):R.ffi.throwNonFunApp(L[370],desugar_DASH_scope_DASH_block9165.$var,[anf_arg20183141,anf_arg20203155,anf_arg20223168,anf_arg20243181]);
};
try {
if(--R.GAS > 0) {
$z31853186 = $f31913192();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f31913192,
"from":L[370]});
}
} catch($e31833184) {
if(R.isCont($e31833184)) {
var $ss31873188 = {"from":L[370],
"go":function(anf_bracket20253193) {
return $Hanf_bracket30533194(anf_bracket20253193,A119,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e31833184.stack[R.EXN_STACKHEIGHT++] = $ss31873188;
}
if(R.isPyretException($e31833184)) {
$e31833184.pyretStack.push(L[370]);
}
throw $e31833184;
}
var $ret31893190 = $Hanf_bracket30533194($z31853186,A119,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret31893190;
};
var $Hanf_bracket30533194 = function(anf_bracket20253193,A119,anf_fun20163142,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_arg20263205 = G(anf_bracket20253193,"first",L[371]);
var anf_arg20273206 = R.makeSrcloc(L[365]);
var $z31973198 = D;
var $f32033204 = function(_) {
return R.isFunction(anf_fun20163142)?anf_fun20163142.app(("desugar-scope-block([list: prog2], [list: ], [list: ], [list: ]).first is prog2"),anf_arg20263205,prog27042717,anf_arg20273206):R.ffi.throwNonFunApp(L[365],anf_fun20163142,[("desugar-scope-block([list: prog2], [list: ], [list: ], [list: ]).first is prog2"),anf_arg20263205,prog27042717,anf_arg20273206]);
};
try {
if(--R.GAS > 0) {
$z31973198 = $f32033204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32033204,
"from":L[365]});
}
} catch($e31953196) {
if(R.isCont($e31953196)) {
var $ss31993200 = {"from":L[365],
"go":function(anf_begin_app_dropped30083207) {
return $Hanf_begin_app_dropped30523208(anf_begin_app_dropped30083207,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e31953196.stack[R.EXN_STACKHEIGHT++] = $ss31993200;
}
if(R.isPyretException($e31953196)) {
$e31953196.pyretStack.push(L[365]);
}
throw $e31953196;
}
var $ret32013202 = $Hanf_begin_app_dropped30523208($z31973198,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret32013202;
};
var $Hanf_begin_app_dropped30523208 = function(anf_begin_app_dropped30083207,A119,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_arg20363221 = R.makeFunction(function(p17053224,p27063225) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[374],2,arguments);
}
var anf_fun20293236 = G(builtins10,"current-checker",L[375]);
var $z32283229 = D;
var $f32343235 = function(_) {
return R.isFunction(anf_fun20293236)?anf_fun20293236.app():R.ffi.throwNonFunApp(L[375],anf_fun20293236,[]);
};
try {
if(--R.GAS > 0) {
$z32283229 = $f32343235();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32343235,
"from":L[375]});
}
} catch($e32263227) {
if(R.isCont($e32263227)) {
var $ss32303231 = {"from":L[375],
"go":function(anf_bracket20303237) {
return $Hanf_bracket30113238(anf_bracket20303237,A119,p17053224,p27063225);
}};
$e32263227.stack[R.EXN_STACKHEIGHT++] = $ss32303231;
}
if(R.isPyretException($e32263227)) {
$e32263227.pyretStack.push(L[375]);
}
throw $e32263227;
}
var $ret32323233 = $Hanf_bracket30113238($z32283229,A119,p17053224,p27063225);
++R.GAS;
return $ret32323233;
});
var anf_arg20373222 = G(prog27042717,"stmts",L[373]);
var anf_fun20383219 = G(list3375,"make",L[372]);
var $z32113212 = D;
var $f32173218 = function(_) {
return R.isFunction(anf_fun20383219)?anf_fun20383219.app([]):R.ffi.throwNonFunApp(L[372],anf_fun20383219,[[]]);
};
try {
if(--R.GAS > 0) {
$z32113212 = $f32173218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32173218,
"from":L[372]});
}
} catch($e32093210) {
if(R.isCont($e32093210)) {
var $ss32133214 = {"from":L[372],
"go":function(anf_arg20393220) {
return $Hanf_arg30513223(anf_arg20393220,A119,anf_arg20363221,anf_arg20373222,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e32093210.stack[R.EXN_STACKHEIGHT++] = $ss32133214;
}
if(R.isPyretException($e32093210)) {
$e32093210.pyretStack.push(L[372]);
}
throw $e32093210;
}
var $ret32153216 = $Hanf_arg30513223($z32113212,A119,anf_arg20363221,anf_arg20373222,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret32153216;
};
var $Hanf_arg30513223 = function(anf_arg20393220,A119,anf_arg20363221,anf_arg20373222,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun20403249 = G(list3375,"make",L[376]);
var $z32413242 = D;
var $f32473248 = function(_) {
return R.isFunction(anf_fun20403249)?anf_fun20403249.app([]):R.ffi.throwNonFunApp(L[376],anf_fun20403249,[[]]);
};
try {
if(--R.GAS > 0) {
$z32413242 = $f32473248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32473248,
"from":L[376]});
}
} catch($e32393240) {
if(R.isCont($e32393240)) {
var $ss32433244 = {"from":L[376],
"go":function(anf_arg20413250) {
return $Hanf_arg30503251(anf_arg20413250,A119,anf_arg20363221,anf_arg20373222,anf_arg20393220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e32393240.stack[R.EXN_STACKHEIGHT++] = $ss32433244;
}
if(R.isPyretException($e32393240)) {
$e32393240.pyretStack.push(L[376]);
}
throw $e32393240;
}
var $ret32453246 = $Hanf_arg30503251($z32413242,A119,anf_arg20363221,anf_arg20373222,anf_arg20393220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret32453246;
};
var $Hanf_arg30503251 = function(anf_arg20413250,A119,anf_arg20363221,anf_arg20373222,anf_arg20393220,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_fun20423262 = G(list3375,"make",L[377]);
var $z32543255 = D;
var $f32603261 = function(_) {
return R.isFunction(anf_fun20423262)?anf_fun20423262.app([]):R.ffi.throwNonFunApp(L[377],anf_fun20423262,[[]]);
};
try {
if(--R.GAS > 0) {
$z32543255 = $f32603261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32603261,
"from":L[377]});
}
} catch($e32523253) {
if(R.isCont($e32523253)) {
var $ss32563257 = {"from":L[377],
"go":function(anf_arg20433263) {
return $Hanf_arg30493264(anf_arg20433263,A119,anf_arg20363221,anf_arg20373222,anf_arg20393220,anf_arg20413250,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e32523253.stack[R.EXN_STACKHEIGHT++] = $ss32563257;
}
if(R.isPyretException($e32523253)) {
$e32523253.pyretStack.push(L[377]);
}
throw $e32523253;
}
var $ret32583259 = $Hanf_arg30493264($z32543255,A119,anf_arg20363221,anf_arg20373222,anf_arg20393220,anf_arg20413250,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret32583259;
};
var $Hanf_arg30493264 = function(anf_arg20433263,A119,anf_arg20363221,anf_arg20373222,anf_arg20393220,anf_arg20413250,b687805,bs693810,d686811,desugar_DASH_scope_DASH_block9165,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var $z32673268 = D;
var $f32733274 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(anf_arg20373222,anf_arg20393220,anf_arg20413250,anf_arg20433263):R.ffi.throwNonFunApp(L[378],desugar_DASH_scope_DASH_block9165.$var,[anf_arg20373222,anf_arg20393220,anf_arg20413250,anf_arg20433263]);
};
try {
if(--R.GAS > 0) {
$z32673268 = $f32733274();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32733274,
"from":L[378]});
}
} catch($e32653266) {
if(R.isCont($e32653266)) {
var $ss32693270 = {"from":L[378],
"go":function(anf_arg20443275) {
return $Hanf_arg30483276(anf_arg20443275,A119,anf_arg20363221,b687805,bs693810,d686811,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
}};
$e32653266.stack[R.EXN_STACKHEIGHT++] = $ss32693270;
}
if(R.isPyretException($e32653266)) {
$e32653266.pyretStack.push(L[378]);
}
throw $e32653266;
}
var $ret32713272 = $Hanf_arg30483276($z32673268,A119,anf_arg20363221,b687805,bs693810,d686811,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10);
++R.GAS;
return $ret32713272;
};
var $Hanf_arg30483276 = function(anf_arg20443275,A119,anf_arg20363221,b687805,bs693810,d686811,each25469,id689812,list3375,p_DASH_s7002718,prog27042717,thunk696814,builtins10) {
var anf_arg20453287 = G(prog27042717,"stmts",L[379]);
var $z32793280 = D;
var $f32853286 = function(_) {
return R.isFunction(each25469)?each25469.app(anf_arg20363221,anf_arg20443275,anf_arg20453287):R.ffi.throwNonFunApp(L[374],each25469,[anf_arg20363221,anf_arg20443275,anf_arg20453287]);
};
try {
if(--R.GAS > 0) {
$z32793280 = $f32853286();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32853286,
"from":L[374]});
}
} catch($e32773278) {
if(R.isCont($e32773278)) {
var $ss32813282 = {"from":L[374],
"go":function(anf_begin_app_dropped30123288) {
return $Hanf_begin_app_dropped30473289(anf_begin_app_dropped30123288,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10);
}};
$e32773278.stack[R.EXN_STACKHEIGHT++] = $ss32813282;
}
if(R.isPyretException($e32773278)) {
$e32773278.pyretStack.push(L[374]);
}
throw $e32773278;
}
var $ret32833284 = $Hanf_begin_app_dropped30473289($z32793280,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10);
++R.GAS;
return $ret32833284;
};
var $Hanf_begin_app_dropped30473289 = function(anf_begin_app_dropped30123288,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10) {
var $z32923293 = D;
var $f32983299 = function(_) {
return R.isFunction(bs693810)?bs693810.app(("print(x) x := 3 print(x)")):R.ffi.throwNonFunApp(L[380],bs693810,[("print(x) x := 3 print(x)")]);
};
try {
if(--R.GAS > 0) {
$z32923293 = $f32983299();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f32983299,
"from":L[380]});
}
} catch($e32903291) {
if(R.isCont($e32903291)) {
var $ss32943295 = {"from":L[380],
"go":function(prog37073300) {
return $Hprog330463301(prog37073300,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10);
}};
$e32903291.stack[R.EXN_STACKHEIGHT++] = $ss32943295;
}
if(R.isPyretException($e32903291)) {
$e32903291.pyretStack.push(L[380]);
}
throw $e32903291;
}
var $ret32963297 = $Hprog330463301($z32923293,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10);
++R.GAS;
return $ret32963297;
};
var $Hprog330463301 = function(prog37073300,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,thunk696814,builtins10) {
var anf_fun20463312 = G(builtins10,"current-checker",L[381]);
var $z33043305 = D;
var $f33103311 = function(_) {
return R.isFunction(anf_fun20463312)?anf_fun20463312.app():R.ffi.throwNonFunApp(L[381],anf_fun20463312,[]);
};
try {
if(--R.GAS > 0) {
$z33043305 = $f33103311();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33103311,
"from":L[381]});
}
} catch($e33023303) {
if(R.isCont($e33023303)) {
var $ss33063307 = {"from":L[381],
"go":function(anf_bracket20473313) {
return $Hanf_bracket30453314(anf_bracket20473313,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
}};
$e33023303.stack[R.EXN_STACKHEIGHT++] = $ss33063307;
}
if(R.isPyretException($e33023303)) {
$e33023303.pyretStack.push(L[381]);
}
throw $e33023303;
}
var $ret33083309 = $Hanf_bracket30453314($z33043305,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret33083309;
};
var $Hanf_bracket30453314 = function(anf_bracket20473313,A119,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10) {
var anf_fun20483326 = G(anf_bracket20473313,"check-is",L[381]);
var anf_fun20493327 = G(A119,"s-block",L[384]);
var anf_fun20503328 = G(list3375,"make",L[383]);
var $z33173318 = D;
var $f33233324 = function(_) {
return R.isFunction(id689812)?id689812.app(("x")):R.ffi.throwNonFunApp(L[382],id689812,[("x")]);
};
try {
if(--R.GAS > 0) {
$z33173318 = $f33233324();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33233324,
"from":L[382]});
}
} catch($e33153316) {
if(R.isCont($e33153316)) {
var $ss33193320 = {"from":L[382],
"go":function(anf_arg20513325) {
return $Hanf_arg30443329(anf_arg20513325,A119,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
}};
$e33153316.stack[R.EXN_STACKHEIGHT++] = $ss33193320;
}
if(R.isPyretException($e33153316)) {
$e33153316.pyretStack.push(L[382]);
}
throw $e33153316;
}
var $ret33213322 = $Hanf_arg30443329($z33173318,A119,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret33213322;
};
var $Hanf_arg30443329 = function(anf_arg20513325,A119,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10) {
var $z33323333 = D;
var $f33383339 = function(_) {
return R.isFunction(p_DASH_s7002718)?p_DASH_s7002718.app(anf_arg20513325):R.ffi.throwNonFunApp(L[385],p_DASH_s7002718,[anf_arg20513325]);
};
try {
if(--R.GAS > 0) {
$z33323333 = $f33383339();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33383339,
"from":L[385]});
}
} catch($e33303331) {
if(R.isCont($e33303331)) {
var $ss33343335 = {"from":L[385],
"go":function(anf_array_val20523340) {
return $Hanf_array_val30433341(anf_array_val20523340,A119,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
}};
$e33303331.stack[R.EXN_STACKHEIGHT++] = $ss33343335;
}
if(R.isPyretException($e33303331)) {
$e33303331.pyretStack.push(L[385]);
}
throw $e33303331;
}
var $ret33363337 = $Hanf_array_val30433341($z33323333,A119,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret33363337;
};
var $Hanf_array_val30433341 = function(anf_array_val20523340,A119,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10) {
var anf_fun20533354 = G(A119,"s-assign",L[388]);
var anf_fun20543352 = G(A119,"s-name",L[387]);
var $z33443345 = D;
var $f33503351 = function(_) {
return R.isFunction(anf_fun20543352)?anf_fun20543352.app(d686811,("x")):R.ffi.throwNonFunApp(L[386],anf_fun20543352,[d686811,("x")]);
};
try {
if(--R.GAS > 0) {
$z33443345 = $f33503351();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33503351,
"from":L[386]});
}
} catch($e33423343) {
if(R.isCont($e33423343)) {
var $ss33463347 = {"from":L[386],
"go":function(anf_arg20553353) {
return $Hanf_arg30423355(anf_arg20553353,A119,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,anf_fun20533354,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
}};
$e33423343.stack[R.EXN_STACKHEIGHT++] = $ss33463347;
}
if(R.isPyretException($e33423343)) {
$e33423343.pyretStack.push(L[386]);
}
throw $e33423343;
}
var $ret33483349 = $Hanf_arg30423355($z33443345,A119,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,anf_fun20533354,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret33483349;
};
var $Hanf_arg30423355 = function(anf_arg20553353,A119,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,anf_fun20533354,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10) {
var anf_fun20563366 = G(A119,"s-num",L[390]);
var $z33583359 = D;
var $f33643365 = function(_) {
return R.isFunction(anf_fun20563366)?anf_fun20563366.app(d686811,(3)):R.ffi.throwNonFunApp(L[389],anf_fun20563366,[d686811,(3)]);
};
try {
if(--R.GAS > 0) {
$z33583359 = $f33643365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33643365,
"from":L[389]});
}
} catch($e33563357) {
if(R.isCont($e33563357)) {
var $ss33603361 = {"from":L[389],
"go":function(anf_arg20573367) {
return $Hanf_arg30413368(anf_arg20573367,A119,anf_arg20553353,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,anf_fun20533354,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
}};
$e33563357.stack[R.EXN_STACKHEIGHT++] = $ss33603361;
}
if(R.isPyretException($e33563357)) {
$e33563357.pyretStack.push(L[389]);
}
throw $e33563357;
}
var $ret33623363 = $Hanf_arg30413368($z33583359,A119,anf_arg20553353,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,anf_fun20533354,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret33623363;
};
var $Hanf_arg30413368 = function(anf_arg20573367,A119,anf_arg20553353,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,anf_fun20533354,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10) {
var $z33713372 = D;
var $f33773378 = function(_) {
return R.isFunction(anf_fun20533354)?anf_fun20533354.app(d686811,anf_arg20553353,anf_arg20573367):R.ffi.throwNonFunApp(L[391],anf_fun20533354,[d686811,anf_arg20553353,anf_arg20573367]);
};
try {
if(--R.GAS > 0) {
$z33713372 = $f33773378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33773378,
"from":L[391]});
}
} catch($e33693370) {
if(R.isCont($e33693370)) {
var $ss33733374 = {"from":L[391],
"go":function(anf_array_val20583379) {
return $Hanf_array_val30403380(anf_array_val20583379,A119,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
}};
$e33693370.stack[R.EXN_STACKHEIGHT++] = $ss33733374;
}
if(R.isPyretException($e33693370)) {
$e33693370.pyretStack.push(L[391]);
}
throw $e33693370;
}
var $ret33753376 = $Hanf_array_val30403380($z33713372,A119,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret33753376;
};
var $Hanf_array_val30403380 = function(anf_array_val20583379,A119,anf_array_val20523340,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10) {
var $z33833384 = D;
var $f33893390 = function(_) {
return R.isFunction(id689812)?id689812.app(("x")):R.ffi.throwNonFunApp(L[392],id689812,[("x")]);
};
try {
if(--R.GAS > 0) {
$z33833384 = $f33893390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f33893390,
"from":L[392]});
}
} catch($e33813382) {
if(R.isCont($e33813382)) {
var $ss33853386 = {"from":L[392],
"go":function(anf_arg20593391) {
return $Hanf_arg30393392(anf_arg20593391,A119,anf_array_val20523340,anf_array_val20583379,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
}};
$e33813382.stack[R.EXN_STACKHEIGHT++] = $ss33853386;
}
if(R.isPyretException($e33813382)) {
$e33813382.pyretStack.push(L[392]);
}
throw $e33813382;
}
var $ret33873388 = $Hanf_arg30393392($z33833384,A119,anf_array_val20523340,anf_array_val20583379,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret33873388;
};
var $Hanf_arg30393392 = function(anf_arg20593391,A119,anf_array_val20523340,anf_array_val20583379,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,p_DASH_s7002718,prog37073300,thunk696814,builtins10) {
var $z33953396 = D;
var $f34013402 = function(_) {
return R.isFunction(p_DASH_s7002718)?p_DASH_s7002718.app(anf_arg20593391):R.ffi.throwNonFunApp(L[393],p_DASH_s7002718,[anf_arg20593391]);
};
try {
if(--R.GAS > 0) {
$z33953396 = $f34013402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34013402,
"from":L[393]});
}
} catch($e33933394) {
if(R.isCont($e33933394)) {
var $ss33973398 = {"from":L[393],
"go":function(anf_array_val20603403) {
return $Hanf_array_val30383404(anf_array_val20603403,A119,anf_array_val20523340,anf_array_val20583379,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10);
}};
$e33933394.stack[R.EXN_STACKHEIGHT++] = $ss33973398;
}
if(R.isPyretException($e33933394)) {
$e33933394.pyretStack.push(L[393]);
}
throw $e33933394;
}
var $ret33993400 = $Hanf_array_val30383404($z33953396,A119,anf_array_val20523340,anf_array_val20583379,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret33993400;
};
var $Hanf_array_val30383404 = function(anf_array_val20603403,A119,anf_array_val20523340,anf_array_val20583379,anf_fun20483326,anf_fun20493327,anf_fun20503328,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10) {
var $z34073408 = D;
var $f34133414 = function(_) {
return R.isFunction(anf_fun20503328)?anf_fun20503328.app([anf_array_val20523340,anf_array_val20583379,anf_array_val20603403]):R.ffi.throwNonFunApp(L[383],anf_fun20503328,[[anf_array_val20523340,anf_array_val20583379,anf_array_val20603403]]);
};
try {
if(--R.GAS > 0) {
$z34073408 = $f34133414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34133414,
"from":L[383]});
}
} catch($e34053406) {
if(R.isCont($e34053406)) {
var $ss34093410 = {"from":L[383],
"go":function(anf_arg20613415) {
return $Hanf_arg30373416(anf_arg20613415,A119,anf_fun20483326,anf_fun20493327,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10);
}};
$e34053406.stack[R.EXN_STACKHEIGHT++] = $ss34093410;
}
if(R.isPyretException($e34053406)) {
$e34053406.pyretStack.push(L[383]);
}
throw $e34053406;
}
var $ret34113412 = $Hanf_arg30373416($z34073408,A119,anf_fun20483326,anf_fun20493327,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret34113412;
};
var $Hanf_arg30373416 = function(anf_arg20613415,A119,anf_fun20483326,anf_fun20493327,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10) {
var $z34193420 = D;
var $f34253426 = function(_) {
return R.isFunction(anf_fun20493327)?anf_fun20493327.app(d686811,anf_arg20613415):R.ffi.throwNonFunApp(L[394],anf_fun20493327,[d686811,anf_arg20613415]);
};
try {
if(--R.GAS > 0) {
$z34193420 = $f34253426();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34253426,
"from":L[394]});
}
} catch($e34173418) {
if(R.isCont($e34173418)) {
var $ss34213422 = {"from":L[394],
"go":function(anf_arg20623427) {
return $Hanf_arg30363428(anf_arg20623427,A119,anf_fun20483326,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10);
}};
$e34173418.stack[R.EXN_STACKHEIGHT++] = $ss34213422;
}
if(R.isPyretException($e34173418)) {
$e34173418.pyretStack.push(L[394]);
}
throw $e34173418;
}
var $ret34233424 = $Hanf_arg30363428($z34193420,A119,anf_fun20483326,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10);
++R.GAS;
return $ret34233424;
};
var $Hanf_arg30363428 = function(anf_arg20623427,A119,anf_fun20483326,b687805,bs693810,d686811,id689812,list3375,prog37073300,thunk696814,builtins10) {
var anf_arg20633439 = R.makeSrcloc(L[381]);
var $z34313432 = D;
var $f34373438 = function(_) {
return R.isFunction(anf_fun20483326)?anf_fun20483326.app(("prog3 is\n  A.s-block(d,\n    [list: \n      p-s(id(\"x\")),\n      A.s-assign(d, A.s-name(d, \"x\"), A.s-num(d, 3)),\n      p-s(id(\"x\"))\n    ])"),prog37073300,anf_arg20623427,anf_arg20633439):R.ffi.throwNonFunApp(L[381],anf_fun20483326,[("prog3 is\n  A.s-block(d,\n    [list: \n      p-s(id(\"x\")),\n      A.s-assign(d, A.s-name(d, \"x\"), A.s-num(d, 3)),\n      p-s(id(\"x\"))\n    ])"),prog37073300,anf_arg20623427,anf_arg20633439]);
};
try {
if(--R.GAS > 0) {
$z34313432 = $f34373438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34373438,
"from":L[381]});
}
} catch($e34293430) {
if(R.isCont($e34293430)) {
var $ss34333434 = {"from":L[381],
"go":function(anf_begin_app_dropped30133440) {
return $Hanf_begin_app_dropped30353441(anf_begin_app_dropped30133440,A119,b687805,bs693810,d686811,id689812,list3375,thunk696814,builtins10);
}};
$e34293430.stack[R.EXN_STACKHEIGHT++] = $ss34333434;
}
if(R.isPyretException($e34293430)) {
$e34293430.pyretStack.push(L[381]);
}
throw $e34293430;
}
var $ret34353436 = $Hanf_begin_app_dropped30353441($z34313432,A119,b687805,bs693810,d686811,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret34353436;
};
var $Hanf_begin_app_dropped30353441 = function(anf_begin_app_dropped30133440,A119,b687805,bs693810,d686811,id689812,list3375,thunk696814,builtins10) {
var $z34443445 = D;
var $f34503451 = function(_) {
return R.isFunction(bs693810)?bs693810.app(("var x = 10 fun f(): 4 end f()")):R.ffi.throwNonFunApp(L[395],bs693810,[("var x = 10 fun f(): 4 end f()")]);
};
try {
if(--R.GAS > 0) {
$z34443445 = $f34503451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34503451,
"from":L[395]});
}
} catch($e34423443) {
if(R.isCont($e34423443)) {
var $ss34463447 = {"from":L[395],
"go":function(prog47083452) {
return $Hprog430343453(prog47083452,A119,b687805,d686811,id689812,list3375,thunk696814,builtins10);
}};
$e34423443.stack[R.EXN_STACKHEIGHT++] = $ss34463447;
}
if(R.isPyretException($e34423443)) {
$e34423443.pyretStack.push(L[395]);
}
throw $e34423443;
}
var $ret34483449 = $Hprog430343453($z34443445,A119,b687805,d686811,id689812,list3375,thunk696814,builtins10);
++R.GAS;
return $ret34483449;
};
var $Hprog430343453 = function(prog47083452,A119,b687805,d686811,id689812,list3375,thunk696814,builtins10) {
var anf_fun20643464 = G(builtins10,"current-checker",L[396]);
var $z34563457 = D;
var $f34623463 = function(_) {
return R.isFunction(anf_fun20643464)?anf_fun20643464.app():R.ffi.throwNonFunApp(L[396],anf_fun20643464,[]);
};
try {
if(--R.GAS > 0) {
$z34563457 = $f34623463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34623463,
"from":L[396]});
}
} catch($e34543455) {
if(R.isCont($e34543455)) {
var $ss34583459 = {"from":L[396],
"go":function(anf_bracket20653465) {
return $Hanf_bracket30333466(anf_bracket20653465,A119,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
}};
$e34543455.stack[R.EXN_STACKHEIGHT++] = $ss34583459;
}
if(R.isPyretException($e34543455)) {
$e34543455.pyretStack.push(L[396]);
}
throw $e34543455;
}
var $ret34603461 = $Hanf_bracket30333466($z34563457,A119,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
++R.GAS;
return $ret34603461;
};
var $Hanf_bracket30333466 = function(anf_bracket20653465,A119,b687805,d686811,id689812,list3375,prog47083452,thunk696814) {
var anf_fun20663478 = G(anf_bracket20653465,"check-is",L[396]);
var anf_fun20673479 = G(A119,"s-block",L[402]);
var anf_fun20683480 = G(list3375,"make",L[401]);
var anf_fun20693481 = G(A119,"s-let-expr",L[400]);
var anf_fun20703482 = G(list3375,"make",L[399]);
var anf_fun20713483 = G(A119,"s-var-bind",L[398]);
var $z34693470 = D;
var $f34753476 = function(_) {
return R.isFunction(b687805)?b687805.app(("x")):R.ffi.throwNonFunApp(L[397],b687805,[("x")]);
};
try {
if(--R.GAS > 0) {
$z34693470 = $f34753476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34753476,
"from":L[397]});
}
} catch($e34673468) {
if(R.isCont($e34673468)) {
var $ss34713472 = {"from":L[397],
"go":function(anf_arg20723477) {
return $Hanf_arg30323484(anf_arg20723477,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,anf_fun20713483,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
}};
$e34673468.stack[R.EXN_STACKHEIGHT++] = $ss34713472;
}
if(R.isPyretException($e34673468)) {
$e34673468.pyretStack.push(L[397]);
}
throw $e34673468;
}
var $ret34733474 = $Hanf_arg30323484($z34693470,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,anf_fun20713483,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
++R.GAS;
return $ret34733474;
};
var $Hanf_arg30323484 = function(anf_arg20723477,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,anf_fun20713483,b687805,d686811,id689812,list3375,prog47083452,thunk696814) {
var anf_fun20733495 = G(A119,"s-num",L[404]);
var $z34873488 = D;
var $f34933494 = function(_) {
return R.isFunction(anf_fun20733495)?anf_fun20733495.app(d686811,(10)):R.ffi.throwNonFunApp(L[403],anf_fun20733495,[d686811,(10)]);
};
try {
if(--R.GAS > 0) {
$z34873488 = $f34933494();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f34933494,
"from":L[403]});
}
} catch($e34853486) {
if(R.isCont($e34853486)) {
var $ss34893490 = {"from":L[403],
"go":function(anf_arg20743496) {
return $Hanf_arg30313497(anf_arg20743496,A119,anf_arg20723477,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,anf_fun20713483,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
}};
$e34853486.stack[R.EXN_STACKHEIGHT++] = $ss34893490;
}
if(R.isPyretException($e34853486)) {
$e34853486.pyretStack.push(L[403]);
}
throw $e34853486;
}
var $ret34913492 = $Hanf_arg30313497($z34873488,A119,anf_arg20723477,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,anf_fun20713483,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
++R.GAS;
return $ret34913492;
};
var $Hanf_arg30313497 = function(anf_arg20743496,A119,anf_arg20723477,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,anf_fun20713483,b687805,d686811,id689812,list3375,prog47083452,thunk696814) {
var $z35003501 = D;
var $f35063507 = function(_) {
return R.isFunction(anf_fun20713483)?anf_fun20713483.app(d686811,anf_arg20723477,anf_arg20743496):R.ffi.throwNonFunApp(L[405],anf_fun20713483,[d686811,anf_arg20723477,anf_arg20743496]);
};
try {
if(--R.GAS > 0) {
$z35003501 = $f35063507();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35063507,
"from":L[405]});
}
} catch($e34983499) {
if(R.isCont($e34983499)) {
var $ss35023503 = {"from":L[405],
"go":function(anf_array_val20753508) {
return $Hanf_array_val30303509(anf_array_val20753508,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
}};
$e34983499.stack[R.EXN_STACKHEIGHT++] = $ss35023503;
}
if(R.isPyretException($e34983499)) {
$e34983499.pyretStack.push(L[405]);
}
throw $e34983499;
}
var $ret35043505 = $Hanf_array_val30303509($z35003501,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
++R.GAS;
return $ret35043505;
};
var $Hanf_array_val30303509 = function(anf_array_val20753508,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20703482,b687805,d686811,id689812,list3375,prog47083452,thunk696814) {
var $z35123513 = D;
var $f35183519 = function(_) {
return R.isFunction(anf_fun20703482)?anf_fun20703482.app([anf_array_val20753508]):R.ffi.throwNonFunApp(L[399],anf_fun20703482,[[anf_array_val20753508]]);
};
try {
if(--R.GAS > 0) {
$z35123513 = $f35183519();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35183519,
"from":L[399]});
}
} catch($e35103511) {
if(R.isCont($e35103511)) {
var $ss35143515 = {"from":L[399],
"go":function(anf_arg20763520) {
return $Hanf_arg30293521(anf_arg20763520,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
}};
$e35103511.stack[R.EXN_STACKHEIGHT++] = $ss35143515;
}
if(R.isPyretException($e35103511)) {
$e35103511.pyretStack.push(L[399]);
}
throw $e35103511;
}
var $ret35163517 = $Hanf_arg30293521($z35123513,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,b687805,d686811,id689812,list3375,prog47083452,thunk696814);
++R.GAS;
return $ret35163517;
};
var $Hanf_arg30293521 = function(anf_arg20763520,A119,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,b687805,d686811,id689812,list3375,prog47083452,thunk696814) {
var anf_fun20773533 = G(A119,"s-block",L[411]);
var anf_fun20783534 = G(list3375,"make",L[410]);
var anf_fun20793535 = G(A119,"s-letrec",L[409]);
var anf_fun20803536 = G(list3375,"make",L[408]);
var anf_fun20813537 = G(A119,"s-letrec-bind",L[407]);
var $z35243525 = D;
var $f35303531 = function(_) {
return R.isFunction(b687805)?b687805.app(("f")):R.ffi.throwNonFunApp(L[406],b687805,[("f")]);
};
try {
if(--R.GAS > 0) {
$z35243525 = $f35303531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35303531,
"from":L[406]});
}
} catch($e35223523) {
if(R.isCont($e35223523)) {
var $ss35263527 = {"from":L[406],
"go":function(anf_arg20823532) {
return $Hanf_arg30283538(anf_arg20823532,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452,thunk696814);
}};
$e35223523.stack[R.EXN_STACKHEIGHT++] = $ss35263527;
}
if(R.isPyretException($e35223523)) {
$e35223523.pyretStack.push(L[406]);
}
throw $e35223523;
}
var $ret35283529 = $Hanf_arg30283538($z35243525,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452,thunk696814);
++R.GAS;
return $ret35283529;
};
var $Hanf_arg30283538 = function(anf_arg20823532,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452,thunk696814) {
var anf_fun20833549 = G(A119,"s-num",L[413]);
var $z35413542 = D;
var $f35473548 = function(_) {
return R.isFunction(anf_fun20833549)?anf_fun20833549.app(d686811,(4)):R.ffi.throwNonFunApp(L[412],anf_fun20833549,[d686811,(4)]);
};
try {
if(--R.GAS > 0) {
$z35413542 = $f35473548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35473548,
"from":L[412]});
}
} catch($e35393540) {
if(R.isCont($e35393540)) {
var $ss35433544 = {"from":L[412],
"go":function(anf_arg20843550) {
return $Hanf_arg30273551(anf_arg20843550,A119,anf_arg20763520,anf_arg20823532,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452,thunk696814);
}};
$e35393540.stack[R.EXN_STACKHEIGHT++] = $ss35433544;
}
if(R.isPyretException($e35393540)) {
$e35393540.pyretStack.push(L[412]);
}
throw $e35393540;
}
var $ret35453546 = $Hanf_arg30273551($z35413542,A119,anf_arg20763520,anf_arg20823532,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452,thunk696814);
++R.GAS;
return $ret35453546;
};
var $Hanf_arg30273551 = function(anf_arg20843550,A119,anf_arg20763520,anf_arg20823532,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452,thunk696814) {
var $z35543555 = D;
var $f35603561 = function(_) {
return R.isFunction(thunk696814)?thunk696814.app(anf_arg20843550):R.ffi.throwNonFunApp(L[414],thunk696814,[anf_arg20843550]);
};
try {
if(--R.GAS > 0) {
$z35543555 = $f35603561();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35603561,
"from":L[414]});
}
} catch($e35523553) {
if(R.isCont($e35523553)) {
var $ss35563557 = {"from":L[414],
"go":function(anf_arg20853562) {
return $Hanf_arg30263563(anf_arg20853562,A119,anf_arg20763520,anf_arg20823532,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452);
}};
$e35523553.stack[R.EXN_STACKHEIGHT++] = $ss35563557;
}
if(R.isPyretException($e35523553)) {
$e35523553.pyretStack.push(L[414]);
}
throw $e35523553;
}
var $ret35583559 = $Hanf_arg30263563($z35543555,A119,anf_arg20763520,anf_arg20823532,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452);
++R.GAS;
return $ret35583559;
};
var $Hanf_arg30263563 = function(anf_arg20853562,A119,anf_arg20763520,anf_arg20823532,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,anf_fun20813537,d686811,id689812,list3375,prog47083452) {
var $z35663567 = D;
var $f35723573 = function(_) {
return R.isFunction(anf_fun20813537)?anf_fun20813537.app(d686811,anf_arg20823532,anf_arg20853562):R.ffi.throwNonFunApp(L[415],anf_fun20813537,[d686811,anf_arg20823532,anf_arg20853562]);
};
try {
if(--R.GAS > 0) {
$z35663567 = $f35723573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35723573,
"from":L[415]});
}
} catch($e35643565) {
if(R.isCont($e35643565)) {
var $ss35683569 = {"from":L[415],
"go":function(anf_array_val20863574) {
return $Hanf_array_val30253575(anf_array_val20863574,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,d686811,id689812,list3375,prog47083452);
}};
$e35643565.stack[R.EXN_STACKHEIGHT++] = $ss35683569;
}
if(R.isPyretException($e35643565)) {
$e35643565.pyretStack.push(L[415]);
}
throw $e35643565;
}
var $ret35703571 = $Hanf_array_val30253575($z35663567,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,d686811,id689812,list3375,prog47083452);
++R.GAS;
return $ret35703571;
};
var $Hanf_array_val30253575 = function(anf_array_val20863574,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20803536,d686811,id689812,list3375,prog47083452) {
var $z35783579 = D;
var $f35843585 = function(_) {
return R.isFunction(anf_fun20803536)?anf_fun20803536.app([anf_array_val20863574]):R.ffi.throwNonFunApp(L[408],anf_fun20803536,[[anf_array_val20863574]]);
};
try {
if(--R.GAS > 0) {
$z35783579 = $f35843585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35843585,
"from":L[408]});
}
} catch($e35763577) {
if(R.isCont($e35763577)) {
var $ss35803581 = {"from":L[408],
"go":function(anf_arg20873586) {
return $Hanf_arg30243587(anf_arg20873586,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,d686811,id689812,list3375,prog47083452);
}};
$e35763577.stack[R.EXN_STACKHEIGHT++] = $ss35803581;
}
if(R.isPyretException($e35763577)) {
$e35763577.pyretStack.push(L[408]);
}
throw $e35763577;
}
var $ret35823583 = $Hanf_arg30243587($z35783579,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,d686811,id689812,list3375,prog47083452);
++R.GAS;
return $ret35823583;
};
var $Hanf_arg30243587 = function(anf_arg20873586,A119,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,d686811,id689812,list3375,prog47083452) {
var anf_fun20883599 = G(A119,"s-app",L[417]);
var $z35903591 = D;
var $f35963597 = function(_) {
return R.isFunction(id689812)?id689812.app(("f")):R.ffi.throwNonFunApp(L[416],id689812,[("f")]);
};
try {
if(--R.GAS > 0) {
$z35903591 = $f35963597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f35963597,
"from":L[416]});
}
} catch($e35883589) {
if(R.isCont($e35883589)) {
var $ss35923593 = {"from":L[416],
"go":function(anf_arg20893598) {
return $Hanf_arg30233600(anf_arg20893598,anf_arg20763520,anf_arg20873586,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20883599,d686811,list3375,prog47083452);
}};
$e35883589.stack[R.EXN_STACKHEIGHT++] = $ss35923593;
}
if(R.isPyretException($e35883589)) {
$e35883589.pyretStack.push(L[416]);
}
throw $e35883589;
}
var $ret35943595 = $Hanf_arg30233600($z35903591,anf_arg20763520,anf_arg20873586,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20883599,d686811,list3375,prog47083452);
++R.GAS;
return $ret35943595;
};
var $Hanf_arg30233600 = function(anf_arg20893598,anf_arg20763520,anf_arg20873586,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20883599,d686811,list3375,prog47083452) {
var anf_fun20903611 = G(list3375,"make",L[418]);
var $z36033604 = D;
var $f36093610 = function(_) {
return R.isFunction(anf_fun20903611)?anf_fun20903611.app([]):R.ffi.throwNonFunApp(L[418],anf_fun20903611,[[]]);
};
try {
if(--R.GAS > 0) {
$z36033604 = $f36093610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36093610,
"from":L[418]});
}
} catch($e36013602) {
if(R.isCont($e36013602)) {
var $ss36053606 = {"from":L[418],
"go":function(anf_arg20913612) {
return $Hanf_arg30223613(anf_arg20913612,anf_arg20763520,anf_arg20873586,anf_arg20893598,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20883599,d686811,prog47083452);
}};
$e36013602.stack[R.EXN_STACKHEIGHT++] = $ss36053606;
}
if(R.isPyretException($e36013602)) {
$e36013602.pyretStack.push(L[418]);
}
throw $e36013602;
}
var $ret36073608 = $Hanf_arg30223613($z36033604,anf_arg20763520,anf_arg20873586,anf_arg20893598,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20883599,d686811,prog47083452);
++R.GAS;
return $ret36073608;
};
var $Hanf_arg30223613 = function(anf_arg20913612,anf_arg20763520,anf_arg20873586,anf_arg20893598,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,anf_fun20883599,d686811,prog47083452) {
var $z36163617 = D;
var $f36223623 = function(_) {
return R.isFunction(anf_fun20883599)?anf_fun20883599.app(d686811,anf_arg20893598,anf_arg20913612):R.ffi.throwNonFunApp(L[419],anf_fun20883599,[d686811,anf_arg20893598,anf_arg20913612]);
};
try {
if(--R.GAS > 0) {
$z36163617 = $f36223623();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36223623,
"from":L[419]});
}
} catch($e36143615) {
if(R.isCont($e36143615)) {
var $ss36183619 = {"from":L[419],
"go":function(anf_arg20923624) {
return $Hanf_arg30213625(anf_arg20923624,anf_arg20763520,anf_arg20873586,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,d686811,prog47083452);
}};
$e36143615.stack[R.EXN_STACKHEIGHT++] = $ss36183619;
}
if(R.isPyretException($e36143615)) {
$e36143615.pyretStack.push(L[419]);
}
throw $e36143615;
}
var $ret36203621 = $Hanf_arg30213625($z36163617,anf_arg20763520,anf_arg20873586,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,d686811,prog47083452);
++R.GAS;
return $ret36203621;
};
var $Hanf_arg30213625 = function(anf_arg20923624,anf_arg20763520,anf_arg20873586,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,anf_fun20793535,d686811,prog47083452) {
var $z36283629 = D;
var $f36343635 = function(_) {
return R.isFunction(anf_fun20793535)?anf_fun20793535.app(d686811,anf_arg20873586,anf_arg20923624):R.ffi.throwNonFunApp(L[420],anf_fun20793535,[d686811,anf_arg20873586,anf_arg20923624]);
};
try {
if(--R.GAS > 0) {
$z36283629 = $f36343635();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36343635,
"from":L[420]});
}
} catch($e36263627) {
if(R.isCont($e36263627)) {
var $ss36303631 = {"from":L[420],
"go":function(anf_array_val20933636) {
return $Hanf_array_val30203637(anf_array_val20933636,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,d686811,prog47083452);
}};
$e36263627.stack[R.EXN_STACKHEIGHT++] = $ss36303631;
}
if(R.isPyretException($e36263627)) {
$e36263627.pyretStack.push(L[420]);
}
throw $e36263627;
}
var $ret36323633 = $Hanf_array_val30203637($z36283629,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,d686811,prog47083452);
++R.GAS;
return $ret36323633;
};
var $Hanf_array_val30203637 = function(anf_array_val20933636,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,anf_fun20783534,d686811,prog47083452) {
var $z36403641 = D;
var $f36463647 = function(_) {
return R.isFunction(anf_fun20783534)?anf_fun20783534.app([anf_array_val20933636]):R.ffi.throwNonFunApp(L[410],anf_fun20783534,[[anf_array_val20933636]]);
};
try {
if(--R.GAS > 0) {
$z36403641 = $f36463647();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36463647,
"from":L[410]});
}
} catch($e36383639) {
if(R.isCont($e36383639)) {
var $ss36423643 = {"from":L[410],
"go":function(anf_arg20943648) {
return $Hanf_arg30193649(anf_arg20943648,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,d686811,prog47083452);
}};
$e36383639.stack[R.EXN_STACKHEIGHT++] = $ss36423643;
}
if(R.isPyretException($e36383639)) {
$e36383639.pyretStack.push(L[410]);
}
throw $e36383639;
}
var $ret36443645 = $Hanf_arg30193649($z36403641,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,d686811,prog47083452);
++R.GAS;
return $ret36443645;
};
var $Hanf_arg30193649 = function(anf_arg20943648,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,anf_fun20773533,d686811,prog47083452) {
var $z36523653 = D;
var $f36583659 = function(_) {
return R.isFunction(anf_fun20773533)?anf_fun20773533.app(d686811,anf_arg20943648):R.ffi.throwNonFunApp(L[421],anf_fun20773533,[d686811,anf_arg20943648]);
};
try {
if(--R.GAS > 0) {
$z36523653 = $f36583659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36583659,
"from":L[421]});
}
} catch($e36503651) {
if(R.isCont($e36503651)) {
var $ss36543655 = {"from":L[421],
"go":function(anf_arg20953660) {
return $Hanf_arg30183661(anf_arg20953660,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,d686811,prog47083452);
}};
$e36503651.stack[R.EXN_STACKHEIGHT++] = $ss36543655;
}
if(R.isPyretException($e36503651)) {
$e36503651.pyretStack.push(L[421]);
}
throw $e36503651;
}
var $ret36563657 = $Hanf_arg30183661($z36523653,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,d686811,prog47083452);
++R.GAS;
return $ret36563657;
};
var $Hanf_arg30183661 = function(anf_arg20953660,anf_arg20763520,anf_fun20663478,anf_fun20673479,anf_fun20683480,anf_fun20693481,d686811,prog47083452) {
var $z36643665 = D;
var $f36703671 = function(_) {
return R.isFunction(anf_fun20693481)?anf_fun20693481.app(d686811,anf_arg20763520,anf_arg20953660):R.ffi.throwNonFunApp(L[422],anf_fun20693481,[d686811,anf_arg20763520,anf_arg20953660]);
};
try {
if(--R.GAS > 0) {
$z36643665 = $f36703671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36703671,
"from":L[422]});
}
} catch($e36623663) {
if(R.isCont($e36623663)) {
var $ss36663667 = {"from":L[422],
"go":function(anf_array_val20963672) {
return $Hanf_array_val30173673(anf_array_val20963672,anf_fun20663478,anf_fun20673479,anf_fun20683480,d686811,prog47083452);
}};
$e36623663.stack[R.EXN_STACKHEIGHT++] = $ss36663667;
}
if(R.isPyretException($e36623663)) {
$e36623663.pyretStack.push(L[422]);
}
throw $e36623663;
}
var $ret36683669 = $Hanf_array_val30173673($z36643665,anf_fun20663478,anf_fun20673479,anf_fun20683480,d686811,prog47083452);
++R.GAS;
return $ret36683669;
};
var $Hanf_array_val30173673 = function(anf_array_val20963672,anf_fun20663478,anf_fun20673479,anf_fun20683480,d686811,prog47083452) {
var $z36763677 = D;
var $f36823683 = function(_) {
return R.isFunction(anf_fun20683480)?anf_fun20683480.app([anf_array_val20963672]):R.ffi.throwNonFunApp(L[401],anf_fun20683480,[[anf_array_val20963672]]);
};
try {
if(--R.GAS > 0) {
$z36763677 = $f36823683();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36823683,
"from":L[401]});
}
} catch($e36743675) {
if(R.isCont($e36743675)) {
var $ss36783679 = {"from":L[401],
"go":function(anf_arg20973684) {
return $Hanf_arg30163685(anf_arg20973684,anf_fun20663478,anf_fun20673479,d686811,prog47083452);
}};
$e36743675.stack[R.EXN_STACKHEIGHT++] = $ss36783679;
}
if(R.isPyretException($e36743675)) {
$e36743675.pyretStack.push(L[401]);
}
throw $e36743675;
}
var $ret36803681 = $Hanf_arg30163685($z36763677,anf_fun20663478,anf_fun20673479,d686811,prog47083452);
++R.GAS;
return $ret36803681;
};
var $Hanf_arg30163685 = function(anf_arg20973684,anf_fun20663478,anf_fun20673479,d686811,prog47083452) {
var $z36883689 = D;
var $f36943695 = function(_) {
return R.isFunction(anf_fun20673479)?anf_fun20673479.app(d686811,anf_arg20973684):R.ffi.throwNonFunApp(L[423],anf_fun20673479,[d686811,anf_arg20973684]);
};
try {
if(--R.GAS > 0) {
$z36883689 = $f36943695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f36943695,
"from":L[423]});
}
} catch($e36863687) {
if(R.isCont($e36863687)) {
var $ss36903691 = {"from":L[423],
"go":function(anf_arg20983696) {
return $Hanf_arg30153697(anf_arg20983696,anf_fun20663478,prog47083452);
}};
$e36863687.stack[R.EXN_STACKHEIGHT++] = $ss36903691;
}
if(R.isPyretException($e36863687)) {
$e36863687.pyretStack.push(L[423]);
}
throw $e36863687;
}
var $ret36923693 = $Hanf_arg30153697($z36883689,anf_fun20663478,prog47083452);
++R.GAS;
return $ret36923693;
};
var $Hanf_arg30153697 = function(anf_arg20983696,anf_fun20663478,prog47083452) {
var anf_arg20993708 = R.makeSrcloc(L[396]);
var $z37003701 = D;
var $f37063707 = function(_) {
return R.isFunction(anf_fun20663478)?anf_fun20663478.app(("prog4 is\n  A.s-block(d,\n    [list: \n      A.s-let-expr(d,\n        [list: A.s-var-bind(d, b(\"x\"), A.s-num(d, 10))],\n        A.s-block(d,\n          [list: \n            A.s-letrec(d,\n              [list: A.s-letrec-bind(d, b(\"f\"), thunk(A.s-num(d, 4)))],\n              A.s-app(d, id(\"f\"), [list: ]))\n          ]))\n    ])"),prog47083452,anf_arg20983696,anf_arg20993708):R.ffi.throwNonFunApp(L[94],anf_fun20663478,[("prog4 is\n  A.s-block(d,\n    [list: \n      A.s-let-expr(d,\n        [list: A.s-var-bind(d, b(\"x\"), A.s-num(d, 10))],\n        A.s-block(d,\n          [list: \n            A.s-letrec(d,\n              [list: A.s-letrec-bind(d, b(\"f\"), thunk(A.s-num(d, 4)))],\n              A.s-app(d, id(\"f\"), [list: ]))\n          ]))\n    ])"),prog47083452,anf_arg20983696,anf_arg20993708]);
};
try {
if(--R.GAS > 0) {
$z37003701 = $f37063707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37063707,
"from":L[94]});
}
} catch($e36983699) {
if(R.isCont($e36983699)) {
var $ss37023703 = {"from":L[94],
"go":function(ann_DASH_check_DASH_temp17973709) {
return $Hann_DASH_check_DASH_temp30143710(ann_DASH_check_DASH_temp17973709);
}};
$e36983699.stack[R.EXN_STACKHEIGHT++] = $ss37023703;
}
if(R.isPyretException($e36983699)) {
$e36983699.pyretStack.push(L[94]);
}
throw $e36983699;
}
var $ret37043705 = $Hann_DASH_check_DASH_temp30143710($z37003701);
++R.GAS;
return $ret37043705;
};
var $Hann_DASH_check_DASH_temp30143710 = function(ann_DASH_check_DASH_temp17973709) {
return ann_DASH_check_DASH_temp17973709;
};
var $Hanf_bracket30113238 = function(anf_bracket20303237,A119,p17053224,p27063225) {
var anf_fun20313724 = G(anf_bracket20303237,"check-is",L[375]);
var anf_fun20323721 = G(p17053224,"visit",L[426]);
var anf_arg20333722 = G(A119,"dummy-loc-visitor",L[425]);
var $z37133714 = D;
var $f37193720 = function(_) {
return R.isFunction(anf_fun20323721)?anf_fun20323721.app(anf_arg20333722):R.ffi.throwNonFunApp(L[424],anf_fun20323721,[anf_arg20333722]);
};
try {
if(--R.GAS > 0) {
$z37133714 = $f37193720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37193720,
"from":L[424]});
}
} catch($e37113712) {
if(R.isCont($e37113712)) {
var $ss37153716 = {"from":L[424],
"go":function(anf_arg20343723) {
return $Hanf_arg30103725(anf_arg20343723,anf_fun20313724,p27063225);
}};
$e37113712.stack[R.EXN_STACKHEIGHT++] = $ss37153716;
}
if(R.isPyretException($e37113712)) {
$e37113712.pyretStack.push(L[424]);
}
throw $e37113712;
}
var $ret37173718 = $Hanf_arg30103725($z37133714,anf_fun20313724,p27063225);
++R.GAS;
return $ret37173718;
};
var $Hanf_arg30103725 = function(anf_arg20343723,anf_fun20313724,p27063225) {
var anf_arg20353736 = R.makeSrcloc(L[375]);
var $z37283729 = D;
var $f37343735 = function(_) {
return R.isFunction(anf_fun20313724)?anf_fun20313724.app(("p1.visit(A.dummy-loc-visitor) is p2"),anf_arg20343723,p27063225,anf_arg20353736):R.ffi.throwNonFunApp(L[374],anf_fun20313724,[("p1.visit(A.dummy-loc-visitor) is p2"),anf_arg20343723,p27063225,anf_arg20353736]);
};
try {
if(--R.GAS > 0) {
$z37283729 = $f37343735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37343735,
"from":L[374]});
}
} catch($e37263727) {
if(R.isCont($e37263727)) {
var $ss37303731 = {"from":L[374],
"go":function(ann_DASH_check_DASH_temp20283737) {
return $Hann_DASH_check_DASH_temp30093738(ann_DASH_check_DASH_temp20283737);
}};
$e37263727.stack[R.EXN_STACKHEIGHT++] = $ss37303731;
}
if(R.isPyretException($e37263727)) {
$e37263727.pyretStack.push(L[374]);
}
throw $e37263727;
}
var $ret37323733 = $Hann_DASH_check_DASH_temp30093738($z37283729);
++R.GAS;
return $ret37323733;
};
var $Hann_DASH_check_DASH_temp30093738 = function(ann_DASH_check_DASH_temp20283737) {
return ann_DASH_check_DASH_temp20283737;
};
var $Hanf_bracket30062734 = function(anf_bracket19622733) {
var anf_fun19633749 = G(anf_bracket19622733,"pretty",L[428]);
var $z37413742 = D;
var $f37473748 = function(_) {
return R.isFunction(anf_fun19633749)?anf_fun19633749.app((80)):R.ffi.throwNonFunApp(L[427],anf_fun19633749,[(80)]);
};
try {
if(--R.GAS > 0) {
$z37413742 = $f37473748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37473748,
"from":L[427]});
}
} catch($e37393740) {
if(R.isCont($e37393740)) {
var $ss37433744 = {"from":L[427],
"go":function(anf_bracket19643750) {
return $Hanf_bracket30053751(anf_bracket19643750);
}};
$e37393740.stack[R.EXN_STACKHEIGHT++] = $ss37433744;
}
if(R.isPyretException($e37393740)) {
$e37393740.pyretStack.push(L[427]);
}
throw $e37393740;
}
var $ret37453746 = $Hanf_bracket30053751($z37413742);
++R.GAS;
return $ret37453746;
};
var $Hanf_bracket30053751 = function(anf_bracket19643750) {
var anf_fun19653762 = G(anf_bracket19643750,"join-str",L[429]);
var $z37543755 = D;
var $f37603761 = function(_) {
return R.isFunction(anf_fun19653762)?anf_fun19653762.app(("\n")):R.ffi.throwNonFunApp(L[318],anf_fun19653762,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z37543755 = $f37603761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37603761,
"from":L[318]});
}
} catch($e37523753) {
if(R.isCont($e37523753)) {
var $ss37563757 = {"from":L[318],
"go":function(ann_DASH_check_DASH_temp19603763) {
return $Hann_DASH_check_DASH_temp30043764(ann_DASH_check_DASH_temp19603763);
}};
$e37523753.stack[R.EXN_STACKHEIGHT++] = $ss37563757;
}
if(R.isPyretException($e37523753)) {
$e37523753.pyretStack.push(L[318]);
}
throw $e37523753;
}
var $ret37583759 = $Hann_DASH_check_DASH_temp30043764($z37543755);
++R.GAS;
return $ret37583759;
};
var $Hann_DASH_check_DASH_temp30043764 = function(ann_DASH_check_DASH_temp19603763) {
return ann_DASH_check_DASH_temp19603763;
};
var $Hanf_arg30032748 = function(anf_arg19572746,anf_fun19562747,d686811,e7012735,list3375) {
var anf_fun19583775 = G(list3375,"make",L[430]);
var $z37673768 = D;
var $f37733774 = function(_) {
return R.isFunction(anf_fun19583775)?anf_fun19583775.app([e7012735]):R.ffi.throwNonFunApp(L[430],anf_fun19583775,[[e7012735]]);
};
try {
if(--R.GAS > 0) {
$z37673768 = $f37733774();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37733774,
"from":L[430]});
}
} catch($e37653766) {
if(R.isCont($e37653766)) {
var $ss37693770 = {"from":L[430],
"go":function(anf_arg19593776) {
return $Hanf_arg30023777(anf_arg19593776,anf_arg19572746,anf_fun19562747,d686811);
}};
$e37653766.stack[R.EXN_STACKHEIGHT++] = $ss37693770;
}
if(R.isPyretException($e37653766)) {
$e37653766.pyretStack.push(L[430]);
}
throw $e37653766;
}
var $ret37713772 = $Hanf_arg30023777($z37673768,anf_arg19572746,anf_fun19562747,d686811);
++R.GAS;
return $ret37713772;
};
var $Hanf_arg30023777 = function(anf_arg19593776,anf_arg19572746,anf_fun19562747,d686811) {
var $z37803781 = D;
var $f37863787 = function(_) {
return R.isFunction(anf_fun19562747)?anf_fun19562747.app(d686811,anf_arg19572746,anf_arg19593776):R.ffi.throwNonFunApp(L[321],anf_fun19562747,[d686811,anf_arg19572746,anf_arg19593776]);
};
try {
if(--R.GAS > 0) {
$z37803781 = $f37863787();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37863787,
"from":L[321]});
}
} catch($e37783779) {
if(R.isCont($e37783779)) {
var $ss37823783 = {"from":L[321],
"go":function(ann_DASH_check_DASH_temp19553788) {
return $Hann_DASH_check_DASH_temp30013789(ann_DASH_check_DASH_temp19553788);
}};
$e37783779.stack[R.EXN_STACKHEIGHT++] = $ss37823783;
}
if(R.isPyretException($e37783779)) {
$e37783779.pyretStack.push(L[321]);
}
throw $e37783779;
}
var $ret37843785 = $Hann_DASH_check_DASH_temp30013789($z37803781);
++R.GAS;
return $ret37843785;
};
var $Hann_DASH_check_DASH_temp30013789 = function(ann_DASH_check_DASH_temp19553788) {
return ann_DASH_check_DASH_temp19553788;
};
var $Hanf_arg2996832 = function(anf_arg1831828,A119,anf_fun1829829,bk691830,d686811,e697816,list3375,n695831) {
var anf_fun18323800 = G(list3375,"make",L[431]);
var $z37923793 = D;
var $f37983799 = function(_) {
return R.isFunction(anf_fun18323800)?anf_fun18323800.app([]):R.ffi.throwNonFunApp(L[431],anf_fun18323800,[[]]);
};
try {
if(--R.GAS > 0) {
$z37923793 = $f37983799();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f37983799,
"from":L[431]});
}
} catch($e37903791) {
if(R.isCont($e37903791)) {
var $ss37943795 = {"from":L[431],
"go":function(anf_arg18333801) {
return $Hanf_arg29953802(anf_arg18333801,A119,anf_arg1831828,anf_fun1829829,bk691830,d686811,e697816,n695831);
}};
$e37903791.stack[R.EXN_STACKHEIGHT++] = $ss37943795;
}
if(R.isPyretException($e37903791)) {
$e37903791.pyretStack.push(L[431]);
}
throw $e37903791;
}
var $ret37963797 = $Hanf_arg29953802($z37923793,A119,anf_arg1831828,anf_fun1829829,bk691830,d686811,e697816,n695831);
++R.GAS;
return $ret37963797;
};
var $Hanf_arg29953802 = function(anf_arg18333801,A119,anf_arg1831828,anf_fun1829829,bk691830,d686811,e697816,n695831) {
var anf_arg18343814 = G(A119,"a-blank",L[433]);
var $z38053806 = D;
var $f38113812 = function(_) {
return R.isFunction(bk691830)?bk691830.app(e697816):R.ffi.throwNonFunApp(L[432],bk691830,[e697816]);
};
try {
if(--R.GAS > 0) {
$z38053806 = $f38113812();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38113812,
"from":L[432]});
}
} catch($e38033804) {
if(R.isCont($e38033804)) {
var $ss38073808 = {"from":L[432],
"go":function(anf_arg18353813) {
return $Hanf_arg29943815(anf_arg18353813,anf_arg1831828,anf_arg18333801,anf_arg18343814,anf_fun1829829,d686811,n695831);
}};
$e38033804.stack[R.EXN_STACKHEIGHT++] = $ss38073808;
}
if(R.isPyretException($e38033804)) {
$e38033804.pyretStack.push(L[432]);
}
throw $e38033804;
}
var $ret38093810 = $Hanf_arg29943815($z38053806,anf_arg1831828,anf_arg18333801,anf_arg18343814,anf_fun1829829,d686811,n695831);
++R.GAS;
return $ret38093810;
};
var $Hanf_arg29943815 = function(anf_arg18353813,anf_arg1831828,anf_arg18333801,anf_arg18343814,anf_fun1829829,d686811,n695831) {
var $z38183819 = D;
var $f38243825 = function(_) {
return R.isFunction(anf_fun1829829)?anf_fun1829829.app(d686811,anf_arg1831828,anf_arg18333801,anf_arg18343814,(""),anf_arg18353813,n695831):R.ffi.throwNonFunApp(L[99],anf_fun1829829,[d686811,anf_arg1831828,anf_arg18333801,anf_arg18343814,(""),anf_arg18353813,n695831]);
};
try {
if(--R.GAS > 0) {
$z38183819 = $f38243825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38243825,
"from":L[99]});
}
} catch($e38163817) {
if(R.isCont($e38163817)) {
var $ss38203821 = {"from":L[99],
"go":function(ann_DASH_check_DASH_temp18283826) {
return $Hann_DASH_check_DASH_temp29933827(ann_DASH_check_DASH_temp18283826);
}};
$e38163817.stack[R.EXN_STACKHEIGHT++] = $ss38203821;
}
if(R.isPyretException($e38163817)) {
$e38163817.pyretStack.push(L[99]);
}
throw $e38163817;
}
var $ret38223823 = $Hann_DASH_check_DASH_temp29933827($z38183819);
++R.GAS;
return $ret38223823;
};
var $Hann_DASH_check_DASH_temp29933827 = function(ann_DASH_check_DASH_temp18283826) {
return ann_DASH_check_DASH_temp18283826;
};
var $Hanf_bracket2992846 = function(anf_bracket1816844,A119,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375) {
var anf_arg18173840 = G(anf_bracket1816844,"stmts",L[435]);
var anf_fun18183838 = G(list3375,"make",L[434]);
var $z38303831 = D;
var $f38363837 = function(_) {
return R.isFunction(anf_fun18183838)?anf_fun18183838.app([]):R.ffi.throwNonFunApp(L[434],anf_fun18183838,[[]]);
};
try {
if(--R.GAS > 0) {
$z38303831 = $f38363837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38363837,
"from":L[434]});
}
} catch($e38283829) {
if(R.isCont($e38283829)) {
var $ss38323833 = {"from":L[434],
"go":function(anf_arg18193839) {
return $Hanf_arg29913841(anf_arg18193839,A119,anf_arg18173840,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375);
}};
$e38283829.stack[R.EXN_STACKHEIGHT++] = $ss38323833;
}
if(R.isPyretException($e38283829)) {
$e38283829.pyretStack.push(L[434]);
}
throw $e38283829;
}
var $ret38343835 = $Hanf_arg29913841($z38303831,A119,anf_arg18173840,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375);
++R.GAS;
return $ret38343835;
};
var $Hanf_arg29913841 = function(anf_arg18193839,A119,anf_arg18173840,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375) {
var anf_fun18203852 = G(list3375,"make",L[436]);
var $z38443845 = D;
var $f38503851 = function(_) {
return R.isFunction(anf_fun18203852)?anf_fun18203852.app([]):R.ffi.throwNonFunApp(L[436],anf_fun18203852,[[]]);
};
try {
if(--R.GAS > 0) {
$z38443845 = $f38503851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38503851,
"from":L[436]});
}
} catch($e38423843) {
if(R.isCont($e38423843)) {
var $ss38463847 = {"from":L[436],
"go":function(anf_arg18213853) {
return $Hanf_arg29903854(anf_arg18213853,A119,anf_arg18173840,anf_arg18193839,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375);
}};
$e38423843.stack[R.EXN_STACKHEIGHT++] = $ss38463847;
}
if(R.isPyretException($e38423843)) {
$e38423843.pyretStack.push(L[436]);
}
throw $e38423843;
}
var $ret38483849 = $Hanf_arg29903854($z38443845,A119,anf_arg18173840,anf_arg18193839,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375);
++R.GAS;
return $ret38483849;
};
var $Hanf_arg29903854 = function(anf_arg18213853,A119,anf_arg18173840,anf_arg18193839,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165,list3375) {
var anf_fun18223865 = G(list3375,"make",L[437]);
var $z38573858 = D;
var $f38633864 = function(_) {
return R.isFunction(anf_fun18223865)?anf_fun18223865.app([]):R.ffi.throwNonFunApp(L[437],anf_fun18223865,[[]]);
};
try {
if(--R.GAS > 0) {
$z38573858 = $f38633864();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38633864,
"from":L[437]});
}
} catch($e38553856) {
if(R.isCont($e38553856)) {
var $ss38593860 = {"from":L[437],
"go":function(anf_arg18233866) {
return $Hanf_arg29893867(anf_arg18233866,A119,anf_arg18173840,anf_arg18193839,anf_arg18213853,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165);
}};
$e38553856.stack[R.EXN_STACKHEIGHT++] = $ss38593860;
}
if(R.isPyretException($e38553856)) {
$e38553856.pyretStack.push(L[437]);
}
throw $e38553856;
}
var $ret38613862 = $Hanf_arg29893867($z38573858,A119,anf_arg18173840,anf_arg18193839,anf_arg18213853,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165);
++R.GAS;
return $ret38613862;
};
var $Hanf_arg29893867 = function(anf_arg18233866,A119,anf_arg18173840,anf_arg18193839,anf_arg18213853,anf_fun1815845,d686811,desugar_DASH_scope_DASH_block9165) {
var $z38703871 = D;
var $f38763877 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(anf_arg18173840,anf_arg18193839,anf_arg18213853,anf_arg18233866):R.ffi.throwNonFunApp(L[438],desugar_DASH_scope_DASH_block9165.$var,[anf_arg18173840,anf_arg18193839,anf_arg18213853,anf_arg18233866]);
};
try {
if(--R.GAS > 0) {
$z38703871 = $f38763877();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38763877,
"from":L[438]});
}
} catch($e38683869) {
if(R.isCont($e38683869)) {
var $ss38723873 = {"from":L[438],
"go":function(anf_arg18243878) {
return $Hanf_arg29883879(anf_arg18243878,A119,anf_fun1815845,d686811);
}};
$e38683869.stack[R.EXN_STACKHEIGHT++] = $ss38723873;
}
if(R.isPyretException($e38683869)) {
$e38683869.pyretStack.push(L[438]);
}
throw $e38683869;
}
var $ret38743875 = $Hanf_arg29883879($z38703871,A119,anf_fun1815845,d686811);
++R.GAS;
return $ret38743875;
};
var $Hanf_arg29883879 = function(anf_arg18243878,A119,anf_fun1815845,d686811) {
var $z38823883 = D;
var $f38883889 = function(_) {
return R.isFunction(anf_fun1815845)?anf_fun1815845.app(d686811,anf_arg18243878):R.ffi.throwNonFunApp(L[439],anf_fun1815845,[d686811,anf_arg18243878]);
};
try {
if(--R.GAS > 0) {
$z38823883 = $f38883889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f38883889,
"from":L[439]});
}
} catch($e38803881) {
if(R.isCont($e38803881)) {
var $ss38843885 = {"from":L[439],
"go":function(anf_bracket18253890) {
return $Hanf_bracket29873891(anf_bracket18253890,A119);
}};
$e38803881.stack[R.EXN_STACKHEIGHT++] = $ss38843885;
}
if(R.isPyretException($e38803881)) {
$e38803881.pyretStack.push(L[439]);
}
throw $e38803881;
}
var $ret38863887 = $Hanf_bracket29873891($z38823883,A119);
++R.GAS;
return $ret38863887;
};
var $Hanf_bracket29873891 = function(anf_bracket18253890,A119) {
var anf_fun18263902 = G(anf_bracket18253890,"visit",L[441]);
var anf_arg18273903 = G(A119,"dummy-loc-visitor",L[440]);
var $z38943895 = D;
var $f39003901 = function(_) {
return R.isFunction(anf_fun18263902)?anf_fun18263902.app(anf_arg18273903):R.ffi.throwNonFunApp(L[102],anf_fun18263902,[anf_arg18273903]);
};
try {
if(--R.GAS > 0) {
$z38943895 = $f39003901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39003901,
"from":L[102]});
}
} catch($e38923893) {
if(R.isCont($e38923893)) {
var $ss38963897 = {"from":L[102],
"go":function(ann_DASH_check_DASH_temp18143904) {
return $Hann_DASH_check_DASH_temp29863905(ann_DASH_check_DASH_temp18143904);
}};
$e38923893.stack[R.EXN_STACKHEIGHT++] = $ss38963897;
}
if(R.isPyretException($e38923893)) {
$e38923893.pyretStack.push(L[102]);
}
throw $e38923893;
}
var $ret38983899 = $Hann_DASH_check_DASH_temp29863905($z38943895);
++R.GAS;
return $ret38983899;
};
var $Hann_DASH_check_DASH_temp29863905 = function(ann_DASH_check_DASH_temp18143904) {
return ann_DASH_check_DASH_temp18143904;
};
var $Hanf_arg2985861 = function(anf_arg1813859,anf_fun1811860,d686811) {
var $z39083909 = D;
var $f39143915 = function(_) {
return R.isFunction(anf_fun1811860)?anf_fun1811860.app(d686811,anf_arg1813859):R.ffi.throwNonFunApp(L[105],anf_fun1811860,[d686811,anf_arg1813859]);
};
try {
if(--R.GAS > 0) {
$z39083909 = $f39143915();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39143915,
"from":L[105]});
}
} catch($e39063907) {
if(R.isCont($e39063907)) {
var $ss39103911 = {"from":L[105],
"go":function(ann_DASH_check_DASH_temp18103916) {
return $Hann_DASH_check_DASH_temp29843917(ann_DASH_check_DASH_temp18103916);
}};
$e39063907.stack[R.EXN_STACKHEIGHT++] = $ss39103911;
}
if(R.isPyretException($e39063907)) {
$e39063907.pyretStack.push(L[105]);
}
throw $e39063907;
}
var $ret39123913 = $Hann_DASH_check_DASH_temp29843917($z39083909);
++R.GAS;
return $ret39123913;
};
var $Hann_DASH_check_DASH_temp29843917 = function(ann_DASH_check_DASH_temp18103916) {
return ann_DASH_check_DASH_temp18103916;
};
var $Hanf_arg2983876 = function(anf_arg1809874,anf_fun1807875,d686811) {
var $z39203921 = D;
var $f39263927 = function(_) {
return R.isFunction(anf_fun1807875)?anf_fun1807875.app(d686811,anf_arg1809874):R.ffi.throwNonFunApp(L[108],anf_fun1807875,[d686811,anf_arg1809874]);
};
try {
if(--R.GAS > 0) {
$z39203921 = $f39263927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39263927,
"from":L[108]});
}
} catch($e39183919) {
if(R.isCont($e39183919)) {
var $ss39223923 = {"from":L[108],
"go":function(ann_DASH_check_DASH_temp18063928) {
return $Hann_DASH_check_DASH_temp29823929(ann_DASH_check_DASH_temp18063928);
}};
$e39183919.stack[R.EXN_STACKHEIGHT++] = $ss39223923;
}
if(R.isPyretException($e39183919)) {
$e39183919.pyretStack.push(L[108]);
}
throw $e39183919;
}
var $ret39243925 = $Hann_DASH_check_DASH_temp29823929($z39203921);
++R.GAS;
return $ret39243925;
};
var $Hann_DASH_check_DASH_temp29823929 = function(ann_DASH_check_DASH_temp18063928) {
return ann_DASH_check_DASH_temp18063928;
};
var $Hanf_arg2981891 = function(anf_arg1804889,A119,anf_fun1802890,d686811) {
var anf_arg18053940 = G(A119,"a-blank",L[442]);
var $z39323933 = D;
var $f39383939 = function(_) {
return R.isFunction(anf_fun1802890)?anf_fun1802890.app(d686811,(false),anf_arg1804889,anf_arg18053940):R.ffi.throwNonFunApp(L[112],anf_fun1802890,[d686811,(false),anf_arg1804889,anf_arg18053940]);
};
try {
if(--R.GAS > 0) {
$z39323933 = $f39383939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39383939,
"from":L[112]});
}
} catch($e39303931) {
if(R.isCont($e39303931)) {
var $ss39343935 = {"from":L[112],
"go":function(ann_DASH_check_DASH_temp18013941) {
return $Hann_DASH_check_DASH_temp29803942(ann_DASH_check_DASH_temp18013941);
}};
$e39303931.stack[R.EXN_STACKHEIGHT++] = $ss39343935;
}
if(R.isPyretException($e39303931)) {
$e39303931.pyretStack.push(L[112]);
}
throw $e39303931;
}
var $ret39363937 = $Hann_DASH_check_DASH_temp29803942($z39323933);
++R.GAS;
return $ret39363937;
};
var $Hann_DASH_check_DASH_temp29803942 = function(ann_DASH_check_DASH_temp18013941) {
return ann_DASH_check_DASH_temp18013941;
};
var $Hanf_bracket2979905 = function(anf_bracket1800904) {
var ann_DASH_check_DASH_temp17983943 = G(anf_bracket1800904,"block",L[443]);
return ann_DASH_check_DASH_temp17983943;
};
var $Hvar_DASH_bind2978160 = function(var_DASH_bind2680159,A119,C923,SD722,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16) {
var name_DASH_errors3453956 = {"$var":var_DASH_bind2680159,
"$name":"name-errors"};
var anf_fun10133954 = G(SD722,"string-dict",L[445]);
var $z39463947 = D;
var $f39523953 = function(_) {
return R.isFunction(anf_fun10133954)?anf_fun10133954.app():R.ffi.throwNonFunApp(L[444],anf_fun10133954,[]);
};
try {
if(--R.GAS > 0) {
$z39463947 = $f39523953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39523953,
"from":L[444]});
}
} catch($e39443945) {
if(R.isCont($e39443945)) {
var $ss39483949 = {"from":L[444],
"go":function(bindings3463955) {
return $Hbindings29773957(bindings3463955,A119,C923,SD722,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,name_DASH_errors3453956,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16);
}};
$e39443945.stack[R.EXN_STACKHEIGHT++] = $ss39483949;
}
if(R.isPyretException($e39443945)) {
$e39443945.pyretStack.push(L[444]);
}
throw $e39443945;
}
var $ret39503951 = $Hbindings29773957($z39463947,A119,C923,SD722,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,name_DASH_errors3453956,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16);
++R.GAS;
return $ret39503951;
};
var $Hbindings29773957 = function(bindings3463955,A119,C923,SD722,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,name_DASH_errors3453956,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16) {
var anf_fun10143968 = G(SD722,"string-dict",L[447]);
var $z39603961 = D;
var $f39663967 = function(_) {
return R.isFunction(anf_fun10143968)?anf_fun10143968.app():R.ffi.throwNonFunApp(L[446],anf_fun10143968,[]);
};
try {
if(--R.GAS > 0) {
$z39603961 = $f39663967();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39663967,
"from":L[446]});
}
} catch($e39583959) {
if(R.isCont($e39583959)) {
var $ss39623963 = {"from":L[446],
"go":function(type_DASH_bindings3473969) {
return $Htype_DASH_bindings29763970(type_DASH_bindings3473969,A119,C923,bindings3463955,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,name_DASH_errors3453956,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16);
}};
$e39583959.stack[R.EXN_STACKHEIGHT++] = $ss39623963;
}
if(R.isPyretException($e39583959)) {
$e39583959.pyretStack.push(L[446]);
}
throw $e39583959;
}
var $ret39643965 = $Htype_DASH_bindings29763970($z39603961,A119,C923,bindings3463955,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,name_DASH_errors3453956,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16);
++R.GAS;
return $ret39643965;
};
var $Htype_DASH_bindings29763970 = function(type_DASH_bindings3473969,A119,C923,bindings3463955,empty3670,fold6171,global_DASH_bind297106,global_DASH_type_DASH_bind302116,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,map24676,name_DASH_errors3453956,names28657,none6979,p343146,resolved8483,scope_DASH_env_DASH_from_DASH_env307126,some7084,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,var_DASH_bind295102,_plus9,not11,nothing12,print13,raise14,torepr16) {
var make_DASH_atom_DASH_for3483971 = {"$var":D,
"$name":"make-atom-for"};
var update_DASH_type_DASH_binding_DASH_ann3493973 = {"$var":D,
"$name":"update-type-binding-ann"};
var update_DASH_binding_DASH_expr3503975 = {"$var":D,
"$name":"update-binding-expr"};
var handle_DASH_id3513977 = {"$var":D,
"$name":"handle-id"};
var handle_DASH_ann3523979 = {"$var":D,
"$name":"handle-ann"};
var anf_assign10603972 = R.makeFunction(function(name3534136,is_DASH_shadowing3544137,env3554138,bindings3564139,typ3574140) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[472],5,arguments);
}
var cases_DASH_val964199 = name3534136;
var anf_fun10164151 = G(cases_DASH_val964199,"_match",L[473]);
var anf_obj10474168 = R.makeFunction(function(l3584184,s3594185) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[478],2,arguments);
}
var anf_fun10184196 = G(env3554138,"has-key",L[480]);
var $z41884189 = D;
var $f41944195 = function(_) {
return R.isFunction(anf_fun10184196)?anf_fun10184196.app(s3594185):R.ffi.throwNonFunApp(L[479],anf_fun10184196,[s3594185]);
};
try {
if(--R.GAS > 0) {
$z41884189 = $f41944195();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41944195,
"from":L[479]});
}
} catch($e41864187) {
if(R.isCont($e41864187)) {
var $ss41904191 = {"from":L[479],
"go":function(and_DASH_oper_DASH_944197) {
return $Hand_DASH_oper_DASH_26954198(and_DASH_oper_DASH_944197,C923,bindings3564139,env3554138,is_DASH_shadowing3544137,l3584184,link3774,name_DASH_errors3453956,names28657,none6979,s3594185,typ3574140,not11,nothing12);
}};
$e41864187.stack[R.EXN_STACKHEIGHT++] = $ss41904191;
}
if(R.isPyretException($e41864187)) {
$e41864187.pyretStack.push(L[479]);
}
throw $e41864187;
}
var $ret41924193 = $Hand_DASH_oper_DASH_26954198($z41884189,C923,bindings3564139,env3554138,is_DASH_shadowing3544137,l3584184,link3774,name_DASH_errors3453956,names28657,none6979,s3594185,typ3574140,not11,nothing12);
++R.GAS;
return $ret41924193;
});
var anf_obj10544169 = R.makeFunction(function(l3634170) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[475],1,arguments);
}
var anf_fun10494181 = G(names28657,"make-atom",L[477]);
var $z41734174 = D;
var $f41794180 = function(_) {
return R.isFunction(anf_fun10494181)?anf_fun10494181.app(("$underscore")):R.ffi.throwNonFunApp(L[476],anf_fun10494181,[("$underscore")]);
};
try {
if(--R.GAS > 0) {
$z41734174 = $f41794180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41794180,
"from":L[476]});
}
} catch($e41714172) {
if(R.isCont($e41714172)) {
var $ss41754176 = {"from":L[476],
"go":function(atom3644182) {
return $Hatom27004183(atom3644182,bindings3564139,env3554138,l3634170,none6979,typ3574140);
}};
$e41714172.stack[R.EXN_STACKHEIGHT++] = $ss41754176;
}
if(R.isPyretException($e41714172)) {
$e41714172.pyretStack.push(L[476]);
}
throw $e41714172;
}
var $ret41774178 = $Hatom27004183($z41734174,bindings3564139,env3554138,l3634170,none6979,typ3574140);
++R.GAS;
return $ret41774178;
});
var anf_arg10554152 = R.makeObject({"s-name":anf_obj10474168,
"s-underscore":anf_obj10544169});
var anf_arg10594153 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[473],0,arguments);
}
var $z41584159 = D;
var $f41644165 = function(_) {
return R.isFunction(torepr16)?torepr16.app(name3534136):R.ffi.throwNonFunApp(L[474],torepr16,[name3534136]);
};
try {
if(--R.GAS > 0) {
$z41584159 = $f41644165();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41644165,
"from":L[474]});
}
} catch($e41564157) {
if(R.isCont($e41564157)) {
var $ss41604161 = {"from":L[474],
"go":function(anf_arg10574166) {
return $Hanf_arg27034167(anf_arg10574166,_plus9,raise14);
}};
$e41564157.stack[R.EXN_STACKHEIGHT++] = $ss41604161;
}
if(R.isPyretException($e41564157)) {
$e41564157.pyretStack.push(L[474]);
}
throw $e41564157;
}
var $ret41624163 = $Hanf_arg27034167($z41584159,_plus9,raise14);
++R.GAS;
return $ret41624163;
});
var $z41434144 = D;
var $f41494150 = function(_) {
return R.isFunction(anf_fun10164151)?anf_fun10164151.app(anf_arg10554152,anf_arg10594153):R.ffi.throwNonFunApp(L[472],anf_fun10164151,[anf_arg10554152,anf_arg10594153]);
};
try {
if(--R.GAS > 0) {
$z41434144 = $f41494150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41494150,
"from":L[472]});
}
} catch($e41414142) {
if(R.isCont($e41414142)) {
var $ss41454146 = {"from":L[472],
"go":function(ann_DASH_check_DASH_temp10154154) {
return $Hann_DASH_check_DASH_temp27044155(ann_DASH_check_DASH_temp10154154);
}};
$e41414142.stack[R.EXN_STACKHEIGHT++] = $ss41454146;
}
if(R.isPyretException($e41414142)) {
$e41414142.pyretStack.push(L[472]);
}
throw $e41414142;
}
var $ret41474148 = $Hann_DASH_check_DASH_temp27044155($z41434144);
++R.GAS;
return $ret41474148;
});
make_DASH_atom_DASH_for3483971.$var = anf_assign10603972;
var anf_assign11013974 = R.makeFunction(function(atom3654120,ann3664121) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[468],2,arguments);
}
var anf_fun10624134 = G(type_DASH_bindings3473969,"has-key",L[471]);
var anf_fun10634132 = G(atom3654120,"key",L[470]);
var $z41244125 = D;
var $f41304131 = function(_) {
return R.isFunction(anf_fun10634132)?anf_fun10634132.app():R.ffi.throwNonFunApp(L[469],anf_fun10634132,[]);
};
try {
if(--R.GAS > 0) {
$z41244125 = $f41304131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41304131,
"from":L[469]});
}
} catch($e41224123) {
if(R.isCont($e41224123)) {
var $ss41264127 = {"from":L[469],
"go":function(anf_arg10644133) {
return $Hanf_arg27214135(anf_arg10644133,anf_fun10624134,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,_plus9,print13,torepr16);
}};
$e41224123.stack[R.EXN_STACKHEIGHT++] = $ss41264127;
}
if(R.isPyretException($e41224123)) {
$e41224123.pyretStack.push(L[469]);
}
throw $e41224123;
}
var $ret41284129 = $Hanf_arg27214135($z41244125,anf_fun10624134,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,_plus9,print13,torepr16);
++R.GAS;
return $ret41284129;
});
update_DASH_type_DASH_binding_DASH_ann3493973.$var = anf_assign11013974;
var anf_assign11343976 = R.makeFunction(function(atom3764104,expr3774105) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[464],2,arguments);
}
var anf_fun11034118 = G(bindings3463955,"get",L[467]);
var anf_fun11044116 = G(atom3764104,"key",L[466]);
var $z41084109 = D;
var $f41144115 = function(_) {
return R.isFunction(anf_fun11044116)?anf_fun11044116.app():R.ffi.throwNonFunApp(L[465],anf_fun11044116,[]);
};
try {
if(--R.GAS > 0) {
$z41084109 = $f41144115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f41144115,
"from":L[465]});
}
} catch($e41064107) {
if(R.isCont($e41064107)) {
var $ss41104111 = {"from":L[465],
"go":function(anf_arg11054117) {
return $Hanf_arg27364119(anf_arg11054117,anf_fun11034118,atom3764104,bindings3463955,expr3774105,global_DASH_bind297106,let_DASH_bind29398,letrec_DASH_bind29194,var_DASH_bind295102);
}};
$e41064107.stack[R.EXN_STACKHEIGHT++] = $ss41104111;
}
if(R.isPyretException($e41064107)) {
$e41064107.pyretStack.push(L[465]);
}
throw $e41064107;
}
var $ret41124113 = $Hanf_arg27364119($z41084109,anf_fun11034118,atom3764104,bindings3463955,expr3774105,global_DASH_bind297106,let_DASH_bind29398,letrec_DASH_bind29194,var_DASH_bind295102);
++R.GAS;
return $ret41124113;
});
update_DASH_binding_DASH_expr3503975.$var = anf_assign11343976;
var anf_assign11773978 = R.makeFunction(function(env3904042,l3914043,id3924044) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[456],3,arguments);
}
var cases_DASH_val1024103 = id3924044;
var anf_fun11364055 = G(cases_DASH_val1024103,"_match",L[457]);
var anf_obj11684072 = R.makeFunction(function(l23934088,s3944089) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[461],2,arguments);
}
var anf_fun11384100 = G(env3904042,"has-key",L[463]);
var $z40924093 = D;
var $f40984099 = function(_) {
return R.isFunction(anf_fun11384100)?anf_fun11384100.app(s3944089):R.ffi.throwNonFunApp(L[462],anf_fun11384100,[s3944089]);
};
try {
if(--R.GAS > 0) {
$z40924093 = $f40984099();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40984099,
"from":L[462]});
}
} catch($e40904091) {
if(R.isCont($e40904091)) {
var $ss40944095 = {"from":L[462],
"go":function(if_DASH_1004101) {
return $Hif_DASH_27454102(if_DASH_1004101,A119,env3904042,l3914043,names28657,s3944089);
}};
$e40904091.stack[R.EXN_STACKHEIGHT++] = $ss40944095;
}
if(R.isPyretException($e40904091)) {
$e40904091.pyretStack.push(L[462]);
}
throw $e40904091;
}
var $ret40964097 = $Hif_DASH_27454102($z40924093,A119,env3904042,l3914043,names28657,s3944089);
++R.GAS;
return $ret40964097;
});
var anf_obj11714073 = R.makeFunction(function($underscore4074074) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[459],1,arguments);
}
var anf_fun11704085 = G(A119,"s-id",L[460]);
var $z40774078 = D;
var $f40834084 = function(_) {
return R.isFunction(anf_fun11704085)?anf_fun11704085.app(l3914043,id3924044):R.ffi.throwNonFunApp(L[459],anf_fun11704085,[l3914043,id3924044]);
};
try {
if(--R.GAS > 0) {
$z40774078 = $f40834084();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40834084,
"from":L[459]});
}
} catch($e40754076) {
if(R.isCont($e40754076)) {
var $ss40794080 = {"from":L[459],
"go":function(ann_DASH_check_DASH_temp11694086) {
return $Hann_DASH_check_DASH_temp27464087(ann_DASH_check_DASH_temp11694086);
}};
$e40754076.stack[R.EXN_STACKHEIGHT++] = $ss40794080;
}
if(R.isPyretException($e40754076)) {
$e40754076.pyretStack.push(L[459]);
}
throw $e40754076;
}
var $ret40814082 = $Hann_DASH_check_DASH_temp27464087($z40774078);
++R.GAS;
return $ret40814082;
});
var anf_arg11724056 = R.makeObject({"s-name":anf_obj11684072,
"s-underscore":anf_obj11714073});
var anf_arg11764057 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[457],0,arguments);
}
var $z40624063 = D;
var $f40684069 = function(_) {
return R.isFunction(torepr16)?torepr16.app(id3924044):R.ffi.throwNonFunApp(L[458],torepr16,[id3924044]);
};
try {
if(--R.GAS > 0) {
$z40624063 = $f40684069();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40684069,
"from":L[458]});
}
} catch($e40604061) {
if(R.isCont($e40604061)) {
var $ss40644065 = {"from":L[458],
"go":function(anf_arg11744070) {
return $Hanf_arg27494071(anf_arg11744070,_plus9,raise14);
}};
$e40604061.stack[R.EXN_STACKHEIGHT++] = $ss40644065;
}
if(R.isPyretException($e40604061)) {
$e40604061.pyretStack.push(L[458]);
}
throw $e40604061;
}
var $ret40664067 = $Hanf_arg27494071($z40624063,_plus9,raise14);
++R.GAS;
return $ret40664067;
});
var $z40474048 = D;
var $f40534054 = function(_) {
return R.isFunction(anf_fun11364055)?anf_fun11364055.app(anf_arg11724056,anf_arg11764057):R.ffi.throwNonFunApp(L[456],anf_fun11364055,[anf_arg11724056,anf_arg11764057]);
};
try {
if(--R.GAS > 0) {
$z40474048 = $f40534054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40534054,
"from":L[456]});
}
} catch($e40454046) {
if(R.isCont($e40454046)) {
var $ss40494050 = {"from":L[456],
"go":function(ann_DASH_check_DASH_temp11354058) {
return $Hann_DASH_check_DASH_temp27504059(ann_DASH_check_DASH_temp11354058);
}};
$e40454046.stack[R.EXN_STACKHEIGHT++] = $ss40494050;
}
if(R.isPyretException($e40454046)) {
$e40454046.pyretStack.push(L[456]);
}
throw $e40454046;
}
var $ret40514052 = $Hann_DASH_check_DASH_temp27504059($z40474048);
++R.GAS;
return $ret40514052;
});
handle_DASH_id3513977.$var = anf_assign11773978;
var anf_assign12123980 = R.makeFunction(function(l4083994,type_DASH_env4093995,id4103996) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[450],3,arguments);
}
var cases_DASH_val1054041 = id4103996;
var anf_fun11794007 = G(cases_DASH_val1054041,"_match",L[451]);
var anf_obj12074025 = R.makeFunction(function($underscore4114026,s4124027) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[453],2,arguments);
}
var anf_fun11814038 = G(type_DASH_env4093995,"has-key",L[455]);
var $z40304031 = D;
var $f40364037 = function(_) {
return R.isFunction(anf_fun11814038)?anf_fun11814038.app(s4124027):R.ffi.throwNonFunApp(L[454],anf_fun11814038,[s4124027]);
};
try {
if(--R.GAS > 0) {
$z40304031 = $f40364037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40364037,
"from":L[454]});
}
} catch($e40284029) {
if(R.isCont($e40284029)) {
var $ss40324033 = {"from":L[454],
"go":function(if_DASH_1034039) {
return $Hif_DASH_27574040(if_DASH_1034039,A119,l4083994,names28657,s4124027,type_DASH_env4093995);
}};
$e40284029.stack[R.EXN_STACKHEIGHT++] = $ss40324033;
}
if(R.isPyretException($e40284029)) {
$e40284029.pyretStack.push(L[454]);
}
throw $e40284029;
}
var $ret40344035 = $Hif_DASH_27574040($z40304031,A119,l4083994,names28657,s4124027,type_DASH_env4093995);
++R.GAS;
return $ret40344035;
});
var anf_arg12084008 = R.makeObject({"s-name":anf_obj12074025});
var anf_arg12114009 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[451],0,arguments);
}
var anf_fun12104022 = G(A119,"a-name",L[452]);
var $z40144015 = D;
var $f40204021 = function(_) {
return R.isFunction(anf_fun12104022)?anf_fun12104022.app(l4083994,id4103996):R.ffi.throwNonFunApp(L[451],anf_fun12104022,[l4083994,id4103996]);
};
try {
if(--R.GAS > 0) {
$z40144015 = $f40204021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40204021,
"from":L[451]});
}
} catch($e40124013) {
if(R.isCont($e40124013)) {
var $ss40164017 = {"from":L[451],
"go":function(ann_DASH_check_DASH_temp12094023) {
return $Hann_DASH_check_DASH_temp27584024(ann_DASH_check_DASH_temp12094023);
}};
$e40124013.stack[R.EXN_STACKHEIGHT++] = $ss40164017;
}
if(R.isPyretException($e40124013)) {
$e40124013.pyretStack.push(L[451]);
}
throw $e40124013;
}
var $ret40184019 = $Hann_DASH_check_DASH_temp27584024($z40144015);
++R.GAS;
return $ret40184019;
});
var $z39994000 = D;
var $f40054006 = function(_) {
return R.isFunction(anf_fun11794007)?anf_fun11794007.app(anf_arg12084008,anf_arg12114009):R.ffi.throwNonFunApp(L[450],anf_fun11794007,[anf_arg12084008,anf_arg12114009]);
};
try {
if(--R.GAS > 0) {
$z39994000 = $f40054006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f40054006,
"from":L[450]});
}
} catch($e39973998) {
if(R.isCont($e39973998)) {
var $ss40014002 = {"from":L[450],
"go":function(ann_DASH_check_DASH_temp11784010) {
return $Hann_DASH_check_DASH_temp27594011(ann_DASH_check_DASH_temp11784010);
}};
$e39973998.stack[R.EXN_STACKHEIGHT++] = $ss40014002;
}
if(R.isPyretException($e39973998)) {
$e39973998.pyretStack.push(L[450]);
}
throw $e39973998;
}
var $ret40034004 = $Hann_DASH_check_DASH_temp27594011($z39994000);
++R.GAS;
return $ret40034004;
});
handle_DASH_ann3523979.$var = anf_assign12123980;
var anf_extend12133992 = G(A119,"default-map-visitor",L[449]);
var $z39833984 = D;
var $f39893990 = function(_) {
return R.isFunction(scope_DASH_env_DASH_from_DASH_env307126.$var)?scope_DASH_env_DASH_from_DASH_env307126.$var.app(initial_DASH_env344147):R.ffi.throwNonFunApp(L[448],scope_DASH_env_DASH_from_DASH_env307126.$var,[initial_DASH_env344147]);
};
try {
if(--R.GAS > 0) {
$z39833984 = $f39893990();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f39893990,
"from":L[448]});
}
} catch($e39813982) {
if(R.isCont($e39813982)) {
var $ss39853986 = {"from":L[448],
"go":function(anf_extend12143991) {
return $Hanf_extend29753993(anf_extend12143991,A119,C923,anf_extend12133992,bindings3463955,empty3670,fold6171,handle_DASH_ann3523979,handle_DASH_id3513977,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,name_DASH_errors3453956,none6979,p343146,resolved8483,some7084,type_DASH_bindings3473969,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973,var_DASH_bind295102,_plus9,raise14,torepr16);
}};
$e39813982.stack[R.EXN_STACKHEIGHT++] = $ss39853986;
}
if(R.isPyretException($e39813982)) {
$e39813982.pyretStack.push(L[448]);
}
throw $e39813982;
}
var $ret39873988 = $Hanf_extend29753993($z39833984,A119,C923,anf_extend12133992,bindings3463955,empty3670,fold6171,handle_DASH_ann3523979,handle_DASH_id3513977,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,name_DASH_errors3453956,none6979,p343146,resolved8483,some7084,type_DASH_bindings3473969,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973,var_DASH_bind295102,_plus9,raise14,torepr16);
++R.GAS;
return $ret39873988;
};
var $Hanf_extend29753993 = function(anf_extend12143991,A119,C923,anf_extend12133992,bindings3463955,empty3670,fold6171,handle_DASH_ann3523979,handle_DASH_id3513977,initial_DASH_env344147,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,name_DASH_errors3453956,none6979,p343146,resolved8483,some7084,type_DASH_bindings3473969,type_DASH_env_DASH_from_DASH_env308128,type_DASH_var_DASH_bind306124,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973,var_DASH_bind295102,_plus9,raise14,torepr16) {
var $z42024203 = D;
var $f42084209 = function(_) {
return R.isFunction(type_DASH_env_DASH_from_DASH_env308128.$var)?type_DASH_env_DASH_from_DASH_env308128.$var.app(initial_DASH_env344147):R.ffi.throwNonFunApp(L[481],type_DASH_env_DASH_from_DASH_env308128.$var,[initial_DASH_env344147]);
};
try {
if(--R.GAS > 0) {
$z42024203 = $f42084209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42084209,
"from":L[481]});
}
} catch($e42004201) {
if(R.isCont($e42004201)) {
var $ss42044205 = {"from":L[481],
"go":function(anf_extend12154210) {
return $Hanf_extend29744211(anf_extend12154210,A119,C923,anf_extend12133992,anf_extend12143991,bindings3463955,empty3670,fold6171,handle_DASH_ann3523979,handle_DASH_id3513977,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,name_DASH_errors3453956,none6979,p343146,resolved8483,some7084,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973,var_DASH_bind295102,_plus9,raise14,torepr16);
}};
$e42004201.stack[R.EXN_STACKHEIGHT++] = $ss42044205;
}
if(R.isPyretException($e42004201)) {
$e42004201.pyretStack.push(L[481]);
}
throw $e42004201;
}
var $ret42064207 = $Hanf_extend29744211($z42024203,A119,C923,anf_extend12133992,anf_extend12143991,bindings3463955,empty3670,fold6171,handle_DASH_ann3523979,handle_DASH_id3513977,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,name_DASH_errors3453956,none6979,p343146,resolved8483,some7084,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973,var_DASH_bind295102,_plus9,raise14,torepr16);
++R.GAS;
return $ret42064207;
};
var $Hanf_extend29744211 = function(anf_extend12154210,A119,C923,anf_extend12133992,anf_extend12143991,bindings3463955,empty3670,fold6171,handle_DASH_ann3523979,handle_DASH_id3513977,let_DASH_bind29398,let_DASH_type_DASH_bind304120,letrec_DASH_bind29194,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,name_DASH_errors3453956,none6979,p343146,resolved8483,some7084,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973,var_DASH_bind295102,_plus9,raise14,torepr16) {
var anf_extend12504226 = R.makeMethod(function(self4235102) {
return function(l4245101,_provide4255095,_provide_DASH_types4265094,imports4275100,body4285099) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[639],5,arguments);
}
var anf_arg12365096 = R.makeFunction(function(acc4305104,i4315105) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[634],2,arguments);
}
var cases_DASH_val1065139 = i4315105;
var anf_fun12185116 = G(cases_DASH_val1065139,"_match",L[635]);
var anf_obj12325122 = R.makeFunction(function(l24325123,file4335124,name4345125) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[636],3,arguments);
}
var anf_arg12205136 = G(acc4305104,"e",L[638]);
var $z51285129 = D;
var $f51345135 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(name4345125,(false),anf_arg12205136,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[637],make_DASH_atom_DASH_for3483971.$var,[name4345125,(false),anf_arg12205136,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z51285129 = $f51345135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51345135,
"from":L[637]});
}
} catch($e51265127) {
if(R.isCont($e51265127)) {
var $ss51305131 = {"from":L[637],
"go":function(atom_DASH_env4355137) {
return $Hatom_DASH_env27685138(atom_DASH_env4355137,A119,acc4305104,file4335124,l24325123,let_DASH_type_DASH_bind304120,link3774,make_DASH_atom_DASH_for3483971,name4345125,none6979,some7084,type_DASH_bindings3473969,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e51265127.stack[R.EXN_STACKHEIGHT++] = $ss51305131;
}
if(R.isPyretException($e51265127)) {
$e51265127.pyretStack.push(L[637]);
}
throw $e51265127;
}
var $ret51325133 = $Hatom_DASH_env27685138($z51285129,A119,acc4305104,file4335124,l24325123,let_DASH_type_DASH_bind304120,link3774,make_DASH_atom_DASH_for3483971,name4345125,none6979,some7084,type_DASH_bindings3473969,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret51325133;
});
var anf_arg12335117 = R.makeObject({"s-import":anf_obj12325122});
var anf_arg12355118 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[635],0,arguments);
}
var ann_DASH_check_DASH_temp12345121 = acc4305104;
return ann_DASH_check_DASH_temp12345121;
});
var $z51085109 = D;
var $f51145115 = function(_) {
return R.isFunction(anf_fun12185116)?anf_fun12185116.app(anf_arg12335117,anf_arg12355118):R.ffi.throwNonFunApp(L[634],anf_fun12185116,[anf_arg12335117,anf_arg12355118]);
};
try {
if(--R.GAS > 0) {
$z51085109 = $f51145115();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51145115,
"from":L[634]});
}
} catch($e51065107) {
if(R.isCont($e51065107)) {
var $ss51105111 = {"from":L[634],
"go":function(ann_DASH_check_DASH_temp12175119) {
return $Hann_DASH_check_DASH_temp27695120(ann_DASH_check_DASH_temp12175119);
}};
$e51065107.stack[R.EXN_STACKHEIGHT++] = $ss51105111;
}
if(R.isPyretException($e51065107)) {
$e51065107.pyretStack.push(L[634]);
}
throw $e51065107;
}
var $ret51125113 = $Hann_DASH_check_DASH_temp27695120($z51085109);
++R.GAS;
return $ret51125113;
});
var anf_obj12375097 = G(self4235102,"env",L[633]);
var anf_obj12385098 = G(self4235102,"type-env",L[632]);
var anf_fun12395092 = G(list3375,"make",L[631]);
var $z50845085 = D;
var $f50905091 = function(_) {
return R.isFunction(anf_fun12395092)?anf_fun12395092.app([]):R.ffi.throwNonFunApp(L[631],anf_fun12395092,[[]]);
};
try {
if(--R.GAS > 0) {
$z50845085 = $f50905091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50905091,
"from":L[631]});
}
} catch($e50825083) {
if(R.isCont($e50825083)) {
var $ss50865087 = {"from":L[631],
"go":function(anf_obj12405093) {
return $Hanf_obj27745103(anf_obj12405093,A119,_provide_DASH_types4265094,_provide4255095,anf_arg12365096,anf_obj12375097,anf_obj12385098,body4285099,fold6171,imports4275100,l4245101,self4235102);
}};
$e50825083.stack[R.EXN_STACKHEIGHT++] = $ss50865087;
}
if(R.isPyretException($e50825083)) {
$e50825083.pyretStack.push(L[631]);
}
throw $e50825083;
}
var $ret50885089 = $Hanf_obj27745103($z50845085,A119,_provide_DASH_types4265094,_provide4255095,anf_arg12365096,anf_obj12375097,anf_obj12385098,body4285099,fold6171,imports4275100,l4245101,self4235102);
++R.GAS;
return $ret50885089;
};
},{"length":6});
var anf_extend12994227 = R.makeMethod(function(self4395027) {
return function(l4405026,binds4415024,body4425025) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[630],3,arguments);
}
var anf_arg12875021 = R.makeFunction(function(acc4445029,b4455030) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[622],2,arguments);
}
var cases_DASH_val1075081 = b4455030;
var anf_fun12535041 = G(cases_DASH_val1075081,"_match",L[623]);
var anf_obj12705047 = R.makeFunction(function(l24465065,name4475066,ann4485067) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[627],3,arguments);
}
var anf_arg12555078 = G(acc4445029,"te",L[629]);
var $z50705071 = D;
var $f50765077 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(name4475066,(false),anf_arg12555078,type_DASH_bindings3473969,let_DASH_type_DASH_bind304120.$var):R.ffi.throwNonFunApp(L[628],make_DASH_atom_DASH_for3483971.$var,[name4475066,(false),anf_arg12555078,type_DASH_bindings3473969,let_DASH_type_DASH_bind304120.$var]);
};
try {
if(--R.GAS > 0) {
$z50705071 = $f50765077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50765077,
"from":L[628]});
}
} catch($e50685069) {
if(R.isCont($e50685069)) {
var $ss50725073 = {"from":L[628],
"go":function(atom_DASH_env4495079) {
return $Hatom_DASH_env27815080(atom_DASH_env4495079,A119,acc4445029,ann4485067,l24465065,link3774,self4395027,some7084,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e50685069.stack[R.EXN_STACKHEIGHT++] = $ss50725073;
}
if(R.isPyretException($e50685069)) {
$e50685069.pyretStack.push(L[628]);
}
throw $e50685069;
}
var $ret50745075 = $Hatom_DASH_env27815080($z50705071,A119,acc4445029,ann4485067,l24465065,link3774,self4395027,some7084,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret50745075;
});
var anf_obj12835048 = R.makeFunction(function(l24515049,name4525050,tname4535051) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[624],3,arguments);
}
var anf_arg12725062 = G(acc4445029,"te",L[626]);
var $z50545055 = D;
var $f50605061 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(name4525050,(false),anf_arg12725062,type_DASH_bindings3473969,let_DASH_type_DASH_bind304120.$var):R.ffi.throwNonFunApp(L[625],make_DASH_atom_DASH_for3483971.$var,[name4525050,(false),anf_arg12725062,type_DASH_bindings3473969,let_DASH_type_DASH_bind304120.$var]);
};
try {
if(--R.GAS > 0) {
$z50545055 = $f50605061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50605061,
"from":L[625]});
}
} catch($e50525053) {
if(R.isCont($e50525053)) {
var $ss50565057 = {"from":L[625],
"go":function(atom_DASH_env_DASH_t4545063) {
return $Hatom_DASH_env_DASH_t27895064(atom_DASH_env_DASH_t4545063,A119,acc4445029,bindings3463955,l24515049,let_DASH_bind29398,link3774,make_DASH_atom_DASH_for3483971,none6979,tname4535051,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e50525053.stack[R.EXN_STACKHEIGHT++] = $ss50565057;
}
if(R.isPyretException($e50525053)) {
$e50525053.pyretStack.push(L[625]);
}
throw $e50525053;
}
var $ret50585059 = $Hatom_DASH_env_DASH_t27895064($z50545055,A119,acc4445029,bindings3463955,l24515049,let_DASH_bind29398,link3774,make_DASH_atom_DASH_for3483971,none6979,tname4535051,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret50585059;
});
var anf_arg12845042 = R.makeObject({"s-type-bind":anf_obj12705047,
"s-newtype-bind":anf_obj12835048});
var anf_arg12865043 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[623],0,arguments);
}
var ann_DASH_check_DASH_temp12855046 = R.throwNoBranchesMatched(L[623],("cases"));
return ann_DASH_check_DASH_temp12855046;
});
var $z50335034 = D;
var $f50395040 = function(_) {
return R.isFunction(anf_fun12535041)?anf_fun12535041.app(anf_arg12845042,anf_arg12865043):R.ffi.throwNonFunApp(L[622],anf_fun12535041,[anf_arg12845042,anf_arg12865043]);
};
try {
if(--R.GAS > 0) {
$z50335034 = $f50395040();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50395040,
"from":L[622]});
}
} catch($e50315032) {
if(R.isCont($e50315032)) {
var $ss50355036 = {"from":L[622],
"go":function(ann_DASH_check_DASH_temp12525044) {
return $Hann_DASH_check_DASH_temp27905045(ann_DASH_check_DASH_temp12525044);
}};
$e50315032.stack[R.EXN_STACKHEIGHT++] = $ss50355036;
}
if(R.isPyretException($e50315032)) {
$e50315032.pyretStack.push(L[622]);
}
throw $e50315032;
}
var $ret50375038 = $Hann_DASH_check_DASH_temp27905045($z50335034);
++R.GAS;
return $ret50375038;
});
var anf_obj12885022 = G(self4395027,"env",L[621]);
var anf_obj12895023 = G(self4395027,"type-env",L[620]);
var anf_fun12905019 = G(list3375,"make",L[619]);
var $z50115012 = D;
var $f50175018 = function(_) {
return R.isFunction(anf_fun12905019)?anf_fun12905019.app([]):R.ffi.throwNonFunApp(L[619],anf_fun12905019,[[]]);
};
try {
if(--R.GAS > 0) {
$z50115012 = $f50175018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50175018,
"from":L[619]});
}
} catch($e50095010) {
if(R.isCont($e50095010)) {
var $ss50135014 = {"from":L[619],
"go":function(anf_obj12915020) {
return $Hanf_obj27945028(anf_obj12915020,A119,anf_arg12875021,anf_obj12885022,anf_obj12895023,binds4415024,body4425025,fold6171,l4405026,self4395027);
}};
$e50095010.stack[R.EXN_STACKHEIGHT++] = $ss50135014;
}
if(R.isPyretException($e50095010)) {
$e50095010.pyretStack.push(L[619]);
}
throw $e50095010;
}
var $ret50155016 = $Hanf_obj27945028($z50115012,A119,anf_arg12875021,anf_obj12885022,anf_obj12895023,binds4415024,body4425025,fold6171,l4405026,self4395027);
++R.GAS;
return $ret50155016;
};
},{"length":4});
var anf_extend13634228 = R.makeMethod(function(self4584950) {
return function(l4594949,binds4604947,body4614948) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[618],3,arguments);
}
var anf_arg13524945 = R.makeFunction(function(acc4634952,b4644953) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[606],2,arguments);
}
var cases_DASH_val1085008 = b4644953;
var anf_fun13024964 = G(cases_DASH_val1085008,"_match",L[607]);
var anf_obj13254970 = R.makeFunction(function(l24654990,bind4664991,expr4674992) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[613],3,arguments);
}
var anf_arg13045003 = G(bind4664991,"id",L[617]);
var anf_arg13055004 = G(bind4664991,"shadows",L[616]);
var anf_arg13065005 = G(acc4634952,"e",L[615]);
var $z49954996 = D;
var $f50015002 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(anf_arg13045003,anf_arg13055004,anf_arg13065005,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[614],make_DASH_atom_DASH_for3483971.$var,[anf_arg13045003,anf_arg13055004,anf_arg13065005,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z49954996 = $f50015002();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f50015002,
"from":L[614]});
}
} catch($e49934994) {
if(R.isCont($e49934994)) {
var $ss49974998 = {"from":L[614],
"go":function(atom_DASH_env4685006) {
return $Hatom_DASH_env28035007(atom_DASH_env4685006,A119,acc4634952,bind4664991,expr4674992,l24654990,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e49934994.stack[R.EXN_STACKHEIGHT++] = $ss49974998;
}
if(R.isPyretException($e49934994)) {
$e49934994.pyretStack.push(L[614]);
}
throw $e49934994;
}
var $ret49995000 = $Hatom_DASH_env28035007($z49954996,A119,acc4634952,bind4664991,expr4674992,l24654990,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret49995000;
});
var anf_obj13484971 = R.makeFunction(function(l24714972,bind4724973,expr4734974) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[608],3,arguments);
}
var anf_arg13274985 = G(bind4724973,"id",L[612]);
var anf_arg13284986 = G(bind4724973,"shadows",L[611]);
var anf_arg13294987 = G(acc4634952,"e",L[610]);
var $z49774978 = D;
var $f49834984 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(anf_arg13274985,anf_arg13284986,anf_arg13294987,bindings3463955,var_DASH_bind295102.$var):R.ffi.throwNonFunApp(L[609],make_DASH_atom_DASH_for3483971.$var,[anf_arg13274985,anf_arg13284986,anf_arg13294987,bindings3463955,var_DASH_bind295102.$var]);
};
try {
if(--R.GAS > 0) {
$z49774978 = $f49834984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49834984,
"from":L[609]});
}
} catch($e49754976) {
if(R.isCont($e49754976)) {
var $ss49794980 = {"from":L[609],
"go":function(atom_DASH_env4744988) {
return $Hatom_DASH_env28124989(atom_DASH_env4744988,A119,acc4634952,bind4724973,expr4734974,l24714972,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e49754976.stack[R.EXN_STACKHEIGHT++] = $ss49794980;
}
if(R.isPyretException($e49754976)) {
$e49754976.pyretStack.push(L[609]);
}
throw $e49754976;
}
var $ret49814982 = $Hatom_DASH_env28124989($z49774978,A119,acc4634952,bind4724973,expr4734974,l24714972,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret49814982;
});
var anf_arg13494965 = R.makeObject({"s-let-bind":anf_obj13254970,
"s-var-bind":anf_obj13484971});
var anf_arg13514966 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[607],0,arguments);
}
var ann_DASH_check_DASH_temp13504969 = R.throwNoBranchesMatched(L[607],("cases"));
return ann_DASH_check_DASH_temp13504969;
});
var $z49564957 = D;
var $f49624963 = function(_) {
return R.isFunction(anf_fun13024964)?anf_fun13024964.app(anf_arg13494965,anf_arg13514966):R.ffi.throwNonFunApp(L[606],anf_fun13024964,[anf_arg13494965,anf_arg13514966]);
};
try {
if(--R.GAS > 0) {
$z49564957 = $f49624963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49624963,
"from":L[606]});
}
} catch($e49544955) {
if(R.isCont($e49544955)) {
var $ss49584959 = {"from":L[606],
"go":function(ann_DASH_check_DASH_temp13014967) {
return $Hann_DASH_check_DASH_temp28134968(ann_DASH_check_DASH_temp13014967);
}};
$e49544955.stack[R.EXN_STACKHEIGHT++] = $ss49584959;
}
if(R.isPyretException($e49544955)) {
$e49544955.pyretStack.push(L[606]);
}
throw $e49544955;
}
var $ret49604961 = $Hann_DASH_check_DASH_temp28134968($z49564957);
++R.GAS;
return $ret49604961;
});
var anf_obj13534946 = G(self4584950,"env",L[605]);
var anf_fun13544943 = G(list3375,"make",L[604]);
var $z49354936 = D;
var $f49414942 = function(_) {
return R.isFunction(anf_fun13544943)?anf_fun13544943.app([]):R.ffi.throwNonFunApp(L[604],anf_fun13544943,[[]]);
};
try {
if(--R.GAS > 0) {
$z49354936 = $f49414942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49414942,
"from":L[604]});
}
} catch($e49334934) {
if(R.isCont($e49334934)) {
var $ss49374938 = {"from":L[604],
"go":function(anf_obj13554944) {
return $Hanf_obj28184951(anf_obj13554944,A119,anf_arg13524945,anf_obj13534946,binds4604947,body4614948,fold6171,l4594949,self4584950);
}};
$e49334934.stack[R.EXN_STACKHEIGHT++] = $ss49374938;
}
if(R.isPyretException($e49334934)) {
$e49334934.pyretStack.push(L[604]);
}
throw $e49334934;
}
var $ret49394940 = $Hanf_obj28184951($z49354936,A119,anf_arg13524945,anf_obj13534946,binds4604947,body4614948,fold6171,l4594949,self4584950);
++R.GAS;
return $ret49394940;
};
},{"length":4});
var anf_extend14034229 = R.makeMethod(function(self4794912) {
return function(l4804911,binds4814909,body4824910) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[603],3,arguments);
}
var anf_arg13754907 = R.makeFunction(function(acc4844914,b4854915) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[596],2,arguments);
}
var anf_bracket13664932 = G(b4854915,"b",L[602]);
var anf_arg13674926 = G(anf_bracket13664932,"id",L[601]);
var anf_bracket13684931 = G(b4854915,"b",L[600]);
var anf_arg13694927 = G(anf_bracket13684931,"shadows",L[599]);
var anf_arg13704928 = G(acc4844914,"env",L[598]);
var $z49184919 = D;
var $f49244925 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(anf_arg13674926,anf_arg13694927,anf_arg13704928,bindings3463955,letrec_DASH_bind29194.$var):R.ffi.throwNonFunApp(L[597],make_DASH_atom_DASH_for3483971.$var,[anf_arg13674926,anf_arg13694927,anf_arg13704928,bindings3463955,letrec_DASH_bind29194.$var]);
};
try {
if(--R.GAS > 0) {
$z49184919 = $f49244925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49244925,
"from":L[597]});
}
} catch($e49164917) {
if(R.isCont($e49164917)) {
var $ss49204921 = {"from":L[597],
"go":function(atom_DASH_env4864929) {
return $Hatom_DASH_env28204930(atom_DASH_env4864929,acc4844914,link3774);
}};
$e49164917.stack[R.EXN_STACKHEIGHT++] = $ss49204921;
}
if(R.isPyretException($e49164917)) {
$e49164917.pyretStack.push(L[597]);
}
throw $e49164917;
}
var $ret49224923 = $Hatom_DASH_env28204930($z49184919,acc4844914,link3774);
++R.GAS;
return $ret49224923;
});
var anf_obj13764908 = G(self4794912,"env",L[595]);
var anf_fun13774905 = G(list3375,"make",L[594]);
var $z48974898 = D;
var $f49034904 = function(_) {
return R.isFunction(anf_fun13774905)?anf_fun13774905.app([]):R.ffi.throwNonFunApp(L[594],anf_fun13774905,[[]]);
};
try {
if(--R.GAS > 0) {
$z48974898 = $f49034904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f49034904,
"from":L[594]});
}
} catch($e48954896) {
if(R.isCont($e48954896)) {
var $ss48994900 = {"from":L[594],
"go":function(anf_obj13784906) {
return $Hanf_obj28344913(anf_obj13784906,A119,anf_arg13754907,anf_obj13764908,binds4814909,body4824910,fold6171,l4804911,map24676,self4794912,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e48954896.stack[R.EXN_STACKHEIGHT++] = $ss48994900;
}
if(R.isPyretException($e48954896)) {
$e48954896.pyretStack.push(L[594]);
}
throw $e48954896;
}
var $ret49014902 = $Hanf_obj28344913($z48974898,A119,anf_arg13754907,anf_obj13764908,binds4814909,body4824910,fold6171,l4804911,map24676,self4794912,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret49014902;
};
},{"length":4});
var anf_extend14504230 = R.makeMethod(function(self4974855) {
return function(l4984854,iter4994853,binds5004851,ann5014850,body5024852) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[593],5,arguments);
}
var anf_arg14334848 = R.makeFunction(function(acc5044857,fb5054858) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[586],2,arguments);
}
var cases_DASH_val1104894 = fb5054858;
var anf_fun14064869 = G(cases_DASH_val1104894,"_match",L[587]);
var anf_obj14294875 = R.makeFunction(function(l25064876,bind5074877,val5084878) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[588],3,arguments);
}
var anf_arg14084889 = G(bind5074877,"id",L[592]);
var anf_arg14094890 = G(bind5074877,"shadows",L[591]);
var anf_arg14104891 = G(acc5044857,"env",L[590]);
var $z48814882 = D;
var $f48874888 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(anf_arg14084889,anf_arg14094890,anf_arg14104891,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[589],make_DASH_atom_DASH_for3483971.$var,[anf_arg14084889,anf_arg14094890,anf_arg14104891,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z48814882 = $f48874888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48874888,
"from":L[589]});
}
} catch($e48794880) {
if(R.isCont($e48794880)) {
var $ss48834884 = {"from":L[589],
"go":function(atom_DASH_env5094892) {
return $Hatom_DASH_env28434893(atom_DASH_env5094892,A119,acc5044857,bind5074877,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878);
}};
$e48794880.stack[R.EXN_STACKHEIGHT++] = $ss48834884;
}
if(R.isPyretException($e48794880)) {
$e48794880.pyretStack.push(L[589]);
}
throw $e48794880;
}
var $ret48854886 = $Hatom_DASH_env28434893($z48814882,A119,acc5044857,bind5074877,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878);
++R.GAS;
return $ret48854886;
});
var anf_arg14304870 = R.makeObject({"s-for-bind":anf_obj14294875});
var anf_arg14324871 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[587],0,arguments);
}
var ann_DASH_check_DASH_temp14314874 = R.throwNoBranchesMatched(L[587],("cases"));
return ann_DASH_check_DASH_temp14314874;
});
var $z48614862 = D;
var $f48674868 = function(_) {
return R.isFunction(anf_fun14064869)?anf_fun14064869.app(anf_arg14304870,anf_arg14324871):R.ffi.throwNonFunApp(L[586],anf_fun14064869,[anf_arg14304870,anf_arg14324871]);
};
try {
if(--R.GAS > 0) {
$z48614862 = $f48674868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48674868,
"from":L[586]});
}
} catch($e48594860) {
if(R.isCont($e48594860)) {
var $ss48634864 = {"from":L[586],
"go":function(ann_DASH_check_DASH_temp14054872) {
return $Hann_DASH_check_DASH_temp28444873(ann_DASH_check_DASH_temp14054872);
}};
$e48594860.stack[R.EXN_STACKHEIGHT++] = $ss48634864;
}
if(R.isPyretException($e48594860)) {
$e48594860.pyretStack.push(L[586]);
}
throw $e48594860;
}
var $ret48654866 = $Hann_DASH_check_DASH_temp28444873($z48614862);
++R.GAS;
return $ret48654866;
});
var anf_obj14344849 = G(self4974855,"env",L[585]);
var anf_fun14354846 = G(list3375,"make",L[584]);
var $z48384839 = D;
var $f48444845 = function(_) {
return R.isFunction(anf_fun14354846)?anf_fun14354846.app([]):R.ffi.throwNonFunApp(L[584],anf_fun14354846,[[]]);
};
try {
if(--R.GAS > 0) {
$z48384839 = $f48444845();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48444845,
"from":L[584]});
}
} catch($e48364837) {
if(R.isCont($e48364837)) {
var $ss48404841 = {"from":L[584],
"go":function(anf_obj14364847) {
return $Hanf_obj28514856(anf_obj14364847,A119,anf_arg14334848,anf_obj14344849,ann5014850,binds5004851,body5024852,fold6171,iter4994853,l4984854,self4974855);
}};
$e48364837.stack[R.EXN_STACKHEIGHT++] = $ss48404841;
}
if(R.isPyretException($e48364837)) {
$e48364837.pyretStack.push(L[584]);
}
throw $e48364837;
}
var $ret48424843 = $Hanf_obj28514856($z48384839,A119,anf_arg14334848,anf_obj14344849,ann5014850,binds5004851,body5024852,fold6171,iter4994853,l4984854,self4974855);
++R.GAS;
return $ret48424843;
};
},{"length":6});
var anf_extend14854231 = R.makeMethod(function(self5134817) {
return function(l5144815,name5154816,args5164813,body5174814) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[583],4,arguments);
}
var anf_arg14604811 = R.makeFunction(function(acc5194819,a5204820) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[578],2,arguments);
}
var anf_arg14534831 = G(a5204820,"id",L[582]);
var anf_arg14544832 = G(a5204820,"shadows",L[581]);
var anf_arg14554833 = G(acc5194819,"env",L[580]);
var $z48234824 = D;
var $f48294830 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(anf_arg14534831,anf_arg14544832,anf_arg14554833,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[579],make_DASH_atom_DASH_for3483971.$var,[anf_arg14534831,anf_arg14544832,anf_arg14554833,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z48234824 = $f48294830();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48294830,
"from":L[579]});
}
} catch($e48214822) {
if(R.isCont($e48214822)) {
var $ss48254826 = {"from":L[579],
"go":function(atom_DASH_env5214834) {
return $Hatom_DASH_env28534835(atom_DASH_env5214834,acc5194819,link3774);
}};
$e48214822.stack[R.EXN_STACKHEIGHT++] = $ss48254826;
}
if(R.isPyretException($e48214822)) {
$e48214822.pyretStack.push(L[579]);
}
throw $e48214822;
}
var $ret48274828 = $Hatom_DASH_env28534835($z48234824,acc5194819,link3774);
++R.GAS;
return $ret48274828;
});
var anf_obj14614812 = G(self5134817,"env",L[577]);
var anf_fun14624809 = G(list3375,"make",L[576]);
var $z48014802 = D;
var $f48074808 = function(_) {
return R.isFunction(anf_fun14624809)?anf_fun14624809.app([]):R.ffi.throwNonFunApp(L[576],anf_fun14624809,[[]]);
};
try {
if(--R.GAS > 0) {
$z48014802 = $f48074808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f48074808,
"from":L[576]});
}
} catch($e47994800) {
if(R.isCont($e47994800)) {
var $ss48034804 = {"from":L[576],
"go":function(anf_obj14634810) {
return $Hanf_obj28624818(anf_obj14634810,A119,anf_arg14604811,anf_obj14614812,args5164813,body5174814,fold6171,l5144815,map24676,name5154816,self5134817);
}};
$e47994800.stack[R.EXN_STACKHEIGHT++] = $ss48034804;
}
if(R.isPyretException($e47994800)) {
$e47994800.pyretStack.push(L[576]);
}
throw $e47994800;
}
var $ret48054806 = $Hanf_obj28624818($z48014802,A119,anf_arg14604811,anf_obj14614812,args5164813,body5174814,fold6171,l5144815,map24676,name5154816,self5134817);
++R.GAS;
return $ret48054806;
};
},{"length":5});
var anf_extend15204232 = R.makeMethod(function(self5304779) {
return function(l5314775,name5324777,namet5334778,params5344772,mixins5354776,variants5364781,shared_DASH_members5374780,_check5384774) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[575],8,arguments);
}
var anf_arg14934770 = R.makeFunction(function(acc5404784,param5414785) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[572],2,arguments);
}
var anf_arg14884796 = G(acc5404784,"env",L[574]);
var $z47884789 = D;
var $f47944795 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(param5414785,(false),anf_arg14884796,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124.$var):R.ffi.throwNonFunApp(L[573],make_DASH_atom_DASH_for3483971.$var,[param5414785,(false),anf_arg14884796,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124.$var]);
};
try {
if(--R.GAS > 0) {
$z47884789 = $f47944795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47944795,
"from":L[573]});
}
} catch($e47864787) {
if(R.isCont($e47864787)) {
var $ss47904791 = {"from":L[573],
"go":function(atom_DASH_env5424797) {
return $Hatom_DASH_env28644798(atom_DASH_env5424797,acc5404784,link3774);
}};
$e47864787.stack[R.EXN_STACKHEIGHT++] = $ss47904791;
}
if(R.isPyretException($e47864787)) {
$e47864787.pyretStack.push(L[573]);
}
throw $e47864787;
}
var $ret47924793 = $Hatom_DASH_env28644798($z47884789,acc5404784,link3774);
++R.GAS;
return $ret47924793;
});
var anf_obj14944783 = G(self5304779,"type-env",L[571]);
var anf_arg14954771 = R.makeObject({"env":anf_obj14944783,
"atoms":empty3670});
var $z47624763 = D;
var $f47684769 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg14934770,anf_arg14954771,params5344772):R.ffi.throwNonFunApp(L[570],fold6171,[anf_arg14934770,anf_arg14954771,params5344772]);
};
try {
if(--R.GAS > 0) {
$z47624763 = $f47684769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47684769,
"from":L[570]});
}
} catch($e47604761) {
if(R.isCont($e47604761)) {
var $ss47644765 = {"from":L[570],
"go":function(new_DASH_types5394773) {
return $Hnew_DASH_types28754782(new_DASH_types5394773,A119,_check5384774,handle_DASH_id3513977,l5314775,mixins5354776,name5324777,namet5334778,self5304779,shared_DASH_members5374780,variants5364781);
}};
$e47604761.stack[R.EXN_STACKHEIGHT++] = $ss47644765;
}
if(R.isPyretException($e47604761)) {
$e47604761.pyretStack.push(L[570]);
}
throw $e47604761;
}
var $ret47664767 = $Hnew_DASH_types28754782($z47624763,A119,_check5384774,handle_DASH_id3513977,l5314775,mixins5354776,name5324777,namet5334778,self5304779,shared_DASH_members5374780,variants5364781);
++R.GAS;
return $ret47664767;
};
},{"length":9});
var anf_extend15684233 = R.makeMethod(function(self5454742) {
return function(l5464741,params5474734,args5484738,ann5494737,doc5504740,body5514739,_check5524736) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[569],7,arguments);
}
var anf_arg15284732 = R.makeFunction(function(acc5544745,param5554746) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[566],2,arguments);
}
var anf_arg15234757 = G(acc5544745,"env",L[568]);
var $z47494750 = D;
var $f47554756 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(param5554746,(false),anf_arg15234757,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124.$var):R.ffi.throwNonFunApp(L[567],make_DASH_atom_DASH_for3483971.$var,[param5554746,(false),anf_arg15234757,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124.$var]);
};
try {
if(--R.GAS > 0) {
$z47494750 = $f47554756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47554756,
"from":L[567]});
}
} catch($e47474748) {
if(R.isCont($e47474748)) {
var $ss47514752 = {"from":L[567],
"go":function(atom_DASH_env5564758) {
return $Hatom_DASH_env28774759(atom_DASH_env5564758,acc5544745,link3774);
}};
$e47474748.stack[R.EXN_STACKHEIGHT++] = $ss47514752;
}
if(R.isPyretException($e47474748)) {
$e47474748.pyretStack.push(L[567]);
}
throw $e47474748;
}
var $ret47534754 = $Hatom_DASH_env28774759($z47494750,acc5544745,link3774);
++R.GAS;
return $ret47534754;
});
var anf_obj15294744 = G(self5454742,"type-env",L[565]);
var anf_arg15304733 = R.makeObject({"env":anf_obj15294744,
"atoms":empty3670});
var $z47244725 = D;
var $f47304731 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg15284732,anf_arg15304733,params5474734):R.ffi.throwNonFunApp(L[564],fold6171,[anf_arg15284732,anf_arg15304733,params5474734]);
};
try {
if(--R.GAS > 0) {
$z47244725 = $f47304731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47304731,
"from":L[564]});
}
} catch($e47224723) {
if(R.isCont($e47224723)) {
var $ss47264727 = {"from":L[564],
"go":function(new_DASH_types5534735) {
return $Hnew_DASH_types28924743(new_DASH_types5534735,A119,_check5524736,ann5494737,args5484738,bindings3463955,body5514739,doc5504740,fold6171,l5464741,let_DASH_bind29398,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,self5454742);
}};
$e47224723.stack[R.EXN_STACKHEIGHT++] = $ss47264727;
}
if(R.isPyretException($e47224723)) {
$e47224723.pyretStack.push(L[564]);
}
throw $e47224723;
}
var $ret47284729 = $Hnew_DASH_types28924743($z47244725,A119,_check5524736,ann5494737,args5484738,bindings3463955,body5514739,doc5504740,fold6171,l5464741,let_DASH_bind29398,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,self5454742);
++R.GAS;
return $ret47284729;
};
},{"length":8});
var anf_extend16084234 = R.makeMethod(function(self5724703) {
return function(l5734702,args5744699,ann5754698,doc5764701,body5774700,_check5784695) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[563],6,arguments);
}
var anf_arg15784696 = R.makeFunction(function(acc5804705,a5814706) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[558],2,arguments);
}
var anf_arg15714717 = G(a5814706,"id",L[562]);
var anf_arg15724718 = G(a5814706,"shadows",L[561]);
var anf_arg15734719 = G(acc5804705,"env",L[560]);
var $z47094710 = D;
var $f47154716 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(anf_arg15714717,anf_arg15724718,anf_arg15734719,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[559],make_DASH_atom_DASH_for3483971.$var,[anf_arg15714717,anf_arg15724718,anf_arg15734719,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z47094710 = $f47154716();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f47154716,
"from":L[559]});
}
} catch($e47074708) {
if(R.isCont($e47074708)) {
var $ss47114712 = {"from":L[559],
"go":function(atom_DASH_env5824720) {
return $Hatom_DASH_env28944721(atom_DASH_env5824720,acc5804705,link3774);
}};
$e47074708.stack[R.EXN_STACKHEIGHT++] = $ss47114712;
}
if(R.isPyretException($e47074708)) {
$e47074708.pyretStack.push(L[559]);
}
throw $e47074708;
}
var $ret47134714 = $Hatom_DASH_env28944721($z47094710,acc5804705,link3774);
++R.GAS;
return $ret47134714;
});
var anf_obj15794697 = G(self5724703,"env",L[557]);
var anf_fun15804693 = G(list3375,"make",L[556]);
var $z46854686 = D;
var $f46914692 = function(_) {
return R.isFunction(anf_fun15804693)?anf_fun15804693.app([]):R.ffi.throwNonFunApp(L[556],anf_fun15804693,[[]]);
};
try {
if(--R.GAS > 0) {
$z46854686 = $f46914692();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46914692,
"from":L[556]});
}
} catch($e46834684) {
if(R.isCont($e46834684)) {
var $ss46874688 = {"from":L[556],
"go":function(anf_obj15814694) {
return $Hanf_obj29054704(anf_obj15814694,A119,_check5784695,anf_arg15784696,anf_obj15794697,ann5754698,args5744699,body5774700,doc5764701,fold6171,l5734702,map24676,self5724703);
}};
$e46834684.stack[R.EXN_STACKHEIGHT++] = $ss46874688;
}
if(R.isPyretException($e46834684)) {
$e46834684.pyretStack.push(L[556]);
}
throw $e46834684;
}
var $ret46894690 = $Hanf_obj29054704($z46854686,A119,_check5784695,anf_arg15784696,anf_obj15794697,ann5754698,args5744699,body5774700,doc5764701,fold6171,l5734702,map24676,self5724703);
++R.GAS;
return $ret46894690;
};
},{"length":7});
var anf_extend16484235 = R.makeMethod(function(self5924664) {
return function(l5934662,name5944663,args5954659,ann5964658,doc5974661,body5984660,_check5994655) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[555],7,arguments);
}
var anf_arg16184656 = R.makeFunction(function(acc6014666,a6024667) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[550],2,arguments);
}
var anf_arg16114678 = G(a6024667,"id",L[554]);
var anf_arg16124679 = G(a6024667,"shadows",L[553]);
var anf_arg16134680 = G(acc6014666,"env",L[552]);
var $z46704671 = D;
var $f46764677 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(anf_arg16114678,anf_arg16124679,anf_arg16134680,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[551],make_DASH_atom_DASH_for3483971.$var,[anf_arg16114678,anf_arg16124679,anf_arg16134680,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z46704671 = $f46764677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46764677,
"from":L[551]});
}
} catch($e46684669) {
if(R.isCont($e46684669)) {
var $ss46724673 = {"from":L[551],
"go":function(atom_DASH_env6034681) {
return $Hatom_DASH_env29074682(atom_DASH_env6034681,acc6014666,link3774);
}};
$e46684669.stack[R.EXN_STACKHEIGHT++] = $ss46724673;
}
if(R.isPyretException($e46684669)) {
$e46684669.pyretStack.push(L[551]);
}
throw $e46684669;
}
var $ret46744675 = $Hatom_DASH_env29074682($z46704671,acc6014666,link3774);
++R.GAS;
return $ret46744675;
});
var anf_obj16194657 = G(self5924664,"env",L[549]);
var anf_fun16204653 = G(list3375,"make",L[548]);
var $z46454646 = D;
var $f46514652 = function(_) {
return R.isFunction(anf_fun16204653)?anf_fun16204653.app([]):R.ffi.throwNonFunApp(L[548],anf_fun16204653,[[]]);
};
try {
if(--R.GAS > 0) {
$z46454646 = $f46514652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46514652,
"from":L[548]});
}
} catch($e46434644) {
if(R.isCont($e46434644)) {
var $ss46474648 = {"from":L[548],
"go":function(anf_obj16214654) {
return $Hanf_obj29184665(anf_obj16214654,A119,_check5994655,anf_arg16184656,anf_obj16194657,ann5964658,args5954659,body5984660,doc5974661,fold6171,l5934662,map24676,name5944663,self5924664);
}};
$e46434644.stack[R.EXN_STACKHEIGHT++] = $ss46474648;
}
if(R.isPyretException($e46434644)) {
$e46434644.pyretStack.push(L[548]);
}
throw $e46434644;
}
var $ret46494650 = $Hanf_obj29184665($z46454646,A119,_check5994655,anf_arg16184656,anf_obj16194657,ann5964658,args5954659,body5984660,doc5974661,fold6171,l5934662,map24676,name5944663,self5924664);
++R.GAS;
return $ret46494650;
};
},{"length":8});
var anf_extend16834236 = R.makeMethod(function(self6134620) {
return function(l6144623,id6154603,expr6164625) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[537],3,arguments);
}
var cases_DASH_val1194642 = id6154603;
var anf_fun16504588 = G(cases_DASH_val1194642,"_match",L[538]);
var anf_obj16724606 = R.makeFunction(function(l26174626,s6184627) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[544],2,arguments);
}
var anf_bracket16524641 = G(self6134620,"env",L[547]);
var anf_fun16534638 = G(anf_bracket16524641,"has-key",L[546]);
var $z46304631 = D;
var $f46364637 = function(_) {
return R.isFunction(anf_fun16534638)?anf_fun16534638.app(s6184627):R.ffi.throwNonFunApp(L[545],anf_fun16534638,[s6184627]);
};
try {
if(--R.GAS > 0) {
$z46304631 = $f46364637();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46364637,
"from":L[545]});
}
} catch($e46284629) {
if(R.isCont($e46284629)) {
var $ss46324633 = {"from":L[545],
"go":function(if_DASH_1184639) {
return $Hif_DASH_29244640(if_DASH_1184639,A119,expr6164625,id6154603,l6144623,s6184627,self6134620);
}};
$e46284629.stack[R.EXN_STACKHEIGHT++] = $ss46324633;
}
if(R.isPyretException($e46284629)) {
$e46284629.pyretStack.push(L[545]);
}
throw $e46284629;
}
var $ret46344635 = $Hif_DASH_29244640($z46304631,A119,expr6164625,id6154603,l6144623,s6184627,self6134620);
++R.GAS;
return $ret46344635;
});
var anf_obj16774607 = R.makeFunction(function($underscore6204608) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[540],1,arguments);
}
var anf_fun16744622 = G(A119,"s-assign",L[543]);
var anf_fun16754619 = G(expr6164625,"visit",L[542]);
var $z46114612 = D;
var $f46174618 = function(_) {
return R.isFunction(anf_fun16754619)?anf_fun16754619.app(self6134620):R.ffi.throwNonFunApp(L[541],anf_fun16754619,[self6134620]);
};
try {
if(--R.GAS > 0) {
$z46114612 = $f46174618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46174618,
"from":L[541]});
}
} catch($e46094610) {
if(R.isCont($e46094610)) {
var $ss46134614 = {"from":L[541],
"go":function(anf_arg16764621) {
return $Hanf_arg29264624(anf_arg16764621,anf_fun16744622,id6154603,l6144623);
}};
$e46094610.stack[R.EXN_STACKHEIGHT++] = $ss46134614;
}
if(R.isPyretException($e46094610)) {
$e46094610.pyretStack.push(L[541]);
}
throw $e46094610;
}
var $ret46154616 = $Hanf_arg29264624($z46114612,anf_fun16744622,id6154603,l6144623);
++R.GAS;
return $ret46154616;
});
var anf_arg16784589 = R.makeObject({"s-name":anf_obj16724606,
"s-underscore":anf_obj16774607});
var anf_arg16824590 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[538],0,arguments);
}
var $z45954596 = D;
var $f46014602 = function(_) {
return R.isFunction(torepr16)?torepr16.app(id6154603):R.ffi.throwNonFunApp(L[539],torepr16,[id6154603]);
};
try {
if(--R.GAS > 0) {
$z45954596 = $f46014602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f46014602,
"from":L[539]});
}
} catch($e45934594) {
if(R.isCont($e45934594)) {
var $ss45974598 = {"from":L[539],
"go":function(anf_arg16804604) {
return $Hanf_arg29294605(anf_arg16804604,_plus9,raise14);
}};
$e45934594.stack[R.EXN_STACKHEIGHT++] = $ss45974598;
}
if(R.isPyretException($e45934594)) {
$e45934594.pyretStack.push(L[539]);
}
throw $e45934594;
}
var $ret45994600 = $Hanf_arg29294605($z45954596,_plus9,raise14);
++R.GAS;
return $ret45994600;
});
var $z45804581 = D;
var $f45864587 = function(_) {
return R.isFunction(anf_fun16504588)?anf_fun16504588.app(anf_arg16784589,anf_arg16824590):R.ffi.throwNonFunApp(L[537],anf_fun16504588,[anf_arg16784589,anf_arg16824590]);
};
try {
if(--R.GAS > 0) {
$z45804581 = $f45864587();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45864587,
"from":L[537]});
}
} catch($e45784579) {
if(R.isCont($e45784579)) {
var $ss45824583 = {"from":L[537],
"go":function(ann_DASH_check_DASH_temp16494591) {
return $Hann_DASH_check_DASH_temp29304592(ann_DASH_check_DASH_temp16494591);
}};
$e45784579.stack[R.EXN_STACKHEIGHT++] = $ss45824583;
}
if(R.isPyretException($e45784579)) {
$e45784579.pyretStack.push(L[537]);
}
throw $e45784579;
}
var $ret45844585 = $Hann_DASH_check_DASH_temp29304592($z45804581);
++R.GAS;
return $ret45844585;
};
},{"length":4});
var anf_extend16864237 = R.makeMethod(function(self6214577) {
return function(l6224573,id6234574) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[535],2,arguments);
}
var anf_arg16854572 = G(self6214577,"env",L[536]);
var $z45644565 = D;
var $f45704571 = function(_) {
return R.isFunction(handle_DASH_id3513977.$var)?handle_DASH_id3513977.$var.app(anf_arg16854572,l6224573,id6234574):R.ffi.throwNonFunApp(L[535],handle_DASH_id3513977.$var,[anf_arg16854572,l6224573,id6234574]);
};
try {
if(--R.GAS > 0) {
$z45644565 = $f45704571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45704571,
"from":L[535]});
}
} catch($e45624563) {
if(R.isCont($e45624563)) {
var $ss45664567 = {"from":L[535],
"go":function(ann_DASH_check_DASH_temp16844575) {
return $Hann_DASH_check_DASH_temp29314576(ann_DASH_check_DASH_temp16844575);
}};
$e45624563.stack[R.EXN_STACKHEIGHT++] = $ss45664567;
}
if(R.isPyretException($e45624563)) {
$e45624563.pyretStack.push(L[535]);
}
throw $e45624563;
}
var $ret45684569 = $Hann_DASH_check_DASH_temp29314576($z45644565);
++R.GAS;
return $ret45684569;
};
},{"length":3});
var anf_extend16894238 = R.makeMethod(function(self6244560) {
return function(l6254556,id6264557,$underscore6274561) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[533],3,arguments);
}
var anf_arg16884555 = G(self6244560,"env",L[534]);
var $z45474548 = D;
var $f45534554 = function(_) {
return R.isFunction(handle_DASH_id3513977.$var)?handle_DASH_id3513977.$var.app(anf_arg16884555,l6254556,id6264557):R.ffi.throwNonFunApp(L[533],handle_DASH_id3513977.$var,[anf_arg16884555,l6254556,id6264557]);
};
try {
if(--R.GAS > 0) {
$z45474548 = $f45534554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45534554,
"from":L[533]});
}
} catch($e45454546) {
if(R.isCont($e45454546)) {
var $ss45494550 = {"from":L[533],
"go":function(ann_DASH_check_DASH_temp16874558) {
return $Hann_DASH_check_DASH_temp29324559(ann_DASH_check_DASH_temp16874558);
}};
$e45454546.stack[R.EXN_STACKHEIGHT++] = $ss45494550;
}
if(R.isPyretException($e45454546)) {
$e45454546.pyretStack.push(L[533]);
}
throw $e45454546;
}
var $ret45514552 = $Hann_DASH_check_DASH_temp29324559($z45474548);
++R.GAS;
return $ret45514552;
};
},{"length":4});
var anf_extend16924239 = R.makeMethod(function(self6284544) {
return function(l6294540,id6304541) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[531],2,arguments);
}
var anf_arg16914539 = G(self6284544,"env",L[532]);
var $z45314532 = D;
var $f45374538 = function(_) {
return R.isFunction(handle_DASH_id3513977.$var)?handle_DASH_id3513977.$var.app(anf_arg16914539,l6294540,id6304541):R.ffi.throwNonFunApp(L[531],handle_DASH_id3513977.$var,[anf_arg16914539,l6294540,id6304541]);
};
try {
if(--R.GAS > 0) {
$z45314532 = $f45374538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45374538,
"from":L[531]});
}
} catch($e45294530) {
if(R.isCont($e45294530)) {
var $ss45334534 = {"from":L[531],
"go":function(ann_DASH_check_DASH_temp16904542) {
return $Hann_DASH_check_DASH_temp29334543(ann_DASH_check_DASH_temp16904542);
}};
$e45294530.stack[R.EXN_STACKHEIGHT++] = $ss45334534;
}
if(R.isPyretException($e45294530)) {
$e45294530.pyretStack.push(L[531]);
}
throw $e45294530;
}
var $ret45354536 = $Hann_DASH_check_DASH_temp29334543($z45314532);
++R.GAS;
return $ret45354536;
};
},{"length":3});
var anf_extend17064240 = R.makeMethod(function(self6314525) {
return function(l6324504,typ6334505,bind6344528) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[530],3,arguments);
}
var cases_DASH_val1204527 = bind6344528;
var anf_fun16944500 = G(cases_DASH_val1204527,"_match",L[526]);
var anf_obj17014508 = R.makeFunction(function(l26364509,shadows6374510,name6384511,ann6394512) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[527],4,arguments);
}
var anf_arg16964523 = G(self6314525,"env",L[529]);
var $z45154516 = D;
var $f45214522 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(name6384511,(true),anf_arg16964523,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[528],make_DASH_atom_DASH_for3483971.$var,[name6384511,(true),anf_arg16964523,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z45154516 = $f45214522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f45214522,
"from":L[528]});
}
} catch($e45134514) {
if(R.isCont($e45134514)) {
var $ss45174518 = {"from":L[528],
"go":function(atom_DASH_env6404524) {
return $Hatom_DASH_env29364526(atom_DASH_env6404524,A119,ann6394512,l26364509,self6314525,shadows6374510);
}};
$e45134514.stack[R.EXN_STACKHEIGHT++] = $ss45174518;
}
if(R.isPyretException($e45134514)) {
$e45134514.pyretStack.push(L[528]);
}
throw $e45134514;
}
var $ret45194520 = $Hatom_DASH_env29364526($z45154516,A119,ann6394512,l26364509,self6314525,shadows6374510);
++R.GAS;
return $ret45194520;
});
var anf_arg17024501 = R.makeObject({"s-bind":anf_obj17014508});
var anf_arg17044502 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[526],0,arguments);
}
var ann_DASH_check_DASH_temp17034507 = R.throwNoBranchesMatched(L[526],("cases"));
return ann_DASH_check_DASH_temp17034507;
});
var $z44924493 = D;
var $f44984499 = function(_) {
return R.isFunction(anf_fun16944500)?anf_fun16944500.app(anf_arg17024501,anf_arg17044502):R.ffi.throwNonFunApp(L[525],anf_fun16944500,[anf_arg17024501,anf_arg17044502]);
};
try {
if(--R.GAS > 0) {
$z44924493 = $f44984499();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44984499,
"from":L[525]});
}
} catch($e44904491) {
if(R.isCont($e44904491)) {
var $ss44944495 = {"from":L[525],
"go":function(new_DASH_bind6354503) {
return $Hnew_DASH_bind29384506(new_DASH_bind6354503,A119,l6324504,typ6334505);
}};
$e44904491.stack[R.EXN_STACKHEIGHT++] = $ss44944495;
}
if(R.isPyretException($e44904491)) {
$e44904491.pyretStack.push(L[525]);
}
throw $e44904491;
}
var $ret44964497 = $Hnew_DASH_bind29384506($z44924493,A119,l6324504,typ6334505);
++R.GAS;
return $ret44964497;
};
},{"length":4});
var anf_extend17194241 = R.makeMethod(function(self6414489) {
return function(l6424467,shadows6434484,id6444469,ann6454485) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[520],4,arguments);
}
var cases_DASH_val1214488 = id6444469;
var anf_fun17084452 = G(cases_DASH_val1214488,"_match",L[521]);
var anf_obj17114471 = R.makeFunction(function($underscore6464472) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[523],1,arguments);
}
var anf_fun17104483 = G(A119,"s-bind",L[524]);
var $z44754476 = D;
var $f44814482 = function(_) {
return R.isFunction(anf_fun17104483)?anf_fun17104483.app(l6424467,shadows6434484,id6444469,ann6454485):R.ffi.throwNonFunApp(L[523],anf_fun17104483,[l6424467,shadows6434484,id6444469,ann6454485]);
};
try {
if(--R.GAS > 0) {
$z44754476 = $f44814482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44814482,
"from":L[523]});
}
} catch($e44734474) {
if(R.isCont($e44734474)) {
var $ss44774478 = {"from":L[523],
"go":function(ann_DASH_check_DASH_temp17094486) {
return $Hann_DASH_check_DASH_temp29394487(ann_DASH_check_DASH_temp17094486);
}};
$e44734474.stack[R.EXN_STACKHEIGHT++] = $ss44774478;
}
if(R.isPyretException($e44734474)) {
$e44734474.pyretStack.push(L[523]);
}
throw $e44734474;
}
var $ret44794480 = $Hann_DASH_check_DASH_temp29394487($z44754476);
++R.GAS;
return $ret44794480;
});
var anf_arg17124453 = R.makeObject({"s-underscore":anf_obj17114471});
var anf_arg17184454 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[521],0,arguments);
}
var $z44594460 = D;
var $f44654466 = function(_) {
return R.isFunction(torepr16)?torepr16.app(l6424467):R.ffi.throwNonFunApp(L[522],torepr16,[l6424467]);
};
try {
if(--R.GAS > 0) {
$z44594460 = $f44654466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44654466,
"from":L[522]});
}
} catch($e44574458) {
if(R.isCont($e44574458)) {
var $ss44614462 = {"from":L[522],
"go":function(anf_arg17144468) {
return $Hanf_arg29444470(anf_arg17144468,id6444469,_plus9,raise14,torepr16);
}};
$e44574458.stack[R.EXN_STACKHEIGHT++] = $ss44614462;
}
if(R.isPyretException($e44574458)) {
$e44574458.pyretStack.push(L[522]);
}
throw $e44574458;
}
var $ret44634464 = $Hanf_arg29444470($z44594460,id6444469,_plus9,raise14,torepr16);
++R.GAS;
return $ret44634464;
});
var $z44444445 = D;
var $f44504451 = function(_) {
return R.isFunction(anf_fun17084452)?anf_fun17084452.app(anf_arg17124453,anf_arg17184454):R.ffi.throwNonFunApp(L[520],anf_fun17084452,[anf_arg17124453,anf_arg17184454]);
};
try {
if(--R.GAS > 0) {
$z44444445 = $f44504451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44504451,
"from":L[520]});
}
} catch($e44424443) {
if(R.isCont($e44424443)) {
var $ss44464447 = {"from":L[520],
"go":function(ann_DASH_check_DASH_temp17074455) {
return $Hann_DASH_check_DASH_temp29454456(ann_DASH_check_DASH_temp17074455);
}};
$e44424443.stack[R.EXN_STACKHEIGHT++] = $ss44464447;
}
if(R.isPyretException($e44424443)) {
$e44424443.pyretStack.push(L[520]);
}
throw $e44424443;
}
var $ret44484449 = $Hann_DASH_check_DASH_temp29454456($z44444445);
++R.GAS;
return $ret44484449;
};
},{"length":5});
var anf_extend17214242 = R.makeMethod(function(self6474441) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[519],0,arguments);
}
var ann_DASH_check_DASH_temp17204440 = G(A119,"a-blank",L[518]);
return ann_DASH_check_DASH_temp17204440;
};
},{"length":1});
var anf_extend17234243 = R.makeMethod(function(self6484439) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[517],0,arguments);
}
var ann_DASH_check_DASH_temp17224438 = G(A119,"a-any",L[516]);
return ann_DASH_check_DASH_temp17224438;
};
},{"length":1});
var anf_extend17264244 = R.makeMethod(function(self6494437) {
return function(l6504432,id6514434) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[514],2,arguments);
}
var anf_arg17254433 = G(self6494437,"type-env",L[515]);
var $z44244425 = D;
var $f44304431 = function(_) {
return R.isFunction(handle_DASH_ann3523979.$var)?handle_DASH_ann3523979.$var.app(l6504432,anf_arg17254433,id6514434):R.ffi.throwNonFunApp(L[514],handle_DASH_ann3523979.$var,[l6504432,anf_arg17254433,id6514434]);
};
try {
if(--R.GAS > 0) {
$z44244425 = $f44304431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44304431,
"from":L[514]});
}
} catch($e44224423) {
if(R.isCont($e44224423)) {
var $ss44264427 = {"from":L[514],
"go":function(ann_DASH_check_DASH_temp17244435) {
return $Hann_DASH_check_DASH_temp29464436(ann_DASH_check_DASH_temp17244435);
}};
$e44224423.stack[R.EXN_STACKHEIGHT++] = $ss44264427;
}
if(R.isPyretException($e44224423)) {
$e44224423.pyretStack.push(L[514]);
}
throw $e44224423;
}
var $ret44284429 = $Hann_DASH_check_DASH_temp29464436($z44244425);
++R.GAS;
return $ret44284429;
};
},{"length":3});
var anf_extend17364245 = R.makeMethod(function(self6524405) {
return function(l6534402,args6544421,ret6554404,parens6564403) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[513],4,arguments);
}
var anf_fun17284401 = G(A119,"a-arrow",L[512]);
var anf_fun17294398 = G(args6544421,"map",L[511]);
var anf_arg17324399 = R.makeFunction(function(recv_DASH_1224407) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[510],1,arguments);
}
var anf_fun17314418 = G(recv_DASH_1224407,"visit",L[510]);
var $z44104411 = D;
var $f44164417 = function(_) {
return R.isFunction(anf_fun17314418)?anf_fun17314418.app(self6524405):R.ffi.throwNonFunApp(L[510],anf_fun17314418,[self6524405]);
};
try {
if(--R.GAS > 0) {
$z44104411 = $f44164417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f44164417,
"from":L[510]});
}
} catch($e44084409) {
if(R.isCont($e44084409)) {
var $ss44124413 = {"from":L[510],
"go":function(ann_DASH_check_DASH_temp17304419) {
return $Hann_DASH_check_DASH_temp29474420(ann_DASH_check_DASH_temp17304419);
}};
$e44084409.stack[R.EXN_STACKHEIGHT++] = $ss44124413;
}
if(R.isPyretException($e44084409)) {
$e44084409.pyretStack.push(L[510]);
}
throw $e44084409;
}
var $ret44144415 = $Hann_DASH_check_DASH_temp29474420($z44104411);
++R.GAS;
return $ret44144415;
});
var $z43904391 = D;
var $f43964397 = function(_) {
return R.isFunction(anf_fun17294398)?anf_fun17294398.app(anf_arg17324399):R.ffi.throwNonFunApp(L[509],anf_fun17294398,[anf_arg17324399]);
};
try {
if(--R.GAS > 0) {
$z43904391 = $f43964397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43964397,
"from":L[509]});
}
} catch($e43884389) {
if(R.isCont($e43884389)) {
var $ss43924393 = {"from":L[509],
"go":function(anf_arg17334400) {
return $Hanf_arg29504406(anf_arg17334400,anf_fun17284401,l6534402,parens6564403,ret6554404,self6524405);
}};
$e43884389.stack[R.EXN_STACKHEIGHT++] = $ss43924393;
}
if(R.isPyretException($e43884389)) {
$e43884389.pyretStack.push(L[509]);
}
throw $e43884389;
}
var $ret43944395 = $Hanf_arg29504406($z43904391,anf_fun17284401,l6534402,parens6564403,ret6554404,self6524405);
++R.GAS;
return $ret43944395;
};
},{"length":5});
var anf_extend17464246 = R.makeMethod(function(self6574371) {
return function(l6584369,args6594387,ret6604370) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[508],3,arguments);
}
var anf_fun17384368 = G(A119,"a-method",L[507]);
var anf_fun17394365 = G(args6594387,"map",L[506]);
var anf_arg17424366 = R.makeFunction(function(recv_DASH_1234373) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[505],1,arguments);
}
var anf_fun17414384 = G(recv_DASH_1234373,"visit",L[505]);
var $z43764377 = D;
var $f43824383 = function(_) {
return R.isFunction(anf_fun17414384)?anf_fun17414384.app(self6574371):R.ffi.throwNonFunApp(L[505],anf_fun17414384,[self6574371]);
};
try {
if(--R.GAS > 0) {
$z43764377 = $f43824383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43824383,
"from":L[505]});
}
} catch($e43744375) {
if(R.isCont($e43744375)) {
var $ss43784379 = {"from":L[505],
"go":function(ann_DASH_check_DASH_temp17404385) {
return $Hann_DASH_check_DASH_temp29514386(ann_DASH_check_DASH_temp17404385);
}};
$e43744375.stack[R.EXN_STACKHEIGHT++] = $ss43784379;
}
if(R.isPyretException($e43744375)) {
$e43744375.pyretStack.push(L[505]);
}
throw $e43744375;
}
var $ret43804381 = $Hann_DASH_check_DASH_temp29514386($z43764377);
++R.GAS;
return $ret43804381;
});
var $z43574358 = D;
var $f43634364 = function(_) {
return R.isFunction(anf_fun17394365)?anf_fun17394365.app(anf_arg17424366):R.ffi.throwNonFunApp(L[504],anf_fun17394365,[anf_arg17424366]);
};
try {
if(--R.GAS > 0) {
$z43574358 = $f43634364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43634364,
"from":L[504]});
}
} catch($e43554356) {
if(R.isCont($e43554356)) {
var $ss43594360 = {"from":L[504],
"go":function(anf_arg17434367) {
return $Hanf_arg29544372(anf_arg17434367,anf_fun17384368,l6584369,ret6604370,self6574371);
}};
$e43554356.stack[R.EXN_STACKHEIGHT++] = $ss43594360;
}
if(R.isPyretException($e43554356)) {
$e43554356.pyretStack.push(L[504]);
}
throw $e43554356;
}
var $ret43614362 = $Hanf_arg29544372($z43574358,anf_fun17384368,l6584369,ret6604370,self6574371);
++R.GAS;
return $ret43614362;
};
},{"length":4});
var anf_extend17544247 = R.makeMethod(function(self6614351) {
return function(l6624337,fields6634354) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[503],2,arguments);
}
var anf_fun17484336 = G(A119,"a-record",L[502]);
var anf_fun17494333 = G(fields6634354,"map",L[501]);
var anf_arg17524334 = R.makeFunction(function(recv_DASH_1244339) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[500],1,arguments);
}
var anf_fun17514350 = G(recv_DASH_1244339,"visit",L[500]);
var $z43424343 = D;
var $f43484349 = function(_) {
return R.isFunction(anf_fun17514350)?anf_fun17514350.app(self6614351):R.ffi.throwNonFunApp(L[500],anf_fun17514350,[self6614351]);
};
try {
if(--R.GAS > 0) {
$z43424343 = $f43484349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43484349,
"from":L[500]});
}
} catch($e43404341) {
if(R.isCont($e43404341)) {
var $ss43444345 = {"from":L[500],
"go":function(ann_DASH_check_DASH_temp17504352) {
return $Hann_DASH_check_DASH_temp29554353(ann_DASH_check_DASH_temp17504352);
}};
$e43404341.stack[R.EXN_STACKHEIGHT++] = $ss43444345;
}
if(R.isPyretException($e43404341)) {
$e43404341.pyretStack.push(L[500]);
}
throw $e43404341;
}
var $ret43464347 = $Hann_DASH_check_DASH_temp29554353($z43424343);
++R.GAS;
return $ret43464347;
});
var $z43254326 = D;
var $f43314332 = function(_) {
return R.isFunction(anf_fun17494333)?anf_fun17494333.app(anf_arg17524334):R.ffi.throwNonFunApp(L[499],anf_fun17494333,[anf_arg17524334]);
};
try {
if(--R.GAS > 0) {
$z43254326 = $f43314332();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43314332,
"from":L[499]});
}
} catch($e43234324) {
if(R.isCont($e43234324)) {
var $ss43274328 = {"from":L[499],
"go":function(anf_arg17534335) {
return $Hanf_arg29574338(anf_arg17534335,anf_fun17484336,l6624337);
}};
$e43234324.stack[R.EXN_STACKHEIGHT++] = $ss43274328;
}
if(R.isPyretException($e43234324)) {
$e43234324.pyretStack.push(L[499]);
}
throw $e43234324;
}
var $ret43294330 = $Hanf_arg29574338($z43254326,anf_fun17484336,l6624337);
++R.GAS;
return $ret43294330;
};
},{"length":3});
var anf_extend17644248 = R.makeMethod(function(self6644316) {
return function(l6654320,ann6664322,args6674319) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[498],3,arguments);
}
var anf_fun17564318 = G(A119,"a-app",L[497]);
var anf_fun17574315 = G(ann6664322,"visit",L[496]);
var $z43074308 = D;
var $f43134314 = function(_) {
return R.isFunction(anf_fun17574315)?anf_fun17574315.app(self6644316):R.ffi.throwNonFunApp(L[495],anf_fun17574315,[self6644316]);
};
try {
if(--R.GAS > 0) {
$z43074308 = $f43134314();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f43134314,
"from":L[495]});
}
} catch($e43054306) {
if(R.isCont($e43054306)) {
var $ss43094310 = {"from":L[495],
"go":function(anf_arg17584317) {
return $Hanf_arg29614321(anf_arg17584317,anf_fun17564318,args6674319,l6654320,self6644316);
}};
$e43054306.stack[R.EXN_STACKHEIGHT++] = $ss43094310;
}
if(R.isPyretException($e43054306)) {
$e43054306.pyretStack.push(L[495]);
}
throw $e43054306;
}
var $ret43114312 = $Hanf_arg29614321($z43074308,anf_fun17564318,args6674319,l6654320,self6644316);
++R.GAS;
return $ret43114312;
};
},{"length":4});
var anf_extend17714249 = R.makeMethod(function(self6684298) {
return function(l6694302,ann6704304,exp6714301) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[494],3,arguments);
}
var anf_fun17664300 = G(A119,"a-pred",L[493]);
var anf_fun17674297 = G(ann6704304,"visit",L[492]);
var $z42894290 = D;
var $f42954296 = function(_) {
return R.isFunction(anf_fun17674297)?anf_fun17674297.app(self6684298):R.ffi.throwNonFunApp(L[491],anf_fun17674297,[self6684298]);
};
try {
if(--R.GAS > 0) {
$z42894290 = $f42954296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42954296,
"from":L[491]});
}
} catch($e42874288) {
if(R.isCont($e42874288)) {
var $ss42914292 = {"from":L[491],
"go":function(anf_arg17684299) {
return $Hanf_arg29644303(anf_arg17684299,anf_fun17664300,exp6714301,l6694302,self6684298);
}};
$e42874288.stack[R.EXN_STACKHEIGHT++] = $ss42914292;
}
if(R.isPyretException($e42874288)) {
$e42874288.pyretStack.push(L[491]);
}
throw $e42874288;
}
var $ret42934294 = $Hanf_arg29644303($z42894290,anf_fun17664300,exp6714301,l6694302,self6684298);
++R.GAS;
return $ret42934294;
};
},{"length":4});
var anf_extend17844250 = R.makeMethod(function(self6724286) {
return function(l6734280,obj6744282,field6754284) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[490],3,arguments);
}
var anf_arg17734281 = G(self6724286,"type-env",L[489]);
var $z42724273 = D;
var $f42784279 = function(_) {
return R.isFunction(handle_DASH_ann3523979.$var)?handle_DASH_ann3523979.$var.app(l6734280,anf_arg17734281,obj6744282):R.ffi.throwNonFunApp(L[488],handle_DASH_ann3523979.$var,[l6734280,anf_arg17734281,obj6744282]);
};
try {
if(--R.GAS > 0) {
$z42724273 = $f42784279();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42784279,
"from":L[488]});
}
} catch($e42704271) {
if(R.isCont($e42704271)) {
var $ss42744275 = {"from":L[488],
"go":function(obj_DASH_ann6764283) {
return $Hobj_DASH_ann29694285(obj_DASH_ann6764283,A119,C923,field6754284,l6734280,link3774,name_DASH_errors3453956,obj6744282);
}};
$e42704271.stack[R.EXN_STACKHEIGHT++] = $ss42744275;
}
if(R.isPyretException($e42704271)) {
$e42704271.pyretStack.push(L[488]);
}
throw $e42704271;
}
var $ret42764277 = $Hobj_DASH_ann29694285($z42724273,A119,C923,field6754284,l6734280,link3774,name_DASH_errors3453956,obj6744282);
++R.GAS;
return $ret42764277;
};
},{"length":4});
var anf_extend17894251 = R.makeMethod(function(self6794263) {
return function(l6804266,name6814267,ann6824269) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[487],3,arguments);
}
var anf_fun17864265 = G(A119,"a-field",L[486]);
var anf_fun17874262 = G(ann6824269,"visit",L[485]);
var $z42544255 = D;
var $f42604261 = function(_) {
return R.isFunction(anf_fun17874262)?anf_fun17874262.app(self6794263):R.ffi.throwNonFunApp(L[484],anf_fun17874262,[self6794263]);
};
try {
if(--R.GAS > 0) {
$z42544255 = $f42604261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42604261,
"from":L[484]});
}
} catch($e42524253) {
if(R.isCont($e42524253)) {
var $ss42564257 = {"from":L[484],
"go":function(anf_arg17884264) {
return $Hanf_arg29714268(anf_arg17884264,anf_fun17864265,l6804266,name6814267);
}};
$e42524253.stack[R.EXN_STACKHEIGHT++] = $ss42564257;
}
if(R.isPyretException($e42524253)) {
$e42524253.pyretStack.push(L[484]);
}
throw $e42524253;
}
var $ret42584259 = $Hanf_arg29714268($z42544255,anf_fun17864265,l6804266,name6814267);
++R.GAS;
return $ret42584259;
};
},{"length":4});
var names_DASH_visitor4224223 = anf_extend12133992.extendWith({"env":anf_extend12143991,
"type-env":anf_extend12154210,
"s-program":anf_extend12504226,
"s-type-let-expr":anf_extend12994227,
"s-let-expr":anf_extend13634228,
"s-letrec":anf_extend14034229,
"s-for":anf_extend14504230,
"s-cases-branch":anf_extend14854231,
"s-data-expr":anf_extend15204232,
"s-lam":anf_extend15684233,
"s-method":anf_extend16084234,
"s-method-field":anf_extend16484235,
"s-assign":anf_extend16834236,
"s-id":anf_extend16864237,
"s-id-letrec":anf_extend16894238,
"s-id-var":anf_extend16924239,
"s-variant-member":anf_extend17064240,
"s-bind":anf_extend17194241,
"a-blank":anf_extend17214242,
"a-any":anf_extend17234243,
"a-name":anf_extend17264244,
"a-arrow":anf_extend17364245,
"a-method":anf_extend17464246,
"a-record":anf_extend17544247,
"a-app":anf_extend17644248,
"a-pred":anf_extend17714249,
"a-dot":anf_extend17844250,
"a-field":anf_extend17894251});
var anf_fun17904222 = G(p343146,"visit",L[483]);
var $z42144215 = D;
var $f42204221 = function(_) {
return R.isFunction(anf_fun17904222)?anf_fun17904222.app(names_DASH_visitor4224223):R.ffi.throwNonFunApp(L[482],anf_fun17904222,[names_DASH_visitor4224223]);
};
try {
if(--R.GAS > 0) {
$z42144215 = $f42204221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f42204221,
"from":L[482]});
}
} catch($e42124213) {
if(R.isCont($e42124213)) {
var $ss42164217 = {"from":L[482],
"go":function(anf_arg17914224) {
return $Hanf_arg29734225(anf_arg17914224,bindings3463955,name_DASH_errors3453956,resolved8483);
}};
$e42124213.stack[R.EXN_STACKHEIGHT++] = $ss42164217;
}
if(R.isPyretException($e42124213)) {
$e42124213.pyretStack.push(L[482]);
}
throw $e42124213;
}
var $ret42184219 = $Hanf_arg29734225($z42144215,bindings3463955,name_DASH_errors3453956,resolved8483);
++R.GAS;
return $ret42184219;
};
var $Hanf_arg29734225 = function(anf_arg17914224,bindings3463955,name_DASH_errors3453956,resolved8483) {
var $z51425143 = D;
var $f51485149 = function(_) {
return R.isFunction(resolved8483.$var)?resolved8483.$var.app(anf_arg17914224,name_DASH_errors3453956.$var,bindings3463955):R.ffi.throwNonFunApp(L[1],resolved8483.$var,[anf_arg17914224,name_DASH_errors3453956.$var,bindings3463955]);
};
try {
if(--R.GAS > 0) {
$z51425143 = $f51485149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51485149,
"from":L[1]});
}
} catch($e51405141) {
if(R.isCont($e51405141)) {
var $ss51445145 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp10115150) {
return $Hann_DASH_check_DASH_temp29725151(ann_DASH_check_DASH_temp10115150);
}};
$e51405141.stack[R.EXN_STACKHEIGHT++] = $ss51445145;
}
if(R.isPyretException($e51405141)) {
$e51405141.pyretStack.push(L[1]);
}
throw $e51405141;
}
var $ret51465147 = $Hann_DASH_check_DASH_temp29725151($z51425143);
++R.GAS;
return $ret51465147;
};
var $Hann_DASH_check_DASH_temp29725151 = function(ann_DASH_check_DASH_temp10115150) {
return ann_DASH_check_DASH_temp10115150;
};
var $Hanf_arg29714268 = function(anf_arg17884264,anf_fun17864265,l6804266,name6814267) {
var $z51545155 = D;
var $f51605161 = function(_) {
return R.isFunction(anf_fun17864265)?anf_fun17864265.app(l6804266,name6814267,anf_arg17884264):R.ffi.throwNonFunApp(L[487],anf_fun17864265,[l6804266,name6814267,anf_arg17884264]);
};
try {
if(--R.GAS > 0) {
$z51545155 = $f51605161();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51605161,
"from":L[487]});
}
} catch($e51525153) {
if(R.isCont($e51525153)) {
var $ss51565157 = {"from":L[487],
"go":function(ann_DASH_check_DASH_temp17855162) {
return $Hann_DASH_check_DASH_temp29705163(ann_DASH_check_DASH_temp17855162);
}};
$e51525153.stack[R.EXN_STACKHEIGHT++] = $ss51565157;
}
if(R.isPyretException($e51525153)) {
$e51525153.pyretStack.push(L[487]);
}
throw $e51525153;
}
var $ret51585159 = $Hann_DASH_check_DASH_temp29705163($z51545155);
++R.GAS;
return $ret51585159;
};
var $Hann_DASH_check_DASH_temp29705163 = function(ann_DASH_check_DASH_temp17855162) {
return ann_DASH_check_DASH_temp17855162;
};
var $Hobj_DASH_ann29694285 = function(obj_DASH_ann6764283,A119,C923,field6754284,l6734280,link3774,name_DASH_errors3453956,obj6744282) {
var cases_DASH_val1265208 = obj_DASH_ann6764283;
var anf_fun17745174 = G(cases_DASH_val1265208,"_match",L[640]);
var anf_obj17775192 = R.makeFunction(function($underscore6775193,name6785194) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[643],2,arguments);
}
var anf_fun17765205 = G(A119,"a-dot",L[644]);
var $z51975198 = D;
var $f52035204 = function(_) {
return R.isFunction(anf_fun17765205)?anf_fun17765205.app(l6734280,name6785194,field6754284):R.ffi.throwNonFunApp(L[643],anf_fun17765205,[l6734280,name6785194,field6754284]);
};
try {
if(--R.GAS > 0) {
$z51975198 = $f52035204();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52035204,
"from":L[643]});
}
} catch($e51955196) {
if(R.isCont($e51955196)) {
var $ss51995200 = {"from":L[643],
"go":function(ann_DASH_check_DASH_temp17755206) {
return $Hann_DASH_check_DASH_temp29655207(ann_DASH_check_DASH_temp17755206);
}};
$e51955196.stack[R.EXN_STACKHEIGHT++] = $ss51995200;
}
if(R.isPyretException($e51955196)) {
$e51955196.pyretStack.push(L[643]);
}
throw $e51955196;
}
var $ret52015202 = $Hann_DASH_check_DASH_temp29655207($z51975198);
++R.GAS;
return $ret52015202;
});
var anf_arg17785175 = R.makeObject({"a-name":anf_obj17775192});
var anf_arg17835176 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[640],0,arguments);
}
var anf_fun17805189 = G(C923,"unexpected-type-var",L[642]);
var $z51815182 = D;
var $f51875188 = function(_) {
return R.isFunction(anf_fun17805189)?anf_fun17805189.app(l6734280,obj6744282):R.ffi.throwNonFunApp(L[641],anf_fun17805189,[l6734280,obj6744282]);
};
try {
if(--R.GAS > 0) {
$z51815182 = $f51875188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51875188,
"from":L[641]});
}
} catch($e51795180) {
if(R.isCont($e51795180)) {
var $ss51835184 = {"from":L[641],
"go":function(anf_arg17815190) {
return $Hanf_arg29675191(anf_arg17815190,A119,link3774,name_DASH_errors3453956);
}};
$e51795180.stack[R.EXN_STACKHEIGHT++] = $ss51835184;
}
if(R.isPyretException($e51795180)) {
$e51795180.pyretStack.push(L[641]);
}
throw $e51795180;
}
var $ret51855186 = $Hanf_arg29675191($z51815182,A119,link3774,name_DASH_errors3453956);
++R.GAS;
return $ret51855186;
});
var $z51665167 = D;
var $f51725173 = function(_) {
return R.isFunction(anf_fun17745174)?anf_fun17745174.app(anf_arg17785175,anf_arg17835176):R.ffi.throwNonFunApp(L[490],anf_fun17745174,[anf_arg17785175,anf_arg17835176]);
};
try {
if(--R.GAS > 0) {
$z51665167 = $f51725173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f51725173,
"from":L[490]});
}
} catch($e51645165) {
if(R.isCont($e51645165)) {
var $ss51685169 = {"from":L[490],
"go":function(ann_DASH_check_DASH_temp17725177) {
return $Hann_DASH_check_DASH_temp29685178(ann_DASH_check_DASH_temp17725177);
}};
$e51645165.stack[R.EXN_STACKHEIGHT++] = $ss51685169;
}
if(R.isPyretException($e51645165)) {
$e51645165.pyretStack.push(L[490]);
}
throw $e51645165;
}
var $ret51705171 = $Hann_DASH_check_DASH_temp29685178($z51665167);
++R.GAS;
return $ret51705171;
};
var $Hann_DASH_check_DASH_temp29685178 = function(ann_DASH_check_DASH_temp17725177) {
return ann_DASH_check_DASH_temp17725177;
};
var $Hanf_arg29675191 = function(anf_arg17815190,A119,link3774,name_DASH_errors3453956) {
var $z52115212 = D;
var $f52175218 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg17815190,name_DASH_errors3453956.$var):R.ffi.throwNonFunApp(L[645],link3774,[anf_arg17815190,name_DASH_errors3453956.$var]);
};
try {
if(--R.GAS > 0) {
$z52115212 = $f52175218();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52175218,
"from":L[645]});
}
} catch($e52095210) {
if(R.isCont($e52095210)) {
var $ss52135214 = {"from":L[645],
"go":function(anf_assign17825219) {
return $Hanf_assign29665220(anf_assign17825219,A119,name_DASH_errors3453956);
}};
$e52095210.stack[R.EXN_STACKHEIGHT++] = $ss52135214;
}
if(R.isPyretException($e52095210)) {
$e52095210.pyretStack.push(L[645]);
}
throw $e52095210;
}
var $ret52155216 = $Hanf_assign29665220($z52115212,A119,name_DASH_errors3453956);
++R.GAS;
return $ret52155216;
};
var $Hanf_assign29665220 = function(anf_assign17825219,A119,name_DASH_errors3453956) {
name_DASH_errors3453956.$var = anf_assign17825219;
var ann_DASH_check_DASH_temp17795221 = G(A119,"a-blank",L[646]);
return ann_DASH_check_DASH_temp17795221;
};
var $Hann_DASH_check_DASH_temp29655207 = function(ann_DASH_check_DASH_temp17755206) {
return ann_DASH_check_DASH_temp17755206;
};
var $Hanf_arg29644303 = function(anf_arg17684299,anf_fun17664300,exp6714301,l6694302,self6684298) {
var anf_fun17695232 = G(exp6714301,"visit",L[648]);
var $z52245225 = D;
var $f52305231 = function(_) {
return R.isFunction(anf_fun17695232)?anf_fun17695232.app(self6684298):R.ffi.throwNonFunApp(L[647],anf_fun17695232,[self6684298]);
};
try {
if(--R.GAS > 0) {
$z52245225 = $f52305231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52305231,
"from":L[647]});
}
} catch($e52225223) {
if(R.isCont($e52225223)) {
var $ss52265227 = {"from":L[647],
"go":function(anf_arg17705233) {
return $Hanf_arg29635234(anf_arg17705233,anf_arg17684299,anf_fun17664300,l6694302);
}};
$e52225223.stack[R.EXN_STACKHEIGHT++] = $ss52265227;
}
if(R.isPyretException($e52225223)) {
$e52225223.pyretStack.push(L[647]);
}
throw $e52225223;
}
var $ret52285229 = $Hanf_arg29635234($z52245225,anf_arg17684299,anf_fun17664300,l6694302);
++R.GAS;
return $ret52285229;
};
var $Hanf_arg29635234 = function(anf_arg17705233,anf_arg17684299,anf_fun17664300,l6694302) {
var $z52375238 = D;
var $f52435244 = function(_) {
return R.isFunction(anf_fun17664300)?anf_fun17664300.app(l6694302,anf_arg17684299,anf_arg17705233):R.ffi.throwNonFunApp(L[494],anf_fun17664300,[l6694302,anf_arg17684299,anf_arg17705233]);
};
try {
if(--R.GAS > 0) {
$z52375238 = $f52435244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52435244,
"from":L[494]});
}
} catch($e52355236) {
if(R.isCont($e52355236)) {
var $ss52395240 = {"from":L[494],
"go":function(ann_DASH_check_DASH_temp17655245) {
return $Hann_DASH_check_DASH_temp29625246(ann_DASH_check_DASH_temp17655245);
}};
$e52355236.stack[R.EXN_STACKHEIGHT++] = $ss52395240;
}
if(R.isPyretException($e52355236)) {
$e52355236.pyretStack.push(L[494]);
}
throw $e52355236;
}
var $ret52415242 = $Hann_DASH_check_DASH_temp29625246($z52375238);
++R.GAS;
return $ret52415242;
};
var $Hann_DASH_check_DASH_temp29625246 = function(ann_DASH_check_DASH_temp17655245) {
return ann_DASH_check_DASH_temp17655245;
};
var $Hanf_arg29614321 = function(anf_arg17584317,anf_fun17564318,args6674319,l6654320,self6644316) {
var anf_fun17595257 = G(args6674319,"map",L[651]);
var anf_arg17625258 = R.makeFunction(function(recv_DASH_1255261) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[650],1,arguments);
}
var anf_fun17615272 = G(recv_DASH_1255261,"visit",L[650]);
var $z52645265 = D;
var $f52705271 = function(_) {
return R.isFunction(anf_fun17615272)?anf_fun17615272.app(self6644316):R.ffi.throwNonFunApp(L[650],anf_fun17615272,[self6644316]);
};
try {
if(--R.GAS > 0) {
$z52645265 = $f52705271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52705271,
"from":L[650]});
}
} catch($e52625263) {
if(R.isCont($e52625263)) {
var $ss52665267 = {"from":L[650],
"go":function(ann_DASH_check_DASH_temp17605273) {
return $Hann_DASH_check_DASH_temp29585274(ann_DASH_check_DASH_temp17605273);
}};
$e52625263.stack[R.EXN_STACKHEIGHT++] = $ss52665267;
}
if(R.isPyretException($e52625263)) {
$e52625263.pyretStack.push(L[650]);
}
throw $e52625263;
}
var $ret52685269 = $Hann_DASH_check_DASH_temp29585274($z52645265);
++R.GAS;
return $ret52685269;
});
var $z52495250 = D;
var $f52555256 = function(_) {
return R.isFunction(anf_fun17595257)?anf_fun17595257.app(anf_arg17625258):R.ffi.throwNonFunApp(L[649],anf_fun17595257,[anf_arg17625258]);
};
try {
if(--R.GAS > 0) {
$z52495250 = $f52555256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52555256,
"from":L[649]});
}
} catch($e52475248) {
if(R.isCont($e52475248)) {
var $ss52515252 = {"from":L[649],
"go":function(anf_arg17635259) {
return $Hanf_arg29605260(anf_arg17635259,anf_arg17584317,anf_fun17564318,l6654320);
}};
$e52475248.stack[R.EXN_STACKHEIGHT++] = $ss52515252;
}
if(R.isPyretException($e52475248)) {
$e52475248.pyretStack.push(L[649]);
}
throw $e52475248;
}
var $ret52535254 = $Hanf_arg29605260($z52495250,anf_arg17584317,anf_fun17564318,l6654320);
++R.GAS;
return $ret52535254;
};
var $Hanf_arg29605260 = function(anf_arg17635259,anf_arg17584317,anf_fun17564318,l6654320) {
var $z52775278 = D;
var $f52835284 = function(_) {
return R.isFunction(anf_fun17564318)?anf_fun17564318.app(l6654320,anf_arg17584317,anf_arg17635259):R.ffi.throwNonFunApp(L[498],anf_fun17564318,[l6654320,anf_arg17584317,anf_arg17635259]);
};
try {
if(--R.GAS > 0) {
$z52775278 = $f52835284();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52835284,
"from":L[498]});
}
} catch($e52755276) {
if(R.isCont($e52755276)) {
var $ss52795280 = {"from":L[498],
"go":function(ann_DASH_check_DASH_temp17555285) {
return $Hann_DASH_check_DASH_temp29595286(ann_DASH_check_DASH_temp17555285);
}};
$e52755276.stack[R.EXN_STACKHEIGHT++] = $ss52795280;
}
if(R.isPyretException($e52755276)) {
$e52755276.pyretStack.push(L[498]);
}
throw $e52755276;
}
var $ret52815282 = $Hann_DASH_check_DASH_temp29595286($z52775278);
++R.GAS;
return $ret52815282;
};
var $Hann_DASH_check_DASH_temp29595286 = function(ann_DASH_check_DASH_temp17555285) {
return ann_DASH_check_DASH_temp17555285;
};
var $Hann_DASH_check_DASH_temp29585274 = function(ann_DASH_check_DASH_temp17605273) {
return ann_DASH_check_DASH_temp17605273;
};
var $Hanf_arg29574338 = function(anf_arg17534335,anf_fun17484336,l6624337) {
var $z52895290 = D;
var $f52955296 = function(_) {
return R.isFunction(anf_fun17484336)?anf_fun17484336.app(l6624337,anf_arg17534335):R.ffi.throwNonFunApp(L[503],anf_fun17484336,[l6624337,anf_arg17534335]);
};
try {
if(--R.GAS > 0) {
$z52895290 = $f52955296();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f52955296,
"from":L[503]});
}
} catch($e52875288) {
if(R.isCont($e52875288)) {
var $ss52915292 = {"from":L[503],
"go":function(ann_DASH_check_DASH_temp17475297) {
return $Hann_DASH_check_DASH_temp29565298(ann_DASH_check_DASH_temp17475297);
}};
$e52875288.stack[R.EXN_STACKHEIGHT++] = $ss52915292;
}
if(R.isPyretException($e52875288)) {
$e52875288.pyretStack.push(L[503]);
}
throw $e52875288;
}
var $ret52935294 = $Hann_DASH_check_DASH_temp29565298($z52895290);
++R.GAS;
return $ret52935294;
};
var $Hann_DASH_check_DASH_temp29565298 = function(ann_DASH_check_DASH_temp17475297) {
return ann_DASH_check_DASH_temp17475297;
};
var $Hann_DASH_check_DASH_temp29554353 = function(ann_DASH_check_DASH_temp17504352) {
return ann_DASH_check_DASH_temp17504352;
};
var $Hanf_arg29544372 = function(anf_arg17434367,anf_fun17384368,l6584369,ret6604370,self6574371) {
var anf_fun17445309 = G(ret6604370,"visit",L[653]);
var $z53015302 = D;
var $f53075308 = function(_) {
return R.isFunction(anf_fun17445309)?anf_fun17445309.app(self6574371):R.ffi.throwNonFunApp(L[652],anf_fun17445309,[self6574371]);
};
try {
if(--R.GAS > 0) {
$z53015302 = $f53075308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53075308,
"from":L[652]});
}
} catch($e52995300) {
if(R.isCont($e52995300)) {
var $ss53035304 = {"from":L[652],
"go":function(anf_arg17455310) {
return $Hanf_arg29535311(anf_arg17455310,anf_arg17434367,anf_fun17384368,l6584369);
}};
$e52995300.stack[R.EXN_STACKHEIGHT++] = $ss53035304;
}
if(R.isPyretException($e52995300)) {
$e52995300.pyretStack.push(L[652]);
}
throw $e52995300;
}
var $ret53055306 = $Hanf_arg29535311($z53015302,anf_arg17434367,anf_fun17384368,l6584369);
++R.GAS;
return $ret53055306;
};
var $Hanf_arg29535311 = function(anf_arg17455310,anf_arg17434367,anf_fun17384368,l6584369) {
var $z53145315 = D;
var $f53205321 = function(_) {
return R.isFunction(anf_fun17384368)?anf_fun17384368.app(l6584369,anf_arg17434367,anf_arg17455310):R.ffi.throwNonFunApp(L[508],anf_fun17384368,[l6584369,anf_arg17434367,anf_arg17455310]);
};
try {
if(--R.GAS > 0) {
$z53145315 = $f53205321();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53205321,
"from":L[508]});
}
} catch($e53125313) {
if(R.isCont($e53125313)) {
var $ss53165317 = {"from":L[508],
"go":function(ann_DASH_check_DASH_temp17375322) {
return $Hann_DASH_check_DASH_temp29525323(ann_DASH_check_DASH_temp17375322);
}};
$e53125313.stack[R.EXN_STACKHEIGHT++] = $ss53165317;
}
if(R.isPyretException($e53125313)) {
$e53125313.pyretStack.push(L[508]);
}
throw $e53125313;
}
var $ret53185319 = $Hann_DASH_check_DASH_temp29525323($z53145315);
++R.GAS;
return $ret53185319;
};
var $Hann_DASH_check_DASH_temp29525323 = function(ann_DASH_check_DASH_temp17375322) {
return ann_DASH_check_DASH_temp17375322;
};
var $Hann_DASH_check_DASH_temp29514386 = function(ann_DASH_check_DASH_temp17404385) {
return ann_DASH_check_DASH_temp17404385;
};
var $Hanf_arg29504406 = function(anf_arg17334400,anf_fun17284401,l6534402,parens6564403,ret6554404,self6524405) {
var anf_fun17345334 = G(ret6554404,"visit",L[655]);
var $z53265327 = D;
var $f53325333 = function(_) {
return R.isFunction(anf_fun17345334)?anf_fun17345334.app(self6524405):R.ffi.throwNonFunApp(L[654],anf_fun17345334,[self6524405]);
};
try {
if(--R.GAS > 0) {
$z53265327 = $f53325333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53325333,
"from":L[654]});
}
} catch($e53245325) {
if(R.isCont($e53245325)) {
var $ss53285329 = {"from":L[654],
"go":function(anf_arg17355335) {
return $Hanf_arg29495336(anf_arg17355335,anf_arg17334400,anf_fun17284401,l6534402,parens6564403);
}};
$e53245325.stack[R.EXN_STACKHEIGHT++] = $ss53285329;
}
if(R.isPyretException($e53245325)) {
$e53245325.pyretStack.push(L[654]);
}
throw $e53245325;
}
var $ret53305331 = $Hanf_arg29495336($z53265327,anf_arg17334400,anf_fun17284401,l6534402,parens6564403);
++R.GAS;
return $ret53305331;
};
var $Hanf_arg29495336 = function(anf_arg17355335,anf_arg17334400,anf_fun17284401,l6534402,parens6564403) {
var $z53395340 = D;
var $f53455346 = function(_) {
return R.isFunction(anf_fun17284401)?anf_fun17284401.app(l6534402,anf_arg17334400,anf_arg17355335,parens6564403):R.ffi.throwNonFunApp(L[513],anf_fun17284401,[l6534402,anf_arg17334400,anf_arg17355335,parens6564403]);
};
try {
if(--R.GAS > 0) {
$z53395340 = $f53455346();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53455346,
"from":L[513]});
}
} catch($e53375338) {
if(R.isCont($e53375338)) {
var $ss53415342 = {"from":L[513],
"go":function(ann_DASH_check_DASH_temp17275347) {
return $Hann_DASH_check_DASH_temp29485348(ann_DASH_check_DASH_temp17275347);
}};
$e53375338.stack[R.EXN_STACKHEIGHT++] = $ss53415342;
}
if(R.isPyretException($e53375338)) {
$e53375338.pyretStack.push(L[513]);
}
throw $e53375338;
}
var $ret53435344 = $Hann_DASH_check_DASH_temp29485348($z53395340);
++R.GAS;
return $ret53435344;
};
var $Hann_DASH_check_DASH_temp29485348 = function(ann_DASH_check_DASH_temp17275347) {
return ann_DASH_check_DASH_temp17275347;
};
var $Hann_DASH_check_DASH_temp29474420 = function(ann_DASH_check_DASH_temp17304419) {
return ann_DASH_check_DASH_temp17304419;
};
var $Hann_DASH_check_DASH_temp29464436 = function(ann_DASH_check_DASH_temp17244435) {
return ann_DASH_check_DASH_temp17244435;
};
var $Hann_DASH_check_DASH_temp29454456 = function(ann_DASH_check_DASH_temp17074455) {
return ann_DASH_check_DASH_temp17074455;
};
var $Hanf_arg29444470 = function(anf_arg17144468,id6444469,_plus9,raise14,torepr16) {
var $z53515352 = D;
var $f53575358 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("Should not reach non-underscore bindings in resolve-names"),anf_arg17144468):R.ffi.throwNonFunApp(L[656],_plus9,[("Should not reach non-underscore bindings in resolve-names"),anf_arg17144468]);
};
try {
if(--R.GAS > 0) {
$z53515352 = $f53575358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53575358,
"from":L[656]});
}
} catch($e53495350) {
if(R.isCont($e53495350)) {
var $ss53535354 = {"from":L[656],
"go":function(anf_arg17155359) {
return $Hanf_arg29435360(anf_arg17155359,id6444469,_plus9,raise14,torepr16);
}};
$e53495350.stack[R.EXN_STACKHEIGHT++] = $ss53535354;
}
if(R.isPyretException($e53495350)) {
$e53495350.pyretStack.push(L[656]);
}
throw $e53495350;
}
var $ret53555356 = $Hanf_arg29435360($z53515352,id6444469,_plus9,raise14,torepr16);
++R.GAS;
return $ret53555356;
};
var $Hanf_arg29435360 = function(anf_arg17155359,id6444469,_plus9,raise14,torepr16) {
var $z53635364 = D;
var $f53695370 = function(_) {
return R.isFunction(torepr16)?torepr16.app(id6444469):R.ffi.throwNonFunApp(L[657],torepr16,[id6444469]);
};
try {
if(--R.GAS > 0) {
$z53635364 = $f53695370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53695370,
"from":L[657]});
}
} catch($e53615362) {
if(R.isCont($e53615362)) {
var $ss53655366 = {"from":L[657],
"go":function(anf_arg17165371) {
return $Hanf_arg29425372(anf_arg17165371,anf_arg17155359,_plus9,raise14);
}};
$e53615362.stack[R.EXN_STACKHEIGHT++] = $ss53655366;
}
if(R.isPyretException($e53615362)) {
$e53615362.pyretStack.push(L[657]);
}
throw $e53615362;
}
var $ret53675368 = $Hanf_arg29425372($z53635364,anf_arg17155359,_plus9,raise14);
++R.GAS;
return $ret53675368;
};
var $Hanf_arg29425372 = function(anf_arg17165371,anf_arg17155359,_plus9,raise14) {
var $z53755376 = D;
var $f53815382 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg17155359,anf_arg17165371):R.ffi.throwNonFunApp(L[656],_plus9,[anf_arg17155359,anf_arg17165371]);
};
try {
if(--R.GAS > 0) {
$z53755376 = $f53815382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53815382,
"from":L[656]});
}
} catch($e53735374) {
if(R.isCont($e53735374)) {
var $ss53775378 = {"from":L[656],
"go":function(anf_arg17175383) {
return $Hanf_arg29415384(anf_arg17175383,raise14);
}};
$e53735374.stack[R.EXN_STACKHEIGHT++] = $ss53775378;
}
if(R.isPyretException($e53735374)) {
$e53735374.pyretStack.push(L[656]);
}
throw $e53735374;
}
var $ret53795380 = $Hanf_arg29415384($z53755376,raise14);
++R.GAS;
return $ret53795380;
};
var $Hanf_arg29415384 = function(anf_arg17175383,raise14) {
var $z53875388 = D;
var $f53935394 = function(_) {
return R.isFunction(raise14)?raise14.app(anf_arg17175383):R.ffi.throwNonFunApp(L[521],raise14,[anf_arg17175383]);
};
try {
if(--R.GAS > 0) {
$z53875388 = $f53935394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f53935394,
"from":L[521]});
}
} catch($e53855386) {
if(R.isCont($e53855386)) {
var $ss53895390 = {"from":L[521],
"go":function(ann_DASH_check_DASH_temp17135395) {
return $Hann_DASH_check_DASH_temp29405396(ann_DASH_check_DASH_temp17135395);
}};
$e53855386.stack[R.EXN_STACKHEIGHT++] = $ss53895390;
}
if(R.isPyretException($e53855386)) {
$e53855386.pyretStack.push(L[521]);
}
throw $e53855386;
}
var $ret53915392 = $Hann_DASH_check_DASH_temp29405396($z53875388);
++R.GAS;
return $ret53915392;
};
var $Hann_DASH_check_DASH_temp29405396 = function(ann_DASH_check_DASH_temp17135395) {
return ann_DASH_check_DASH_temp17135395;
};
var $Hann_DASH_check_DASH_temp29394487 = function(ann_DASH_check_DASH_temp17094486) {
return ann_DASH_check_DASH_temp17094486;
};
var $Hnew_DASH_bind29384506 = function(new_DASH_bind6354503,A119,l6324504,typ6334505) {
var anf_fun17055407 = G(A119,"s-variant-member",L[658]);
var $z53995400 = D;
var $f54055406 = function(_) {
return R.isFunction(anf_fun17055407)?anf_fun17055407.app(l6324504,typ6334505,new_DASH_bind6354503):R.ffi.throwNonFunApp(L[530],anf_fun17055407,[l6324504,typ6334505,new_DASH_bind6354503]);
};
try {
if(--R.GAS > 0) {
$z53995400 = $f54055406();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54055406,
"from":L[530]});
}
} catch($e53975398) {
if(R.isCont($e53975398)) {
var $ss54015402 = {"from":L[530],
"go":function(ann_DASH_check_DASH_temp16935408) {
return $Hann_DASH_check_DASH_temp29375409(ann_DASH_check_DASH_temp16935408);
}};
$e53975398.stack[R.EXN_STACKHEIGHT++] = $ss54015402;
}
if(R.isPyretException($e53975398)) {
$e53975398.pyretStack.push(L[530]);
}
throw $e53975398;
}
var $ret54035404 = $Hann_DASH_check_DASH_temp29375409($z53995400);
++R.GAS;
return $ret54035404;
};
var $Hann_DASH_check_DASH_temp29375409 = function(ann_DASH_check_DASH_temp16935408) {
return ann_DASH_check_DASH_temp16935408;
};
var $Hatom_DASH_env29364526 = function(atom_DASH_env6404524,A119,ann6394512,l26364509,self6314525,shadows6374510) {
var anf_fun16975423 = G(A119,"s-bind",L[662]);
var anf_arg16985422 = G(atom_DASH_env6404524,"atom",L[661]);
var anf_fun16995420 = G(ann6394512,"visit",L[660]);
var $z54125413 = D;
var $f54185419 = function(_) {
return R.isFunction(anf_fun16995420)?anf_fun16995420.app(self6314525):R.ffi.throwNonFunApp(L[659],anf_fun16995420,[self6314525]);
};
try {
if(--R.GAS > 0) {
$z54125413 = $f54185419();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54185419,
"from":L[659]});
}
} catch($e54105411) {
if(R.isCont($e54105411)) {
var $ss54145415 = {"from":L[659],
"go":function(anf_arg17005421) {
return $Hanf_arg29355424(anf_arg17005421,anf_arg16985422,anf_fun16975423,l26364509,shadows6374510);
}};
$e54105411.stack[R.EXN_STACKHEIGHT++] = $ss54145415;
}
if(R.isPyretException($e54105411)) {
$e54105411.pyretStack.push(L[659]);
}
throw $e54105411;
}
var $ret54165417 = $Hanf_arg29355424($z54125413,anf_arg16985422,anf_fun16975423,l26364509,shadows6374510);
++R.GAS;
return $ret54165417;
};
var $Hanf_arg29355424 = function(anf_arg17005421,anf_arg16985422,anf_fun16975423,l26364509,shadows6374510) {
var $z54275428 = D;
var $f54335434 = function(_) {
return R.isFunction(anf_fun16975423)?anf_fun16975423.app(l26364509,shadows6374510,anf_arg16985422,anf_arg17005421):R.ffi.throwNonFunApp(L[527],anf_fun16975423,[l26364509,shadows6374510,anf_arg16985422,anf_arg17005421]);
};
try {
if(--R.GAS > 0) {
$z54275428 = $f54335434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54335434,
"from":L[527]});
}
} catch($e54255426) {
if(R.isCont($e54255426)) {
var $ss54295430 = {"from":L[527],
"go":function(ann_DASH_check_DASH_temp16955435) {
return $Hann_DASH_check_DASH_temp29345436(ann_DASH_check_DASH_temp16955435);
}};
$e54255426.stack[R.EXN_STACKHEIGHT++] = $ss54295430;
}
if(R.isPyretException($e54255426)) {
$e54255426.pyretStack.push(L[527]);
}
throw $e54255426;
}
var $ret54315432 = $Hann_DASH_check_DASH_temp29345436($z54275428);
++R.GAS;
return $ret54315432;
};
var $Hann_DASH_check_DASH_temp29345436 = function(ann_DASH_check_DASH_temp16955435) {
return ann_DASH_check_DASH_temp16955435;
};
var $Hann_DASH_check_DASH_temp29334543 = function(ann_DASH_check_DASH_temp16904542) {
return ann_DASH_check_DASH_temp16904542;
};
var $Hann_DASH_check_DASH_temp29324559 = function(ann_DASH_check_DASH_temp16874558) {
return ann_DASH_check_DASH_temp16874558;
};
var $Hann_DASH_check_DASH_temp29314576 = function(ann_DASH_check_DASH_temp16844575) {
return ann_DASH_check_DASH_temp16844575;
};
var $Hann_DASH_check_DASH_temp29304592 = function(ann_DASH_check_DASH_temp16494591) {
return ann_DASH_check_DASH_temp16494591;
};
var $Hanf_arg29294605 = function(anf_arg16804604,_plus9,raise14) {
var $z54395440 = D;
var $f54455446 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("Wasn't expecting a non-s-name in resolve-names for assignment: "),anf_arg16804604):R.ffi.throwNonFunApp(L[663],_plus9,[("Wasn't expecting a non-s-name in resolve-names for assignment: "),anf_arg16804604]);
};
try {
if(--R.GAS > 0) {
$z54395440 = $f54455446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54455446,
"from":L[663]});
}
} catch($e54375438) {
if(R.isCont($e54375438)) {
var $ss54415442 = {"from":L[663],
"go":function(anf_arg16815447) {
return $Hanf_arg29285448(anf_arg16815447,raise14);
}};
$e54375438.stack[R.EXN_STACKHEIGHT++] = $ss54415442;
}
if(R.isPyretException($e54375438)) {
$e54375438.pyretStack.push(L[663]);
}
throw $e54375438;
}
var $ret54435444 = $Hanf_arg29285448($z54395440,raise14);
++R.GAS;
return $ret54435444;
};
var $Hanf_arg29285448 = function(anf_arg16815447,raise14) {
var $z54515452 = D;
var $f54575458 = function(_) {
return R.isFunction(raise14)?raise14.app(anf_arg16815447):R.ffi.throwNonFunApp(L[538],raise14,[anf_arg16815447]);
};
try {
if(--R.GAS > 0) {
$z54515452 = $f54575458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54575458,
"from":L[538]});
}
} catch($e54495450) {
if(R.isCont($e54495450)) {
var $ss54535454 = {"from":L[538],
"go":function(ann_DASH_check_DASH_temp16795459) {
return $Hann_DASH_check_DASH_temp29275460(ann_DASH_check_DASH_temp16795459);
}};
$e54495450.stack[R.EXN_STACKHEIGHT++] = $ss54535454;
}
if(R.isPyretException($e54495450)) {
$e54495450.pyretStack.push(L[538]);
}
throw $e54495450;
}
var $ret54555456 = $Hann_DASH_check_DASH_temp29275460($z54515452);
++R.GAS;
return $ret54555456;
};
var $Hann_DASH_check_DASH_temp29275460 = function(ann_DASH_check_DASH_temp16795459) {
return ann_DASH_check_DASH_temp16795459;
};
var $Hanf_arg29264624 = function(anf_arg16764621,anf_fun16744622,id6154603,l6144623) {
var $z54635464 = D;
var $f54695470 = function(_) {
return R.isFunction(anf_fun16744622)?anf_fun16744622.app(l6144623,id6154603,anf_arg16764621):R.ffi.throwNonFunApp(L[540],anf_fun16744622,[l6144623,id6154603,anf_arg16764621]);
};
try {
if(--R.GAS > 0) {
$z54635464 = $f54695470();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54695470,
"from":L[540]});
}
} catch($e54615462) {
if(R.isCont($e54615462)) {
var $ss54655466 = {"from":L[540],
"go":function(ann_DASH_check_DASH_temp16735471) {
return $Hann_DASH_check_DASH_temp29255472(ann_DASH_check_DASH_temp16735471);
}};
$e54615462.stack[R.EXN_STACKHEIGHT++] = $ss54655466;
}
if(R.isPyretException($e54615462)) {
$e54615462.pyretStack.push(L[540]);
}
throw $e54615462;
}
var $ret54675468 = $Hann_DASH_check_DASH_temp29255472($z54635464);
++R.GAS;
return $ret54675468;
};
var $Hann_DASH_check_DASH_temp29255472 = function(ann_DASH_check_DASH_temp16735471) {
return ann_DASH_check_DASH_temp16735471;
};
var $Hif_DASH_29244640 = function(if_DASH_1184639,A119,expr6164625,id6154603,l6144623,s6184627,self6134620) {
var if_helper16545485 = R.makeFunction(function(if_helper_arg16555506) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[545],1,arguments);
}
var ann_DASH_check_DASH_temp16515507 = if_helper_arg16555506;
return ann_DASH_check_DASH_temp16515507;
});
var anf_if16585505 = R.isBoolean(if_DASH_1184639);
if(R.isPyretTrue(anf_if16585505)) {
if(R.isPyretTrue(if_DASH_1184639)) {
var anf_bracket16645487 = G(self6134620,"env",L[666]);
var anf_fun16655483 = G(anf_bracket16645487,"get",L[665]);
var $z54755476 = D;
var $f54815482 = function(_) {
return R.isFunction(anf_fun16655483)?anf_fun16655483.app(s6184627):R.ffi.throwNonFunApp(L[664],anf_fun16655483,[s6184627]);
};
try {
if(--R.GAS > 0) {
$z54755476 = $f54815482();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54815482,
"from":L[664]});
}
} catch($e54735474) {
if(R.isCont($e54735474)) {
var $ss54775478 = {"from":L[664],
"go":function(bind6195484) {
return $Hbind29215486(bind6195484,A119,expr6164625,if_helper16545485,l6144623,self6134620);
}};
$e54735474.stack[R.EXN_STACKHEIGHT++] = $ss54775478;
}
if(R.isPyretException($e54735474)) {
$e54735474.pyretStack.push(L[664]);
}
throw $e54735474;
}
var $ret54795480 = $Hbind29215486($z54755476,A119,expr6164625,if_helper16545485,l6144623,self6134620);
++R.GAS;
return $ret54795480;
} else {
var anf_fun16595500 = G(A119,"s-assign",L[669]);
var anf_fun16605498 = G(expr6164625,"visit",L[668]);
var $z54905491 = D;
var $f54965497 = function(_) {
return R.isFunction(anf_fun16605498)?anf_fun16605498.app(self6134620):R.ffi.throwNonFunApp(L[667],anf_fun16605498,[self6134620]);
};
try {
if(--R.GAS > 0) {
$z54905491 = $f54965497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f54965497,
"from":L[667]});
}
} catch($e54885489) {
if(R.isCont($e54885489)) {
var $ss54925493 = {"from":L[667],
"go":function(anf_arg16615499) {
return $Hanf_arg29235501(anf_arg16615499,anf_fun16595500,id6154603,if_helper16545485,l6144623);
}};
$e54885489.stack[R.EXN_STACKHEIGHT++] = $ss54925493;
}
if(R.isPyretException($e54885489)) {
$e54885489.pyretStack.push(L[667]);
}
throw $e54885489;
}
var $ret54945495 = $Hanf_arg29235501($z54905491,anf_fun16595500,id6154603,if_helper16545485,l6144623);
++R.GAS;
return $ret54945495;
}
} else {
var cont_tail_arg16565504 = R.throwNonBooleanCondition(L[545],("if"),if_DASH_1184639);
if(--R.GAS > 0) {
$z55025503 = R.isFunction(if_helper16545485)?if_helper16545485.app(cont_tail_arg16565504):R.ffi.throwNonFunApp(L[545],if_helper16545485,[cont_tail_arg16565504]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper16545485)?if_helper16545485.app(cont_tail_arg16565504):R.ffi.throwNonFunApp(L[545],if_helper16545485,[cont_tail_arg16565504]);
},
"from":L[545]});
}
++R.GAS;
return $z55025503;
}
};
var $Hbind29215486 = function(bind6195484,A119,expr6164625,if_helper16545485,l6144623,self6134620) {
var anf_fun16665521 = G(A119,"s-assign",L[673]);
var anf_arg16675520 = G(bind6195484,"atom",L[672]);
var anf_fun16685518 = G(expr6164625,"visit",L[671]);
var $z55105511 = D;
var $f55165517 = function(_) {
return R.isFunction(anf_fun16685518)?anf_fun16685518.app(self6134620):R.ffi.throwNonFunApp(L[670],anf_fun16685518,[self6134620]);
};
try {
if(--R.GAS > 0) {
$z55105511 = $f55165517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55165517,
"from":L[670]});
}
} catch($e55085509) {
if(R.isCont($e55085509)) {
var $ss55125513 = {"from":L[670],
"go":function(anf_arg16695519) {
return $Hanf_arg29205522(anf_arg16695519,anf_arg16675520,anf_fun16665521,if_helper16545485,l6144623);
}};
$e55085509.stack[R.EXN_STACKHEIGHT++] = $ss55125513;
}
if(R.isPyretException($e55085509)) {
$e55085509.pyretStack.push(L[670]);
}
throw $e55085509;
}
var $ret55145515 = $Hanf_arg29205522($z55105511,anf_arg16675520,anf_fun16665521,if_helper16545485,l6144623);
++R.GAS;
return $ret55145515;
};
var $Hanf_arg29205522 = function(anf_arg16695519,anf_arg16675520,anf_fun16665521,if_helper16545485,l6144623) {
var $z55255526 = D;
var $f55315532 = function(_) {
return R.isFunction(anf_fun16665521)?anf_fun16665521.app(l6144623,anf_arg16675520,anf_arg16695519):R.ffi.throwNonFunApp(L[674],anf_fun16665521,[l6144623,anf_arg16675520,anf_arg16695519]);
};
try {
if(--R.GAS > 0) {
$z55255526 = $f55315532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55315532,
"from":L[674]});
}
} catch($e55235524) {
if(R.isCont($e55235524)) {
var $ss55275528 = {"from":L[674],
"go":function(cont_tail_arg16705533) {
return $Hcont_tail_arg29195534(cont_tail_arg16705533,if_helper16545485);
}};
$e55235524.stack[R.EXN_STACKHEIGHT++] = $ss55275528;
}
if(R.isPyretException($e55235524)) {
$e55235524.pyretStack.push(L[674]);
}
throw $e55235524;
}
var $ret55295530 = $Hcont_tail_arg29195534($z55255526,if_helper16545485);
++R.GAS;
return $ret55295530;
};
var $Hcont_tail_arg29195534 = function(cont_tail_arg16705533,if_helper16545485) {
if(--R.GAS > 0) {
$z55355536 = R.isFunction(if_helper16545485)?if_helper16545485.app(cont_tail_arg16705533):R.ffi.throwNonFunApp(L[674],if_helper16545485,[cont_tail_arg16705533]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper16545485)?if_helper16545485.app(cont_tail_arg16705533):R.ffi.throwNonFunApp(L[674],if_helper16545485,[cont_tail_arg16705533]);
},
"from":L[674]});
}
++R.GAS;
return $z55355536;
};
var $Hanf_arg29235501 = function(anf_arg16615499,anf_fun16595500,id6154603,if_helper16545485,l6144623) {
var $z55395540 = D;
var $f55455546 = function(_) {
return R.isFunction(anf_fun16595500)?anf_fun16595500.app(l6144623,id6154603,anf_arg16615499):R.ffi.throwNonFunApp(L[675],anf_fun16595500,[l6144623,id6154603,anf_arg16615499]);
};
try {
if(--R.GAS > 0) {
$z55395540 = $f55455546();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55455546,
"from":L[675]});
}
} catch($e55375538) {
if(R.isCont($e55375538)) {
var $ss55415542 = {"from":L[675],
"go":function(cont_tail_arg16625547) {
return $Hcont_tail_arg29225548(cont_tail_arg16625547,if_helper16545485);
}};
$e55375538.stack[R.EXN_STACKHEIGHT++] = $ss55415542;
}
if(R.isPyretException($e55375538)) {
$e55375538.pyretStack.push(L[675]);
}
throw $e55375538;
}
var $ret55435544 = $Hcont_tail_arg29225548($z55395540,if_helper16545485);
++R.GAS;
return $ret55435544;
};
var $Hcont_tail_arg29225548 = function(cont_tail_arg16625547,if_helper16545485) {
if(--R.GAS > 0) {
$z55495550 = R.isFunction(if_helper16545485)?if_helper16545485.app(cont_tail_arg16625547):R.ffi.throwNonFunApp(L[675],if_helper16545485,[cont_tail_arg16625547]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper16545485)?if_helper16545485.app(cont_tail_arg16625547):R.ffi.throwNonFunApp(L[675],if_helper16545485,[cont_tail_arg16625547]);
},
"from":L[675]});
}
++R.GAS;
return $z55495550;
};
var $Hanf_obj29184665 = function(anf_obj16214654,A119,_check5994655,anf_arg16184656,anf_obj16194657,ann5964658,args5954659,body5984660,doc5974661,fold6171,l5934662,map24676,name5944663,self5924664) {
var anf_arg16225561 = R.makeObject({"env":anf_obj16194657,
"atoms":anf_obj16214654});
var $z55535554 = D;
var $f55595560 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg16184656,anf_arg16225561,args5954659):R.ffi.throwNonFunApp(L[676],fold6171,[anf_arg16184656,anf_arg16225561,args5954659]);
};
try {
if(--R.GAS > 0) {
$z55535554 = $f55595560();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55595560,
"from":L[676]});
}
} catch($e55515552) {
if(R.isCont($e55515552)) {
var $ss55555556 = {"from":L[676],
"go":function(env_DASH_and_DASH_atoms6005562) {
return $Henv_DASH_and_DASH_atoms29175563(env_DASH_and_DASH_atoms6005562,A119,_check5994655,ann5964658,args5954659,body5984660,doc5974661,l5934662,map24676,name5944663,self5924664);
}};
$e55515552.stack[R.EXN_STACKHEIGHT++] = $ss55555556;
}
if(R.isPyretException($e55515552)) {
$e55515552.pyretStack.push(L[676]);
}
throw $e55515552;
}
var $ret55575558 = $Henv_DASH_and_DASH_atoms29175563($z55535554,A119,_check5994655,ann5964658,args5954659,body5984660,doc5974661,l5934662,map24676,name5944663,self5924664);
++R.GAS;
return $ret55575558;
};
var $Henv_DASH_and_DASH_atoms29175563 = function(env_DASH_and_DASH_atoms6005562,A119,_check5994655,ann5964658,args5954659,body5984660,doc5974661,l5934662,map24676,name5944663,self5924664) {
var anf_arg16355576 = R.makeFunction(function(a6055579,at6065580) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[680],2,arguments);
}
var cases_DASH_val1175618 = a6055579;
var anf_fun16245591 = G(cases_DASH_val1175618,"_match",L[681]);
var anf_obj16315597 = R.makeFunction(function(l26075598,shadows6085599,id6095600,ann26105601) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[682],4,arguments);
}
var anf_fun16265615 = G(A119,"s-bind",L[686]);
var anf_fun16275612 = G(ann26105601,"visit",L[685]);
var anf_extend16285617 = G(env_DASH_and_DASH_atoms6005562,"env",L[684]);
var anf_arg16295613 = self5924664.extendWith({"env":anf_extend16285617});
var $z56045605 = D;
var $f56105611 = function(_) {
return R.isFunction(anf_fun16275612)?anf_fun16275612.app(anf_arg16295613):R.ffi.throwNonFunApp(L[683],anf_fun16275612,[anf_arg16295613]);
};
try {
if(--R.GAS > 0) {
$z56045605 = $f56105611();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56105611,
"from":L[683]});
}
} catch($e56025603) {
if(R.isCont($e56025603)) {
var $ss56065607 = {"from":L[683],
"go":function(anf_arg16305614) {
return $Hanf_arg29095616(anf_arg16305614,anf_fun16265615,at6065580,l26075598,shadows6085599);
}};
$e56025603.stack[R.EXN_STACKHEIGHT++] = $ss56065607;
}
if(R.isPyretException($e56025603)) {
$e56025603.pyretStack.push(L[683]);
}
throw $e56025603;
}
var $ret56085609 = $Hanf_arg29095616($z56045605,anf_fun16265615,at6065580,l26075598,shadows6085599);
++R.GAS;
return $ret56085609;
});
var anf_arg16325592 = R.makeObject({"s-bind":anf_obj16315597});
var anf_arg16345593 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[681],0,arguments);
}
var ann_DASH_check_DASH_temp16335596 = R.throwNoBranchesMatched(L[681],("cases"));
return ann_DASH_check_DASH_temp16335596;
});
var $z55835584 = D;
var $f55895590 = function(_) {
return R.isFunction(anf_fun16245591)?anf_fun16245591.app(anf_arg16325592,anf_arg16345593):R.ffi.throwNonFunApp(L[680],anf_fun16245591,[anf_arg16325592,anf_arg16345593]);
};
try {
if(--R.GAS > 0) {
$z55835584 = $f55895590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55895590,
"from":L[680]});
}
} catch($e55815582) {
if(R.isCont($e55815582)) {
var $ss55855586 = {"from":L[680],
"go":function(ann_DASH_check_DASH_temp16235594) {
return $Hann_DASH_check_DASH_temp29105595(ann_DASH_check_DASH_temp16235594);
}};
$e55815582.stack[R.EXN_STACKHEIGHT++] = $ss55855586;
}
if(R.isPyretException($e55815582)) {
$e55815582.pyretStack.push(L[680]);
}
throw $e55815582;
}
var $ret55875588 = $Hann_DASH_check_DASH_temp29105595($z55835584);
++R.GAS;
return $ret55875588;
});
var anf_bracket16365578 = G(env_DASH_and_DASH_atoms6005562,"atoms",L[679]);
var anf_fun16375574 = G(anf_bracket16365578,"reverse",L[678]);
var $z55665567 = D;
var $f55725573 = function(_) {
return R.isFunction(anf_fun16375574)?anf_fun16375574.app():R.ffi.throwNonFunApp(L[677],anf_fun16375574,[]);
};
try {
if(--R.GAS > 0) {
$z55665567 = $f55725573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f55725573,
"from":L[677]});
}
} catch($e55645565) {
if(R.isCont($e55645565)) {
var $ss55685569 = {"from":L[677],
"go":function(anf_arg16385575) {
return $Hanf_arg29165577(anf_arg16385575,A119,_check5994655,anf_arg16355576,ann5964658,args5954659,body5984660,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,map24676,name5944663,self5924664);
}};
$e55645565.stack[R.EXN_STACKHEIGHT++] = $ss55685569;
}
if(R.isPyretException($e55645565)) {
$e55645565.pyretStack.push(L[677]);
}
throw $e55645565;
}
var $ret55705571 = $Hanf_arg29165577($z55665567,A119,_check5994655,anf_arg16355576,ann5964658,args5954659,body5984660,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,map24676,name5944663,self5924664);
++R.GAS;
return $ret55705571;
};
var $Hanf_arg29165577 = function(anf_arg16385575,A119,_check5994655,anf_arg16355576,ann5964658,args5954659,body5984660,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,map24676,name5944663,self5924664) {
var $z56215622 = D;
var $f56275628 = function(_) {
return R.isFunction(map24676)?map24676.app(anf_arg16355576,args5954659,anf_arg16385575):R.ffi.throwNonFunApp(L[687],map24676,[anf_arg16355576,args5954659,anf_arg16385575]);
};
try {
if(--R.GAS > 0) {
$z56215622 = $f56275628();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56275628,
"from":L[687]});
}
} catch($e56195620) {
if(R.isCont($e56195620)) {
var $ss56235624 = {"from":L[687],
"go":function(new_DASH_args6045629) {
return $Hnew_DASH_args29155630(new_DASH_args6045629,A119,_check5994655,ann5964658,body5984660,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,self5924664);
}};
$e56195620.stack[R.EXN_STACKHEIGHT++] = $ss56235624;
}
if(R.isPyretException($e56195620)) {
$e56195620.pyretStack.push(L[687]);
}
throw $e56195620;
}
var $ret56255626 = $Hnew_DASH_args29155630($z56215622,A119,_check5994655,ann5964658,body5984660,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,self5924664);
++R.GAS;
return $ret56255626;
};
var $Hnew_DASH_args29155630 = function(new_DASH_args6045629,A119,_check5994655,ann5964658,body5984660,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,self5924664) {
var anf_fun16395641 = G(body5984660,"visit",L[690]);
var anf_extend16405645 = G(env_DASH_and_DASH_atoms6005562,"env",L[689]);
var anf_arg16415642 = self5924664.extendWith({"env":anf_extend16405645});
var $z56335634 = D;
var $f56395640 = function(_) {
return R.isFunction(anf_fun16395641)?anf_fun16395641.app(anf_arg16415642):R.ffi.throwNonFunApp(L[688],anf_fun16395641,[anf_arg16415642]);
};
try {
if(--R.GAS > 0) {
$z56335634 = $f56395640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56395640,
"from":L[688]});
}
} catch($e56315632) {
if(R.isCont($e56315632)) {
var $ss56355636 = {"from":L[688],
"go":function(new_DASH_body6115643) {
return $Hnew_DASH_body29145644(new_DASH_body6115643,A119,_check5994655,ann5964658,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,new_DASH_args6045629,self5924664);
}};
$e56315632.stack[R.EXN_STACKHEIGHT++] = $ss56355636;
}
if(R.isPyretException($e56315632)) {
$e56315632.pyretStack.push(L[688]);
}
throw $e56315632;
}
var $ret56375638 = $Hnew_DASH_body29145644($z56335634,A119,_check5994655,ann5964658,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,new_DASH_args6045629,self5924664);
++R.GAS;
return $ret56375638;
};
var $Hnew_DASH_body29145644 = function(new_DASH_body6115643,A119,_check5994655,ann5964658,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,new_DASH_args6045629,self5924664) {
var anf_fun16425656 = G(self5924664,"option",L[692]);
var $z56485649 = D;
var $f56545655 = function(_) {
return R.isFunction(anf_fun16425656)?anf_fun16425656.app(_check5994655):R.ffi.throwNonFunApp(L[691],anf_fun16425656,[_check5994655]);
};
try {
if(--R.GAS > 0) {
$z56485649 = $f56545655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56545655,
"from":L[691]});
}
} catch($e56465647) {
if(R.isCont($e56465647)) {
var $ss56505651 = {"from":L[691],
"go":function(new_DASH_check6125657) {
return $Hnew_DASH_check29135658(new_DASH_check6125657,A119,ann5964658,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,new_DASH_args6045629,new_DASH_body6115643,self5924664);
}};
$e56465647.stack[R.EXN_STACKHEIGHT++] = $ss56505651;
}
if(R.isPyretException($e56465647)) {
$e56465647.pyretStack.push(L[691]);
}
throw $e56465647;
}
var $ret56525653 = $Hnew_DASH_check29135658($z56485649,A119,ann5964658,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,new_DASH_args6045629,new_DASH_body6115643,self5924664);
++R.GAS;
return $ret56525653;
};
var $Hnew_DASH_check29135658 = function(new_DASH_check6125657,A119,ann5964658,doc5974661,env_DASH_and_DASH_atoms6005562,l5934662,name5944663,new_DASH_args6045629,new_DASH_body6115643,self5924664) {
var anf_fun16435672 = G(A119,"s-method-field",L[696]);
var anf_fun16445669 = G(ann5964658,"visit",L[695]);
var anf_extend16455674 = G(env_DASH_and_DASH_atoms6005562,"env",L[694]);
var anf_arg16465670 = self5924664.extendWith({"env":anf_extend16455674});
var $z56615662 = D;
var $f56675668 = function(_) {
return R.isFunction(anf_fun16445669)?anf_fun16445669.app(anf_arg16465670):R.ffi.throwNonFunApp(L[693],anf_fun16445669,[anf_arg16465670]);
};
try {
if(--R.GAS > 0) {
$z56615662 = $f56675668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56675668,
"from":L[693]});
}
} catch($e56595660) {
if(R.isCont($e56595660)) {
var $ss56635664 = {"from":L[693],
"go":function(anf_arg16475671) {
return $Hanf_arg29125673(anf_arg16475671,anf_fun16435672,doc5974661,l5934662,name5944663,new_DASH_args6045629,new_DASH_body6115643,new_DASH_check6125657);
}};
$e56595660.stack[R.EXN_STACKHEIGHT++] = $ss56635664;
}
if(R.isPyretException($e56595660)) {
$e56595660.pyretStack.push(L[693]);
}
throw $e56595660;
}
var $ret56655666 = $Hanf_arg29125673($z56615662,anf_fun16435672,doc5974661,l5934662,name5944663,new_DASH_args6045629,new_DASH_body6115643,new_DASH_check6125657);
++R.GAS;
return $ret56655666;
};
var $Hanf_arg29125673 = function(anf_arg16475671,anf_fun16435672,doc5974661,l5934662,name5944663,new_DASH_args6045629,new_DASH_body6115643,new_DASH_check6125657) {
var $z56775678 = D;
var $f56835684 = function(_) {
return R.isFunction(anf_fun16435672)?anf_fun16435672.app(l5934662,name5944663,new_DASH_args6045629,anf_arg16475671,doc5974661,new_DASH_body6115643,new_DASH_check6125657):R.ffi.throwNonFunApp(L[555],anf_fun16435672,[l5934662,name5944663,new_DASH_args6045629,anf_arg16475671,doc5974661,new_DASH_body6115643,new_DASH_check6125657]);
};
try {
if(--R.GAS > 0) {
$z56775678 = $f56835684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56835684,
"from":L[555]});
}
} catch($e56755676) {
if(R.isCont($e56755676)) {
var $ss56795680 = {"from":L[555],
"go":function(ann_DASH_check_DASH_temp16095685) {
return $Hann_DASH_check_DASH_temp29115686(ann_DASH_check_DASH_temp16095685);
}};
$e56755676.stack[R.EXN_STACKHEIGHT++] = $ss56795680;
}
if(R.isPyretException($e56755676)) {
$e56755676.pyretStack.push(L[555]);
}
throw $e56755676;
}
var $ret56815682 = $Hann_DASH_check_DASH_temp29115686($z56775678);
++R.GAS;
return $ret56815682;
};
var $Hann_DASH_check_DASH_temp29115686 = function(ann_DASH_check_DASH_temp16095685) {
return ann_DASH_check_DASH_temp16095685;
};
var $Hann_DASH_check_DASH_temp29105595 = function(ann_DASH_check_DASH_temp16235594) {
return ann_DASH_check_DASH_temp16235594;
};
var $Hanf_arg29095616 = function(anf_arg16305614,anf_fun16265615,at6065580,l26075598,shadows6085599) {
var $z56895690 = D;
var $f56955696 = function(_) {
return R.isFunction(anf_fun16265615)?anf_fun16265615.app(l26075598,shadows6085599,at6065580,anf_arg16305614):R.ffi.throwNonFunApp(L[682],anf_fun16265615,[l26075598,shadows6085599,at6065580,anf_arg16305614]);
};
try {
if(--R.GAS > 0) {
$z56895690 = $f56955696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f56955696,
"from":L[682]});
}
} catch($e56875688) {
if(R.isCont($e56875688)) {
var $ss56915692 = {"from":L[682],
"go":function(ann_DASH_check_DASH_temp16255697) {
return $Hann_DASH_check_DASH_temp29085698(ann_DASH_check_DASH_temp16255697);
}};
$e56875688.stack[R.EXN_STACKHEIGHT++] = $ss56915692;
}
if(R.isPyretException($e56875688)) {
$e56875688.pyretStack.push(L[682]);
}
throw $e56875688;
}
var $ret56935694 = $Hann_DASH_check_DASH_temp29085698($z56895690);
++R.GAS;
return $ret56935694;
};
var $Hann_DASH_check_DASH_temp29085698 = function(ann_DASH_check_DASH_temp16255697) {
return ann_DASH_check_DASH_temp16255697;
};
var $Hatom_DASH_env29074682 = function(atom_DASH_env6034681,acc6014666,link3774) {
var anf_obj16145712 = G(atom_DASH_env6034681,"env",L[700]);
var anf_arg16155709 = G(atom_DASH_env6034681,"atom",L[699]);
var anf_arg16165710 = G(acc6014666,"atoms",L[698]);
var $z57015702 = D;
var $f57075708 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg16155709,anf_arg16165710):R.ffi.throwNonFunApp(L[697],link3774,[anf_arg16155709,anf_arg16165710]);
};
try {
if(--R.GAS > 0) {
$z57015702 = $f57075708();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57075708,
"from":L[697]});
}
} catch($e56995700) {
if(R.isCont($e56995700)) {
var $ss57035704 = {"from":L[697],
"go":function(anf_obj16175711) {
return $Hanf_obj29065713(anf_obj16175711,anf_obj16145712);
}};
$e56995700.stack[R.EXN_STACKHEIGHT++] = $ss57035704;
}
if(R.isPyretException($e56995700)) {
$e56995700.pyretStack.push(L[697]);
}
throw $e56995700;
}
var $ret57055706 = $Hanf_obj29065713($z57015702,anf_obj16145712);
++R.GAS;
return $ret57055706;
};
var $Hanf_obj29065713 = function(anf_obj16175711,anf_obj16145712) {
var ann_DASH_check_DASH_temp16105714 = R.makeObject({"env":anf_obj16145712,
"atoms":anf_obj16175711});
return ann_DASH_check_DASH_temp16105714;
};
var $Hanf_obj29054704 = function(anf_obj15814694,A119,_check5784695,anf_arg15784696,anf_obj15794697,ann5754698,args5744699,body5774700,doc5764701,fold6171,l5734702,map24676,self5724703) {
var anf_arg15825725 = R.makeObject({"env":anf_obj15794697,
"atoms":anf_obj15814694});
var $z57175718 = D;
var $f57235724 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg15784696,anf_arg15825725,args5744699):R.ffi.throwNonFunApp(L[701],fold6171,[anf_arg15784696,anf_arg15825725,args5744699]);
};
try {
if(--R.GAS > 0) {
$z57175718 = $f57235724();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57235724,
"from":L[701]});
}
} catch($e57155716) {
if(R.isCont($e57155716)) {
var $ss57195720 = {"from":L[701],
"go":function(env_DASH_and_DASH_atoms5795726) {
return $Henv_DASH_and_DASH_atoms29045727(env_DASH_and_DASH_atoms5795726,A119,_check5784695,ann5754698,args5744699,body5774700,doc5764701,l5734702,map24676,self5724703);
}};
$e57155716.stack[R.EXN_STACKHEIGHT++] = $ss57195720;
}
if(R.isPyretException($e57155716)) {
$e57155716.pyretStack.push(L[701]);
}
throw $e57155716;
}
var $ret57215722 = $Henv_DASH_and_DASH_atoms29045727($z57175718,A119,_check5784695,ann5754698,args5744699,body5774700,doc5764701,l5734702,map24676,self5724703);
++R.GAS;
return $ret57215722;
};
var $Henv_DASH_and_DASH_atoms29045727 = function(env_DASH_and_DASH_atoms5795726,A119,_check5784695,ann5754698,args5744699,body5774700,doc5764701,l5734702,map24676,self5724703) {
var anf_arg15955740 = R.makeFunction(function(a5845743,at5855744) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[705],2,arguments);
}
var cases_DASH_val1165782 = a5845743;
var anf_fun15845755 = G(cases_DASH_val1165782,"_match",L[706]);
var anf_obj15915761 = R.makeFunction(function(l25865762,shadows5875763,id5885764,ann25895765) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[707],4,arguments);
}
var anf_fun15865779 = G(A119,"s-bind",L[711]);
var anf_fun15875776 = G(ann25895765,"visit",L[710]);
var anf_extend15885781 = G(env_DASH_and_DASH_atoms5795726,"env",L[709]);
var anf_arg15895777 = self5724703.extendWith({"env":anf_extend15885781});
var $z57685769 = D;
var $f57745775 = function(_) {
return R.isFunction(anf_fun15875776)?anf_fun15875776.app(anf_arg15895777):R.ffi.throwNonFunApp(L[708],anf_fun15875776,[anf_arg15895777]);
};
try {
if(--R.GAS > 0) {
$z57685769 = $f57745775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57745775,
"from":L[708]});
}
} catch($e57665767) {
if(R.isCont($e57665767)) {
var $ss57705771 = {"from":L[708],
"go":function(anf_arg15905778) {
return $Hanf_arg28965780(anf_arg15905778,anf_fun15865779,at5855744,l25865762,shadows5875763);
}};
$e57665767.stack[R.EXN_STACKHEIGHT++] = $ss57705771;
}
if(R.isPyretException($e57665767)) {
$e57665767.pyretStack.push(L[708]);
}
throw $e57665767;
}
var $ret57725773 = $Hanf_arg28965780($z57685769,anf_fun15865779,at5855744,l25865762,shadows5875763);
++R.GAS;
return $ret57725773;
});
var anf_arg15925756 = R.makeObject({"s-bind":anf_obj15915761});
var anf_arg15945757 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[706],0,arguments);
}
var ann_DASH_check_DASH_temp15935760 = R.throwNoBranchesMatched(L[706],("cases"));
return ann_DASH_check_DASH_temp15935760;
});
var $z57475748 = D;
var $f57535754 = function(_) {
return R.isFunction(anf_fun15845755)?anf_fun15845755.app(anf_arg15925756,anf_arg15945757):R.ffi.throwNonFunApp(L[705],anf_fun15845755,[anf_arg15925756,anf_arg15945757]);
};
try {
if(--R.GAS > 0) {
$z57475748 = $f57535754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57535754,
"from":L[705]});
}
} catch($e57455746) {
if(R.isCont($e57455746)) {
var $ss57495750 = {"from":L[705],
"go":function(ann_DASH_check_DASH_temp15835758) {
return $Hann_DASH_check_DASH_temp28975759(ann_DASH_check_DASH_temp15835758);
}};
$e57455746.stack[R.EXN_STACKHEIGHT++] = $ss57495750;
}
if(R.isPyretException($e57455746)) {
$e57455746.pyretStack.push(L[705]);
}
throw $e57455746;
}
var $ret57515752 = $Hann_DASH_check_DASH_temp28975759($z57475748);
++R.GAS;
return $ret57515752;
});
var anf_bracket15965742 = G(env_DASH_and_DASH_atoms5795726,"atoms",L[704]);
var anf_fun15975738 = G(anf_bracket15965742,"reverse",L[703]);
var $z57305731 = D;
var $f57365737 = function(_) {
return R.isFunction(anf_fun15975738)?anf_fun15975738.app():R.ffi.throwNonFunApp(L[702],anf_fun15975738,[]);
};
try {
if(--R.GAS > 0) {
$z57305731 = $f57365737();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57365737,
"from":L[702]});
}
} catch($e57285729) {
if(R.isCont($e57285729)) {
var $ss57325733 = {"from":L[702],
"go":function(anf_arg15985739) {
return $Hanf_arg29035741(anf_arg15985739,A119,_check5784695,anf_arg15955740,ann5754698,args5744699,body5774700,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,map24676,self5724703);
}};
$e57285729.stack[R.EXN_STACKHEIGHT++] = $ss57325733;
}
if(R.isPyretException($e57285729)) {
$e57285729.pyretStack.push(L[702]);
}
throw $e57285729;
}
var $ret57345735 = $Hanf_arg29035741($z57305731,A119,_check5784695,anf_arg15955740,ann5754698,args5744699,body5774700,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,map24676,self5724703);
++R.GAS;
return $ret57345735;
};
var $Hanf_arg29035741 = function(anf_arg15985739,A119,_check5784695,anf_arg15955740,ann5754698,args5744699,body5774700,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,map24676,self5724703) {
var $z57855786 = D;
var $f57915792 = function(_) {
return R.isFunction(map24676)?map24676.app(anf_arg15955740,args5744699,anf_arg15985739):R.ffi.throwNonFunApp(L[712],map24676,[anf_arg15955740,args5744699,anf_arg15985739]);
};
try {
if(--R.GAS > 0) {
$z57855786 = $f57915792();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f57915792,
"from":L[712]});
}
} catch($e57835784) {
if(R.isCont($e57835784)) {
var $ss57875788 = {"from":L[712],
"go":function(new_DASH_args5835793) {
return $Hnew_DASH_args29025794(new_DASH_args5835793,A119,_check5784695,ann5754698,body5774700,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,self5724703);
}};
$e57835784.stack[R.EXN_STACKHEIGHT++] = $ss57875788;
}
if(R.isPyretException($e57835784)) {
$e57835784.pyretStack.push(L[712]);
}
throw $e57835784;
}
var $ret57895790 = $Hnew_DASH_args29025794($z57855786,A119,_check5784695,ann5754698,body5774700,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,self5724703);
++R.GAS;
return $ret57895790;
};
var $Hnew_DASH_args29025794 = function(new_DASH_args5835793,A119,_check5784695,ann5754698,body5774700,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,self5724703) {
var anf_fun15995805 = G(body5774700,"visit",L[715]);
var anf_extend16005809 = G(env_DASH_and_DASH_atoms5795726,"env",L[714]);
var anf_arg16015806 = self5724703.extendWith({"env":anf_extend16005809});
var $z57975798 = D;
var $f58035804 = function(_) {
return R.isFunction(anf_fun15995805)?anf_fun15995805.app(anf_arg16015806):R.ffi.throwNonFunApp(L[713],anf_fun15995805,[anf_arg16015806]);
};
try {
if(--R.GAS > 0) {
$z57975798 = $f58035804();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58035804,
"from":L[713]});
}
} catch($e57955796) {
if(R.isCont($e57955796)) {
var $ss57995800 = {"from":L[713],
"go":function(new_DASH_body5905807) {
return $Hnew_DASH_body29015808(new_DASH_body5905807,A119,_check5784695,ann5754698,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,new_DASH_args5835793,self5724703);
}};
$e57955796.stack[R.EXN_STACKHEIGHT++] = $ss57995800;
}
if(R.isPyretException($e57955796)) {
$e57955796.pyretStack.push(L[713]);
}
throw $e57955796;
}
var $ret58015802 = $Hnew_DASH_body29015808($z57975798,A119,_check5784695,ann5754698,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,new_DASH_args5835793,self5724703);
++R.GAS;
return $ret58015802;
};
var $Hnew_DASH_body29015808 = function(new_DASH_body5905807,A119,_check5784695,ann5754698,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,new_DASH_args5835793,self5724703) {
var anf_fun16025820 = G(self5724703,"option",L[717]);
var $z58125813 = D;
var $f58185819 = function(_) {
return R.isFunction(anf_fun16025820)?anf_fun16025820.app(_check5784695):R.ffi.throwNonFunApp(L[716],anf_fun16025820,[_check5784695]);
};
try {
if(--R.GAS > 0) {
$z58125813 = $f58185819();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58185819,
"from":L[716]});
}
} catch($e58105811) {
if(R.isCont($e58105811)) {
var $ss58145815 = {"from":L[716],
"go":function(new_DASH_check5915821) {
return $Hnew_DASH_check29005822(new_DASH_check5915821,A119,ann5754698,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,new_DASH_args5835793,new_DASH_body5905807,self5724703);
}};
$e58105811.stack[R.EXN_STACKHEIGHT++] = $ss58145815;
}
if(R.isPyretException($e58105811)) {
$e58105811.pyretStack.push(L[716]);
}
throw $e58105811;
}
var $ret58165817 = $Hnew_DASH_check29005822($z58125813,A119,ann5754698,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,new_DASH_args5835793,new_DASH_body5905807,self5724703);
++R.GAS;
return $ret58165817;
};
var $Hnew_DASH_check29005822 = function(new_DASH_check5915821,A119,ann5754698,doc5764701,env_DASH_and_DASH_atoms5795726,l5734702,new_DASH_args5835793,new_DASH_body5905807,self5724703) {
var anf_fun16035836 = G(A119,"s-method",L[721]);
var anf_fun16045833 = G(ann5754698,"visit",L[720]);
var anf_extend16055838 = G(env_DASH_and_DASH_atoms5795726,"env",L[719]);
var anf_arg16065834 = self5724703.extendWith({"env":anf_extend16055838});
var $z58255826 = D;
var $f58315832 = function(_) {
return R.isFunction(anf_fun16045833)?anf_fun16045833.app(anf_arg16065834):R.ffi.throwNonFunApp(L[718],anf_fun16045833,[anf_arg16065834]);
};
try {
if(--R.GAS > 0) {
$z58255826 = $f58315832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58315832,
"from":L[718]});
}
} catch($e58235824) {
if(R.isCont($e58235824)) {
var $ss58275828 = {"from":L[718],
"go":function(anf_arg16075835) {
return $Hanf_arg28995837(anf_arg16075835,anf_fun16035836,doc5764701,l5734702,new_DASH_args5835793,new_DASH_body5905807,new_DASH_check5915821);
}};
$e58235824.stack[R.EXN_STACKHEIGHT++] = $ss58275828;
}
if(R.isPyretException($e58235824)) {
$e58235824.pyretStack.push(L[718]);
}
throw $e58235824;
}
var $ret58295830 = $Hanf_arg28995837($z58255826,anf_fun16035836,doc5764701,l5734702,new_DASH_args5835793,new_DASH_body5905807,new_DASH_check5915821);
++R.GAS;
return $ret58295830;
};
var $Hanf_arg28995837 = function(anf_arg16075835,anf_fun16035836,doc5764701,l5734702,new_DASH_args5835793,new_DASH_body5905807,new_DASH_check5915821) {
var $z58415842 = D;
var $f58475848 = function(_) {
return R.isFunction(anf_fun16035836)?anf_fun16035836.app(l5734702,new_DASH_args5835793,anf_arg16075835,doc5764701,new_DASH_body5905807,new_DASH_check5915821):R.ffi.throwNonFunApp(L[563],anf_fun16035836,[l5734702,new_DASH_args5835793,anf_arg16075835,doc5764701,new_DASH_body5905807,new_DASH_check5915821]);
};
try {
if(--R.GAS > 0) {
$z58415842 = $f58475848();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58475848,
"from":L[563]});
}
} catch($e58395840) {
if(R.isCont($e58395840)) {
var $ss58435844 = {"from":L[563],
"go":function(ann_DASH_check_DASH_temp15695849) {
return $Hann_DASH_check_DASH_temp28985850(ann_DASH_check_DASH_temp15695849);
}};
$e58395840.stack[R.EXN_STACKHEIGHT++] = $ss58435844;
}
if(R.isPyretException($e58395840)) {
$e58395840.pyretStack.push(L[563]);
}
throw $e58395840;
}
var $ret58455846 = $Hann_DASH_check_DASH_temp28985850($z58415842);
++R.GAS;
return $ret58455846;
};
var $Hann_DASH_check_DASH_temp28985850 = function(ann_DASH_check_DASH_temp15695849) {
return ann_DASH_check_DASH_temp15695849;
};
var $Hann_DASH_check_DASH_temp28975759 = function(ann_DASH_check_DASH_temp15835758) {
return ann_DASH_check_DASH_temp15835758;
};
var $Hanf_arg28965780 = function(anf_arg15905778,anf_fun15865779,at5855744,l25865762,shadows5875763) {
var $z58535854 = D;
var $f58595860 = function(_) {
return R.isFunction(anf_fun15865779)?anf_fun15865779.app(l25865762,shadows5875763,at5855744,anf_arg15905778):R.ffi.throwNonFunApp(L[707],anf_fun15865779,[l25865762,shadows5875763,at5855744,anf_arg15905778]);
};
try {
if(--R.GAS > 0) {
$z58535854 = $f58595860();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58595860,
"from":L[707]});
}
} catch($e58515852) {
if(R.isCont($e58515852)) {
var $ss58555856 = {"from":L[707],
"go":function(ann_DASH_check_DASH_temp15855861) {
return $Hann_DASH_check_DASH_temp28955862(ann_DASH_check_DASH_temp15855861);
}};
$e58515852.stack[R.EXN_STACKHEIGHT++] = $ss58555856;
}
if(R.isPyretException($e58515852)) {
$e58515852.pyretStack.push(L[707]);
}
throw $e58515852;
}
var $ret58575858 = $Hann_DASH_check_DASH_temp28955862($z58535854);
++R.GAS;
return $ret58575858;
};
var $Hann_DASH_check_DASH_temp28955862 = function(ann_DASH_check_DASH_temp15855861) {
return ann_DASH_check_DASH_temp15855861;
};
var $Hatom_DASH_env28944721 = function(atom_DASH_env5824720,acc5804705,link3774) {
var anf_obj15745876 = G(atom_DASH_env5824720,"env",L[725]);
var anf_arg15755873 = G(atom_DASH_env5824720,"atom",L[724]);
var anf_arg15765874 = G(acc5804705,"atoms",L[723]);
var $z58655866 = D;
var $f58715872 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg15755873,anf_arg15765874):R.ffi.throwNonFunApp(L[722],link3774,[anf_arg15755873,anf_arg15765874]);
};
try {
if(--R.GAS > 0) {
$z58655866 = $f58715872();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58715872,
"from":L[722]});
}
} catch($e58635864) {
if(R.isCont($e58635864)) {
var $ss58675868 = {"from":L[722],
"go":function(anf_obj15775875) {
return $Hanf_obj28935877(anf_obj15775875,anf_obj15745876);
}};
$e58635864.stack[R.EXN_STACKHEIGHT++] = $ss58675868;
}
if(R.isPyretException($e58635864)) {
$e58635864.pyretStack.push(L[722]);
}
throw $e58635864;
}
var $ret58695870 = $Hanf_obj28935877($z58655866,anf_obj15745876);
++R.GAS;
return $ret58695870;
};
var $Hanf_obj28935877 = function(anf_obj15775875,anf_obj15745876) {
var ann_DASH_check_DASH_temp15705878 = R.makeObject({"env":anf_obj15745876,
"atoms":anf_obj15775875});
return ann_DASH_check_DASH_temp15705878;
};
var $Hnew_DASH_types28924743 = function(new_DASH_types5534735,A119,_check5524736,ann5494737,args5484738,bindings3463955,body5514739,doc5504740,fold6171,l5464741,let_DASH_bind29398,link3774,list3375,make_DASH_atom_DASH_for3483971,map24676,self5454742) {
var anf_extend15315912 = G(new_DASH_types5534735,"env",L[733]);
var with_DASH_params5575893 = self5454742.extendWith({"type-env":anf_extend15315912});
var anf_arg15405891 = R.makeFunction(function(acc5595895,a5605896) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[728],2,arguments);
}
var anf_arg15335907 = G(a5605896,"id",L[732]);
var anf_arg15345908 = G(a5605896,"shadows",L[731]);
var anf_arg15355909 = G(acc5595895,"env",L[730]);
var $z58995900 = D;
var $f59055906 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(anf_arg15335907,anf_arg15345908,anf_arg15355909,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[729],make_DASH_atom_DASH_for3483971.$var,[anf_arg15335907,anf_arg15345908,anf_arg15355909,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z58995900 = $f59055906();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59055906,
"from":L[729]});
}
} catch($e58975898) {
if(R.isCont($e58975898)) {
var $ss59015902 = {"from":L[729],
"go":function(atom_DASH_env5615910) {
return $Hatom_DASH_env28795911(atom_DASH_env5615910,acc5595895,link3774);
}};
$e58975898.stack[R.EXN_STACKHEIGHT++] = $ss59015902;
}
if(R.isPyretException($e58975898)) {
$e58975898.pyretStack.push(L[729]);
}
throw $e58975898;
}
var $ret59035904 = $Hatom_DASH_env28795911($z58995900,acc5595895,link3774);
++R.GAS;
return $ret59035904;
});
var anf_obj15415892 = G(with_DASH_params5575893,"env",L[727]);
var anf_fun15425889 = G(list3375,"make",L[726]);
var $z58815882 = D;
var $f58875888 = function(_) {
return R.isFunction(anf_fun15425889)?anf_fun15425889.app([]):R.ffi.throwNonFunApp(L[726],anf_fun15425889,[[]]);
};
try {
if(--R.GAS > 0) {
$z58815882 = $f58875888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f58875888,
"from":L[726]});
}
} catch($e58795880) {
if(R.isCont($e58795880)) {
var $ss58835884 = {"from":L[726],
"go":function(anf_obj15435890) {
return $Hanf_obj28915894(anf_obj15435890,A119,_check5524736,anf_arg15405891,anf_obj15415892,ann5494737,args5484738,body5514739,doc5504740,fold6171,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893);
}};
$e58795880.stack[R.EXN_STACKHEIGHT++] = $ss58835884;
}
if(R.isPyretException($e58795880)) {
$e58795880.pyretStack.push(L[726]);
}
throw $e58795880;
}
var $ret58855886 = $Hanf_obj28915894($z58815882,A119,_check5524736,anf_arg15405891,anf_obj15415892,ann5494737,args5484738,body5514739,doc5504740,fold6171,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893);
++R.GAS;
return $ret58855886;
};
var $Hanf_obj28915894 = function(anf_obj15435890,A119,_check5524736,anf_arg15405891,anf_obj15415892,ann5494737,args5484738,body5514739,doc5504740,fold6171,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893) {
var anf_arg15445923 = R.makeObject({"env":anf_obj15415892,
"atoms":anf_obj15435890});
var $z59155916 = D;
var $f59215922 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg15405891,anf_arg15445923,args5484738):R.ffi.throwNonFunApp(L[734],fold6171,[anf_arg15405891,anf_arg15445923,args5484738]);
};
try {
if(--R.GAS > 0) {
$z59155916 = $f59215922();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59215922,
"from":L[734]});
}
} catch($e59135914) {
if(R.isCont($e59135914)) {
var $ss59175918 = {"from":L[734],
"go":function(env_DASH_and_DASH_atoms5585924) {
return $Henv_DASH_and_DASH_atoms28905925(env_DASH_and_DASH_atoms5585924,A119,_check5524736,ann5494737,args5484738,body5514739,doc5504740,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893);
}};
$e59135914.stack[R.EXN_STACKHEIGHT++] = $ss59175918;
}
if(R.isPyretException($e59135914)) {
$e59135914.pyretStack.push(L[734]);
}
throw $e59135914;
}
var $ret59195920 = $Henv_DASH_and_DASH_atoms28905925($z59155916,A119,_check5524736,ann5494737,args5484738,body5514739,doc5504740,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893);
++R.GAS;
return $ret59195920;
};
var $Henv_DASH_and_DASH_atoms28905925 = function(env_DASH_and_DASH_atoms5585924,A119,_check5524736,ann5494737,args5484738,body5514739,doc5504740,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893) {
var anf_arg15555938 = R.makeFunction(function(a5635941,at5645942) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[738],2,arguments);
}
var cases_DASH_val1155978 = a5635941;
var anf_fun15465953 = G(cases_DASH_val1155978,"_match",L[739]);
var anf_obj15515959 = R.makeFunction(function(l25655960,shadows5665961,id5675962,ann25685963) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[740],4,arguments);
}
var anf_fun15485976 = G(A119,"s-bind",L[743]);
var anf_fun15495974 = G(ann25685963,"visit",L[742]);
var $z59665967 = D;
var $f59725973 = function(_) {
return R.isFunction(anf_fun15495974)?anf_fun15495974.app(with_DASH_params5575893):R.ffi.throwNonFunApp(L[741],anf_fun15495974,[with_DASH_params5575893]);
};
try {
if(--R.GAS > 0) {
$z59665967 = $f59725973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59725973,
"from":L[741]});
}
} catch($e59645965) {
if(R.isCont($e59645965)) {
var $ss59685969 = {"from":L[741],
"go":function(anf_arg15505975) {
return $Hanf_arg28815977(anf_arg15505975,anf_fun15485976,at5645942,l25655960);
}};
$e59645965.stack[R.EXN_STACKHEIGHT++] = $ss59685969;
}
if(R.isPyretException($e59645965)) {
$e59645965.pyretStack.push(L[741]);
}
throw $e59645965;
}
var $ret59705971 = $Hanf_arg28815977($z59665967,anf_fun15485976,at5645942,l25655960);
++R.GAS;
return $ret59705971;
});
var anf_arg15525954 = R.makeObject({"s-bind":anf_obj15515959});
var anf_arg15545955 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[739],0,arguments);
}
var ann_DASH_check_DASH_temp15535958 = R.throwNoBranchesMatched(L[739],("cases"));
return ann_DASH_check_DASH_temp15535958;
});
var $z59455946 = D;
var $f59515952 = function(_) {
return R.isFunction(anf_fun15465953)?anf_fun15465953.app(anf_arg15525954,anf_arg15545955):R.ffi.throwNonFunApp(L[738],anf_fun15465953,[anf_arg15525954,anf_arg15545955]);
};
try {
if(--R.GAS > 0) {
$z59455946 = $f59515952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59515952,
"from":L[738]});
}
} catch($e59435944) {
if(R.isCont($e59435944)) {
var $ss59475948 = {"from":L[738],
"go":function(ann_DASH_check_DASH_temp15455956) {
return $Hann_DASH_check_DASH_temp28825957(ann_DASH_check_DASH_temp15455956);
}};
$e59435944.stack[R.EXN_STACKHEIGHT++] = $ss59475948;
}
if(R.isPyretException($e59435944)) {
$e59435944.pyretStack.push(L[738]);
}
throw $e59435944;
}
var $ret59495950 = $Hann_DASH_check_DASH_temp28825957($z59455946);
++R.GAS;
return $ret59495950;
});
var anf_bracket15565940 = G(env_DASH_and_DASH_atoms5585924,"atoms",L[737]);
var anf_fun15575936 = G(anf_bracket15565940,"reverse",L[736]);
var $z59285929 = D;
var $f59345935 = function(_) {
return R.isFunction(anf_fun15575936)?anf_fun15575936.app():R.ffi.throwNonFunApp(L[735],anf_fun15575936,[]);
};
try {
if(--R.GAS > 0) {
$z59285929 = $f59345935();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59345935,
"from":L[735]});
}
} catch($e59265927) {
if(R.isCont($e59265927)) {
var $ss59305931 = {"from":L[735],
"go":function(anf_arg15585937) {
return $Hanf_arg28895939(anf_arg15585937,A119,_check5524736,anf_arg15555938,ann5494737,args5484738,body5514739,doc5504740,env_DASH_and_DASH_atoms5585924,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893);
}};
$e59265927.stack[R.EXN_STACKHEIGHT++] = $ss59305931;
}
if(R.isPyretException($e59265927)) {
$e59265927.pyretStack.push(L[735]);
}
throw $e59265927;
}
var $ret59325933 = $Hanf_arg28895939($z59285929,A119,_check5524736,anf_arg15555938,ann5494737,args5484738,body5514739,doc5504740,env_DASH_and_DASH_atoms5585924,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893);
++R.GAS;
return $ret59325933;
};
var $Hanf_arg28895939 = function(anf_arg15585937,A119,_check5524736,anf_arg15555938,ann5494737,args5484738,body5514739,doc5504740,env_DASH_and_DASH_atoms5585924,l5464741,map24676,new_DASH_types5534735,with_DASH_params5575893) {
var $z59815982 = D;
var $f59875988 = function(_) {
return R.isFunction(map24676)?map24676.app(anf_arg15555938,args5484738,anf_arg15585937):R.ffi.throwNonFunApp(L[744],map24676,[anf_arg15555938,args5484738,anf_arg15585937]);
};
try {
if(--R.GAS > 0) {
$z59815982 = $f59875988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59875988,
"from":L[744]});
}
} catch($e59795980) {
if(R.isCont($e59795980)) {
var $ss59835984 = {"from":L[744],
"go":function(new_DASH_args5625989) {
return $Hnew_DASH_args28885990(new_DASH_args5625989,A119,_check5524736,ann5494737,body5514739,doc5504740,env_DASH_and_DASH_atoms5585924,l5464741,new_DASH_types5534735,with_DASH_params5575893);
}};
$e59795980.stack[R.EXN_STACKHEIGHT++] = $ss59835984;
}
if(R.isPyretException($e59795980)) {
$e59795980.pyretStack.push(L[744]);
}
throw $e59795980;
}
var $ret59855986 = $Hnew_DASH_args28885990($z59815982,A119,_check5524736,ann5494737,body5514739,doc5504740,env_DASH_and_DASH_atoms5585924,l5464741,new_DASH_types5534735,with_DASH_params5575893);
++R.GAS;
return $ret59855986;
};
var $Hnew_DASH_args28885990 = function(new_DASH_args5625989,A119,_check5524736,ann5494737,body5514739,doc5504740,env_DASH_and_DASH_atoms5585924,l5464741,new_DASH_types5534735,with_DASH_params5575893) {
var anf_extend15596005 = G(env_DASH_and_DASH_atoms5585924,"env",L[747]);
var with_DASH_params_DASH_and_DASH_args5696002 = with_DASH_params5575893.extendWith({"env":anf_extend15596005});
var anf_fun15606001 = G(body5514739,"visit",L[746]);
var $z59935994 = D;
var $f59996000 = function(_) {
return R.isFunction(anf_fun15606001)?anf_fun15606001.app(with_DASH_params_DASH_and_DASH_args5696002):R.ffi.throwNonFunApp(L[745],anf_fun15606001,[with_DASH_params_DASH_and_DASH_args5696002]);
};
try {
if(--R.GAS > 0) {
$z59935994 = $f59996000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f59996000,
"from":L[745]});
}
} catch($e59915992) {
if(R.isCont($e59915992)) {
var $ss59955996 = {"from":L[745],
"go":function(new_DASH_body5706003) {
return $Hnew_DASH_body28876004(new_DASH_body5706003,A119,_check5524736,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_types5534735,with_DASH_params5575893);
}};
$e59915992.stack[R.EXN_STACKHEIGHT++] = $ss59955996;
}
if(R.isPyretException($e59915992)) {
$e59915992.pyretStack.push(L[745]);
}
throw $e59915992;
}
var $ret59975998 = $Hnew_DASH_body28876004($z59935994,A119,_check5524736,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_types5534735,with_DASH_params5575893);
++R.GAS;
return $ret59975998;
};
var $Hnew_DASH_body28876004 = function(new_DASH_body5706003,A119,_check5524736,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_types5534735,with_DASH_params5575893) {
var anf_fun15616016 = G(with_DASH_params5575893,"option",L[749]);
var $z60086009 = D;
var $f60146015 = function(_) {
return R.isFunction(anf_fun15616016)?anf_fun15616016.app(_check5524736):R.ffi.throwNonFunApp(L[748],anf_fun15616016,[_check5524736]);
};
try {
if(--R.GAS > 0) {
$z60086009 = $f60146015();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60146015,
"from":L[748]});
}
} catch($e60066007) {
if(R.isCont($e60066007)) {
var $ss60106011 = {"from":L[748],
"go":function(new_DASH_check5716017) {
return $Hnew_DASH_check28866018(new_DASH_check5716017,A119,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_types5534735,with_DASH_params5575893);
}};
$e60066007.stack[R.EXN_STACKHEIGHT++] = $ss60106011;
}
if(R.isPyretException($e60066007)) {
$e60066007.pyretStack.push(L[748]);
}
throw $e60066007;
}
var $ret60126013 = $Hnew_DASH_check28866018($z60086009,A119,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_types5534735,with_DASH_params5575893);
++R.GAS;
return $ret60126013;
};
var $Hnew_DASH_check28866018 = function(new_DASH_check5716017,A119,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_types5534735,with_DASH_params5575893) {
var anf_fun15626031 = G(A119,"s-lam",L[753]);
var anf_bracket15636033 = G(new_DASH_types5534735,"atoms",L[752]);
var anf_fun15646029 = G(anf_bracket15636033,"reverse",L[751]);
var $z60216022 = D;
var $f60276028 = function(_) {
return R.isFunction(anf_fun15646029)?anf_fun15646029.app():R.ffi.throwNonFunApp(L[750],anf_fun15646029,[]);
};
try {
if(--R.GAS > 0) {
$z60216022 = $f60276028();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60276028,
"from":L[750]});
}
} catch($e60196020) {
if(R.isCont($e60196020)) {
var $ss60236024 = {"from":L[750],
"go":function(anf_arg15656030) {
return $Hanf_arg28856032(anf_arg15656030,anf_fun15626031,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_check5716017,with_DASH_params5575893);
}};
$e60196020.stack[R.EXN_STACKHEIGHT++] = $ss60236024;
}
if(R.isPyretException($e60196020)) {
$e60196020.pyretStack.push(L[750]);
}
throw $e60196020;
}
var $ret60256026 = $Hanf_arg28856032($z60216022,anf_fun15626031,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_check5716017,with_DASH_params5575893);
++R.GAS;
return $ret60256026;
};
var $Hanf_arg28856032 = function(anf_arg15656030,anf_fun15626031,ann5494737,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_check5716017,with_DASH_params5575893) {
var anf_fun15666044 = G(ann5494737,"visit",L[755]);
var $z60366037 = D;
var $f60426043 = function(_) {
return R.isFunction(anf_fun15666044)?anf_fun15666044.app(with_DASH_params5575893):R.ffi.throwNonFunApp(L[754],anf_fun15666044,[with_DASH_params5575893]);
};
try {
if(--R.GAS > 0) {
$z60366037 = $f60426043();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60426043,
"from":L[754]});
}
} catch($e60346035) {
if(R.isCont($e60346035)) {
var $ss60386039 = {"from":L[754],
"go":function(anf_arg15676045) {
return $Hanf_arg28846046(anf_arg15676045,anf_arg15656030,anf_fun15626031,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_check5716017);
}};
$e60346035.stack[R.EXN_STACKHEIGHT++] = $ss60386039;
}
if(R.isPyretException($e60346035)) {
$e60346035.pyretStack.push(L[754]);
}
throw $e60346035;
}
var $ret60406041 = $Hanf_arg28846046($z60366037,anf_arg15656030,anf_fun15626031,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_check5716017);
++R.GAS;
return $ret60406041;
};
var $Hanf_arg28846046 = function(anf_arg15676045,anf_arg15656030,anf_fun15626031,doc5504740,l5464741,new_DASH_args5625989,new_DASH_body5706003,new_DASH_check5716017) {
var $z60496050 = D;
var $f60556056 = function(_) {
return R.isFunction(anf_fun15626031)?anf_fun15626031.app(l5464741,anf_arg15656030,new_DASH_args5625989,anf_arg15676045,doc5504740,new_DASH_body5706003,new_DASH_check5716017):R.ffi.throwNonFunApp(L[569],anf_fun15626031,[l5464741,anf_arg15656030,new_DASH_args5625989,anf_arg15676045,doc5504740,new_DASH_body5706003,new_DASH_check5716017]);
};
try {
if(--R.GAS > 0) {
$z60496050 = $f60556056();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60556056,
"from":L[569]});
}
} catch($e60476048) {
if(R.isCont($e60476048)) {
var $ss60516052 = {"from":L[569],
"go":function(ann_DASH_check_DASH_temp15216057) {
return $Hann_DASH_check_DASH_temp28836058(ann_DASH_check_DASH_temp15216057);
}};
$e60476048.stack[R.EXN_STACKHEIGHT++] = $ss60516052;
}
if(R.isPyretException($e60476048)) {
$e60476048.pyretStack.push(L[569]);
}
throw $e60476048;
}
var $ret60536054 = $Hann_DASH_check_DASH_temp28836058($z60496050);
++R.GAS;
return $ret60536054;
};
var $Hann_DASH_check_DASH_temp28836058 = function(ann_DASH_check_DASH_temp15216057) {
return ann_DASH_check_DASH_temp15216057;
};
var $Hann_DASH_check_DASH_temp28825957 = function(ann_DASH_check_DASH_temp15455956) {
return ann_DASH_check_DASH_temp15455956;
};
var $Hanf_arg28815977 = function(anf_arg15505975,anf_fun15485976,at5645942,l25655960) {
var $z60616062 = D;
var $f60676068 = function(_) {
return R.isFunction(anf_fun15485976)?anf_fun15485976.app(l25655960,(false),at5645942,anf_arg15505975):R.ffi.throwNonFunApp(L[740],anf_fun15485976,[l25655960,(false),at5645942,anf_arg15505975]);
};
try {
if(--R.GAS > 0) {
$z60616062 = $f60676068();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60676068,
"from":L[740]});
}
} catch($e60596060) {
if(R.isCont($e60596060)) {
var $ss60636064 = {"from":L[740],
"go":function(ann_DASH_check_DASH_temp15476069) {
return $Hann_DASH_check_DASH_temp28806070(ann_DASH_check_DASH_temp15476069);
}};
$e60596060.stack[R.EXN_STACKHEIGHT++] = $ss60636064;
}
if(R.isPyretException($e60596060)) {
$e60596060.pyretStack.push(L[740]);
}
throw $e60596060;
}
var $ret60656066 = $Hann_DASH_check_DASH_temp28806070($z60616062);
++R.GAS;
return $ret60656066;
};
var $Hann_DASH_check_DASH_temp28806070 = function(ann_DASH_check_DASH_temp15476069) {
return ann_DASH_check_DASH_temp15476069;
};
var $Hatom_DASH_env28795911 = function(atom_DASH_env5615910,acc5595895,link3774) {
var anf_obj15366084 = G(atom_DASH_env5615910,"env",L[759]);
var anf_arg15376081 = G(atom_DASH_env5615910,"atom",L[758]);
var anf_arg15386082 = G(acc5595895,"atoms",L[757]);
var $z60736074 = D;
var $f60796080 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg15376081,anf_arg15386082):R.ffi.throwNonFunApp(L[756],link3774,[anf_arg15376081,anf_arg15386082]);
};
try {
if(--R.GAS > 0) {
$z60736074 = $f60796080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60796080,
"from":L[756]});
}
} catch($e60716072) {
if(R.isCont($e60716072)) {
var $ss60756076 = {"from":L[756],
"go":function(anf_obj15396083) {
return $Hanf_obj28786085(anf_obj15396083,anf_obj15366084);
}};
$e60716072.stack[R.EXN_STACKHEIGHT++] = $ss60756076;
}
if(R.isPyretException($e60716072)) {
$e60716072.pyretStack.push(L[756]);
}
throw $e60716072;
}
var $ret60776078 = $Hanf_obj28786085($z60736074,anf_obj15366084);
++R.GAS;
return $ret60776078;
};
var $Hanf_obj28786085 = function(anf_obj15396083,anf_obj15366084) {
var ann_DASH_check_DASH_temp15326086 = R.makeObject({"env":anf_obj15366084,
"atoms":anf_obj15396083});
return ann_DASH_check_DASH_temp15326086;
};
var $Hatom_DASH_env28774759 = function(atom_DASH_env5564758,acc5544745,link3774) {
var anf_obj15246100 = G(atom_DASH_env5564758,"env",L[763]);
var anf_arg15256097 = G(atom_DASH_env5564758,"atom",L[762]);
var anf_arg15266098 = G(acc5544745,"atoms",L[761]);
var $z60896090 = D;
var $f60956096 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg15256097,anf_arg15266098):R.ffi.throwNonFunApp(L[760],link3774,[anf_arg15256097,anf_arg15266098]);
};
try {
if(--R.GAS > 0) {
$z60896090 = $f60956096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f60956096,
"from":L[760]});
}
} catch($e60876088) {
if(R.isCont($e60876088)) {
var $ss60916092 = {"from":L[760],
"go":function(anf_obj15276099) {
return $Hanf_obj28766101(anf_obj15276099,anf_obj15246100);
}};
$e60876088.stack[R.EXN_STACKHEIGHT++] = $ss60916092;
}
if(R.isPyretException($e60876088)) {
$e60876088.pyretStack.push(L[760]);
}
throw $e60876088;
}
var $ret60936094 = $Hanf_obj28766101($z60896090,anf_obj15246100);
++R.GAS;
return $ret60936094;
};
var $Hanf_obj28766101 = function(anf_obj15276099,anf_obj15246100) {
var ann_DASH_check_DASH_temp15226102 = R.makeObject({"env":anf_obj15246100,
"atoms":anf_obj15276099});
return ann_DASH_check_DASH_temp15226102;
};
var $Hnew_DASH_types28754782 = function(new_DASH_types5394773,A119,_check5384774,handle_DASH_id3513977,l5314775,mixins5354776,name5324777,namet5334778,self5304779,shared_DASH_members5374780,variants5364781) {
var anf_extend14966117 = G(new_DASH_types5394773,"env",L[766]);
var with_DASH_params5436115 = self5304779.extendWith({"type-env":anf_extend14966117});
var anf_arg14976113 = G(self5304779,"env",L[765]);
var $z61056106 = D;
var $f61116112 = function(_) {
return R.isFunction(handle_DASH_id3513977.$var)?handle_DASH_id3513977.$var.app(anf_arg14976113,l5314775,namet5334778):R.ffi.throwNonFunApp(L[764],handle_DASH_id3513977.$var,[anf_arg14976113,l5314775,namet5334778]);
};
try {
if(--R.GAS > 0) {
$z61056106 = $f61116112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61116112,
"from":L[764]});
}
} catch($e61036104) {
if(R.isCont($e61036104)) {
var $ss61076108 = {"from":L[764],
"go":function(anf_bracket14986114) {
return $Hanf_bracket28746116(anf_bracket14986114,A119,_check5384774,l5314775,mixins5354776,name5324777,new_DASH_types5394773,shared_DASH_members5374780,variants5364781,with_DASH_params5436115);
}};
$e61036104.stack[R.EXN_STACKHEIGHT++] = $ss61076108;
}
if(R.isPyretException($e61036104)) {
$e61036104.pyretStack.push(L[764]);
}
throw $e61036104;
}
var $ret61096110 = $Hanf_bracket28746116($z61056106,A119,_check5384774,l5314775,mixins5354776,name5324777,new_DASH_types5394773,shared_DASH_members5374780,variants5364781,with_DASH_params5436115);
++R.GAS;
return $ret61096110;
};
var $Hanf_bracket28746116 = function(anf_bracket14986114,A119,_check5384774,l5314775,mixins5354776,name5324777,new_DASH_types5394773,shared_DASH_members5374780,variants5364781,with_DASH_params5436115) {
var new_DASH_namet5446131 = G(anf_bracket14986114,"id",L[771]);
var anf_fun14996130 = G(A119,"s-data-expr",L[770]);
var anf_bracket15006133 = G(new_DASH_types5394773,"atoms",L[769]);
var anf_fun15016128 = G(anf_bracket15006133,"reverse",L[768]);
var $z61206121 = D;
var $f61266127 = function(_) {
return R.isFunction(anf_fun15016128)?anf_fun15016128.app():R.ffi.throwNonFunApp(L[767],anf_fun15016128,[]);
};
try {
if(--R.GAS > 0) {
$z61206121 = $f61266127();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61266127,
"from":L[767]});
}
} catch($e61186119) {
if(R.isCont($e61186119)) {
var $ss61226123 = {"from":L[767],
"go":function(anf_arg15026129) {
return $Hanf_arg28736132(anf_arg15026129,_check5384774,anf_fun14996130,l5314775,mixins5354776,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,variants5364781,with_DASH_params5436115);
}};
$e61186119.stack[R.EXN_STACKHEIGHT++] = $ss61226123;
}
if(R.isPyretException($e61186119)) {
$e61186119.pyretStack.push(L[767]);
}
throw $e61186119;
}
var $ret61246125 = $Hanf_arg28736132($z61206121,_check5384774,anf_fun14996130,l5314775,mixins5354776,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,variants5364781,with_DASH_params5436115);
++R.GAS;
return $ret61246125;
};
var $Hanf_arg28736132 = function(anf_arg15026129,_check5384774,anf_fun14996130,l5314775,mixins5354776,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,variants5364781,with_DASH_params5436115) {
var anf_fun15036144 = G(mixins5354776,"map",L[774]);
var anf_arg15066145 = R.makeFunction(function(recv_DASH_1126148) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[773],1,arguments);
}
var anf_fun15056159 = G(recv_DASH_1126148,"visit",L[773]);
var $z61516152 = D;
var $f61576158 = function(_) {
return R.isFunction(anf_fun15056159)?anf_fun15056159.app(with_DASH_params5436115):R.ffi.throwNonFunApp(L[773],anf_fun15056159,[with_DASH_params5436115]);
};
try {
if(--R.GAS > 0) {
$z61516152 = $f61576158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61576158,
"from":L[773]});
}
} catch($e61496150) {
if(R.isCont($e61496150)) {
var $ss61536154 = {"from":L[773],
"go":function(ann_DASH_check_DASH_temp15046160) {
return $Hann_DASH_check_DASH_temp28656161(ann_DASH_check_DASH_temp15046160);
}};
$e61496150.stack[R.EXN_STACKHEIGHT++] = $ss61536154;
}
if(R.isPyretException($e61496150)) {
$e61496150.pyretStack.push(L[773]);
}
throw $e61496150;
}
var $ret61556156 = $Hann_DASH_check_DASH_temp28656161($z61516152);
++R.GAS;
return $ret61556156;
});
var $z61366137 = D;
var $f61426143 = function(_) {
return R.isFunction(anf_fun15036144)?anf_fun15036144.app(anf_arg15066145):R.ffi.throwNonFunApp(L[772],anf_fun15036144,[anf_arg15066145]);
};
try {
if(--R.GAS > 0) {
$z61366137 = $f61426143();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61426143,
"from":L[772]});
}
} catch($e61346135) {
if(R.isCont($e61346135)) {
var $ss61386139 = {"from":L[772],
"go":function(anf_arg15076146) {
return $Hanf_arg28726147(anf_arg15076146,_check5384774,anf_arg15026129,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,variants5364781,with_DASH_params5436115);
}};
$e61346135.stack[R.EXN_STACKHEIGHT++] = $ss61386139;
}
if(R.isPyretException($e61346135)) {
$e61346135.pyretStack.push(L[772]);
}
throw $e61346135;
}
var $ret61406141 = $Hanf_arg28726147($z61366137,_check5384774,anf_arg15026129,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,variants5364781,with_DASH_params5436115);
++R.GAS;
return $ret61406141;
};
var $Hanf_arg28726147 = function(anf_arg15076146,_check5384774,anf_arg15026129,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,variants5364781,with_DASH_params5436115) {
var anf_fun15086172 = G(variants5364781,"map",L[777]);
var anf_arg15116173 = R.makeFunction(function(recv_DASH_1136176) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[776],1,arguments);
}
var anf_fun15106187 = G(recv_DASH_1136176,"visit",L[776]);
var $z61796180 = D;
var $f61856186 = function(_) {
return R.isFunction(anf_fun15106187)?anf_fun15106187.app(with_DASH_params5436115):R.ffi.throwNonFunApp(L[776],anf_fun15106187,[with_DASH_params5436115]);
};
try {
if(--R.GAS > 0) {
$z61796180 = $f61856186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61856186,
"from":L[776]});
}
} catch($e61776178) {
if(R.isCont($e61776178)) {
var $ss61816182 = {"from":L[776],
"go":function(ann_DASH_check_DASH_temp15096188) {
return $Hann_DASH_check_DASH_temp28666189(ann_DASH_check_DASH_temp15096188);
}};
$e61776178.stack[R.EXN_STACKHEIGHT++] = $ss61816182;
}
if(R.isPyretException($e61776178)) {
$e61776178.pyretStack.push(L[776]);
}
throw $e61776178;
}
var $ret61836184 = $Hann_DASH_check_DASH_temp28666189($z61796180);
++R.GAS;
return $ret61836184;
});
var $z61646165 = D;
var $f61706171 = function(_) {
return R.isFunction(anf_fun15086172)?anf_fun15086172.app(anf_arg15116173):R.ffi.throwNonFunApp(L[775],anf_fun15086172,[anf_arg15116173]);
};
try {
if(--R.GAS > 0) {
$z61646165 = $f61706171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61706171,
"from":L[775]});
}
} catch($e61626163) {
if(R.isCont($e61626163)) {
var $ss61666167 = {"from":L[775],
"go":function(anf_arg15126174) {
return $Hanf_arg28716175(anf_arg15126174,_check5384774,anf_arg15026129,anf_arg15076146,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,with_DASH_params5436115);
}};
$e61626163.stack[R.EXN_STACKHEIGHT++] = $ss61666167;
}
if(R.isPyretException($e61626163)) {
$e61626163.pyretStack.push(L[775]);
}
throw $e61626163;
}
var $ret61686169 = $Hanf_arg28716175($z61646165,_check5384774,anf_arg15026129,anf_arg15076146,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,with_DASH_params5436115);
++R.GAS;
return $ret61686169;
};
var $Hanf_arg28716175 = function(anf_arg15126174,_check5384774,anf_arg15026129,anf_arg15076146,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,shared_DASH_members5374780,with_DASH_params5436115) {
var anf_fun15136200 = G(shared_DASH_members5374780,"map",L[780]);
var anf_arg15166201 = R.makeFunction(function(recv_DASH_1146204) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[779],1,arguments);
}
var anf_fun15156215 = G(recv_DASH_1146204,"visit",L[779]);
var $z62076208 = D;
var $f62136214 = function(_) {
return R.isFunction(anf_fun15156215)?anf_fun15156215.app(with_DASH_params5436115):R.ffi.throwNonFunApp(L[779],anf_fun15156215,[with_DASH_params5436115]);
};
try {
if(--R.GAS > 0) {
$z62076208 = $f62136214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62136214,
"from":L[779]});
}
} catch($e62056206) {
if(R.isCont($e62056206)) {
var $ss62096210 = {"from":L[779],
"go":function(ann_DASH_check_DASH_temp15146216) {
return $Hann_DASH_check_DASH_temp28676217(ann_DASH_check_DASH_temp15146216);
}};
$e62056206.stack[R.EXN_STACKHEIGHT++] = $ss62096210;
}
if(R.isPyretException($e62056206)) {
$e62056206.pyretStack.push(L[779]);
}
throw $e62056206;
}
var $ret62116212 = $Hann_DASH_check_DASH_temp28676217($z62076208);
++R.GAS;
return $ret62116212;
});
var $z61926193 = D;
var $f61986199 = function(_) {
return R.isFunction(anf_fun15136200)?anf_fun15136200.app(anf_arg15166201):R.ffi.throwNonFunApp(L[778],anf_fun15136200,[anf_arg15166201]);
};
try {
if(--R.GAS > 0) {
$z61926193 = $f61986199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f61986199,
"from":L[778]});
}
} catch($e61906191) {
if(R.isCont($e61906191)) {
var $ss61946195 = {"from":L[778],
"go":function(anf_arg15176202) {
return $Hanf_arg28706203(anf_arg15176202,_check5384774,anf_arg15026129,anf_arg15076146,anf_arg15126174,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,with_DASH_params5436115);
}};
$e61906191.stack[R.EXN_STACKHEIGHT++] = $ss61946195;
}
if(R.isPyretException($e61906191)) {
$e61906191.pyretStack.push(L[778]);
}
throw $e61906191;
}
var $ret61966197 = $Hanf_arg28706203($z61926193,_check5384774,anf_arg15026129,anf_arg15076146,anf_arg15126174,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,with_DASH_params5436115);
++R.GAS;
return $ret61966197;
};
var $Hanf_arg28706203 = function(anf_arg15176202,_check5384774,anf_arg15026129,anf_arg15076146,anf_arg15126174,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131,with_DASH_params5436115) {
var anf_fun15186228 = G(with_DASH_params5436115,"option",L[782]);
var $z62206221 = D;
var $f62266227 = function(_) {
return R.isFunction(anf_fun15186228)?anf_fun15186228.app(_check5384774):R.ffi.throwNonFunApp(L[781],anf_fun15186228,[_check5384774]);
};
try {
if(--R.GAS > 0) {
$z62206221 = $f62266227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62266227,
"from":L[781]});
}
} catch($e62186219) {
if(R.isCont($e62186219)) {
var $ss62226223 = {"from":L[781],
"go":function(anf_arg15196229) {
return $Hanf_arg28696230(anf_arg15196229,anf_arg15026129,anf_arg15076146,anf_arg15126174,anf_arg15176202,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131);
}};
$e62186219.stack[R.EXN_STACKHEIGHT++] = $ss62226223;
}
if(R.isPyretException($e62186219)) {
$e62186219.pyretStack.push(L[781]);
}
throw $e62186219;
}
var $ret62246225 = $Hanf_arg28696230($z62206221,anf_arg15026129,anf_arg15076146,anf_arg15126174,anf_arg15176202,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131);
++R.GAS;
return $ret62246225;
};
var $Hanf_arg28696230 = function(anf_arg15196229,anf_arg15026129,anf_arg15076146,anf_arg15126174,anf_arg15176202,anf_fun14996130,l5314775,name5324777,new_DASH_namet5446131) {
var $z62336234 = D;
var $f62396240 = function(_) {
return R.isFunction(anf_fun14996130)?anf_fun14996130.app(l5314775,name5324777,new_DASH_namet5446131,anf_arg15026129,anf_arg15076146,anf_arg15126174,anf_arg15176202,anf_arg15196229):R.ffi.throwNonFunApp(L[575],anf_fun14996130,[l5314775,name5324777,new_DASH_namet5446131,anf_arg15026129,anf_arg15076146,anf_arg15126174,anf_arg15176202,anf_arg15196229]);
};
try {
if(--R.GAS > 0) {
$z62336234 = $f62396240();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62396240,
"from":L[575]});
}
} catch($e62316232) {
if(R.isCont($e62316232)) {
var $ss62356236 = {"from":L[575],
"go":function(ann_DASH_check_DASH_temp14866241) {
return $Hann_DASH_check_DASH_temp28686242(ann_DASH_check_DASH_temp14866241);
}};
$e62316232.stack[R.EXN_STACKHEIGHT++] = $ss62356236;
}
if(R.isPyretException($e62316232)) {
$e62316232.pyretStack.push(L[575]);
}
throw $e62316232;
}
var $ret62376238 = $Hann_DASH_check_DASH_temp28686242($z62336234);
++R.GAS;
return $ret62376238;
};
var $Hann_DASH_check_DASH_temp28686242 = function(ann_DASH_check_DASH_temp14866241) {
return ann_DASH_check_DASH_temp14866241;
};
var $Hann_DASH_check_DASH_temp28676217 = function(ann_DASH_check_DASH_temp15146216) {
return ann_DASH_check_DASH_temp15146216;
};
var $Hann_DASH_check_DASH_temp28666189 = function(ann_DASH_check_DASH_temp15096188) {
return ann_DASH_check_DASH_temp15096188;
};
var $Hann_DASH_check_DASH_temp28656161 = function(ann_DASH_check_DASH_temp15046160) {
return ann_DASH_check_DASH_temp15046160;
};
var $Hatom_DASH_env28644798 = function(atom_DASH_env5424797,acc5404784,link3774) {
var anf_obj14896256 = G(atom_DASH_env5424797,"env",L[786]);
var anf_arg14906253 = G(atom_DASH_env5424797,"atom",L[785]);
var anf_arg14916254 = G(acc5404784,"atoms",L[784]);
var $z62456246 = D;
var $f62516252 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg14906253,anf_arg14916254):R.ffi.throwNonFunApp(L[783],link3774,[anf_arg14906253,anf_arg14916254]);
};
try {
if(--R.GAS > 0) {
$z62456246 = $f62516252();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62516252,
"from":L[783]});
}
} catch($e62436244) {
if(R.isCont($e62436244)) {
var $ss62476248 = {"from":L[783],
"go":function(anf_obj14926255) {
return $Hanf_obj28636257(anf_obj14926255,anf_obj14896256);
}};
$e62436244.stack[R.EXN_STACKHEIGHT++] = $ss62476248;
}
if(R.isPyretException($e62436244)) {
$e62436244.pyretStack.push(L[783]);
}
throw $e62436244;
}
var $ret62496250 = $Hanf_obj28636257($z62456246,anf_obj14896256);
++R.GAS;
return $ret62496250;
};
var $Hanf_obj28636257 = function(anf_obj14926255,anf_obj14896256) {
var ann_DASH_check_DASH_temp14876258 = R.makeObject({"env":anf_obj14896256,
"atoms":anf_obj14926255});
return ann_DASH_check_DASH_temp14876258;
};
var $Hanf_obj28624818 = function(anf_obj14634810,A119,anf_arg14604811,anf_obj14614812,args5164813,body5174814,fold6171,l5144815,map24676,name5154816,self5134817) {
var anf_arg14646269 = R.makeObject({"env":anf_obj14614812,
"atoms":anf_obj14634810});
var $z62616262 = D;
var $f62676268 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg14604811,anf_arg14646269,args5164813):R.ffi.throwNonFunApp(L[787],fold6171,[anf_arg14604811,anf_arg14646269,args5164813]);
};
try {
if(--R.GAS > 0) {
$z62616262 = $f62676268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62676268,
"from":L[787]});
}
} catch($e62596260) {
if(R.isCont($e62596260)) {
var $ss62636264 = {"from":L[787],
"go":function(env_DASH_and_DASH_atoms5186270) {
return $Henv_DASH_and_DASH_atoms28616271(env_DASH_and_DASH_atoms5186270,A119,args5164813,body5174814,l5144815,map24676,name5154816,self5134817);
}};
$e62596260.stack[R.EXN_STACKHEIGHT++] = $ss62636264;
}
if(R.isPyretException($e62596260)) {
$e62596260.pyretStack.push(L[787]);
}
throw $e62596260;
}
var $ret62656266 = $Henv_DASH_and_DASH_atoms28616271($z62616262,A119,args5164813,body5174814,l5144815,map24676,name5154816,self5134817);
++R.GAS;
return $ret62656266;
};
var $Henv_DASH_and_DASH_atoms28616271 = function(env_DASH_and_DASH_atoms5186270,A119,args5164813,body5174814,l5144815,map24676,name5154816,self5134817) {
var anf_arg14776284 = R.makeFunction(function(a5236287,at5246288) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[791],2,arguments);
}
var cases_DASH_val1116326 = a5236287;
var anf_fun14666299 = G(cases_DASH_val1116326,"_match",L[792]);
var anf_obj14736305 = R.makeFunction(function(l25256306,shadows5266307,id5276308,ann5286309) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[793],4,arguments);
}
var anf_fun14686323 = G(A119,"s-bind",L[797]);
var anf_fun14696320 = G(ann5286309,"visit",L[796]);
var anf_extend14706325 = G(env_DASH_and_DASH_atoms5186270,"env",L[795]);
var anf_arg14716321 = self5134817.extendWith({"env":anf_extend14706325});
var $z63126313 = D;
var $f63186319 = function(_) {
return R.isFunction(anf_fun14696320)?anf_fun14696320.app(anf_arg14716321):R.ffi.throwNonFunApp(L[794],anf_fun14696320,[anf_arg14716321]);
};
try {
if(--R.GAS > 0) {
$z63126313 = $f63186319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63186319,
"from":L[794]});
}
} catch($e63106311) {
if(R.isCont($e63106311)) {
var $ss63146315 = {"from":L[794],
"go":function(anf_arg14726322) {
return $Hanf_arg28556324(anf_arg14726322,anf_fun14686323,at5246288,l25256306);
}};
$e63106311.stack[R.EXN_STACKHEIGHT++] = $ss63146315;
}
if(R.isPyretException($e63106311)) {
$e63106311.pyretStack.push(L[794]);
}
throw $e63106311;
}
var $ret63166317 = $Hanf_arg28556324($z63126313,anf_fun14686323,at5246288,l25256306);
++R.GAS;
return $ret63166317;
});
var anf_arg14746300 = R.makeObject({"s-bind":anf_obj14736305});
var anf_arg14766301 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[792],0,arguments);
}
var ann_DASH_check_DASH_temp14756304 = R.throwNoBranchesMatched(L[792],("cases"));
return ann_DASH_check_DASH_temp14756304;
});
var $z62916292 = D;
var $f62976298 = function(_) {
return R.isFunction(anf_fun14666299)?anf_fun14666299.app(anf_arg14746300,anf_arg14766301):R.ffi.throwNonFunApp(L[791],anf_fun14666299,[anf_arg14746300,anf_arg14766301]);
};
try {
if(--R.GAS > 0) {
$z62916292 = $f62976298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62976298,
"from":L[791]});
}
} catch($e62896290) {
if(R.isCont($e62896290)) {
var $ss62936294 = {"from":L[791],
"go":function(ann_DASH_check_DASH_temp14656302) {
return $Hann_DASH_check_DASH_temp28566303(ann_DASH_check_DASH_temp14656302);
}};
$e62896290.stack[R.EXN_STACKHEIGHT++] = $ss62936294;
}
if(R.isPyretException($e62896290)) {
$e62896290.pyretStack.push(L[791]);
}
throw $e62896290;
}
var $ret62956296 = $Hann_DASH_check_DASH_temp28566303($z62916292);
++R.GAS;
return $ret62956296;
});
var anf_bracket14786286 = G(env_DASH_and_DASH_atoms5186270,"atoms",L[790]);
var anf_fun14796282 = G(anf_bracket14786286,"reverse",L[789]);
var $z62746275 = D;
var $f62806281 = function(_) {
return R.isFunction(anf_fun14796282)?anf_fun14796282.app():R.ffi.throwNonFunApp(L[788],anf_fun14796282,[]);
};
try {
if(--R.GAS > 0) {
$z62746275 = $f62806281();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f62806281,
"from":L[788]});
}
} catch($e62726273) {
if(R.isCont($e62726273)) {
var $ss62766277 = {"from":L[788],
"go":function(anf_arg14806283) {
return $Hanf_arg28606285(anf_arg14806283,A119,anf_arg14776284,args5164813,body5174814,env_DASH_and_DASH_atoms5186270,l5144815,map24676,name5154816,self5134817);
}};
$e62726273.stack[R.EXN_STACKHEIGHT++] = $ss62766277;
}
if(R.isPyretException($e62726273)) {
$e62726273.pyretStack.push(L[788]);
}
throw $e62726273;
}
var $ret62786279 = $Hanf_arg28606285($z62746275,A119,anf_arg14776284,args5164813,body5174814,env_DASH_and_DASH_atoms5186270,l5144815,map24676,name5154816,self5134817);
++R.GAS;
return $ret62786279;
};
var $Hanf_arg28606285 = function(anf_arg14806283,A119,anf_arg14776284,args5164813,body5174814,env_DASH_and_DASH_atoms5186270,l5144815,map24676,name5154816,self5134817) {
var $z63296330 = D;
var $f63356336 = function(_) {
return R.isFunction(map24676)?map24676.app(anf_arg14776284,args5164813,anf_arg14806283):R.ffi.throwNonFunApp(L[798],map24676,[anf_arg14776284,args5164813,anf_arg14806283]);
};
try {
if(--R.GAS > 0) {
$z63296330 = $f63356336();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63356336,
"from":L[798]});
}
} catch($e63276328) {
if(R.isCont($e63276328)) {
var $ss63316332 = {"from":L[798],
"go":function(new_DASH_args5226337) {
return $Hnew_DASH_args28596338(new_DASH_args5226337,A119,body5174814,env_DASH_and_DASH_atoms5186270,l5144815,name5154816,self5134817);
}};
$e63276328.stack[R.EXN_STACKHEIGHT++] = $ss63316332;
}
if(R.isPyretException($e63276328)) {
$e63276328.pyretStack.push(L[798]);
}
throw $e63276328;
}
var $ret63336334 = $Hnew_DASH_args28596338($z63296330,A119,body5174814,env_DASH_and_DASH_atoms5186270,l5144815,name5154816,self5134817);
++R.GAS;
return $ret63336334;
};
var $Hnew_DASH_args28596338 = function(new_DASH_args5226337,A119,body5174814,env_DASH_and_DASH_atoms5186270,l5144815,name5154816,self5134817) {
var anf_fun14816349 = G(body5174814,"visit",L[801]);
var anf_extend14826353 = G(env_DASH_and_DASH_atoms5186270,"env",L[800]);
var anf_arg14836350 = self5134817.extendWith({"env":anf_extend14826353});
var $z63416342 = D;
var $f63476348 = function(_) {
return R.isFunction(anf_fun14816349)?anf_fun14816349.app(anf_arg14836350):R.ffi.throwNonFunApp(L[799],anf_fun14816349,[anf_arg14836350]);
};
try {
if(--R.GAS > 0) {
$z63416342 = $f63476348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63476348,
"from":L[799]});
}
} catch($e63396340) {
if(R.isCont($e63396340)) {
var $ss63436344 = {"from":L[799],
"go":function(new_DASH_body5296351) {
return $Hnew_DASH_body28586352(new_DASH_body5296351,A119,l5144815,name5154816,new_DASH_args5226337);
}};
$e63396340.stack[R.EXN_STACKHEIGHT++] = $ss63436344;
}
if(R.isPyretException($e63396340)) {
$e63396340.pyretStack.push(L[799]);
}
throw $e63396340;
}
var $ret63456346 = $Hnew_DASH_body28586352($z63416342,A119,l5144815,name5154816,new_DASH_args5226337);
++R.GAS;
return $ret63456346;
};
var $Hnew_DASH_body28586352 = function(new_DASH_body5296351,A119,l5144815,name5154816,new_DASH_args5226337) {
var anf_fun14846364 = G(A119,"s-cases-branch",L[802]);
var $z63566357 = D;
var $f63626363 = function(_) {
return R.isFunction(anf_fun14846364)?anf_fun14846364.app(l5144815,name5154816,new_DASH_args5226337,new_DASH_body5296351):R.ffi.throwNonFunApp(L[583],anf_fun14846364,[l5144815,name5154816,new_DASH_args5226337,new_DASH_body5296351]);
};
try {
if(--R.GAS > 0) {
$z63566357 = $f63626363();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63626363,
"from":L[583]});
}
} catch($e63546355) {
if(R.isCont($e63546355)) {
var $ss63586359 = {"from":L[583],
"go":function(ann_DASH_check_DASH_temp14516365) {
return $Hann_DASH_check_DASH_temp28576366(ann_DASH_check_DASH_temp14516365);
}};
$e63546355.stack[R.EXN_STACKHEIGHT++] = $ss63586359;
}
if(R.isPyretException($e63546355)) {
$e63546355.pyretStack.push(L[583]);
}
throw $e63546355;
}
var $ret63606361 = $Hann_DASH_check_DASH_temp28576366($z63566357);
++R.GAS;
return $ret63606361;
};
var $Hann_DASH_check_DASH_temp28576366 = function(ann_DASH_check_DASH_temp14516365) {
return ann_DASH_check_DASH_temp14516365;
};
var $Hann_DASH_check_DASH_temp28566303 = function(ann_DASH_check_DASH_temp14656302) {
return ann_DASH_check_DASH_temp14656302;
};
var $Hanf_arg28556324 = function(anf_arg14726322,anf_fun14686323,at5246288,l25256306) {
var $z63696370 = D;
var $f63756376 = function(_) {
return R.isFunction(anf_fun14686323)?anf_fun14686323.app(l25256306,(false),at5246288,anf_arg14726322):R.ffi.throwNonFunApp(L[793],anf_fun14686323,[l25256306,(false),at5246288,anf_arg14726322]);
};
try {
if(--R.GAS > 0) {
$z63696370 = $f63756376();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63756376,
"from":L[793]});
}
} catch($e63676368) {
if(R.isCont($e63676368)) {
var $ss63716372 = {"from":L[793],
"go":function(ann_DASH_check_DASH_temp14676377) {
return $Hann_DASH_check_DASH_temp28546378(ann_DASH_check_DASH_temp14676377);
}};
$e63676368.stack[R.EXN_STACKHEIGHT++] = $ss63716372;
}
if(R.isPyretException($e63676368)) {
$e63676368.pyretStack.push(L[793]);
}
throw $e63676368;
}
var $ret63736374 = $Hann_DASH_check_DASH_temp28546378($z63696370);
++R.GAS;
return $ret63736374;
};
var $Hann_DASH_check_DASH_temp28546378 = function(ann_DASH_check_DASH_temp14676377) {
return ann_DASH_check_DASH_temp14676377;
};
var $Hatom_DASH_env28534835 = function(atom_DASH_env5214834,acc5194819,link3774) {
var anf_obj14566392 = G(atom_DASH_env5214834,"env",L[806]);
var anf_arg14576389 = G(atom_DASH_env5214834,"atom",L[805]);
var anf_arg14586390 = G(acc5194819,"atoms",L[804]);
var $z63816382 = D;
var $f63876388 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg14576389,anf_arg14586390):R.ffi.throwNonFunApp(L[803],link3774,[anf_arg14576389,anf_arg14586390]);
};
try {
if(--R.GAS > 0) {
$z63816382 = $f63876388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f63876388,
"from":L[803]});
}
} catch($e63796380) {
if(R.isCont($e63796380)) {
var $ss63836384 = {"from":L[803],
"go":function(anf_obj14596391) {
return $Hanf_obj28526393(anf_obj14596391,anf_obj14566392);
}};
$e63796380.stack[R.EXN_STACKHEIGHT++] = $ss63836384;
}
if(R.isPyretException($e63796380)) {
$e63796380.pyretStack.push(L[803]);
}
throw $e63796380;
}
var $ret63856386 = $Hanf_obj28526393($z63816382,anf_obj14566392);
++R.GAS;
return $ret63856386;
};
var $Hanf_obj28526393 = function(anf_obj14596391,anf_obj14566392) {
var ann_DASH_check_DASH_temp14526394 = R.makeObject({"env":anf_obj14566392,
"atoms":anf_obj14596391});
return ann_DASH_check_DASH_temp14526394;
};
var $Hanf_obj28514856 = function(anf_obj14364847,A119,anf_arg14334848,anf_obj14344849,ann5014850,binds5004851,body5024852,fold6171,iter4994853,l4984854,self4974855) {
var anf_arg14376405 = R.makeObject({"env":anf_obj14344849,
"fbs":anf_obj14364847});
var $z63976398 = D;
var $f64036404 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg14334848,anf_arg14376405,binds5004851):R.ffi.throwNonFunApp(L[807],fold6171,[anf_arg14334848,anf_arg14376405,binds5004851]);
};
try {
if(--R.GAS > 0) {
$z63976398 = $f64036404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64036404,
"from":L[807]});
}
} catch($e63956396) {
if(R.isCont($e63956396)) {
var $ss63996400 = {"from":L[807],
"go":function(env_DASH_and_DASH_binds5036406) {
return $Henv_DASH_and_DASH_binds28506407(env_DASH_and_DASH_binds5036406,A119,ann5014850,body5024852,iter4994853,l4984854,self4974855);
}};
$e63956396.stack[R.EXN_STACKHEIGHT++] = $ss63996400;
}
if(R.isPyretException($e63956396)) {
$e63956396.pyretStack.push(L[807]);
}
throw $e63956396;
}
var $ret64016402 = $Henv_DASH_and_DASH_binds28506407($z63976398,A119,ann5014850,body5024852,iter4994853,l4984854,self4974855);
++R.GAS;
return $ret64016402;
};
var $Henv_DASH_and_DASH_binds28506407 = function(env_DASH_and_DASH_binds5036406,A119,ann5014850,body5024852,iter4994853,l4984854,self4974855) {
var anf_fun14386420 = G(A119,"s-for",L[810]);
var anf_fun14396418 = G(iter4994853,"visit",L[809]);
var $z64106411 = D;
var $f64166417 = function(_) {
return R.isFunction(anf_fun14396418)?anf_fun14396418.app(self4974855):R.ffi.throwNonFunApp(L[808],anf_fun14396418,[self4974855]);
};
try {
if(--R.GAS > 0) {
$z64106411 = $f64166417();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64166417,
"from":L[808]});
}
} catch($e64086409) {
if(R.isCont($e64086409)) {
var $ss64126413 = {"from":L[808],
"go":function(anf_arg14406419) {
return $Hanf_arg28496421(anf_arg14406419,anf_fun14386420,ann5014850,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855);
}};
$e64086409.stack[R.EXN_STACKHEIGHT++] = $ss64126413;
}
if(R.isPyretException($e64086409)) {
$e64086409.pyretStack.push(L[808]);
}
throw $e64086409;
}
var $ret64146415 = $Hanf_arg28496421($z64106411,anf_fun14386420,ann5014850,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855);
++R.GAS;
return $ret64146415;
};
var $Hanf_arg28496421 = function(anf_arg14406419,anf_fun14386420,ann5014850,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855) {
var anf_bracket14416435 = G(env_DASH_and_DASH_binds5036406,"fbs",L[813]);
var anf_fun14426432 = G(anf_bracket14416435,"reverse",L[812]);
var $z64246425 = D;
var $f64306431 = function(_) {
return R.isFunction(anf_fun14426432)?anf_fun14426432.app():R.ffi.throwNonFunApp(L[811],anf_fun14426432,[]);
};
try {
if(--R.GAS > 0) {
$z64246425 = $f64306431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64306431,
"from":L[811]});
}
} catch($e64226423) {
if(R.isCont($e64226423)) {
var $ss64266427 = {"from":L[811],
"go":function(anf_arg14436433) {
return $Hanf_arg28486434(anf_arg14436433,anf_arg14406419,anf_fun14386420,ann5014850,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855);
}};
$e64226423.stack[R.EXN_STACKHEIGHT++] = $ss64266427;
}
if(R.isPyretException($e64226423)) {
$e64226423.pyretStack.push(L[811]);
}
throw $e64226423;
}
var $ret64286429 = $Hanf_arg28486434($z64246425,anf_arg14406419,anf_fun14386420,ann5014850,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855);
++R.GAS;
return $ret64286429;
};
var $Hanf_arg28486434 = function(anf_arg14436433,anf_arg14406419,anf_fun14386420,ann5014850,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855) {
var anf_fun14446446 = G(ann5014850,"visit",L[815]);
var $z64386439 = D;
var $f64446445 = function(_) {
return R.isFunction(anf_fun14446446)?anf_fun14446446.app(self4974855):R.ffi.throwNonFunApp(L[814],anf_fun14446446,[self4974855]);
};
try {
if(--R.GAS > 0) {
$z64386439 = $f64446445();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64446445,
"from":L[814]});
}
} catch($e64366437) {
if(R.isCont($e64366437)) {
var $ss64406441 = {"from":L[814],
"go":function(anf_arg14456447) {
return $Hanf_arg28476448(anf_arg14456447,anf_arg14406419,anf_arg14436433,anf_fun14386420,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855);
}};
$e64366437.stack[R.EXN_STACKHEIGHT++] = $ss64406441;
}
if(R.isPyretException($e64366437)) {
$e64366437.pyretStack.push(L[814]);
}
throw $e64366437;
}
var $ret64426443 = $Hanf_arg28476448($z64386439,anf_arg14406419,anf_arg14436433,anf_fun14386420,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855);
++R.GAS;
return $ret64426443;
};
var $Hanf_arg28476448 = function(anf_arg14456447,anf_arg14406419,anf_arg14436433,anf_fun14386420,body5024852,env_DASH_and_DASH_binds5036406,l4984854,self4974855) {
var anf_fun14466459 = G(body5024852,"visit",L[818]);
var anf_extend14476463 = G(env_DASH_and_DASH_binds5036406,"env",L[817]);
var anf_arg14486460 = self4974855.extendWith({"env":anf_extend14476463});
var $z64516452 = D;
var $f64576458 = function(_) {
return R.isFunction(anf_fun14466459)?anf_fun14466459.app(anf_arg14486460):R.ffi.throwNonFunApp(L[816],anf_fun14466459,[anf_arg14486460]);
};
try {
if(--R.GAS > 0) {
$z64516452 = $f64576458();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64576458,
"from":L[816]});
}
} catch($e64496450) {
if(R.isCont($e64496450)) {
var $ss64536454 = {"from":L[816],
"go":function(anf_arg14496461) {
return $Hanf_arg28466462(anf_arg14496461,anf_arg14406419,anf_arg14436433,anf_arg14456447,anf_fun14386420,l4984854);
}};
$e64496450.stack[R.EXN_STACKHEIGHT++] = $ss64536454;
}
if(R.isPyretException($e64496450)) {
$e64496450.pyretStack.push(L[816]);
}
throw $e64496450;
}
var $ret64556456 = $Hanf_arg28466462($z64516452,anf_arg14406419,anf_arg14436433,anf_arg14456447,anf_fun14386420,l4984854);
++R.GAS;
return $ret64556456;
};
var $Hanf_arg28466462 = function(anf_arg14496461,anf_arg14406419,anf_arg14436433,anf_arg14456447,anf_fun14386420,l4984854) {
var $z64666467 = D;
var $f64726473 = function(_) {
return R.isFunction(anf_fun14386420)?anf_fun14386420.app(l4984854,anf_arg14406419,anf_arg14436433,anf_arg14456447,anf_arg14496461):R.ffi.throwNonFunApp(L[593],anf_fun14386420,[l4984854,anf_arg14406419,anf_arg14436433,anf_arg14456447,anf_arg14496461]);
};
try {
if(--R.GAS > 0) {
$z64666467 = $f64726473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64726473,
"from":L[593]});
}
} catch($e64646465) {
if(R.isCont($e64646465)) {
var $ss64686469 = {"from":L[593],
"go":function(ann_DASH_check_DASH_temp14046474) {
return $Hann_DASH_check_DASH_temp28456475(ann_DASH_check_DASH_temp14046474);
}};
$e64646465.stack[R.EXN_STACKHEIGHT++] = $ss64686469;
}
if(R.isPyretException($e64646465)) {
$e64646465.pyretStack.push(L[593]);
}
throw $e64646465;
}
var $ret64706471 = $Hann_DASH_check_DASH_temp28456475($z64666467);
++R.GAS;
return $ret64706471;
};
var $Hann_DASH_check_DASH_temp28456475 = function(ann_DASH_check_DASH_temp14046474) {
return ann_DASH_check_DASH_temp14046474;
};
var $Hann_DASH_check_DASH_temp28444873 = function(ann_DASH_check_DASH_temp14054872) {
return ann_DASH_check_DASH_temp14054872;
};
var $Hatom_DASH_env28434893 = function(atom_DASH_env5094892,A119,acc5044857,bind5074877,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878) {
var anf_fun14116492 = G(A119,"s-bind",L[826]);
var anf_arg14126489 = G(bind5074877,"l",L[825]);
var anf_arg14136490 = G(bind5074877,"shadows",L[824]);
var anf_arg14146491 = G(atom_DASH_env5094892,"atom",L[823]);
var anf_bracket14156495 = G(bind5074877,"ann",L[822]);
var anf_fun14166486 = G(anf_bracket14156495,"visit",L[821]);
var anf_extend14176494 = G(acc5044857,"env",L[820]);
var anf_arg14186487 = self4974855.extendWith({"env":anf_extend14176494});
var $z64786479 = D;
var $f64846485 = function(_) {
return R.isFunction(anf_fun14166486)?anf_fun14166486.app(anf_arg14186487):R.ffi.throwNonFunApp(L[819],anf_fun14166486,[anf_arg14186487]);
};
try {
if(--R.GAS > 0) {
$z64786479 = $f64846485();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f64846485,
"from":L[819]});
}
} catch($e64766477) {
if(R.isCont($e64766477)) {
var $ss64806481 = {"from":L[819],
"go":function(anf_arg14196488) {
return $Hanf_arg28426493(anf_arg14196488,A119,acc5044857,anf_arg14126489,anf_arg14136490,anf_arg14146491,anf_fun14116492,atom_DASH_env5094892,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878);
}};
$e64766477.stack[R.EXN_STACKHEIGHT++] = $ss64806481;
}
if(R.isPyretException($e64766477)) {
$e64766477.pyretStack.push(L[819]);
}
throw $e64766477;
}
var $ret64826483 = $Hanf_arg28426493($z64786479,A119,acc5044857,anf_arg14126489,anf_arg14136490,anf_arg14146491,anf_fun14116492,atom_DASH_env5094892,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878);
++R.GAS;
return $ret64826483;
};
var $Hanf_arg28426493 = function(anf_arg14196488,A119,acc5044857,anf_arg14126489,anf_arg14136490,anf_arg14146491,anf_fun14116492,atom_DASH_env5094892,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878) {
var $z64986499 = D;
var $f65046505 = function(_) {
return R.isFunction(anf_fun14116492)?anf_fun14116492.app(anf_arg14126489,anf_arg14136490,anf_arg14146491,anf_arg14196488):R.ffi.throwNonFunApp(L[827],anf_fun14116492,[anf_arg14126489,anf_arg14136490,anf_arg14146491,anf_arg14196488]);
};
try {
if(--R.GAS > 0) {
$z64986499 = $f65046505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65046505,
"from":L[827]});
}
} catch($e64966497) {
if(R.isCont($e64966497)) {
var $ss65006501 = {"from":L[827],
"go":function(new_DASH_bind5106506) {
return $Hnew_DASH_bind28416507(new_DASH_bind5106506,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878);
}};
$e64966497.stack[R.EXN_STACKHEIGHT++] = $ss65006501;
}
if(R.isPyretException($e64966497)) {
$e64966497.pyretStack.push(L[827]);
}
throw $e64966497;
}
var $ret65026503 = $Hnew_DASH_bind28416507($z64986499,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878);
++R.GAS;
return $ret65026503;
};
var $Hnew_DASH_bind28416507 = function(new_DASH_bind5106506,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,self4974855,some7084,update_DASH_binding_DASH_expr3503975,val5084878) {
var anf_fun14206518 = G(val5084878,"visit",L[830]);
var anf_extend14216522 = G(acc5044857,"env",L[829]);
var anf_arg14226519 = self4974855.extendWith({"env":anf_extend14216522});
var $z65106511 = D;
var $f65166517 = function(_) {
return R.isFunction(anf_fun14206518)?anf_fun14206518.app(anf_arg14226519):R.ffi.throwNonFunApp(L[828],anf_fun14206518,[anf_arg14226519]);
};
try {
if(--R.GAS > 0) {
$z65106511 = $f65166517();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65166517,
"from":L[828]});
}
} catch($e65086509) {
if(R.isCont($e65086509)) {
var $ss65126513 = {"from":L[828],
"go":function(visit_DASH_val5116520) {
return $Hvisit_DASH_val28406521(visit_DASH_val5116520,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e65086509.stack[R.EXN_STACKHEIGHT++] = $ss65126513;
}
if(R.isPyretException($e65086509)) {
$e65086509.pyretStack.push(L[828]);
}
throw $e65086509;
}
var $ret65146515 = $Hvisit_DASH_val28406521($z65106511,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret65146515;
};
var $Hvisit_DASH_val28406521 = function(visit_DASH_val5116520,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,some7084,update_DASH_binding_DASH_expr3503975) {
var anf_arg14236534 = G(atom_DASH_env5094892,"atom",L[832]);
var $z65256526 = D;
var $f65316532 = function(_) {
return R.isFunction(some7084)?some7084.app(visit_DASH_val5116520):R.ffi.throwNonFunApp(L[831],some7084,[visit_DASH_val5116520]);
};
try {
if(--R.GAS > 0) {
$z65256526 = $f65316532();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65316532,
"from":L[831]});
}
} catch($e65236524) {
if(R.isCont($e65236524)) {
var $ss65276528 = {"from":L[831],
"go":function(anf_arg14246533) {
return $Hanf_arg28396535(anf_arg14246533,A119,acc5044857,anf_arg14236534,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,update_DASH_binding_DASH_expr3503975,visit_DASH_val5116520);
}};
$e65236524.stack[R.EXN_STACKHEIGHT++] = $ss65276528;
}
if(R.isPyretException($e65236524)) {
$e65236524.pyretStack.push(L[831]);
}
throw $e65236524;
}
var $ret65296530 = $Hanf_arg28396535($z65256526,A119,acc5044857,anf_arg14236534,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,update_DASH_binding_DASH_expr3503975,visit_DASH_val5116520);
++R.GAS;
return $ret65296530;
};
var $Hanf_arg28396535 = function(anf_arg14246533,A119,acc5044857,anf_arg14236534,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,update_DASH_binding_DASH_expr3503975,visit_DASH_val5116520) {
var $z65386539 = D;
var $f65446545 = function(_) {
return R.isFunction(update_DASH_binding_DASH_expr3503975.$var)?update_DASH_binding_DASH_expr3503975.$var.app(anf_arg14236534,anf_arg14246533):R.ffi.throwNonFunApp(L[833],update_DASH_binding_DASH_expr3503975.$var,[anf_arg14236534,anf_arg14246533]);
};
try {
if(--R.GAS > 0) {
$z65386539 = $f65446545();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65446545,
"from":L[833]});
}
} catch($e65366537) {
if(R.isCont($e65366537)) {
var $ss65406541 = {"from":L[833],
"go":function(anf_begin_app_dropped28356546) {
return $Hanf_begin_app_dropped28386547(anf_begin_app_dropped28356546,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,visit_DASH_val5116520);
}};
$e65366537.stack[R.EXN_STACKHEIGHT++] = $ss65406541;
}
if(R.isPyretException($e65366537)) {
$e65366537.pyretStack.push(L[833]);
}
throw $e65366537;
}
var $ret65426543 = $Hanf_begin_app_dropped28386547($z65386539,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,visit_DASH_val5116520);
++R.GAS;
return $ret65426543;
};
var $Hanf_begin_app_dropped28386547 = function(anf_begin_app_dropped28356546,A119,acc5044857,atom_DASH_env5094892,l25064876,link3774,new_DASH_bind5106506,visit_DASH_val5116520) {
var anf_fun14256558 = G(A119,"s-for-bind",L[835]);
var $z65506551 = D;
var $f65566557 = function(_) {
return R.isFunction(anf_fun14256558)?anf_fun14256558.app(l25064876,new_DASH_bind5106506,visit_DASH_val5116520):R.ffi.throwNonFunApp(L[834],anf_fun14256558,[l25064876,new_DASH_bind5106506,visit_DASH_val5116520]);
};
try {
if(--R.GAS > 0) {
$z65506551 = $f65566557();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65566557,
"from":L[834]});
}
} catch($e65486549) {
if(R.isCont($e65486549)) {
var $ss65526553 = {"from":L[834],
"go":function(new_DASH_fb5126559) {
return $Hnew_DASH_fb28376560(new_DASH_fb5126559,acc5044857,atom_DASH_env5094892,link3774);
}};
$e65486549.stack[R.EXN_STACKHEIGHT++] = $ss65526553;
}
if(R.isPyretException($e65486549)) {
$e65486549.pyretStack.push(L[834]);
}
throw $e65486549;
}
var $ret65546555 = $Hnew_DASH_fb28376560($z65506551,acc5044857,atom_DASH_env5094892,link3774);
++R.GAS;
return $ret65546555;
};
var $Hnew_DASH_fb28376560 = function(new_DASH_fb5126559,acc5044857,atom_DASH_env5094892,link3774) {
var anf_obj14266573 = G(atom_DASH_env5094892,"env",L[838]);
var anf_arg14276571 = G(acc5044857,"fbs",L[837]);
var $z65636564 = D;
var $f65696570 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_fb5126559,anf_arg14276571):R.ffi.throwNonFunApp(L[836],link3774,[new_DASH_fb5126559,anf_arg14276571]);
};
try {
if(--R.GAS > 0) {
$z65636564 = $f65696570();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65696570,
"from":L[836]});
}
} catch($e65616562) {
if(R.isCont($e65616562)) {
var $ss65656566 = {"from":L[836],
"go":function(anf_obj14286572) {
return $Hanf_obj28366574(anf_obj14286572,anf_obj14266573);
}};
$e65616562.stack[R.EXN_STACKHEIGHT++] = $ss65656566;
}
if(R.isPyretException($e65616562)) {
$e65616562.pyretStack.push(L[836]);
}
throw $e65616562;
}
var $ret65676568 = $Hanf_obj28366574($z65636564,anf_obj14266573);
++R.GAS;
return $ret65676568;
};
var $Hanf_obj28366574 = function(anf_obj14286572,anf_obj14266573) {
var ann_DASH_check_DASH_temp14076575 = R.makeObject({"env":anf_obj14266573,
"fbs":anf_obj14286572});
return ann_DASH_check_DASH_temp14076575;
};
var $Hanf_obj28344913 = function(anf_obj13784906,A119,anf_arg13754907,anf_obj13764908,binds4814909,body4824910,fold6171,l4804911,map24676,self4794912,some7084,update_DASH_binding_DASH_expr3503975) {
var anf_arg13796586 = R.makeObject({"env":anf_obj13764908,
"atoms":anf_obj13784906});
var $z65786579 = D;
var $f65846585 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg13754907,anf_arg13796586,binds4814909):R.ffi.throwNonFunApp(L[839],fold6171,[anf_arg13754907,anf_arg13796586,binds4814909]);
};
try {
if(--R.GAS > 0) {
$z65786579 = $f65846585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65846585,
"from":L[839]});
}
} catch($e65766577) {
if(R.isCont($e65766577)) {
var $ss65806581 = {"from":L[839],
"go":function(bind_DASH_env_DASH_and_DASH_atoms4836587) {
return $Hbind_DASH_env_DASH_and_DASH_atoms28336588(bind_DASH_env_DASH_and_DASH_atoms4836587,A119,binds4814909,body4824910,l4804911,map24676,self4794912,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e65766577.stack[R.EXN_STACKHEIGHT++] = $ss65806581;
}
if(R.isPyretException($e65766577)) {
$e65766577.pyretStack.push(L[839]);
}
throw $e65766577;
}
var $ret65826583 = $Hbind_DASH_env_DASH_and_DASH_atoms28336588($z65786579,A119,binds4814909,body4824910,l4804911,map24676,self4794912,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret65826583;
};
var $Hbind_DASH_env_DASH_and_DASH_atoms28336588 = function(bind_DASH_env_DASH_and_DASH_atoms4836587,A119,binds4814909,body4824910,l4804911,map24676,self4794912,some7084,update_DASH_binding_DASH_expr3503975) {
var anf_extend13806645 = G(bind_DASH_env_DASH_and_DASH_atoms4836587,"env",L[851]);
var new_DASH_visitor4876602 = self4794912.extendWith({"env":anf_extend13806645});
var anf_arg13976601 = R.makeFunction(function(b4896605,a4906606) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[843],2,arguments);
}
var cases_DASH_val1096644 = b4896605;
var anf_fun13826617 = G(cases_DASH_val1096644,"_match",L[844]);
var anf_obj13936623 = R.makeFunction(function(l24916624,bind4926625,expr4936626) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[845],3,arguments);
}
var anf_fun13846640 = G(A119,"s-bind",L[850]);
var anf_bracket13856643 = G(bind4926625,"ann",L[849]);
var anf_fun13866637 = G(anf_bracket13856643,"visit",L[848]);
var anf_extend13876642 = G(bind_DASH_env_DASH_and_DASH_atoms4836587,"env",L[847]);
var anf_arg13886638 = self4794912.extendWith({"env":anf_extend13876642});
var $z66296630 = D;
var $f66356636 = function(_) {
return R.isFunction(anf_fun13866637)?anf_fun13866637.app(anf_arg13886638):R.ffi.throwNonFunApp(L[846],anf_fun13866637,[anf_arg13886638]);
};
try {
if(--R.GAS > 0) {
$z66296630 = $f66356636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66356636,
"from":L[846]});
}
} catch($e66276628) {
if(R.isCont($e66276628)) {
var $ss66316632 = {"from":L[846],
"go":function(anf_arg13896639) {
return $Hanf_arg28276641(anf_arg13896639,A119,a4906606,anf_fun13846640,expr4936626,l24916624,new_DASH_visitor4876602,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e66276628.stack[R.EXN_STACKHEIGHT++] = $ss66316632;
}
if(R.isPyretException($e66276628)) {
$e66276628.pyretStack.push(L[846]);
}
throw $e66276628;
}
var $ret66336634 = $Hanf_arg28276641($z66296630,A119,a4906606,anf_fun13846640,expr4936626,l24916624,new_DASH_visitor4876602,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret66336634;
});
var anf_arg13946618 = R.makeObject({"s-letrec-bind":anf_obj13936623});
var anf_arg13966619 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[844],0,arguments);
}
var ann_DASH_check_DASH_temp13956622 = R.throwNoBranchesMatched(L[844],("cases"));
return ann_DASH_check_DASH_temp13956622;
});
var $z66096610 = D;
var $f66156616 = function(_) {
return R.isFunction(anf_fun13826617)?anf_fun13826617.app(anf_arg13946618,anf_arg13966619):R.ffi.throwNonFunApp(L[843],anf_fun13826617,[anf_arg13946618,anf_arg13966619]);
};
try {
if(--R.GAS > 0) {
$z66096610 = $f66156616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66156616,
"from":L[843]});
}
} catch($e66076608) {
if(R.isCont($e66076608)) {
var $ss66116612 = {"from":L[843],
"go":function(ann_DASH_check_DASH_temp13816620) {
return $Hann_DASH_check_DASH_temp28286621(ann_DASH_check_DASH_temp13816620);
}};
$e66076608.stack[R.EXN_STACKHEIGHT++] = $ss66116612;
}
if(R.isPyretException($e66076608)) {
$e66076608.pyretStack.push(L[843]);
}
throw $e66076608;
}
var $ret66136614 = $Hann_DASH_check_DASH_temp28286621($z66096610);
++R.GAS;
return $ret66136614;
});
var anf_bracket13986604 = G(bind_DASH_env_DASH_and_DASH_atoms4836587,"atoms",L[842]);
var anf_fun13996599 = G(anf_bracket13986604,"reverse",L[841]);
var $z65916592 = D;
var $f65976598 = function(_) {
return R.isFunction(anf_fun13996599)?anf_fun13996599.app():R.ffi.throwNonFunApp(L[840],anf_fun13996599,[]);
};
try {
if(--R.GAS > 0) {
$z65916592 = $f65976598();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f65976598,
"from":L[840]});
}
} catch($e65896590) {
if(R.isCont($e65896590)) {
var $ss65936594 = {"from":L[840],
"go":function(anf_arg14006600) {
return $Hanf_arg28326603(anf_arg14006600,A119,anf_arg13976601,binds4814909,body4824910,l4804911,map24676,new_DASH_visitor4876602);
}};
$e65896590.stack[R.EXN_STACKHEIGHT++] = $ss65936594;
}
if(R.isPyretException($e65896590)) {
$e65896590.pyretStack.push(L[840]);
}
throw $e65896590;
}
var $ret65956596 = $Hanf_arg28326603($z65916592,A119,anf_arg13976601,binds4814909,body4824910,l4804911,map24676,new_DASH_visitor4876602);
++R.GAS;
return $ret65956596;
};
var $Hanf_arg28326603 = function(anf_arg14006600,A119,anf_arg13976601,binds4814909,body4824910,l4804911,map24676,new_DASH_visitor4876602) {
var $z66486649 = D;
var $f66546655 = function(_) {
return R.isFunction(map24676)?map24676.app(anf_arg13976601,binds4814909,anf_arg14006600):R.ffi.throwNonFunApp(L[852],map24676,[anf_arg13976601,binds4814909,anf_arg14006600]);
};
try {
if(--R.GAS > 0) {
$z66486649 = $f66546655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66546655,
"from":L[852]});
}
} catch($e66466647) {
if(R.isCont($e66466647)) {
var $ss66506651 = {"from":L[852],
"go":function(visit_DASH_binds4886656) {
return $Hvisit_DASH_binds28316657(visit_DASH_binds4886656,A119,body4824910,l4804911,new_DASH_visitor4876602);
}};
$e66466647.stack[R.EXN_STACKHEIGHT++] = $ss66506651;
}
if(R.isPyretException($e66466647)) {
$e66466647.pyretStack.push(L[852]);
}
throw $e66466647;
}
var $ret66526653 = $Hvisit_DASH_binds28316657($z66486649,A119,body4824910,l4804911,new_DASH_visitor4876602);
++R.GAS;
return $ret66526653;
};
var $Hvisit_DASH_binds28316657 = function(visit_DASH_binds4886656,A119,body4824910,l4804911,new_DASH_visitor4876602) {
var anf_fun14016668 = G(body4824910,"visit",L[854]);
var $z66606661 = D;
var $f66666667 = function(_) {
return R.isFunction(anf_fun14016668)?anf_fun14016668.app(new_DASH_visitor4876602):R.ffi.throwNonFunApp(L[853],anf_fun14016668,[new_DASH_visitor4876602]);
};
try {
if(--R.GAS > 0) {
$z66606661 = $f66666667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66666667,
"from":L[853]});
}
} catch($e66586659) {
if(R.isCont($e66586659)) {
var $ss66626663 = {"from":L[853],
"go":function(visit_DASH_body4966669) {
return $Hvisit_DASH_body28306670(visit_DASH_body4966669,A119,l4804911,visit_DASH_binds4886656);
}};
$e66586659.stack[R.EXN_STACKHEIGHT++] = $ss66626663;
}
if(R.isPyretException($e66586659)) {
$e66586659.pyretStack.push(L[853]);
}
throw $e66586659;
}
var $ret66646665 = $Hvisit_DASH_body28306670($z66606661,A119,l4804911,visit_DASH_binds4886656);
++R.GAS;
return $ret66646665;
};
var $Hvisit_DASH_body28306670 = function(visit_DASH_body4966669,A119,l4804911,visit_DASH_binds4886656) {
var anf_fun14026681 = G(A119,"s-letrec",L[855]);
var $z66736674 = D;
var $f66796680 = function(_) {
return R.isFunction(anf_fun14026681)?anf_fun14026681.app(l4804911,visit_DASH_binds4886656,visit_DASH_body4966669):R.ffi.throwNonFunApp(L[603],anf_fun14026681,[l4804911,visit_DASH_binds4886656,visit_DASH_body4966669]);
};
try {
if(--R.GAS > 0) {
$z66736674 = $f66796680();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66796680,
"from":L[603]});
}
} catch($e66716672) {
if(R.isCont($e66716672)) {
var $ss66756676 = {"from":L[603],
"go":function(ann_DASH_check_DASH_temp13646682) {
return $Hann_DASH_check_DASH_temp28296683(ann_DASH_check_DASH_temp13646682);
}};
$e66716672.stack[R.EXN_STACKHEIGHT++] = $ss66756676;
}
if(R.isPyretException($e66716672)) {
$e66716672.pyretStack.push(L[603]);
}
throw $e66716672;
}
var $ret66776678 = $Hann_DASH_check_DASH_temp28296683($z66736674);
++R.GAS;
return $ret66776678;
};
var $Hann_DASH_check_DASH_temp28296683 = function(ann_DASH_check_DASH_temp13646682) {
return ann_DASH_check_DASH_temp13646682;
};
var $Hann_DASH_check_DASH_temp28286621 = function(ann_DASH_check_DASH_temp13816620) {
return ann_DASH_check_DASH_temp13816620;
};
var $Hanf_arg28276641 = function(anf_arg13896639,A119,a4906606,anf_fun13846640,expr4936626,l24916624,new_DASH_visitor4876602,some7084,update_DASH_binding_DASH_expr3503975) {
var $z66866687 = D;
var $f66926693 = function(_) {
return R.isFunction(anf_fun13846640)?anf_fun13846640.app(l24916624,(false),a4906606,anf_arg13896639):R.ffi.throwNonFunApp(L[856],anf_fun13846640,[l24916624,(false),a4906606,anf_arg13896639]);
};
try {
if(--R.GAS > 0) {
$z66866687 = $f66926693();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f66926693,
"from":L[856]});
}
} catch($e66846685) {
if(R.isCont($e66846685)) {
var $ss66886689 = {"from":L[856],
"go":function(new_DASH_bind4946694) {
return $Hnew_DASH_bind28266695(new_DASH_bind4946694,A119,a4906606,expr4936626,l24916624,new_DASH_visitor4876602,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e66846685.stack[R.EXN_STACKHEIGHT++] = $ss66886689;
}
if(R.isPyretException($e66846685)) {
$e66846685.pyretStack.push(L[856]);
}
throw $e66846685;
}
var $ret66906691 = $Hnew_DASH_bind28266695($z66866687,A119,a4906606,expr4936626,l24916624,new_DASH_visitor4876602,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret66906691;
};
var $Hnew_DASH_bind28266695 = function(new_DASH_bind4946694,A119,a4906606,expr4936626,l24916624,new_DASH_visitor4876602,some7084,update_DASH_binding_DASH_expr3503975) {
var anf_fun13906706 = G(expr4936626,"visit",L[858]);
var $z66986699 = D;
var $f67046705 = function(_) {
return R.isFunction(anf_fun13906706)?anf_fun13906706.app(new_DASH_visitor4876602):R.ffi.throwNonFunApp(L[857],anf_fun13906706,[new_DASH_visitor4876602]);
};
try {
if(--R.GAS > 0) {
$z66986699 = $f67046705();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67046705,
"from":L[857]});
}
} catch($e66966697) {
if(R.isCont($e66966697)) {
var $ss67006701 = {"from":L[857],
"go":function(visit_DASH_expr4956707) {
return $Hvisit_DASH_expr28256708(visit_DASH_expr4956707,A119,a4906606,l24916624,new_DASH_bind4946694,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e66966697.stack[R.EXN_STACKHEIGHT++] = $ss67006701;
}
if(R.isPyretException($e66966697)) {
$e66966697.pyretStack.push(L[857]);
}
throw $e66966697;
}
var $ret67026703 = $Hvisit_DASH_expr28256708($z66986699,A119,a4906606,l24916624,new_DASH_bind4946694,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret67026703;
};
var $Hvisit_DASH_expr28256708 = function(visit_DASH_expr4956707,A119,a4906606,l24916624,new_DASH_bind4946694,some7084,update_DASH_binding_DASH_expr3503975) {
var $z67116712 = D;
var $f67176718 = function(_) {
return R.isFunction(some7084)?some7084.app(visit_DASH_expr4956707):R.ffi.throwNonFunApp(L[859],some7084,[visit_DASH_expr4956707]);
};
try {
if(--R.GAS > 0) {
$z67116712 = $f67176718();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67176718,
"from":L[859]});
}
} catch($e67096710) {
if(R.isCont($e67096710)) {
var $ss67136714 = {"from":L[859],
"go":function(anf_arg13916719) {
return $Hanf_arg28246720(anf_arg13916719,A119,a4906606,l24916624,new_DASH_bind4946694,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4956707);
}};
$e67096710.stack[R.EXN_STACKHEIGHT++] = $ss67136714;
}
if(R.isPyretException($e67096710)) {
$e67096710.pyretStack.push(L[859]);
}
throw $e67096710;
}
var $ret67156716 = $Hanf_arg28246720($z67116712,A119,a4906606,l24916624,new_DASH_bind4946694,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4956707);
++R.GAS;
return $ret67156716;
};
var $Hanf_arg28246720 = function(anf_arg13916719,A119,a4906606,l24916624,new_DASH_bind4946694,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4956707) {
var $z67236724 = D;
var $f67296730 = function(_) {
return R.isFunction(update_DASH_binding_DASH_expr3503975.$var)?update_DASH_binding_DASH_expr3503975.$var.app(a4906606,anf_arg13916719):R.ffi.throwNonFunApp(L[860],update_DASH_binding_DASH_expr3503975.$var,[a4906606,anf_arg13916719]);
};
try {
if(--R.GAS > 0) {
$z67236724 = $f67296730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67296730,
"from":L[860]});
}
} catch($e67216722) {
if(R.isCont($e67216722)) {
var $ss67256726 = {"from":L[860],
"go":function(anf_begin_app_dropped28216731) {
return $Hanf_begin_app_dropped28236732(anf_begin_app_dropped28216731,A119,l24916624,new_DASH_bind4946694,visit_DASH_expr4956707);
}};
$e67216722.stack[R.EXN_STACKHEIGHT++] = $ss67256726;
}
if(R.isPyretException($e67216722)) {
$e67216722.pyretStack.push(L[860]);
}
throw $e67216722;
}
var $ret67276728 = $Hanf_begin_app_dropped28236732($z67236724,A119,l24916624,new_DASH_bind4946694,visit_DASH_expr4956707);
++R.GAS;
return $ret67276728;
};
var $Hanf_begin_app_dropped28236732 = function(anf_begin_app_dropped28216731,A119,l24916624,new_DASH_bind4946694,visit_DASH_expr4956707) {
var anf_fun13926743 = G(A119,"s-letrec-bind",L[861]);
var $z67356736 = D;
var $f67416742 = function(_) {
return R.isFunction(anf_fun13926743)?anf_fun13926743.app(l24916624,new_DASH_bind4946694,visit_DASH_expr4956707):R.ffi.throwNonFunApp(L[845],anf_fun13926743,[l24916624,new_DASH_bind4946694,visit_DASH_expr4956707]);
};
try {
if(--R.GAS > 0) {
$z67356736 = $f67416742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67416742,
"from":L[845]});
}
} catch($e67336734) {
if(R.isCont($e67336734)) {
var $ss67376738 = {"from":L[845],
"go":function(ann_DASH_check_DASH_temp13836744) {
return $Hann_DASH_check_DASH_temp28226745(ann_DASH_check_DASH_temp13836744);
}};
$e67336734.stack[R.EXN_STACKHEIGHT++] = $ss67376738;
}
if(R.isPyretException($e67336734)) {
$e67336734.pyretStack.push(L[845]);
}
throw $e67336734;
}
var $ret67396740 = $Hann_DASH_check_DASH_temp28226745($z67356736);
++R.GAS;
return $ret67396740;
};
var $Hann_DASH_check_DASH_temp28226745 = function(ann_DASH_check_DASH_temp13836744) {
return ann_DASH_check_DASH_temp13836744;
};
var $Hatom_DASH_env28204930 = function(atom_DASH_env4864929,acc4844914,link3774) {
var anf_obj13716759 = G(atom_DASH_env4864929,"env",L[865]);
var anf_arg13726756 = G(atom_DASH_env4864929,"atom",L[864]);
var anf_arg13736757 = G(acc4844914,"atoms",L[863]);
var $z67486749 = D;
var $f67546755 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg13726756,anf_arg13736757):R.ffi.throwNonFunApp(L[862],link3774,[anf_arg13726756,anf_arg13736757]);
};
try {
if(--R.GAS > 0) {
$z67486749 = $f67546755();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67546755,
"from":L[862]});
}
} catch($e67466747) {
if(R.isCont($e67466747)) {
var $ss67506751 = {"from":L[862],
"go":function(anf_obj13746758) {
return $Hanf_obj28196760(anf_obj13746758,anf_obj13716759);
}};
$e67466747.stack[R.EXN_STACKHEIGHT++] = $ss67506751;
}
if(R.isPyretException($e67466747)) {
$e67466747.pyretStack.push(L[862]);
}
throw $e67466747;
}
var $ret67526753 = $Hanf_obj28196760($z67486749,anf_obj13716759);
++R.GAS;
return $ret67526753;
};
var $Hanf_obj28196760 = function(anf_obj13746758,anf_obj13716759) {
var ann_DASH_check_DASH_temp13656761 = R.makeObject({"env":anf_obj13716759,
"atoms":anf_obj13746758});
return ann_DASH_check_DASH_temp13656761;
};
var $Hanf_obj28184951 = function(anf_obj13554944,A119,anf_arg13524945,anf_obj13534946,binds4604947,body4614948,fold6171,l4594949,self4584950) {
var anf_arg13566772 = R.makeObject({"e":anf_obj13534946,
"bs":anf_obj13554944});
var $z67646765 = D;
var $f67706771 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg13524945,anf_arg13566772,binds4604947):R.ffi.throwNonFunApp(L[866],fold6171,[anf_arg13524945,anf_arg13566772,binds4604947]);
};
try {
if(--R.GAS > 0) {
$z67646765 = $f67706771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67706771,
"from":L[866]});
}
} catch($e67626763) {
if(R.isCont($e67626763)) {
var $ss67666767 = {"from":L[866],
"go":function(bound_DASH_env4626773) {
return $Hbound_DASH_env28176774(bound_DASH_env4626773,A119,body4614948,l4594949,self4584950);
}};
$e67626763.stack[R.EXN_STACKHEIGHT++] = $ss67666767;
}
if(R.isPyretException($e67626763)) {
$e67626763.pyretStack.push(L[866]);
}
throw $e67626763;
}
var $ret67686769 = $Hbound_DASH_env28176774($z67646765,A119,body4614948,l4594949,self4584950);
++R.GAS;
return $ret67686769;
};
var $Hbound_DASH_env28176774 = function(bound_DASH_env4626773,A119,body4614948,l4594949,self4584950) {
var anf_bracket13576788 = G(bound_DASH_env4626773,"bs",L[869]);
var anf_fun13586785 = G(anf_bracket13576788,"reverse",L[868]);
var $z67776778 = D;
var $f67836784 = function(_) {
return R.isFunction(anf_fun13586785)?anf_fun13586785.app():R.ffi.throwNonFunApp(L[867],anf_fun13586785,[]);
};
try {
if(--R.GAS > 0) {
$z67776778 = $f67836784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67836784,
"from":L[867]});
}
} catch($e67756776) {
if(R.isCont($e67756776)) {
var $ss67796780 = {"from":L[867],
"go":function(visit_DASH_binds4776786) {
return $Hvisit_DASH_binds28166787(visit_DASH_binds4776786,A119,body4614948,bound_DASH_env4626773,l4594949,self4584950);
}};
$e67756776.stack[R.EXN_STACKHEIGHT++] = $ss67796780;
}
if(R.isPyretException($e67756776)) {
$e67756776.pyretStack.push(L[867]);
}
throw $e67756776;
}
var $ret67816782 = $Hvisit_DASH_binds28166787($z67776778,A119,body4614948,bound_DASH_env4626773,l4594949,self4584950);
++R.GAS;
return $ret67816782;
};
var $Hvisit_DASH_binds28166787 = function(visit_DASH_binds4776786,A119,body4614948,bound_DASH_env4626773,l4594949,self4584950) {
var anf_fun13596799 = G(body4614948,"visit",L[872]);
var anf_extend13606803 = G(bound_DASH_env4626773,"e",L[871]);
var anf_arg13616800 = self4584950.extendWith({"env":anf_extend13606803});
var $z67916792 = D;
var $f67976798 = function(_) {
return R.isFunction(anf_fun13596799)?anf_fun13596799.app(anf_arg13616800):R.ffi.throwNonFunApp(L[870],anf_fun13596799,[anf_arg13616800]);
};
try {
if(--R.GAS > 0) {
$z67916792 = $f67976798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f67976798,
"from":L[870]});
}
} catch($e67896790) {
if(R.isCont($e67896790)) {
var $ss67936794 = {"from":L[870],
"go":function(visit_DASH_body4786801) {
return $Hvisit_DASH_body28156802(visit_DASH_body4786801,A119,l4594949,visit_DASH_binds4776786);
}};
$e67896790.stack[R.EXN_STACKHEIGHT++] = $ss67936794;
}
if(R.isPyretException($e67896790)) {
$e67896790.pyretStack.push(L[870]);
}
throw $e67896790;
}
var $ret67956796 = $Hvisit_DASH_body28156802($z67916792,A119,l4594949,visit_DASH_binds4776786);
++R.GAS;
return $ret67956796;
};
var $Hvisit_DASH_body28156802 = function(visit_DASH_body4786801,A119,l4594949,visit_DASH_binds4776786) {
var anf_fun13626814 = G(A119,"s-let-expr",L[873]);
var $z68066807 = D;
var $f68126813 = function(_) {
return R.isFunction(anf_fun13626814)?anf_fun13626814.app(l4594949,visit_DASH_binds4776786,visit_DASH_body4786801):R.ffi.throwNonFunApp(L[618],anf_fun13626814,[l4594949,visit_DASH_binds4776786,visit_DASH_body4786801]);
};
try {
if(--R.GAS > 0) {
$z68066807 = $f68126813();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68126813,
"from":L[618]});
}
} catch($e68046805) {
if(R.isCont($e68046805)) {
var $ss68086809 = {"from":L[618],
"go":function(ann_DASH_check_DASH_temp13006815) {
return $Hann_DASH_check_DASH_temp28146816(ann_DASH_check_DASH_temp13006815);
}};
$e68046805.stack[R.EXN_STACKHEIGHT++] = $ss68086809;
}
if(R.isPyretException($e68046805)) {
$e68046805.pyretStack.push(L[618]);
}
throw $e68046805;
}
var $ret68106811 = $Hann_DASH_check_DASH_temp28146816($z68066807);
++R.GAS;
return $ret68106811;
};
var $Hann_DASH_check_DASH_temp28146816 = function(ann_DASH_check_DASH_temp13006815) {
return ann_DASH_check_DASH_temp13006815;
};
var $Hann_DASH_check_DASH_temp28134968 = function(ann_DASH_check_DASH_temp13014967) {
return ann_DASH_check_DASH_temp13014967;
};
var $Hatom_DASH_env28124989 = function(atom_DASH_env4744988,A119,acc4634952,bind4724973,expr4734974,l24714972,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975) {
var anf_fun13306827 = G(expr4734974,"visit",L[876]);
var anf_extend13316831 = G(acc4634952,"e",L[875]);
var anf_arg13326828 = self4584950.extendWith({"env":anf_extend13316831});
var $z68196820 = D;
var $f68256826 = function(_) {
return R.isFunction(anf_fun13306827)?anf_fun13306827.app(anf_arg13326828):R.ffi.throwNonFunApp(L[874],anf_fun13306827,[anf_arg13326828]);
};
try {
if(--R.GAS > 0) {
$z68196820 = $f68256826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68256826,
"from":L[874]});
}
} catch($e68176818) {
if(R.isCont($e68176818)) {
var $ss68216822 = {"from":L[874],
"go":function(visit_DASH_expr4756829) {
return $Hvisit_DASH_expr28116830(visit_DASH_expr4756829,A119,acc4634952,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e68176818.stack[R.EXN_STACKHEIGHT++] = $ss68216822;
}
if(R.isPyretException($e68176818)) {
$e68176818.pyretStack.push(L[874]);
}
throw $e68176818;
}
var $ret68236824 = $Hvisit_DASH_expr28116830($z68196820,A119,acc4634952,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret68236824;
};
var $Hvisit_DASH_expr28116830 = function(visit_DASH_expr4756829,A119,acc4634952,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975) {
var anf_arg13336843 = G(atom_DASH_env4744988,"atom",L[878]);
var $z68346835 = D;
var $f68406841 = function(_) {
return R.isFunction(some7084)?some7084.app(visit_DASH_expr4756829):R.ffi.throwNonFunApp(L[877],some7084,[visit_DASH_expr4756829]);
};
try {
if(--R.GAS > 0) {
$z68346835 = $f68406841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68406841,
"from":L[877]});
}
} catch($e68326833) {
if(R.isCont($e68326833)) {
var $ss68366837 = {"from":L[877],
"go":function(anf_arg13346842) {
return $Hanf_arg28106844(anf_arg13346842,A119,acc4634952,anf_arg13336843,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4756829);
}};
$e68326833.stack[R.EXN_STACKHEIGHT++] = $ss68366837;
}
if(R.isPyretException($e68326833)) {
$e68326833.pyretStack.push(L[877]);
}
throw $e68326833;
}
var $ret68386839 = $Hanf_arg28106844($z68346835,A119,acc4634952,anf_arg13336843,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4756829);
++R.GAS;
return $ret68386839;
};
var $Hanf_arg28106844 = function(anf_arg13346842,A119,acc4634952,anf_arg13336843,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4756829) {
var $z68476848 = D;
var $f68536854 = function(_) {
return R.isFunction(update_DASH_binding_DASH_expr3503975.$var)?update_DASH_binding_DASH_expr3503975.$var.app(anf_arg13336843,anf_arg13346842):R.ffi.throwNonFunApp(L[879],update_DASH_binding_DASH_expr3503975.$var,[anf_arg13336843,anf_arg13346842]);
};
try {
if(--R.GAS > 0) {
$z68476848 = $f68536854();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68536854,
"from":L[879]});
}
} catch($e68456846) {
if(R.isCont($e68456846)) {
var $ss68496850 = {"from":L[879],
"go":function(anf_begin_app_dropped28046855) {
return $Hanf_begin_app_dropped28096856(anf_begin_app_dropped28046855,A119,acc4634952,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,visit_DASH_expr4756829);
}};
$e68456846.stack[R.EXN_STACKHEIGHT++] = $ss68496850;
}
if(R.isPyretException($e68456846)) {
$e68456846.pyretStack.push(L[879]);
}
throw $e68456846;
}
var $ret68516852 = $Hanf_begin_app_dropped28096856($z68476848,A119,acc4634952,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,visit_DASH_expr4756829);
++R.GAS;
return $ret68516852;
};
var $Hanf_begin_app_dropped28096856 = function(anf_begin_app_dropped28046855,A119,acc4634952,atom_DASH_env4744988,bind4724973,l24714972,link3774,self4584950,visit_DASH_expr4756829) {
var anf_fun13356872 = G(A119,"s-var-bind",L[887]);
var anf_fun13366873 = G(A119,"s-bind",L[886]);
var anf_arg13376870 = G(bind4724973,"shadows",L[885]);
var anf_arg13386871 = G(atom_DASH_env4744988,"atom",L[884]);
var anf_bracket13396876 = G(bind4724973,"ann",L[883]);
var anf_fun13406867 = G(anf_bracket13396876,"visit",L[882]);
var anf_extend13416875 = G(acc4634952,"e",L[881]);
var anf_arg13426868 = self4584950.extendWith({"env":anf_extend13416875});
var $z68596860 = D;
var $f68656866 = function(_) {
return R.isFunction(anf_fun13406867)?anf_fun13406867.app(anf_arg13426868):R.ffi.throwNonFunApp(L[880],anf_fun13406867,[anf_arg13426868]);
};
try {
if(--R.GAS > 0) {
$z68596860 = $f68656866();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68656866,
"from":L[880]});
}
} catch($e68576858) {
if(R.isCont($e68576858)) {
var $ss68616862 = {"from":L[880],
"go":function(anf_arg13436869) {
return $Hanf_arg28086874(anf_arg13436869,acc4634952,anf_arg13376870,anf_arg13386871,anf_fun13356872,anf_fun13366873,atom_DASH_env4744988,l24714972,link3774,visit_DASH_expr4756829);
}};
$e68576858.stack[R.EXN_STACKHEIGHT++] = $ss68616862;
}
if(R.isPyretException($e68576858)) {
$e68576858.pyretStack.push(L[880]);
}
throw $e68576858;
}
var $ret68636864 = $Hanf_arg28086874($z68596860,acc4634952,anf_arg13376870,anf_arg13386871,anf_fun13356872,anf_fun13366873,atom_DASH_env4744988,l24714972,link3774,visit_DASH_expr4756829);
++R.GAS;
return $ret68636864;
};
var $Hanf_arg28086874 = function(anf_arg13436869,acc4634952,anf_arg13376870,anf_arg13386871,anf_fun13356872,anf_fun13366873,atom_DASH_env4744988,l24714972,link3774,visit_DASH_expr4756829) {
var $z68796880 = D;
var $f68856886 = function(_) {
return R.isFunction(anf_fun13366873)?anf_fun13366873.app(l24714972,anf_arg13376870,anf_arg13386871,anf_arg13436869):R.ffi.throwNonFunApp(L[888],anf_fun13366873,[l24714972,anf_arg13376870,anf_arg13386871,anf_arg13436869]);
};
try {
if(--R.GAS > 0) {
$z68796880 = $f68856886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68856886,
"from":L[888]});
}
} catch($e68776878) {
if(R.isCont($e68776878)) {
var $ss68816882 = {"from":L[888],
"go":function(anf_arg13446887) {
return $Hanf_arg28076888(anf_arg13446887,acc4634952,anf_fun13356872,atom_DASH_env4744988,l24714972,link3774,visit_DASH_expr4756829);
}};
$e68776878.stack[R.EXN_STACKHEIGHT++] = $ss68816882;
}
if(R.isPyretException($e68776878)) {
$e68776878.pyretStack.push(L[888]);
}
throw $e68776878;
}
var $ret68836884 = $Hanf_arg28076888($z68796880,acc4634952,anf_fun13356872,atom_DASH_env4744988,l24714972,link3774,visit_DASH_expr4756829);
++R.GAS;
return $ret68836884;
};
var $Hanf_arg28076888 = function(anf_arg13446887,acc4634952,anf_fun13356872,atom_DASH_env4744988,l24714972,link3774,visit_DASH_expr4756829) {
var $z68916892 = D;
var $f68976898 = function(_) {
return R.isFunction(anf_fun13356872)?anf_fun13356872.app(l24714972,anf_arg13446887,visit_DASH_expr4756829):R.ffi.throwNonFunApp(L[889],anf_fun13356872,[l24714972,anf_arg13446887,visit_DASH_expr4756829]);
};
try {
if(--R.GAS > 0) {
$z68916892 = $f68976898();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f68976898,
"from":L[889]});
}
} catch($e68896890) {
if(R.isCont($e68896890)) {
var $ss68936894 = {"from":L[889],
"go":function(new_DASH_bind4766899) {
return $Hnew_DASH_bind28066900(new_DASH_bind4766899,acc4634952,atom_DASH_env4744988,link3774);
}};
$e68896890.stack[R.EXN_STACKHEIGHT++] = $ss68936894;
}
if(R.isPyretException($e68896890)) {
$e68896890.pyretStack.push(L[889]);
}
throw $e68896890;
}
var $ret68956896 = $Hnew_DASH_bind28066900($z68916892,acc4634952,atom_DASH_env4744988,link3774);
++R.GAS;
return $ret68956896;
};
var $Hnew_DASH_bind28066900 = function(new_DASH_bind4766899,acc4634952,atom_DASH_env4744988,link3774) {
var anf_obj13456913 = G(atom_DASH_env4744988,"env",L[892]);
var anf_arg13466911 = G(acc4634952,"bs",L[891]);
var $z69036904 = D;
var $f69096910 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_bind4766899,anf_arg13466911):R.ffi.throwNonFunApp(L[890],link3774,[new_DASH_bind4766899,anf_arg13466911]);
};
try {
if(--R.GAS > 0) {
$z69036904 = $f69096910();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69096910,
"from":L[890]});
}
} catch($e69016902) {
if(R.isCont($e69016902)) {
var $ss69056906 = {"from":L[890],
"go":function(anf_obj13476912) {
return $Hanf_obj28056914(anf_obj13476912,anf_obj13456913);
}};
$e69016902.stack[R.EXN_STACKHEIGHT++] = $ss69056906;
}
if(R.isPyretException($e69016902)) {
$e69016902.pyretStack.push(L[890]);
}
throw $e69016902;
}
var $ret69076908 = $Hanf_obj28056914($z69036904,anf_obj13456913);
++R.GAS;
return $ret69076908;
};
var $Hanf_obj28056914 = function(anf_obj13476912,anf_obj13456913) {
var ann_DASH_check_DASH_temp13266915 = R.makeObject({"e":anf_obj13456913,
"bs":anf_obj13476912});
return ann_DASH_check_DASH_temp13266915;
};
var $Hatom_DASH_env28035007 = function(atom_DASH_env4685006,A119,acc4634952,bind4664991,expr4674992,l24654990,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975) {
var anf_fun13076926 = G(expr4674992,"visit",L[895]);
var anf_extend13086930 = G(acc4634952,"e",L[894]);
var anf_arg13096927 = self4584950.extendWith({"env":anf_extend13086930});
var $z69186919 = D;
var $f69246925 = function(_) {
return R.isFunction(anf_fun13076926)?anf_fun13076926.app(anf_arg13096927):R.ffi.throwNonFunApp(L[893],anf_fun13076926,[anf_arg13096927]);
};
try {
if(--R.GAS > 0) {
$z69186919 = $f69246925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69246925,
"from":L[893]});
}
} catch($e69166917) {
if(R.isCont($e69166917)) {
var $ss69206921 = {"from":L[893],
"go":function(visit_DASH_expr4696928) {
return $Hvisit_DASH_expr28026929(visit_DASH_expr4696928,A119,acc4634952,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975);
}};
$e69166917.stack[R.EXN_STACKHEIGHT++] = $ss69206921;
}
if(R.isPyretException($e69166917)) {
$e69166917.pyretStack.push(L[893]);
}
throw $e69166917;
}
var $ret69226923 = $Hvisit_DASH_expr28026929($z69186919,A119,acc4634952,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975);
++R.GAS;
return $ret69226923;
};
var $Hvisit_DASH_expr28026929 = function(visit_DASH_expr4696928,A119,acc4634952,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,some7084,update_DASH_binding_DASH_expr3503975) {
var anf_arg13106942 = G(atom_DASH_env4685006,"atom",L[897]);
var $z69336934 = D;
var $f69396940 = function(_) {
return R.isFunction(some7084)?some7084.app(visit_DASH_expr4696928):R.ffi.throwNonFunApp(L[896],some7084,[visit_DASH_expr4696928]);
};
try {
if(--R.GAS > 0) {
$z69336934 = $f69396940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69396940,
"from":L[896]});
}
} catch($e69316932) {
if(R.isCont($e69316932)) {
var $ss69356936 = {"from":L[896],
"go":function(anf_arg13116941) {
return $Hanf_arg28016943(anf_arg13116941,A119,acc4634952,anf_arg13106942,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4696928);
}};
$e69316932.stack[R.EXN_STACKHEIGHT++] = $ss69356936;
}
if(R.isPyretException($e69316932)) {
$e69316932.pyretStack.push(L[896]);
}
throw $e69316932;
}
var $ret69376938 = $Hanf_arg28016943($z69336934,A119,acc4634952,anf_arg13106942,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4696928);
++R.GAS;
return $ret69376938;
};
var $Hanf_arg28016943 = function(anf_arg13116941,A119,acc4634952,anf_arg13106942,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,update_DASH_binding_DASH_expr3503975,visit_DASH_expr4696928) {
var $z69466947 = D;
var $f69526953 = function(_) {
return R.isFunction(update_DASH_binding_DASH_expr3503975.$var)?update_DASH_binding_DASH_expr3503975.$var.app(anf_arg13106942,anf_arg13116941):R.ffi.throwNonFunApp(L[898],update_DASH_binding_DASH_expr3503975.$var,[anf_arg13106942,anf_arg13116941]);
};
try {
if(--R.GAS > 0) {
$z69466947 = $f69526953();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69526953,
"from":L[898]});
}
} catch($e69446945) {
if(R.isCont($e69446945)) {
var $ss69486949 = {"from":L[898],
"go":function(anf_begin_app_dropped27956954) {
return $Hanf_begin_app_dropped28006955(anf_begin_app_dropped27956954,A119,acc4634952,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,visit_DASH_expr4696928);
}};
$e69446945.stack[R.EXN_STACKHEIGHT++] = $ss69486949;
}
if(R.isPyretException($e69446945)) {
$e69446945.pyretStack.push(L[898]);
}
throw $e69446945;
}
var $ret69506951 = $Hanf_begin_app_dropped28006955($z69466947,A119,acc4634952,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,visit_DASH_expr4696928);
++R.GAS;
return $ret69506951;
};
var $Hanf_begin_app_dropped28006955 = function(anf_begin_app_dropped27956954,A119,acc4634952,atom_DASH_env4685006,bind4664991,l24654990,link3774,self4584950,visit_DASH_expr4696928) {
var anf_fun13126971 = G(A119,"s-let-bind",L[906]);
var anf_fun13136972 = G(A119,"s-bind",L[905]);
var anf_arg13146969 = G(bind4664991,"shadows",L[904]);
var anf_arg13156970 = G(atom_DASH_env4685006,"atom",L[903]);
var anf_bracket13166975 = G(bind4664991,"ann",L[902]);
var anf_fun13176966 = G(anf_bracket13166975,"visit",L[901]);
var anf_extend13186974 = G(acc4634952,"e",L[900]);
var anf_arg13196967 = self4584950.extendWith({"env":anf_extend13186974});
var $z69586959 = D;
var $f69646965 = function(_) {
return R.isFunction(anf_fun13176966)?anf_fun13176966.app(anf_arg13196967):R.ffi.throwNonFunApp(L[899],anf_fun13176966,[anf_arg13196967]);
};
try {
if(--R.GAS > 0) {
$z69586959 = $f69646965();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69646965,
"from":L[899]});
}
} catch($e69566957) {
if(R.isCont($e69566957)) {
var $ss69606961 = {"from":L[899],
"go":function(anf_arg13206968) {
return $Hanf_arg27996973(anf_arg13206968,acc4634952,anf_arg13146969,anf_arg13156970,anf_fun13126971,anf_fun13136972,atom_DASH_env4685006,l24654990,link3774,visit_DASH_expr4696928);
}};
$e69566957.stack[R.EXN_STACKHEIGHT++] = $ss69606961;
}
if(R.isPyretException($e69566957)) {
$e69566957.pyretStack.push(L[899]);
}
throw $e69566957;
}
var $ret69626963 = $Hanf_arg27996973($z69586959,acc4634952,anf_arg13146969,anf_arg13156970,anf_fun13126971,anf_fun13136972,atom_DASH_env4685006,l24654990,link3774,visit_DASH_expr4696928);
++R.GAS;
return $ret69626963;
};
var $Hanf_arg27996973 = function(anf_arg13206968,acc4634952,anf_arg13146969,anf_arg13156970,anf_fun13126971,anf_fun13136972,atom_DASH_env4685006,l24654990,link3774,visit_DASH_expr4696928) {
var $z69786979 = D;
var $f69846985 = function(_) {
return R.isFunction(anf_fun13136972)?anf_fun13136972.app(l24654990,anf_arg13146969,anf_arg13156970,anf_arg13206968):R.ffi.throwNonFunApp(L[907],anf_fun13136972,[l24654990,anf_arg13146969,anf_arg13156970,anf_arg13206968]);
};
try {
if(--R.GAS > 0) {
$z69786979 = $f69846985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69846985,
"from":L[907]});
}
} catch($e69766977) {
if(R.isCont($e69766977)) {
var $ss69806981 = {"from":L[907],
"go":function(anf_arg13216986) {
return $Hanf_arg27986987(anf_arg13216986,acc4634952,anf_fun13126971,atom_DASH_env4685006,l24654990,link3774,visit_DASH_expr4696928);
}};
$e69766977.stack[R.EXN_STACKHEIGHT++] = $ss69806981;
}
if(R.isPyretException($e69766977)) {
$e69766977.pyretStack.push(L[907]);
}
throw $e69766977;
}
var $ret69826983 = $Hanf_arg27986987($z69786979,acc4634952,anf_fun13126971,atom_DASH_env4685006,l24654990,link3774,visit_DASH_expr4696928);
++R.GAS;
return $ret69826983;
};
var $Hanf_arg27986987 = function(anf_arg13216986,acc4634952,anf_fun13126971,atom_DASH_env4685006,l24654990,link3774,visit_DASH_expr4696928) {
var $z69906991 = D;
var $f69966997 = function(_) {
return R.isFunction(anf_fun13126971)?anf_fun13126971.app(l24654990,anf_arg13216986,visit_DASH_expr4696928):R.ffi.throwNonFunApp(L[908],anf_fun13126971,[l24654990,anf_arg13216986,visit_DASH_expr4696928]);
};
try {
if(--R.GAS > 0) {
$z69906991 = $f69966997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f69966997,
"from":L[908]});
}
} catch($e69886989) {
if(R.isCont($e69886989)) {
var $ss69926993 = {"from":L[908],
"go":function(new_DASH_bind4706998) {
return $Hnew_DASH_bind27976999(new_DASH_bind4706998,acc4634952,atom_DASH_env4685006,link3774);
}};
$e69886989.stack[R.EXN_STACKHEIGHT++] = $ss69926993;
}
if(R.isPyretException($e69886989)) {
$e69886989.pyretStack.push(L[908]);
}
throw $e69886989;
}
var $ret69946995 = $Hnew_DASH_bind27976999($z69906991,acc4634952,atom_DASH_env4685006,link3774);
++R.GAS;
return $ret69946995;
};
var $Hnew_DASH_bind27976999 = function(new_DASH_bind4706998,acc4634952,atom_DASH_env4685006,link3774) {
var anf_obj13227012 = G(atom_DASH_env4685006,"env",L[911]);
var anf_arg13237010 = G(acc4634952,"bs",L[910]);
var $z70027003 = D;
var $f70087009 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_bind4706998,anf_arg13237010):R.ffi.throwNonFunApp(L[909],link3774,[new_DASH_bind4706998,anf_arg13237010]);
};
try {
if(--R.GAS > 0) {
$z70027003 = $f70087009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70087009,
"from":L[909]});
}
} catch($e70007001) {
if(R.isCont($e70007001)) {
var $ss70047005 = {"from":L[909],
"go":function(anf_obj13247011) {
return $Hanf_obj27967013(anf_obj13247011,anf_obj13227012);
}};
$e70007001.stack[R.EXN_STACKHEIGHT++] = $ss70047005;
}
if(R.isPyretException($e70007001)) {
$e70007001.pyretStack.push(L[909]);
}
throw $e70007001;
}
var $ret70067007 = $Hanf_obj27967013($z70027003,anf_obj13227012);
++R.GAS;
return $ret70067007;
};
var $Hanf_obj27967013 = function(anf_obj13247011,anf_obj13227012) {
var ann_DASH_check_DASH_temp13037014 = R.makeObject({"e":anf_obj13227012,
"bs":anf_obj13247011});
return ann_DASH_check_DASH_temp13037014;
};
var $Hanf_obj27945028 = function(anf_obj12915020,A119,anf_arg12875021,anf_obj12885022,anf_obj12895023,binds4415024,body4425025,fold6171,l4405026,self4395027) {
var anf_arg12927025 = R.makeObject({"e":anf_obj12885022,
"te":anf_obj12895023,
"bs":anf_obj12915020});
var $z70177018 = D;
var $f70237024 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg12875021,anf_arg12927025,binds4415024):R.ffi.throwNonFunApp(L[912],fold6171,[anf_arg12875021,anf_arg12927025,binds4415024]);
};
try {
if(--R.GAS > 0) {
$z70177018 = $f70237024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70237024,
"from":L[912]});
}
} catch($e70157016) {
if(R.isCont($e70157016)) {
var $ss70197020 = {"from":L[912],
"go":function(bound_DASH_env4437026) {
return $Hbound_DASH_env27937027(bound_DASH_env4437026,A119,body4425025,l4405026,self4395027);
}};
$e70157016.stack[R.EXN_STACKHEIGHT++] = $ss70197020;
}
if(R.isPyretException($e70157016)) {
$e70157016.pyretStack.push(L[912]);
}
throw $e70157016;
}
var $ret70217022 = $Hbound_DASH_env27937027($z70177018,A119,body4425025,l4405026,self4395027);
++R.GAS;
return $ret70217022;
};
var $Hbound_DASH_env27937027 = function(bound_DASH_env4437026,A119,body4425025,l4405026,self4395027) {
var anf_fun12937038 = G(body4425025,"visit",L[916]);
var anf_extend12947042 = G(bound_DASH_env4437026,"e",L[915]);
var anf_extend12957043 = G(bound_DASH_env4437026,"te",L[914]);
var anf_arg12967039 = self4395027.extendWith({"env":anf_extend12947042,
"type-env":anf_extend12957043});
var $z70307031 = D;
var $f70367037 = function(_) {
return R.isFunction(anf_fun12937038)?anf_fun12937038.app(anf_arg12967039):R.ffi.throwNonFunApp(L[913],anf_fun12937038,[anf_arg12967039]);
};
try {
if(--R.GAS > 0) {
$z70307031 = $f70367037();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70367037,
"from":L[913]});
}
} catch($e70287029) {
if(R.isCont($e70287029)) {
var $ss70327033 = {"from":L[913],
"go":function(visit_DASH_body4577040) {
return $Hvisit_DASH_body27927041(visit_DASH_body4577040,A119,bound_DASH_env4437026,l4405026);
}};
$e70287029.stack[R.EXN_STACKHEIGHT++] = $ss70327033;
}
if(R.isPyretException($e70287029)) {
$e70287029.pyretStack.push(L[913]);
}
throw $e70287029;
}
var $ret70347035 = $Hvisit_DASH_body27927041($z70307031,A119,bound_DASH_env4437026,l4405026);
++R.GAS;
return $ret70347035;
};
var $Hvisit_DASH_body27927041 = function(visit_DASH_body4577040,A119,bound_DASH_env4437026,l4405026) {
var anf_fun12977054 = G(A119,"s-type-let-expr",L[918]);
var anf_arg12987055 = G(bound_DASH_env4437026,"bs",L[917]);
var $z70467047 = D;
var $f70527053 = function(_) {
return R.isFunction(anf_fun12977054)?anf_fun12977054.app(l4405026,anf_arg12987055,visit_DASH_body4577040):R.ffi.throwNonFunApp(L[630],anf_fun12977054,[l4405026,anf_arg12987055,visit_DASH_body4577040]);
};
try {
if(--R.GAS > 0) {
$z70467047 = $f70527053();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70527053,
"from":L[630]});
}
} catch($e70447045) {
if(R.isCont($e70447045)) {
var $ss70487049 = {"from":L[630],
"go":function(ann_DASH_check_DASH_temp12517056) {
return $Hann_DASH_check_DASH_temp27917057(ann_DASH_check_DASH_temp12517056);
}};
$e70447045.stack[R.EXN_STACKHEIGHT++] = $ss70487049;
}
if(R.isPyretException($e70447045)) {
$e70447045.pyretStack.push(L[630]);
}
throw $e70447045;
}
var $ret70507051 = $Hann_DASH_check_DASH_temp27917057($z70467047);
++R.GAS;
return $ret70507051;
};
var $Hann_DASH_check_DASH_temp27917057 = function(ann_DASH_check_DASH_temp12517056) {
return ann_DASH_check_DASH_temp12517056;
};
var $Hann_DASH_check_DASH_temp27905045 = function(ann_DASH_check_DASH_temp12525044) {
return ann_DASH_check_DASH_temp12525044;
};
var $Hatom_DASH_env_DASH_t27895064 = function(atom_DASH_env_DASH_t4545063,A119,acc4445029,bindings3463955,l24515049,let_DASH_bind29398,link3774,make_DASH_atom_DASH_for3483971,none6979,tname4535051,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_arg12737068 = G(acc4445029,"e",L[920]);
var $z70607061 = D;
var $f70667067 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(tname4535051,(false),anf_arg12737068,bindings3463955,let_DASH_bind29398.$var):R.ffi.throwNonFunApp(L[919],make_DASH_atom_DASH_for3483971.$var,[tname4535051,(false),anf_arg12737068,bindings3463955,let_DASH_bind29398.$var]);
};
try {
if(--R.GAS > 0) {
$z70607061 = $f70667067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70667067,
"from":L[919]});
}
} catch($e70587059) {
if(R.isCont($e70587059)) {
var $ss70627063 = {"from":L[919],
"go":function(atom_DASH_env4557069) {
return $Hatom_DASH_env27887070(atom_DASH_env4557069,A119,acc4445029,atom_DASH_env_DASH_t4545063,l24515049,link3774,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e70587059.stack[R.EXN_STACKHEIGHT++] = $ss70627063;
}
if(R.isPyretException($e70587059)) {
$e70587059.pyretStack.push(L[919]);
}
throw $e70587059;
}
var $ret70647065 = $Hatom_DASH_env27887070($z70607061,A119,acc4445029,atom_DASH_env_DASH_t4545063,l24515049,link3774,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret70647065;
};
var $Hatom_DASH_env27887070 = function(atom_DASH_env4557069,A119,acc4445029,atom_DASH_env_DASH_t4545063,l24515049,link3774,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_fun12747081 = G(A119,"s-newtype-bind",L[924]);
var anf_arg12757082 = G(atom_DASH_env_DASH_t4545063,"atom",L[923]);
var anf_arg12767083 = G(atom_DASH_env4557069,"atom",L[922]);
var $z70737074 = D;
var $f70797080 = function(_) {
return R.isFunction(anf_fun12747081)?anf_fun12747081.app(l24515049,anf_arg12757082,anf_arg12767083):R.ffi.throwNonFunApp(L[921],anf_fun12747081,[l24515049,anf_arg12757082,anf_arg12767083]);
};
try {
if(--R.GAS > 0) {
$z70737074 = $f70797080();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70797080,
"from":L[921]});
}
} catch($e70717072) {
if(R.isCont($e70717072)) {
var $ss70757076 = {"from":L[921],
"go":function(new_DASH_bind4567084) {
return $Hnew_DASH_bind27877085(new_DASH_bind4567084,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e70717072.stack[R.EXN_STACKHEIGHT++] = $ss70757076;
}
if(R.isPyretException($e70717072)) {
$e70717072.pyretStack.push(L[921]);
}
throw $e70717072;
}
var $ret70777078 = $Hnew_DASH_bind27877085($z70737074,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret70777078;
};
var $Hnew_DASH_bind27877085 = function(new_DASH_bind4567084,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_arg12777096 = G(atom_DASH_env4557069,"atom",L[926]);
var $z70887089 = D;
var $f70947095 = function(_) {
return R.isFunction(update_DASH_binding_DASH_expr3503975.$var)?update_DASH_binding_DASH_expr3503975.$var.app(anf_arg12777096,none6979):R.ffi.throwNonFunApp(L[925],update_DASH_binding_DASH_expr3503975.$var,[anf_arg12777096,none6979]);
};
try {
if(--R.GAS > 0) {
$z70887089 = $f70947095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f70947095,
"from":L[925]});
}
} catch($e70867087) {
if(R.isCont($e70867087)) {
var $ss70907091 = {"from":L[925],
"go":function(anf_begin_app_dropped27827097) {
return $Hanf_begin_app_dropped27867098(anf_begin_app_dropped27827097,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,new_DASH_bind4567084,none6979,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e70867087.stack[R.EXN_STACKHEIGHT++] = $ss70907091;
}
if(R.isPyretException($e70867087)) {
$e70867087.pyretStack.push(L[925]);
}
throw $e70867087;
}
var $ret70927093 = $Hanf_begin_app_dropped27867098($z70887089,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,new_DASH_bind4567084,none6979,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret70927093;
};
var $Hanf_begin_app_dropped27867098 = function(anf_begin_app_dropped27827097,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,new_DASH_bind4567084,none6979,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_arg12787109 = G(atom_DASH_env_DASH_t4545063,"atom",L[928]);
var $z71017102 = D;
var $f71077108 = function(_) {
return R.isFunction(update_DASH_type_DASH_binding_DASH_ann3493973.$var)?update_DASH_type_DASH_binding_DASH_ann3493973.$var.app(anf_arg12787109,none6979):R.ffi.throwNonFunApp(L[927],update_DASH_type_DASH_binding_DASH_ann3493973.$var,[anf_arg12787109,none6979]);
};
try {
if(--R.GAS > 0) {
$z71017102 = $f71077108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71077108,
"from":L[927]});
}
} catch($e70997100) {
if(R.isCont($e70997100)) {
var $ss71037104 = {"from":L[927],
"go":function(anf_begin_app_dropped27837110) {
return $Hanf_begin_app_dropped27857111(anf_begin_app_dropped27837110,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,new_DASH_bind4567084);
}};
$e70997100.stack[R.EXN_STACKHEIGHT++] = $ss71037104;
}
if(R.isPyretException($e70997100)) {
$e70997100.pyretStack.push(L[927]);
}
throw $e70997100;
}
var $ret71057106 = $Hanf_begin_app_dropped27857111($z71017102,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,new_DASH_bind4567084);
++R.GAS;
return $ret71057106;
};
var $Hanf_begin_app_dropped27857111 = function(anf_begin_app_dropped27837110,acc4445029,atom_DASH_env_DASH_t4545063,atom_DASH_env4557069,link3774,new_DASH_bind4567084) {
var anf_obj12797124 = G(atom_DASH_env4557069,"env",L[932]);
var anf_obj12807125 = G(atom_DASH_env_DASH_t4545063,"env",L[931]);
var anf_arg12817122 = G(acc4445029,"bs",L[930]);
var $z71147115 = D;
var $f71207121 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_bind4567084,anf_arg12817122):R.ffi.throwNonFunApp(L[929],link3774,[new_DASH_bind4567084,anf_arg12817122]);
};
try {
if(--R.GAS > 0) {
$z71147115 = $f71207121();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71207121,
"from":L[929]});
}
} catch($e71127113) {
if(R.isCont($e71127113)) {
var $ss71167117 = {"from":L[929],
"go":function(anf_obj12827123) {
return $Hanf_obj27847126(anf_obj12827123,anf_obj12797124,anf_obj12807125);
}};
$e71127113.stack[R.EXN_STACKHEIGHT++] = $ss71167117;
}
if(R.isPyretException($e71127113)) {
$e71127113.pyretStack.push(L[929]);
}
throw $e71127113;
}
var $ret71187119 = $Hanf_obj27847126($z71147115,anf_obj12797124,anf_obj12807125);
++R.GAS;
return $ret71187119;
};
var $Hanf_obj27847126 = function(anf_obj12827123,anf_obj12797124,anf_obj12807125) {
var ann_DASH_check_DASH_temp12717127 = R.makeObject({"e":anf_obj12797124,
"te":anf_obj12807125,
"bs":anf_obj12827123});
return ann_DASH_check_DASH_temp12717127;
};
var $Hatom_DASH_env27815080 = function(atom_DASH_env4495079,A119,acc4445029,ann4485067,l24465065,link3774,self4395027,some7084,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_fun12567142 = G(A119,"s-type-bind",L[938]);
var anf_arg12577141 = G(atom_DASH_env4495079,"atom",L[937]);
var anf_fun12587138 = G(ann4485067,"visit",L[936]);
var anf_extend12597144 = G(acc4445029,"e",L[935]);
var anf_extend12607145 = G(acc4445029,"te",L[934]);
var anf_arg12617139 = self4395027.extendWith({"env":anf_extend12597144,
"type-env":anf_extend12607145});
var $z71307131 = D;
var $f71367137 = function(_) {
return R.isFunction(anf_fun12587138)?anf_fun12587138.app(anf_arg12617139):R.ffi.throwNonFunApp(L[933],anf_fun12587138,[anf_arg12617139]);
};
try {
if(--R.GAS > 0) {
$z71307131 = $f71367137();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71367137,
"from":L[933]});
}
} catch($e71287129) {
if(R.isCont($e71287129)) {
var $ss71327133 = {"from":L[933],
"go":function(anf_arg12627140) {
return $Hanf_arg27807143(anf_arg12627140,acc4445029,anf_arg12577141,anf_fun12567142,atom_DASH_env4495079,l24465065,link3774,some7084,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e71287129.stack[R.EXN_STACKHEIGHT++] = $ss71327133;
}
if(R.isPyretException($e71287129)) {
$e71287129.pyretStack.push(L[933]);
}
throw $e71287129;
}
var $ret71347135 = $Hanf_arg27807143($z71307131,acc4445029,anf_arg12577141,anf_fun12567142,atom_DASH_env4495079,l24465065,link3774,some7084,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret71347135;
};
var $Hanf_arg27807143 = function(anf_arg12627140,acc4445029,anf_arg12577141,anf_fun12567142,atom_DASH_env4495079,l24465065,link3774,some7084,update_DASH_type_DASH_binding_DASH_ann3493973) {
var $z71487149 = D;
var $f71547155 = function(_) {
return R.isFunction(anf_fun12567142)?anf_fun12567142.app(l24465065,anf_arg12577141,anf_arg12627140):R.ffi.throwNonFunApp(L[939],anf_fun12567142,[l24465065,anf_arg12577141,anf_arg12627140]);
};
try {
if(--R.GAS > 0) {
$z71487149 = $f71547155();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71547155,
"from":L[939]});
}
} catch($e71467147) {
if(R.isCont($e71467147)) {
var $ss71507151 = {"from":L[939],
"go":function(new_DASH_bind4507156) {
return $Hnew_DASH_bind27797157(new_DASH_bind4507156,acc4445029,atom_DASH_env4495079,link3774,some7084,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e71467147.stack[R.EXN_STACKHEIGHT++] = $ss71507151;
}
if(R.isPyretException($e71467147)) {
$e71467147.pyretStack.push(L[939]);
}
throw $e71467147;
}
var $ret71527153 = $Hnew_DASH_bind27797157($z71487149,acc4445029,atom_DASH_env4495079,link3774,some7084,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret71527153;
};
var $Hnew_DASH_bind27797157 = function(new_DASH_bind4507156,acc4445029,atom_DASH_env4495079,link3774,some7084,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_arg12637170 = G(atom_DASH_env4495079,"atom",L[942]);
var anf_arg12647168 = G(new_DASH_bind4507156,"ann",L[941]);
var $z71607161 = D;
var $f71667167 = function(_) {
return R.isFunction(some7084)?some7084.app(anf_arg12647168):R.ffi.throwNonFunApp(L[940],some7084,[anf_arg12647168]);
};
try {
if(--R.GAS > 0) {
$z71607161 = $f71667167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71667167,
"from":L[940]});
}
} catch($e71587159) {
if(R.isCont($e71587159)) {
var $ss71627163 = {"from":L[940],
"go":function(anf_arg12657169) {
return $Hanf_arg27787171(anf_arg12657169,acc4445029,anf_arg12637170,atom_DASH_env4495079,link3774,new_DASH_bind4507156,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e71587159.stack[R.EXN_STACKHEIGHT++] = $ss71627163;
}
if(R.isPyretException($e71587159)) {
$e71587159.pyretStack.push(L[940]);
}
throw $e71587159;
}
var $ret71647165 = $Hanf_arg27787171($z71607161,acc4445029,anf_arg12637170,atom_DASH_env4495079,link3774,new_DASH_bind4507156,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret71647165;
};
var $Hanf_arg27787171 = function(anf_arg12657169,acc4445029,anf_arg12637170,atom_DASH_env4495079,link3774,new_DASH_bind4507156,update_DASH_type_DASH_binding_DASH_ann3493973) {
var $z71747175 = D;
var $f71807181 = function(_) {
return R.isFunction(update_DASH_type_DASH_binding_DASH_ann3493973.$var)?update_DASH_type_DASH_binding_DASH_ann3493973.$var.app(anf_arg12637170,anf_arg12657169):R.ffi.throwNonFunApp(L[943],update_DASH_type_DASH_binding_DASH_ann3493973.$var,[anf_arg12637170,anf_arg12657169]);
};
try {
if(--R.GAS > 0) {
$z71747175 = $f71807181();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71807181,
"from":L[943]});
}
} catch($e71727173) {
if(R.isCont($e71727173)) {
var $ss71767177 = {"from":L[943],
"go":function(anf_begin_app_dropped27757182) {
return $Hanf_begin_app_dropped27777183(anf_begin_app_dropped27757182,acc4445029,atom_DASH_env4495079,link3774,new_DASH_bind4507156);
}};
$e71727173.stack[R.EXN_STACKHEIGHT++] = $ss71767177;
}
if(R.isPyretException($e71727173)) {
$e71727173.pyretStack.push(L[943]);
}
throw $e71727173;
}
var $ret71787179 = $Hanf_begin_app_dropped27777183($z71747175,acc4445029,atom_DASH_env4495079,link3774,new_DASH_bind4507156);
++R.GAS;
return $ret71787179;
};
var $Hanf_begin_app_dropped27777183 = function(anf_begin_app_dropped27757182,acc4445029,atom_DASH_env4495079,link3774,new_DASH_bind4507156) {
var anf_obj12667196 = G(acc4445029,"e",L[947]);
var anf_obj12677197 = G(atom_DASH_env4495079,"env",L[946]);
var anf_arg12687194 = G(acc4445029,"bs",L[945]);
var $z71867187 = D;
var $f71927193 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_bind4507156,anf_arg12687194):R.ffi.throwNonFunApp(L[944],link3774,[new_DASH_bind4507156,anf_arg12687194]);
};
try {
if(--R.GAS > 0) {
$z71867187 = $f71927193();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f71927193,
"from":L[944]});
}
} catch($e71847185) {
if(R.isCont($e71847185)) {
var $ss71887189 = {"from":L[944],
"go":function(anf_obj12697195) {
return $Hanf_obj27767198(anf_obj12697195,anf_obj12667196,anf_obj12677197);
}};
$e71847185.stack[R.EXN_STACKHEIGHT++] = $ss71887189;
}
if(R.isPyretException($e71847185)) {
$e71847185.pyretStack.push(L[944]);
}
throw $e71847185;
}
var $ret71907191 = $Hanf_obj27767198($z71867187,anf_obj12667196,anf_obj12677197);
++R.GAS;
return $ret71907191;
};
var $Hanf_obj27767198 = function(anf_obj12697195,anf_obj12667196,anf_obj12677197) {
var ann_DASH_check_DASH_temp12547199 = R.makeObject({"e":anf_obj12667196,
"te":anf_obj12677197,
"bs":anf_obj12697195});
return ann_DASH_check_DASH_temp12547199;
};
var $Hanf_obj27745103 = function(anf_obj12405093,A119,_provide_DASH_types4265094,_provide4255095,anf_arg12365096,anf_obj12375097,anf_obj12385098,body4285099,fold6171,imports4275100,l4245101,self4235102) {
var anf_arg12417210 = R.makeObject({"e":anf_obj12375097,
"te":anf_obj12385098,
"imps":anf_obj12405093});
var $z72027203 = D;
var $f72087209 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg12365096,anf_arg12417210,imports4275100):R.ffi.throwNonFunApp(L[948],fold6171,[anf_arg12365096,anf_arg12417210,imports4275100]);
};
try {
if(--R.GAS > 0) {
$z72027203 = $f72087209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72087209,
"from":L[948]});
}
} catch($e72007201) {
if(R.isCont($e72007201)) {
var $ss72047205 = {"from":L[948],
"go":function(imports_DASH_and_DASH_env4297211) {
return $Himports_DASH_and_DASH_env27737212(imports_DASH_and_DASH_env4297211,A119,_provide_DASH_types4265094,_provide4255095,body4285099,l4245101,self4235102);
}};
$e72007201.stack[R.EXN_STACKHEIGHT++] = $ss72047205;
}
if(R.isPyretException($e72007201)) {
$e72007201.pyretStack.push(L[948]);
}
throw $e72007201;
}
var $ret72067207 = $Himports_DASH_and_DASH_env27737212($z72027203,A119,_provide_DASH_types4265094,_provide4255095,body4285099,l4245101,self4235102);
++R.GAS;
return $ret72067207;
};
var $Himports_DASH_and_DASH_env27737212 = function(imports_DASH_and_DASH_env4297211,A119,_provide_DASH_types4265094,_provide4255095,body4285099,l4245101,self4235102) {
var anf_fun12427223 = G(body4285099,"visit",L[952]);
var anf_extend12437227 = G(imports_DASH_and_DASH_env4297211,"e",L[951]);
var anf_extend12447228 = G(imports_DASH_and_DASH_env4297211,"te",L[950]);
var anf_arg12457224 = self4235102.extendWith({"env":anf_extend12437227,
"type-env":anf_extend12447228});
var $z72157216 = D;
var $f72217222 = function(_) {
return R.isFunction(anf_fun12427223)?anf_fun12427223.app(anf_arg12457224):R.ffi.throwNonFunApp(L[949],anf_fun12427223,[anf_arg12457224]);
};
try {
if(--R.GAS > 0) {
$z72157216 = $f72217222();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72217222,
"from":L[949]});
}
} catch($e72137214) {
if(R.isCont($e72137214)) {
var $ss72177218 = {"from":L[949],
"go":function(visit_DASH_body4387225) {
return $Hvisit_DASH_body27727226(visit_DASH_body4387225,A119,_provide_DASH_types4265094,_provide4255095,imports_DASH_and_DASH_env4297211,l4245101);
}};
$e72137214.stack[R.EXN_STACKHEIGHT++] = $ss72177218;
}
if(R.isPyretException($e72137214)) {
$e72137214.pyretStack.push(L[949]);
}
throw $e72137214;
}
var $ret72197220 = $Hvisit_DASH_body27727226($z72157216,A119,_provide_DASH_types4265094,_provide4255095,imports_DASH_and_DASH_env4297211,l4245101);
++R.GAS;
return $ret72197220;
};
var $Hvisit_DASH_body27727226 = function(visit_DASH_body4387225,A119,_provide_DASH_types4265094,_provide4255095,imports_DASH_and_DASH_env4297211,l4245101) {
var anf_fun12467241 = G(A119,"s-program",L[956]);
var anf_bracket12477243 = G(imports_DASH_and_DASH_env4297211,"imps",L[955]);
var anf_fun12487239 = G(anf_bracket12477243,"reverse",L[954]);
var $z72317232 = D;
var $f72377238 = function(_) {
return R.isFunction(anf_fun12487239)?anf_fun12487239.app():R.ffi.throwNonFunApp(L[953],anf_fun12487239,[]);
};
try {
if(--R.GAS > 0) {
$z72317232 = $f72377238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72377238,
"from":L[953]});
}
} catch($e72297230) {
if(R.isCont($e72297230)) {
var $ss72337234 = {"from":L[953],
"go":function(anf_arg12497240) {
return $Hanf_arg27717242(anf_arg12497240,_provide_DASH_types4265094,_provide4255095,anf_fun12467241,l4245101,visit_DASH_body4387225);
}};
$e72297230.stack[R.EXN_STACKHEIGHT++] = $ss72337234;
}
if(R.isPyretException($e72297230)) {
$e72297230.pyretStack.push(L[953]);
}
throw $e72297230;
}
var $ret72357236 = $Hanf_arg27717242($z72317232,_provide_DASH_types4265094,_provide4255095,anf_fun12467241,l4245101,visit_DASH_body4387225);
++R.GAS;
return $ret72357236;
};
var $Hanf_arg27717242 = function(anf_arg12497240,_provide_DASH_types4265094,_provide4255095,anf_fun12467241,l4245101,visit_DASH_body4387225) {
var $z72467247 = D;
var $f72527253 = function(_) {
return R.isFunction(anf_fun12467241)?anf_fun12467241.app(l4245101,_provide4255095,_provide_DASH_types4265094,anf_arg12497240,visit_DASH_body4387225):R.ffi.throwNonFunApp(L[639],anf_fun12467241,[l4245101,_provide4255095,_provide_DASH_types4265094,anf_arg12497240,visit_DASH_body4387225]);
};
try {
if(--R.GAS > 0) {
$z72467247 = $f72527253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72527253,
"from":L[639]});
}
} catch($e72447245) {
if(R.isCont($e72447245)) {
var $ss72487249 = {"from":L[639],
"go":function(ann_DASH_check_DASH_temp12167254) {
return $Hann_DASH_check_DASH_temp27707255(ann_DASH_check_DASH_temp12167254);
}};
$e72447245.stack[R.EXN_STACKHEIGHT++] = $ss72487249;
}
if(R.isPyretException($e72447245)) {
$e72447245.pyretStack.push(L[639]);
}
throw $e72447245;
}
var $ret72507251 = $Hann_DASH_check_DASH_temp27707255($z72467247);
++R.GAS;
return $ret72507251;
};
var $Hann_DASH_check_DASH_temp27707255 = function(ann_DASH_check_DASH_temp12167254) {
return ann_DASH_check_DASH_temp12167254;
};
var $Hann_DASH_check_DASH_temp27695120 = function(ann_DASH_check_DASH_temp12175119) {
return ann_DASH_check_DASH_temp12175119;
};
var $Hatom_DASH_env27685138 = function(atom_DASH_env4355137,A119,acc4305104,file4335124,l24325123,let_DASH_type_DASH_bind304120,link3774,make_DASH_atom_DASH_for3483971,name4345125,none6979,some7084,type_DASH_bindings3473969,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_arg12217266 = G(acc4305104,"te",L[958]);
var $z72587259 = D;
var $f72647265 = function(_) {
return R.isFunction(make_DASH_atom_DASH_for3483971.$var)?make_DASH_atom_DASH_for3483971.$var.app(name4345125,(false),anf_arg12217266,type_DASH_bindings3473969,let_DASH_type_DASH_bind304120.$var):R.ffi.throwNonFunApp(L[957],make_DASH_atom_DASH_for3483971.$var,[name4345125,(false),anf_arg12217266,type_DASH_bindings3473969,let_DASH_type_DASH_bind304120.$var]);
};
try {
if(--R.GAS > 0) {
$z72587259 = $f72647265();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72647265,
"from":L[957]});
}
} catch($e72567257) {
if(R.isCont($e72567257)) {
var $ss72607261 = {"from":L[957],
"go":function(atom_DASH_env_DASH_t4367267) {
return $Hatom_DASH_env_DASH_t27677268(atom_DASH_env_DASH_t4367267,A119,acc4305104,atom_DASH_env4355137,file4335124,l24325123,link3774,none6979,some7084,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e72567257.stack[R.EXN_STACKHEIGHT++] = $ss72607261;
}
if(R.isPyretException($e72567257)) {
$e72567257.pyretStack.push(L[957]);
}
throw $e72567257;
}
var $ret72627263 = $Hatom_DASH_env_DASH_t27677268($z72587259,A119,acc4305104,atom_DASH_env4355137,file4335124,l24325123,link3774,none6979,some7084,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret72627263;
};
var $Hatom_DASH_env_DASH_t27677268 = function(atom_DASH_env_DASH_t4367267,A119,acc4305104,atom_DASH_env4355137,file4335124,l24325123,link3774,none6979,some7084,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_fun12227279 = G(A119,"s-import-types",L[962]);
var anf_arg12237280 = G(atom_DASH_env4355137,"atom",L[961]);
var anf_arg12247281 = G(atom_DASH_env_DASH_t4367267,"atom",L[960]);
var $z72717272 = D;
var $f72777278 = function(_) {
return R.isFunction(anf_fun12227279)?anf_fun12227279.app(l24325123,file4335124,anf_arg12237280,anf_arg12247281):R.ffi.throwNonFunApp(L[959],anf_fun12227279,[l24325123,file4335124,anf_arg12237280,anf_arg12247281]);
};
try {
if(--R.GAS > 0) {
$z72717272 = $f72777278();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72777278,
"from":L[959]});
}
} catch($e72697270) {
if(R.isCont($e72697270)) {
var $ss72737274 = {"from":L[959],
"go":function(new_DASH_header4377282) {
return $Hnew_DASH_header27667283(new_DASH_header4377282,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,none6979,some7084,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e72697270.stack[R.EXN_STACKHEIGHT++] = $ss72737274;
}
if(R.isPyretException($e72697270)) {
$e72697270.pyretStack.push(L[959]);
}
throw $e72697270;
}
var $ret72757276 = $Hnew_DASH_header27667283($z72717272,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,none6979,some7084,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret72757276;
};
var $Hnew_DASH_header27667283 = function(new_DASH_header4377282,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,none6979,some7084,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_arg12257295 = G(atom_DASH_env4355137,"atom",L[964]);
var $z72867287 = D;
var $f72927293 = function(_) {
return R.isFunction(some7084)?some7084.app(new_DASH_header4377282):R.ffi.throwNonFunApp(L[963],some7084,[new_DASH_header4377282]);
};
try {
if(--R.GAS > 0) {
$z72867287 = $f72927293();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f72927293,
"from":L[963]});
}
} catch($e72847285) {
if(R.isCont($e72847285)) {
var $ss72887289 = {"from":L[963],
"go":function(anf_arg12267294) {
return $Hanf_arg27657296(anf_arg12267294,acc4305104,anf_arg12257295,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e72847285.stack[R.EXN_STACKHEIGHT++] = $ss72887289;
}
if(R.isPyretException($e72847285)) {
$e72847285.pyretStack.push(L[963]);
}
throw $e72847285;
}
var $ret72907291 = $Hanf_arg27657296($z72867287,acc4305104,anf_arg12257295,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret72907291;
};
var $Hanf_arg27657296 = function(anf_arg12267294,acc4305104,anf_arg12257295,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282,none6979,update_DASH_binding_DASH_expr3503975,update_DASH_type_DASH_binding_DASH_ann3493973) {
var $z72997300 = D;
var $f73057306 = function(_) {
return R.isFunction(update_DASH_binding_DASH_expr3503975.$var)?update_DASH_binding_DASH_expr3503975.$var.app(anf_arg12257295,anf_arg12267294):R.ffi.throwNonFunApp(L[965],update_DASH_binding_DASH_expr3503975.$var,[anf_arg12257295,anf_arg12267294]);
};
try {
if(--R.GAS > 0) {
$z72997300 = $f73057306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73057306,
"from":L[965]});
}
} catch($e72977298) {
if(R.isCont($e72977298)) {
var $ss73017302 = {"from":L[965],
"go":function(anf_begin_app_dropped27607307) {
return $Hanf_begin_app_dropped27647308(anf_begin_app_dropped27607307,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282,none6979,update_DASH_type_DASH_binding_DASH_ann3493973);
}};
$e72977298.stack[R.EXN_STACKHEIGHT++] = $ss73017302;
}
if(R.isPyretException($e72977298)) {
$e72977298.pyretStack.push(L[965]);
}
throw $e72977298;
}
var $ret73037304 = $Hanf_begin_app_dropped27647308($z72997300,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282,none6979,update_DASH_type_DASH_binding_DASH_ann3493973);
++R.GAS;
return $ret73037304;
};
var $Hanf_begin_app_dropped27647308 = function(anf_begin_app_dropped27607307,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282,none6979,update_DASH_type_DASH_binding_DASH_ann3493973) {
var anf_arg12277319 = G(atom_DASH_env_DASH_t4367267,"atom",L[967]);
var $z73117312 = D;
var $f73177318 = function(_) {
return R.isFunction(update_DASH_type_DASH_binding_DASH_ann3493973.$var)?update_DASH_type_DASH_binding_DASH_ann3493973.$var.app(anf_arg12277319,none6979):R.ffi.throwNonFunApp(L[966],update_DASH_type_DASH_binding_DASH_ann3493973.$var,[anf_arg12277319,none6979]);
};
try {
if(--R.GAS > 0) {
$z73117312 = $f73177318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73177318,
"from":L[966]});
}
} catch($e73097310) {
if(R.isCont($e73097310)) {
var $ss73137314 = {"from":L[966],
"go":function(anf_begin_app_dropped27617320) {
return $Hanf_begin_app_dropped27637321(anf_begin_app_dropped27617320,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282);
}};
$e73097310.stack[R.EXN_STACKHEIGHT++] = $ss73137314;
}
if(R.isPyretException($e73097310)) {
$e73097310.pyretStack.push(L[966]);
}
throw $e73097310;
}
var $ret73157316 = $Hanf_begin_app_dropped27637321($z73117312,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282);
++R.GAS;
return $ret73157316;
};
var $Hanf_begin_app_dropped27637321 = function(anf_begin_app_dropped27617320,acc4305104,atom_DASH_env_DASH_t4367267,atom_DASH_env4355137,link3774,new_DASH_header4377282) {
var anf_obj12287334 = G(atom_DASH_env4355137,"env",L[971]);
var anf_obj12297335 = G(atom_DASH_env_DASH_t4367267,"env",L[970]);
var anf_arg12307332 = G(acc4305104,"imps",L[969]);
var $z73247325 = D;
var $f73307331 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_header4377282,anf_arg12307332):R.ffi.throwNonFunApp(L[968],link3774,[new_DASH_header4377282,anf_arg12307332]);
};
try {
if(--R.GAS > 0) {
$z73247325 = $f73307331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73307331,
"from":L[968]});
}
} catch($e73227323) {
if(R.isCont($e73227323)) {
var $ss73267327 = {"from":L[968],
"go":function(anf_obj12317333) {
return $Hanf_obj27627336(anf_obj12317333,anf_obj12287334,anf_obj12297335);
}};
$e73227323.stack[R.EXN_STACKHEIGHT++] = $ss73267327;
}
if(R.isPyretException($e73227323)) {
$e73227323.pyretStack.push(L[968]);
}
throw $e73227323;
}
var $ret73287329 = $Hanf_obj27627336($z73247325,anf_obj12287334,anf_obj12297335);
++R.GAS;
return $ret73287329;
};
var $Hanf_obj27627336 = function(anf_obj12317333,anf_obj12287334,anf_obj12297335) {
var ann_DASH_check_DASH_temp12197337 = R.makeObject({"e":anf_obj12287334,
"te":anf_obj12297335,
"imps":anf_obj12317333});
return ann_DASH_check_DASH_temp12197337;
};
var $Hann_DASH_check_DASH_temp27594011 = function(ann_DASH_check_DASH_temp11784010) {
return ann_DASH_check_DASH_temp11784010;
};
var $Hann_DASH_check_DASH_temp27584024 = function(ann_DASH_check_DASH_temp12094023) {
return ann_DASH_check_DASH_temp12094023;
};
var $Hif_DASH_27574040 = function(if_DASH_1034039,A119,l4083994,names28657,s4124027,type_DASH_env4093995) {
var if_helper11827350 = R.makeFunction(function(if_helper_arg11837370) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[454],1,arguments);
}
var ann_DASH_check_DASH_temp11807371 = if_helper_arg11837370;
return ann_DASH_check_DASH_temp11807371;
});
var anf_if11867369 = R.isBoolean(if_DASH_1034039);
if(R.isPyretTrue(anf_if11867369)) {
if(R.isPyretTrue(if_DASH_1034039)) {
var anf_fun11927348 = G(type_DASH_env4093995,"get",L[973]);
var $z73407341 = D;
var $f73467347 = function(_) {
return R.isFunction(anf_fun11927348)?anf_fun11927348.app(s4124027):R.ffi.throwNonFunApp(L[972],anf_fun11927348,[s4124027]);
};
try {
if(--R.GAS > 0) {
$z73407341 = $f73467347();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73467347,
"from":L[972]});
}
} catch($e73387339) {
if(R.isCont($e73387339)) {
var $ss73427343 = {"from":L[972],
"go":function(cases_DASH_val1047349) {
return $Hcases_DASH_val27547351(cases_DASH_val1047349,A119,if_helper11827350,l4083994);
}};
$e73387339.stack[R.EXN_STACKHEIGHT++] = $ss73427343;
}
if(R.isPyretException($e73387339)) {
$e73387339.pyretStack.push(L[972]);
}
throw $e73387339;
}
var $ret73447345 = $Hcases_DASH_val27547351($z73407341,A119,if_helper11827350,l4083994);
++R.GAS;
return $ret73447345;
} else {
var anf_fun11877364 = G(A119,"a-name",L[976]);
var anf_fun11887362 = G(names28657,"s-type-global",L[975]);
var $z73547355 = D;
var $f73607361 = function(_) {
return R.isFunction(anf_fun11887362)?anf_fun11887362.app(s4124027):R.ffi.throwNonFunApp(L[974],anf_fun11887362,[s4124027]);
};
try {
if(--R.GAS > 0) {
$z73547355 = $f73607361();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73607361,
"from":L[974]});
}
} catch($e73527353) {
if(R.isCont($e73527353)) {
var $ss73567357 = {"from":L[974],
"go":function(anf_arg11897363) {
return $Hanf_arg27567365(anf_arg11897363,anf_fun11877364,if_helper11827350,l4083994);
}};
$e73527353.stack[R.EXN_STACKHEIGHT++] = $ss73567357;
}
if(R.isPyretException($e73527353)) {
$e73527353.pyretStack.push(L[974]);
}
throw $e73527353;
}
var $ret73587359 = $Hanf_arg27567365($z73547355,anf_fun11877364,if_helper11827350,l4083994);
++R.GAS;
return $ret73587359;
}
} else {
var cont_tail_arg11847368 = R.throwNonBooleanCondition(L[454],("if"),if_DASH_1034039);
if(--R.GAS > 0) {
$z73667367 = R.isFunction(if_helper11827350)?if_helper11827350.app(cont_tail_arg11847368):R.ffi.throwNonFunApp(L[454],if_helper11827350,[cont_tail_arg11847368]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper11827350)?if_helper11827350.app(cont_tail_arg11847368):R.ffi.throwNonFunApp(L[454],if_helper11827350,[cont_tail_arg11847368]);
},
"from":L[454]});
}
++R.GAS;
return $z73667367;
}
};
var $Hcases_DASH_val27547351 = function(cases_DASH_val1047349,A119,if_helper11827350,l4083994) {
var anf_fun11937382 = G(cases_DASH_val1047349,"_match",L[972]);
var anf_obj11967388 = R.makeFunction(function($underscore4137411,name4147412,$underscore4157413) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[981],3,arguments);
}
var anf_fun11957424 = G(A119,"a-name",L[982]);
var $z74167417 = D;
var $f74227423 = function(_) {
return R.isFunction(anf_fun11957424)?anf_fun11957424.app(l4083994,name4147412):R.ffi.throwNonFunApp(L[981],anf_fun11957424,[l4083994,name4147412]);
};
try {
if(--R.GAS > 0) {
$z74167417 = $f74227423();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74227423,
"from":L[981]});
}
} catch($e74147415) {
if(R.isCont($e74147415)) {
var $ss74187419 = {"from":L[981],
"go":function(ann_DASH_check_DASH_temp11947425) {
return $Hann_DASH_check_DASH_temp27517426(ann_DASH_check_DASH_temp11947425);
}};
$e74147415.stack[R.EXN_STACKHEIGHT++] = $ss74187419;
}
if(R.isPyretException($e74147415)) {
$e74147415.pyretStack.push(L[981]);
}
throw $e74147415;
}
var $ret74207421 = $Hann_DASH_check_DASH_temp27517426($z74167417);
++R.GAS;
return $ret74207421;
});
var anf_obj11997389 = R.makeFunction(function($underscore4167395,name4177396,$underscore4187397) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[979],3,arguments);
}
var anf_fun11987408 = G(A119,"a-name",L[980]);
var $z74007401 = D;
var $f74067407 = function(_) {
return R.isFunction(anf_fun11987408)?anf_fun11987408.app(l4083994,name4177396):R.ffi.throwNonFunApp(L[979],anf_fun11987408,[l4083994,name4177396]);
};
try {
if(--R.GAS > 0) {
$z74007401 = $f74067407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74067407,
"from":L[979]});
}
} catch($e73987399) {
if(R.isCont($e73987399)) {
var $ss74027403 = {"from":L[979],
"go":function(ann_DASH_check_DASH_temp11977409) {
return $Hann_DASH_check_DASH_temp27527410(ann_DASH_check_DASH_temp11977409);
}};
$e73987399.stack[R.EXN_STACKHEIGHT++] = $ss74027403;
}
if(R.isPyretException($e73987399)) {
$e73987399.pyretStack.push(L[979]);
}
throw $e73987399;
}
var $ret74047405 = $Hann_DASH_check_DASH_temp27527410($z74007401);
++R.GAS;
return $ret74047405;
});
var anf_obj12017390 = R.makeFunction(function($underscore4197391,name4207392,$underscore4217393) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[977],3,arguments);
}
var ann_DASH_check_DASH_temp12007394 = G(A119,"a-blank",L[978]);
return ann_DASH_check_DASH_temp12007394;
});
var anf_arg12027383 = R.makeObject({"global-type-bind":anf_obj11967388,
"let-type-bind":anf_obj11997389,
"type-var-bind":anf_obj12017390});
var anf_arg12047384 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[972],0,arguments);
}
var ann_DASH_check_DASH_temp12037387 = R.throwNoBranchesMatched(L[972],("cases"));
return ann_DASH_check_DASH_temp12037387;
});
var $z73747375 = D;
var $f73807381 = function(_) {
return R.isFunction(anf_fun11937382)?anf_fun11937382.app(anf_arg12027383,anf_arg12047384):R.ffi.throwNonFunApp(L[972],anf_fun11937382,[anf_arg12027383,anf_arg12047384]);
};
try {
if(--R.GAS > 0) {
$z73747375 = $f73807381();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f73807381,
"from":L[972]});
}
} catch($e73727373) {
if(R.isCont($e73727373)) {
var $ss73767377 = {"from":L[972],
"go":function(cont_tail_arg12057385) {
return $Hcont_tail_arg27537386(cont_tail_arg12057385,if_helper11827350);
}};
$e73727373.stack[R.EXN_STACKHEIGHT++] = $ss73767377;
}
if(R.isPyretException($e73727373)) {
$e73727373.pyretStack.push(L[972]);
}
throw $e73727373;
}
var $ret73787379 = $Hcont_tail_arg27537386($z73747375,if_helper11827350);
++R.GAS;
return $ret73787379;
};
var $Hcont_tail_arg27537386 = function(cont_tail_arg12057385,if_helper11827350) {
if(--R.GAS > 0) {
$z74277428 = R.isFunction(if_helper11827350)?if_helper11827350.app(cont_tail_arg12057385):R.ffi.throwNonFunApp(L[972],if_helper11827350,[cont_tail_arg12057385]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper11827350)?if_helper11827350.app(cont_tail_arg12057385):R.ffi.throwNonFunApp(L[972],if_helper11827350,[cont_tail_arg12057385]);
},
"from":L[972]});
}
++R.GAS;
return $z74277428;
};
var $Hann_DASH_check_DASH_temp27527410 = function(ann_DASH_check_DASH_temp11977409) {
return ann_DASH_check_DASH_temp11977409;
};
var $Hann_DASH_check_DASH_temp27517426 = function(ann_DASH_check_DASH_temp11947425) {
return ann_DASH_check_DASH_temp11947425;
};
var $Hanf_arg27567365 = function(anf_arg11897363,anf_fun11877364,if_helper11827350,l4083994) {
var $z74317432 = D;
var $f74377438 = function(_) {
return R.isFunction(anf_fun11877364)?anf_fun11877364.app(l4083994,anf_arg11897363):R.ffi.throwNonFunApp(L[983],anf_fun11877364,[l4083994,anf_arg11897363]);
};
try {
if(--R.GAS > 0) {
$z74317432 = $f74377438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74377438,
"from":L[983]});
}
} catch($e74297430) {
if(R.isCont($e74297430)) {
var $ss74337434 = {"from":L[983],
"go":function(cont_tail_arg11907439) {
return $Hcont_tail_arg27557440(cont_tail_arg11907439,if_helper11827350);
}};
$e74297430.stack[R.EXN_STACKHEIGHT++] = $ss74337434;
}
if(R.isPyretException($e74297430)) {
$e74297430.pyretStack.push(L[983]);
}
throw $e74297430;
}
var $ret74357436 = $Hcont_tail_arg27557440($z74317432,if_helper11827350);
++R.GAS;
return $ret74357436;
};
var $Hcont_tail_arg27557440 = function(cont_tail_arg11907439,if_helper11827350) {
if(--R.GAS > 0) {
$z74417442 = R.isFunction(if_helper11827350)?if_helper11827350.app(cont_tail_arg11907439):R.ffi.throwNonFunApp(L[983],if_helper11827350,[cont_tail_arg11907439]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper11827350)?if_helper11827350.app(cont_tail_arg11907439):R.ffi.throwNonFunApp(L[983],if_helper11827350,[cont_tail_arg11907439]);
},
"from":L[983]});
}
++R.GAS;
return $z74417442;
};
var $Hann_DASH_check_DASH_temp27504059 = function(ann_DASH_check_DASH_temp11354058) {
return ann_DASH_check_DASH_temp11354058;
};
var $Hanf_arg27494071 = function(anf_arg11744070,_plus9,raise14) {
var $z74457446 = D;
var $f74517452 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("Wasn't expecting a non-s-name in resolve-names id: "),anf_arg11744070):R.ffi.throwNonFunApp(L[984],_plus9,[("Wasn't expecting a non-s-name in resolve-names id: "),anf_arg11744070]);
};
try {
if(--R.GAS > 0) {
$z74457446 = $f74517452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74517452,
"from":L[984]});
}
} catch($e74437444) {
if(R.isCont($e74437444)) {
var $ss74477448 = {"from":L[984],
"go":function(anf_arg11757453) {
return $Hanf_arg27487454(anf_arg11757453,raise14);
}};
$e74437444.stack[R.EXN_STACKHEIGHT++] = $ss74477448;
}
if(R.isPyretException($e74437444)) {
$e74437444.pyretStack.push(L[984]);
}
throw $e74437444;
}
var $ret74497450 = $Hanf_arg27487454($z74457446,raise14);
++R.GAS;
return $ret74497450;
};
var $Hanf_arg27487454 = function(anf_arg11757453,raise14) {
var $z74577458 = D;
var $f74637464 = function(_) {
return R.isFunction(raise14)?raise14.app(anf_arg11757453):R.ffi.throwNonFunApp(L[457],raise14,[anf_arg11757453]);
};
try {
if(--R.GAS > 0) {
$z74577458 = $f74637464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74637464,
"from":L[457]});
}
} catch($e74557456) {
if(R.isCont($e74557456)) {
var $ss74597460 = {"from":L[457],
"go":function(ann_DASH_check_DASH_temp11737465) {
return $Hann_DASH_check_DASH_temp27477466(ann_DASH_check_DASH_temp11737465);
}};
$e74557456.stack[R.EXN_STACKHEIGHT++] = $ss74597460;
}
if(R.isPyretException($e74557456)) {
$e74557456.pyretStack.push(L[457]);
}
throw $e74557456;
}
var $ret74617462 = $Hann_DASH_check_DASH_temp27477466($z74577458);
++R.GAS;
return $ret74617462;
};
var $Hann_DASH_check_DASH_temp27477466 = function(ann_DASH_check_DASH_temp11737465) {
return ann_DASH_check_DASH_temp11737465;
};
var $Hann_DASH_check_DASH_temp27464087 = function(ann_DASH_check_DASH_temp11694086) {
return ann_DASH_check_DASH_temp11694086;
};
var $Hif_DASH_27454102 = function(if_DASH_1004101,A119,env3904042,l3914043,names28657,s3944089) {
var if_helper11397479 = R.makeFunction(function(if_helper_arg11407499) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[462],1,arguments);
}
var ann_DASH_check_DASH_temp11377500 = if_helper_arg11407499;
return ann_DASH_check_DASH_temp11377500;
});
var anf_if11437498 = R.isBoolean(if_DASH_1004101);
if(R.isPyretTrue(anf_if11437498)) {
if(R.isPyretTrue(if_DASH_1004101)) {
var anf_fun11497477 = G(env3904042,"get",L[986]);
var $z74697470 = D;
var $f74757476 = function(_) {
return R.isFunction(anf_fun11497477)?anf_fun11497477.app(s3944089):R.ffi.throwNonFunApp(L[985],anf_fun11497477,[s3944089]);
};
try {
if(--R.GAS > 0) {
$z74697470 = $f74757476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74757476,
"from":L[985]});
}
} catch($e74677468) {
if(R.isCont($e74677468)) {
var $ss74717472 = {"from":L[985],
"go":function(cases_DASH_val1017478) {
return $Hcases_DASH_val27427480(cases_DASH_val1017478,A119,if_helper11397479,l3914043);
}};
$e74677468.stack[R.EXN_STACKHEIGHT++] = $ss74717472;
}
if(R.isPyretException($e74677468)) {
$e74677468.pyretStack.push(L[985]);
}
throw $e74677468;
}
var $ret74737474 = $Hcases_DASH_val27427480($z74697470,A119,if_helper11397479,l3914043);
++R.GAS;
return $ret74737474;
} else {
var anf_fun11447493 = G(A119,"s-id",L[989]);
var anf_fun11457491 = G(names28657,"s-global",L[988]);
var $z74837484 = D;
var $f74897490 = function(_) {
return R.isFunction(anf_fun11457491)?anf_fun11457491.app(s3944089):R.ffi.throwNonFunApp(L[987],anf_fun11457491,[s3944089]);
};
try {
if(--R.GAS > 0) {
$z74837484 = $f74897490();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f74897490,
"from":L[987]});
}
} catch($e74817482) {
if(R.isCont($e74817482)) {
var $ss74857486 = {"from":L[987],
"go":function(anf_arg11467492) {
return $Hanf_arg27447494(anf_arg11467492,anf_fun11447493,if_helper11397479,l3914043);
}};
$e74817482.stack[R.EXN_STACKHEIGHT++] = $ss74857486;
}
if(R.isPyretException($e74817482)) {
$e74817482.pyretStack.push(L[987]);
}
throw $e74817482;
}
var $ret74877488 = $Hanf_arg27447494($z74837484,anf_fun11447493,if_helper11397479,l3914043);
++R.GAS;
return $ret74877488;
}
} else {
var cont_tail_arg11417497 = R.throwNonBooleanCondition(L[462],("if"),if_DASH_1004101);
if(--R.GAS > 0) {
$z74957496 = R.isFunction(if_helper11397479)?if_helper11397479.app(cont_tail_arg11417497):R.ffi.throwNonFunApp(L[462],if_helper11397479,[cont_tail_arg11417497]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper11397479)?if_helper11397479.app(cont_tail_arg11417497):R.ffi.throwNonFunApp(L[462],if_helper11397479,[cont_tail_arg11417497]);
},
"from":L[462]});
}
++R.GAS;
return $z74957496;
}
};
var $Hcases_DASH_val27427480 = function(cases_DASH_val1017478,A119,if_helper11397479,l3914043) {
var anf_fun11507511 = G(cases_DASH_val1017478,"_match",L[985]);
var anf_obj11537517 = R.makeFunction(function($underscore3957569,atom3967570,$underscore3977571) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[996],3,arguments);
}
var anf_fun11527582 = G(A119,"s-id",L[997]);
var $z75747575 = D;
var $f75807581 = function(_) {
return R.isFunction(anf_fun11527582)?anf_fun11527582.app(l3914043,atom3967570):R.ffi.throwNonFunApp(L[996],anf_fun11527582,[l3914043,atom3967570]);
};
try {
if(--R.GAS > 0) {
$z75747575 = $f75807581();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75807581,
"from":L[996]});
}
} catch($e75727573) {
if(R.isCont($e75727573)) {
var $ss75767577 = {"from":L[996],
"go":function(ann_DASH_check_DASH_temp11517583) {
return $Hann_DASH_check_DASH_temp27377584(ann_DASH_check_DASH_temp11517583);
}};
$e75727573.stack[R.EXN_STACKHEIGHT++] = $ss75767577;
}
if(R.isPyretException($e75727573)) {
$e75727573.pyretStack.push(L[996]);
}
throw $e75727573;
}
var $ret75787579 = $Hann_DASH_check_DASH_temp27377584($z75747575);
++R.GAS;
return $ret75787579;
});
var anf_obj11567518 = R.makeFunction(function($underscore3987553,atom3997554,$underscore4007555) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[994],3,arguments);
}
var anf_fun11557566 = G(A119,"s-id-letrec",L[995]);
var $z75587559 = D;
var $f75647565 = function(_) {
return R.isFunction(anf_fun11557566)?anf_fun11557566.app(l3914043,atom3997554,(false)):R.ffi.throwNonFunApp(L[994],anf_fun11557566,[l3914043,atom3997554,(false)]);
};
try {
if(--R.GAS > 0) {
$z75587559 = $f75647565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75647565,
"from":L[994]});
}
} catch($e75567557) {
if(R.isCont($e75567557)) {
var $ss75607561 = {"from":L[994],
"go":function(ann_DASH_check_DASH_temp11547567) {
return $Hann_DASH_check_DASH_temp27387568(ann_DASH_check_DASH_temp11547567);
}};
$e75567557.stack[R.EXN_STACKHEIGHT++] = $ss75607561;
}
if(R.isPyretException($e75567557)) {
$e75567557.pyretStack.push(L[994]);
}
throw $e75567557;
}
var $ret75627563 = $Hann_DASH_check_DASH_temp27387568($z75587559);
++R.GAS;
return $ret75627563;
});
var anf_obj11597519 = R.makeFunction(function($underscore4017537,atom4027538,$underscore4037539) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[992],3,arguments);
}
var anf_fun11587550 = G(A119,"s-id-var",L[993]);
var $z75427543 = D;
var $f75487549 = function(_) {
return R.isFunction(anf_fun11587550)?anf_fun11587550.app(l3914043,atom4027538):R.ffi.throwNonFunApp(L[992],anf_fun11587550,[l3914043,atom4027538]);
};
try {
if(--R.GAS > 0) {
$z75427543 = $f75487549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75487549,
"from":L[992]});
}
} catch($e75407541) {
if(R.isCont($e75407541)) {
var $ss75447545 = {"from":L[992],
"go":function(ann_DASH_check_DASH_temp11577551) {
return $Hann_DASH_check_DASH_temp27397552(ann_DASH_check_DASH_temp11577551);
}};
$e75407541.stack[R.EXN_STACKHEIGHT++] = $ss75447545;
}
if(R.isPyretException($e75407541)) {
$e75407541.pyretStack.push(L[992]);
}
throw $e75407541;
}
var $ret75467547 = $Hann_DASH_check_DASH_temp27397552($z75427543);
++R.GAS;
return $ret75467547;
});
var anf_obj11627520 = R.makeFunction(function($underscore4047521,atom4057522,$underscore4067523) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[990],3,arguments);
}
var anf_fun11617534 = G(A119,"s-id",L[991]);
var $z75267527 = D;
var $f75327533 = function(_) {
return R.isFunction(anf_fun11617534)?anf_fun11617534.app(l3914043,atom4057522):R.ffi.throwNonFunApp(L[990],anf_fun11617534,[l3914043,atom4057522]);
};
try {
if(--R.GAS > 0) {
$z75267527 = $f75327533();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75327533,
"from":L[990]});
}
} catch($e75247525) {
if(R.isCont($e75247525)) {
var $ss75287529 = {"from":L[990],
"go":function(ann_DASH_check_DASH_temp11607535) {
return $Hann_DASH_check_DASH_temp27407536(ann_DASH_check_DASH_temp11607535);
}};
$e75247525.stack[R.EXN_STACKHEIGHT++] = $ss75287529;
}
if(R.isPyretException($e75247525)) {
$e75247525.pyretStack.push(L[990]);
}
throw $e75247525;
}
var $ret75307531 = $Hann_DASH_check_DASH_temp27407536($z75267527);
++R.GAS;
return $ret75307531;
});
var anf_arg11637512 = R.makeObject({"let-bind":anf_obj11537517,
"letrec-bind":anf_obj11567518,
"var-bind":anf_obj11597519,
"global-bind":anf_obj11627520});
var anf_arg11657513 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[985],0,arguments);
}
var ann_DASH_check_DASH_temp11647516 = R.throwNoBranchesMatched(L[985],("cases"));
return ann_DASH_check_DASH_temp11647516;
});
var $z75037504 = D;
var $f75097510 = function(_) {
return R.isFunction(anf_fun11507511)?anf_fun11507511.app(anf_arg11637512,anf_arg11657513):R.ffi.throwNonFunApp(L[985],anf_fun11507511,[anf_arg11637512,anf_arg11657513]);
};
try {
if(--R.GAS > 0) {
$z75037504 = $f75097510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75097510,
"from":L[985]});
}
} catch($e75017502) {
if(R.isCont($e75017502)) {
var $ss75057506 = {"from":L[985],
"go":function(cont_tail_arg11667514) {
return $Hcont_tail_arg27417515(cont_tail_arg11667514,if_helper11397479);
}};
$e75017502.stack[R.EXN_STACKHEIGHT++] = $ss75057506;
}
if(R.isPyretException($e75017502)) {
$e75017502.pyretStack.push(L[985]);
}
throw $e75017502;
}
var $ret75077508 = $Hcont_tail_arg27417515($z75037504,if_helper11397479);
++R.GAS;
return $ret75077508;
};
var $Hcont_tail_arg27417515 = function(cont_tail_arg11667514,if_helper11397479) {
if(--R.GAS > 0) {
$z75857586 = R.isFunction(if_helper11397479)?if_helper11397479.app(cont_tail_arg11667514):R.ffi.throwNonFunApp(L[985],if_helper11397479,[cont_tail_arg11667514]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper11397479)?if_helper11397479.app(cont_tail_arg11667514):R.ffi.throwNonFunApp(L[985],if_helper11397479,[cont_tail_arg11667514]);
},
"from":L[985]});
}
++R.GAS;
return $z75857586;
};
var $Hann_DASH_check_DASH_temp27407536 = function(ann_DASH_check_DASH_temp11607535) {
return ann_DASH_check_DASH_temp11607535;
};
var $Hann_DASH_check_DASH_temp27397552 = function(ann_DASH_check_DASH_temp11577551) {
return ann_DASH_check_DASH_temp11577551;
};
var $Hann_DASH_check_DASH_temp27387568 = function(ann_DASH_check_DASH_temp11547567) {
return ann_DASH_check_DASH_temp11547567;
};
var $Hann_DASH_check_DASH_temp27377584 = function(ann_DASH_check_DASH_temp11517583) {
return ann_DASH_check_DASH_temp11517583;
};
var $Hanf_arg27447494 = function(anf_arg11467492,anf_fun11447493,if_helper11397479,l3914043) {
var $z75897590 = D;
var $f75957596 = function(_) {
return R.isFunction(anf_fun11447493)?anf_fun11447493.app(l3914043,anf_arg11467492):R.ffi.throwNonFunApp(L[998],anf_fun11447493,[l3914043,anf_arg11467492]);
};
try {
if(--R.GAS > 0) {
$z75897590 = $f75957596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f75957596,
"from":L[998]});
}
} catch($e75877588) {
if(R.isCont($e75877588)) {
var $ss75917592 = {"from":L[998],
"go":function(cont_tail_arg11477597) {
return $Hcont_tail_arg27437598(cont_tail_arg11477597,if_helper11397479);
}};
$e75877588.stack[R.EXN_STACKHEIGHT++] = $ss75917592;
}
if(R.isPyretException($e75877588)) {
$e75877588.pyretStack.push(L[998]);
}
throw $e75877588;
}
var $ret75937594 = $Hcont_tail_arg27437598($z75897590,if_helper11397479);
++R.GAS;
return $ret75937594;
};
var $Hcont_tail_arg27437598 = function(cont_tail_arg11477597,if_helper11397479) {
if(--R.GAS > 0) {
$z75997600 = R.isFunction(if_helper11397479)?if_helper11397479.app(cont_tail_arg11477597):R.ffi.throwNonFunApp(L[998],if_helper11397479,[cont_tail_arg11477597]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper11397479)?if_helper11397479.app(cont_tail_arg11477597):R.ffi.throwNonFunApp(L[998],if_helper11397479,[cont_tail_arg11477597]);
},
"from":L[998]});
}
++R.GAS;
return $z75997600;
};
var $Hanf_arg27364119 = function(anf_arg11054117,anf_fun11034118,atom3764104,bindings3463955,expr3774105,global_DASH_bind297106,let_DASH_bind29398,letrec_DASH_bind29194,var_DASH_bind295102) {
var $z76037604 = D;
var $f76097610 = function(_) {
return R.isFunction(anf_fun11034118)?anf_fun11034118.app(anf_arg11054117):R.ffi.throwNonFunApp(L[999],anf_fun11034118,[anf_arg11054117]);
};
try {
if(--R.GAS > 0) {
$z76037604 = $f76097610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76097610,
"from":L[999]});
}
} catch($e76017602) {
if(R.isCont($e76017602)) {
var $ss76057606 = {"from":L[999],
"go":function(cases_DASH_val997611) {
return $Hcases_DASH_val27357612(cases_DASH_val997611,atom3764104,bindings3463955,expr3774105,global_DASH_bind297106,let_DASH_bind29398,letrec_DASH_bind29194,var_DASH_bind295102);
}};
$e76017602.stack[R.EXN_STACKHEIGHT++] = $ss76057606;
}
if(R.isPyretException($e76017602)) {
$e76017602.pyretStack.push(L[999]);
}
throw $e76017602;
}
var $ret76077608 = $Hcases_DASH_val27357612($z76037604,atom3764104,bindings3463955,expr3774105,global_DASH_bind297106,let_DASH_bind29398,letrec_DASH_bind29194,var_DASH_bind295102);
++R.GAS;
return $ret76077608;
};
var $Hcases_DASH_val27357612 = function(cases_DASH_val997611,atom3764104,bindings3463955,expr3774105,global_DASH_bind297106,let_DASH_bind29398,letrec_DASH_bind29194,var_DASH_bind295102) {
var anf_fun11067623 = G(cases_DASH_val997611,"_match",L[999]);
var anf_obj11127629 = R.makeFunction(function(loc3787684,$underscore3797685,$underscore3807686) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1012],3,arguments);
}
var anf_fun11087699 = G(bindings3463955,"set",L[1015]);
var anf_fun11097697 = G(atom3764104,"key",L[1014]);
var $z76897690 = D;
var $f76957696 = function(_) {
return R.isFunction(anf_fun11097697)?anf_fun11097697.app():R.ffi.throwNonFunApp(L[1013],anf_fun11097697,[]);
};
try {
if(--R.GAS > 0) {
$z76897690 = $f76957696();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76957696,
"from":L[1013]});
}
} catch($e76877688) {
if(R.isCont($e76877688)) {
var $ss76917692 = {"from":L[1013],
"go":function(anf_arg11107698) {
return $Hanf_arg27247700(anf_arg11107698,anf_fun11087699,atom3764104,expr3774105,letrec_DASH_bind29194,loc3787684);
}};
$e76877688.stack[R.EXN_STACKHEIGHT++] = $ss76917692;
}
if(R.isPyretException($e76877688)) {
$e76877688.pyretStack.push(L[1013]);
}
throw $e76877688;
}
var $ret76937694 = $Hanf_arg27247700($z76897690,anf_fun11087699,atom3764104,expr3774105,letrec_DASH_bind29194,loc3787684);
++R.GAS;
return $ret76937694;
});
var anf_obj11187630 = R.makeFunction(function(loc3817667,$underscore3827668,$underscore3837669) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1008],3,arguments);
}
var anf_fun11147682 = G(bindings3463955,"set",L[1011]);
var anf_fun11157680 = G(atom3764104,"key",L[1010]);
var $z76727673 = D;
var $f76787679 = function(_) {
return R.isFunction(anf_fun11157680)?anf_fun11157680.app():R.ffi.throwNonFunApp(L[1009],anf_fun11157680,[]);
};
try {
if(--R.GAS > 0) {
$z76727673 = $f76787679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76787679,
"from":L[1009]});
}
} catch($e76707671) {
if(R.isCont($e76707671)) {
var $ss76747675 = {"from":L[1009],
"go":function(anf_arg11167681) {
return $Hanf_arg27277683(anf_arg11167681,anf_fun11147682,atom3764104,expr3774105,let_DASH_bind29398,loc3817667);
}};
$e76707671.stack[R.EXN_STACKHEIGHT++] = $ss76747675;
}
if(R.isPyretException($e76707671)) {
$e76707671.pyretStack.push(L[1009]);
}
throw $e76707671;
}
var $ret76767677 = $Hanf_arg27277683($z76727673,anf_fun11147682,atom3764104,expr3774105,let_DASH_bind29398,loc3817667);
++R.GAS;
return $ret76767677;
});
var anf_obj11247631 = R.makeFunction(function(loc3847650,$underscore3857651,$underscore3867652) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1004],3,arguments);
}
var anf_fun11207665 = G(bindings3463955,"set",L[1007]);
var anf_fun11217663 = G(atom3764104,"key",L[1006]);
var $z76557656 = D;
var $f76617662 = function(_) {
return R.isFunction(anf_fun11217663)?anf_fun11217663.app():R.ffi.throwNonFunApp(L[1005],anf_fun11217663,[]);
};
try {
if(--R.GAS > 0) {
$z76557656 = $f76617662();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76617662,
"from":L[1005]});
}
} catch($e76537654) {
if(R.isCont($e76537654)) {
var $ss76577658 = {"from":L[1005],
"go":function(anf_arg11227664) {
return $Hanf_arg27307666(anf_arg11227664,anf_fun11207665,atom3764104,expr3774105,loc3847650,var_DASH_bind295102);
}};
$e76537654.stack[R.EXN_STACKHEIGHT++] = $ss76577658;
}
if(R.isPyretException($e76537654)) {
$e76537654.pyretStack.push(L[1005]);
}
throw $e76537654;
}
var $ret76597660 = $Hanf_arg27307666($z76557656,anf_fun11207665,atom3764104,expr3774105,loc3847650,var_DASH_bind295102);
++R.GAS;
return $ret76597660;
});
var anf_obj11307632 = R.makeFunction(function(loc3877633,$underscore3887634,$underscore3897635) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1000],3,arguments);
}
var anf_fun11267648 = G(bindings3463955,"set",L[1003]);
var anf_fun11277646 = G(atom3764104,"key",L[1002]);
var $z76387639 = D;
var $f76447645 = function(_) {
return R.isFunction(anf_fun11277646)?anf_fun11277646.app():R.ffi.throwNonFunApp(L[1001],anf_fun11277646,[]);
};
try {
if(--R.GAS > 0) {
$z76387639 = $f76447645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76447645,
"from":L[1001]});
}
} catch($e76367637) {
if(R.isCont($e76367637)) {
var $ss76407641 = {"from":L[1001],
"go":function(anf_arg11287647) {
return $Hanf_arg27337649(anf_arg11287647,anf_fun11267648,atom3764104,expr3774105,global_DASH_bind297106,loc3877633);
}};
$e76367637.stack[R.EXN_STACKHEIGHT++] = $ss76407641;
}
if(R.isPyretException($e76367637)) {
$e76367637.pyretStack.push(L[1001]);
}
throw $e76367637;
}
var $ret76427643 = $Hanf_arg27337649($z76387639,anf_fun11267648,atom3764104,expr3774105,global_DASH_bind297106,loc3877633);
++R.GAS;
return $ret76427643;
});
var anf_arg11317624 = R.makeObject({"letrec-bind":anf_obj11127629,
"let-bind":anf_obj11187630,
"var-bind":anf_obj11247631,
"global-bind":anf_obj11307632});
var anf_arg11337625 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[999],0,arguments);
}
var ann_DASH_check_DASH_temp11327628 = R.throwNoBranchesMatched(L[999],("cases"));
return ann_DASH_check_DASH_temp11327628;
});
var $z76157616 = D;
var $f76217622 = function(_) {
return R.isFunction(anf_fun11067623)?anf_fun11067623.app(anf_arg11317624,anf_arg11337625):R.ffi.throwNonFunApp(L[464],anf_fun11067623,[anf_arg11317624,anf_arg11337625]);
};
try {
if(--R.GAS > 0) {
$z76157616 = $f76217622();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f76217622,
"from":L[464]});
}
} catch($e76137614) {
if(R.isCont($e76137614)) {
var $ss76177618 = {"from":L[464],
"go":function(ann_DASH_check_DASH_temp11027626) {
return $Hann_DASH_check_DASH_temp27347627(ann_DASH_check_DASH_temp11027626);
}};
$e76137614.stack[R.EXN_STACKHEIGHT++] = $ss76177618;
}
if(R.isPyretException($e76137614)) {
$e76137614.pyretStack.push(L[464]);
}
throw $e76137614;
}
var $ret76197620 = $Hann_DASH_check_DASH_temp27347627($z76157616);
++R.GAS;
return $ret76197620;
};
var $Hann_DASH_check_DASH_temp27347627 = function(ann_DASH_check_DASH_temp11027626) {
return ann_DASH_check_DASH_temp11027626;
};
var $Hanf_arg27337649 = function(anf_arg11287647,anf_fun11267648,atom3764104,expr3774105,global_DASH_bind297106,loc3877633) {
var $z77037704 = D;
var $f77097710 = function(_) {
return R.isFunction(global_DASH_bind297106.$var)?global_DASH_bind297106.$var.app(loc3877633,atom3764104,expr3774105):R.ffi.throwNonFunApp(L[1016],global_DASH_bind297106.$var,[loc3877633,atom3764104,expr3774105]);
};
try {
if(--R.GAS > 0) {
$z77037704 = $f77097710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77097710,
"from":L[1016]});
}
} catch($e77017702) {
if(R.isCont($e77017702)) {
var $ss77057706 = {"from":L[1016],
"go":function(anf_arg11297711) {
return $Hanf_arg27327712(anf_arg11297711,anf_arg11287647,anf_fun11267648);
}};
$e77017702.stack[R.EXN_STACKHEIGHT++] = $ss77057706;
}
if(R.isPyretException($e77017702)) {
$e77017702.pyretStack.push(L[1016]);
}
throw $e77017702;
}
var $ret77077708 = $Hanf_arg27327712($z77037704,anf_arg11287647,anf_fun11267648);
++R.GAS;
return $ret77077708;
};
var $Hanf_arg27327712 = function(anf_arg11297711,anf_arg11287647,anf_fun11267648) {
var $z77157716 = D;
var $f77217722 = function(_) {
return R.isFunction(anf_fun11267648)?anf_fun11267648.app(anf_arg11287647,anf_arg11297711):R.ffi.throwNonFunApp(L[1000],anf_fun11267648,[anf_arg11287647,anf_arg11297711]);
};
try {
if(--R.GAS > 0) {
$z77157716 = $f77217722();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77217722,
"from":L[1000]});
}
} catch($e77137714) {
if(R.isCont($e77137714)) {
var $ss77177718 = {"from":L[1000],
"go":function(ann_DASH_check_DASH_temp11257723) {
return $Hann_DASH_check_DASH_temp27317724(ann_DASH_check_DASH_temp11257723);
}};
$e77137714.stack[R.EXN_STACKHEIGHT++] = $ss77177718;
}
if(R.isPyretException($e77137714)) {
$e77137714.pyretStack.push(L[1000]);
}
throw $e77137714;
}
var $ret77197720 = $Hann_DASH_check_DASH_temp27317724($z77157716);
++R.GAS;
return $ret77197720;
};
var $Hann_DASH_check_DASH_temp27317724 = function(ann_DASH_check_DASH_temp11257723) {
return ann_DASH_check_DASH_temp11257723;
};
var $Hanf_arg27307666 = function(anf_arg11227664,anf_fun11207665,atom3764104,expr3774105,loc3847650,var_DASH_bind295102) {
var $z77277728 = D;
var $f77337734 = function(_) {
return R.isFunction(var_DASH_bind295102.$var)?var_DASH_bind295102.$var.app(loc3847650,atom3764104,expr3774105):R.ffi.throwNonFunApp(L[1017],var_DASH_bind295102.$var,[loc3847650,atom3764104,expr3774105]);
};
try {
if(--R.GAS > 0) {
$z77277728 = $f77337734();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77337734,
"from":L[1017]});
}
} catch($e77257726) {
if(R.isCont($e77257726)) {
var $ss77297730 = {"from":L[1017],
"go":function(anf_arg11237735) {
return $Hanf_arg27297736(anf_arg11237735,anf_arg11227664,anf_fun11207665);
}};
$e77257726.stack[R.EXN_STACKHEIGHT++] = $ss77297730;
}
if(R.isPyretException($e77257726)) {
$e77257726.pyretStack.push(L[1017]);
}
throw $e77257726;
}
var $ret77317732 = $Hanf_arg27297736($z77277728,anf_arg11227664,anf_fun11207665);
++R.GAS;
return $ret77317732;
};
var $Hanf_arg27297736 = function(anf_arg11237735,anf_arg11227664,anf_fun11207665) {
var $z77397740 = D;
var $f77457746 = function(_) {
return R.isFunction(anf_fun11207665)?anf_fun11207665.app(anf_arg11227664,anf_arg11237735):R.ffi.throwNonFunApp(L[1004],anf_fun11207665,[anf_arg11227664,anf_arg11237735]);
};
try {
if(--R.GAS > 0) {
$z77397740 = $f77457746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77457746,
"from":L[1004]});
}
} catch($e77377738) {
if(R.isCont($e77377738)) {
var $ss77417742 = {"from":L[1004],
"go":function(ann_DASH_check_DASH_temp11197747) {
return $Hann_DASH_check_DASH_temp27287748(ann_DASH_check_DASH_temp11197747);
}};
$e77377738.stack[R.EXN_STACKHEIGHT++] = $ss77417742;
}
if(R.isPyretException($e77377738)) {
$e77377738.pyretStack.push(L[1004]);
}
throw $e77377738;
}
var $ret77437744 = $Hann_DASH_check_DASH_temp27287748($z77397740);
++R.GAS;
return $ret77437744;
};
var $Hann_DASH_check_DASH_temp27287748 = function(ann_DASH_check_DASH_temp11197747) {
return ann_DASH_check_DASH_temp11197747;
};
var $Hanf_arg27277683 = function(anf_arg11167681,anf_fun11147682,atom3764104,expr3774105,let_DASH_bind29398,loc3817667) {
var $z77517752 = D;
var $f77577758 = function(_) {
return R.isFunction(let_DASH_bind29398.$var)?let_DASH_bind29398.$var.app(loc3817667,atom3764104,expr3774105):R.ffi.throwNonFunApp(L[1018],let_DASH_bind29398.$var,[loc3817667,atom3764104,expr3774105]);
};
try {
if(--R.GAS > 0) {
$z77517752 = $f77577758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77577758,
"from":L[1018]});
}
} catch($e77497750) {
if(R.isCont($e77497750)) {
var $ss77537754 = {"from":L[1018],
"go":function(anf_arg11177759) {
return $Hanf_arg27267760(anf_arg11177759,anf_arg11167681,anf_fun11147682);
}};
$e77497750.stack[R.EXN_STACKHEIGHT++] = $ss77537754;
}
if(R.isPyretException($e77497750)) {
$e77497750.pyretStack.push(L[1018]);
}
throw $e77497750;
}
var $ret77557756 = $Hanf_arg27267760($z77517752,anf_arg11167681,anf_fun11147682);
++R.GAS;
return $ret77557756;
};
var $Hanf_arg27267760 = function(anf_arg11177759,anf_arg11167681,anf_fun11147682) {
var $z77637764 = D;
var $f77697770 = function(_) {
return R.isFunction(anf_fun11147682)?anf_fun11147682.app(anf_arg11167681,anf_arg11177759):R.ffi.throwNonFunApp(L[1008],anf_fun11147682,[anf_arg11167681,anf_arg11177759]);
};
try {
if(--R.GAS > 0) {
$z77637764 = $f77697770();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77697770,
"from":L[1008]});
}
} catch($e77617762) {
if(R.isCont($e77617762)) {
var $ss77657766 = {"from":L[1008],
"go":function(ann_DASH_check_DASH_temp11137771) {
return $Hann_DASH_check_DASH_temp27257772(ann_DASH_check_DASH_temp11137771);
}};
$e77617762.stack[R.EXN_STACKHEIGHT++] = $ss77657766;
}
if(R.isPyretException($e77617762)) {
$e77617762.pyretStack.push(L[1008]);
}
throw $e77617762;
}
var $ret77677768 = $Hann_DASH_check_DASH_temp27257772($z77637764);
++R.GAS;
return $ret77677768;
};
var $Hann_DASH_check_DASH_temp27257772 = function(ann_DASH_check_DASH_temp11137771) {
return ann_DASH_check_DASH_temp11137771;
};
var $Hanf_arg27247700 = function(anf_arg11107698,anf_fun11087699,atom3764104,expr3774105,letrec_DASH_bind29194,loc3787684) {
var $z77757776 = D;
var $f77817782 = function(_) {
return R.isFunction(letrec_DASH_bind29194.$var)?letrec_DASH_bind29194.$var.app(loc3787684,atom3764104,expr3774105):R.ffi.throwNonFunApp(L[1019],letrec_DASH_bind29194.$var,[loc3787684,atom3764104,expr3774105]);
};
try {
if(--R.GAS > 0) {
$z77757776 = $f77817782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77817782,
"from":L[1019]});
}
} catch($e77737774) {
if(R.isCont($e77737774)) {
var $ss77777778 = {"from":L[1019],
"go":function(anf_arg11117783) {
return $Hanf_arg27237784(anf_arg11117783,anf_arg11107698,anf_fun11087699);
}};
$e77737774.stack[R.EXN_STACKHEIGHT++] = $ss77777778;
}
if(R.isPyretException($e77737774)) {
$e77737774.pyretStack.push(L[1019]);
}
throw $e77737774;
}
var $ret77797780 = $Hanf_arg27237784($z77757776,anf_arg11107698,anf_fun11087699);
++R.GAS;
return $ret77797780;
};
var $Hanf_arg27237784 = function(anf_arg11117783,anf_arg11107698,anf_fun11087699) {
var $z77877788 = D;
var $f77937794 = function(_) {
return R.isFunction(anf_fun11087699)?anf_fun11087699.app(anf_arg11107698,anf_arg11117783):R.ffi.throwNonFunApp(L[1012],anf_fun11087699,[anf_arg11107698,anf_arg11117783]);
};
try {
if(--R.GAS > 0) {
$z77877788 = $f77937794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f77937794,
"from":L[1012]});
}
} catch($e77857786) {
if(R.isCont($e77857786)) {
var $ss77897790 = {"from":L[1012],
"go":function(ann_DASH_check_DASH_temp11077795) {
return $Hann_DASH_check_DASH_temp27227796(ann_DASH_check_DASH_temp11077795);
}};
$e77857786.stack[R.EXN_STACKHEIGHT++] = $ss77897790;
}
if(R.isPyretException($e77857786)) {
$e77857786.pyretStack.push(L[1012]);
}
throw $e77857786;
}
var $ret77917792 = $Hann_DASH_check_DASH_temp27227796($z77877788);
++R.GAS;
return $ret77917792;
};
var $Hann_DASH_check_DASH_temp27227796 = function(ann_DASH_check_DASH_temp11077795) {
return ann_DASH_check_DASH_temp11077795;
};
var $Hanf_arg27214135 = function(anf_arg10644133,anf_fun10624134,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,_plus9,print13,torepr16) {
var $z77997800 = D;
var $f78057806 = function(_) {
return R.isFunction(anf_fun10624134)?anf_fun10624134.app(anf_arg10644133):R.ffi.throwNonFunApp(L[1020],anf_fun10624134,[anf_arg10644133]);
};
try {
if(--R.GAS > 0) {
$z77997800 = $f78057806();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78057806,
"from":L[1020]});
}
} catch($e77977798) {
if(R.isCont($e77977798)) {
var $ss78017802 = {"from":L[1020],
"go":function(if_DASH_977807) {
return $Hif_DASH_27207808(if_DASH_977807,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,_plus9,print13,torepr16);
}};
$e77977798.stack[R.EXN_STACKHEIGHT++] = $ss78017802;
}
if(R.isPyretException($e77977798)) {
$e77977798.pyretStack.push(L[1020]);
}
throw $e77977798;
}
var $ret78037804 = $Hif_DASH_27207808($z77997800,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,_plus9,print13,torepr16);
++R.GAS;
return $ret78037804;
};
var $Hif_DASH_27207808 = function(if_DASH_977807,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124,_plus9,print13,torepr16) {
var if_helper10657822 = R.makeFunction(function(if_helper_arg10667840) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1020],1,arguments);
}
var ann_DASH_check_DASH_temp10617841 = if_helper_arg10667840;
return ann_DASH_check_DASH_temp10617841;
});
var anf_if10697839 = R.isBoolean(if_DASH_977807);
if(R.isPyretTrue(anf_if10697839)) {
if(R.isPyretTrue(if_DASH_977807)) {
var anf_fun10747821 = G(type_DASH_bindings3473969,"get",L[1023]);
var anf_fun10757819 = G(atom3654120,"key",L[1022]);
var $z78117812 = D;
var $f78177818 = function(_) {
return R.isFunction(anf_fun10757819)?anf_fun10757819.app():R.ffi.throwNonFunApp(L[1021],anf_fun10757819,[]);
};
try {
if(--R.GAS > 0) {
$z78117812 = $f78177818();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78177818,
"from":L[1021]});
}
} catch($e78097810) {
if(R.isCont($e78097810)) {
var $ss78137814 = {"from":L[1021],
"go":function(anf_arg10767820) {
return $Hanf_arg27167823(anf_arg10767820,anf_fun10747821,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,if_helper10657822,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124);
}};
$e78097810.stack[R.EXN_STACKHEIGHT++] = $ss78137814;
}
if(R.isPyretException($e78097810)) {
$e78097810.pyretStack.push(L[1021]);
}
throw $e78097810;
}
var $ret78157816 = $Hanf_arg27167823($z78117812,anf_fun10747821,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,if_helper10657822,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124);
++R.GAS;
return $ret78157816;
} else {
var $z78267827 = D;
var $f78327833 = function(_) {
return R.isFunction(torepr16)?torepr16.app(atom3654120):R.ffi.throwNonFunApp(L[1024],torepr16,[atom3654120]);
};
try {
if(--R.GAS > 0) {
$z78267827 = $f78327833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78327833,
"from":L[1024]});
}
} catch($e78247825) {
if(R.isCont($e78247825)) {
var $ss78287829 = {"from":L[1024],
"go":function(anf_arg10707834) {
return $Hanf_arg27197835(anf_arg10707834,if_helper10657822,_plus9,print13);
}};
$e78247825.stack[R.EXN_STACKHEIGHT++] = $ss78287829;
}
if(R.isPyretException($e78247825)) {
$e78247825.pyretStack.push(L[1024]);
}
throw $e78247825;
}
var $ret78307831 = $Hanf_arg27197835($z78267827,if_helper10657822,_plus9,print13);
++R.GAS;
return $ret78307831;
}
} else {
var cont_tail_arg10677838 = R.throwNonBooleanCondition(L[1020],("if"),if_DASH_977807);
if(--R.GAS > 0) {
$z78367837 = R.isFunction(if_helper10657822)?if_helper10657822.app(cont_tail_arg10677838):R.ffi.throwNonFunApp(L[1020],if_helper10657822,[cont_tail_arg10677838]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper10657822)?if_helper10657822.app(cont_tail_arg10677838):R.ffi.throwNonFunApp(L[1020],if_helper10657822,[cont_tail_arg10677838]);
},
"from":L[1020]});
}
++R.GAS;
return $z78367837;
}
};
var $Hanf_arg27167823 = function(anf_arg10767820,anf_fun10747821,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,if_helper10657822,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124) {
var $z78447845 = D;
var $f78507851 = function(_) {
return R.isFunction(anf_fun10747821)?anf_fun10747821.app(anf_arg10767820):R.ffi.throwNonFunApp(L[1025],anf_fun10747821,[anf_arg10767820]);
};
try {
if(--R.GAS > 0) {
$z78447845 = $f78507851();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78507851,
"from":L[1025]});
}
} catch($e78427843) {
if(R.isCont($e78427843)) {
var $ss78467847 = {"from":L[1025],
"go":function(cases_DASH_val987852) {
return $Hcases_DASH_val27157853(cases_DASH_val987852,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,if_helper10657822,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124);
}};
$e78427843.stack[R.EXN_STACKHEIGHT++] = $ss78467847;
}
if(R.isPyretException($e78427843)) {
$e78427843.pyretStack.push(L[1025]);
}
throw $e78427843;
}
var $ret78487849 = $Hcases_DASH_val27157853($z78447845,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,if_helper10657822,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124);
++R.GAS;
return $ret78487849;
};
var $Hcases_DASH_val27157853 = function(cases_DASH_val987852,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,if_helper10657822,let_DASH_type_DASH_bind304120,type_DASH_bindings3473969,type_DASH_var_DASH_bind306124) {
var anf_fun10777864 = G(cases_DASH_val987852,"_match",L[1025]);
var anf_obj10837870 = R.makeFunction(function(l3677907,$underscore3687908,$underscore3697909) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1034],3,arguments);
}
var anf_fun10797922 = G(type_DASH_bindings3473969,"set",L[1037]);
var anf_fun10807920 = G(atom3654120,"key",L[1036]);
var $z79127913 = D;
var $f79187919 = function(_) {
return R.isFunction(anf_fun10807920)?anf_fun10807920.app():R.ffi.throwNonFunApp(L[1035],anf_fun10807920,[]);
};
try {
if(--R.GAS > 0) {
$z79127913 = $f79187919();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79187919,
"from":L[1035]});
}
} catch($e79107911) {
if(R.isCont($e79107911)) {
var $ss79147915 = {"from":L[1035],
"go":function(anf_arg10817921) {
return $Hanf_arg27077923(anf_arg10817921,anf_fun10797922,ann3664121,atom3654120,l3677907,let_DASH_type_DASH_bind304120);
}};
$e79107911.stack[R.EXN_STACKHEIGHT++] = $ss79147915;
}
if(R.isPyretException($e79107911)) {
$e79107911.pyretStack.push(L[1035]);
}
throw $e79107911;
}
var $ret79167917 = $Hanf_arg27077923($z79127913,anf_fun10797922,ann3664121,atom3654120,l3677907,let_DASH_type_DASH_bind304120);
++R.GAS;
return $ret79167917;
});
var anf_obj10897871 = R.makeFunction(function(l3707890,$underscore3717891,$underscore3727892) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1030],3,arguments);
}
var anf_fun10857905 = G(type_DASH_bindings3473969,"set",L[1033]);
var anf_fun10867903 = G(atom3654120,"key",L[1032]);
var $z78957896 = D;
var $f79017902 = function(_) {
return R.isFunction(anf_fun10867903)?anf_fun10867903.app():R.ffi.throwNonFunApp(L[1031],anf_fun10867903,[]);
};
try {
if(--R.GAS > 0) {
$z78957896 = $f79017902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79017902,
"from":L[1031]});
}
} catch($e78937894) {
if(R.isCont($e78937894)) {
var $ss78977898 = {"from":L[1031],
"go":function(anf_arg10877904) {
return $Hanf_arg27107906(anf_arg10877904,anf_fun10857905,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,l3707890);
}};
$e78937894.stack[R.EXN_STACKHEIGHT++] = $ss78977898;
}
if(R.isPyretException($e78937894)) {
$e78937894.pyretStack.push(L[1031]);
}
throw $e78937894;
}
var $ret78997900 = $Hanf_arg27107906($z78957896,anf_fun10857905,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,l3707890);
++R.GAS;
return $ret78997900;
});
var anf_obj10957872 = R.makeFunction(function(l3737873,$underscore3747874,$underscore3757875) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1026],3,arguments);
}
var anf_fun10917888 = G(type_DASH_bindings3473969,"set",L[1029]);
var anf_fun10927886 = G(atom3654120,"key",L[1028]);
var $z78787879 = D;
var $f78847885 = function(_) {
return R.isFunction(anf_fun10927886)?anf_fun10927886.app():R.ffi.throwNonFunApp(L[1027],anf_fun10927886,[]);
};
try {
if(--R.GAS > 0) {
$z78787879 = $f78847885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78847885,
"from":L[1027]});
}
} catch($e78767877) {
if(R.isCont($e78767877)) {
var $ss78807881 = {"from":L[1027],
"go":function(anf_arg10937887) {
return $Hanf_arg27137889(anf_arg10937887,anf_fun10917888,ann3664121,atom3654120,l3737873,type_DASH_var_DASH_bind306124);
}};
$e78767877.stack[R.EXN_STACKHEIGHT++] = $ss78807881;
}
if(R.isPyretException($e78767877)) {
$e78767877.pyretStack.push(L[1027]);
}
throw $e78767877;
}
var $ret78827883 = $Hanf_arg27137889($z78787879,anf_fun10917888,ann3664121,atom3654120,l3737873,type_DASH_var_DASH_bind306124);
++R.GAS;
return $ret78827883;
});
var anf_arg10967865 = R.makeObject({"let-type-bind":anf_obj10837870,
"global-type-bind":anf_obj10897871,
"type-var-bind":anf_obj10957872});
var anf_arg10987866 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1025],0,arguments);
}
var ann_DASH_check_DASH_temp10977869 = R.throwNoBranchesMatched(L[1025],("cases"));
return ann_DASH_check_DASH_temp10977869;
});
var $z78567857 = D;
var $f78627863 = function(_) {
return R.isFunction(anf_fun10777864)?anf_fun10777864.app(anf_arg10967865,anf_arg10987866):R.ffi.throwNonFunApp(L[1025],anf_fun10777864,[anf_arg10967865,anf_arg10987866]);
};
try {
if(--R.GAS > 0) {
$z78567857 = $f78627863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f78627863,
"from":L[1025]});
}
} catch($e78547855) {
if(R.isCont($e78547855)) {
var $ss78587859 = {"from":L[1025],
"go":function(cont_tail_arg10997867) {
return $Hcont_tail_arg27147868(cont_tail_arg10997867,if_helper10657822);
}};
$e78547855.stack[R.EXN_STACKHEIGHT++] = $ss78587859;
}
if(R.isPyretException($e78547855)) {
$e78547855.pyretStack.push(L[1025]);
}
throw $e78547855;
}
var $ret78607861 = $Hcont_tail_arg27147868($z78567857,if_helper10657822);
++R.GAS;
return $ret78607861;
};
var $Hcont_tail_arg27147868 = function(cont_tail_arg10997867,if_helper10657822) {
if(--R.GAS > 0) {
$z79247925 = R.isFunction(if_helper10657822)?if_helper10657822.app(cont_tail_arg10997867):R.ffi.throwNonFunApp(L[1025],if_helper10657822,[cont_tail_arg10997867]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper10657822)?if_helper10657822.app(cont_tail_arg10997867):R.ffi.throwNonFunApp(L[1025],if_helper10657822,[cont_tail_arg10997867]);
},
"from":L[1025]});
}
++R.GAS;
return $z79247925;
};
var $Hanf_arg27137889 = function(anf_arg10937887,anf_fun10917888,ann3664121,atom3654120,l3737873,type_DASH_var_DASH_bind306124) {
var $z79287929 = D;
var $f79347935 = function(_) {
return R.isFunction(type_DASH_var_DASH_bind306124.$var)?type_DASH_var_DASH_bind306124.$var.app(l3737873,atom3654120,ann3664121):R.ffi.throwNonFunApp(L[1038],type_DASH_var_DASH_bind306124.$var,[l3737873,atom3654120,ann3664121]);
};
try {
if(--R.GAS > 0) {
$z79287929 = $f79347935();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79347935,
"from":L[1038]});
}
} catch($e79267927) {
if(R.isCont($e79267927)) {
var $ss79307931 = {"from":L[1038],
"go":function(anf_arg10947936) {
return $Hanf_arg27127937(anf_arg10947936,anf_arg10937887,anf_fun10917888);
}};
$e79267927.stack[R.EXN_STACKHEIGHT++] = $ss79307931;
}
if(R.isPyretException($e79267927)) {
$e79267927.pyretStack.push(L[1038]);
}
throw $e79267927;
}
var $ret79327933 = $Hanf_arg27127937($z79287929,anf_arg10937887,anf_fun10917888);
++R.GAS;
return $ret79327933;
};
var $Hanf_arg27127937 = function(anf_arg10947936,anf_arg10937887,anf_fun10917888) {
var $z79407941 = D;
var $f79467947 = function(_) {
return R.isFunction(anf_fun10917888)?anf_fun10917888.app(anf_arg10937887,anf_arg10947936):R.ffi.throwNonFunApp(L[1026],anf_fun10917888,[anf_arg10937887,anf_arg10947936]);
};
try {
if(--R.GAS > 0) {
$z79407941 = $f79467947();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79467947,
"from":L[1026]});
}
} catch($e79387939) {
if(R.isCont($e79387939)) {
var $ss79427943 = {"from":L[1026],
"go":function(ann_DASH_check_DASH_temp10907948) {
return $Hann_DASH_check_DASH_temp27117949(ann_DASH_check_DASH_temp10907948);
}};
$e79387939.stack[R.EXN_STACKHEIGHT++] = $ss79427943;
}
if(R.isPyretException($e79387939)) {
$e79387939.pyretStack.push(L[1026]);
}
throw $e79387939;
}
var $ret79447945 = $Hann_DASH_check_DASH_temp27117949($z79407941);
++R.GAS;
return $ret79447945;
};
var $Hann_DASH_check_DASH_temp27117949 = function(ann_DASH_check_DASH_temp10907948) {
return ann_DASH_check_DASH_temp10907948;
};
var $Hanf_arg27107906 = function(anf_arg10877904,anf_fun10857905,ann3664121,atom3654120,global_DASH_type_DASH_bind302116,l3707890) {
var $z79527953 = D;
var $f79587959 = function(_) {
return R.isFunction(global_DASH_type_DASH_bind302116.$var)?global_DASH_type_DASH_bind302116.$var.app(l3707890,atom3654120,ann3664121):R.ffi.throwNonFunApp(L[1039],global_DASH_type_DASH_bind302116.$var,[l3707890,atom3654120,ann3664121]);
};
try {
if(--R.GAS > 0) {
$z79527953 = $f79587959();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79587959,
"from":L[1039]});
}
} catch($e79507951) {
if(R.isCont($e79507951)) {
var $ss79547955 = {"from":L[1039],
"go":function(anf_arg10887960) {
return $Hanf_arg27097961(anf_arg10887960,anf_arg10877904,anf_fun10857905);
}};
$e79507951.stack[R.EXN_STACKHEIGHT++] = $ss79547955;
}
if(R.isPyretException($e79507951)) {
$e79507951.pyretStack.push(L[1039]);
}
throw $e79507951;
}
var $ret79567957 = $Hanf_arg27097961($z79527953,anf_arg10877904,anf_fun10857905);
++R.GAS;
return $ret79567957;
};
var $Hanf_arg27097961 = function(anf_arg10887960,anf_arg10877904,anf_fun10857905) {
var $z79647965 = D;
var $f79707971 = function(_) {
return R.isFunction(anf_fun10857905)?anf_fun10857905.app(anf_arg10877904,anf_arg10887960):R.ffi.throwNonFunApp(L[1030],anf_fun10857905,[anf_arg10877904,anf_arg10887960]);
};
try {
if(--R.GAS > 0) {
$z79647965 = $f79707971();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79707971,
"from":L[1030]});
}
} catch($e79627963) {
if(R.isCont($e79627963)) {
var $ss79667967 = {"from":L[1030],
"go":function(ann_DASH_check_DASH_temp10847972) {
return $Hann_DASH_check_DASH_temp27087973(ann_DASH_check_DASH_temp10847972);
}};
$e79627963.stack[R.EXN_STACKHEIGHT++] = $ss79667967;
}
if(R.isPyretException($e79627963)) {
$e79627963.pyretStack.push(L[1030]);
}
throw $e79627963;
}
var $ret79687969 = $Hann_DASH_check_DASH_temp27087973($z79647965);
++R.GAS;
return $ret79687969;
};
var $Hann_DASH_check_DASH_temp27087973 = function(ann_DASH_check_DASH_temp10847972) {
return ann_DASH_check_DASH_temp10847972;
};
var $Hanf_arg27077923 = function(anf_arg10817921,anf_fun10797922,ann3664121,atom3654120,l3677907,let_DASH_type_DASH_bind304120) {
var $z79767977 = D;
var $f79827983 = function(_) {
return R.isFunction(let_DASH_type_DASH_bind304120.$var)?let_DASH_type_DASH_bind304120.$var.app(l3677907,atom3654120,ann3664121):R.ffi.throwNonFunApp(L[1040],let_DASH_type_DASH_bind304120.$var,[l3677907,atom3654120,ann3664121]);
};
try {
if(--R.GAS > 0) {
$z79767977 = $f79827983();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79827983,
"from":L[1040]});
}
} catch($e79747975) {
if(R.isCont($e79747975)) {
var $ss79787979 = {"from":L[1040],
"go":function(anf_arg10827984) {
return $Hanf_arg27067985(anf_arg10827984,anf_arg10817921,anf_fun10797922);
}};
$e79747975.stack[R.EXN_STACKHEIGHT++] = $ss79787979;
}
if(R.isPyretException($e79747975)) {
$e79747975.pyretStack.push(L[1040]);
}
throw $e79747975;
}
var $ret79807981 = $Hanf_arg27067985($z79767977,anf_arg10817921,anf_fun10797922);
++R.GAS;
return $ret79807981;
};
var $Hanf_arg27067985 = function(anf_arg10827984,anf_arg10817921,anf_fun10797922) {
var $z79887989 = D;
var $f79947995 = function(_) {
return R.isFunction(anf_fun10797922)?anf_fun10797922.app(anf_arg10817921,anf_arg10827984):R.ffi.throwNonFunApp(L[1034],anf_fun10797922,[anf_arg10817921,anf_arg10827984]);
};
try {
if(--R.GAS > 0) {
$z79887989 = $f79947995();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f79947995,
"from":L[1034]});
}
} catch($e79867987) {
if(R.isCont($e79867987)) {
var $ss79907991 = {"from":L[1034],
"go":function(ann_DASH_check_DASH_temp10787996) {
return $Hann_DASH_check_DASH_temp27057997(ann_DASH_check_DASH_temp10787996);
}};
$e79867987.stack[R.EXN_STACKHEIGHT++] = $ss79907991;
}
if(R.isPyretException($e79867987)) {
$e79867987.pyretStack.push(L[1034]);
}
throw $e79867987;
}
var $ret79927993 = $Hann_DASH_check_DASH_temp27057997($z79887989);
++R.GAS;
return $ret79927993;
};
var $Hann_DASH_check_DASH_temp27057997 = function(ann_DASH_check_DASH_temp10787996) {
return ann_DASH_check_DASH_temp10787996;
};
var $Hanf_arg27197835 = function(anf_arg10707834,if_helper10657822,_plus9,print13) {
var $z80008001 = D;
var $f80068007 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("No binding for "),anf_arg10707834):R.ffi.throwNonFunApp(L[1041],_plus9,[("No binding for "),anf_arg10707834]);
};
try {
if(--R.GAS > 0) {
$z80008001 = $f80068007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80068007,
"from":L[1041]});
}
} catch($e79987999) {
if(R.isCont($e79987999)) {
var $ss80028003 = {"from":L[1041],
"go":function(anf_arg10718008) {
return $Hanf_arg27188009(anf_arg10718008,if_helper10657822,print13);
}};
$e79987999.stack[R.EXN_STACKHEIGHT++] = $ss80028003;
}
if(R.isPyretException($e79987999)) {
$e79987999.pyretStack.push(L[1041]);
}
throw $e79987999;
}
var $ret80048005 = $Hanf_arg27188009($z80008001,if_helper10657822,print13);
++R.GAS;
return $ret80048005;
};
var $Hanf_arg27188009 = function(anf_arg10718008,if_helper10657822,print13) {
var $z80128013 = D;
var $f80188019 = function(_) {
return R.isFunction(print13)?print13.app(anf_arg10718008):R.ffi.throwNonFunApp(L[1042],print13,[anf_arg10718008]);
};
try {
if(--R.GAS > 0) {
$z80128013 = $f80188019();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80188019,
"from":L[1042]});
}
} catch($e80108011) {
if(R.isCont($e80108011)) {
var $ss80148015 = {"from":L[1042],
"go":function(cont_tail_arg10728020) {
return $Hcont_tail_arg27178021(cont_tail_arg10728020,if_helper10657822);
}};
$e80108011.stack[R.EXN_STACKHEIGHT++] = $ss80148015;
}
if(R.isPyretException($e80108011)) {
$e80108011.pyretStack.push(L[1042]);
}
throw $e80108011;
}
var $ret80168017 = $Hcont_tail_arg27178021($z80128013,if_helper10657822);
++R.GAS;
return $ret80168017;
};
var $Hcont_tail_arg27178021 = function(cont_tail_arg10728020,if_helper10657822) {
if(--R.GAS > 0) {
$z80228023 = R.isFunction(if_helper10657822)?if_helper10657822.app(cont_tail_arg10728020):R.ffi.throwNonFunApp(L[1042],if_helper10657822,[cont_tail_arg10728020]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper10657822)?if_helper10657822.app(cont_tail_arg10728020):R.ffi.throwNonFunApp(L[1042],if_helper10657822,[cont_tail_arg10728020]);
},
"from":L[1042]});
}
++R.GAS;
return $z80228023;
};
var $Hann_DASH_check_DASH_temp27044155 = function(ann_DASH_check_DASH_temp10154154) {
return ann_DASH_check_DASH_temp10154154;
};
var $Hanf_arg27034167 = function(anf_arg10574166,_plus9,raise14) {
var $z80268027 = D;
var $f80328033 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("Unexpected atom type: "),anf_arg10574166):R.ffi.throwNonFunApp(L[1043],_plus9,[("Unexpected atom type: "),anf_arg10574166]);
};
try {
if(--R.GAS > 0) {
$z80268027 = $f80328033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80328033,
"from":L[1043]});
}
} catch($e80248025) {
if(R.isCont($e80248025)) {
var $ss80288029 = {"from":L[1043],
"go":function(anf_arg10588034) {
return $Hanf_arg27028035(anf_arg10588034,raise14);
}};
$e80248025.stack[R.EXN_STACKHEIGHT++] = $ss80288029;
}
if(R.isPyretException($e80248025)) {
$e80248025.pyretStack.push(L[1043]);
}
throw $e80248025;
}
var $ret80308031 = $Hanf_arg27028035($z80268027,raise14);
++R.GAS;
return $ret80308031;
};
var $Hanf_arg27028035 = function(anf_arg10588034,raise14) {
var $z80388039 = D;
var $f80448045 = function(_) {
return R.isFunction(raise14)?raise14.app(anf_arg10588034):R.ffi.throwNonFunApp(L[473],raise14,[anf_arg10588034]);
};
try {
if(--R.GAS > 0) {
$z80388039 = $f80448045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80448045,
"from":L[473]});
}
} catch($e80368037) {
if(R.isCont($e80368037)) {
var $ss80408041 = {"from":L[473],
"go":function(ann_DASH_check_DASH_temp10568046) {
return $Hann_DASH_check_DASH_temp27018047(ann_DASH_check_DASH_temp10568046);
}};
$e80368037.stack[R.EXN_STACKHEIGHT++] = $ss80408041;
}
if(R.isPyretException($e80368037)) {
$e80368037.pyretStack.push(L[473]);
}
throw $e80368037;
}
var $ret80428043 = $Hann_DASH_check_DASH_temp27018047($z80388039);
++R.GAS;
return $ret80428043;
};
var $Hann_DASH_check_DASH_temp27018047 = function(ann_DASH_check_DASH_temp10568046) {
return ann_DASH_check_DASH_temp10568046;
};
var $Hatom27004183 = function(atom3644182,bindings3564139,env3554138,l3634170,none6979,typ3574140) {
var anf_fun10508060 = G(bindings3564139,"set",L[1046]);
var anf_fun10518058 = G(atom3644182,"key",L[1045]);
var $z80508051 = D;
var $f80568057 = function(_) {
return R.isFunction(anf_fun10518058)?anf_fun10518058.app():R.ffi.throwNonFunApp(L[1044],anf_fun10518058,[]);
};
try {
if(--R.GAS > 0) {
$z80508051 = $f80568057();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80568057,
"from":L[1044]});
}
} catch($e80488049) {
if(R.isCont($e80488049)) {
var $ss80528053 = {"from":L[1044],
"go":function(anf_arg10528059) {
return $Hanf_arg26998061(anf_arg10528059,anf_fun10508060,atom3644182,env3554138,l3634170,none6979,typ3574140);
}};
$e80488049.stack[R.EXN_STACKHEIGHT++] = $ss80528053;
}
if(R.isPyretException($e80488049)) {
$e80488049.pyretStack.push(L[1044]);
}
throw $e80488049;
}
var $ret80548055 = $Hanf_arg26998061($z80508051,anf_fun10508060,atom3644182,env3554138,l3634170,none6979,typ3574140);
++R.GAS;
return $ret80548055;
};
var $Hanf_arg26998061 = function(anf_arg10528059,anf_fun10508060,atom3644182,env3554138,l3634170,none6979,typ3574140) {
var $z80648065 = D;
var $f80708071 = function(_) {
return R.isFunction(typ3574140)?typ3574140.app(l3634170,atom3644182,none6979):R.ffi.throwNonFunApp(L[1047],typ3574140,[l3634170,atom3644182,none6979]);
};
try {
if(--R.GAS > 0) {
$z80648065 = $f80708071();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80708071,
"from":L[1047]});
}
} catch($e80628063) {
if(R.isCont($e80628063)) {
var $ss80668067 = {"from":L[1047],
"go":function(anf_arg10538072) {
return $Hanf_arg26988073(anf_arg10538072,anf_arg10528059,anf_fun10508060,atom3644182,env3554138);
}};
$e80628063.stack[R.EXN_STACKHEIGHT++] = $ss80668067;
}
if(R.isPyretException($e80628063)) {
$e80628063.pyretStack.push(L[1047]);
}
throw $e80628063;
}
var $ret80688069 = $Hanf_arg26988073($z80648065,anf_arg10528059,anf_fun10508060,atom3644182,env3554138);
++R.GAS;
return $ret80688069;
};
var $Hanf_arg26988073 = function(anf_arg10538072,anf_arg10528059,anf_fun10508060,atom3644182,env3554138) {
var $z80768077 = D;
var $f80828083 = function(_) {
return R.isFunction(anf_fun10508060)?anf_fun10508060.app(anf_arg10528059,anf_arg10538072):R.ffi.throwNonFunApp(L[1048],anf_fun10508060,[anf_arg10528059,anf_arg10538072]);
};
try {
if(--R.GAS > 0) {
$z80768077 = $f80828083();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80828083,
"from":L[1048]});
}
} catch($e80748075) {
if(R.isCont($e80748075)) {
var $ss80788079 = {"from":L[1048],
"go":function(anf_begin_app_dropped26968084) {
return $Hanf_begin_app_dropped26978085(anf_begin_app_dropped26968084,atom3644182,env3554138);
}};
$e80748075.stack[R.EXN_STACKHEIGHT++] = $ss80788079;
}
if(R.isPyretException($e80748075)) {
$e80748075.pyretStack.push(L[1048]);
}
throw $e80748075;
}
var $ret80808081 = $Hanf_begin_app_dropped26978085($z80768077,atom3644182,env3554138);
++R.GAS;
return $ret80808081;
};
var $Hanf_begin_app_dropped26978085 = function(anf_begin_app_dropped26968084,atom3644182,env3554138) {
var ann_DASH_check_DASH_temp10488086 = R.makeObject({"atom":atom3644182,
"env":env3554138});
return ann_DASH_check_DASH_temp10488086;
};
var $Hand_DASH_oper_DASH_26954198 = function(and_DASH_oper_DASH_944197,C923,bindings3564139,env3554138,is_DASH_shadowing3544137,l3584184,link3774,name_DASH_errors3453956,names28657,none6979,s3594185,typ3574140,not11,nothing12) {
var if_helper10198098 = R.makeFunction(function(if_helper_arg10208116) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[479],1,arguments);
}
var when_DASH_938143 = if_helper_arg10208116;
var if_helper10218129 = R.makeFunction(function(if_helper_arg10228148) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1052],1,arguments);
}
if_helper_arg10228148;
var anf_fun10238159 = G(names28657,"make-atom",L[1054]);
var $z81518152 = D;
var $f81578158 = function(_) {
return R.isFunction(anf_fun10238159)?anf_fun10238159.app(s3594185):R.ffi.throwNonFunApp(L[1053],anf_fun10238159,[s3594185]);
};
try {
if(--R.GAS > 0) {
$z81518152 = $f81578158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81578158,
"from":L[1053]});
}
} catch($e81498150) {
if(R.isCont($e81498150)) {
var $ss81538154 = {"from":L[1053],
"go":function(atom3618160) {
return $Hatom26868161(atom3618160,bindings3564139,env3554138,l3584184,none6979,s3594185,typ3574140);
}};
$e81498150.stack[R.EXN_STACKHEIGHT++] = $ss81538154;
}
if(R.isPyretException($e81498150)) {
$e81498150.pyretStack.push(L[1053]);
}
throw $e81498150;
}
var $ret81558156 = $Hatom26868161($z81518152,bindings3564139,env3554138,l3584184,none6979,s3594185,typ3574140);
++R.GAS;
return $ret81558156;
});
var anf_if10318147 = R.isBoolean(when_DASH_938143);
if(R.isPyretTrue(anf_if10318147)) {
if(R.isPyretTrue(when_DASH_938143)) {
var anf_fun10338127 = G(env3554138,"get",L[1051]);
var $z81198120 = D;
var $f81258126 = function(_) {
return R.isFunction(anf_fun10338127)?anf_fun10338127.app(s3594185):R.ffi.throwNonFunApp(L[1050],anf_fun10338127,[s3594185]);
};
try {
if(--R.GAS > 0) {
$z81198120 = $f81258126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81258126,
"from":L[1050]});
}
} catch($e81178118) {
if(R.isCont($e81178118)) {
var $ss81218122 = {"from":L[1050],
"go":function(anf_bracket10348128) {
return $Hanf_bracket26908130(anf_bracket10348128,C923,if_helper10218129,l3584184,link3774,name_DASH_errors3453956,s3594185,nothing12);
}};
$e81178118.stack[R.EXN_STACKHEIGHT++] = $ss81218122;
}
if(R.isPyretException($e81178118)) {
$e81178118.pyretStack.push(L[1050]);
}
throw $e81178118;
}
var $ret81238124 = $Hanf_bracket26908130($z81198120,C923,if_helper10218129,l3584184,link3774,name_DASH_errors3453956,s3594185,nothing12);
++R.GAS;
return $ret81238124;
} else {
var $z81338134 = D;
var $f81398140 = function(_) {
return R.isFunction(if_helper10218129)?if_helper10218129.app(nothing12):R.ffi.throwNonFunApp(L[1052],if_helper10218129,[nothing12]);
};
try {
if(--R.GAS > 0) {
$z81338134 = $f81398140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81398140,
"from":L[1052]});
}
} catch($e81318132) {
if(R.isCont($e81318132)) {
var $ss81358136 = {"from":L[1052],
"go":function(cont_tail_app10328141) {
return $Hcont_tail_app26918142(cont_tail_app10328141);
}};
$e81318132.stack[R.EXN_STACKHEIGHT++] = $ss81358136;
}
if(R.isPyretException($e81318132)) {
$e81318132.pyretStack.push(L[1052]);
}
throw $e81318132;
}
var $ret81378138 = $Hcont_tail_app26918142($z81338134);
++R.GAS;
return $ret81378138;
}
} else {
var cont_tail_arg10298146 = R.throwNonBooleanCondition(L[479],("when"),when_DASH_938143);
if(--R.GAS > 0) {
$z81448145 = R.isFunction(if_helper10218129)?if_helper10218129.app(cont_tail_arg10298146):R.ffi.throwNonFunApp(L[479],if_helper10218129,[cont_tail_arg10298146]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper10218129)?if_helper10218129.app(cont_tail_arg10298146):R.ffi.throwNonFunApp(L[479],if_helper10218129,[cont_tail_arg10298146]);
},
"from":L[479]});
}
++R.GAS;
return $z81448145;
}
});
var anf_if10418115 = R.isBoolean(and_DASH_oper_DASH_944197);
if(R.isPyretTrue(anf_if10418115)) {
if(R.isPyretTrue(and_DASH_oper_DASH_944197)) {
var $z80898090 = D;
var $f80958096 = function(_) {
return R.isFunction(not11)?not11.app(is_DASH_shadowing3544137):R.ffi.throwNonFunApp(L[479],not11,[is_DASH_shadowing3544137]);
};
try {
if(--R.GAS > 0) {
$z80898090 = $f80958096();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f80958096,
"from":L[479]});
}
} catch($e80878088) {
if(R.isCont($e80878088)) {
var $ss80918092 = {"from":L[479],
"go":function(and_DASH_oper_DASH_958097) {
return $Hand_DASH_oper_DASH_26938099(and_DASH_oper_DASH_958097,if_helper10198098);
}};
$e80878088.stack[R.EXN_STACKHEIGHT++] = $ss80918092;
}
if(R.isPyretException($e80878088)) {
$e80878088.pyretStack.push(L[479]);
}
throw $e80878088;
}
var $ret80938094 = $Hand_DASH_oper_DASH_26938099($z80898090,if_helper10198098);
++R.GAS;
return $ret80938094;
} else {
var $z81028103 = D;
var $f81088109 = function(_) {
return R.isFunction(if_helper10198098)?if_helper10198098.app((false)):R.ffi.throwNonFunApp(L[479],if_helper10198098,[(false)]);
};
try {
if(--R.GAS > 0) {
$z81028103 = $f81088109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81088109,
"from":L[479]});
}
} catch($e81008101) {
if(R.isCont($e81008101)) {
var $ss81048105 = {"from":L[479],
"go":function(cont_tail_app10428110) {
return $Hcont_tail_app26948111(cont_tail_app10428110);
}};
$e81008101.stack[R.EXN_STACKHEIGHT++] = $ss81048105;
}
if(R.isPyretException($e81008101)) {
$e81008101.pyretStack.push(L[479]);
}
throw $e81008101;
}
var $ret81068107 = $Hcont_tail_app26948111($z81028103);
++R.GAS;
return $ret81068107;
}
} else {
var cont_tail_arg10398114 = R.throwNonBooleanOp(L[1049],("first"),("and"),and_DASH_oper_DASH_944197);
if(--R.GAS > 0) {
$z81128113 = R.isFunction(if_helper10198098)?if_helper10198098.app(cont_tail_arg10398114):R.ffi.throwNonFunApp(L[1049],if_helper10198098,[cont_tail_arg10398114]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper10198098)?if_helper10198098.app(cont_tail_arg10398114):R.ffi.throwNonFunApp(L[1049],if_helper10198098,[cont_tail_arg10398114]);
},
"from":L[1049]});
}
++R.GAS;
return $z81128113;
}
};
var $Hand_DASH_oper_DASH_26938099 = function(and_DASH_oper_DASH_958097,if_helper10198098) {
var anf_if10458177 = R.isBoolean(and_DASH_oper_DASH_958097);
if(R.isPyretTrue(anf_if10458177)) {
var $z81648165 = D;
var $f81708171 = function(_) {
return R.isFunction(if_helper10198098)?if_helper10198098.app(and_DASH_oper_DASH_958097):R.ffi.throwNonFunApp(L[479],if_helper10198098,[and_DASH_oper_DASH_958097]);
};
try {
if(--R.GAS > 0) {
$z81648165 = $f81708171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81708171,
"from":L[479]});
}
} catch($e81628163) {
if(R.isCont($e81628163)) {
var $ss81668167 = {"from":L[479],
"go":function(cont_tail_app10468172) {
return $Hcont_tail_app26928173(cont_tail_app10468172);
}};
$e81628163.stack[R.EXN_STACKHEIGHT++] = $ss81668167;
}
if(R.isPyretException($e81628163)) {
$e81628163.pyretStack.push(L[479]);
}
throw $e81628163;
}
var $ret81688169 = $Hcont_tail_app26928173($z81648165);
++R.GAS;
return $ret81688169;
} else {
var cont_tail_arg10438176 = R.throwNonBooleanOp(L[1055],("second"),("and"),and_DASH_oper_DASH_958097);
if(--R.GAS > 0) {
$z81748175 = R.isFunction(if_helper10198098)?if_helper10198098.app(cont_tail_arg10438176):R.ffi.throwNonFunApp(L[1055],if_helper10198098,[cont_tail_arg10438176]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper10198098)?if_helper10198098.app(cont_tail_arg10438176):R.ffi.throwNonFunApp(L[1055],if_helper10198098,[cont_tail_arg10438176]);
},
"from":L[1055]});
}
++R.GAS;
return $z81748175;
}
};
var $Hcont_tail_app26928173 = function(cont_tail_app10468172) {
return cont_tail_app10468172;
};
var $Hcont_tail_app26948111 = function(cont_tail_app10428110) {
return cont_tail_app10428110;
};
var $Hanf_bracket26908130 = function(anf_bracket10348128,C923,if_helper10218129,l3584184,link3774,name_DASH_errors3453956,s3594185,nothing12) {
var old_DASH_loc3608189 = G(anf_bracket10348128,"loc",L[1058]);
var anf_fun10358188 = G(C923,"shadow-id",L[1057]);
var $z81808181 = D;
var $f81868187 = function(_) {
return R.isFunction(anf_fun10358188)?anf_fun10358188.app(s3594185,l3584184,old_DASH_loc3608189):R.ffi.throwNonFunApp(L[1056],anf_fun10358188,[s3594185,l3584184,old_DASH_loc3608189]);
};
try {
if(--R.GAS > 0) {
$z81808181 = $f81868187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f81868187,
"from":L[1056]});
}
} catch($e81788179) {
if(R.isCont($e81788179)) {
var $ss81828183 = {"from":L[1056],
"go":function(anf_arg10368190) {
return $Hanf_arg26898191(anf_arg10368190,if_helper10218129,link3774,name_DASH_errors3453956,nothing12);
}};
$e81788179.stack[R.EXN_STACKHEIGHT++] = $ss81828183;
}
if(R.isPyretException($e81788179)) {
$e81788179.pyretStack.push(L[1056]);
}
throw $e81788179;
}
var $ret81848185 = $Hanf_arg26898191($z81808181,if_helper10218129,link3774,name_DASH_errors3453956,nothing12);
++R.GAS;
return $ret81848185;
};
var $Hanf_arg26898191 = function(anf_arg10368190,if_helper10218129,link3774,name_DASH_errors3453956,nothing12) {
var $z81948195 = D;
var $f82008201 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg10368190,name_DASH_errors3453956.$var):R.ffi.throwNonFunApp(L[1059],link3774,[anf_arg10368190,name_DASH_errors3453956.$var]);
};
try {
if(--R.GAS > 0) {
$z81948195 = $f82008201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82008201,
"from":L[1059]});
}
} catch($e81928193) {
if(R.isCont($e81928193)) {
var $ss81968197 = {"from":L[1059],
"go":function(anf_assign10378202) {
return $Hanf_assign26888203(anf_assign10378202,if_helper10218129,name_DASH_errors3453956,nothing12);
}};
$e81928193.stack[R.EXN_STACKHEIGHT++] = $ss81968197;
}
if(R.isPyretException($e81928193)) {
$e81928193.pyretStack.push(L[1059]);
}
throw $e81928193;
}
var $ret81988199 = $Hanf_assign26888203($z81948195,if_helper10218129,name_DASH_errors3453956,nothing12);
++R.GAS;
return $ret81988199;
};
var $Hanf_assign26888203 = function(anf_assign10378202,if_helper10218129,name_DASH_errors3453956,nothing12) {
name_DASH_errors3453956.$var = anf_assign10378202;
var $z82068207 = D;
var $f82128213 = function(_) {
return R.isFunction(if_helper10218129)?if_helper10218129.app(nothing12):R.ffi.throwNonFunApp(L[1052],if_helper10218129,[nothing12]);
};
try {
if(--R.GAS > 0) {
$z82068207 = $f82128213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82128213,
"from":L[1052]});
}
} catch($e82048205) {
if(R.isCont($e82048205)) {
var $ss82088209 = {"from":L[1052],
"go":function(cont_tail_app10388214) {
return $Hcont_tail_app26878215(cont_tail_app10388214);
}};
$e82048205.stack[R.EXN_STACKHEIGHT++] = $ss82088209;
}
if(R.isPyretException($e82048205)) {
$e82048205.pyretStack.push(L[1052]);
}
throw $e82048205;
}
var $ret82108211 = $Hcont_tail_app26878215($z82068207);
++R.GAS;
return $ret82108211;
};
var $Hcont_tail_app26878215 = function(cont_tail_app10388214) {
return cont_tail_app10388214;
};
var $Hcont_tail_app26918142 = function(cont_tail_app10328141) {
return cont_tail_app10328141;
};
var $Hatom26868161 = function(atom3618160,bindings3564139,env3554138,l3584184,none6979,s3594185,typ3574140) {
var $z82188219 = D;
var $f82248225 = function(_) {
return R.isFunction(typ3574140)?typ3574140.app(l3584184,atom3618160,none6979):R.ffi.throwNonFunApp(L[1060],typ3574140,[l3584184,atom3618160,none6979]);
};
try {
if(--R.GAS > 0) {
$z82188219 = $f82248225();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82248225,
"from":L[1060]});
}
} catch($e82168217) {
if(R.isCont($e82168217)) {
var $ss82208221 = {"from":L[1060],
"go":function(binding3628226) {
return $Hbinding26858227(binding3628226,atom3618160,bindings3564139,env3554138,s3594185);
}};
$e82168217.stack[R.EXN_STACKHEIGHT++] = $ss82208221;
}
if(R.isPyretException($e82168217)) {
$e82168217.pyretStack.push(L[1060]);
}
throw $e82168217;
}
var $ret82228223 = $Hbinding26858227($z82188219,atom3618160,bindings3564139,env3554138,s3594185);
++R.GAS;
return $ret82228223;
};
var $Hbinding26858227 = function(binding3628226,atom3618160,bindings3564139,env3554138,s3594185) {
var anf_fun10248240 = G(bindings3564139,"set",L[1063]);
var anf_fun10258238 = G(atom3618160,"key",L[1062]);
var $z82308231 = D;
var $f82368237 = function(_) {
return R.isFunction(anf_fun10258238)?anf_fun10258238.app():R.ffi.throwNonFunApp(L[1061],anf_fun10258238,[]);
};
try {
if(--R.GAS > 0) {
$z82308231 = $f82368237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82368237,
"from":L[1061]});
}
} catch($e82288229) {
if(R.isCont($e82288229)) {
var $ss82328233 = {"from":L[1061],
"go":function(anf_arg10268239) {
return $Hanf_arg26848241(anf_arg10268239,anf_fun10248240,atom3618160,binding3628226,env3554138,s3594185);
}};
$e82288229.stack[R.EXN_STACKHEIGHT++] = $ss82328233;
}
if(R.isPyretException($e82288229)) {
$e82288229.pyretStack.push(L[1061]);
}
throw $e82288229;
}
var $ret82348235 = $Hanf_arg26848241($z82308231,anf_fun10248240,atom3618160,binding3628226,env3554138,s3594185);
++R.GAS;
return $ret82348235;
};
var $Hanf_arg26848241 = function(anf_arg10268239,anf_fun10248240,atom3618160,binding3628226,env3554138,s3594185) {
var $z82448245 = D;
var $f82508251 = function(_) {
return R.isFunction(anf_fun10248240)?anf_fun10248240.app(anf_arg10268239,binding3628226):R.ffi.throwNonFunApp(L[1064],anf_fun10248240,[anf_arg10268239,binding3628226]);
};
try {
if(--R.GAS > 0) {
$z82448245 = $f82508251();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82508251,
"from":L[1064]});
}
} catch($e82428243) {
if(R.isCont($e82428243)) {
var $ss82468247 = {"from":L[1064],
"go":function(anf_begin_app_dropped26818252) {
return $Hanf_begin_app_dropped26838253(anf_begin_app_dropped26818252,atom3618160,binding3628226,env3554138,s3594185);
}};
$e82428243.stack[R.EXN_STACKHEIGHT++] = $ss82468247;
}
if(R.isPyretException($e82428243)) {
$e82428243.pyretStack.push(L[1064]);
}
throw $e82428243;
}
var $ret82488249 = $Hanf_begin_app_dropped26838253($z82448245,atom3618160,binding3628226,env3554138,s3594185);
++R.GAS;
return $ret82488249;
};
var $Hanf_begin_app_dropped26838253 = function(anf_begin_app_dropped26818252,atom3618160,binding3628226,env3554138,s3594185) {
var anf_fun10278264 = G(env3554138,"set",L[1066]);
var $z82568257 = D;
var $f82628263 = function(_) {
return R.isFunction(anf_fun10278264)?anf_fun10278264.app(s3594185,binding3628226):R.ffi.throwNonFunApp(L[1065],anf_fun10278264,[s3594185,binding3628226]);
};
try {
if(--R.GAS > 0) {
$z82568257 = $f82628263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82628263,
"from":L[1065]});
}
} catch($e82548255) {
if(R.isCont($e82548255)) {
var $ss82588259 = {"from":L[1065],
"go":function(anf_obj10288265) {
return $Hanf_obj26828266(anf_obj10288265,atom3618160);
}};
$e82548255.stack[R.EXN_STACKHEIGHT++] = $ss82588259;
}
if(R.isPyretException($e82548255)) {
$e82548255.pyretStack.push(L[1065]);
}
throw $e82548255;
}
var $ret82608261 = $Hanf_obj26828266($z82568257,atom3618160);
++R.GAS;
return $ret82608261;
};
var $Hanf_obj26828266 = function(anf_obj10288265,atom3618160) {
var ann_DASH_check_DASH_temp10178267 = R.makeObject({"atom":atom3618160,
"env":anf_obj10288265});
return ann_DASH_check_DASH_temp10178267;
};
var $Hanf_arg2679175 = function(anf_arg1008173,anf_arg1006174,fold6171,initial337161) {
var anf_arg10098278 = G(initial337161,"types",L[1067]);
var $z82708271 = D;
var $f82768277 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg1006174,anf_arg1008173,anf_arg10098278):R.ffi.throwNonFunApp(L[6],fold6171,[anf_arg1006174,anf_arg1008173,anf_arg10098278]);
};
try {
if(--R.GAS > 0) {
$z82708271 = $f82768277();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82768277,
"from":L[6]});
}
} catch($e82688269) {
if(R.isCont($e82688269)) {
var $ss82728273 = {"from":L[6],
"go":function(ann_DASH_check_DASH_temp9908279) {
return $Hann_DASH_check_DASH_temp26788280(ann_DASH_check_DASH_temp9908279);
}};
$e82688269.stack[R.EXN_STACKHEIGHT++] = $ss82728273;
}
if(R.isPyretException($e82688269)) {
$e82688269.pyretStack.push(L[6]);
}
throw $e82688269;
}
var $ret82748275 = $Hann_DASH_check_DASH_temp26788280($z82708271);
++R.GAS;
return $ret82748275;
};
var $Hann_DASH_check_DASH_temp26788280 = function(ann_DASH_check_DASH_temp9908279) {
return ann_DASH_check_DASH_temp9908279;
};
var $Hann_DASH_check_DASH_temp2677192 = function(ann_DASH_check_DASH_temp991191) {
return ann_DASH_check_DASH_temp991191;
};
var $Hanf_arg2676210 = function(anf_arg998208,anf_fun996209,global_DASH_type_DASH_bind302116,name342196,names28657,none6979) {
var anf_fun9998291 = G(names28657,"s-type-global",L[1069]);
var $z82838284 = D;
var $f82898290 = function(_) {
return R.isFunction(anf_fun9998291)?anf_fun9998291.app(name342196):R.ffi.throwNonFunApp(L[1068],anf_fun9998291,[name342196]);
};
try {
if(--R.GAS > 0) {
$z82838284 = $f82898290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f82898290,
"from":L[1068]});
}
} catch($e82818282) {
if(R.isCont($e82818282)) {
var $ss82858286 = {"from":L[1068],
"go":function(anf_arg10008292) {
return $Hanf_arg26758293(anf_arg10008292,anf_arg998208,anf_fun996209,global_DASH_type_DASH_bind302116,name342196,none6979);
}};
$e82818282.stack[R.EXN_STACKHEIGHT++] = $ss82858286;
}
if(R.isPyretException($e82818282)) {
$e82818282.pyretStack.push(L[1068]);
}
throw $e82818282;
}
var $ret82878288 = $Hanf_arg26758293($z82838284,anf_arg998208,anf_fun996209,global_DASH_type_DASH_bind302116,name342196,none6979);
++R.GAS;
return $ret82878288;
};
var $Hanf_arg26758293 = function(anf_arg10008292,anf_arg998208,anf_fun996209,global_DASH_type_DASH_bind302116,name342196,none6979) {
var $z82968297 = D;
var $f83028303 = function(_) {
return R.isFunction(global_DASH_type_DASH_bind302116.$var)?global_DASH_type_DASH_bind302116.$var.app(anf_arg998208,anf_arg10008292,none6979):R.ffi.throwNonFunApp(L[1070],global_DASH_type_DASH_bind302116.$var,[anf_arg998208,anf_arg10008292,none6979]);
};
try {
if(--R.GAS > 0) {
$z82968297 = $f83028303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83028303,
"from":L[1070]});
}
} catch($e82948295) {
if(R.isCont($e82948295)) {
var $ss82988299 = {"from":L[1070],
"go":function(anf_arg10018304) {
return $Hanf_arg26748305(anf_arg10018304,anf_fun996209,name342196);
}};
$e82948295.stack[R.EXN_STACKHEIGHT++] = $ss82988299;
}
if(R.isPyretException($e82948295)) {
$e82948295.pyretStack.push(L[1070]);
}
throw $e82948295;
}
var $ret83008301 = $Hanf_arg26748305($z82968297,anf_fun996209,name342196);
++R.GAS;
return $ret83008301;
};
var $Hanf_arg26748305 = function(anf_arg10018304,anf_fun996209,name342196) {
var $z83088309 = D;
var $f83148315 = function(_) {
return R.isFunction(anf_fun996209)?anf_fun996209.app(name342196,anf_arg10018304):R.ffi.throwNonFunApp(L[11],anf_fun996209,[name342196,anf_arg10018304]);
};
try {
if(--R.GAS > 0) {
$z83088309 = $f83148315();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83148315,
"from":L[11]});
}
} catch($e83068307) {
if(R.isCont($e83068307)) {
var $ss83108311 = {"from":L[11],
"go":function(ann_DASH_check_DASH_temp9958316) {
return $Hann_DASH_check_DASH_temp26738317(ann_DASH_check_DASH_temp9958316);
}};
$e83068307.stack[R.EXN_STACKHEIGHT++] = $ss83108311;
}
if(R.isPyretException($e83068307)) {
$e83068307.pyretStack.push(L[11]);
}
throw $e83068307;
}
var $ret83128313 = $Hann_DASH_check_DASH_temp26738317($z83088309);
++R.GAS;
return $ret83128313;
};
var $Hann_DASH_check_DASH_temp26738317 = function(ann_DASH_check_DASH_temp9958316) {
return ann_DASH_check_DASH_temp9958316;
};
var $Hanf_arg2672229 = function(anf_arg987227,anf_arg985228,fold6171,initial331215) {
var anf_arg9888328 = G(initial331215,"bindings",L[1071]);
var $z83208321 = D;
var $f83268327 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg985228,anf_arg987227,anf_arg9888328):R.ffi.throwNonFunApp(L[17],fold6171,[anf_arg985228,anf_arg987227,anf_arg9888328]);
};
try {
if(--R.GAS > 0) {
$z83208321 = $f83268327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83268327,
"from":L[17]});
}
} catch($e83188319) {
if(R.isCont($e83188319)) {
var $ss83228323 = {"from":L[17],
"go":function(ann_DASH_check_DASH_temp9698329) {
return $Hann_DASH_check_DASH_temp26718330(ann_DASH_check_DASH_temp9698329);
}};
$e83188319.stack[R.EXN_STACKHEIGHT++] = $ss83228323;
}
if(R.isPyretException($e83188319)) {
$e83188319.pyretStack.push(L[17]);
}
throw $e83188319;
}
var $ret83248325 = $Hann_DASH_check_DASH_temp26718330($z83208321);
++R.GAS;
return $ret83248325;
};
var $Hann_DASH_check_DASH_temp26718330 = function(ann_DASH_check_DASH_temp9698329) {
return ann_DASH_check_DASH_temp9698329;
};
var $Hann_DASH_check_DASH_temp2670246 = function(ann_DASH_check_DASH_temp970245) {
return ann_DASH_check_DASH_temp970245;
};
var $Hanf_arg2669264 = function(anf_arg977262,anf_fun975263,let_DASH_bind29398,name336250,names28657,none6979) {
var anf_fun9788341 = G(names28657,"s-global",L[1073]);
var $z83338334 = D;
var $f83398340 = function(_) {
return R.isFunction(anf_fun9788341)?anf_fun9788341.app(name336250):R.ffi.throwNonFunApp(L[1072],anf_fun9788341,[name336250]);
};
try {
if(--R.GAS > 0) {
$z83338334 = $f83398340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83398340,
"from":L[1072]});
}
} catch($e83318332) {
if(R.isCont($e83318332)) {
var $ss83358336 = {"from":L[1072],
"go":function(anf_arg9798342) {
return $Hanf_arg26688343(anf_arg9798342,anf_arg977262,anf_fun975263,let_DASH_bind29398,name336250,none6979);
}};
$e83318332.stack[R.EXN_STACKHEIGHT++] = $ss83358336;
}
if(R.isPyretException($e83318332)) {
$e83318332.pyretStack.push(L[1072]);
}
throw $e83318332;
}
var $ret83378338 = $Hanf_arg26688343($z83338334,anf_arg977262,anf_fun975263,let_DASH_bind29398,name336250,none6979);
++R.GAS;
return $ret83378338;
};
var $Hanf_arg26688343 = function(anf_arg9798342,anf_arg977262,anf_fun975263,let_DASH_bind29398,name336250,none6979) {
var $z83468347 = D;
var $f83528353 = function(_) {
return R.isFunction(let_DASH_bind29398.$var)?let_DASH_bind29398.$var.app(anf_arg977262,anf_arg9798342,none6979):R.ffi.throwNonFunApp(L[1074],let_DASH_bind29398.$var,[anf_arg977262,anf_arg9798342,none6979]);
};
try {
if(--R.GAS > 0) {
$z83468347 = $f83528353();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83528353,
"from":L[1074]});
}
} catch($e83448345) {
if(R.isCont($e83448345)) {
var $ss83488349 = {"from":L[1074],
"go":function(anf_arg9808354) {
return $Hanf_arg26678355(anf_arg9808354,anf_fun975263,name336250);
}};
$e83448345.stack[R.EXN_STACKHEIGHT++] = $ss83488349;
}
if(R.isPyretException($e83448345)) {
$e83448345.pyretStack.push(L[1074]);
}
throw $e83448345;
}
var $ret83508351 = $Hanf_arg26678355($z83468347,anf_fun975263,name336250);
++R.GAS;
return $ret83508351;
};
var $Hanf_arg26678355 = function(anf_arg9808354,anf_fun975263,name336250) {
var $z83588359 = D;
var $f83648365 = function(_) {
return R.isFunction(anf_fun975263)?anf_fun975263.app(name336250,anf_arg9808354):R.ffi.throwNonFunApp(L[22],anf_fun975263,[name336250,anf_arg9808354]);
};
try {
if(--R.GAS > 0) {
$z83588359 = $f83648365();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83648365,
"from":L[22]});
}
} catch($e83568357) {
if(R.isCont($e83568357)) {
var $ss83608361 = {"from":L[22],
"go":function(ann_DASH_check_DASH_temp9748366) {
return $Hann_DASH_check_DASH_temp26668367(ann_DASH_check_DASH_temp9748366);
}};
$e83568357.stack[R.EXN_STACKHEIGHT++] = $ss83608361;
}
if(R.isPyretException($e83568357)) {
$e83568357.pyretStack.push(L[22]);
}
throw $e83568357;
}
var $ret83628363 = $Hann_DASH_check_DASH_temp26668367($z83588359);
++R.GAS;
return $ret83628363;
};
var $Hann_DASH_check_DASH_temp26668367 = function(ann_DASH_check_DASH_temp9748366) {
return ann_DASH_check_DASH_temp9748366;
};
var $Hanf_arg2665312 = function(anf_arg948310,self89311,_plus9,torepr16) {
var anf_arg9498378 = G(self89311,"atom",L[28]);
var $z83708371 = D;
var $f83768377 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg9498378):R.ffi.throwNonFunApp(L[28],torepr16,[anf_arg9498378]);
};
try {
if(--R.GAS > 0) {
$z83708371 = $f83768377();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83768377,
"from":L[28]});
}
} catch($e83688369) {
if(R.isCont($e83688369)) {
var $ss83728373 = {"from":L[28],
"go":function(anf_arg9508379) {
return $Hanf_arg26648380(anf_arg9508379,anf_arg948310,self89311,_plus9,torepr16);
}};
$e83688369.stack[R.EXN_STACKHEIGHT++] = $ss83728373;
}
if(R.isPyretException($e83688369)) {
$e83688369.pyretStack.push(L[28]);
}
throw $e83688369;
}
var $ret83748375 = $Hanf_arg26648380($z83708371,anf_arg948310,self89311,_plus9,torepr16);
++R.GAS;
return $ret83748375;
};
var $Hanf_arg26648380 = function(anf_arg9508379,anf_arg948310,self89311,_plus9,torepr16) {
var $z83838384 = D;
var $f83898390 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg9508379):R.ffi.throwNonFunApp(L[28],_plus9,[(", "),anf_arg9508379]);
};
try {
if(--R.GAS > 0) {
$z83838384 = $f83898390();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f83898390,
"from":L[28]});
}
} catch($e83818382) {
if(R.isCont($e83818382)) {
var $ss83858386 = {"from":L[28],
"go":function(anf_arg9518391) {
return $Hanf_arg26638392(anf_arg9518391,anf_arg948310,self89311,_plus9,torepr16);
}};
$e83818382.stack[R.EXN_STACKHEIGHT++] = $ss83858386;
}
if(R.isPyretException($e83818382)) {
$e83818382.pyretStack.push(L[28]);
}
throw $e83818382;
}
var $ret83878388 = $Hanf_arg26638392($z83838384,anf_arg948310,self89311,_plus9,torepr16);
++R.GAS;
return $ret83878388;
};
var $Hanf_arg26638392 = function(anf_arg9518391,anf_arg948310,self89311,_plus9,torepr16) {
var $z83958396 = D;
var $f84018402 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg948310,anf_arg9518391):R.ffi.throwNonFunApp(L[28],_plus9,[anf_arg948310,anf_arg9518391]);
};
try {
if(--R.GAS > 0) {
$z83958396 = $f84018402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84018402,
"from":L[28]});
}
} catch($e83938394) {
if(R.isCont($e83938394)) {
var $ss83978398 = {"from":L[28],
"go":function(anf_arg9528403) {
return $Hanf_arg26628404(anf_arg9528403,self89311,_plus9,torepr16);
}};
$e83938394.stack[R.EXN_STACKHEIGHT++] = $ss83978398;
}
if(R.isPyretException($e83938394)) {
$e83938394.pyretStack.push(L[28]);
}
throw $e83938394;
}
var $ret83998400 = $Hanf_arg26628404($z83958396,self89311,_plus9,torepr16);
++R.GAS;
return $ret83998400;
};
var $Hanf_arg26628404 = function(anf_arg9528403,self89311,_plus9,torepr16) {
var anf_arg9538415 = G(self89311,"ann",L[28]);
var $z84078408 = D;
var $f84138414 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg9538415):R.ffi.throwNonFunApp(L[28],torepr16,[anf_arg9538415]);
};
try {
if(--R.GAS > 0) {
$z84078408 = $f84138414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84138414,
"from":L[28]});
}
} catch($e84058406) {
if(R.isCont($e84058406)) {
var $ss84098410 = {"from":L[28],
"go":function(anf_arg9548416) {
return $Hanf_arg26618417(anf_arg9548416,anf_arg9528403,_plus9);
}};
$e84058406.stack[R.EXN_STACKHEIGHT++] = $ss84098410;
}
if(R.isPyretException($e84058406)) {
$e84058406.pyretStack.push(L[28]);
}
throw $e84058406;
}
var $ret84118412 = $Hanf_arg26618417($z84078408,anf_arg9528403,_plus9);
++R.GAS;
return $ret84118412;
};
var $Hanf_arg26618417 = function(anf_arg9548416,anf_arg9528403,_plus9) {
var $z84208421 = D;
var $f84268427 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg9548416):R.ffi.throwNonFunApp(L[28],_plus9,[(", "),anf_arg9548416]);
};
try {
if(--R.GAS > 0) {
$z84208421 = $f84268427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84268427,
"from":L[28]});
}
} catch($e84188419) {
if(R.isCont($e84188419)) {
var $ss84228423 = {"from":L[28],
"go":function(anf_arg9558428) {
return $Hanf_arg26608429(anf_arg9558428,anf_arg9528403,_plus9);
}};
$e84188419.stack[R.EXN_STACKHEIGHT++] = $ss84228423;
}
if(R.isPyretException($e84188419)) {
$e84188419.pyretStack.push(L[28]);
}
throw $e84188419;
}
var $ret84248425 = $Hanf_arg26608429($z84208421,anf_arg9528403,_plus9);
++R.GAS;
return $ret84248425;
};
var $Hanf_arg26608429 = function(anf_arg9558428,anf_arg9528403,_plus9) {
var $z84328433 = D;
var $f84388439 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg9528403,anf_arg9558428):R.ffi.throwNonFunApp(L[28],_plus9,[anf_arg9528403,anf_arg9558428]);
};
try {
if(--R.GAS > 0) {
$z84328433 = $f84388439();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84388439,
"from":L[28]});
}
} catch($e84308431) {
if(R.isCont($e84308431)) {
var $ss84348435 = {"from":L[28],
"go":function(anf_arg9568440) {
return $Hanf_arg26598441(anf_arg9568440,_plus9);
}};
$e84308431.stack[R.EXN_STACKHEIGHT++] = $ss84348435;
}
if(R.isPyretException($e84308431)) {
$e84308431.pyretStack.push(L[28]);
}
throw $e84308431;
}
var $ret84368437 = $Hanf_arg26598441($z84328433,_plus9);
++R.GAS;
return $ret84368437;
};
var $Hanf_arg26598441 = function(anf_arg9568440,_plus9) {
var $z84448445 = D;
var $f84508451 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg9568440,(")")):R.ffi.throwNonFunApp(L[28],_plus9,[anf_arg9568440,(")")]);
};
try {
if(--R.GAS > 0) {
$z84448445 = $f84508451();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84508451,
"from":L[28]});
}
} catch($e84428443) {
if(R.isCont($e84428443)) {
var $ss84468447 = {"from":L[28],
"go":function(anf_arg9578452) {
return $Hanf_arg26588453(anf_arg9578452,_plus9);
}};
$e84428443.stack[R.EXN_STACKHEIGHT++] = $ss84468447;
}
if(R.isPyretException($e84428443)) {
$e84428443.pyretStack.push(L[28]);
}
throw $e84428443;
}
var $ret84488449 = $Hanf_arg26588453($z84448445,_plus9);
++R.GAS;
return $ret84488449;
};
var $Hanf_arg26588453 = function(anf_arg9578452,_plus9) {
var $z84568457 = D;
var $f84628463 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg9578452):R.ffi.throwNonFunApp(L[28],_plus9,[("("),anf_arg9578452]);
};
try {
if(--R.GAS > 0) {
$z84568457 = $f84628463();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84628463,
"from":L[28]});
}
} catch($e84548455) {
if(R.isCont($e84548455)) {
var $ss84588459 = {"from":L[28],
"go":function(anf_arg9588464) {
return $Hanf_arg26578465(anf_arg9588464,_plus9);
}};
$e84548455.stack[R.EXN_STACKHEIGHT++] = $ss84588459;
}
if(R.isPyretException($e84548455)) {
$e84548455.pyretStack.push(L[28]);
}
throw $e84548455;
}
var $ret84608461 = $Hanf_arg26578465($z84568457,_plus9);
++R.GAS;
return $ret84608461;
};
var $Hanf_arg26578465 = function(anf_arg9588464,_plus9) {
var $z84688469 = D;
var $f84748475 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("type-var-bind"),anf_arg9588464):R.ffi.throwNonFunApp(L[28],_plus9,[("type-var-bind"),anf_arg9588464]);
};
try {
if(--R.GAS > 0) {
$z84688469 = $f84748475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84748475,
"from":L[28]});
}
} catch($e84668467) {
if(R.isCont($e84668467)) {
var $ss84708471 = {"from":L[28],
"go":function(ann_DASH_check_DASH_temp9468476) {
return $Hann_DASH_check_DASH_temp26568477(ann_DASH_check_DASH_temp9468476);
}};
$e84668467.stack[R.EXN_STACKHEIGHT++] = $ss84708471;
}
if(R.isPyretException($e84668467)) {
$e84668467.pyretStack.push(L[28]);
}
throw $e84668467;
}
var $ret84728473 = $Hann_DASH_check_DASH_temp26568477($z84688469);
++R.GAS;
return $ret84728473;
};
var $Hann_DASH_check_DASH_temp26568477 = function(ann_DASH_check_DASH_temp9468476) {
return ann_DASH_check_DASH_temp9468476;
};
var $Hcont_tail_arg2654329 = function(cont_tail_arg943327,if_helper933328) {
if(--R.GAS > 0) {
$z84788479 = R.isFunction(if_helper933328)?if_helper933328.app(cont_tail_arg943327):R.ffi.throwNonFunApp(L[28],if_helper933328,[cont_tail_arg943327]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper933328)?if_helper933328.app(cont_tail_arg943327):R.ffi.throwNonFunApp(L[28],if_helper933328,[cont_tail_arg943327]);
},
"from":L[28]});
}
++R.GAS;
return $z84788479;
};
var $Hcont_tail_arg2655344 = function(cont_tail_arg938343,if_helper933328) {
if(--R.GAS > 0) {
$z84808481 = R.isFunction(if_helper933328)?if_helper933328.app(cont_tail_arg938343):R.ffi.throwNonFunApp(L[28],if_helper933328,[cont_tail_arg938343]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper933328)?if_helper933328.app(cont_tail_arg938343):R.ffi.throwNonFunApp(L[28],if_helper933328,[cont_tail_arg938343]);
},
"from":L[28]});
}
++R.GAS;
return $z84808481;
};
var $Hanf_arg2653366 = function(anf_arg920364,self83365,_plus9,torepr16) {
var anf_arg9218492 = G(self83365,"atom",L[29]);
var $z84848485 = D;
var $f84908491 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg9218492):R.ffi.throwNonFunApp(L[29],torepr16,[anf_arg9218492]);
};
try {
if(--R.GAS > 0) {
$z84848485 = $f84908491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f84908491,
"from":L[29]});
}
} catch($e84828483) {
if(R.isCont($e84828483)) {
var $ss84868487 = {"from":L[29],
"go":function(anf_arg9228493) {
return $Hanf_arg26528494(anf_arg9228493,anf_arg920364,self83365,_plus9,torepr16);
}};
$e84828483.stack[R.EXN_STACKHEIGHT++] = $ss84868487;
}
if(R.isPyretException($e84828483)) {
$e84828483.pyretStack.push(L[29]);
}
throw $e84828483;
}
var $ret84888489 = $Hanf_arg26528494($z84848485,anf_arg920364,self83365,_plus9,torepr16);
++R.GAS;
return $ret84888489;
};
var $Hanf_arg26528494 = function(anf_arg9228493,anf_arg920364,self83365,_plus9,torepr16) {
var $z84978498 = D;
var $f85038504 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg9228493):R.ffi.throwNonFunApp(L[29],_plus9,[(", "),anf_arg9228493]);
};
try {
if(--R.GAS > 0) {
$z84978498 = $f85038504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85038504,
"from":L[29]});
}
} catch($e84958496) {
if(R.isCont($e84958496)) {
var $ss84998500 = {"from":L[29],
"go":function(anf_arg9238505) {
return $Hanf_arg26518506(anf_arg9238505,anf_arg920364,self83365,_plus9,torepr16);
}};
$e84958496.stack[R.EXN_STACKHEIGHT++] = $ss84998500;
}
if(R.isPyretException($e84958496)) {
$e84958496.pyretStack.push(L[29]);
}
throw $e84958496;
}
var $ret85018502 = $Hanf_arg26518506($z84978498,anf_arg920364,self83365,_plus9,torepr16);
++R.GAS;
return $ret85018502;
};
var $Hanf_arg26518506 = function(anf_arg9238505,anf_arg920364,self83365,_plus9,torepr16) {
var $z85098510 = D;
var $f85158516 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg920364,anf_arg9238505):R.ffi.throwNonFunApp(L[29],_plus9,[anf_arg920364,anf_arg9238505]);
};
try {
if(--R.GAS > 0) {
$z85098510 = $f85158516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85158516,
"from":L[29]});
}
} catch($e85078508) {
if(R.isCont($e85078508)) {
var $ss85118512 = {"from":L[29],
"go":function(anf_arg9248517) {
return $Hanf_arg26508518(anf_arg9248517,self83365,_plus9,torepr16);
}};
$e85078508.stack[R.EXN_STACKHEIGHT++] = $ss85118512;
}
if(R.isPyretException($e85078508)) {
$e85078508.pyretStack.push(L[29]);
}
throw $e85078508;
}
var $ret85138514 = $Hanf_arg26508518($z85098510,self83365,_plus9,torepr16);
++R.GAS;
return $ret85138514;
};
var $Hanf_arg26508518 = function(anf_arg9248517,self83365,_plus9,torepr16) {
var anf_arg9258529 = G(self83365,"ann",L[29]);
var $z85218522 = D;
var $f85278528 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg9258529):R.ffi.throwNonFunApp(L[29],torepr16,[anf_arg9258529]);
};
try {
if(--R.GAS > 0) {
$z85218522 = $f85278528();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85278528,
"from":L[29]});
}
} catch($e85198520) {
if(R.isCont($e85198520)) {
var $ss85238524 = {"from":L[29],
"go":function(anf_arg9268530) {
return $Hanf_arg26498531(anf_arg9268530,anf_arg9248517,_plus9);
}};
$e85198520.stack[R.EXN_STACKHEIGHT++] = $ss85238524;
}
if(R.isPyretException($e85198520)) {
$e85198520.pyretStack.push(L[29]);
}
throw $e85198520;
}
var $ret85258526 = $Hanf_arg26498531($z85218522,anf_arg9248517,_plus9);
++R.GAS;
return $ret85258526;
};
var $Hanf_arg26498531 = function(anf_arg9268530,anf_arg9248517,_plus9) {
var $z85348535 = D;
var $f85408541 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg9268530):R.ffi.throwNonFunApp(L[29],_plus9,[(", "),anf_arg9268530]);
};
try {
if(--R.GAS > 0) {
$z85348535 = $f85408541();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85408541,
"from":L[29]});
}
} catch($e85328533) {
if(R.isCont($e85328533)) {
var $ss85368537 = {"from":L[29],
"go":function(anf_arg9278542) {
return $Hanf_arg26488543(anf_arg9278542,anf_arg9248517,_plus9);
}};
$e85328533.stack[R.EXN_STACKHEIGHT++] = $ss85368537;
}
if(R.isPyretException($e85328533)) {
$e85328533.pyretStack.push(L[29]);
}
throw $e85328533;
}
var $ret85388539 = $Hanf_arg26488543($z85348535,anf_arg9248517,_plus9);
++R.GAS;
return $ret85388539;
};
var $Hanf_arg26488543 = function(anf_arg9278542,anf_arg9248517,_plus9) {
var $z85468547 = D;
var $f85528553 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg9248517,anf_arg9278542):R.ffi.throwNonFunApp(L[29],_plus9,[anf_arg9248517,anf_arg9278542]);
};
try {
if(--R.GAS > 0) {
$z85468547 = $f85528553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85528553,
"from":L[29]});
}
} catch($e85448545) {
if(R.isCont($e85448545)) {
var $ss85488549 = {"from":L[29],
"go":function(anf_arg9288554) {
return $Hanf_arg26478555(anf_arg9288554,_plus9);
}};
$e85448545.stack[R.EXN_STACKHEIGHT++] = $ss85488549;
}
if(R.isPyretException($e85448545)) {
$e85448545.pyretStack.push(L[29]);
}
throw $e85448545;
}
var $ret85508551 = $Hanf_arg26478555($z85468547,_plus9);
++R.GAS;
return $ret85508551;
};
var $Hanf_arg26478555 = function(anf_arg9288554,_plus9) {
var $z85588559 = D;
var $f85648565 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg9288554,(")")):R.ffi.throwNonFunApp(L[29],_plus9,[anf_arg9288554,(")")]);
};
try {
if(--R.GAS > 0) {
$z85588559 = $f85648565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85648565,
"from":L[29]});
}
} catch($e85568557) {
if(R.isCont($e85568557)) {
var $ss85608561 = {"from":L[29],
"go":function(anf_arg9298566) {
return $Hanf_arg26468567(anf_arg9298566,_plus9);
}};
$e85568557.stack[R.EXN_STACKHEIGHT++] = $ss85608561;
}
if(R.isPyretException($e85568557)) {
$e85568557.pyretStack.push(L[29]);
}
throw $e85568557;
}
var $ret85628563 = $Hanf_arg26468567($z85588559,_plus9);
++R.GAS;
return $ret85628563;
};
var $Hanf_arg26468567 = function(anf_arg9298566,_plus9) {
var $z85708571 = D;
var $f85768577 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg9298566):R.ffi.throwNonFunApp(L[29],_plus9,[("("),anf_arg9298566]);
};
try {
if(--R.GAS > 0) {
$z85708571 = $f85768577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85768577,
"from":L[29]});
}
} catch($e85688569) {
if(R.isCont($e85688569)) {
var $ss85728573 = {"from":L[29],
"go":function(anf_arg9308578) {
return $Hanf_arg26458579(anf_arg9308578,_plus9);
}};
$e85688569.stack[R.EXN_STACKHEIGHT++] = $ss85728573;
}
if(R.isPyretException($e85688569)) {
$e85688569.pyretStack.push(L[29]);
}
throw $e85688569;
}
var $ret85748575 = $Hanf_arg26458579($z85708571,_plus9);
++R.GAS;
return $ret85748575;
};
var $Hanf_arg26458579 = function(anf_arg9308578,_plus9) {
var $z85828583 = D;
var $f85888589 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("let-type-bind"),anf_arg9308578):R.ffi.throwNonFunApp(L[29],_plus9,[("let-type-bind"),anf_arg9308578]);
};
try {
if(--R.GAS > 0) {
$z85828583 = $f85888589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f85888589,
"from":L[29]});
}
} catch($e85808581) {
if(R.isCont($e85808581)) {
var $ss85848585 = {"from":L[29],
"go":function(ann_DASH_check_DASH_temp9188590) {
return $Hann_DASH_check_DASH_temp26448591(ann_DASH_check_DASH_temp9188590);
}};
$e85808581.stack[R.EXN_STACKHEIGHT++] = $ss85848585;
}
if(R.isPyretException($e85808581)) {
$e85808581.pyretStack.push(L[29]);
}
throw $e85808581;
}
var $ret85868587 = $Hann_DASH_check_DASH_temp26448591($z85828583);
++R.GAS;
return $ret85868587;
};
var $Hann_DASH_check_DASH_temp26448591 = function(ann_DASH_check_DASH_temp9188590) {
return ann_DASH_check_DASH_temp9188590;
};
var $Hcont_tail_arg2642383 = function(cont_tail_arg915381,if_helper905382) {
if(--R.GAS > 0) {
$z85928593 = R.isFunction(if_helper905382)?if_helper905382.app(cont_tail_arg915381):R.ffi.throwNonFunApp(L[29],if_helper905382,[cont_tail_arg915381]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper905382)?if_helper905382.app(cont_tail_arg915381):R.ffi.throwNonFunApp(L[29],if_helper905382,[cont_tail_arg915381]);
},
"from":L[29]});
}
++R.GAS;
return $z85928593;
};
var $Hcont_tail_arg2643398 = function(cont_tail_arg910397,if_helper905382) {
if(--R.GAS > 0) {
$z85948595 = R.isFunction(if_helper905382)?if_helper905382.app(cont_tail_arg910397):R.ffi.throwNonFunApp(L[29],if_helper905382,[cont_tail_arg910397]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper905382)?if_helper905382.app(cont_tail_arg910397):R.ffi.throwNonFunApp(L[29],if_helper905382,[cont_tail_arg910397]);
},
"from":L[29]});
}
++R.GAS;
return $z85948595;
};
var $Hanf_arg2641419 = function(anf_arg892417,self77418,_plus9,torepr16) {
var anf_arg8938606 = G(self77418,"atom",L[30]);
var $z85988599 = D;
var $f86048605 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg8938606):R.ffi.throwNonFunApp(L[30],torepr16,[anf_arg8938606]);
};
try {
if(--R.GAS > 0) {
$z85988599 = $f86048605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86048605,
"from":L[30]});
}
} catch($e85968597) {
if(R.isCont($e85968597)) {
var $ss86008601 = {"from":L[30],
"go":function(anf_arg8948607) {
return $Hanf_arg26408608(anf_arg8948607,anf_arg892417,self77418,_plus9,torepr16);
}};
$e85968597.stack[R.EXN_STACKHEIGHT++] = $ss86008601;
}
if(R.isPyretException($e85968597)) {
$e85968597.pyretStack.push(L[30]);
}
throw $e85968597;
}
var $ret86028603 = $Hanf_arg26408608($z85988599,anf_arg892417,self77418,_plus9,torepr16);
++R.GAS;
return $ret86028603;
};
var $Hanf_arg26408608 = function(anf_arg8948607,anf_arg892417,self77418,_plus9,torepr16) {
var $z86118612 = D;
var $f86178618 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg8948607):R.ffi.throwNonFunApp(L[30],_plus9,[(", "),anf_arg8948607]);
};
try {
if(--R.GAS > 0) {
$z86118612 = $f86178618();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86178618,
"from":L[30]});
}
} catch($e86098610) {
if(R.isCont($e86098610)) {
var $ss86138614 = {"from":L[30],
"go":function(anf_arg8958619) {
return $Hanf_arg26398620(anf_arg8958619,anf_arg892417,self77418,_plus9,torepr16);
}};
$e86098610.stack[R.EXN_STACKHEIGHT++] = $ss86138614;
}
if(R.isPyretException($e86098610)) {
$e86098610.pyretStack.push(L[30]);
}
throw $e86098610;
}
var $ret86158616 = $Hanf_arg26398620($z86118612,anf_arg892417,self77418,_plus9,torepr16);
++R.GAS;
return $ret86158616;
};
var $Hanf_arg26398620 = function(anf_arg8958619,anf_arg892417,self77418,_plus9,torepr16) {
var $z86238624 = D;
var $f86298630 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg892417,anf_arg8958619):R.ffi.throwNonFunApp(L[30],_plus9,[anf_arg892417,anf_arg8958619]);
};
try {
if(--R.GAS > 0) {
$z86238624 = $f86298630();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86298630,
"from":L[30]});
}
} catch($e86218622) {
if(R.isCont($e86218622)) {
var $ss86258626 = {"from":L[30],
"go":function(anf_arg8968631) {
return $Hanf_arg26388632(anf_arg8968631,self77418,_plus9,torepr16);
}};
$e86218622.stack[R.EXN_STACKHEIGHT++] = $ss86258626;
}
if(R.isPyretException($e86218622)) {
$e86218622.pyretStack.push(L[30]);
}
throw $e86218622;
}
var $ret86278628 = $Hanf_arg26388632($z86238624,self77418,_plus9,torepr16);
++R.GAS;
return $ret86278628;
};
var $Hanf_arg26388632 = function(anf_arg8968631,self77418,_plus9,torepr16) {
var anf_arg8978643 = G(self77418,"ann",L[30]);
var $z86358636 = D;
var $f86418642 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg8978643):R.ffi.throwNonFunApp(L[30],torepr16,[anf_arg8978643]);
};
try {
if(--R.GAS > 0) {
$z86358636 = $f86418642();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86418642,
"from":L[30]});
}
} catch($e86338634) {
if(R.isCont($e86338634)) {
var $ss86378638 = {"from":L[30],
"go":function(anf_arg8988644) {
return $Hanf_arg26378645(anf_arg8988644,anf_arg8968631,_plus9);
}};
$e86338634.stack[R.EXN_STACKHEIGHT++] = $ss86378638;
}
if(R.isPyretException($e86338634)) {
$e86338634.pyretStack.push(L[30]);
}
throw $e86338634;
}
var $ret86398640 = $Hanf_arg26378645($z86358636,anf_arg8968631,_plus9);
++R.GAS;
return $ret86398640;
};
var $Hanf_arg26378645 = function(anf_arg8988644,anf_arg8968631,_plus9) {
var $z86488649 = D;
var $f86548655 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg8988644):R.ffi.throwNonFunApp(L[30],_plus9,[(", "),anf_arg8988644]);
};
try {
if(--R.GAS > 0) {
$z86488649 = $f86548655();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86548655,
"from":L[30]});
}
} catch($e86468647) {
if(R.isCont($e86468647)) {
var $ss86508651 = {"from":L[30],
"go":function(anf_arg8998656) {
return $Hanf_arg26368657(anf_arg8998656,anf_arg8968631,_plus9);
}};
$e86468647.stack[R.EXN_STACKHEIGHT++] = $ss86508651;
}
if(R.isPyretException($e86468647)) {
$e86468647.pyretStack.push(L[30]);
}
throw $e86468647;
}
var $ret86528653 = $Hanf_arg26368657($z86488649,anf_arg8968631,_plus9);
++R.GAS;
return $ret86528653;
};
var $Hanf_arg26368657 = function(anf_arg8998656,anf_arg8968631,_plus9) {
var $z86608661 = D;
var $f86668667 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg8968631,anf_arg8998656):R.ffi.throwNonFunApp(L[30],_plus9,[anf_arg8968631,anf_arg8998656]);
};
try {
if(--R.GAS > 0) {
$z86608661 = $f86668667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86668667,
"from":L[30]});
}
} catch($e86588659) {
if(R.isCont($e86588659)) {
var $ss86628663 = {"from":L[30],
"go":function(anf_arg9008668) {
return $Hanf_arg26358669(anf_arg9008668,_plus9);
}};
$e86588659.stack[R.EXN_STACKHEIGHT++] = $ss86628663;
}
if(R.isPyretException($e86588659)) {
$e86588659.pyretStack.push(L[30]);
}
throw $e86588659;
}
var $ret86648665 = $Hanf_arg26358669($z86608661,_plus9);
++R.GAS;
return $ret86648665;
};
var $Hanf_arg26358669 = function(anf_arg9008668,_plus9) {
var $z86728673 = D;
var $f86788679 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg9008668,(")")):R.ffi.throwNonFunApp(L[30],_plus9,[anf_arg9008668,(")")]);
};
try {
if(--R.GAS > 0) {
$z86728673 = $f86788679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86788679,
"from":L[30]});
}
} catch($e86708671) {
if(R.isCont($e86708671)) {
var $ss86748675 = {"from":L[30],
"go":function(anf_arg9018680) {
return $Hanf_arg26348681(anf_arg9018680,_plus9);
}};
$e86708671.stack[R.EXN_STACKHEIGHT++] = $ss86748675;
}
if(R.isPyretException($e86708671)) {
$e86708671.pyretStack.push(L[30]);
}
throw $e86708671;
}
var $ret86768677 = $Hanf_arg26348681($z86728673,_plus9);
++R.GAS;
return $ret86768677;
};
var $Hanf_arg26348681 = function(anf_arg9018680,_plus9) {
var $z86848685 = D;
var $f86908691 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg9018680):R.ffi.throwNonFunApp(L[30],_plus9,[("("),anf_arg9018680]);
};
try {
if(--R.GAS > 0) {
$z86848685 = $f86908691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f86908691,
"from":L[30]});
}
} catch($e86828683) {
if(R.isCont($e86828683)) {
var $ss86868687 = {"from":L[30],
"go":function(anf_arg9028692) {
return $Hanf_arg26338693(anf_arg9028692,_plus9);
}};
$e86828683.stack[R.EXN_STACKHEIGHT++] = $ss86868687;
}
if(R.isPyretException($e86828683)) {
$e86828683.pyretStack.push(L[30]);
}
throw $e86828683;
}
var $ret86888689 = $Hanf_arg26338693($z86848685,_plus9);
++R.GAS;
return $ret86888689;
};
var $Hanf_arg26338693 = function(anf_arg9028692,_plus9) {
var $z86968697 = D;
var $f87028703 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("global-type-bind"),anf_arg9028692):R.ffi.throwNonFunApp(L[30],_plus9,[("global-type-bind"),anf_arg9028692]);
};
try {
if(--R.GAS > 0) {
$z86968697 = $f87028703();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87028703,
"from":L[30]});
}
} catch($e86948695) {
if(R.isCont($e86948695)) {
var $ss86988699 = {"from":L[30],
"go":function(ann_DASH_check_DASH_temp8908704) {
return $Hann_DASH_check_DASH_temp26328705(ann_DASH_check_DASH_temp8908704);
}};
$e86948695.stack[R.EXN_STACKHEIGHT++] = $ss86988699;
}
if(R.isPyretException($e86948695)) {
$e86948695.pyretStack.push(L[30]);
}
throw $e86948695;
}
var $ret87008701 = $Hann_DASH_check_DASH_temp26328705($z86968697);
++R.GAS;
return $ret87008701;
};
var $Hann_DASH_check_DASH_temp26328705 = function(ann_DASH_check_DASH_temp8908704) {
return ann_DASH_check_DASH_temp8908704;
};
var $Hcont_tail_arg2630436 = function(cont_tail_arg887434,if_helper877435) {
if(--R.GAS > 0) {
$z87068707 = R.isFunction(if_helper877435)?if_helper877435.app(cont_tail_arg887434):R.ffi.throwNonFunApp(L[30],if_helper877435,[cont_tail_arg887434]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper877435)?if_helper877435.app(cont_tail_arg887434):R.ffi.throwNonFunApp(L[30],if_helper877435,[cont_tail_arg887434]);
},
"from":L[30]});
}
++R.GAS;
return $z87068707;
};
var $Hcont_tail_arg2631451 = function(cont_tail_arg882450,if_helper877435) {
if(--R.GAS > 0) {
$z87088709 = R.isFunction(if_helper877435)?if_helper877435.app(cont_tail_arg882450):R.ffi.throwNonFunApp(L[30],if_helper877435,[cont_tail_arg882450]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper877435)?if_helper877435.app(cont_tail_arg882450):R.ffi.throwNonFunApp(L[30],if_helper877435,[cont_tail_arg882450]);
},
"from":L[30]});
}
++R.GAS;
return $z87088709;
};
var $Hanf_arg2629512 = function(anf_arg853510,self71511,_plus9,torepr16) {
var anf_arg8548720 = G(self71511,"atom",L[50]);
var $z87128713 = D;
var $f87188719 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg8548720):R.ffi.throwNonFunApp(L[50],torepr16,[anf_arg8548720]);
};
try {
if(--R.GAS > 0) {
$z87128713 = $f87188719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87188719,
"from":L[50]});
}
} catch($e87108711) {
if(R.isCont($e87108711)) {
var $ss87148715 = {"from":L[50],
"go":function(anf_arg8558721) {
return $Hanf_arg26288722(anf_arg8558721,anf_arg853510,self71511,_plus9,torepr16);
}};
$e87108711.stack[R.EXN_STACKHEIGHT++] = $ss87148715;
}
if(R.isPyretException($e87108711)) {
$e87108711.pyretStack.push(L[50]);
}
throw $e87108711;
}
var $ret87168717 = $Hanf_arg26288722($z87128713,anf_arg853510,self71511,_plus9,torepr16);
++R.GAS;
return $ret87168717;
};
var $Hanf_arg26288722 = function(anf_arg8558721,anf_arg853510,self71511,_plus9,torepr16) {
var $z87258726 = D;
var $f87318732 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg8558721):R.ffi.throwNonFunApp(L[50],_plus9,[(", "),anf_arg8558721]);
};
try {
if(--R.GAS > 0) {
$z87258726 = $f87318732();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87318732,
"from":L[50]});
}
} catch($e87238724) {
if(R.isCont($e87238724)) {
var $ss87278728 = {"from":L[50],
"go":function(anf_arg8568733) {
return $Hanf_arg26278734(anf_arg8568733,anf_arg853510,self71511,_plus9,torepr16);
}};
$e87238724.stack[R.EXN_STACKHEIGHT++] = $ss87278728;
}
if(R.isPyretException($e87238724)) {
$e87238724.pyretStack.push(L[50]);
}
throw $e87238724;
}
var $ret87298730 = $Hanf_arg26278734($z87258726,anf_arg853510,self71511,_plus9,torepr16);
++R.GAS;
return $ret87298730;
};
var $Hanf_arg26278734 = function(anf_arg8568733,anf_arg853510,self71511,_plus9,torepr16) {
var $z87378738 = D;
var $f87438744 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg853510,anf_arg8568733):R.ffi.throwNonFunApp(L[50],_plus9,[anf_arg853510,anf_arg8568733]);
};
try {
if(--R.GAS > 0) {
$z87378738 = $f87438744();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87438744,
"from":L[50]});
}
} catch($e87358736) {
if(R.isCont($e87358736)) {
var $ss87398740 = {"from":L[50],
"go":function(anf_arg8578745) {
return $Hanf_arg26268746(anf_arg8578745,self71511,_plus9,torepr16);
}};
$e87358736.stack[R.EXN_STACKHEIGHT++] = $ss87398740;
}
if(R.isPyretException($e87358736)) {
$e87358736.pyretStack.push(L[50]);
}
throw $e87358736;
}
var $ret87418742 = $Hanf_arg26268746($z87378738,self71511,_plus9,torepr16);
++R.GAS;
return $ret87418742;
};
var $Hanf_arg26268746 = function(anf_arg8578745,self71511,_plus9,torepr16) {
var anf_arg8588757 = G(self71511,"expr",L[50]);
var $z87498750 = D;
var $f87558756 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg8588757):R.ffi.throwNonFunApp(L[50],torepr16,[anf_arg8588757]);
};
try {
if(--R.GAS > 0) {
$z87498750 = $f87558756();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87558756,
"from":L[50]});
}
} catch($e87478748) {
if(R.isCont($e87478748)) {
var $ss87518752 = {"from":L[50],
"go":function(anf_arg8598758) {
return $Hanf_arg26258759(anf_arg8598758,anf_arg8578745,_plus9);
}};
$e87478748.stack[R.EXN_STACKHEIGHT++] = $ss87518752;
}
if(R.isPyretException($e87478748)) {
$e87478748.pyretStack.push(L[50]);
}
throw $e87478748;
}
var $ret87538754 = $Hanf_arg26258759($z87498750,anf_arg8578745,_plus9);
++R.GAS;
return $ret87538754;
};
var $Hanf_arg26258759 = function(anf_arg8598758,anf_arg8578745,_plus9) {
var $z87628763 = D;
var $f87688769 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg8598758):R.ffi.throwNonFunApp(L[50],_plus9,[(", "),anf_arg8598758]);
};
try {
if(--R.GAS > 0) {
$z87628763 = $f87688769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87688769,
"from":L[50]});
}
} catch($e87608761) {
if(R.isCont($e87608761)) {
var $ss87648765 = {"from":L[50],
"go":function(anf_arg8608770) {
return $Hanf_arg26248771(anf_arg8608770,anf_arg8578745,_plus9);
}};
$e87608761.stack[R.EXN_STACKHEIGHT++] = $ss87648765;
}
if(R.isPyretException($e87608761)) {
$e87608761.pyretStack.push(L[50]);
}
throw $e87608761;
}
var $ret87668767 = $Hanf_arg26248771($z87628763,anf_arg8578745,_plus9);
++R.GAS;
return $ret87668767;
};
var $Hanf_arg26248771 = function(anf_arg8608770,anf_arg8578745,_plus9) {
var $z87748775 = D;
var $f87808781 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg8578745,anf_arg8608770):R.ffi.throwNonFunApp(L[50],_plus9,[anf_arg8578745,anf_arg8608770]);
};
try {
if(--R.GAS > 0) {
$z87748775 = $f87808781();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87808781,
"from":L[50]});
}
} catch($e87728773) {
if(R.isCont($e87728773)) {
var $ss87768777 = {"from":L[50],
"go":function(anf_arg8618782) {
return $Hanf_arg26238783(anf_arg8618782,_plus9);
}};
$e87728773.stack[R.EXN_STACKHEIGHT++] = $ss87768777;
}
if(R.isPyretException($e87728773)) {
$e87728773.pyretStack.push(L[50]);
}
throw $e87728773;
}
var $ret87788779 = $Hanf_arg26238783($z87748775,_plus9);
++R.GAS;
return $ret87788779;
};
var $Hanf_arg26238783 = function(anf_arg8618782,_plus9) {
var $z87868787 = D;
var $f87928793 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg8618782,(")")):R.ffi.throwNonFunApp(L[50],_plus9,[anf_arg8618782,(")")]);
};
try {
if(--R.GAS > 0) {
$z87868787 = $f87928793();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f87928793,
"from":L[50]});
}
} catch($e87848785) {
if(R.isCont($e87848785)) {
var $ss87888789 = {"from":L[50],
"go":function(anf_arg8628794) {
return $Hanf_arg26228795(anf_arg8628794,_plus9);
}};
$e87848785.stack[R.EXN_STACKHEIGHT++] = $ss87888789;
}
if(R.isPyretException($e87848785)) {
$e87848785.pyretStack.push(L[50]);
}
throw $e87848785;
}
var $ret87908791 = $Hanf_arg26228795($z87868787,_plus9);
++R.GAS;
return $ret87908791;
};
var $Hanf_arg26228795 = function(anf_arg8628794,_plus9) {
var $z87988799 = D;
var $f88048805 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg8628794):R.ffi.throwNonFunApp(L[50],_plus9,[("("),anf_arg8628794]);
};
try {
if(--R.GAS > 0) {
$z87988799 = $f88048805();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88048805,
"from":L[50]});
}
} catch($e87968797) {
if(R.isCont($e87968797)) {
var $ss88008801 = {"from":L[50],
"go":function(anf_arg8638806) {
return $Hanf_arg26218807(anf_arg8638806,_plus9);
}};
$e87968797.stack[R.EXN_STACKHEIGHT++] = $ss88008801;
}
if(R.isPyretException($e87968797)) {
$e87968797.pyretStack.push(L[50]);
}
throw $e87968797;
}
var $ret88028803 = $Hanf_arg26218807($z87988799,_plus9);
++R.GAS;
return $ret88028803;
};
var $Hanf_arg26218807 = function(anf_arg8638806,_plus9) {
var $z88108811 = D;
var $f88168817 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("global-bind"),anf_arg8638806):R.ffi.throwNonFunApp(L[50],_plus9,[("global-bind"),anf_arg8638806]);
};
try {
if(--R.GAS > 0) {
$z88108811 = $f88168817();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88168817,
"from":L[50]});
}
} catch($e88088809) {
if(R.isCont($e88088809)) {
var $ss88128813 = {"from":L[50],
"go":function(ann_DASH_check_DASH_temp8518818) {
return $Hann_DASH_check_DASH_temp26208819(ann_DASH_check_DASH_temp8518818);
}};
$e88088809.stack[R.EXN_STACKHEIGHT++] = $ss88128813;
}
if(R.isPyretException($e88088809)) {
$e88088809.pyretStack.push(L[50]);
}
throw $e88088809;
}
var $ret88148815 = $Hann_DASH_check_DASH_temp26208819($z88108811);
++R.GAS;
return $ret88148815;
};
var $Hann_DASH_check_DASH_temp26208819 = function(ann_DASH_check_DASH_temp8518818) {
return ann_DASH_check_DASH_temp8518818;
};
var $Hcont_tail_arg2618529 = function(cont_tail_arg848527,if_helper838528) {
if(--R.GAS > 0) {
$z88208821 = R.isFunction(if_helper838528)?if_helper838528.app(cont_tail_arg848527):R.ffi.throwNonFunApp(L[50],if_helper838528,[cont_tail_arg848527]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper838528)?if_helper838528.app(cont_tail_arg848527):R.ffi.throwNonFunApp(L[50],if_helper838528,[cont_tail_arg848527]);
},
"from":L[50]});
}
++R.GAS;
return $z88208821;
};
var $Hcont_tail_arg2619544 = function(cont_tail_arg843543,if_helper838528) {
if(--R.GAS > 0) {
$z88228823 = R.isFunction(if_helper838528)?if_helper838528.app(cont_tail_arg843543):R.ffi.throwNonFunApp(L[50],if_helper838528,[cont_tail_arg843543]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper838528)?if_helper838528.app(cont_tail_arg843543):R.ffi.throwNonFunApp(L[50],if_helper838528,[cont_tail_arg843543]);
},
"from":L[50]});
}
++R.GAS;
return $z88228823;
};
var $Hanf_arg2617565 = function(anf_arg825563,self65564,_plus9,torepr16) {
var anf_arg8268834 = G(self65564,"atom",L[51]);
var $z88268827 = D;
var $f88328833 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg8268834):R.ffi.throwNonFunApp(L[51],torepr16,[anf_arg8268834]);
};
try {
if(--R.GAS > 0) {
$z88268827 = $f88328833();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88328833,
"from":L[51]});
}
} catch($e88248825) {
if(R.isCont($e88248825)) {
var $ss88288829 = {"from":L[51],
"go":function(anf_arg8278835) {
return $Hanf_arg26168836(anf_arg8278835,anf_arg825563,self65564,_plus9,torepr16);
}};
$e88248825.stack[R.EXN_STACKHEIGHT++] = $ss88288829;
}
if(R.isPyretException($e88248825)) {
$e88248825.pyretStack.push(L[51]);
}
throw $e88248825;
}
var $ret88308831 = $Hanf_arg26168836($z88268827,anf_arg825563,self65564,_plus9,torepr16);
++R.GAS;
return $ret88308831;
};
var $Hanf_arg26168836 = function(anf_arg8278835,anf_arg825563,self65564,_plus9,torepr16) {
var $z88398840 = D;
var $f88458846 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg8278835):R.ffi.throwNonFunApp(L[51],_plus9,[(", "),anf_arg8278835]);
};
try {
if(--R.GAS > 0) {
$z88398840 = $f88458846();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88458846,
"from":L[51]});
}
} catch($e88378838) {
if(R.isCont($e88378838)) {
var $ss88418842 = {"from":L[51],
"go":function(anf_arg8288847) {
return $Hanf_arg26158848(anf_arg8288847,anf_arg825563,self65564,_plus9,torepr16);
}};
$e88378838.stack[R.EXN_STACKHEIGHT++] = $ss88418842;
}
if(R.isPyretException($e88378838)) {
$e88378838.pyretStack.push(L[51]);
}
throw $e88378838;
}
var $ret88438844 = $Hanf_arg26158848($z88398840,anf_arg825563,self65564,_plus9,torepr16);
++R.GAS;
return $ret88438844;
};
var $Hanf_arg26158848 = function(anf_arg8288847,anf_arg825563,self65564,_plus9,torepr16) {
var $z88518852 = D;
var $f88578858 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg825563,anf_arg8288847):R.ffi.throwNonFunApp(L[51],_plus9,[anf_arg825563,anf_arg8288847]);
};
try {
if(--R.GAS > 0) {
$z88518852 = $f88578858();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88578858,
"from":L[51]});
}
} catch($e88498850) {
if(R.isCont($e88498850)) {
var $ss88538854 = {"from":L[51],
"go":function(anf_arg8298859) {
return $Hanf_arg26148860(anf_arg8298859,self65564,_plus9,torepr16);
}};
$e88498850.stack[R.EXN_STACKHEIGHT++] = $ss88538854;
}
if(R.isPyretException($e88498850)) {
$e88498850.pyretStack.push(L[51]);
}
throw $e88498850;
}
var $ret88558856 = $Hanf_arg26148860($z88518852,self65564,_plus9,torepr16);
++R.GAS;
return $ret88558856;
};
var $Hanf_arg26148860 = function(anf_arg8298859,self65564,_plus9,torepr16) {
var anf_arg8308871 = G(self65564,"expr",L[51]);
var $z88638864 = D;
var $f88698870 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg8308871):R.ffi.throwNonFunApp(L[51],torepr16,[anf_arg8308871]);
};
try {
if(--R.GAS > 0) {
$z88638864 = $f88698870();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88698870,
"from":L[51]});
}
} catch($e88618862) {
if(R.isCont($e88618862)) {
var $ss88658866 = {"from":L[51],
"go":function(anf_arg8318872) {
return $Hanf_arg26138873(anf_arg8318872,anf_arg8298859,_plus9);
}};
$e88618862.stack[R.EXN_STACKHEIGHT++] = $ss88658866;
}
if(R.isPyretException($e88618862)) {
$e88618862.pyretStack.push(L[51]);
}
throw $e88618862;
}
var $ret88678868 = $Hanf_arg26138873($z88638864,anf_arg8298859,_plus9);
++R.GAS;
return $ret88678868;
};
var $Hanf_arg26138873 = function(anf_arg8318872,anf_arg8298859,_plus9) {
var $z88768877 = D;
var $f88828883 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg8318872):R.ffi.throwNonFunApp(L[51],_plus9,[(", "),anf_arg8318872]);
};
try {
if(--R.GAS > 0) {
$z88768877 = $f88828883();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88828883,
"from":L[51]});
}
} catch($e88748875) {
if(R.isCont($e88748875)) {
var $ss88788879 = {"from":L[51],
"go":function(anf_arg8328884) {
return $Hanf_arg26128885(anf_arg8328884,anf_arg8298859,_plus9);
}};
$e88748875.stack[R.EXN_STACKHEIGHT++] = $ss88788879;
}
if(R.isPyretException($e88748875)) {
$e88748875.pyretStack.push(L[51]);
}
throw $e88748875;
}
var $ret88808881 = $Hanf_arg26128885($z88768877,anf_arg8298859,_plus9);
++R.GAS;
return $ret88808881;
};
var $Hanf_arg26128885 = function(anf_arg8328884,anf_arg8298859,_plus9) {
var $z88888889 = D;
var $f88948895 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg8298859,anf_arg8328884):R.ffi.throwNonFunApp(L[51],_plus9,[anf_arg8298859,anf_arg8328884]);
};
try {
if(--R.GAS > 0) {
$z88888889 = $f88948895();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f88948895,
"from":L[51]});
}
} catch($e88868887) {
if(R.isCont($e88868887)) {
var $ss88908891 = {"from":L[51],
"go":function(anf_arg8338896) {
return $Hanf_arg26118897(anf_arg8338896,_plus9);
}};
$e88868887.stack[R.EXN_STACKHEIGHT++] = $ss88908891;
}
if(R.isPyretException($e88868887)) {
$e88868887.pyretStack.push(L[51]);
}
throw $e88868887;
}
var $ret88928893 = $Hanf_arg26118897($z88888889,_plus9);
++R.GAS;
return $ret88928893;
};
var $Hanf_arg26118897 = function(anf_arg8338896,_plus9) {
var $z89008901 = D;
var $f89068907 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg8338896,(")")):R.ffi.throwNonFunApp(L[51],_plus9,[anf_arg8338896,(")")]);
};
try {
if(--R.GAS > 0) {
$z89008901 = $f89068907();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89068907,
"from":L[51]});
}
} catch($e88988899) {
if(R.isCont($e88988899)) {
var $ss89028903 = {"from":L[51],
"go":function(anf_arg8348908) {
return $Hanf_arg26108909(anf_arg8348908,_plus9);
}};
$e88988899.stack[R.EXN_STACKHEIGHT++] = $ss89028903;
}
if(R.isPyretException($e88988899)) {
$e88988899.pyretStack.push(L[51]);
}
throw $e88988899;
}
var $ret89048905 = $Hanf_arg26108909($z89008901,_plus9);
++R.GAS;
return $ret89048905;
};
var $Hanf_arg26108909 = function(anf_arg8348908,_plus9) {
var $z89128913 = D;
var $f89188919 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg8348908):R.ffi.throwNonFunApp(L[51],_plus9,[("("),anf_arg8348908]);
};
try {
if(--R.GAS > 0) {
$z89128913 = $f89188919();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89188919,
"from":L[51]});
}
} catch($e89108911) {
if(R.isCont($e89108911)) {
var $ss89148915 = {"from":L[51],
"go":function(anf_arg8358920) {
return $Hanf_arg26098921(anf_arg8358920,_plus9);
}};
$e89108911.stack[R.EXN_STACKHEIGHT++] = $ss89148915;
}
if(R.isPyretException($e89108911)) {
$e89108911.pyretStack.push(L[51]);
}
throw $e89108911;
}
var $ret89168917 = $Hanf_arg26098921($z89128913,_plus9);
++R.GAS;
return $ret89168917;
};
var $Hanf_arg26098921 = function(anf_arg8358920,_plus9) {
var $z89248925 = D;
var $f89308931 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("var-bind"),anf_arg8358920):R.ffi.throwNonFunApp(L[51],_plus9,[("var-bind"),anf_arg8358920]);
};
try {
if(--R.GAS > 0) {
$z89248925 = $f89308931();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89308931,
"from":L[51]});
}
} catch($e89228923) {
if(R.isCont($e89228923)) {
var $ss89268927 = {"from":L[51],
"go":function(ann_DASH_check_DASH_temp8238932) {
return $Hann_DASH_check_DASH_temp26088933(ann_DASH_check_DASH_temp8238932);
}};
$e89228923.stack[R.EXN_STACKHEIGHT++] = $ss89268927;
}
if(R.isPyretException($e89228923)) {
$e89228923.pyretStack.push(L[51]);
}
throw $e89228923;
}
var $ret89288929 = $Hann_DASH_check_DASH_temp26088933($z89248925);
++R.GAS;
return $ret89288929;
};
var $Hann_DASH_check_DASH_temp26088933 = function(ann_DASH_check_DASH_temp8238932) {
return ann_DASH_check_DASH_temp8238932;
};
var $Hcont_tail_arg2606582 = function(cont_tail_arg820580,if_helper810581) {
if(--R.GAS > 0) {
$z89348935 = R.isFunction(if_helper810581)?if_helper810581.app(cont_tail_arg820580):R.ffi.throwNonFunApp(L[51],if_helper810581,[cont_tail_arg820580]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper810581)?if_helper810581.app(cont_tail_arg820580):R.ffi.throwNonFunApp(L[51],if_helper810581,[cont_tail_arg820580]);
},
"from":L[51]});
}
++R.GAS;
return $z89348935;
};
var $Hcont_tail_arg2607597 = function(cont_tail_arg815596,if_helper810581) {
if(--R.GAS > 0) {
$z89368937 = R.isFunction(if_helper810581)?if_helper810581.app(cont_tail_arg815596):R.ffi.throwNonFunApp(L[51],if_helper810581,[cont_tail_arg815596]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper810581)?if_helper810581.app(cont_tail_arg815596):R.ffi.throwNonFunApp(L[51],if_helper810581,[cont_tail_arg815596]);
},
"from":L[51]});
}
++R.GAS;
return $z89368937;
};
var $Hanf_arg2605618 = function(anf_arg797616,self59617,_plus9,torepr16) {
var anf_arg7988948 = G(self59617,"atom",L[52]);
var $z89408941 = D;
var $f89468947 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg7988948):R.ffi.throwNonFunApp(L[52],torepr16,[anf_arg7988948]);
};
try {
if(--R.GAS > 0) {
$z89408941 = $f89468947();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89468947,
"from":L[52]});
}
} catch($e89388939) {
if(R.isCont($e89388939)) {
var $ss89428943 = {"from":L[52],
"go":function(anf_arg7998949) {
return $Hanf_arg26048950(anf_arg7998949,anf_arg797616,self59617,_plus9,torepr16);
}};
$e89388939.stack[R.EXN_STACKHEIGHT++] = $ss89428943;
}
if(R.isPyretException($e89388939)) {
$e89388939.pyretStack.push(L[52]);
}
throw $e89388939;
}
var $ret89448945 = $Hanf_arg26048950($z89408941,anf_arg797616,self59617,_plus9,torepr16);
++R.GAS;
return $ret89448945;
};
var $Hanf_arg26048950 = function(anf_arg7998949,anf_arg797616,self59617,_plus9,torepr16) {
var $z89538954 = D;
var $f89598960 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg7998949):R.ffi.throwNonFunApp(L[52],_plus9,[(", "),anf_arg7998949]);
};
try {
if(--R.GAS > 0) {
$z89538954 = $f89598960();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89598960,
"from":L[52]});
}
} catch($e89518952) {
if(R.isCont($e89518952)) {
var $ss89558956 = {"from":L[52],
"go":function(anf_arg8008961) {
return $Hanf_arg26038962(anf_arg8008961,anf_arg797616,self59617,_plus9,torepr16);
}};
$e89518952.stack[R.EXN_STACKHEIGHT++] = $ss89558956;
}
if(R.isPyretException($e89518952)) {
$e89518952.pyretStack.push(L[52]);
}
throw $e89518952;
}
var $ret89578958 = $Hanf_arg26038962($z89538954,anf_arg797616,self59617,_plus9,torepr16);
++R.GAS;
return $ret89578958;
};
var $Hanf_arg26038962 = function(anf_arg8008961,anf_arg797616,self59617,_plus9,torepr16) {
var $z89658966 = D;
var $f89718972 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg797616,anf_arg8008961):R.ffi.throwNonFunApp(L[52],_plus9,[anf_arg797616,anf_arg8008961]);
};
try {
if(--R.GAS > 0) {
$z89658966 = $f89718972();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89718972,
"from":L[52]});
}
} catch($e89638964) {
if(R.isCont($e89638964)) {
var $ss89678968 = {"from":L[52],
"go":function(anf_arg8018973) {
return $Hanf_arg26028974(anf_arg8018973,self59617,_plus9,torepr16);
}};
$e89638964.stack[R.EXN_STACKHEIGHT++] = $ss89678968;
}
if(R.isPyretException($e89638964)) {
$e89638964.pyretStack.push(L[52]);
}
throw $e89638964;
}
var $ret89698970 = $Hanf_arg26028974($z89658966,self59617,_plus9,torepr16);
++R.GAS;
return $ret89698970;
};
var $Hanf_arg26028974 = function(anf_arg8018973,self59617,_plus9,torepr16) {
var anf_arg8028985 = G(self59617,"expr",L[52]);
var $z89778978 = D;
var $f89838984 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg8028985):R.ffi.throwNonFunApp(L[52],torepr16,[anf_arg8028985]);
};
try {
if(--R.GAS > 0) {
$z89778978 = $f89838984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89838984,
"from":L[52]});
}
} catch($e89758976) {
if(R.isCont($e89758976)) {
var $ss89798980 = {"from":L[52],
"go":function(anf_arg8038986) {
return $Hanf_arg26018987(anf_arg8038986,anf_arg8018973,_plus9);
}};
$e89758976.stack[R.EXN_STACKHEIGHT++] = $ss89798980;
}
if(R.isPyretException($e89758976)) {
$e89758976.pyretStack.push(L[52]);
}
throw $e89758976;
}
var $ret89818982 = $Hanf_arg26018987($z89778978,anf_arg8018973,_plus9);
++R.GAS;
return $ret89818982;
};
var $Hanf_arg26018987 = function(anf_arg8038986,anf_arg8018973,_plus9) {
var $z89908991 = D;
var $f89968997 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg8038986):R.ffi.throwNonFunApp(L[52],_plus9,[(", "),anf_arg8038986]);
};
try {
if(--R.GAS > 0) {
$z89908991 = $f89968997();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f89968997,
"from":L[52]});
}
} catch($e89888989) {
if(R.isCont($e89888989)) {
var $ss89928993 = {"from":L[52],
"go":function(anf_arg8048998) {
return $Hanf_arg26008999(anf_arg8048998,anf_arg8018973,_plus9);
}};
$e89888989.stack[R.EXN_STACKHEIGHT++] = $ss89928993;
}
if(R.isPyretException($e89888989)) {
$e89888989.pyretStack.push(L[52]);
}
throw $e89888989;
}
var $ret89948995 = $Hanf_arg26008999($z89908991,anf_arg8018973,_plus9);
++R.GAS;
return $ret89948995;
};
var $Hanf_arg26008999 = function(anf_arg8048998,anf_arg8018973,_plus9) {
var $z90029003 = D;
var $f90089009 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg8018973,anf_arg8048998):R.ffi.throwNonFunApp(L[52],_plus9,[anf_arg8018973,anf_arg8048998]);
};
try {
if(--R.GAS > 0) {
$z90029003 = $f90089009();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90089009,
"from":L[52]});
}
} catch($e90009001) {
if(R.isCont($e90009001)) {
var $ss90049005 = {"from":L[52],
"go":function(anf_arg8059010) {
return $Hanf_arg25999011(anf_arg8059010,_plus9);
}};
$e90009001.stack[R.EXN_STACKHEIGHT++] = $ss90049005;
}
if(R.isPyretException($e90009001)) {
$e90009001.pyretStack.push(L[52]);
}
throw $e90009001;
}
var $ret90069007 = $Hanf_arg25999011($z90029003,_plus9);
++R.GAS;
return $ret90069007;
};
var $Hanf_arg25999011 = function(anf_arg8059010,_plus9) {
var $z90149015 = D;
var $f90209021 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg8059010,(")")):R.ffi.throwNonFunApp(L[52],_plus9,[anf_arg8059010,(")")]);
};
try {
if(--R.GAS > 0) {
$z90149015 = $f90209021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90209021,
"from":L[52]});
}
} catch($e90129013) {
if(R.isCont($e90129013)) {
var $ss90169017 = {"from":L[52],
"go":function(anf_arg8069022) {
return $Hanf_arg25989023(anf_arg8069022,_plus9);
}};
$e90129013.stack[R.EXN_STACKHEIGHT++] = $ss90169017;
}
if(R.isPyretException($e90129013)) {
$e90129013.pyretStack.push(L[52]);
}
throw $e90129013;
}
var $ret90189019 = $Hanf_arg25989023($z90149015,_plus9);
++R.GAS;
return $ret90189019;
};
var $Hanf_arg25989023 = function(anf_arg8069022,_plus9) {
var $z90269027 = D;
var $f90329033 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg8069022):R.ffi.throwNonFunApp(L[52],_plus9,[("("),anf_arg8069022]);
};
try {
if(--R.GAS > 0) {
$z90269027 = $f90329033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90329033,
"from":L[52]});
}
} catch($e90249025) {
if(R.isCont($e90249025)) {
var $ss90289029 = {"from":L[52],
"go":function(anf_arg8079034) {
return $Hanf_arg25979035(anf_arg8079034,_plus9);
}};
$e90249025.stack[R.EXN_STACKHEIGHT++] = $ss90289029;
}
if(R.isPyretException($e90249025)) {
$e90249025.pyretStack.push(L[52]);
}
throw $e90249025;
}
var $ret90309031 = $Hanf_arg25979035($z90269027,_plus9);
++R.GAS;
return $ret90309031;
};
var $Hanf_arg25979035 = function(anf_arg8079034,_plus9) {
var $z90389039 = D;
var $f90449045 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("let-bind"),anf_arg8079034):R.ffi.throwNonFunApp(L[52],_plus9,[("let-bind"),anf_arg8079034]);
};
try {
if(--R.GAS > 0) {
$z90389039 = $f90449045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90449045,
"from":L[52]});
}
} catch($e90369037) {
if(R.isCont($e90369037)) {
var $ss90409041 = {"from":L[52],
"go":function(ann_DASH_check_DASH_temp7959046) {
return $Hann_DASH_check_DASH_temp25969047(ann_DASH_check_DASH_temp7959046);
}};
$e90369037.stack[R.EXN_STACKHEIGHT++] = $ss90409041;
}
if(R.isPyretException($e90369037)) {
$e90369037.pyretStack.push(L[52]);
}
throw $e90369037;
}
var $ret90429043 = $Hann_DASH_check_DASH_temp25969047($z90389039);
++R.GAS;
return $ret90429043;
};
var $Hann_DASH_check_DASH_temp25969047 = function(ann_DASH_check_DASH_temp7959046) {
return ann_DASH_check_DASH_temp7959046;
};
var $Hcont_tail_arg2594635 = function(cont_tail_arg792633,if_helper782634) {
if(--R.GAS > 0) {
$z90489049 = R.isFunction(if_helper782634)?if_helper782634.app(cont_tail_arg792633):R.ffi.throwNonFunApp(L[52],if_helper782634,[cont_tail_arg792633]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper782634)?if_helper782634.app(cont_tail_arg792633):R.ffi.throwNonFunApp(L[52],if_helper782634,[cont_tail_arg792633]);
},
"from":L[52]});
}
++R.GAS;
return $z90489049;
};
var $Hcont_tail_arg2595650 = function(cont_tail_arg787649,if_helper782634) {
if(--R.GAS > 0) {
$z90509051 = R.isFunction(if_helper782634)?if_helper782634.app(cont_tail_arg787649):R.ffi.throwNonFunApp(L[52],if_helper782634,[cont_tail_arg787649]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper782634)?if_helper782634.app(cont_tail_arg787649):R.ffi.throwNonFunApp(L[52],if_helper782634,[cont_tail_arg787649]);
},
"from":L[52]});
}
++R.GAS;
return $z90509051;
};
var $Hanf_arg2593671 = function(anf_arg769669,self53670,_plus9,torepr16) {
var anf_arg7709062 = G(self53670,"atom",L[53]);
var $z90549055 = D;
var $f90609061 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg7709062):R.ffi.throwNonFunApp(L[53],torepr16,[anf_arg7709062]);
};
try {
if(--R.GAS > 0) {
$z90549055 = $f90609061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90609061,
"from":L[53]});
}
} catch($e90529053) {
if(R.isCont($e90529053)) {
var $ss90569057 = {"from":L[53],
"go":function(anf_arg7719063) {
return $Hanf_arg25929064(anf_arg7719063,anf_arg769669,self53670,_plus9,torepr16);
}};
$e90529053.stack[R.EXN_STACKHEIGHT++] = $ss90569057;
}
if(R.isPyretException($e90529053)) {
$e90529053.pyretStack.push(L[53]);
}
throw $e90529053;
}
var $ret90589059 = $Hanf_arg25929064($z90549055,anf_arg769669,self53670,_plus9,torepr16);
++R.GAS;
return $ret90589059;
};
var $Hanf_arg25929064 = function(anf_arg7719063,anf_arg769669,self53670,_plus9,torepr16) {
var $z90679068 = D;
var $f90739074 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg7719063):R.ffi.throwNonFunApp(L[53],_plus9,[(", "),anf_arg7719063]);
};
try {
if(--R.GAS > 0) {
$z90679068 = $f90739074();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90739074,
"from":L[53]});
}
} catch($e90659066) {
if(R.isCont($e90659066)) {
var $ss90699070 = {"from":L[53],
"go":function(anf_arg7729075) {
return $Hanf_arg25919076(anf_arg7729075,anf_arg769669,self53670,_plus9,torepr16);
}};
$e90659066.stack[R.EXN_STACKHEIGHT++] = $ss90699070;
}
if(R.isPyretException($e90659066)) {
$e90659066.pyretStack.push(L[53]);
}
throw $e90659066;
}
var $ret90719072 = $Hanf_arg25919076($z90679068,anf_arg769669,self53670,_plus9,torepr16);
++R.GAS;
return $ret90719072;
};
var $Hanf_arg25919076 = function(anf_arg7729075,anf_arg769669,self53670,_plus9,torepr16) {
var $z90799080 = D;
var $f90859086 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg769669,anf_arg7729075):R.ffi.throwNonFunApp(L[53],_plus9,[anf_arg769669,anf_arg7729075]);
};
try {
if(--R.GAS > 0) {
$z90799080 = $f90859086();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90859086,
"from":L[53]});
}
} catch($e90779078) {
if(R.isCont($e90779078)) {
var $ss90819082 = {"from":L[53],
"go":function(anf_arg7739087) {
return $Hanf_arg25909088(anf_arg7739087,self53670,_plus9,torepr16);
}};
$e90779078.stack[R.EXN_STACKHEIGHT++] = $ss90819082;
}
if(R.isPyretException($e90779078)) {
$e90779078.pyretStack.push(L[53]);
}
throw $e90779078;
}
var $ret90839084 = $Hanf_arg25909088($z90799080,self53670,_plus9,torepr16);
++R.GAS;
return $ret90839084;
};
var $Hanf_arg25909088 = function(anf_arg7739087,self53670,_plus9,torepr16) {
var anf_arg7749099 = G(self53670,"expr",L[53]);
var $z90919092 = D;
var $f90979098 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg7749099):R.ffi.throwNonFunApp(L[53],torepr16,[anf_arg7749099]);
};
try {
if(--R.GAS > 0) {
$z90919092 = $f90979098();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f90979098,
"from":L[53]});
}
} catch($e90899090) {
if(R.isCont($e90899090)) {
var $ss90939094 = {"from":L[53],
"go":function(anf_arg7759100) {
return $Hanf_arg25899101(anf_arg7759100,anf_arg7739087,_plus9);
}};
$e90899090.stack[R.EXN_STACKHEIGHT++] = $ss90939094;
}
if(R.isPyretException($e90899090)) {
$e90899090.pyretStack.push(L[53]);
}
throw $e90899090;
}
var $ret90959096 = $Hanf_arg25899101($z90919092,anf_arg7739087,_plus9);
++R.GAS;
return $ret90959096;
};
var $Hanf_arg25899101 = function(anf_arg7759100,anf_arg7739087,_plus9) {
var $z91049105 = D;
var $f91109111 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg7759100):R.ffi.throwNonFunApp(L[53],_plus9,[(", "),anf_arg7759100]);
};
try {
if(--R.GAS > 0) {
$z91049105 = $f91109111();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91109111,
"from":L[53]});
}
} catch($e91029103) {
if(R.isCont($e91029103)) {
var $ss91069107 = {"from":L[53],
"go":function(anf_arg7769112) {
return $Hanf_arg25889113(anf_arg7769112,anf_arg7739087,_plus9);
}};
$e91029103.stack[R.EXN_STACKHEIGHT++] = $ss91069107;
}
if(R.isPyretException($e91029103)) {
$e91029103.pyretStack.push(L[53]);
}
throw $e91029103;
}
var $ret91089109 = $Hanf_arg25889113($z91049105,anf_arg7739087,_plus9);
++R.GAS;
return $ret91089109;
};
var $Hanf_arg25889113 = function(anf_arg7769112,anf_arg7739087,_plus9) {
var $z91169117 = D;
var $f91229123 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg7739087,anf_arg7769112):R.ffi.throwNonFunApp(L[53],_plus9,[anf_arg7739087,anf_arg7769112]);
};
try {
if(--R.GAS > 0) {
$z91169117 = $f91229123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91229123,
"from":L[53]});
}
} catch($e91149115) {
if(R.isCont($e91149115)) {
var $ss91189119 = {"from":L[53],
"go":function(anf_arg7779124) {
return $Hanf_arg25879125(anf_arg7779124,_plus9);
}};
$e91149115.stack[R.EXN_STACKHEIGHT++] = $ss91189119;
}
if(R.isPyretException($e91149115)) {
$e91149115.pyretStack.push(L[53]);
}
throw $e91149115;
}
var $ret91209121 = $Hanf_arg25879125($z91169117,_plus9);
++R.GAS;
return $ret91209121;
};
var $Hanf_arg25879125 = function(anf_arg7779124,_plus9) {
var $z91289129 = D;
var $f91349135 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg7779124,(")")):R.ffi.throwNonFunApp(L[53],_plus9,[anf_arg7779124,(")")]);
};
try {
if(--R.GAS > 0) {
$z91289129 = $f91349135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91349135,
"from":L[53]});
}
} catch($e91269127) {
if(R.isCont($e91269127)) {
var $ss91309131 = {"from":L[53],
"go":function(anf_arg7789136) {
return $Hanf_arg25869137(anf_arg7789136,_plus9);
}};
$e91269127.stack[R.EXN_STACKHEIGHT++] = $ss91309131;
}
if(R.isPyretException($e91269127)) {
$e91269127.pyretStack.push(L[53]);
}
throw $e91269127;
}
var $ret91329133 = $Hanf_arg25869137($z91289129,_plus9);
++R.GAS;
return $ret91329133;
};
var $Hanf_arg25869137 = function(anf_arg7789136,_plus9) {
var $z91409141 = D;
var $f91469147 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg7789136):R.ffi.throwNonFunApp(L[53],_plus9,[("("),anf_arg7789136]);
};
try {
if(--R.GAS > 0) {
$z91409141 = $f91469147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91469147,
"from":L[53]});
}
} catch($e91389139) {
if(R.isCont($e91389139)) {
var $ss91429143 = {"from":L[53],
"go":function(anf_arg7799148) {
return $Hanf_arg25859149(anf_arg7799148,_plus9);
}};
$e91389139.stack[R.EXN_STACKHEIGHT++] = $ss91429143;
}
if(R.isPyretException($e91389139)) {
$e91389139.pyretStack.push(L[53]);
}
throw $e91389139;
}
var $ret91449145 = $Hanf_arg25859149($z91409141,_plus9);
++R.GAS;
return $ret91449145;
};
var $Hanf_arg25859149 = function(anf_arg7799148,_plus9) {
var $z91529153 = D;
var $f91589159 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("letrec-bind"),anf_arg7799148):R.ffi.throwNonFunApp(L[53],_plus9,[("letrec-bind"),anf_arg7799148]);
};
try {
if(--R.GAS > 0) {
$z91529153 = $f91589159();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91589159,
"from":L[53]});
}
} catch($e91509151) {
if(R.isCont($e91509151)) {
var $ss91549155 = {"from":L[53],
"go":function(ann_DASH_check_DASH_temp7679160) {
return $Hann_DASH_check_DASH_temp25849161(ann_DASH_check_DASH_temp7679160);
}};
$e91509151.stack[R.EXN_STACKHEIGHT++] = $ss91549155;
}
if(R.isPyretException($e91509151)) {
$e91509151.pyretStack.push(L[53]);
}
throw $e91509151;
}
var $ret91569157 = $Hann_DASH_check_DASH_temp25849161($z91529153);
++R.GAS;
return $ret91569157;
};
var $Hann_DASH_check_DASH_temp25849161 = function(ann_DASH_check_DASH_temp7679160) {
return ann_DASH_check_DASH_temp7679160;
};
var $Hcont_tail_arg2582688 = function(cont_tail_arg764686,if_helper754687) {
if(--R.GAS > 0) {
$z91629163 = R.isFunction(if_helper754687)?if_helper754687.app(cont_tail_arg764686):R.ffi.throwNonFunApp(L[53],if_helper754687,[cont_tail_arg764686]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper754687)?if_helper754687.app(cont_tail_arg764686):R.ffi.throwNonFunApp(L[53],if_helper754687,[cont_tail_arg764686]);
},
"from":L[53]});
}
++R.GAS;
return $z91629163;
};
var $Hcont_tail_arg2583703 = function(cont_tail_arg759702,if_helper754687) {
if(--R.GAS > 0) {
$z91649165 = R.isFunction(if_helper754687)?if_helper754687.app(cont_tail_arg759702):R.ffi.throwNonFunApp(L[53],if_helper754687,[cont_tail_arg759702]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper754687)?if_helper754687.app(cont_tail_arg759702):R.ffi.throwNonFunApp(L[53],if_helper754687,[cont_tail_arg759702]);
},
"from":L[53]});
}
++R.GAS;
return $z91649165;
};
var $Hann_DASH_check_DASH_temp25819166 = function(ann_DASH_check_DASH_temp6249167) {
return ann_DASH_check_DASH_temp6249167;
};
var $Himports_DASH_and_DASH_lets25809168 = function(imports_DASH_and_DASH_lets2569169,A119,C923,U1124,_provide_DASH_raw2529170,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16) {
var imports2579188 = G(imports_DASH_and_DASH_lets2569169,"imports",L[1079]);
var extra_DASH_lets2589187 = G(imports_DASH_and_DASH_lets2569169,"lets",L[1078]);
var str2599190 = R.makeFunction(function(arg_DASH_419191) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1076],1,arguments);
}
var anf_fun6289202 = G(A119,"s-str",L[1077]);
var $z91949195 = D;
var $f92009201 = function(_) {
return R.isFunction(anf_fun6289202)?anf_fun6289202.app(l2519173,arg_DASH_419191):R.ffi.throwNonFunApp(L[1076],anf_fun6289202,[l2519173,arg_DASH_419191]);
};
try {
if(--R.GAS > 0) {
$z91949195 = $f92009201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92009201,
"from":L[1076]});
}
} catch($e91929193) {
if(R.isCont($e91929193)) {
var $ss91969197 = {"from":L[1076],
"go":function(ann_DASH_check_DASH_temp6279203) {
return $Hann_DASH_check_DASH_temp25189204(ann_DASH_check_DASH_temp6279203);
}};
$e91929193.stack[R.EXN_STACKHEIGHT++] = $ss91969197;
}
if(R.isPyretException($e91929193)) {
$e91929193.pyretStack.push(L[1076]);
}
throw $e91929193;
}
var $ret91989199 = $Hann_DASH_check_DASH_temp25189204($z91949195);
++R.GAS;
return $ret91989199;
});
var $z91789179 = D;
var $f91849185 = function(_) {
return R.isFunction(resolve_DASH_provide8781.$var)?resolve_DASH_provide8781.$var.app(_provide_DASH_raw2529170,body2559171):R.ffi.throwNonFunApp(L[1075],resolve_DASH_provide8781.$var,[_provide_DASH_raw2529170,body2559171]);
};
try {
if(--R.GAS > 0) {
$z91789179 = $f91849185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f91849185,
"from":L[1075]});
}
} catch($e91769177) {
if(R.isCont($e91769177)) {
var $ss91809181 = {"from":L[1075],
"go":function(cases_DASH_val429186) {
return $Hcases_DASH_val25799189(cases_DASH_val429186,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16);
}};
$e91769177.stack[R.EXN_STACKHEIGHT++] = $ss91809181;
}
if(R.isPyretException($e91769177)) {
$e91769177.pyretStack.push(L[1075]);
}
throw $e91769177;
}
var $ret91829183 = $Hcases_DASH_val25799189($z91789179,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16);
++R.GAS;
return $ret91829183;
};
var $Hcases_DASH_val25799189 = function(cases_DASH_val429186,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16) {
var anf_fun6299215 = G(cases_DASH_val429186,"_match",L[1075]);
var anf_obj6349232 = R.makeFunction(function($underscore2619237) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1082],1,arguments);
}
var anf_fun6319250 = G(A119,"s-obj",L[1084]);
var anf_fun6329248 = G(list3375,"make",L[1083]);
var $z92409241 = D;
var $f92469247 = function(_) {
return R.isFunction(anf_fun6329248)?anf_fun6329248.app([]):R.ffi.throwNonFunApp(L[1083],anf_fun6329248,[[]]);
};
try {
if(--R.GAS > 0) {
$z92409241 = $f92469247();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92469247,
"from":L[1083]});
}
} catch($e92389239) {
if(R.isCont($e92389239)) {
var $ss92429243 = {"from":L[1083],
"go":function(anf_arg6339249) {
return $Hanf_arg25209251(anf_arg6339249,anf_fun6319250,l2519173);
}};
$e92389239.stack[R.EXN_STACKHEIGHT++] = $ss92429243;
}
if(R.isPyretException($e92389239)) {
$e92389239.pyretStack.push(L[1083]);
}
throw $e92389239;
}
var $ret92449245 = $Hanf_arg25209251($z92409241,anf_fun6319250,l2519173);
++R.GAS;
return $ret92449245;
});
var anf_obj6369233 = R.makeFunction(function($underscore2629234,block2639235) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1081],2,arguments);
}
var ann_DASH_check_DASH_temp6359236 = block2639235;
return ann_DASH_check_DASH_temp6359236;
});
var anf_arg6379216 = R.makeObject({"s-provide-none":anf_obj6349232,
"s-provide":anf_obj6369233});
var anf_arg6399217 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1075],0,arguments);
}
var $z92229223 = D;
var $f92289229 = function(_) {
return R.isFunction(raise14)?raise14.app(("Should have been resolved away")):R.ffi.throwNonFunApp(L[1075],raise14,[("Should have been resolved away")]);
};
try {
if(--R.GAS > 0) {
$z92229223 = $f92289229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92289229,
"from":L[1075]});
}
} catch($e92209221) {
if(R.isCont($e92209221)) {
var $ss92249225 = {"from":L[1075],
"go":function(ann_DASH_check_DASH_temp6389230) {
return $Hann_DASH_check_DASH_temp25219231(ann_DASH_check_DASH_temp6389230);
}};
$e92209221.stack[R.EXN_STACKHEIGHT++] = $ss92249225;
}
if(R.isPyretException($e92209221)) {
$e92209221.pyretStack.push(L[1075]);
}
throw $e92209221;
}
var $ret92269227 = $Hann_DASH_check_DASH_temp25219231($z92229223);
++R.GAS;
return $ret92269227;
});
var $z92079208 = D;
var $f92139214 = function(_) {
return R.isFunction(anf_fun6299215)?anf_fun6299215.app(anf_arg6379216,anf_arg6399217):R.ffi.throwNonFunApp(L[1080],anf_fun6299215,[anf_arg6379216,anf_arg6399217]);
};
try {
if(--R.GAS > 0) {
$z92079208 = $f92139214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92139214,
"from":L[1080]});
}
} catch($e92059206) {
if(R.isCont($e92059206)) {
var $ss92099210 = {"from":L[1080],
"go":function(prov2609218) {
return $Hprov25789219(prov2609218,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16);
}};
$e92059206.stack[R.EXN_STACKHEIGHT++] = $ss92099210;
}
if(R.isPyretException($e92059206)) {
$e92059206.pyretStack.push(L[1080]);
}
throw $e92059206;
}
var $ret92119212 = $Hprov25789219($z92079208,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16);
++R.GAS;
return $ret92119212;
};
var $Hprov25789219 = function(prov2609218,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16) {
var $z92549255 = D;
var $f92609261 = function(_) {
return R.isFunction(resolve_DASH_type_DASH_provide8882.$var)?resolve_DASH_type_DASH_provide8882.$var.app(provide_DASH_types_DASH_raw2539175,body2559171):R.ffi.throwNonFunApp(L[1085],resolve_DASH_type_DASH_provide8882.$var,[provide_DASH_types_DASH_raw2539175,body2559171]);
};
try {
if(--R.GAS > 0) {
$z92549255 = $f92609261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92609261,
"from":L[1085]});
}
} catch($e92529253) {
if(R.isCont($e92529253)) {
var $ss92569257 = {"from":L[1085],
"go":function(provides2649262) {
return $Hprovides25779263(provides2649262,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,prov2609218,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16);
}};
$e92529253.stack[R.EXN_STACKHEIGHT++] = $ss92569257;
}
if(R.isPyretException($e92529253)) {
$e92529253.pyretStack.push(L[1085]);
}
throw $e92529253;
}
var $ret92589259 = $Hprovides25779263($z92549255,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,prov2609218,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16);
++R.GAS;
return $ret92589259;
};
var $Hprovides25779263 = function(provides2649262,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,prov2609218,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16) {
var cases_DASH_val439310 = provides2649262;
var anf_fun6409274 = G(cases_DASH_val439310,"_match",L[1087]);
var anf_obj6439291 = R.makeFunction(function($underscore2669296) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1090],1,arguments);
}
var anf_fun6429307 = G(list3375,"make",L[1091]);
var $z92999300 = D;
var $f93059306 = function(_) {
return R.isFunction(anf_fun6429307)?anf_fun6429307.app([]):R.ffi.throwNonFunApp(L[1090],anf_fun6429307,[[]]);
};
try {
if(--R.GAS > 0) {
$z92999300 = $f93059306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93059306,
"from":L[1090]});
}
} catch($e92979298) {
if(R.isCont($e92979298)) {
var $ss93019302 = {"from":L[1090],
"go":function(ann_DASH_check_DASH_temp6419308) {
return $Hann_DASH_check_DASH_temp25229309(ann_DASH_check_DASH_temp6419308);
}};
$e92979298.stack[R.EXN_STACKHEIGHT++] = $ss93019302;
}
if(R.isPyretException($e92979298)) {
$e92979298.pyretStack.push(L[1090]);
}
throw $e92979298;
}
var $ret93039304 = $Hann_DASH_check_DASH_temp25229309($z92999300);
++R.GAS;
return $ret93039304;
});
var anf_obj6459292 = R.makeFunction(function($underscore2679293,anns2689294) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1089],2,arguments);
}
var ann_DASH_check_DASH_temp6449295 = anns2689294;
return ann_DASH_check_DASH_temp6449295;
});
var anf_arg6469275 = R.makeObject({"s-provide-types-none":anf_obj6439291,
"s-provide-types":anf_obj6459292});
var anf_arg6509276 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1087],0,arguments);
}
var $z92819282 = D;
var $f92879288 = function(_) {
return R.isFunction(torepr16)?torepr16.app(provides2649262):R.ffi.throwNonFunApp(L[1088],torepr16,[provides2649262]);
};
try {
if(--R.GAS > 0) {
$z92819282 = $f92879288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92879288,
"from":L[1088]});
}
} catch($e92799280) {
if(R.isCont($e92799280)) {
var $ss92839284 = {"from":L[1088],
"go":function(anf_arg6489289) {
return $Hanf_arg25259290(anf_arg6489289,_plus9,raise14);
}};
$e92799280.stack[R.EXN_STACKHEIGHT++] = $ss92839284;
}
if(R.isPyretException($e92799280)) {
$e92799280.pyretStack.push(L[1088]);
}
throw $e92799280;
}
var $ret92859286 = $Hanf_arg25259290($z92819282,_plus9,raise14);
++R.GAS;
return $ret92859286;
});
var $z92669267 = D;
var $f92729273 = function(_) {
return R.isFunction(anf_fun6409274)?anf_fun6409274.app(anf_arg6469275,anf_arg6509276):R.ffi.throwNonFunApp(L[1086],anf_fun6409274,[anf_arg6469275,anf_arg6509276]);
};
try {
if(--R.GAS > 0) {
$z92669267 = $f92729273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f92729273,
"from":L[1086]});
}
} catch($e92649265) {
if(R.isCont($e92649265)) {
var $ss92689269 = {"from":L[1086],
"go":function(provt2659277) {
return $Hprovt25769278(provt2659277,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,prov2609218,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14);
}};
$e92649265.stack[R.EXN_STACKHEIGHT++] = $ss92689269;
}
if(R.isPyretException($e92649265)) {
$e92649265.pyretStack.push(L[1086]);
}
throw $e92649265;
}
var $ret92709271 = $Hprovt25769278($z92669267,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,prov2609218,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14);
++R.GAS;
return $ret92709271;
};
var $Hprovt25769278 = function(provt2659277,A119,C923,U1124,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,extra_DASH_lets2589187,imports2579188,l2519173,list3375,map459174,prov2609218,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14) {
var cases_DASH_val449356 = body2559171;
var anf_fun6519321 = G(cases_DASH_val449356,"_match",L[1093]);
var anf_obj6569340 = R.makeFunction(function(l22709341,stmts2719342) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1096],2,arguments);
}
var anf_fun6539354 = G(A119,"s-block",L[1098]);
var $z93459346 = D;
var $f93519352 = function(_) {
return R.isFunction(desugar_DASH_toplevel_DASH_types9068.$var)?desugar_DASH_toplevel_DASH_types9068.$var.app(stmts2719342):R.ffi.throwNonFunApp(L[1097],desugar_DASH_toplevel_DASH_types9068.$var,[stmts2719342]);
};
try {
if(--R.GAS > 0) {
$z93459346 = $f93519352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93519352,
"from":L[1097]});
}
} catch($e93439344) {
if(R.isCont($e93439344)) {
var $ss93479348 = {"from":L[1097],
"go":function(anf_arg6549353) {
return $Hanf_arg25289355(anf_arg6549353,anf_fun6539354,extra_DASH_lets2589187,l22709341,_plus9);
}};
$e93439344.stack[R.EXN_STACKHEIGHT++] = $ss93479348;
}
if(R.isPyretException($e93439344)) {
$e93439344.pyretStack.push(L[1097]);
}
throw $e93439344;
}
var $ret93499350 = $Hanf_arg25289355($z93459346,anf_fun6539354,extra_DASH_lets2589187,l22709341,_plus9);
++R.GAS;
return $ret93499350;
});
var anf_arg6579322 = R.makeObject({"s-block":anf_obj6569340});
var anf_arg6649323 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1093],0,arguments);
}
var anf_fun6599338 = G(A119,"s-block",L[1095]);
var anf_fun6609336 = G(list3375,"make",L[1094]);
var $z93289329 = D;
var $f93349335 = function(_) {
return R.isFunction(anf_fun6609336)?anf_fun6609336.app([body2559171]):R.ffi.throwNonFunApp(L[1094],anf_fun6609336,[[body2559171]]);
};
try {
if(--R.GAS > 0) {
$z93289329 = $f93349335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93349335,
"from":L[1094]});
}
} catch($e93269327) {
if(R.isCont($e93269327)) {
var $ss93309331 = {"from":L[1094],
"go":function(anf_arg6619337) {
return $Hanf_arg25329339(anf_arg6619337,anf_fun6599338,desugar_DASH_toplevel_DASH_types9068,extra_DASH_lets2589187,l2519173,_plus9);
}};
$e93269327.stack[R.EXN_STACKHEIGHT++] = $ss93309331;
}
if(R.isPyretException($e93269327)) {
$e93269327.pyretStack.push(L[1094]);
}
throw $e93269327;
}
var $ret93329333 = $Hanf_arg25329339($z93289329,anf_fun6599338,desugar_DASH_toplevel_DASH_types9068,extra_DASH_lets2589187,l2519173,_plus9);
++R.GAS;
return $ret93329333;
});
var $z93139314 = D;
var $f93199320 = function(_) {
return R.isFunction(anf_fun6519321)?anf_fun6519321.app(anf_arg6579322,anf_arg6649323):R.ffi.throwNonFunApp(L[1092],anf_fun6519321,[anf_arg6579322,anf_arg6649323]);
};
try {
if(--R.GAS > 0) {
$z93139314 = $f93199320();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93199320,
"from":L[1092]});
}
} catch($e93119312) {
if(R.isCont($e93119312)) {
var $ss93159316 = {"from":L[1092],
"go":function(with_DASH_imports2699324) {
return $Hwith_DASH_imports25759325(with_DASH_imports2699324,A119,C923,U1124,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,empty3670,imports2579188,l2519173,list3375,map459174,prov2609218,provt2659277,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14);
}};
$e93119312.stack[R.EXN_STACKHEIGHT++] = $ss93159316;
}
if(R.isPyretException($e93119312)) {
$e93119312.pyretStack.push(L[1092]);
}
throw $e93119312;
}
var $ret93179318 = $Hwith_DASH_imports25759325($z93139314,A119,C923,U1124,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,empty3670,imports2579188,l2519173,list3375,map459174,prov2609218,provt2659277,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14);
++R.GAS;
return $ret93179318;
};
var $Hwith_DASH_imports25759325 = function(with_DASH_imports2699324,A119,C923,U1124,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,empty3670,imports2579188,l2519173,list3375,map459174,prov2609218,provt2659277,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14) {
var transform_DASH_toplevel_DASH_last2729357 = {"$var":D,
"$name":"transform-toplevel-last"};
var anf_assign6739358 = R.makeFunction(function(l22739403,last2749404) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1104],2,arguments);
}
var anf_fun6669417 = G(A119,"s-module",L[1109]);
var anf_fun6679418 = G(A119,"s-app",L[1108]);
var anf_fun6689419 = G(A119,"s-dot",L[1107]);
var anf_fun6699415 = G(U1124,"checkers",L[1106]);
var $z94079408 = D;
var $f94139414 = function(_) {
return R.isFunction(anf_fun6699415)?anf_fun6699415.app(l22739403):R.ffi.throwNonFunApp(L[1105],anf_fun6699415,[l22739403]);
};
try {
if(--R.GAS > 0) {
$z94079408 = $f94139414();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94139414,
"from":L[1105]});
}
} catch($e94059406) {
if(R.isCont($e94059406)) {
var $ss94099410 = {"from":L[1105],
"go":function(anf_arg6709416) {
return $Hanf_arg25369420(anf_arg6709416,anf_fun6669417,anf_fun6679418,anf_fun6689419,empty3670,l22739403,last2749404,prov2609218,provt2659277);
}};
$e94059406.stack[R.EXN_STACKHEIGHT++] = $ss94099410;
}
if(R.isPyretException($e94059406)) {
$e94059406.pyretStack.push(L[1105]);
}
throw $e94059406;
}
var $ret94119412 = $Hanf_arg25369420($z94079408,anf_fun6669417,anf_fun6679418,anf_fun6689419,empty3670,l22739403,last2749404,prov2609218,provt2659277);
++R.GAS;
return $ret94119412;
});
transform_DASH_toplevel_DASH_last2729357.$var = anf_assign6739358;
var cases_DASH_val469402 = with_DASH_imports2699324;
var anf_fun6749369 = G(cases_DASH_val469402,"_match",L[1100]);
var anf_obj7209386 = R.makeFunction(function(l22769387,stmts2779388) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1101],2,arguments);
}
var anf_fun6769399 = G(stmts2779388,"last",L[1103]);
var $z93919392 = D;
var $f93979398 = function(_) {
return R.isFunction(anf_fun6769399)?anf_fun6769399.app():R.ffi.throwNonFunApp(L[1102],anf_fun6769399,[]);
};
try {
if(--R.GAS > 0) {
$z93919392 = $f93979398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93979398,
"from":L[1102]});
}
} catch($e93899390) {
if(R.isCont($e93899390)) {
var $ss93939394 = {"from":L[1102],
"go":function(last2789400) {
return $Hlast25609401(last2789400,A119,l22769387,list3375,stmts2779388,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
}};
$e93899390.stack[R.EXN_STACKHEIGHT++] = $ss93939394;
}
if(R.isPyretException($e93899390)) {
$e93899390.pyretStack.push(L[1102]);
}
throw $e93899390;
}
var $ret93959396 = $Hlast25609401($z93919392,A119,l22769387,list3375,stmts2779388,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
++R.GAS;
return $ret93959396;
});
var anf_arg7219370 = R.makeObject({"s-block":anf_obj7209386});
var anf_arg7239371 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1100],0,arguments);
}
var $z93769377 = D;
var $f93829383 = function(_) {
return R.isFunction(raise14)?raise14.app(("Impossible")):R.ffi.throwNonFunApp(L[1100],raise14,[("Impossible")]);
};
try {
if(--R.GAS > 0) {
$z93769377 = $f93829383();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93829383,
"from":L[1100]});
}
} catch($e93749375) {
if(R.isCont($e93749375)) {
var $ss93789379 = {"from":L[1100],
"go":function(ann_DASH_check_DASH_temp7229384) {
return $Hann_DASH_check_DASH_temp25619385(ann_DASH_check_DASH_temp7229384);
}};
$e93749375.stack[R.EXN_STACKHEIGHT++] = $ss93789379;
}
if(R.isPyretException($e93749375)) {
$e93749375.pyretStack.push(L[1100]);
}
throw $e93749375;
}
var $ret93809381 = $Hann_DASH_check_DASH_temp25619385($z93769377);
++R.GAS;
return $ret93809381;
});
var $z93619362 = D;
var $f93679368 = function(_) {
return R.isFunction(anf_fun6749369)?anf_fun6749369.app(anf_arg7219370,anf_arg7239371):R.ffi.throwNonFunApp(L[1099],anf_fun6749369,[anf_arg7219370,anf_arg7239371]);
};
try {
if(--R.GAS > 0) {
$z93619362 = $f93679368();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f93679368,
"from":L[1099]});
}
} catch($e93599360) {
if(R.isCont($e93599360)) {
var $ss93639364 = {"from":L[1099],
"go":function(with_DASH_provides2759372) {
return $Hwith_DASH_provides25749373(with_DASH_provides2759372,A119,C923,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrap_DASH_env_DASH_imports22985,_plus9);
}};
$e93599360.stack[R.EXN_STACKHEIGHT++] = $ss93639364;
}
if(R.isPyretException($e93599360)) {
$e93599360.pyretStack.push(L[1099]);
}
throw $e93599360;
}
var $ret93659366 = $Hwith_DASH_provides25749373($z93619362,A119,C923,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrap_DASH_env_DASH_imports22985,_plus9);
++R.GAS;
return $ret93659366;
};
var $Hwith_DASH_provides25749373 = function(with_DASH_provides2759372,A119,C923,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrap_DASH_env_DASH_imports22985,_plus9) {
var $z94239424 = D;
var $f94299430 = function(_) {
return R.isFunction(wrap_DASH_env_DASH_imports22985.$var)?wrap_DASH_env_DASH_imports22985.$var.app(l2519173,with_DASH_provides2759372,compile_DASH_env2509172):R.ffi.throwNonFunApp(L[1110],wrap_DASH_env_DASH_imports22985.$var,[l2519173,with_DASH_provides2759372,compile_DASH_env2509172]);
};
try {
if(--R.GAS > 0) {
$z94239424 = $f94299430();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94299430,
"from":L[1110]});
}
} catch($e94219422) {
if(R.isCont($e94219422)) {
var $ss94259426 = {"from":L[1110],
"go":function(wrapped2839431) {
return $Hwrapped25739432(wrapped2839431,A119,C923,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,_plus9);
}};
$e94219422.stack[R.EXN_STACKHEIGHT++] = $ss94259426;
}
if(R.isPyretException($e94219422)) {
$e94219422.pyretStack.push(L[1110]);
}
throw $e94219422;
}
var $ret94279428 = $Hwrapped25739432($z94239424,A119,C923,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,_plus9);
++R.GAS;
return $ret94279428;
};
var $Hwrapped25739432 = function(wrapped2839431,A119,C923,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,_plus9) {
var anf_arg7309446 = R.makeFunction(function(k2859449) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1115],1,arguments);
}
var anf_fun7259462 = G(A119,"s-import",L[1118]);
var anf_fun7269460 = G(A119,"s-const-import",L[1117]);
var $z94529453 = D;
var $f94589459 = function(_) {
return R.isFunction(anf_fun7269460)?anf_fun7269460.app(l2519173,k2859449):R.ffi.throwNonFunApp(L[1116],anf_fun7269460,[l2519173,k2859449]);
};
try {
if(--R.GAS > 0) {
$z94529453 = $f94589459();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94589459,
"from":L[1116]});
}
} catch($e94509451) {
if(R.isCont($e94509451)) {
var $ss94549455 = {"from":L[1116],
"go":function(anf_arg7279461) {
return $Hanf_arg25649463(anf_arg7279461,A119,anf_fun7259462,k2859449,l2519173);
}};
$e94509451.stack[R.EXN_STACKHEIGHT++] = $ss94549455;
}
if(R.isPyretException($e94509451)) {
$e94509451.pyretStack.push(L[1116]);
}
throw $e94509451;
}
var $ret94569457 = $Hanf_arg25649463($z94529453,A119,anf_fun7259462,k2859449,l2519173);
++R.GAS;
return $ret94569457;
});
var anf_bracket7319448 = G(compile_DASH_env2509172,"bindings",L[1114]);
var anf_fun7329443 = G(anf_bracket7319448,"filter",L[1113]);
var anf_arg7339444 = G(C923,"is-module-bindings",L[1112]);
var $z94359436 = D;
var $f94419442 = function(_) {
return R.isFunction(anf_fun7329443)?anf_fun7329443.app(anf_arg7339444):R.ffi.throwNonFunApp(L[1111],anf_fun7329443,[anf_arg7339444]);
};
try {
if(--R.GAS > 0) {
$z94359436 = $f94419442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94419442,
"from":L[1111]});
}
} catch($e94339434) {
if(R.isCont($e94339434)) {
var $ss94379438 = {"from":L[1111],
"go":function(anf_bracket7349445) {
return $Hanf_bracket25729447(anf_bracket7349445,A119,anf_arg7309446,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrapped2839431,_plus9);
}};
$e94339434.stack[R.EXN_STACKHEIGHT++] = $ss94379438;
}
if(R.isPyretException($e94339434)) {
$e94339434.pyretStack.push(L[1111]);
}
throw $e94339434;
}
var $ret94399440 = $Hanf_bracket25729447($z94359436,A119,anf_arg7309446,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrapped2839431,_plus9);
++R.GAS;
return $ret94399440;
};
var $Hanf_bracket25729447 = function(anf_bracket7349445,A119,anf_arg7309446,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrapped2839431,_plus9) {
var anf_fun7359474 = G(anf_bracket7349445,"map",L[1121]);
var anf_arg7379475 = R.makeFunction(function(recv_DASH_479478) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1120],1,arguments);
}
var ann_DASH_check_DASH_temp7369479 = G(recv_DASH_479478,"name",L[1120]);
return ann_DASH_check_DASH_temp7369479;
});
var $z94669467 = D;
var $f94729473 = function(_) {
return R.isFunction(anf_fun7359474)?anf_fun7359474.app(anf_arg7379475):R.ffi.throwNonFunApp(L[1119],anf_fun7359474,[anf_arg7379475]);
};
try {
if(--R.GAS > 0) {
$z94669467 = $f94729473();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94729473,
"from":L[1119]});
}
} catch($e94649465) {
if(R.isCont($e94649465)) {
var $ss94689469 = {"from":L[1119],
"go":function(anf_arg7389476) {
return $Hanf_arg25719477(anf_arg7389476,A119,anf_arg7309446,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrapped2839431,_plus9);
}};
$e94649465.stack[R.EXN_STACKHEIGHT++] = $ss94689469;
}
if(R.isPyretException($e94649465)) {
$e94649465.pyretStack.push(L[1119]);
}
throw $e94649465;
}
var $ret94709471 = $Hanf_arg25719477($z94669467,A119,anf_arg7309446,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrapped2839431,_plus9);
++R.GAS;
return $ret94709471;
};
var $Hanf_arg25719477 = function(anf_arg7389476,A119,anf_arg7309446,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,map459174,wrapped2839431,_plus9) {
var $z94829483 = D;
var $f94889489 = function(_) {
return R.isFunction(map459174)?map459174.app(anf_arg7309446,anf_arg7389476):R.ffi.throwNonFunApp(L[1115],map459174,[anf_arg7309446,anf_arg7389476]);
};
try {
if(--R.GAS > 0) {
$z94829483 = $f94889489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f94889489,
"from":L[1115]});
}
} catch($e94809481) {
if(R.isCont($e94809481)) {
var $ss94849485 = {"from":L[1115],
"go":function(anf_arg7399490) {
return $Hanf_arg25709491(anf_arg7399490,A119,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,wrapped2839431,_plus9);
}};
$e94809481.stack[R.EXN_STACKHEIGHT++] = $ss94849485;
}
if(R.isPyretException($e94809481)) {
$e94809481.pyretStack.push(L[1115]);
}
throw $e94809481;
}
var $ret94869487 = $Hanf_arg25709491($z94829483,A119,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,wrapped2839431,_plus9);
++R.GAS;
return $ret94869487;
};
var $Hanf_arg25709491 = function(anf_arg7399490,A119,desugar_DASH_scope_DASH_visitor22566,imports2579188,l2519173,wrapped2839431,_plus9) {
var $z94949495 = D;
var $f95009501 = function(_) {
return R.isFunction(_plus9)?_plus9.app(imports2579188,anf_arg7399490):R.ffi.throwNonFunApp(L[1122],_plus9,[imports2579188,anf_arg7399490]);
};
try {
if(--R.GAS > 0) {
$z94949495 = $f95009501();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95009501,
"from":L[1122]});
}
} catch($e94929493) {
if(R.isCont($e94929493)) {
var $ss94969497 = {"from":L[1122],
"go":function(full_DASH_imports2849502) {
return $Hfull_DASH_imports25699503(full_DASH_imports2849502,A119,desugar_DASH_scope_DASH_visitor22566,l2519173,wrapped2839431);
}};
$e94929493.stack[R.EXN_STACKHEIGHT++] = $ss94969497;
}
if(R.isPyretException($e94929493)) {
$e94929493.pyretStack.push(L[1122]);
}
throw $e94929493;
}
var $ret94989499 = $Hfull_DASH_imports25699503($z94949495,A119,desugar_DASH_scope_DASH_visitor22566,l2519173,wrapped2839431);
++R.GAS;
return $ret94989499;
};
var $Hfull_DASH_imports25699503 = function(full_DASH_imports2849502,A119,desugar_DASH_scope_DASH_visitor22566,l2519173,wrapped2839431) {
var anf_fun7409516 = G(A119,"s-program",L[1125]);
var anf_fun7419514 = G(A119,"s-provide-none",L[1124]);
var $z95069507 = D;
var $f95129513 = function(_) {
return R.isFunction(anf_fun7419514)?anf_fun7419514.app(l2519173):R.ffi.throwNonFunApp(L[1123],anf_fun7419514,[l2519173]);
};
try {
if(--R.GAS > 0) {
$z95069507 = $f95129513();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95129513,
"from":L[1123]});
}
} catch($e95049505) {
if(R.isCont($e95049505)) {
var $ss95089509 = {"from":L[1123],
"go":function(anf_arg7429515) {
return $Hanf_arg25689517(anf_arg7429515,A119,anf_fun7409516,desugar_DASH_scope_DASH_visitor22566,full_DASH_imports2849502,l2519173,wrapped2839431);
}};
$e95049505.stack[R.EXN_STACKHEIGHT++] = $ss95089509;
}
if(R.isPyretException($e95049505)) {
$e95049505.pyretStack.push(L[1123]);
}
throw $e95049505;
}
var $ret95109511 = $Hanf_arg25689517($z95069507,A119,anf_fun7409516,desugar_DASH_scope_DASH_visitor22566,full_DASH_imports2849502,l2519173,wrapped2839431);
++R.GAS;
return $ret95109511;
};
var $Hanf_arg25689517 = function(anf_arg7429515,A119,anf_fun7409516,desugar_DASH_scope_DASH_visitor22566,full_DASH_imports2849502,l2519173,wrapped2839431) {
var anf_fun7439528 = G(A119,"s-provide-types-none",L[1127]);
var $z95209521 = D;
var $f95269527 = function(_) {
return R.isFunction(anf_fun7439528)?anf_fun7439528.app(l2519173):R.ffi.throwNonFunApp(L[1126],anf_fun7439528,[l2519173]);
};
try {
if(--R.GAS > 0) {
$z95209521 = $f95269527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95269527,
"from":L[1126]});
}
} catch($e95189519) {
if(R.isCont($e95189519)) {
var $ss95229523 = {"from":L[1126],
"go":function(anf_arg7449529) {
return $Hanf_arg25679530(anf_arg7449529,anf_arg7429515,anf_fun7409516,desugar_DASH_scope_DASH_visitor22566,full_DASH_imports2849502,l2519173,wrapped2839431);
}};
$e95189519.stack[R.EXN_STACKHEIGHT++] = $ss95229523;
}
if(R.isPyretException($e95189519)) {
$e95189519.pyretStack.push(L[1126]);
}
throw $e95189519;
}
var $ret95249525 = $Hanf_arg25679530($z95209521,anf_arg7429515,anf_fun7409516,desugar_DASH_scope_DASH_visitor22566,full_DASH_imports2849502,l2519173,wrapped2839431);
++R.GAS;
return $ret95249525;
};
var $Hanf_arg25679530 = function(anf_arg7449529,anf_arg7429515,anf_fun7409516,desugar_DASH_scope_DASH_visitor22566,full_DASH_imports2849502,l2519173,wrapped2839431) {
var anf_fun7459541 = G(wrapped2839431,"visit",L[1129]);
var $z95339534 = D;
var $f95399540 = function(_) {
return R.isFunction(anf_fun7459541)?anf_fun7459541.app(desugar_DASH_scope_DASH_visitor22566):R.ffi.throwNonFunApp(L[1128],anf_fun7459541,[desugar_DASH_scope_DASH_visitor22566]);
};
try {
if(--R.GAS > 0) {
$z95339534 = $f95399540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95399540,
"from":L[1128]});
}
} catch($e95319532) {
if(R.isCont($e95319532)) {
var $ss95359536 = {"from":L[1128],
"go":function(anf_arg7469542) {
return $Hanf_arg25669543(anf_arg7469542,anf_arg7429515,anf_arg7449529,anf_fun7409516,full_DASH_imports2849502,l2519173);
}};
$e95319532.stack[R.EXN_STACKHEIGHT++] = $ss95359536;
}
if(R.isPyretException($e95319532)) {
$e95319532.pyretStack.push(L[1128]);
}
throw $e95319532;
}
var $ret95379538 = $Hanf_arg25669543($z95339534,anf_arg7429515,anf_arg7449529,anf_fun7409516,full_DASH_imports2849502,l2519173);
++R.GAS;
return $ret95379538;
};
var $Hanf_arg25669543 = function(anf_arg7469542,anf_arg7429515,anf_arg7449529,anf_fun7409516,full_DASH_imports2849502,l2519173) {
var $z95469547 = D;
var $f95529553 = function(_) {
return R.isFunction(anf_fun7409516)?anf_fun7409516.app(l2519173,anf_arg7429515,anf_arg7449529,full_DASH_imports2849502,anf_arg7469542):R.ffi.throwNonFunApp(L[1130],anf_fun7409516,[l2519173,anf_arg7429515,anf_arg7449529,full_DASH_imports2849502,anf_arg7469542]);
};
try {
if(--R.GAS > 0) {
$z95469547 = $f95529553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95529553,
"from":L[1130]});
}
} catch($e95449545) {
if(R.isCont($e95449545)) {
var $ss95489549 = {"from":L[1130],
"go":function(ann_DASH_check_DASH_temp6269554) {
return $Hann_DASH_check_DASH_temp25659555(ann_DASH_check_DASH_temp6269554);
}};
$e95449545.stack[R.EXN_STACKHEIGHT++] = $ss95489549;
}
if(R.isPyretException($e95449545)) {
$e95449545.pyretStack.push(L[1130]);
}
throw $e95449545;
}
var $ret95509551 = $Hann_DASH_check_DASH_temp25659555($z95469547);
++R.GAS;
return $ret95509551;
};
var $Hann_DASH_check_DASH_temp25659555 = function(ann_DASH_check_DASH_temp6269554) {
return ann_DASH_check_DASH_temp6269554;
};
var $Hanf_arg25649463 = function(anf_arg7279461,A119,anf_fun7259462,k2859449,l2519173) {
var anf_fun7289566 = G(A119,"s-name",L[1132]);
var $z95589559 = D;
var $f95649565 = function(_) {
return R.isFunction(anf_fun7289566)?anf_fun7289566.app(l2519173,k2859449):R.ffi.throwNonFunApp(L[1131],anf_fun7289566,[l2519173,k2859449]);
};
try {
if(--R.GAS > 0) {
$z95589559 = $f95649565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95649565,
"from":L[1131]});
}
} catch($e95569557) {
if(R.isCont($e95569557)) {
var $ss95609561 = {"from":L[1131],
"go":function(anf_arg7299567) {
return $Hanf_arg25639568(anf_arg7299567,anf_arg7279461,anf_fun7259462,l2519173);
}};
$e95569557.stack[R.EXN_STACKHEIGHT++] = $ss95609561;
}
if(R.isPyretException($e95569557)) {
$e95569557.pyretStack.push(L[1131]);
}
throw $e95569557;
}
var $ret95629563 = $Hanf_arg25639568($z95589559,anf_arg7279461,anf_fun7259462,l2519173);
++R.GAS;
return $ret95629563;
};
var $Hanf_arg25639568 = function(anf_arg7299567,anf_arg7279461,anf_fun7259462,l2519173) {
var $z95719572 = D;
var $f95779578 = function(_) {
return R.isFunction(anf_fun7259462)?anf_fun7259462.app(l2519173,anf_arg7279461,anf_arg7299567):R.ffi.throwNonFunApp(L[1115],anf_fun7259462,[l2519173,anf_arg7279461,anf_arg7299567]);
};
try {
if(--R.GAS > 0) {
$z95719572 = $f95779578();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95779578,
"from":L[1115]});
}
} catch($e95699570) {
if(R.isCont($e95699570)) {
var $ss95739574 = {"from":L[1115],
"go":function(ann_DASH_check_DASH_temp7249579) {
return $Hann_DASH_check_DASH_temp25629580(ann_DASH_check_DASH_temp7249579);
}};
$e95699570.stack[R.EXN_STACKHEIGHT++] = $ss95739574;
}
if(R.isPyretException($e95699570)) {
$e95699570.pyretStack.push(L[1115]);
}
throw $e95699570;
}
var $ret95759576 = $Hann_DASH_check_DASH_temp25629580($z95719572);
++R.GAS;
return $ret95759576;
};
var $Hann_DASH_check_DASH_temp25629580 = function(ann_DASH_check_DASH_temp7249579) {
return ann_DASH_check_DASH_temp7249579;
};
var $Hann_DASH_check_DASH_temp25619385 = function(ann_DASH_check_DASH_temp7229384) {
return ann_DASH_check_DASH_temp7229384;
};
var $Hlast25609401 = function(last2789400,A119,l22769387,list3375,stmts2779388,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9) {
var cases_DASH_val459629 = last2789400;
var anf_fun6779591 = G(cases_DASH_val459629,"_match",L[1133]);
var anf_obj7069611 = R.makeFunction(function(l32799612,binds2809613,body22819614) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1138],3,arguments);
}
var anf_bracket6799628 = G(body22819614,"stmts",L[1141]);
var anf_fun6809625 = G(anf_bracket6799628,"last",L[1140]);
var $z96179618 = D;
var $f96239624 = function(_) {
return R.isFunction(anf_fun6809625)?anf_fun6809625.app():R.ffi.throwNonFunApp(L[1139],anf_fun6809625,[]);
};
try {
if(--R.GAS > 0) {
$z96179618 = $f96239624();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96239624,
"from":L[1139]});
}
} catch($e96159616) {
if(R.isCont($e96159616)) {
var $ss96199620 = {"from":L[1139],
"go":function(inner_DASH_last2829626) {
return $Hinner_DASH_last25519627(inner_DASH_last2829626,A119,binds2809613,body22819614,l22769387,l32799612,list3375,stmts2779388,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
}};
$e96159616.stack[R.EXN_STACKHEIGHT++] = $ss96199620;
}
if(R.isPyretException($e96159616)) {
$e96159616.pyretStack.push(L[1139]);
}
throw $e96159616;
}
var $ret96219622 = $Hinner_DASH_last25519627($z96179618,A119,binds2809613,body22819614,l22769387,l32799612,list3375,stmts2779388,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
++R.GAS;
return $ret96219622;
});
var anf_arg7079592 = R.makeObject({"s-type-let-expr":anf_obj7069611});
var anf_arg7199593 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1133],0,arguments);
}
var anf_fun7099608 = G(A119,"s-block",L[1137]);
var anf_fun7109609 = G(stmts2779388,"take",L[1136]);
var anf_fun7119606 = G(stmts2779388,"length",L[1135]);
var $z95989599 = D;
var $f96049605 = function(_) {
return R.isFunction(anf_fun7119606)?anf_fun7119606.app():R.ffi.throwNonFunApp(L[1134],anf_fun7119606,[]);
};
try {
if(--R.GAS > 0) {
$z95989599 = $f96049605();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96049605,
"from":L[1134]});
}
} catch($e95969597) {
if(R.isCont($e95969597)) {
var $ss96009601 = {"from":L[1134],
"go":function(anf_arg7129607) {
return $Hanf_arg25589610(anf_arg7129607,anf_fun7099608,anf_fun7109609,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
}};
$e95969597.stack[R.EXN_STACKHEIGHT++] = $ss96009601;
}
if(R.isPyretException($e95969597)) {
$e95969597.pyretStack.push(L[1134]);
}
throw $e95969597;
}
var $ret96029603 = $Hanf_arg25589610($z95989599,anf_fun7099608,anf_fun7109609,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
++R.GAS;
return $ret96029603;
});
var $z95839584 = D;
var $f95899590 = function(_) {
return R.isFunction(anf_fun6779591)?anf_fun6779591.app(anf_arg7079592,anf_arg7199593):R.ffi.throwNonFunApp(L[1101],anf_fun6779591,[anf_arg7079592,anf_arg7199593]);
};
try {
if(--R.GAS > 0) {
$z95839584 = $f95899590();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f95899590,
"from":L[1101]});
}
} catch($e95819582) {
if(R.isCont($e95819582)) {
var $ss95859586 = {"from":L[1101],
"go":function(ann_DASH_check_DASH_temp6759594) {
return $Hann_DASH_check_DASH_temp25599595(ann_DASH_check_DASH_temp6759594);
}};
$e95819582.stack[R.EXN_STACKHEIGHT++] = $ss95859586;
}
if(R.isPyretException($e95819582)) {
$e95819582.pyretStack.push(L[1101]);
}
throw $e95819582;
}
var $ret95879588 = $Hann_DASH_check_DASH_temp25599595($z95839584);
++R.GAS;
return $ret95879588;
};
var $Hann_DASH_check_DASH_temp25599595 = function(ann_DASH_check_DASH_temp6759594) {
return ann_DASH_check_DASH_temp6759594;
};
var $Hanf_arg25589610 = function(anf_arg7129607,anf_fun7099608,anf_fun7109609,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9) {
var $z96329633 = D;
var $f96389639 = function(_) {
return R.isFunction(_minus8)?_minus8.app(anf_arg7129607,(1)):R.ffi.throwNonFunApp(L[1142],_minus8,[anf_arg7129607,(1)]);
};
try {
if(--R.GAS > 0) {
$z96329633 = $f96389639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96389639,
"from":L[1142]});
}
} catch($e96309631) {
if(R.isCont($e96309631)) {
var $ss96349635 = {"from":L[1142],
"go":function(anf_arg7139640) {
return $Hanf_arg25579641(anf_arg7139640,anf_fun7099608,anf_fun7109609,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9);
}};
$e96309631.stack[R.EXN_STACKHEIGHT++] = $ss96349635;
}
if(R.isPyretException($e96309631)) {
$e96309631.pyretStack.push(L[1142]);
}
throw $e96309631;
}
var $ret96369637 = $Hanf_arg25579641($z96329633,anf_fun7099608,anf_fun7109609,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9);
++R.GAS;
return $ret96369637;
};
var $Hanf_arg25579641 = function(anf_arg7139640,anf_fun7099608,anf_fun7109609,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9) {
var $z96449645 = D;
var $f96509651 = function(_) {
return R.isFunction(anf_fun7109609)?anf_fun7109609.app(anf_arg7139640):R.ffi.throwNonFunApp(L[1143],anf_fun7109609,[anf_arg7139640]);
};
try {
if(--R.GAS > 0) {
$z96449645 = $f96509651();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96509651,
"from":L[1143]});
}
} catch($e96429643) {
if(R.isCont($e96429643)) {
var $ss96469647 = {"from":L[1143],
"go":function(anf_arg7149652) {
return $Hanf_arg25569653(anf_arg7149652,anf_fun7099608,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9);
}};
$e96429643.stack[R.EXN_STACKHEIGHT++] = $ss96469647;
}
if(R.isPyretException($e96429643)) {
$e96429643.pyretStack.push(L[1143]);
}
throw $e96429643;
}
var $ret96489649 = $Hanf_arg25569653($z96449645,anf_fun7099608,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9);
++R.GAS;
return $ret96489649;
};
var $Hanf_arg25569653 = function(anf_arg7149652,anf_fun7099608,l22769387,last2789400,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9) {
var anf_fun7159665 = G(list3375,"make",L[1145]);
var $z96569657 = D;
var $f96629663 = function(_) {
return R.isFunction(transform_DASH_toplevel_DASH_last2729357.$var)?transform_DASH_toplevel_DASH_last2729357.$var.app(l22769387,last2789400):R.ffi.throwNonFunApp(L[1144],transform_DASH_toplevel_DASH_last2729357.$var,[l22769387,last2789400]);
};
try {
if(--R.GAS > 0) {
$z96569657 = $f96629663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96629663,
"from":L[1144]});
}
} catch($e96549655) {
if(R.isCont($e96549655)) {
var $ss96589659 = {"from":L[1144],
"go":function(anf_array_val7169664) {
return $Hanf_array_val25559666(anf_array_val7169664,anf_arg7149652,anf_fun7099608,anf_fun7159665,l22769387,_plus9);
}};
$e96549655.stack[R.EXN_STACKHEIGHT++] = $ss96589659;
}
if(R.isPyretException($e96549655)) {
$e96549655.pyretStack.push(L[1144]);
}
throw $e96549655;
}
var $ret96609661 = $Hanf_array_val25559666($z96569657,anf_arg7149652,anf_fun7099608,anf_fun7159665,l22769387,_plus9);
++R.GAS;
return $ret96609661;
};
var $Hanf_array_val25559666 = function(anf_array_val7169664,anf_arg7149652,anf_fun7099608,anf_fun7159665,l22769387,_plus9) {
var $z96699670 = D;
var $f96759676 = function(_) {
return R.isFunction(anf_fun7159665)?anf_fun7159665.app([anf_array_val7169664]):R.ffi.throwNonFunApp(L[1145],anf_fun7159665,[[anf_array_val7169664]]);
};
try {
if(--R.GAS > 0) {
$z96699670 = $f96759676();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96759676,
"from":L[1145]});
}
} catch($e96679668) {
if(R.isCont($e96679668)) {
var $ss96719672 = {"from":L[1145],
"go":function(anf_arg7179677) {
return $Hanf_arg25549678(anf_arg7179677,anf_arg7149652,anf_fun7099608,l22769387,_plus9);
}};
$e96679668.stack[R.EXN_STACKHEIGHT++] = $ss96719672;
}
if(R.isPyretException($e96679668)) {
$e96679668.pyretStack.push(L[1145]);
}
throw $e96679668;
}
var $ret96739674 = $Hanf_arg25549678($z96699670,anf_arg7149652,anf_fun7099608,l22769387,_plus9);
++R.GAS;
return $ret96739674;
};
var $Hanf_arg25549678 = function(anf_arg7179677,anf_arg7149652,anf_fun7099608,l22769387,_plus9) {
var $z96819682 = D;
var $f96879688 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg7149652,anf_arg7179677):R.ffi.throwNonFunApp(L[1146],_plus9,[anf_arg7149652,anf_arg7179677]);
};
try {
if(--R.GAS > 0) {
$z96819682 = $f96879688();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96879688,
"from":L[1146]});
}
} catch($e96799680) {
if(R.isCont($e96799680)) {
var $ss96839684 = {"from":L[1146],
"go":function(anf_arg7189689) {
return $Hanf_arg25539690(anf_arg7189689,anf_fun7099608,l22769387);
}};
$e96799680.stack[R.EXN_STACKHEIGHT++] = $ss96839684;
}
if(R.isPyretException($e96799680)) {
$e96799680.pyretStack.push(L[1146]);
}
throw $e96799680;
}
var $ret96859686 = $Hanf_arg25539690($z96819682,anf_fun7099608,l22769387);
++R.GAS;
return $ret96859686;
};
var $Hanf_arg25539690 = function(anf_arg7189689,anf_fun7099608,l22769387) {
var $z96939694 = D;
var $f96999700 = function(_) {
return R.isFunction(anf_fun7099608)?anf_fun7099608.app(l22769387,anf_arg7189689):R.ffi.throwNonFunApp(L[1133],anf_fun7099608,[l22769387,anf_arg7189689]);
};
try {
if(--R.GAS > 0) {
$z96939694 = $f96999700();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f96999700,
"from":L[1133]});
}
} catch($e96919692) {
if(R.isCont($e96919692)) {
var $ss96959696 = {"from":L[1133],
"go":function(ann_DASH_check_DASH_temp7089701) {
return $Hann_DASH_check_DASH_temp25529702(ann_DASH_check_DASH_temp7089701);
}};
$e96919692.stack[R.EXN_STACKHEIGHT++] = $ss96959696;
}
if(R.isPyretException($e96919692)) {
$e96919692.pyretStack.push(L[1133]);
}
throw $e96919692;
}
var $ret96979698 = $Hann_DASH_check_DASH_temp25529702($z96939694);
++R.GAS;
return $ret96979698;
};
var $Hann_DASH_check_DASH_temp25529702 = function(ann_DASH_check_DASH_temp7089701) {
return ann_DASH_check_DASH_temp7089701;
};
var $Hinner_DASH_last25519627 = function(inner_DASH_last2829626,A119,binds2809613,body22819614,l22769387,l32799612,list3375,stmts2779388,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9) {
var anf_fun6819715 = G(A119,"s-block",L[1150]);
var anf_fun6829716 = G(stmts2779388,"take",L[1149]);
var anf_fun6839713 = G(stmts2779388,"length",L[1148]);
var $z97059706 = D;
var $f97119712 = function(_) {
return R.isFunction(anf_fun6839713)?anf_fun6839713.app():R.ffi.throwNonFunApp(L[1147],anf_fun6839713,[]);
};
try {
if(--R.GAS > 0) {
$z97059706 = $f97119712();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97119712,
"from":L[1147]});
}
} catch($e97039704) {
if(R.isCont($e97039704)) {
var $ss97079708 = {"from":L[1147],
"go":function(anf_arg6849714) {
return $Hanf_arg25509717(anf_arg6849714,A119,anf_fun6819715,anf_fun6829716,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
}};
$e97039704.stack[R.EXN_STACKHEIGHT++] = $ss97079708;
}
if(R.isPyretException($e97039704)) {
$e97039704.pyretStack.push(L[1147]);
}
throw $e97039704;
}
var $ret97099710 = $Hanf_arg25509717($z97059706,A119,anf_fun6819715,anf_fun6829716,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
++R.GAS;
return $ret97099710;
};
var $Hanf_arg25509717 = function(anf_arg6849714,A119,anf_fun6819715,anf_fun6829716,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9) {
var $z97209721 = D;
var $f97269727 = function(_) {
return R.isFunction(_minus8)?_minus8.app(anf_arg6849714,(1)):R.ffi.throwNonFunApp(L[1151],_minus8,[anf_arg6849714,(1)]);
};
try {
if(--R.GAS > 0) {
$z97209721 = $f97269727();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97269727,
"from":L[1151]});
}
} catch($e97189719) {
if(R.isCont($e97189719)) {
var $ss97229723 = {"from":L[1151],
"go":function(anf_arg6859728) {
return $Hanf_arg25499729(anf_arg6859728,A119,anf_fun6819715,anf_fun6829716,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
}};
$e97189719.stack[R.EXN_STACKHEIGHT++] = $ss97229723;
}
if(R.isPyretException($e97189719)) {
$e97189719.pyretStack.push(L[1151]);
}
throw $e97189719;
}
var $ret97249725 = $Hanf_arg25499729($z97209721,A119,anf_fun6819715,anf_fun6829716,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
++R.GAS;
return $ret97249725;
};
var $Hanf_arg25499729 = function(anf_arg6859728,A119,anf_fun6819715,anf_fun6829716,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9) {
var $z97329733 = D;
var $f97389739 = function(_) {
return R.isFunction(anf_fun6829716)?anf_fun6829716.app(anf_arg6859728):R.ffi.throwNonFunApp(L[1152],anf_fun6829716,[anf_arg6859728]);
};
try {
if(--R.GAS > 0) {
$z97329733 = $f97389739();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97389739,
"from":L[1152]});
}
} catch($e97309731) {
if(R.isCont($e97309731)) {
var $ss97349735 = {"from":L[1152],
"go":function(anf_arg6869740) {
return $Hanf_arg25489741(anf_arg6869740,A119,anf_fun6819715,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
}};
$e97309731.stack[R.EXN_STACKHEIGHT++] = $ss97349735;
}
if(R.isPyretException($e97309731)) {
$e97309731.pyretStack.push(L[1152]);
}
throw $e97309731;
}
var $ret97369737 = $Hanf_arg25489741($z97329733,A119,anf_fun6819715,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
++R.GAS;
return $ret97369737;
};
var $Hanf_arg25489741 = function(anf_arg6869740,A119,anf_fun6819715,binds2809613,body22819614,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9) {
var anf_fun6879755 = G(list3375,"make",L[1161]);
var anf_fun6889756 = G(A119,"s-type-let-expr",L[1160]);
var anf_fun6899757 = G(A119,"s-block",L[1159]);
var anf_arg6909754 = G(body22819614,"l",L[1158]);
var anf_bracket6919761 = G(body22819614,"stmts",L[1157]);
var anf_fun6929758 = G(anf_bracket6919761,"take",L[1156]);
var anf_bracket6939760 = G(body22819614,"stmts",L[1155]);
var anf_fun6949752 = G(anf_bracket6939760,"length",L[1154]);
var $z97449745 = D;
var $f97509751 = function(_) {
return R.isFunction(anf_fun6949752)?anf_fun6949752.app():R.ffi.throwNonFunApp(L[1153],anf_fun6949752,[]);
};
try {
if(--R.GAS > 0) {
$z97449745 = $f97509751();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97509751,
"from":L[1153]});
}
} catch($e97429743) {
if(R.isCont($e97429743)) {
var $ss97469747 = {"from":L[1153],
"go":function(anf_arg6959753) {
return $Hanf_arg25479759(anf_arg6959753,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6929758,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
}};
$e97429743.stack[R.EXN_STACKHEIGHT++] = $ss97469747;
}
if(R.isPyretException($e97429743)) {
$e97429743.pyretStack.push(L[1153]);
}
throw $e97429743;
}
var $ret97489749 = $Hanf_arg25479759($z97449745,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6929758,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9);
++R.GAS;
return $ret97489749;
};
var $Hanf_arg25479759 = function(anf_arg6959753,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6929758,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_minus8,_plus9) {
var $z97649765 = D;
var $f97709771 = function(_) {
return R.isFunction(_minus8)?_minus8.app(anf_arg6959753,(1)):R.ffi.throwNonFunApp(L[1162],_minus8,[anf_arg6959753,(1)]);
};
try {
if(--R.GAS > 0) {
$z97649765 = $f97709771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97709771,
"from":L[1162]});
}
} catch($e97629763) {
if(R.isCont($e97629763)) {
var $ss97669767 = {"from":L[1162],
"go":function(anf_arg6969772) {
return $Hanf_arg25469773(anf_arg6969772,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6929758,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9);
}};
$e97629763.stack[R.EXN_STACKHEIGHT++] = $ss97669767;
}
if(R.isPyretException($e97629763)) {
$e97629763.pyretStack.push(L[1162]);
}
throw $e97629763;
}
var $ret97689769 = $Hanf_arg25469773($z97649765,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6929758,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9);
++R.GAS;
return $ret97689769;
};
var $Hanf_arg25469773 = function(anf_arg6969772,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6929758,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9) {
var $z97769777 = D;
var $f97829783 = function(_) {
return R.isFunction(anf_fun6929758)?anf_fun6929758.app(anf_arg6969772):R.ffi.throwNonFunApp(L[1163],anf_fun6929758,[anf_arg6969772]);
};
try {
if(--R.GAS > 0) {
$z97769777 = $f97829783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97829783,
"from":L[1163]});
}
} catch($e97749775) {
if(R.isCont($e97749775)) {
var $ss97789779 = {"from":L[1163],
"go":function(anf_arg6979784) {
return $Hanf_arg25459785(anf_arg6979784,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9);
}};
$e97749775.stack[R.EXN_STACKHEIGHT++] = $ss97789779;
}
if(R.isPyretException($e97749775)) {
$e97749775.pyretStack.push(L[1163]);
}
throw $e97749775;
}
var $ret97809781 = $Hanf_arg25459785($z97769777,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9);
++R.GAS;
return $ret97809781;
};
var $Hanf_arg25459785 = function(anf_arg6979784,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,inner_DASH_last2829626,l22769387,l32799612,list3375,transform_DASH_toplevel_DASH_last2729357,_plus9) {
var anf_fun6989797 = G(list3375,"make",L[1165]);
var $z97889789 = D;
var $f97949795 = function(_) {
return R.isFunction(transform_DASH_toplevel_DASH_last2729357.$var)?transform_DASH_toplevel_DASH_last2729357.$var.app(l32799612,inner_DASH_last2829626):R.ffi.throwNonFunApp(L[1164],transform_DASH_toplevel_DASH_last2729357.$var,[l32799612,inner_DASH_last2829626]);
};
try {
if(--R.GAS > 0) {
$z97889789 = $f97949795();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f97949795,
"from":L[1164]});
}
} catch($e97869787) {
if(R.isCont($e97869787)) {
var $ss97909791 = {"from":L[1164],
"go":function(anf_array_val6999796) {
return $Hanf_array_val25449798(anf_array_val6999796,anf_arg6869740,anf_arg6909754,anf_arg6979784,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6989797,binds2809613,l22769387,l32799612,_plus9);
}};
$e97869787.stack[R.EXN_STACKHEIGHT++] = $ss97909791;
}
if(R.isPyretException($e97869787)) {
$e97869787.pyretStack.push(L[1164]);
}
throw $e97869787;
}
var $ret97929793 = $Hanf_array_val25449798($z97889789,anf_arg6869740,anf_arg6909754,anf_arg6979784,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6989797,binds2809613,l22769387,l32799612,_plus9);
++R.GAS;
return $ret97929793;
};
var $Hanf_array_val25449798 = function(anf_array_val6999796,anf_arg6869740,anf_arg6909754,anf_arg6979784,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,anf_fun6989797,binds2809613,l22769387,l32799612,_plus9) {
var $z98019802 = D;
var $f98079808 = function(_) {
return R.isFunction(anf_fun6989797)?anf_fun6989797.app([anf_array_val6999796]):R.ffi.throwNonFunApp(L[1165],anf_fun6989797,[[anf_array_val6999796]]);
};
try {
if(--R.GAS > 0) {
$z98019802 = $f98079808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98079808,
"from":L[1165]});
}
} catch($e97999800) {
if(R.isCont($e97999800)) {
var $ss98039804 = {"from":L[1165],
"go":function(anf_arg7009809) {
return $Hanf_arg25439810(anf_arg7009809,anf_arg6869740,anf_arg6909754,anf_arg6979784,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,l22769387,l32799612,_plus9);
}};
$e97999800.stack[R.EXN_STACKHEIGHT++] = $ss98039804;
}
if(R.isPyretException($e97999800)) {
$e97999800.pyretStack.push(L[1165]);
}
throw $e97999800;
}
var $ret98059806 = $Hanf_arg25439810($z98019802,anf_arg6869740,anf_arg6909754,anf_arg6979784,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,l22769387,l32799612,_plus9);
++R.GAS;
return $ret98059806;
};
var $Hanf_arg25439810 = function(anf_arg7009809,anf_arg6869740,anf_arg6909754,anf_arg6979784,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,l22769387,l32799612,_plus9) {
var $z98139814 = D;
var $f98199820 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg6979784,anf_arg7009809):R.ffi.throwNonFunApp(L[1166],_plus9,[anf_arg6979784,anf_arg7009809]);
};
try {
if(--R.GAS > 0) {
$z98139814 = $f98199820();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98199820,
"from":L[1166]});
}
} catch($e98119812) {
if(R.isCont($e98119812)) {
var $ss98159816 = {"from":L[1166],
"go":function(anf_arg7019821) {
return $Hanf_arg25429822(anf_arg7019821,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,l22769387,l32799612,_plus9);
}};
$e98119812.stack[R.EXN_STACKHEIGHT++] = $ss98159816;
}
if(R.isPyretException($e98119812)) {
$e98119812.pyretStack.push(L[1166]);
}
throw $e98119812;
}
var $ret98179818 = $Hanf_arg25429822($z98139814,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,l22769387,l32799612,_plus9);
++R.GAS;
return $ret98179818;
};
var $Hanf_arg25429822 = function(anf_arg7019821,anf_arg6869740,anf_arg6909754,anf_fun6819715,anf_fun6879755,anf_fun6889756,anf_fun6899757,binds2809613,l22769387,l32799612,_plus9) {
var $z98259826 = D;
var $f98319832 = function(_) {
return R.isFunction(anf_fun6899757)?anf_fun6899757.app(anf_arg6909754,anf_arg7019821):R.ffi.throwNonFunApp(L[1167],anf_fun6899757,[anf_arg6909754,anf_arg7019821]);
};
try {
if(--R.GAS > 0) {
$z98259826 = $f98319832();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98319832,
"from":L[1167]});
}
} catch($e98239824) {
if(R.isCont($e98239824)) {
var $ss98279828 = {"from":L[1167],
"go":function(anf_arg7029833) {
return $Hanf_arg25419834(anf_arg7029833,anf_arg6869740,anf_fun6819715,anf_fun6879755,anf_fun6889756,binds2809613,l22769387,l32799612,_plus9);
}};
$e98239824.stack[R.EXN_STACKHEIGHT++] = $ss98279828;
}
if(R.isPyretException($e98239824)) {
$e98239824.pyretStack.push(L[1167]);
}
throw $e98239824;
}
var $ret98299830 = $Hanf_arg25419834($z98259826,anf_arg6869740,anf_fun6819715,anf_fun6879755,anf_fun6889756,binds2809613,l22769387,l32799612,_plus9);
++R.GAS;
return $ret98299830;
};
var $Hanf_arg25419834 = function(anf_arg7029833,anf_arg6869740,anf_fun6819715,anf_fun6879755,anf_fun6889756,binds2809613,l22769387,l32799612,_plus9) {
var $z98379838 = D;
var $f98439844 = function(_) {
return R.isFunction(anf_fun6889756)?anf_fun6889756.app(l32799612,binds2809613,anf_arg7029833):R.ffi.throwNonFunApp(L[1168],anf_fun6889756,[l32799612,binds2809613,anf_arg7029833]);
};
try {
if(--R.GAS > 0) {
$z98379838 = $f98439844();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98439844,
"from":L[1168]});
}
} catch($e98359836) {
if(R.isCont($e98359836)) {
var $ss98399840 = {"from":L[1168],
"go":function(anf_array_val7039845) {
return $Hanf_array_val25409846(anf_array_val7039845,anf_arg6869740,anf_fun6819715,anf_fun6879755,l22769387,_plus9);
}};
$e98359836.stack[R.EXN_STACKHEIGHT++] = $ss98399840;
}
if(R.isPyretException($e98359836)) {
$e98359836.pyretStack.push(L[1168]);
}
throw $e98359836;
}
var $ret98419842 = $Hanf_array_val25409846($z98379838,anf_arg6869740,anf_fun6819715,anf_fun6879755,l22769387,_plus9);
++R.GAS;
return $ret98419842;
};
var $Hanf_array_val25409846 = function(anf_array_val7039845,anf_arg6869740,anf_fun6819715,anf_fun6879755,l22769387,_plus9) {
var $z98499850 = D;
var $f98559856 = function(_) {
return R.isFunction(anf_fun6879755)?anf_fun6879755.app([anf_array_val7039845]):R.ffi.throwNonFunApp(L[1161],anf_fun6879755,[[anf_array_val7039845]]);
};
try {
if(--R.GAS > 0) {
$z98499850 = $f98559856();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98559856,
"from":L[1161]});
}
} catch($e98479848) {
if(R.isCont($e98479848)) {
var $ss98519852 = {"from":L[1161],
"go":function(anf_arg7049857) {
return $Hanf_arg25399858(anf_arg7049857,anf_arg6869740,anf_fun6819715,l22769387,_plus9);
}};
$e98479848.stack[R.EXN_STACKHEIGHT++] = $ss98519852;
}
if(R.isPyretException($e98479848)) {
$e98479848.pyretStack.push(L[1161]);
}
throw $e98479848;
}
var $ret98539854 = $Hanf_arg25399858($z98499850,anf_arg6869740,anf_fun6819715,l22769387,_plus9);
++R.GAS;
return $ret98539854;
};
var $Hanf_arg25399858 = function(anf_arg7049857,anf_arg6869740,anf_fun6819715,l22769387,_plus9) {
var $z98619862 = D;
var $f98679868 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg6869740,anf_arg7049857):R.ffi.throwNonFunApp(L[1169],_plus9,[anf_arg6869740,anf_arg7049857]);
};
try {
if(--R.GAS > 0) {
$z98619862 = $f98679868();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98679868,
"from":L[1169]});
}
} catch($e98599860) {
if(R.isCont($e98599860)) {
var $ss98639864 = {"from":L[1169],
"go":function(anf_arg7059869) {
return $Hanf_arg25389870(anf_arg7059869,anf_fun6819715,l22769387);
}};
$e98599860.stack[R.EXN_STACKHEIGHT++] = $ss98639864;
}
if(R.isPyretException($e98599860)) {
$e98599860.pyretStack.push(L[1169]);
}
throw $e98599860;
}
var $ret98659866 = $Hanf_arg25389870($z98619862,anf_fun6819715,l22769387);
++R.GAS;
return $ret98659866;
};
var $Hanf_arg25389870 = function(anf_arg7059869,anf_fun6819715,l22769387) {
var $z98739874 = D;
var $f98799880 = function(_) {
return R.isFunction(anf_fun6819715)?anf_fun6819715.app(l22769387,anf_arg7059869):R.ffi.throwNonFunApp(L[1138],anf_fun6819715,[l22769387,anf_arg7059869]);
};
try {
if(--R.GAS > 0) {
$z98739874 = $f98799880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98799880,
"from":L[1138]});
}
} catch($e98719872) {
if(R.isCont($e98719872)) {
var $ss98759876 = {"from":L[1138],
"go":function(ann_DASH_check_DASH_temp6789881) {
return $Hann_DASH_check_DASH_temp25379882(ann_DASH_check_DASH_temp6789881);
}};
$e98719872.stack[R.EXN_STACKHEIGHT++] = $ss98759876;
}
if(R.isPyretException($e98719872)) {
$e98719872.pyretStack.push(L[1138]);
}
throw $e98719872;
}
var $ret98779878 = $Hann_DASH_check_DASH_temp25379882($z98739874);
++R.GAS;
return $ret98779878;
};
var $Hann_DASH_check_DASH_temp25379882 = function(ann_DASH_check_DASH_temp6789881) {
return ann_DASH_check_DASH_temp6789881;
};
var $Hanf_arg25369420 = function(anf_arg6709416,anf_fun6669417,anf_fun6679418,anf_fun6689419,empty3670,l22739403,last2749404,prov2609218,provt2659277) {
var $z98859886 = D;
var $f98919892 = function(_) {
return R.isFunction(anf_fun6689419)?anf_fun6689419.app(l22739403,anf_arg6709416,("results")):R.ffi.throwNonFunApp(L[1170],anf_fun6689419,[l22739403,anf_arg6709416,("results")]);
};
try {
if(--R.GAS > 0) {
$z98859886 = $f98919892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f98919892,
"from":L[1170]});
}
} catch($e98839884) {
if(R.isCont($e98839884)) {
var $ss98879888 = {"from":L[1170],
"go":function(anf_arg6719893) {
return $Hanf_arg25359894(anf_arg6719893,anf_fun6669417,anf_fun6679418,empty3670,l22739403,last2749404,prov2609218,provt2659277);
}};
$e98839884.stack[R.EXN_STACKHEIGHT++] = $ss98879888;
}
if(R.isPyretException($e98839884)) {
$e98839884.pyretStack.push(L[1170]);
}
throw $e98839884;
}
var $ret98899890 = $Hanf_arg25359894($z98859886,anf_fun6669417,anf_fun6679418,empty3670,l22739403,last2749404,prov2609218,provt2659277);
++R.GAS;
return $ret98899890;
};
var $Hanf_arg25359894 = function(anf_arg6719893,anf_fun6669417,anf_fun6679418,empty3670,l22739403,last2749404,prov2609218,provt2659277) {
var $z98979898 = D;
var $f99039904 = function(_) {
return R.isFunction(anf_fun6679418)?anf_fun6679418.app(l22739403,anf_arg6719893,empty3670):R.ffi.throwNonFunApp(L[1171],anf_fun6679418,[l22739403,anf_arg6719893,empty3670]);
};
try {
if(--R.GAS > 0) {
$z98979898 = $f99039904();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99039904,
"from":L[1171]});
}
} catch($e98959896) {
if(R.isCont($e98959896)) {
var $ss98999900 = {"from":L[1171],
"go":function(anf_arg6729905) {
return $Hanf_arg25349906(anf_arg6729905,anf_fun6669417,l22739403,last2749404,prov2609218,provt2659277);
}};
$e98959896.stack[R.EXN_STACKHEIGHT++] = $ss98999900;
}
if(R.isPyretException($e98959896)) {
$e98959896.pyretStack.push(L[1171]);
}
throw $e98959896;
}
var $ret99019902 = $Hanf_arg25349906($z98979898,anf_fun6669417,l22739403,last2749404,prov2609218,provt2659277);
++R.GAS;
return $ret99019902;
};
var $Hanf_arg25349906 = function(anf_arg6729905,anf_fun6669417,l22739403,last2749404,prov2609218,provt2659277) {
var $z99099910 = D;
var $f99159916 = function(_) {
return R.isFunction(anf_fun6669417)?anf_fun6669417.app(l22739403,last2749404,prov2609218,provt2659277,anf_arg6729905):R.ffi.throwNonFunApp(L[1104],anf_fun6669417,[l22739403,last2749404,prov2609218,provt2659277,anf_arg6729905]);
};
try {
if(--R.GAS > 0) {
$z99099910 = $f99159916();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99159916,
"from":L[1104]});
}
} catch($e99079908) {
if(R.isCont($e99079908)) {
var $ss99119912 = {"from":L[1104],
"go":function(ann_DASH_check_DASH_temp6659917) {
return $Hann_DASH_check_DASH_temp25339918(ann_DASH_check_DASH_temp6659917);
}};
$e99079908.stack[R.EXN_STACKHEIGHT++] = $ss99119912;
}
if(R.isPyretException($e99079908)) {
$e99079908.pyretStack.push(L[1104]);
}
throw $e99079908;
}
var $ret99139914 = $Hann_DASH_check_DASH_temp25339918($z99099910);
++R.GAS;
return $ret99139914;
};
var $Hann_DASH_check_DASH_temp25339918 = function(ann_DASH_check_DASH_temp6659917) {
return ann_DASH_check_DASH_temp6659917;
};
var $Hanf_arg25329339 = function(anf_arg6619337,anf_fun6599338,desugar_DASH_toplevel_DASH_types9068,extra_DASH_lets2589187,l2519173,_plus9) {
var $z99219922 = D;
var $f99279928 = function(_) {
return R.isFunction(desugar_DASH_toplevel_DASH_types9068.$var)?desugar_DASH_toplevel_DASH_types9068.$var.app(anf_arg6619337):R.ffi.throwNonFunApp(L[1172],desugar_DASH_toplevel_DASH_types9068.$var,[anf_arg6619337]);
};
try {
if(--R.GAS > 0) {
$z99219922 = $f99279928();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99279928,
"from":L[1172]});
}
} catch($e99199920) {
if(R.isCont($e99199920)) {
var $ss99239924 = {"from":L[1172],
"go":function(anf_arg6629929) {
return $Hanf_arg25319930(anf_arg6629929,anf_fun6599338,extra_DASH_lets2589187,l2519173,_plus9);
}};
$e99199920.stack[R.EXN_STACKHEIGHT++] = $ss99239924;
}
if(R.isPyretException($e99199920)) {
$e99199920.pyretStack.push(L[1172]);
}
throw $e99199920;
}
var $ret99259926 = $Hanf_arg25319930($z99219922,anf_fun6599338,extra_DASH_lets2589187,l2519173,_plus9);
++R.GAS;
return $ret99259926;
};
var $Hanf_arg25319930 = function(anf_arg6629929,anf_fun6599338,extra_DASH_lets2589187,l2519173,_plus9) {
var $z99339934 = D;
var $f99399940 = function(_) {
return R.isFunction(_plus9)?_plus9.app(extra_DASH_lets2589187,anf_arg6629929):R.ffi.throwNonFunApp(L[1173],_plus9,[extra_DASH_lets2589187,anf_arg6629929]);
};
try {
if(--R.GAS > 0) {
$z99339934 = $f99399940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99399940,
"from":L[1173]});
}
} catch($e99319932) {
if(R.isCont($e99319932)) {
var $ss99359936 = {"from":L[1173],
"go":function(anf_arg6639941) {
return $Hanf_arg25309942(anf_arg6639941,anf_fun6599338,l2519173);
}};
$e99319932.stack[R.EXN_STACKHEIGHT++] = $ss99359936;
}
if(R.isPyretException($e99319932)) {
$e99319932.pyretStack.push(L[1173]);
}
throw $e99319932;
}
var $ret99379938 = $Hanf_arg25309942($z99339934,anf_fun6599338,l2519173);
++R.GAS;
return $ret99379938;
};
var $Hanf_arg25309942 = function(anf_arg6639941,anf_fun6599338,l2519173) {
var $z99459946 = D;
var $f99519952 = function(_) {
return R.isFunction(anf_fun6599338)?anf_fun6599338.app(l2519173,anf_arg6639941):R.ffi.throwNonFunApp(L[1093],anf_fun6599338,[l2519173,anf_arg6639941]);
};
try {
if(--R.GAS > 0) {
$z99459946 = $f99519952();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99519952,
"from":L[1093]});
}
} catch($e99439944) {
if(R.isCont($e99439944)) {
var $ss99479948 = {"from":L[1093],
"go":function(ann_DASH_check_DASH_temp6589953) {
return $Hann_DASH_check_DASH_temp25299954(ann_DASH_check_DASH_temp6589953);
}};
$e99439944.stack[R.EXN_STACKHEIGHT++] = $ss99479948;
}
if(R.isPyretException($e99439944)) {
$e99439944.pyretStack.push(L[1093]);
}
throw $e99439944;
}
var $ret99499950 = $Hann_DASH_check_DASH_temp25299954($z99459946);
++R.GAS;
return $ret99499950;
};
var $Hann_DASH_check_DASH_temp25299954 = function(ann_DASH_check_DASH_temp6589953) {
return ann_DASH_check_DASH_temp6589953;
};
var $Hanf_arg25289355 = function(anf_arg6549353,anf_fun6539354,extra_DASH_lets2589187,l22709341,_plus9) {
var $z99579958 = D;
var $f99639964 = function(_) {
return R.isFunction(_plus9)?_plus9.app(extra_DASH_lets2589187,anf_arg6549353):R.ffi.throwNonFunApp(L[1174],_plus9,[extra_DASH_lets2589187,anf_arg6549353]);
};
try {
if(--R.GAS > 0) {
$z99579958 = $f99639964();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99639964,
"from":L[1174]});
}
} catch($e99559956) {
if(R.isCont($e99559956)) {
var $ss99599960 = {"from":L[1174],
"go":function(anf_arg6559965) {
return $Hanf_arg25279966(anf_arg6559965,anf_fun6539354,l22709341);
}};
$e99559956.stack[R.EXN_STACKHEIGHT++] = $ss99599960;
}
if(R.isPyretException($e99559956)) {
$e99559956.pyretStack.push(L[1174]);
}
throw $e99559956;
}
var $ret99619962 = $Hanf_arg25279966($z99579958,anf_fun6539354,l22709341);
++R.GAS;
return $ret99619962;
};
var $Hanf_arg25279966 = function(anf_arg6559965,anf_fun6539354,l22709341) {
var $z99699970 = D;
var $f99759976 = function(_) {
return R.isFunction(anf_fun6539354)?anf_fun6539354.app(l22709341,anf_arg6559965):R.ffi.throwNonFunApp(L[1096],anf_fun6539354,[l22709341,anf_arg6559965]);
};
try {
if(--R.GAS > 0) {
$z99699970 = $f99759976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99759976,
"from":L[1096]});
}
} catch($e99679968) {
if(R.isCont($e99679968)) {
var $ss99719972 = {"from":L[1096],
"go":function(ann_DASH_check_DASH_temp6529977) {
return $Hann_DASH_check_DASH_temp25269978(ann_DASH_check_DASH_temp6529977);
}};
$e99679968.stack[R.EXN_STACKHEIGHT++] = $ss99719972;
}
if(R.isPyretException($e99679968)) {
$e99679968.pyretStack.push(L[1096]);
}
throw $e99679968;
}
var $ret99739974 = $Hann_DASH_check_DASH_temp25269978($z99699970);
++R.GAS;
return $ret99739974;
};
var $Hann_DASH_check_DASH_temp25269978 = function(ann_DASH_check_DASH_temp6529977) {
return ann_DASH_check_DASH_temp6529977;
};
var $Hanf_arg25259290 = function(anf_arg6489289,_plus9,raise14) {
var $z99819982 = D;
var $f99879988 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("Should have been resolve-typed away"),anf_arg6489289):R.ffi.throwNonFunApp(L[1175],_plus9,[("Should have been resolve-typed away"),anf_arg6489289]);
};
try {
if(--R.GAS > 0) {
$z99819982 = $f99879988();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f99879988,
"from":L[1175]});
}
} catch($e99799980) {
if(R.isCont($e99799980)) {
var $ss99839984 = {"from":L[1175],
"go":function(anf_arg6499989) {
return $Hanf_arg25249990(anf_arg6499989,raise14);
}};
$e99799980.stack[R.EXN_STACKHEIGHT++] = $ss99839984;
}
if(R.isPyretException($e99799980)) {
$e99799980.pyretStack.push(L[1175]);
}
throw $e99799980;
}
var $ret99859986 = $Hanf_arg25249990($z99819982,raise14);
++R.GAS;
return $ret99859986;
};
var $Hanf_arg25249990 = function(anf_arg6499989,raise14) {
var $z99939994 = D;
var $f999910000 = function(_) {
return R.isFunction(raise14)?raise14.app(anf_arg6499989):R.ffi.throwNonFunApp(L[1087],raise14,[anf_arg6499989]);
};
try {
if(--R.GAS > 0) {
$z99939994 = $f999910000();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f999910000,
"from":L[1087]});
}
} catch($e99919992) {
if(R.isCont($e99919992)) {
var $ss99959996 = {"from":L[1087],
"go":function(ann_DASH_check_DASH_temp64710001) {
return $Hann_DASH_check_DASH_temp252310002(ann_DASH_check_DASH_temp64710001);
}};
$e99919992.stack[R.EXN_STACKHEIGHT++] = $ss99959996;
}
if(R.isPyretException($e99919992)) {
$e99919992.pyretStack.push(L[1087]);
}
throw $e99919992;
}
var $ret99979998 = $Hann_DASH_check_DASH_temp252310002($z99939994);
++R.GAS;
return $ret99979998;
};
var $Hann_DASH_check_DASH_temp252310002 = function(ann_DASH_check_DASH_temp64710001) {
return ann_DASH_check_DASH_temp64710001;
};
var $Hann_DASH_check_DASH_temp25229309 = function(ann_DASH_check_DASH_temp6419308) {
return ann_DASH_check_DASH_temp6419308;
};
var $Hann_DASH_check_DASH_temp25219231 = function(ann_DASH_check_DASH_temp6389230) {
return ann_DASH_check_DASH_temp6389230;
};
var $Hanf_arg25209251 = function(anf_arg6339249,anf_fun6319250,l2519173) {
var $z1000510006 = D;
var $f1001110012 = function(_) {
return R.isFunction(anf_fun6319250)?anf_fun6319250.app(l2519173,anf_arg6339249):R.ffi.throwNonFunApp(L[1082],anf_fun6319250,[l2519173,anf_arg6339249]);
};
try {
if(--R.GAS > 0) {
$z1000510006 = $f1001110012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1001110012,
"from":L[1082]});
}
} catch($e1000310004) {
if(R.isCont($e1000310004)) {
var $ss1000710008 = {"from":L[1082],
"go":function(ann_DASH_check_DASH_temp63010013) {
return $Hann_DASH_check_DASH_temp251910014(ann_DASH_check_DASH_temp63010013);
}};
$e1000310004.stack[R.EXN_STACKHEIGHT++] = $ss1000710008;
}
if(R.isPyretException($e1000310004)) {
$e1000310004.pyretStack.push(L[1082]);
}
throw $e1000310004;
}
var $ret1000910010 = $Hann_DASH_check_DASH_temp251910014($z1000510006);
++R.GAS;
return $ret1000910010;
};
var $Hann_DASH_check_DASH_temp251910014 = function(ann_DASH_check_DASH_temp63010013) {
return ann_DASH_check_DASH_temp63010013;
};
var $Hann_DASH_check_DASH_temp25189204 = function(ann_DASH_check_DASH_temp6279203) {
return ann_DASH_check_DASH_temp6279203;
};
var $Hann_DASH_check_DASH_temp251710015 = function(ann_DASH_check_DASH_temp56310016) {
return ann_DASH_check_DASH_temp56310016;
};
var $Hanf_arg251610017 = function(anf_arg59010018,A119,anf_arg58810019,compile_DASH_bindings23410020,expr23210021,fold6171,l23110022,list3375,map459174,type_DASH_env23510023,_plus9) {
var $z1002610027 = D;
var $f1003210033 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg58810019,anf_arg59010018,compile_DASH_bindings23410020):R.ffi.throwNonFunApp(L[1176],fold6171,[anf_arg58810019,anf_arg59010018,compile_DASH_bindings23410020]);
};
try {
if(--R.GAS > 0) {
$z1002610027 = $f1003210033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1003210033,
"from":L[1176]});
}
} catch($e1002410025) {
if(R.isCont($e1002410025)) {
var $ss1002810029 = {"from":L[1176],
"go":function(let_DASH_binds23610034) {
return $Hlet_DASH_binds251510035(let_DASH_binds23610034,A119,expr23210021,fold6171,l23110022,list3375,map459174,type_DASH_env23510023,_plus9);
}};
$e1002410025.stack[R.EXN_STACKHEIGHT++] = $ss1002810029;
}
if(R.isPyretException($e1002410025)) {
$e1002410025.pyretStack.push(L[1176]);
}
throw $e1002410025;
}
var $ret1003010031 = $Hlet_DASH_binds251510035($z1002610027,A119,expr23210021,fold6171,l23110022,list3375,map459174,type_DASH_env23510023,_plus9);
++R.GAS;
return $ret1003010031;
};
var $Hlet_DASH_binds251510035 = function(let_DASH_binds23610034,A119,expr23210021,fold6171,l23110022,list3375,map459174,type_DASH_env23510023,_plus9) {
var anf_arg61010048 = R.makeFunction(function(lst24310050,t24410051) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1178],2,arguments);
}
var cases_DASH_val3910102 = t24410051;
var anf_fun59210062 = G(cases_DASH_val3910102,"_match",L[1179]);
var anf_obj59410068 = R.makeFunction(function(id24510100) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1185],1,arguments);
}
var ann_DASH_check_DASH_temp59310101 = lst24310050;
return ann_DASH_check_DASH_temp59310101;
});
var anf_obj60610069 = R.makeFunction(function(name24610070,bindings24710071) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1180],2,arguments);
}
var anf_arg60410082 = R.makeFunction(function(tname24810085) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1181],1,arguments);
}
var anf_fun59710098 = G(A119,"s-type-bind",L[1184]);
var anf_fun59810096 = G(A119,"s-name",L[1183]);
var $z1008810089 = D;
var $f1009410095 = function(_) {
return R.isFunction(anf_fun59810096)?anf_fun59810096.app(l23110022,tname24810085):R.ffi.throwNonFunApp(L[1182],anf_fun59810096,[l23110022,tname24810085]);
};
try {
if(--R.GAS > 0) {
$z1008810089 = $f1009410095();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1009410095,
"from":L[1182]});
}
} catch($e1008610087) {
if(R.isCont($e1008610087)) {
var $ss1009010091 = {"from":L[1182],
"go":function(anf_arg59910097) {
return $Hanf_arg250510099(anf_arg59910097,A119,anf_fun59710098,l23110022,name24610070,tname24810085);
}};
$e1008610087.stack[R.EXN_STACKHEIGHT++] = $ss1009010091;
}
if(R.isPyretException($e1008610087)) {
$e1008610087.pyretStack.push(L[1182]);
}
throw $e1008610087;
}
var $ret1009210093 = $Hanf_arg250510099($z1008810089,A119,anf_fun59710098,l23110022,name24610070,tname24810085);
++R.GAS;
return $ret1009210093;
});
var $z1007410075 = D;
var $f1008010081 = function(_) {
return R.isFunction(map459174)?map459174.app(anf_arg60410082,bindings24710071):R.ffi.throwNonFunApp(L[1181],map459174,[anf_arg60410082,bindings24710071]);
};
try {
if(--R.GAS > 0) {
$z1007410075 = $f1008010081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1008010081,
"from":L[1181]});
}
} catch($e1007210073) {
if(R.isCont($e1007210073)) {
var $ss1007610077 = {"from":L[1181],
"go":function(anf_arg60510083) {
return $Hanf_arg250710084(anf_arg60510083,lst24310050,_plus9);
}};
$e1007210073.stack[R.EXN_STACKHEIGHT++] = $ss1007610077;
}
if(R.isPyretException($e1007210073)) {
$e1007210073.pyretStack.push(L[1181]);
}
throw $e1007210073;
}
var $ret1007810079 = $Hanf_arg250710084($z1007410075,lst24310050,_plus9);
++R.GAS;
return $ret1007810079;
});
var anf_arg60710063 = R.makeObject({"type-id":anf_obj59410068,
"type-module-bindings":anf_obj60610069});
var anf_arg60910064 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1179],0,arguments);
}
var ann_DASH_check_DASH_temp60810067 = R.throwNoBranchesMatched(L[1179],("cases"));
return ann_DASH_check_DASH_temp60810067;
});
var $z1005410055 = D;
var $f1006010061 = function(_) {
return R.isFunction(anf_fun59210062)?anf_fun59210062.app(anf_arg60710063,anf_arg60910064):R.ffi.throwNonFunApp(L[1178],anf_fun59210062,[anf_arg60710063,anf_arg60910064]);
};
try {
if(--R.GAS > 0) {
$z1005410055 = $f1006010061();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1006010061,
"from":L[1178]});
}
} catch($e1005210053) {
if(R.isCont($e1005210053)) {
var $ss1005610057 = {"from":L[1178],
"go":function(ann_DASH_check_DASH_temp59110065) {
return $Hann_DASH_check_DASH_temp250810066(ann_DASH_check_DASH_temp59110065);
}};
$e1005210053.stack[R.EXN_STACKHEIGHT++] = $ss1005610057;
}
if(R.isPyretException($e1005210053)) {
$e1005210053.pyretStack.push(L[1178]);
}
throw $e1005210053;
}
var $ret1005810059 = $Hann_DASH_check_DASH_temp250810066($z1005410055);
++R.GAS;
return $ret1005810059;
});
var anf_fun61110046 = G(list3375,"make",L[1177]);
var $z1003810039 = D;
var $f1004410045 = function(_) {
return R.isFunction(anf_fun61110046)?anf_fun61110046.app([]):R.ffi.throwNonFunApp(L[1177],anf_fun61110046,[[]]);
};
try {
if(--R.GAS > 0) {
$z1003810039 = $f1004410045();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1004410045,
"from":L[1177]});
}
} catch($e1003610037) {
if(R.isCont($e1003610037)) {
var $ss1004010041 = {"from":L[1177],
"go":function(anf_arg61210047) {
return $Hanf_arg251410049(anf_arg61210047,A119,anf_arg61010048,expr23210021,fold6171,l23110022,let_DASH_binds23610034,list3375,type_DASH_env23510023,_plus9);
}};
$e1003610037.stack[R.EXN_STACKHEIGHT++] = $ss1004010041;
}
if(R.isPyretException($e1003610037)) {
$e1003610037.pyretStack.push(L[1177]);
}
throw $e1003610037;
}
var $ret1004210043 = $Hanf_arg251410049($z1003810039,A119,anf_arg61010048,expr23210021,fold6171,l23110022,let_DASH_binds23610034,list3375,type_DASH_env23510023,_plus9);
++R.GAS;
return $ret1004210043;
};
var $Hanf_arg251410049 = function(anf_arg61210047,A119,anf_arg61010048,expr23210021,fold6171,l23110022,let_DASH_binds23610034,list3375,type_DASH_env23510023,_plus9) {
var $z1010510106 = D;
var $f1011110112 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg61010048,anf_arg61210047,type_DASH_env23510023):R.ffi.throwNonFunApp(L[1186],fold6171,[anf_arg61010048,anf_arg61210047,type_DASH_env23510023]);
};
try {
if(--R.GAS > 0) {
$z1010510106 = $f1011110112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1011110112,
"from":L[1186]});
}
} catch($e1010310104) {
if(R.isCont($e1010310104)) {
var $ss1010710108 = {"from":L[1186],
"go":function(type_DASH_binds24210113) {
return $Htype_DASH_binds251310114(type_DASH_binds24210113,A119,expr23210021,l23110022,let_DASH_binds23610034,list3375,_plus9);
}};
$e1010310104.stack[R.EXN_STACKHEIGHT++] = $ss1010710108;
}
if(R.isPyretException($e1010310104)) {
$e1010310104.pyretStack.push(L[1186]);
}
throw $e1010310104;
}
var $ret1010910110 = $Htype_DASH_binds251310114($z1010510106,A119,expr23210021,l23110022,let_DASH_binds23610034,list3375,_plus9);
++R.GAS;
return $ret1010910110;
};
var $Htype_DASH_binds251310114 = function(type_DASH_binds24210113,A119,expr23210021,l23110022,let_DASH_binds23610034,list3375,_plus9) {
var anf_fun61310127 = G(A119,"s-type-let-expr",L[1189]);
var anf_fun61410128 = G(A119,"s-block",L[1188]);
var anf_fun61510125 = G(list3375,"make",L[1187]);
var $z1011710118 = D;
var $f1012310124 = function(_) {
return R.isFunction(anf_fun61510125)?anf_fun61510125.app([expr23210021]):R.ffi.throwNonFunApp(L[1187],anf_fun61510125,[[expr23210021]]);
};
try {
if(--R.GAS > 0) {
$z1011710118 = $f1012310124();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1012310124,
"from":L[1187]});
}
} catch($e1011510116) {
if(R.isCont($e1011510116)) {
var $ss1011910120 = {"from":L[1187],
"go":function(anf_arg61610126) {
return $Hanf_arg251210129(anf_arg61610126,anf_fun61310127,anf_fun61410128,l23110022,let_DASH_binds23610034,type_DASH_binds24210113,_plus9);
}};
$e1011510116.stack[R.EXN_STACKHEIGHT++] = $ss1011910120;
}
if(R.isPyretException($e1011510116)) {
$e1011510116.pyretStack.push(L[1187]);
}
throw $e1011510116;
}
var $ret1012110122 = $Hanf_arg251210129($z1011710118,anf_fun61310127,anf_fun61410128,l23110022,let_DASH_binds23610034,type_DASH_binds24210113,_plus9);
++R.GAS;
return $ret1012110122;
};
var $Hanf_arg251210129 = function(anf_arg61610126,anf_fun61310127,anf_fun61410128,l23110022,let_DASH_binds23610034,type_DASH_binds24210113,_plus9) {
var $z1013210133 = D;
var $f1013810139 = function(_) {
return R.isFunction(_plus9)?_plus9.app(let_DASH_binds23610034,anf_arg61610126):R.ffi.throwNonFunApp(L[1190],_plus9,[let_DASH_binds23610034,anf_arg61610126]);
};
try {
if(--R.GAS > 0) {
$z1013210133 = $f1013810139();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1013810139,
"from":L[1190]});
}
} catch($e1013010131) {
if(R.isCont($e1013010131)) {
var $ss1013410135 = {"from":L[1190],
"go":function(anf_arg61710140) {
return $Hanf_arg251110141(anf_arg61710140,anf_fun61310127,anf_fun61410128,l23110022,type_DASH_binds24210113);
}};
$e1013010131.stack[R.EXN_STACKHEIGHT++] = $ss1013410135;
}
if(R.isPyretException($e1013010131)) {
$e1013010131.pyretStack.push(L[1190]);
}
throw $e1013010131;
}
var $ret1013610137 = $Hanf_arg251110141($z1013210133,anf_fun61310127,anf_fun61410128,l23110022,type_DASH_binds24210113);
++R.GAS;
return $ret1013610137;
};
var $Hanf_arg251110141 = function(anf_arg61710140,anf_fun61310127,anf_fun61410128,l23110022,type_DASH_binds24210113) {
var $z1014410145 = D;
var $f1015010151 = function(_) {
return R.isFunction(anf_fun61410128)?anf_fun61410128.app(l23110022,anf_arg61710140):R.ffi.throwNonFunApp(L[1191],anf_fun61410128,[l23110022,anf_arg61710140]);
};
try {
if(--R.GAS > 0) {
$z1014410145 = $f1015010151();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1015010151,
"from":L[1191]});
}
} catch($e1014210143) {
if(R.isCont($e1014210143)) {
var $ss1014610147 = {"from":L[1191],
"go":function(anf_arg61810152) {
return $Hanf_arg251010153(anf_arg61810152,anf_fun61310127,l23110022,type_DASH_binds24210113);
}};
$e1014210143.stack[R.EXN_STACKHEIGHT++] = $ss1014610147;
}
if(R.isPyretException($e1014210143)) {
$e1014210143.pyretStack.push(L[1191]);
}
throw $e1014210143;
}
var $ret1014810149 = $Hanf_arg251010153($z1014410145,anf_fun61310127,l23110022,type_DASH_binds24210113);
++R.GAS;
return $ret1014810149;
};
var $Hanf_arg251010153 = function(anf_arg61810152,anf_fun61310127,l23110022,type_DASH_binds24210113) {
var $z1015610157 = D;
var $f1016210163 = function(_) {
return R.isFunction(anf_fun61310127)?anf_fun61310127.app(l23110022,type_DASH_binds24210113,anf_arg61810152):R.ffi.throwNonFunApp(L[1192],anf_fun61310127,[l23110022,type_DASH_binds24210113,anf_arg61810152]);
};
try {
if(--R.GAS > 0) {
$z1015610157 = $f1016210163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1016210163,
"from":L[1192]});
}
} catch($e1015410155) {
if(R.isCont($e1015410155)) {
var $ss1015810159 = {"from":L[1192],
"go":function(ann_DASH_check_DASH_temp56510164) {
return $Hann_DASH_check_DASH_temp250910165(ann_DASH_check_DASH_temp56510164);
}};
$e1015410155.stack[R.EXN_STACKHEIGHT++] = $ss1015810159;
}
if(R.isPyretException($e1015410155)) {
$e1015410155.pyretStack.push(L[1192]);
}
throw $e1015410155;
}
var $ret1016010161 = $Hann_DASH_check_DASH_temp250910165($z1015610157);
++R.GAS;
return $ret1016010161;
};
var $Hann_DASH_check_DASH_temp250910165 = function(ann_DASH_check_DASH_temp56510164) {
return ann_DASH_check_DASH_temp56510164;
};
var $Hann_DASH_check_DASH_temp250810066 = function(ann_DASH_check_DASH_temp59110065) {
return ann_DASH_check_DASH_temp59110065;
};
var $Hanf_arg250710084 = function(anf_arg60510083,lst24310050,_plus9) {
var $z1016810169 = D;
var $f1017410175 = function(_) {
return R.isFunction(_plus9)?_plus9.app(lst24310050,anf_arg60510083):R.ffi.throwNonFunApp(L[1180],_plus9,[lst24310050,anf_arg60510083]);
};
try {
if(--R.GAS > 0) {
$z1016810169 = $f1017410175();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1017410175,
"from":L[1180]});
}
} catch($e1016610167) {
if(R.isCont($e1016610167)) {
var $ss1017010171 = {"from":L[1180],
"go":function(ann_DASH_check_DASH_temp59510176) {
return $Hann_DASH_check_DASH_temp250610177(ann_DASH_check_DASH_temp59510176);
}};
$e1016610167.stack[R.EXN_STACKHEIGHT++] = $ss1017010171;
}
if(R.isPyretException($e1016610167)) {
$e1016610167.pyretStack.push(L[1180]);
}
throw $e1016610167;
}
var $ret1017210173 = $Hann_DASH_check_DASH_temp250610177($z1016810169);
++R.GAS;
return $ret1017210173;
};
var $Hann_DASH_check_DASH_temp250610177 = function(ann_DASH_check_DASH_temp59510176) {
return ann_DASH_check_DASH_temp59510176;
};
var $Hanf_arg250510099 = function(anf_arg59910097,A119,anf_fun59710098,l23110022,name24610070,tname24810085) {
var anf_fun60010190 = G(A119,"a-dot",L[1195]);
var anf_fun60110188 = G(A119,"s-name",L[1194]);
var $z1018010181 = D;
var $f1018610187 = function(_) {
return R.isFunction(anf_fun60110188)?anf_fun60110188.app(l23110022,name24610070):R.ffi.throwNonFunApp(L[1193],anf_fun60110188,[l23110022,name24610070]);
};
try {
if(--R.GAS > 0) {
$z1018010181 = $f1018610187();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1018610187,
"from":L[1193]});
}
} catch($e1017810179) {
if(R.isCont($e1017810179)) {
var $ss1018210183 = {"from":L[1193],
"go":function(anf_arg60210189) {
return $Hanf_arg250410191(anf_arg60210189,anf_arg59910097,anf_fun59710098,anf_fun60010190,l23110022,tname24810085);
}};
$e1017810179.stack[R.EXN_STACKHEIGHT++] = $ss1018210183;
}
if(R.isPyretException($e1017810179)) {
$e1017810179.pyretStack.push(L[1193]);
}
throw $e1017810179;
}
var $ret1018410185 = $Hanf_arg250410191($z1018010181,anf_arg59910097,anf_fun59710098,anf_fun60010190,l23110022,tname24810085);
++R.GAS;
return $ret1018410185;
};
var $Hanf_arg250410191 = function(anf_arg60210189,anf_arg59910097,anf_fun59710098,anf_fun60010190,l23110022,tname24810085) {
var $z1019410195 = D;
var $f1020010201 = function(_) {
return R.isFunction(anf_fun60010190)?anf_fun60010190.app(l23110022,anf_arg60210189,tname24810085):R.ffi.throwNonFunApp(L[1196],anf_fun60010190,[l23110022,anf_arg60210189,tname24810085]);
};
try {
if(--R.GAS > 0) {
$z1019410195 = $f1020010201();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1020010201,
"from":L[1196]});
}
} catch($e1019210193) {
if(R.isCont($e1019210193)) {
var $ss1019610197 = {"from":L[1196],
"go":function(anf_arg60310202) {
return $Hanf_arg250310203(anf_arg60310202,anf_arg59910097,anf_fun59710098,l23110022);
}};
$e1019210193.stack[R.EXN_STACKHEIGHT++] = $ss1019610197;
}
if(R.isPyretException($e1019210193)) {
$e1019210193.pyretStack.push(L[1196]);
}
throw $e1019210193;
}
var $ret1019810199 = $Hanf_arg250310203($z1019410195,anf_arg59910097,anf_fun59710098,l23110022);
++R.GAS;
return $ret1019810199;
};
var $Hanf_arg250310203 = function(anf_arg60310202,anf_arg59910097,anf_fun59710098,l23110022) {
var $z1020610207 = D;
var $f1021210213 = function(_) {
return R.isFunction(anf_fun59710098)?anf_fun59710098.app(l23110022,anf_arg59910097,anf_arg60310202):R.ffi.throwNonFunApp(L[1181],anf_fun59710098,[l23110022,anf_arg59910097,anf_arg60310202]);
};
try {
if(--R.GAS > 0) {
$z1020610207 = $f1021210213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1021210213,
"from":L[1181]});
}
} catch($e1020410205) {
if(R.isCont($e1020410205)) {
var $ss1020810209 = {"from":L[1181],
"go":function(ann_DASH_check_DASH_temp59610214) {
return $Hann_DASH_check_DASH_temp250210215(ann_DASH_check_DASH_temp59610214);
}};
$e1020410205.stack[R.EXN_STACKHEIGHT++] = $ss1020810209;
}
if(R.isPyretException($e1020410205)) {
$e1020410205.pyretStack.push(L[1181]);
}
throw $e1020410205;
}
var $ret1021010211 = $Hann_DASH_check_DASH_temp250210215($z1020610207);
++R.GAS;
return $ret1021010211;
};
var $Hann_DASH_check_DASH_temp250210215 = function(ann_DASH_check_DASH_temp59610214) {
return ann_DASH_check_DASH_temp59610214;
};
var $Hann_DASH_check_DASH_temp250110216 = function(ann_DASH_check_DASH_temp56610217) {
return ann_DASH_check_DASH_temp56610217;
};
var $Hanf_arg250010218 = function(anf_arg58310219,lst23710220,_plus9) {
var $z1022310224 = D;
var $f1022910230 = function(_) {
return R.isFunction(_plus9)?_plus9.app(lst23710220,anf_arg58310219):R.ffi.throwNonFunApp(L[1197],_plus9,[lst23710220,anf_arg58310219]);
};
try {
if(--R.GAS > 0) {
$z1022310224 = $f1022910230();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1022910230,
"from":L[1197]});
}
} catch($e1022110222) {
if(R.isCont($e1022110222)) {
var $ss1022510226 = {"from":L[1197],
"go":function(ann_DASH_check_DASH_temp56810231) {
return $Hann_DASH_check_DASH_temp249910232(ann_DASH_check_DASH_temp56810231);
}};
$e1022110222.stack[R.EXN_STACKHEIGHT++] = $ss1022510226;
}
if(R.isPyretException($e1022110222)) {
$e1022110222.pyretStack.push(L[1197]);
}
throw $e1022110222;
}
var $ret1022710228 = $Hann_DASH_check_DASH_temp249910232($z1022310224);
++R.GAS;
return $ret1022710228;
};
var $Hann_DASH_check_DASH_temp249910232 = function(ann_DASH_check_DASH_temp56810231) {
return ann_DASH_check_DASH_temp56810231;
};
var $Hanf_arg249810233 = function(anf_arg57310234,A119,anf_fun57010235,anf_fun57110236,l23110022,mname23910237,name24110238) {
var anf_arg57410249 = G(A119,"a-blank",L[1199]);
var $z1024110242 = D;
var $f1024710248 = function(_) {
return R.isFunction(anf_fun57110236)?anf_fun57110236.app(l23110022,(false),anf_arg57310234,anf_arg57410249):R.ffi.throwNonFunApp(L[1198],anf_fun57110236,[l23110022,(false),anf_arg57310234,anf_arg57410249]);
};
try {
if(--R.GAS > 0) {
$z1024110242 = $f1024710248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1024710248,
"from":L[1198]});
}
} catch($e1023910240) {
if(R.isCont($e1023910240)) {
var $ss1024310244 = {"from":L[1198],
"go":function(anf_arg57510250) {
return $Hanf_arg249710251(anf_arg57510250,A119,anf_fun57010235,l23110022,mname23910237,name24110238);
}};
$e1023910240.stack[R.EXN_STACKHEIGHT++] = $ss1024310244;
}
if(R.isPyretException($e1023910240)) {
$e1023910240.pyretStack.push(L[1198]);
}
throw $e1023910240;
}
var $ret1024510246 = $Hanf_arg249710251($z1024110242,A119,anf_fun57010235,l23110022,mname23910237,name24110238);
++R.GAS;
return $ret1024510246;
};
var $Hanf_arg249710251 = function(anf_arg57510250,A119,anf_fun57010235,l23110022,mname23910237,name24110238) {
var anf_fun57610264 = G(A119,"s-dot",L[1203]);
var anf_fun57710265 = G(A119,"s-id",L[1202]);
var anf_fun57810262 = G(A119,"s-name",L[1201]);
var $z1025410255 = D;
var $f1026010261 = function(_) {
return R.isFunction(anf_fun57810262)?anf_fun57810262.app(l23110022,mname23910237):R.ffi.throwNonFunApp(L[1200],anf_fun57810262,[l23110022,mname23910237]);
};
try {
if(--R.GAS > 0) {
$z1025410255 = $f1026010261();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1026010261,
"from":L[1200]});
}
} catch($e1025210253) {
if(R.isCont($e1025210253)) {
var $ss1025610257 = {"from":L[1200],
"go":function(anf_arg57910263) {
return $Hanf_arg249610266(anf_arg57910263,anf_arg57510250,anf_fun57010235,anf_fun57610264,anf_fun57710265,l23110022,name24110238);
}};
$e1025210253.stack[R.EXN_STACKHEIGHT++] = $ss1025610257;
}
if(R.isPyretException($e1025210253)) {
$e1025210253.pyretStack.push(L[1200]);
}
throw $e1025210253;
}
var $ret1025810259 = $Hanf_arg249610266($z1025410255,anf_arg57510250,anf_fun57010235,anf_fun57610264,anf_fun57710265,l23110022,name24110238);
++R.GAS;
return $ret1025810259;
};
var $Hanf_arg249610266 = function(anf_arg57910263,anf_arg57510250,anf_fun57010235,anf_fun57610264,anf_fun57710265,l23110022,name24110238) {
var $z1026910270 = D;
var $f1027510276 = function(_) {
return R.isFunction(anf_fun57710265)?anf_fun57710265.app(l23110022,anf_arg57910263):R.ffi.throwNonFunApp(L[1204],anf_fun57710265,[l23110022,anf_arg57910263]);
};
try {
if(--R.GAS > 0) {
$z1026910270 = $f1027510276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1027510276,
"from":L[1204]});
}
} catch($e1026710268) {
if(R.isCont($e1026710268)) {
var $ss1027110272 = {"from":L[1204],
"go":function(anf_arg58010277) {
return $Hanf_arg249510278(anf_arg58010277,anf_arg57510250,anf_fun57010235,anf_fun57610264,l23110022,name24110238);
}};
$e1026710268.stack[R.EXN_STACKHEIGHT++] = $ss1027110272;
}
if(R.isPyretException($e1026710268)) {
$e1026710268.pyretStack.push(L[1204]);
}
throw $e1026710268;
}
var $ret1027310274 = $Hanf_arg249510278($z1026910270,anf_arg57510250,anf_fun57010235,anf_fun57610264,l23110022,name24110238);
++R.GAS;
return $ret1027310274;
};
var $Hanf_arg249510278 = function(anf_arg58010277,anf_arg57510250,anf_fun57010235,anf_fun57610264,l23110022,name24110238) {
var $z1028110282 = D;
var $f1028710288 = function(_) {
return R.isFunction(anf_fun57610264)?anf_fun57610264.app(l23110022,anf_arg58010277,name24110238):R.ffi.throwNonFunApp(L[1205],anf_fun57610264,[l23110022,anf_arg58010277,name24110238]);
};
try {
if(--R.GAS > 0) {
$z1028110282 = $f1028710288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1028710288,
"from":L[1205]});
}
} catch($e1027910280) {
if(R.isCont($e1027910280)) {
var $ss1028310284 = {"from":L[1205],
"go":function(anf_arg58110289) {
return $Hanf_arg249410290(anf_arg58110289,anf_arg57510250,anf_fun57010235,l23110022);
}};
$e1027910280.stack[R.EXN_STACKHEIGHT++] = $ss1028310284;
}
if(R.isPyretException($e1027910280)) {
$e1027910280.pyretStack.push(L[1205]);
}
throw $e1027910280;
}
var $ret1028510286 = $Hanf_arg249410290($z1028110282,anf_arg57510250,anf_fun57010235,l23110022);
++R.GAS;
return $ret1028510286;
};
var $Hanf_arg249410290 = function(anf_arg58110289,anf_arg57510250,anf_fun57010235,l23110022) {
var $z1029310294 = D;
var $f1029910300 = function(_) {
return R.isFunction(anf_fun57010235)?anf_fun57010235.app(l23110022,anf_arg57510250,anf_arg58110289,(false)):R.ffi.throwNonFunApp(L[1206],anf_fun57010235,[l23110022,anf_arg57510250,anf_arg58110289,(false)]);
};
try {
if(--R.GAS > 0) {
$z1029310294 = $f1029910300();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1029910300,
"from":L[1206]});
}
} catch($e1029110292) {
if(R.isCont($e1029110292)) {
var $ss1029510296 = {"from":L[1206],
"go":function(ann_DASH_check_DASH_temp56910301) {
return $Hann_DASH_check_DASH_temp249310302(ann_DASH_check_DASH_temp56910301);
}};
$e1029110292.stack[R.EXN_STACKHEIGHT++] = $ss1029510296;
}
if(R.isPyretException($e1029110292)) {
$e1029110292.pyretStack.push(L[1206]);
}
throw $e1029110292;
}
var $ret1029710298 = $Hann_DASH_check_DASH_temp249310302($z1029310294);
++R.GAS;
return $ret1029710298;
};
var $Hann_DASH_check_DASH_temp249310302 = function(ann_DASH_check_DASH_temp56910301) {
return ann_DASH_check_DASH_temp56910301;
};
var $Hanf_arg249210303 = function(anf_arg55410304,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375) {
var anf_fun55510317 = G(list3375,"make",L[1207]);
var $z1030910310 = D;
var $f1031510316 = function(_) {
return R.isFunction(anf_fun55510317)?anf_fun55510317.app([]):R.ffi.throwNonFunApp(L[1207],anf_fun55510317,[[]]);
};
try {
if(--R.GAS > 0) {
$z1030910310 = $f1031510316();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1031510316,
"from":L[1207]});
}
} catch($e1030710308) {
if(R.isCont($e1030710308)) {
var $ss1031110312 = {"from":L[1207],
"go":function(anf_arg55610318) {
return $Hanf_arg249110319(anf_arg55610318,anf_arg55410304,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375);
}};
$e1030710308.stack[R.EXN_STACKHEIGHT++] = $ss1031110312;
}
if(R.isPyretException($e1030710308)) {
$e1030710308.pyretStack.push(L[1207]);
}
throw $e1030710308;
}
var $ret1031310314 = $Hanf_arg249110319($z1030910310,anf_arg55410304,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375);
++R.GAS;
return $ret1031310314;
};
var $Hanf_arg249110319 = function(anf_arg55610318,anf_arg55410304,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375) {
var anf_fun55710330 = G(list3375,"make",L[1208]);
var $z1032210323 = D;
var $f1032810329 = function(_) {
return R.isFunction(anf_fun55710330)?anf_fun55710330.app([]):R.ffi.throwNonFunApp(L[1208],anf_fun55710330,[[]]);
};
try {
if(--R.GAS > 0) {
$z1032210323 = $f1032810329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1032810329,
"from":L[1208]});
}
} catch($e1032010321) {
if(R.isCont($e1032010321)) {
var $ss1032410325 = {"from":L[1208],
"go":function(anf_arg55810331) {
return $Hanf_arg249010332(anf_arg55810331,anf_arg55410304,anf_arg55610318,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375);
}};
$e1032010321.stack[R.EXN_STACKHEIGHT++] = $ss1032410325;
}
if(R.isPyretException($e1032010321)) {
$e1032010321.pyretStack.push(L[1208]);
}
throw $e1032010321;
}
var $ret1032610327 = $Hanf_arg249010332($z1032210323,anf_arg55410304,anf_arg55610318,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375);
++R.GAS;
return $ret1032610327;
};
var $Hanf_arg249010332 = function(anf_arg55810331,anf_arg55410304,anf_arg55610318,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375) {
var anf_fun55910343 = G(list3375,"make",L[1209]);
var $z1033510336 = D;
var $f1034110342 = function(_) {
return R.isFunction(anf_fun55910343)?anf_fun55910343.app([]):R.ffi.throwNonFunApp(L[1209],anf_fun55910343,[[]]);
};
try {
if(--R.GAS > 0) {
$z1033510336 = $f1034110342();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1034110342,
"from":L[1209]});
}
} catch($e1033310334) {
if(R.isCont($e1033310334)) {
var $ss1033710338 = {"from":L[1209],
"go":function(anf_arg56010344) {
return $Hanf_arg248910345(anf_arg56010344,anf_arg55410304,anf_arg55610318,anf_arg55810331,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306);
}};
$e1033310334.stack[R.EXN_STACKHEIGHT++] = $ss1033710338;
}
if(R.isPyretException($e1033310334)) {
$e1033310334.pyretStack.push(L[1209]);
}
throw $e1033310334;
}
var $ret1033910340 = $Hanf_arg248910345($z1033510336,anf_arg55410304,anf_arg55610318,anf_arg55810331,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306);
++R.GAS;
return $ret1033910340;
};
var $Hanf_arg248910345 = function(anf_arg56010344,anf_arg55410304,anf_arg55610318,anf_arg55810331,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306) {
var $z1034810349 = D;
var $f1035410355 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(anf_arg55410304,anf_arg55610318,anf_arg55810331,anf_arg56010344):R.ffi.throwNonFunApp(L[1210],desugar_DASH_scope_DASH_block9165.$var,[anf_arg55410304,anf_arg55610318,anf_arg55810331,anf_arg56010344]);
};
try {
if(--R.GAS > 0) {
$z1034810349 = $f1035410355();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1035410355,
"from":L[1210]});
}
} catch($e1034610347) {
if(R.isCont($e1034610347)) {
var $ss1035010351 = {"from":L[1210],
"go":function(anf_arg56110356) {
return $Hanf_arg248810357(anf_arg56110356,anf_fun54910305,l22710306);
}};
$e1034610347.stack[R.EXN_STACKHEIGHT++] = $ss1035010351;
}
if(R.isPyretException($e1034610347)) {
$e1034610347.pyretStack.push(L[1210]);
}
throw $e1034610347;
}
var $ret1035210353 = $Hanf_arg248810357($z1034810349,anf_fun54910305,l22710306);
++R.GAS;
return $ret1035210353;
};
var $Hanf_arg248810357 = function(anf_arg56110356,anf_fun54910305,l22710306) {
var $z1036010361 = D;
var $f1036610367 = function(_) {
return R.isFunction(anf_fun54910305)?anf_fun54910305.app(l22710306,anf_arg56110356):R.ffi.throwNonFunApp(L[1211],anf_fun54910305,[l22710306,anf_arg56110356]);
};
try {
if(--R.GAS > 0) {
$z1036010361 = $f1036610367();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1036610367,
"from":L[1211]});
}
} catch($e1035810359) {
if(R.isCont($e1035810359)) {
var $ss1036210363 = {"from":L[1211],
"go":function(ann_DASH_check_DASH_temp54810368) {
return $Hann_DASH_check_DASH_temp248710369(ann_DASH_check_DASH_temp54810368);
}};
$e1035810359.stack[R.EXN_STACKHEIGHT++] = $ss1036210363;
}
if(R.isPyretException($e1035810359)) {
$e1035810359.pyretStack.push(L[1211]);
}
throw $e1035810359;
}
var $ret1036410365 = $Hann_DASH_check_DASH_temp248710369($z1036010361);
++R.GAS;
return $ret1036410365;
};
var $Hann_DASH_check_DASH_temp248710369 = function(ann_DASH_check_DASH_temp54810368) {
return ann_DASH_check_DASH_temp54810368;
};
var $Hann_DASH_check_DASH_temp248610370 = function(ann_DASH_check_DASH_temp55110371) {
return ann_DASH_check_DASH_temp55110371;
};
var $Hann_DASH_check_DASH_temp248510372 = function(ann_DASH_check_DASH_temp25310373,A231,List2510374) {
return ann_DASH_check_DASH_temp25310373;
};
var $Hif_DASH_248410375 = function(if_DASH_2310376,A119,G1325,desugar_DASH_scope_DASH_block9165,f15810377,fold6171,handle_DASH_let_DASH_bind16310378,is_DASH_empty3410379,is_DASH_link3510380,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,_plus9,not11,$type$String18) {
var if_helper30810398 = R.makeFunction(function(if_helper_arg30910417) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1214],1,arguments);
}
var wrapper17110464 = if_helper_arg30910417;
var cases_DASH_val3510630 = f15810377;
var anf_fun31010428 = G(cases_DASH_val3510630,"_match",L[1216]);
var anf_obj34110480 = R.makeFunction(function(l17310614,name17410615,ann17510616) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1247],3,arguments);
}
var anf_fun31210627 = G(A119,"s-type-bind",L[1249]);
var $z1061910620 = D;
var $f1062510626 = function(_) {
return R.isFunction(anf_fun31210627)?anf_fun31210627.app(l17310614,name17410615,ann17510616):R.ffi.throwNonFunApp(L[1248],anf_fun31210627,[l17310614,name17410615,ann17510616]);
};
try {
if(--R.GAS > 0) {
$z1061910620 = $f1062510626();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1062510626,
"from":L[1248]});
}
} catch($e1061710618) {
if(R.isCont($e1061710618)) {
var $ss1062110622 = {"from":L[1248],
"go":function(anf_arg31310628) {
return $Hanf_arg238710629(anf_arg31310628,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
}};
$e1061710618.stack[R.EXN_STACKHEIGHT++] = $ss1062110622;
}
if(R.isPyretException($e1061710618)) {
$e1061710618.pyretStack.push(L[1248]);
}
throw $e1061710618;
}
var $ret1062310624 = $Hanf_arg238710629($z1061910620,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
++R.GAS;
return $ret1062310624;
});
var anf_obj34510481 = R.makeFunction(function(l17810597,bind17910598,expr18010599,$underscore18110600) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1244],4,arguments);
}
var anf_fun34310611 = G(A119,"s-let-bind",L[1246]);
var $z1060310604 = D;
var $f1060910610 = function(_) {
return R.isFunction(anf_fun34310611)?anf_fun34310611.app(l17810597,bind17910598,expr18010599):R.ffi.throwNonFunApp(L[1245],anf_fun34310611,[l17810597,bind17910598,expr18010599]);
};
try {
if(--R.GAS > 0) {
$z1060310604 = $f1060910610();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1060910610,
"from":L[1245]});
}
} catch($e1060110602) {
if(R.isCont($e1060110602)) {
var $ss1060510606 = {"from":L[1245],
"go":function(anf_arg34410612) {
return $Hanf_arg238910613(anf_arg34410612,handle_DASH_let_DASH_bind16310378,l17810597);
}};
$e1060110602.stack[R.EXN_STACKHEIGHT++] = $ss1060510606;
}
if(R.isPyretException($e1060110602)) {
$e1060110602.pyretStack.push(L[1245]);
}
throw $e1060110602;
}
var $ret1060710608 = $Hanf_arg238910613($z1060310604,handle_DASH_let_DASH_bind16310378,l17810597);
++R.GAS;
return $ret1060710608;
});
var anf_obj34910482 = R.makeFunction(function(l18210581,bind18310582,expr18410583) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1241],3,arguments);
}
var anf_fun34710594 = G(A119,"s-var-bind",L[1243]);
var $z1058610587 = D;
var $f1059210593 = function(_) {
return R.isFunction(anf_fun34710594)?anf_fun34710594.app(l18210581,bind18310582,expr18410583):R.ffi.throwNonFunApp(L[1242],anf_fun34710594,[l18210581,bind18310582,expr18410583]);
};
try {
if(--R.GAS > 0) {
$z1058610587 = $f1059210593();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1059210593,
"from":L[1242]});
}
} catch($e1058410585) {
if(R.isCont($e1058410585)) {
var $ss1058810589 = {"from":L[1242],
"go":function(anf_arg34810595) {
return $Hanf_arg239110596(anf_arg34810595,handle_DASH_let_DASH_bind16310378,l18210581);
}};
$e1058410585.stack[R.EXN_STACKHEIGHT++] = $ss1058810589;
}
if(R.isPyretException($e1058410585)) {
$e1058410585.pyretStack.push(L[1242]);
}
throw $e1058410585;
}
var $ret1059010591 = $Hanf_arg239110596($z1058610587,handle_DASH_let_DASH_bind16310378,l18210581);
++R.GAS;
return $ret1059010591;
});
var anf_obj38710483 = R.makeFunction(function(l18510558,name18610559,params18710560,args18810561,ann18910562,doc19010563,body19110564,_check19210565) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[1236],8,arguments);
}
var anf_fun35110578 = G(A119,"s-letrec-bind",L[1240]);
var anf_fun35210579 = G(A119,"s-bind",L[1239]);
var anf_fun35310576 = G(A119,"s-name",L[1238]);
var $z1056810569 = D;
var $f1057410575 = function(_) {
return R.isFunction(anf_fun35310576)?anf_fun35310576.app(l18510558,name18610559):R.ffi.throwNonFunApp(L[1237],anf_fun35310576,[l18510558,name18610559]);
};
try {
if(--R.GAS > 0) {
$z1056810569 = $f1057410575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1057410575,
"from":L[1237]});
}
} catch($e1056610567) {
if(R.isCont($e1056610567)) {
var $ss1057010571 = {"from":L[1237],
"go":function(anf_arg35410577) {
return $Hanf_arg241010580(anf_arg35410577,A119,_check19210565,anf_fun35110578,anf_fun35210579,ann18910562,args18810561,body19110564,desugar_DASH_scope_DASH_block9165,doc19010563,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,params18710560,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1056610567.stack[R.EXN_STACKHEIGHT++] = $ss1057010571;
}
if(R.isPyretException($e1056610567)) {
$e1056610567.pyretStack.push(L[1237]);
}
throw $e1056610567;
}
var $ret1057210573 = $Hanf_arg241010580($z1056810569,A119,_check19210565,anf_fun35110578,anf_fun35210579,ann18910562,args18810561,body19110564,desugar_DASH_scope_DASH_block9165,doc19010563,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,params18710560,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1057210573;
});
var anf_obj46810484 = R.makeFunction(function(l19510501,name19610502,namet19710503,params19810504,mixins19910505,variants20010506,shared20110507,_check20210508) {
if(arguments.length !== 8) {
throw R.ffi.throwArityErrorC(L[1224],8,arguments);
}
var b20310509 = {"$var":D,
"$name":"b"};
var variant_DASH_binds20410511 = {"$var":D,
"$name":"variant-binds"};
var anf_assign39410510 = R.makeFunction(function(loc20510542,id20610543) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1231],2,arguments);
}
return R.checkAnnArgs([$type$String18],[id20610543],[L[1235]],function() {
var anf_fun39010556 = G(A119,"s-bind",L[1234]);
var anf_fun39110554 = G(A119,"s-name",L[1233]);
var $z1054610547 = D;
var $f1055210553 = function(_) {
return R.isFunction(anf_fun39110554)?anf_fun39110554.app(l19510501,id20610543):R.ffi.throwNonFunApp(L[1232],anf_fun39110554,[l19510501,id20610543]);
};
try {
if(--R.GAS > 0) {
$z1054610547 = $f1055210553();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1055210553,
"from":L[1232]});
}
} catch($e1054410545) {
if(R.isCont($e1054410545)) {
var $ss1054810549 = {"from":L[1232],
"go":function(anf_arg39210555) {
return $Hanf_arg241210557(anf_arg39210555,A119,anf_fun39010556,loc20510542);
}};
$e1054410545.stack[R.EXN_STACKHEIGHT++] = $ss1054810549;
}
if(R.isPyretException($e1054410545)) {
$e1054410545.pyretStack.push(L[1232]);
}
throw $e1054410545;
}
var $ret1055010551 = $Hanf_arg241210557($z1054610547,A119,anf_fun39010556,loc20510542);
++R.GAS;
return $ret1055010551;
});
});
b20310509.$var = anf_assign39410510;
var anf_assign41310512 = R.makeFunction(function(data_DASH_blob_DASH_id20710526,v20810527) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1227],2,arguments);
}
var vname20910539 = G(v20810527,"name",L[1230]);
var anf_fun39610538 = G(A119,"make-checker-name",L[1229]);
var $z1053010531 = D;
var $f1053610537 = function(_) {
return R.isFunction(anf_fun39610538)?anf_fun39610538.app(vname20910539):R.ffi.throwNonFunApp(L[1228],anf_fun39610538,[vname20910539]);
};
try {
if(--R.GAS > 0) {
$z1053010531 = $f1053610537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1053610537,
"from":L[1228]});
}
} catch($e1052810529) {
if(R.isCont($e1052810529)) {
var $ss1053210533 = {"from":L[1228],
"go":function(checker_DASH_name21010540) {
return $Hchecker_DASH_name242110541(checker_DASH_name21010540,A119,b20310509,data_DASH_blob_DASH_id20710526,list3375,v20810527,vname20910539);
}};
$e1052810529.stack[R.EXN_STACKHEIGHT++] = $ss1053210533;
}
if(R.isPyretException($e1052810529)) {
$e1052810529.pyretStack.push(L[1228]);
}
throw $e1052810529;
}
var $ret1053410535 = $Hchecker_DASH_name242110541($z1053010531,A119,b20310509,data_DASH_blob_DASH_id20710526,list3375,v20810527,vname20910539);
++R.GAS;
return $ret1053410535;
});
variant_DASH_binds20410511.$var = anf_assign41310512;
var anf_fun41410523 = G(G1325,"make-name",L[1226]);
var $z1051510516 = D;
var $f1052110522 = function(_) {
return R.isFunction(anf_fun41410523)?anf_fun41410523.app(name19610502):R.ffi.throwNonFunApp(L[1225],anf_fun41410523,[name19610502]);
};
try {
if(--R.GAS > 0) {
$z1051510516 = $f1052110522();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1052110522,
"from":L[1225]});
}
} catch($e1051310514) {
if(R.isCont($e1051310514)) {
var $ss1051710518 = {"from":L[1225],
"go":function(blob_DASH_id21210524) {
return $Hblob_DASH_id245310525(blob_DASH_id21210524,A119,_check20210508,b20310509,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,mixins19910505,name19610502,namet19710503,params19810504,rest_DASH_stmts15910383,shared20110507,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1051310514.stack[R.EXN_STACKHEIGHT++] = $ss1051710518;
}
if(R.isPyretException($e1051310514)) {
$e1051310514.pyretStack.push(L[1225]);
}
throw $e1051310514;
}
var $ret1051910520 = $Hblob_DASH_id245310525($z1051510516,A119,_check20210508,b20310509,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,mixins19910505,name19610502,namet19710503,params19810504,rest_DASH_stmts15910383,shared20110507,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1051910520;
});
var anf_obj47010485 = R.makeFunction(function(l22010486,name22110487,ann22210488) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1223],3,arguments);
}
var $z1049110492 = D;
var $f1049710498 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(rest_DASH_stmts15910383,let_DASH_binds15510381,letrec_DASH_binds15610382,type_DASH_let_DASH_binds15710384):R.ffi.throwNonFunApp(L[1223],desugar_DASH_scope_DASH_block9165.$var,[rest_DASH_stmts15910383,let_DASH_binds15510381,letrec_DASH_binds15610382,type_DASH_let_DASH_binds15710384]);
};
try {
if(--R.GAS > 0) {
$z1049110492 = $f1049710498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1049710498,
"from":L[1223]});
}
} catch($e1048910490) {
if(R.isCont($e1048910490)) {
var $ss1049310494 = {"from":L[1223],
"go":function(ann_DASH_check_DASH_temp46910499) {
return $Hann_DASH_check_DASH_temp245410500(ann_DASH_check_DASH_temp46910499);
}};
$e1048910490.stack[R.EXN_STACKHEIGHT++] = $ss1049310494;
}
if(R.isPyretException($e1048910490)) {
$e1048910490.pyretStack.push(L[1223]);
}
throw $e1048910490;
}
var $ret1049510496 = $Hann_DASH_check_DASH_temp245410500($z1049110492);
++R.GAS;
return $ret1049510496;
});
var anf_arg47110429 = R.makeObject({"s-type":anf_obj34110480,
"s-let":anf_obj34510481,
"s-var":anf_obj34910482,
"s-fun":anf_obj38710483,
"s-data-expr":anf_obj46810484,
"s-contract":anf_obj47010485});
var anf_arg52610430 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1216],0,arguments);
}
var cases_DASH_val3410479 = rest_DASH_stmts15910383;
var anf_fun47310443 = G(cases_DASH_val3410479,"_match",L[1217]);
var anf_obj47710449 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1220],0,arguments);
}
var anf_fun47510477 = G(list3375,"make",L[1222]);
var $z1046810469 = D;
var $f1047410475 = function(_) {
return R.isFunction(wrapper17110464)?wrapper17110464.app(f15810377):R.ffi.throwNonFunApp(L[1221],wrapper17110464,[f15810377]);
};
try {
if(--R.GAS > 0) {
$z1046810469 = $f1047410475();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1047410475,
"from":L[1221]});
}
} catch($e1046610467) {
if(R.isCont($e1046610467)) {
var $ss1047010471 = {"from":L[1221],
"go":function(anf_array_val47610476) {
return $Hanf_array_val245610478(anf_array_val47610476,anf_fun47510477);
}};
$e1046610467.stack[R.EXN_STACKHEIGHT++] = $ss1047010471;
}
if(R.isPyretException($e1046610467)) {
$e1046610467.pyretStack.push(L[1221]);
}
throw $e1046610467;
}
var $ret1047210473 = $Hanf_array_val245610478($z1046810469,anf_fun47510477);
++R.GAS;
return $ret1047210473;
});
var anf_obj52210450 = R.makeFunction(function($underscore22310451,$underscore22410452) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1218],2,arguments);
}
var $z1045510456 = D;
var $f1046110462 = function(_) {
return R.isFunction(is_DASH_link3510380)?is_DASH_link3510380.app(let_DASH_binds15510381):R.ffi.throwNonFunApp(L[1219],is_DASH_link3510380,[let_DASH_binds15510381]);
};
try {
if(--R.GAS > 0) {
$z1045510456 = $f1046110462();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1046110462,
"from":L[1219]});
}
} catch($e1045310454) {
if(R.isCont($e1045310454)) {
var $ss1045710458 = {"from":L[1219],
"go":function(or_DASH_oper_DASH_3110463) {
return $Hor_DASH_oper_DASH_247610465(or_DASH_oper_DASH_3110463,A119,desugar_DASH_scope_DASH_block9165,f15810377,is_DASH_link3510380,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrapper17110464,not11);
}};
$e1045310454.stack[R.EXN_STACKHEIGHT++] = $ss1045710458;
}
if(R.isPyretException($e1045310454)) {
$e1045310454.pyretStack.push(L[1219]);
}
throw $e1045310454;
}
var $ret1045910460 = $Hor_DASH_oper_DASH_247610465($z1045510456,A119,desugar_DASH_scope_DASH_block9165,f15810377,is_DASH_link3510380,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrapper17110464,not11);
++R.GAS;
return $ret1045910460;
});
var anf_arg52310444 = R.makeObject({"empty":anf_obj47710449,
"link":anf_obj52210450});
var anf_arg52510445 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1217],0,arguments);
}
var ann_DASH_check_DASH_temp52410448 = R.throwNoBranchesMatched(L[1217],("cases"));
return ann_DASH_check_DASH_temp52410448;
});
var $z1043510436 = D;
var $f1044110442 = function(_) {
return R.isFunction(anf_fun47310443)?anf_fun47310443.app(anf_arg52310444,anf_arg52510445):R.ffi.throwNonFunApp(L[1216],anf_fun47310443,[anf_arg52310444,anf_arg52510445]);
};
try {
if(--R.GAS > 0) {
$z1043510436 = $f1044110442();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1044110442,
"from":L[1216]});
}
} catch($e1043310434) {
if(R.isCont($e1043310434)) {
var $ss1043710438 = {"from":L[1216],
"go":function(ann_DASH_check_DASH_temp47210446) {
return $Hann_DASH_check_DASH_temp247710447(ann_DASH_check_DASH_temp47210446);
}};
$e1043310434.stack[R.EXN_STACKHEIGHT++] = $ss1043710438;
}
if(R.isPyretException($e1043310434)) {
$e1043310434.pyretStack.push(L[1216]);
}
throw $e1043310434;
}
var $ret1043910440 = $Hann_DASH_check_DASH_temp247710447($z1043510436);
++R.GAS;
return $ret1043910440;
});
var $z1042010421 = D;
var $f1042610427 = function(_) {
return R.isFunction(anf_fun31010428)?anf_fun31010428.app(anf_arg47110429,anf_arg52610430):R.ffi.throwNonFunApp(L[1215],anf_fun31010428,[anf_arg47110429,anf_arg52610430]);
};
try {
if(--R.GAS > 0) {
$z1042010421 = $f1042610427();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1042610427,
"from":L[1215]});
}
} catch($e1041810419) {
if(R.isCont($e1041810419)) {
var $ss1042210423 = {"from":L[1215],
"go":function(ann_DASH_check_DASH_temp25710431) {
return $Hann_DASH_check_DASH_temp247810432(ann_DASH_check_DASH_temp25710431);
}};
$e1041810419.stack[R.EXN_STACKHEIGHT++] = $ss1042210423;
}
if(R.isPyretException($e1041810419)) {
$e1041810419.pyretStack.push(L[1215]);
}
throw $e1041810419;
}
var $ret1042410425 = $Hann_DASH_check_DASH_temp247810432($z1042010421);
++R.GAS;
return $ret1042410425;
});
var anf_if52910416 = R.isBoolean(if_DASH_2310376);
if(R.isPyretTrue(anf_if52910416)) {
if(R.isPyretTrue(if_DASH_2310376)) {
var $z1039010391 = D;
var $f1039610397 = function(_) {
return R.isFunction(if_helper30810398)?if_helper30810398.app(wrap_DASH_lets16110386.$var):R.ffi.throwNonFunApp(L[1212],if_helper30810398,[wrap_DASH_lets16110386.$var]);
};
try {
if(--R.GAS > 0) {
$z1039010391 = $f1039610397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1039610397,
"from":L[1212]});
}
} catch($e1038810389) {
if(R.isCont($e1038810389)) {
var $ss1039210393 = {"from":L[1212],
"go":function(cont_tail_app54110399) {
return $Hcont_tail_app247910400(cont_tail_app54110399);
}};
$e1038810389.stack[R.EXN_STACKHEIGHT++] = $ss1039210393;
}
if(R.isPyretException($e1038810389)) {
$e1038810389.pyretStack.push(L[1212]);
}
throw $e1038810389;
}
var $ret1039410395 = $Hcont_tail_app247910400($z1039010391);
++R.GAS;
return $ret1039410395;
} else {
var $z1040310404 = D;
var $f1040910410 = function(_) {
return R.isFunction(is_DASH_link3510380)?is_DASH_link3510380.app(letrec_DASH_binds15610382):R.ffi.throwNonFunApp(L[1213],is_DASH_link3510380,[letrec_DASH_binds15610382]);
};
try {
if(--R.GAS > 0) {
$z1040310404 = $f1040910410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1040910410,
"from":L[1213]});
}
} catch($e1040110402) {
if(R.isCont($e1040110402)) {
var $ss1040510406 = {"from":L[1213],
"go":function(if_DASH_2210411) {
return $Hif_DASH_248310412(if_DASH_2210411,if_helper30810398,is_DASH_link3510380,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387);
}};
$e1040110402.stack[R.EXN_STACKHEIGHT++] = $ss1040510406;
}
if(R.isPyretException($e1040110402)) {
$e1040110402.pyretStack.push(L[1213]);
}
throw $e1040110402;
}
var $ret1040710408 = $Hif_DASH_248310412($z1040310404,if_helper30810398,is_DASH_link3510380,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387);
++R.GAS;
return $ret1040710408;
}
} else {
var cont_tail_arg52710415 = R.throwNonBooleanCondition(L[1214],("if"),if_DASH_2310376);
if(--R.GAS > 0) {
$z1041310414 = R.isFunction(if_helper30810398)?if_helper30810398.app(cont_tail_arg52710415):R.ffi.throwNonFunApp(L[1214],if_helper30810398,[cont_tail_arg52710415]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper30810398)?if_helper30810398.app(cont_tail_arg52710415):R.ffi.throwNonFunApp(L[1214],if_helper30810398,[cont_tail_arg52710415]);
},
"from":L[1214]});
}
++R.GAS;
return $z1041310414;
}
};
var $Hcont_tail_app247910400 = function(cont_tail_app54110399) {
return cont_tail_app54110399;
};
var $Hif_DASH_248310412 = function(if_DASH_2210411,if_helper30810398,is_DASH_link3510380,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387) {
var anf_if53210658 = R.isBoolean(if_DASH_2210411);
if(R.isPyretTrue(anf_if53210658)) {
if(R.isPyretTrue(if_DASH_2210411)) {
var $z1063310634 = D;
var $f1063910640 = function(_) {
return R.isFunction(if_helper30810398)?if_helper30810398.app(wrap_DASH_letrecs16010385.$var):R.ffi.throwNonFunApp(L[1250],if_helper30810398,[wrap_DASH_letrecs16010385.$var]);
};
try {
if(--R.GAS > 0) {
$z1063310634 = $f1063910640();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1063910640,
"from":L[1250]});
}
} catch($e1063110632) {
if(R.isCont($e1063110632)) {
var $ss1063510636 = {"from":L[1250],
"go":function(cont_tail_app54010641) {
return $Hcont_tail_app248010642(cont_tail_app54010641);
}};
$e1063110632.stack[R.EXN_STACKHEIGHT++] = $ss1063510636;
}
if(R.isPyretException($e1063110632)) {
$e1063110632.pyretStack.push(L[1250]);
}
throw $e1063110632;
}
var $ret1063710638 = $Hcont_tail_app248010642($z1063310634);
++R.GAS;
return $ret1063710638;
} else {
var $z1064510646 = D;
var $f1065110652 = function(_) {
return R.isFunction(is_DASH_link3510380)?is_DASH_link3510380.app(type_DASH_let_DASH_binds15710384):R.ffi.throwNonFunApp(L[1251],is_DASH_link3510380,[type_DASH_let_DASH_binds15710384]);
};
try {
if(--R.GAS > 0) {
$z1064510646 = $f1065110652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1065110652,
"from":L[1251]});
}
} catch($e1064310644) {
if(R.isCont($e1064310644)) {
var $ss1064710648 = {"from":L[1251],
"go":function(if_DASH_2110653) {
return $Hif_DASH_248210654(if_DASH_2110653,if_helper30810398,wrap_DASH_type_DASH_lets16210387);
}};
$e1064310644.stack[R.EXN_STACKHEIGHT++] = $ss1064710648;
}
if(R.isPyretException($e1064310644)) {
$e1064310644.pyretStack.push(L[1251]);
}
throw $e1064310644;
}
var $ret1064910650 = $Hif_DASH_248210654($z1064510646,if_helper30810398,wrap_DASH_type_DASH_lets16210387);
++R.GAS;
return $ret1064910650;
}
} else {
var cont_tail_arg53010657 = R.throwNonBooleanCondition(L[1252],("if"),if_DASH_2210411);
if(--R.GAS > 0) {
$z1065510656 = R.isFunction(if_helper30810398)?if_helper30810398.app(cont_tail_arg53010657):R.ffi.throwNonFunApp(L[1252],if_helper30810398,[cont_tail_arg53010657]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper30810398)?if_helper30810398.app(cont_tail_arg53010657):R.ffi.throwNonFunApp(L[1252],if_helper30810398,[cont_tail_arg53010657]);
},
"from":L[1252]});
}
++R.GAS;
return $z1065510656;
}
};
var $Hcont_tail_app248010642 = function(cont_tail_app54010641) {
return cont_tail_app54010641;
};
var $Hif_DASH_248210654 = function(if_DASH_2110653,if_helper30810398,wrap_DASH_type_DASH_lets16210387) {
var anf_if53510679 = R.isBoolean(if_DASH_2110653);
if(R.isPyretTrue(anf_if53510679)) {
if(R.isPyretTrue(if_DASH_2110653)) {
var $z1066110662 = D;
var $f1066710668 = function(_) {
return R.isFunction(if_helper30810398)?if_helper30810398.app(wrap_DASH_type_DASH_lets16210387.$var):R.ffi.throwNonFunApp(L[1253],if_helper30810398,[wrap_DASH_type_DASH_lets16210387.$var]);
};
try {
if(--R.GAS > 0) {
$z1066110662 = $f1066710668();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1066710668,
"from":L[1253]});
}
} catch($e1065910660) {
if(R.isCont($e1065910660)) {
var $ss1066310664 = {"from":L[1253],
"go":function(cont_tail_app53910669) {
return $Hcont_tail_app248110670(cont_tail_app53910669);
}};
$e1065910660.stack[R.EXN_STACKHEIGHT++] = $ss1066310664;
}
if(R.isPyretException($e1065910660)) {
$e1065910660.pyretStack.push(L[1253]);
}
throw $e1065910660;
}
var $ret1066510666 = $Hcont_tail_app248110670($z1066110662);
++R.GAS;
return $ret1066510666;
} else {
var cont_tail_arg53710673 = R.makeFunction(function(e17210674) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1254],1,arguments);
}
var ann_DASH_check_DASH_temp53610675 = e17210674;
return ann_DASH_check_DASH_temp53610675;
});
if(--R.GAS > 0) {
$z1067110672 = R.isFunction(if_helper30810398)?if_helper30810398.app(cont_tail_arg53710673):R.ffi.throwNonFunApp(L[1254],if_helper30810398,[cont_tail_arg53710673]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper30810398)?if_helper30810398.app(cont_tail_arg53710673):R.ffi.throwNonFunApp(L[1254],if_helper30810398,[cont_tail_arg53710673]);
},
"from":L[1254]});
}
++R.GAS;
return $z1067110672;
}
} else {
var cont_tail_arg53310678 = R.throwNonBooleanCondition(L[1255],("if"),if_DASH_2110653);
if(--R.GAS > 0) {
$z1067610677 = R.isFunction(if_helper30810398)?if_helper30810398.app(cont_tail_arg53310678):R.ffi.throwNonFunApp(L[1255],if_helper30810398,[cont_tail_arg53310678]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper30810398)?if_helper30810398.app(cont_tail_arg53310678):R.ffi.throwNonFunApp(L[1255],if_helper30810398,[cont_tail_arg53310678]);
},
"from":L[1255]});
}
++R.GAS;
return $z1067610677;
}
};
var $Hcont_tail_app248110670 = function(cont_tail_app53910669) {
return cont_tail_app53910669;
};
var $Hann_DASH_check_DASH_temp247810432 = function(ann_DASH_check_DASH_temp25710431) {
return ann_DASH_check_DASH_temp25710431;
};
var $Hann_DASH_check_DASH_temp247710447 = function(ann_DASH_check_DASH_temp47210446) {
return ann_DASH_check_DASH_temp47210446;
};
var $Hor_DASH_oper_DASH_247610465 = function(or_DASH_oper_DASH_3110463,A119,desugar_DASH_scope_DASH_block9165,f15810377,is_DASH_link3510380,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrapper17110464,not11) {
var if_helper47910690 = R.makeFunction(function(if_helper_arg48010709) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1219],1,arguments);
}
var $z1071210713 = D;
var $f1071810719 = function(_) {
return R.isFunction(not11)?not11.app(if_helper_arg48010709):R.ffi.throwNonFunApp(L[1257],not11,[if_helper_arg48010709]);
};
try {
if(--R.GAS > 0) {
$z1071210713 = $f1071810719();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1071810719,
"from":L[1257]});
}
} catch($e1071010711) {
if(R.isCont($e1071010711)) {
var $ss1071410715 = {"from":L[1257],
"go":function(if_DASH_3010720) {
return $Hif_DASH_247010721(if_DASH_3010720,A119,desugar_DASH_scope_DASH_block9165,f15810377,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464);
}};
$e1071010711.stack[R.EXN_STACKHEIGHT++] = $ss1071410715;
}
if(R.isPyretException($e1071010711)) {
$e1071010711.pyretStack.push(L[1257]);
}
throw $e1071010711;
}
var $ret1071610717 = $Hif_DASH_247010721($z1071210713,A119,desugar_DASH_scope_DASH_block9165,f15810377,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464);
++R.GAS;
return $ret1071610717;
});
var anf_if51210708 = R.isBoolean(or_DASH_oper_DASH_3110463);
if(R.isPyretTrue(anf_if51210708)) {
if(R.isPyretTrue(or_DASH_oper_DASH_3110463)) {
var $z1068210683 = D;
var $f1068810689 = function(_) {
return R.isFunction(if_helper47910690)?if_helper47910690.app((true)):R.ffi.throwNonFunApp(L[1219],if_helper47910690,[(true)]);
};
try {
if(--R.GAS > 0) {
$z1068210683 = $f1068810689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1068810689,
"from":L[1219]});
}
} catch($e1068010681) {
if(R.isCont($e1068010681)) {
var $ss1068410685 = {"from":L[1219],
"go":function(cont_tail_app52110691) {
return $Hcont_tail_app247110692(cont_tail_app52110691);
}};
$e1068010681.stack[R.EXN_STACKHEIGHT++] = $ss1068410685;
}
if(R.isPyretException($e1068010681)) {
$e1068010681.pyretStack.push(L[1219]);
}
throw $e1068010681;
}
var $ret1068610687 = $Hcont_tail_app247110692($z1068210683);
++R.GAS;
return $ret1068610687;
} else {
var $z1069510696 = D;
var $f1070110702 = function(_) {
return R.isFunction(is_DASH_link3510380)?is_DASH_link3510380.app(letrec_DASH_binds15610382):R.ffi.throwNonFunApp(L[1219],is_DASH_link3510380,[letrec_DASH_binds15610382]);
};
try {
if(--R.GAS > 0) {
$z1069510696 = $f1070110702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1070110702,
"from":L[1219]});
}
} catch($e1069310694) {
if(R.isCont($e1069310694)) {
var $ss1069710698 = {"from":L[1219],
"go":function(or_DASH_oper_DASH_3210703) {
return $Hor_DASH_oper_DASH_247510704(or_DASH_oper_DASH_3210703,if_helper47910690,is_DASH_link3510380,type_DASH_let_DASH_binds15710384);
}};
$e1069310694.stack[R.EXN_STACKHEIGHT++] = $ss1069710698;
}
if(R.isPyretException($e1069310694)) {
$e1069310694.pyretStack.push(L[1219]);
}
throw $e1069310694;
}
var $ret1069910700 = $Hor_DASH_oper_DASH_247510704($z1069510696,if_helper47910690,is_DASH_link3510380,type_DASH_let_DASH_binds15710384);
++R.GAS;
return $ret1069910700;
}
} else {
var cont_tail_arg51010707 = R.throwNonBooleanOp(L[1256],("first"),("or"),or_DASH_oper_DASH_3110463);
if(--R.GAS > 0) {
$z1070510706 = R.isFunction(if_helper47910690)?if_helper47910690.app(cont_tail_arg51010707):R.ffi.throwNonFunApp(L[1256],if_helper47910690,[cont_tail_arg51010707]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper47910690)?if_helper47910690.app(cont_tail_arg51010707):R.ffi.throwNonFunApp(L[1256],if_helper47910690,[cont_tail_arg51010707]);
},
"from":L[1256]});
}
++R.GAS;
return $z1070510706;
}
};
var $Hcont_tail_app247110692 = function(cont_tail_app52110691) {
return cont_tail_app52110691;
};
var $Hor_DASH_oper_DASH_247510704 = function(or_DASH_oper_DASH_3210703,if_helper47910690,is_DASH_link3510380,type_DASH_let_DASH_binds15710384) {
var anf_if51510749 = R.isBoolean(or_DASH_oper_DASH_3210703);
if(R.isPyretTrue(anf_if51510749)) {
if(R.isPyretTrue(or_DASH_oper_DASH_3210703)) {
var $z1072410725 = D;
var $f1073010731 = function(_) {
return R.isFunction(if_helper47910690)?if_helper47910690.app((true)):R.ffi.throwNonFunApp(L[1219],if_helper47910690,[(true)]);
};
try {
if(--R.GAS > 0) {
$z1072410725 = $f1073010731();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1073010731,
"from":L[1219]});
}
} catch($e1072210723) {
if(R.isCont($e1072210723)) {
var $ss1072610727 = {"from":L[1219],
"go":function(cont_tail_app52010732) {
return $Hcont_tail_app247210733(cont_tail_app52010732);
}};
$e1072210723.stack[R.EXN_STACKHEIGHT++] = $ss1072610727;
}
if(R.isPyretException($e1072210723)) {
$e1072210723.pyretStack.push(L[1219]);
}
throw $e1072210723;
}
var $ret1072810729 = $Hcont_tail_app247210733($z1072410725);
++R.GAS;
return $ret1072810729;
} else {
var $z1073610737 = D;
var $f1074210743 = function(_) {
return R.isFunction(is_DASH_link3510380)?is_DASH_link3510380.app(type_DASH_let_DASH_binds15710384):R.ffi.throwNonFunApp(L[1219],is_DASH_link3510380,[type_DASH_let_DASH_binds15710384]);
};
try {
if(--R.GAS > 0) {
$z1073610737 = $f1074210743();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1074210743,
"from":L[1219]});
}
} catch($e1073410735) {
if(R.isCont($e1073410735)) {
var $ss1073810739 = {"from":L[1219],
"go":function(or_DASH_oper_DASH_3310744) {
return $Hor_DASH_oper_DASH_247410745(or_DASH_oper_DASH_3310744,if_helper47910690);
}};
$e1073410735.stack[R.EXN_STACKHEIGHT++] = $ss1073810739;
}
if(R.isPyretException($e1073410735)) {
$e1073410735.pyretStack.push(L[1219]);
}
throw $e1073410735;
}
var $ret1074010741 = $Hor_DASH_oper_DASH_247410745($z1073610737,if_helper47910690);
++R.GAS;
return $ret1074010741;
}
} else {
var cont_tail_arg51310748 = R.throwNonBooleanOp(L[1258],("first"),("or"),or_DASH_oper_DASH_3210703);
if(--R.GAS > 0) {
$z1074610747 = R.isFunction(if_helper47910690)?if_helper47910690.app(cont_tail_arg51310748):R.ffi.throwNonFunApp(L[1258],if_helper47910690,[cont_tail_arg51310748]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper47910690)?if_helper47910690.app(cont_tail_arg51310748):R.ffi.throwNonFunApp(L[1258],if_helper47910690,[cont_tail_arg51310748]);
},
"from":L[1258]});
}
++R.GAS;
return $z1074610747;
}
};
var $Hcont_tail_app247210733 = function(cont_tail_app52010732) {
return cont_tail_app52010732;
};
var $Hor_DASH_oper_DASH_247410745 = function(or_DASH_oper_DASH_3310744,if_helper47910690) {
var anf_if51810765 = R.isBoolean(or_DASH_oper_DASH_3310744);
if(R.isPyretTrue(anf_if51810765)) {
var $z1075210753 = D;
var $f1075810759 = function(_) {
return R.isFunction(if_helper47910690)?if_helper47910690.app(or_DASH_oper_DASH_3310744):R.ffi.throwNonFunApp(L[1219],if_helper47910690,[or_DASH_oper_DASH_3310744]);
};
try {
if(--R.GAS > 0) {
$z1075210753 = $f1075810759();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1075810759,
"from":L[1219]});
}
} catch($e1075010751) {
if(R.isCont($e1075010751)) {
var $ss1075410755 = {"from":L[1219],
"go":function(cont_tail_app51910760) {
return $Hcont_tail_app247310761(cont_tail_app51910760);
}};
$e1075010751.stack[R.EXN_STACKHEIGHT++] = $ss1075410755;
}
if(R.isPyretException($e1075010751)) {
$e1075010751.pyretStack.push(L[1219]);
}
throw $e1075010751;
}
var $ret1075610757 = $Hcont_tail_app247310761($z1075210753);
++R.GAS;
return $ret1075610757;
} else {
var cont_tail_arg51610764 = R.throwNonBooleanOp(L[1259],("second"),("or"),or_DASH_oper_DASH_3310744);
if(--R.GAS > 0) {
$z1076210763 = R.isFunction(if_helper47910690)?if_helper47910690.app(cont_tail_arg51610764):R.ffi.throwNonFunApp(L[1259],if_helper47910690,[cont_tail_arg51610764]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper47910690)?if_helper47910690.app(cont_tail_arg51610764):R.ffi.throwNonFunApp(L[1259],if_helper47910690,[cont_tail_arg51610764]);
},
"from":L[1259]});
}
++R.GAS;
return $z1076210763;
}
};
var $Hcont_tail_app247310761 = function(cont_tail_app51910760) {
return cont_tail_app51910760;
};
var $Hif_DASH_247010721 = function(if_DASH_3010720,A119,desugar_DASH_scope_DASH_block9165,f15810377,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464) {
var if_helper48110778 = R.makeFunction(function(if_helper_arg48210800) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1257],1,arguments);
}
var ann_DASH_check_DASH_temp47810801 = if_helper_arg48210800;
return ann_DASH_check_DASH_temp47810801;
});
var anf_if48510799 = R.isBoolean(if_DASH_3010720);
if(R.isPyretTrue(anf_if48510799)) {
if(R.isPyretTrue(if_DASH_3010720)) {
var anf_fun50110776 = G(list3375,"make",L[1260]);
var $z1076810769 = D;
var $f1077410775 = function(_) {
return R.isFunction(anf_fun50110776)?anf_fun50110776.app([]):R.ffi.throwNonFunApp(L[1260],anf_fun50110776,[[]]);
};
try {
if(--R.GAS > 0) {
$z1076810769 = $f1077410775();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1077410775,
"from":L[1260]});
}
} catch($e1076610767) {
if(R.isCont($e1076610767)) {
var $ss1077010771 = {"from":L[1260],
"go":function(anf_arg50210777) {
return $Hanf_arg246110779(anf_arg50210777,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383);
}};
$e1076610767.stack[R.EXN_STACKHEIGHT++] = $ss1077010771;
}
if(R.isPyretException($e1076610767)) {
$e1076610767.pyretStack.push(L[1260]);
}
throw $e1076610767;
}
var $ret1077210773 = $Hanf_arg246110779($z1076810769,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383);
++R.GAS;
return $ret1077210773;
} else {
var anf_fun48610793 = G(list3375,"make",L[1264]);
var anf_fun48710794 = G(A119,"s-block",L[1263]);
var anf_arg48810792 = G(f15810377,"l",L[1262]);
var anf_fun48910790 = G(list3375,"make",L[1261]);
var $z1078210783 = D;
var $f1078810789 = function(_) {
return R.isFunction(anf_fun48910790)?anf_fun48910790.app([]):R.ffi.throwNonFunApp(L[1261],anf_fun48910790,[[]]);
};
try {
if(--R.GAS > 0) {
$z1078210783 = $f1078810789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1078810789,
"from":L[1261]});
}
} catch($e1078010781) {
if(R.isCont($e1078010781)) {
var $ss1078410785 = {"from":L[1261],
"go":function(anf_arg49010791) {
return $Hanf_arg246910795(anf_arg49010791,anf_arg48810792,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464);
}};
$e1078010781.stack[R.EXN_STACKHEIGHT++] = $ss1078410785;
}
if(R.isPyretException($e1078010781)) {
$e1078010781.pyretStack.push(L[1261]);
}
throw $e1078010781;
}
var $ret1078610787 = $Hanf_arg246910795($z1078210783,anf_arg48810792,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464);
++R.GAS;
return $ret1078610787;
}
} else {
var cont_tail_arg48310798 = R.throwNonBooleanCondition(L[1257],("if"),if_DASH_3010720);
if(--R.GAS > 0) {
$z1079610797 = R.isFunction(if_helper48110778)?if_helper48110778.app(cont_tail_arg48310798):R.ffi.throwNonFunApp(L[1257],if_helper48110778,[cont_tail_arg48310798]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper48110778)?if_helper48110778.app(cont_tail_arg48310798):R.ffi.throwNonFunApp(L[1257],if_helper48110778,[cont_tail_arg48310798]);
},
"from":L[1257]});
}
++R.GAS;
return $z1079610797;
}
};
var $Hanf_arg246110779 = function(anf_arg50210777,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383) {
var anf_fun50310812 = G(list3375,"make",L[1265]);
var $z1080410805 = D;
var $f1081010811 = function(_) {
return R.isFunction(anf_fun50310812)?anf_fun50310812.app([]):R.ffi.throwNonFunApp(L[1265],anf_fun50310812,[[]]);
};
try {
if(--R.GAS > 0) {
$z1080410805 = $f1081010811();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1081010811,
"from":L[1265]});
}
} catch($e1080210803) {
if(R.isCont($e1080210803)) {
var $ss1080610807 = {"from":L[1265],
"go":function(anf_arg50410813) {
return $Hanf_arg246010814(anf_arg50410813,anf_arg50210777,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383);
}};
$e1080210803.stack[R.EXN_STACKHEIGHT++] = $ss1080610807;
}
if(R.isPyretException($e1080210803)) {
$e1080210803.pyretStack.push(L[1265]);
}
throw $e1080210803;
}
var $ret1080810809 = $Hanf_arg246010814($z1080410805,anf_arg50210777,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383);
++R.GAS;
return $ret1080810809;
};
var $Hanf_arg246010814 = function(anf_arg50410813,anf_arg50210777,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383) {
var anf_fun50510825 = G(list3375,"make",L[1266]);
var $z1081710818 = D;
var $f1082310824 = function(_) {
return R.isFunction(anf_fun50510825)?anf_fun50510825.app([]):R.ffi.throwNonFunApp(L[1266],anf_fun50510825,[[]]);
};
try {
if(--R.GAS > 0) {
$z1081710818 = $f1082310824();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1082310824,
"from":L[1266]});
}
} catch($e1081510816) {
if(R.isCont($e1081510816)) {
var $ss1081910820 = {"from":L[1266],
"go":function(anf_arg50610826) {
return $Hanf_arg245910827(anf_arg50610826,anf_arg50210777,anf_arg50410813,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,rest_DASH_stmts15910383);
}};
$e1081510816.stack[R.EXN_STACKHEIGHT++] = $ss1081910820;
}
if(R.isPyretException($e1081510816)) {
$e1081510816.pyretStack.push(L[1266]);
}
throw $e1081510816;
}
var $ret1082110822 = $Hanf_arg245910827($z1081710818,anf_arg50210777,anf_arg50410813,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,rest_DASH_stmts15910383);
++R.GAS;
return $ret1082110822;
};
var $Hanf_arg245910827 = function(anf_arg50610826,anf_arg50210777,anf_arg50410813,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,rest_DASH_stmts15910383) {
var $z1083010831 = D;
var $f1083610837 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(rest_DASH_stmts15910383,anf_arg50210777,anf_arg50410813,anf_arg50610826):R.ffi.throwNonFunApp(L[1267],desugar_DASH_scope_DASH_block9165.$var,[rest_DASH_stmts15910383,anf_arg50210777,anf_arg50410813,anf_arg50610826]);
};
try {
if(--R.GAS > 0) {
$z1083010831 = $f1083610837();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1083610837,
"from":L[1267]});
}
} catch($e1082810829) {
if(R.isCont($e1082810829)) {
var $ss1083210833 = {"from":L[1267],
"go":function(anf_arg50710838) {
return $Hanf_arg245810839(anf_arg50710838,f15810377,if_helper48110778,link3774);
}};
$e1082810829.stack[R.EXN_STACKHEIGHT++] = $ss1083210833;
}
if(R.isPyretException($e1082810829)) {
$e1082810829.pyretStack.push(L[1267]);
}
throw $e1082810829;
}
var $ret1083410835 = $Hanf_arg245810839($z1083010831,f15810377,if_helper48110778,link3774);
++R.GAS;
return $ret1083410835;
};
var $Hanf_arg245810839 = function(anf_arg50710838,f15810377,if_helper48110778,link3774) {
var $z1084210843 = D;
var $f1084810849 = function(_) {
return R.isFunction(link3774)?link3774.app(f15810377,anf_arg50710838):R.ffi.throwNonFunApp(L[1268],link3774,[f15810377,anf_arg50710838]);
};
try {
if(--R.GAS > 0) {
$z1084210843 = $f1084810849();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1084810849,
"from":L[1268]});
}
} catch($e1084010841) {
if(R.isCont($e1084010841)) {
var $ss1084410845 = {"from":L[1268],
"go":function(cont_tail_arg50810850) {
return $Hcont_tail_arg245710851(cont_tail_arg50810850,if_helper48110778);
}};
$e1084010841.stack[R.EXN_STACKHEIGHT++] = $ss1084410845;
}
if(R.isPyretException($e1084010841)) {
$e1084010841.pyretStack.push(L[1268]);
}
throw $e1084010841;
}
var $ret1084610847 = $Hcont_tail_arg245710851($z1084210843,if_helper48110778);
++R.GAS;
return $ret1084610847;
};
var $Hcont_tail_arg245710851 = function(cont_tail_arg50810850,if_helper48110778) {
if(--R.GAS > 0) {
$z1085210853 = R.isFunction(if_helper48110778)?if_helper48110778.app(cont_tail_arg50810850):R.ffi.throwNonFunApp(L[1268],if_helper48110778,[cont_tail_arg50810850]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper48110778)?if_helper48110778.app(cont_tail_arg50810850):R.ffi.throwNonFunApp(L[1268],if_helper48110778,[cont_tail_arg50810850]);
},
"from":L[1268]});
}
++R.GAS;
return $z1085210853;
};
var $Hanf_arg246910795 = function(anf_arg49010791,anf_arg48810792,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464) {
var anf_fun49110864 = G(list3375,"make",L[1269]);
var $z1085610857 = D;
var $f1086210863 = function(_) {
return R.isFunction(anf_fun49110864)?anf_fun49110864.app([]):R.ffi.throwNonFunApp(L[1269],anf_fun49110864,[[]]);
};
try {
if(--R.GAS > 0) {
$z1085610857 = $f1086210863();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1086210863,
"from":L[1269]});
}
} catch($e1085410855) {
if(R.isCont($e1085410855)) {
var $ss1085810859 = {"from":L[1269],
"go":function(anf_arg49210865) {
return $Hanf_arg246810866(anf_arg49210865,anf_arg48810792,anf_arg49010791,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464);
}};
$e1085410855.stack[R.EXN_STACKHEIGHT++] = $ss1085810859;
}
if(R.isPyretException($e1085410855)) {
$e1085410855.pyretStack.push(L[1269]);
}
throw $e1085410855;
}
var $ret1086010861 = $Hanf_arg246810866($z1085610857,anf_arg48810792,anf_arg49010791,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464);
++R.GAS;
return $ret1086010861;
};
var $Hanf_arg246810866 = function(anf_arg49210865,anf_arg48810792,anf_arg49010791,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,list3375,rest_DASH_stmts15910383,wrapper17110464) {
var anf_fun49310877 = G(list3375,"make",L[1270]);
var $z1086910870 = D;
var $f1087510876 = function(_) {
return R.isFunction(anf_fun49310877)?anf_fun49310877.app([]):R.ffi.throwNonFunApp(L[1270],anf_fun49310877,[[]]);
};
try {
if(--R.GAS > 0) {
$z1086910870 = $f1087510876();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1087510876,
"from":L[1270]});
}
} catch($e1086710868) {
if(R.isCont($e1086710868)) {
var $ss1087110872 = {"from":L[1270],
"go":function(anf_arg49410878) {
return $Hanf_arg246710879(anf_arg49410878,anf_arg48810792,anf_arg49010791,anf_arg49210865,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,rest_DASH_stmts15910383,wrapper17110464);
}};
$e1086710868.stack[R.EXN_STACKHEIGHT++] = $ss1087110872;
}
if(R.isPyretException($e1086710868)) {
$e1086710868.pyretStack.push(L[1270]);
}
throw $e1086710868;
}
var $ret1087310874 = $Hanf_arg246710879($z1086910870,anf_arg48810792,anf_arg49010791,anf_arg49210865,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,rest_DASH_stmts15910383,wrapper17110464);
++R.GAS;
return $ret1087310874;
};
var $Hanf_arg246710879 = function(anf_arg49410878,anf_arg48810792,anf_arg49010791,anf_arg49210865,anf_fun48610793,anf_fun48710794,desugar_DASH_scope_DASH_block9165,f15810377,if_helper48110778,link3774,rest_DASH_stmts15910383,wrapper17110464) {
var $z1088210883 = D;
var $f1088810889 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(rest_DASH_stmts15910383,anf_arg49010791,anf_arg49210865,anf_arg49410878):R.ffi.throwNonFunApp(L[1271],desugar_DASH_scope_DASH_block9165.$var,[rest_DASH_stmts15910383,anf_arg49010791,anf_arg49210865,anf_arg49410878]);
};
try {
if(--R.GAS > 0) {
$z1088210883 = $f1088810889();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1088810889,
"from":L[1271]});
}
} catch($e1088010881) {
if(R.isCont($e1088010881)) {
var $ss1088410885 = {"from":L[1271],
"go":function(anf_arg49510890) {
return $Hanf_arg246610891(anf_arg49510890,anf_arg48810792,anf_fun48610793,anf_fun48710794,f15810377,if_helper48110778,link3774,wrapper17110464);
}};
$e1088010881.stack[R.EXN_STACKHEIGHT++] = $ss1088410885;
}
if(R.isPyretException($e1088010881)) {
$e1088010881.pyretStack.push(L[1271]);
}
throw $e1088010881;
}
var $ret1088610887 = $Hanf_arg246610891($z1088210883,anf_arg48810792,anf_fun48610793,anf_fun48710794,f15810377,if_helper48110778,link3774,wrapper17110464);
++R.GAS;
return $ret1088610887;
};
var $Hanf_arg246610891 = function(anf_arg49510890,anf_arg48810792,anf_fun48610793,anf_fun48710794,f15810377,if_helper48110778,link3774,wrapper17110464) {
var $z1089410895 = D;
var $f1090010901 = function(_) {
return R.isFunction(link3774)?link3774.app(f15810377,anf_arg49510890):R.ffi.throwNonFunApp(L[1272],link3774,[f15810377,anf_arg49510890]);
};
try {
if(--R.GAS > 0) {
$z1089410895 = $f1090010901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1090010901,
"from":L[1272]});
}
} catch($e1089210893) {
if(R.isCont($e1089210893)) {
var $ss1089610897 = {"from":L[1272],
"go":function(anf_arg49610902) {
return $Hanf_arg246510903(anf_arg49610902,anf_arg48810792,anf_fun48610793,anf_fun48710794,if_helper48110778,wrapper17110464);
}};
$e1089210893.stack[R.EXN_STACKHEIGHT++] = $ss1089610897;
}
if(R.isPyretException($e1089210893)) {
$e1089210893.pyretStack.push(L[1272]);
}
throw $e1089210893;
}
var $ret1089810899 = $Hanf_arg246510903($z1089410895,anf_arg48810792,anf_fun48610793,anf_fun48710794,if_helper48110778,wrapper17110464);
++R.GAS;
return $ret1089810899;
};
var $Hanf_arg246510903 = function(anf_arg49610902,anf_arg48810792,anf_fun48610793,anf_fun48710794,if_helper48110778,wrapper17110464) {
var $z1090610907 = D;
var $f1091210913 = function(_) {
return R.isFunction(anf_fun48710794)?anf_fun48710794.app(anf_arg48810792,anf_arg49610902):R.ffi.throwNonFunApp(L[1273],anf_fun48710794,[anf_arg48810792,anf_arg49610902]);
};
try {
if(--R.GAS > 0) {
$z1090610907 = $f1091210913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1091210913,
"from":L[1273]});
}
} catch($e1090410905) {
if(R.isCont($e1090410905)) {
var $ss1090810909 = {"from":L[1273],
"go":function(anf_arg49710914) {
return $Hanf_arg246410915(anf_arg49710914,anf_fun48610793,if_helper48110778,wrapper17110464);
}};
$e1090410905.stack[R.EXN_STACKHEIGHT++] = $ss1090810909;
}
if(R.isPyretException($e1090410905)) {
$e1090410905.pyretStack.push(L[1273]);
}
throw $e1090410905;
}
var $ret1091010911 = $Hanf_arg246410915($z1090610907,anf_fun48610793,if_helper48110778,wrapper17110464);
++R.GAS;
return $ret1091010911;
};
var $Hanf_arg246410915 = function(anf_arg49710914,anf_fun48610793,if_helper48110778,wrapper17110464) {
var $z1091810919 = D;
var $f1092410925 = function(_) {
return R.isFunction(wrapper17110464)?wrapper17110464.app(anf_arg49710914):R.ffi.throwNonFunApp(L[1274],wrapper17110464,[anf_arg49710914]);
};
try {
if(--R.GAS > 0) {
$z1091810919 = $f1092410925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1092410925,
"from":L[1274]});
}
} catch($e1091610917) {
if(R.isCont($e1091610917)) {
var $ss1092010921 = {"from":L[1274],
"go":function(anf_array_val49810926) {
return $Hanf_array_val246310927(anf_array_val49810926,anf_fun48610793,if_helper48110778);
}};
$e1091610917.stack[R.EXN_STACKHEIGHT++] = $ss1092010921;
}
if(R.isPyretException($e1091610917)) {
$e1091610917.pyretStack.push(L[1274]);
}
throw $e1091610917;
}
var $ret1092210923 = $Hanf_array_val246310927($z1091810919,anf_fun48610793,if_helper48110778);
++R.GAS;
return $ret1092210923;
};
var $Hanf_array_val246310927 = function(anf_array_val49810926,anf_fun48610793,if_helper48110778) {
var $z1093010931 = D;
var $f1093610937 = function(_) {
return R.isFunction(anf_fun48610793)?anf_fun48610793.app([anf_array_val49810926]):R.ffi.throwNonFunApp(L[1264],anf_fun48610793,[[anf_array_val49810926]]);
};
try {
if(--R.GAS > 0) {
$z1093010931 = $f1093610937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1093610937,
"from":L[1264]});
}
} catch($e1092810929) {
if(R.isCont($e1092810929)) {
var $ss1093210933 = {"from":L[1264],
"go":function(cont_tail_arg49910938) {
return $Hcont_tail_arg246210939(cont_tail_arg49910938,if_helper48110778);
}};
$e1092810929.stack[R.EXN_STACKHEIGHT++] = $ss1093210933;
}
if(R.isPyretException($e1092810929)) {
$e1092810929.pyretStack.push(L[1264]);
}
throw $e1092810929;
}
var $ret1093410935 = $Hcont_tail_arg246210939($z1093010931,if_helper48110778);
++R.GAS;
return $ret1093410935;
};
var $Hcont_tail_arg246210939 = function(cont_tail_arg49910938,if_helper48110778) {
if(--R.GAS > 0) {
$z1094010941 = R.isFunction(if_helper48110778)?if_helper48110778.app(cont_tail_arg49910938):R.ffi.throwNonFunApp(L[1264],if_helper48110778,[cont_tail_arg49910938]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper48110778)?if_helper48110778.app(cont_tail_arg49910938):R.ffi.throwNonFunApp(L[1264],if_helper48110778,[cont_tail_arg49910938]);
},
"from":L[1264]});
}
++R.GAS;
return $z1094010941;
};
var $Hanf_array_val245610478 = function(anf_array_val47610476,anf_fun47510477) {
var $z1094410945 = D;
var $f1095010951 = function(_) {
return R.isFunction(anf_fun47510477)?anf_fun47510477.app([anf_array_val47610476]):R.ffi.throwNonFunApp(L[1220],anf_fun47510477,[[anf_array_val47610476]]);
};
try {
if(--R.GAS > 0) {
$z1094410945 = $f1095010951();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1095010951,
"from":L[1220]});
}
} catch($e1094210943) {
if(R.isCont($e1094210943)) {
var $ss1094610947 = {"from":L[1220],
"go":function(ann_DASH_check_DASH_temp47410952) {
return $Hann_DASH_check_DASH_temp245510953(ann_DASH_check_DASH_temp47410952);
}};
$e1094210943.stack[R.EXN_STACKHEIGHT++] = $ss1094610947;
}
if(R.isPyretException($e1094210943)) {
$e1094210943.pyretStack.push(L[1220]);
}
throw $e1094210943;
}
var $ret1094810949 = $Hann_DASH_check_DASH_temp245510953($z1094410945);
++R.GAS;
return $ret1094810949;
};
var $Hann_DASH_check_DASH_temp245510953 = function(ann_DASH_check_DASH_temp47410952) {
return ann_DASH_check_DASH_temp47410952;
};
var $Hann_DASH_check_DASH_temp245410500 = function(ann_DASH_check_DASH_temp46910499) {
return ann_DASH_check_DASH_temp46910499;
};
var $Hblob_DASH_id245310525 = function(blob_DASH_id21210524,A119,_check20210508,b20310509,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,mixins19910505,name19610502,namet19710503,params19810504,rest_DASH_stmts15910383,shared20110507,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var anf_fun41510964 = G(A119,"s-data-expr",L[1276]);
var $z1095610957 = D;
var $f1096210963 = function(_) {
return R.isFunction(anf_fun41510964)?anf_fun41510964.app(l19510501,name19610502,namet19710503,params19810504,mixins19910505,variants20010506,shared20110507,_check20210508):R.ffi.throwNonFunApp(L[1275],anf_fun41510964,[l19510501,name19610502,namet19710503,params19810504,mixins19910505,variants20010506,shared20110507,_check20210508]);
};
try {
if(--R.GAS > 0) {
$z1095610957 = $f1096210963();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1096210963,
"from":L[1275]});
}
} catch($e1095410955) {
if(R.isCont($e1095410955)) {
var $ss1095810959 = {"from":L[1275],
"go":function(data_DASH_expr21310965) {
return $Hdata_DASH_expr245210966(data_DASH_expr21310965,A119,b20310509,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1095410955.stack[R.EXN_STACKHEIGHT++] = $ss1095810959;
}
if(R.isPyretException($e1095410955)) {
$e1095410955.pyretStack.push(L[1275]);
}
throw $e1095410955;
}
var $ret1096010961 = $Hdata_DASH_expr245210966($z1095610957,A119,b20310509,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1096010961;
};
var $Hdata_DASH_expr245210966 = function(data_DASH_expr21310965,A119,b20310509,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var anf_fun41610978 = G(A119,"s-letrec-bind",L[1278]);
var $z1096910970 = D;
var $f1097510976 = function(_) {
return R.isFunction(b20310509.$var)?b20310509.$var.app(l19510501,blob_DASH_id21210524):R.ffi.throwNonFunApp(L[1277],b20310509.$var,[l19510501,blob_DASH_id21210524]);
};
try {
if(--R.GAS > 0) {
$z1096910970 = $f1097510976();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1097510976,
"from":L[1277]});
}
} catch($e1096710968) {
if(R.isCont($e1096710968)) {
var $ss1097110972 = {"from":L[1277],
"go":function(anf_arg41710977) {
return $Hanf_arg245110979(anf_arg41710977,A119,anf_fun41610978,b20310509,blob_DASH_id21210524,data_DASH_expr21310965,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1096710968.stack[R.EXN_STACKHEIGHT++] = $ss1097110972;
}
if(R.isPyretException($e1096710968)) {
$e1096710968.pyretStack.push(L[1277]);
}
throw $e1096710968;
}
var $ret1097310974 = $Hanf_arg245110979($z1096910970,A119,anf_fun41610978,b20310509,blob_DASH_id21210524,data_DASH_expr21310965,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1097310974;
};
var $Hanf_arg245110979 = function(anf_arg41710977,A119,anf_fun41610978,b20310509,blob_DASH_id21210524,data_DASH_expr21310965,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var $z1098210983 = D;
var $f1098810989 = function(_) {
return R.isFunction(anf_fun41610978)?anf_fun41610978.app(l19510501,anf_arg41710977,data_DASH_expr21310965):R.ffi.throwNonFunApp(L[1279],anf_fun41610978,[l19510501,anf_arg41710977,data_DASH_expr21310965]);
};
try {
if(--R.GAS > 0) {
$z1098210983 = $f1098810989();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1098810989,
"from":L[1279]});
}
} catch($e1098010981) {
if(R.isCont($e1098010981)) {
var $ss1098410985 = {"from":L[1279],
"go":function(bind_DASH_data21410990) {
return $Hbind_DASH_data245010991(bind_DASH_data21410990,A119,b20310509,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1098010981.stack[R.EXN_STACKHEIGHT++] = $ss1098410985;
}
if(R.isPyretException($e1098010981)) {
$e1098010981.pyretStack.push(L[1279]);
}
throw $e1098010981;
}
var $ret1098610987 = $Hbind_DASH_data245010991($z1098210983,A119,b20310509,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1098610987;
};
var $Hbind_DASH_data245010991 = function(bind_DASH_data21410990,A119,b20310509,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var anf_fun41811004 = G(A119,"s-letrec-bind",L[1282]);
var anf_fun41911002 = G(A119,"make-checker-name",L[1281]);
var $z1099410995 = D;
var $f1100011001 = function(_) {
return R.isFunction(anf_fun41911002)?anf_fun41911002.app(name19610502):R.ffi.throwNonFunApp(L[1280],anf_fun41911002,[name19610502]);
};
try {
if(--R.GAS > 0) {
$z1099410995 = $f1100011001();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1100011001,
"from":L[1280]});
}
} catch($e1099210993) {
if(R.isCont($e1099210993)) {
var $ss1099610997 = {"from":L[1280],
"go":function(anf_arg42011003) {
return $Hanf_arg244911005(anf_arg42011003,A119,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1099210993.stack[R.EXN_STACKHEIGHT++] = $ss1099610997;
}
if(R.isPyretException($e1099210993)) {
$e1099210993.pyretStack.push(L[1280]);
}
throw $e1099210993;
}
var $ret1099810999 = $Hanf_arg244911005($z1099410995,A119,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1099810999;
};
var $Hanf_arg244911005 = function(anf_arg42011003,A119,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var $z1100811009 = D;
var $f1101411015 = function(_) {
return R.isFunction(b20310509.$var)?b20310509.$var.app(l19510501,anf_arg42011003):R.ffi.throwNonFunApp(L[1283],b20310509.$var,[l19510501,anf_arg42011003]);
};
try {
if(--R.GAS > 0) {
$z1100811009 = $f1101411015();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1101411015,
"from":L[1283]});
}
} catch($e1100611007) {
if(R.isCont($e1100611007)) {
var $ss1101011011 = {"from":L[1283],
"go":function(anf_arg42111016) {
return $Hanf_arg244811017(anf_arg42111016,A119,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1100611007.stack[R.EXN_STACKHEIGHT++] = $ss1101011011;
}
if(R.isPyretException($e1100611007)) {
$e1100611007.pyretStack.push(L[1283]);
}
throw $e1100611007;
}
var $ret1101211013 = $Hanf_arg244811017($z1100811009,A119,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1101211013;
};
var $Hanf_arg244811017 = function(anf_arg42111016,A119,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var anf_fun42211030 = G(A119,"s-dot",L[1287]);
var anf_fun42311031 = G(A119,"s-id",L[1286]);
var anf_fun42411028 = G(A119,"s-name",L[1285]);
var $z1102011021 = D;
var $f1102611027 = function(_) {
return R.isFunction(anf_fun42411028)?anf_fun42411028.app(l19510501,blob_DASH_id21210524):R.ffi.throwNonFunApp(L[1284],anf_fun42411028,[l19510501,blob_DASH_id21210524]);
};
try {
if(--R.GAS > 0) {
$z1102011021 = $f1102611027();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1102611027,
"from":L[1284]});
}
} catch($e1101811019) {
if(R.isCont($e1101811019)) {
var $ss1102211023 = {"from":L[1284],
"go":function(anf_arg42511029) {
return $Hanf_arg244711032(anf_arg42511029,A119,anf_arg42111016,anf_fun41811004,anf_fun42211030,anf_fun42311031,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1101811019.stack[R.EXN_STACKHEIGHT++] = $ss1102211023;
}
if(R.isPyretException($e1101811019)) {
$e1101811019.pyretStack.push(L[1284]);
}
throw $e1101811019;
}
var $ret1102411025 = $Hanf_arg244711032($z1102011021,A119,anf_arg42111016,anf_fun41811004,anf_fun42211030,anf_fun42311031,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1102411025;
};
var $Hanf_arg244711032 = function(anf_arg42511029,A119,anf_arg42111016,anf_fun41811004,anf_fun42211030,anf_fun42311031,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var $z1103511036 = D;
var $f1104111042 = function(_) {
return R.isFunction(anf_fun42311031)?anf_fun42311031.app(l19510501,anf_arg42511029):R.ffi.throwNonFunApp(L[1288],anf_fun42311031,[l19510501,anf_arg42511029]);
};
try {
if(--R.GAS > 0) {
$z1103511036 = $f1104111042();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1104111042,
"from":L[1288]});
}
} catch($e1103311034) {
if(R.isCont($e1103311034)) {
var $ss1103711038 = {"from":L[1288],
"go":function(anf_arg42611043) {
return $Hanf_arg244611044(anf_arg42611043,A119,anf_arg42111016,anf_fun41811004,anf_fun42211030,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1103311034.stack[R.EXN_STACKHEIGHT++] = $ss1103711038;
}
if(R.isPyretException($e1103311034)) {
$e1103311034.pyretStack.push(L[1288]);
}
throw $e1103311034;
}
var $ret1103911040 = $Hanf_arg244611044($z1103511036,A119,anf_arg42111016,anf_fun41811004,anf_fun42211030,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1103911040;
};
var $Hanf_arg244611044 = function(anf_arg42611043,A119,anf_arg42111016,anf_fun41811004,anf_fun42211030,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var $z1104711048 = D;
var $f1105311054 = function(_) {
return R.isFunction(anf_fun42211030)?anf_fun42211030.app(l19510501,anf_arg42611043,name19610502):R.ffi.throwNonFunApp(L[1289],anf_fun42211030,[l19510501,anf_arg42611043,name19610502]);
};
try {
if(--R.GAS > 0) {
$z1104711048 = $f1105311054();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1105311054,
"from":L[1289]});
}
} catch($e1104511046) {
if(R.isCont($e1104511046)) {
var $ss1104911050 = {"from":L[1289],
"go":function(anf_arg42711055) {
return $Hanf_arg244511056(anf_arg42711055,A119,anf_arg42111016,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1104511046.stack[R.EXN_STACKHEIGHT++] = $ss1104911050;
}
if(R.isPyretException($e1104511046)) {
$e1104511046.pyretStack.push(L[1289]);
}
throw $e1104511046;
}
var $ret1105111052 = $Hanf_arg244511056($z1104711048,A119,anf_arg42111016,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1105111052;
};
var $Hanf_arg244511056 = function(anf_arg42711055,A119,anf_arg42111016,anf_fun41811004,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var $z1105911060 = D;
var $f1106511066 = function(_) {
return R.isFunction(anf_fun41811004)?anf_fun41811004.app(l19510501,anf_arg42111016,anf_arg42711055):R.ffi.throwNonFunApp(L[1290],anf_fun41811004,[l19510501,anf_arg42111016,anf_arg42711055]);
};
try {
if(--R.GAS > 0) {
$z1105911060 = $f1106511066();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1106511066,
"from":L[1290]});
}
} catch($e1105711058) {
if(R.isCont($e1105711058)) {
var $ss1106111062 = {"from":L[1290],
"go":function(bind_DASH_data_DASH_pred21511067) {
return $Hbind_DASH_data_DASH_pred244411068(bind_DASH_data_DASH_pred21511067,A119,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1105711058.stack[R.EXN_STACKHEIGHT++] = $ss1106111062;
}
if(R.isPyretException($e1105711058)) {
$e1105711058.pyretStack.push(L[1290]);
}
throw $e1105711058;
}
var $ret1106311064 = $Hbind_DASH_data_DASH_pred244411068($z1105911060,A119,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1106311064;
};
var $Hbind_DASH_data_DASH_pred244411068 = function(bind_DASH_data_DASH_pred21511067,A119,b20310509,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var anf_fun42811080 = G(A119,"s-letrec-bind",L[1292]);
var $z1107111072 = D;
var $f1107711078 = function(_) {
return R.isFunction(b20310509.$var)?b20310509.$var.app(l19510501,name19610502):R.ffi.throwNonFunApp(L[1291],b20310509.$var,[l19510501,name19610502]);
};
try {
if(--R.GAS > 0) {
$z1107111072 = $f1107711078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1107711078,
"from":L[1291]});
}
} catch($e1106911070) {
if(R.isCont($e1106911070)) {
var $ss1107311074 = {"from":L[1291],
"go":function(anf_arg42911079) {
return $Hanf_arg244311081(anf_arg42911079,A119,anf_fun42811080,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1106911070.stack[R.EXN_STACKHEIGHT++] = $ss1107311074;
}
if(R.isPyretException($e1106911070)) {
$e1106911070.pyretStack.push(L[1291]);
}
throw $e1106911070;
}
var $ret1107511076 = $Hanf_arg244311081($z1107111072,A119,anf_fun42811080,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1107511076;
};
var $Hanf_arg244311081 = function(anf_arg42911079,A119,anf_fun42811080,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var anf_fun43011094 = G(A119,"s-dot",L[1296]);
var anf_fun43111095 = G(A119,"s-id",L[1295]);
var anf_fun43211092 = G(A119,"s-name",L[1294]);
var $z1108411085 = D;
var $f1109011091 = function(_) {
return R.isFunction(anf_fun43211092)?anf_fun43211092.app(l19510501,blob_DASH_id21210524):R.ffi.throwNonFunApp(L[1293],anf_fun43211092,[l19510501,blob_DASH_id21210524]);
};
try {
if(--R.GAS > 0) {
$z1108411085 = $f1109011091();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1109011091,
"from":L[1293]});
}
} catch($e1108211083) {
if(R.isCont($e1108211083)) {
var $ss1108611087 = {"from":L[1293],
"go":function(anf_arg43311093) {
return $Hanf_arg244211096(anf_arg43311093,A119,anf_arg42911079,anf_fun42811080,anf_fun43011094,anf_fun43111095,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1108211083.stack[R.EXN_STACKHEIGHT++] = $ss1108611087;
}
if(R.isPyretException($e1108211083)) {
$e1108211083.pyretStack.push(L[1293]);
}
throw $e1108211083;
}
var $ret1108811089 = $Hanf_arg244211096($z1108411085,A119,anf_arg42911079,anf_fun42811080,anf_fun43011094,anf_fun43111095,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1108811089;
};
var $Hanf_arg244211096 = function(anf_arg43311093,A119,anf_arg42911079,anf_fun42811080,anf_fun43011094,anf_fun43111095,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var $z1109911100 = D;
var $f1110511106 = function(_) {
return R.isFunction(anf_fun43111095)?anf_fun43111095.app(l19510501,anf_arg43311093):R.ffi.throwNonFunApp(L[1297],anf_fun43111095,[l19510501,anf_arg43311093]);
};
try {
if(--R.GAS > 0) {
$z1109911100 = $f1110511106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1110511106,
"from":L[1297]});
}
} catch($e1109711098) {
if(R.isCont($e1109711098)) {
var $ss1110111102 = {"from":L[1297],
"go":function(anf_arg43411107) {
return $Hanf_arg244111108(anf_arg43411107,A119,anf_arg42911079,anf_fun42811080,anf_fun43011094,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1109711098.stack[R.EXN_STACKHEIGHT++] = $ss1110111102;
}
if(R.isPyretException($e1109711098)) {
$e1109711098.pyretStack.push(L[1297]);
}
throw $e1109711098;
}
var $ret1110311104 = $Hanf_arg244111108($z1109911100,A119,anf_arg42911079,anf_fun42811080,anf_fun43011094,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1110311104;
};
var $Hanf_arg244111108 = function(anf_arg43411107,A119,anf_arg42911079,anf_fun42811080,anf_fun43011094,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,name19610502,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var $z1111111112 = D;
var $f1111711118 = function(_) {
return R.isFunction(anf_fun43011094)?anf_fun43011094.app(l19510501,anf_arg43411107,name19610502):R.ffi.throwNonFunApp(L[1298],anf_fun43011094,[l19510501,anf_arg43411107,name19610502]);
};
try {
if(--R.GAS > 0) {
$z1111111112 = $f1111711118();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1111711118,
"from":L[1298]});
}
} catch($e1110911110) {
if(R.isCont($e1110911110)) {
var $ss1111311114 = {"from":L[1298],
"go":function(anf_arg43511119) {
return $Hanf_arg244011120(anf_arg43511119,A119,anf_arg42911079,anf_fun42811080,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1110911110.stack[R.EXN_STACKHEIGHT++] = $ss1111311114;
}
if(R.isPyretException($e1110911110)) {
$e1110911110.pyretStack.push(L[1298]);
}
throw $e1110911110;
}
var $ret1111511116 = $Hanf_arg244011120($z1111111112,A119,anf_arg42911079,anf_fun42811080,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1111511116;
};
var $Hanf_arg244011120 = function(anf_arg43511119,A119,anf_arg42911079,anf_fun42811080,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var $z1112311124 = D;
var $f1112911130 = function(_) {
return R.isFunction(anf_fun42811080)?anf_fun42811080.app(l19510501,anf_arg42911079,anf_arg43511119):R.ffi.throwNonFunApp(L[1299],anf_fun42811080,[l19510501,anf_arg42911079,anf_arg43511119]);
};
try {
if(--R.GAS > 0) {
$z1112311124 = $f1112911130();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1112911130,
"from":L[1299]});
}
} catch($e1112111122) {
if(R.isCont($e1112111122)) {
var $ss1112511126 = {"from":L[1299],
"go":function(bind_DASH_data_DASH_pred221611131) {
return $Hbind_DASH_data_DASH_pred2243911132(bind_DASH_data_DASH_pred221611131,A119,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
}};
$e1112111122.stack[R.EXN_STACKHEIGHT++] = $ss1112511126;
}
if(R.isPyretException($e1112111122)) {
$e1112111122.pyretStack.push(L[1299]);
}
throw $e1112111122;
}
var $ret1112711128 = $Hbind_DASH_data_DASH_pred2243911132($z1112311124,A119,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1112711128;
};
var $Hbind_DASH_data_DASH_pred2243911132 = function(bind_DASH_data_DASH_pred221611131,A119,bind_DASH_data_DASH_pred21511067,bind_DASH_data21410990,blob_DASH_id21210524,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variant_DASH_binds20410511,variants20010506,wrapper17110464,_plus9) {
var anf_arg44211145 = R.makeFunction(function(acc21811147,v21911148) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1301],2,arguments);
}
var anf_fun43711161 = G(A119,"s-id",L[1304]);
var anf_fun43811159 = G(A119,"s-name",L[1303]);
var $z1115111152 = D;
var $f1115711158 = function(_) {
return R.isFunction(anf_fun43811159)?anf_fun43811159.app(l19510501,blob_DASH_id21210524):R.ffi.throwNonFunApp(L[1302],anf_fun43811159,[l19510501,blob_DASH_id21210524]);
};
try {
if(--R.GAS > 0) {
$z1115111152 = $f1115711158();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1115711158,
"from":L[1302]});
}
} catch($e1114911150) {
if(R.isCont($e1114911150)) {
var $ss1115311154 = {"from":L[1302],
"go":function(anf_arg43911160) {
return $Hanf_arg242511162(anf_arg43911160,acc21811147,anf_fun43711161,l19510501,v21911148,variant_DASH_binds20410511,_plus9);
}};
$e1114911150.stack[R.EXN_STACKHEIGHT++] = $ss1115311154;
}
if(R.isPyretException($e1114911150)) {
$e1114911150.pyretStack.push(L[1302]);
}
throw $e1114911150;
}
var $ret1115511156 = $Hanf_arg242511162($z1115111152,acc21811147,anf_fun43711161,l19510501,v21911148,variant_DASH_binds20410511,_plus9);
++R.GAS;
return $ret1115511156;
});
var anf_fun44311143 = G(list3375,"make",L[1300]);
var $z1113511136 = D;
var $f1114111142 = function(_) {
return R.isFunction(anf_fun44311143)?anf_fun44311143.app([bind_DASH_data_DASH_pred21511067,bind_DASH_data_DASH_pred221611131,bind_DASH_data21410990]):R.ffi.throwNonFunApp(L[1300],anf_fun44311143,[[bind_DASH_data_DASH_pred21511067,bind_DASH_data_DASH_pred221611131,bind_DASH_data21410990]]);
};
try {
if(--R.GAS > 0) {
$z1113511136 = $f1114111142();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1114111142,
"from":L[1300]});
}
} catch($e1113311134) {
if(R.isCont($e1113311134)) {
var $ss1113711138 = {"from":L[1300],
"go":function(anf_arg44411144) {
return $Hanf_arg243811146(anf_arg44411144,A119,anf_arg44211145,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variants20010506,wrapper17110464,_plus9);
}};
$e1113311134.stack[R.EXN_STACKHEIGHT++] = $ss1113711138;
}
if(R.isPyretException($e1113311134)) {
$e1113311134.pyretStack.push(L[1300]);
}
throw $e1113311134;
}
var $ret1113911140 = $Hanf_arg243811146($z1113511136,A119,anf_arg44211145,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variants20010506,wrapper17110464,_plus9);
++R.GAS;
return $ret1113911140;
};
var $Hanf_arg243811146 = function(anf_arg44411144,A119,anf_arg44211145,desugar_DASH_scope_DASH_block9165,fold6171,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,variants20010506,wrapper17110464,_plus9) {
var $z1116511166 = D;
var $f1117111172 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg44211145,anf_arg44411144,variants20010506):R.ffi.throwNonFunApp(L[1305],fold6171,[anf_arg44211145,anf_arg44411144,variants20010506]);
};
try {
if(--R.GAS > 0) {
$z1116511166 = $f1117111172();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1117111172,
"from":L[1305]});
}
} catch($e1116311164) {
if(R.isCont($e1116311164)) {
var $ss1116711168 = {"from":L[1305],
"go":function(all_DASH_binds21711173) {
return $Hall_DASH_binds243711174(all_DASH_binds21711173,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrapper17110464,_plus9);
}};
$e1116311164.stack[R.EXN_STACKHEIGHT++] = $ss1116711168;
}
if(R.isPyretException($e1116311164)) {
$e1116311164.pyretStack.push(L[1305]);
}
throw $e1116311164;
}
var $ret1116911170 = $Hall_DASH_binds243711174($z1116511166,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrapper17110464,_plus9);
++R.GAS;
return $ret1116911170;
};
var $Hall_DASH_binds243711174 = function(all_DASH_binds21711173,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrapper17110464,_plus9) {
var $z1117711178 = D;
var $f1118311184 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(letrec_DASH_binds15610382):R.ffi.throwNonFunApp(L[1306],is_DASH_empty3410379,[letrec_DASH_binds15610382]);
};
try {
if(--R.GAS > 0) {
$z1117711178 = $f1118311184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1118311184,
"from":L[1306]});
}
} catch($e1117511176) {
if(R.isCont($e1117511176)) {
var $ss1117911180 = {"from":L[1306],
"go":function(if_DASH_2911185) {
return $Hif_DASH_243611186(if_DASH_2911185,A119,all_DASH_binds21711173,desugar_DASH_scope_DASH_block9165,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrapper17110464,_plus9);
}};
$e1117511176.stack[R.EXN_STACKHEIGHT++] = $ss1117911180;
}
if(R.isPyretException($e1117511176)) {
$e1117511176.pyretStack.push(L[1306]);
}
throw $e1117511176;
}
var $ret1118111182 = $Hif_DASH_243611186($z1117711178,A119,all_DASH_binds21711173,desugar_DASH_scope_DASH_block9165,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrapper17110464,_plus9);
++R.GAS;
return $ret1118111182;
};
var $Hif_DASH_243611186 = function(if_DASH_2911185,A119,all_DASH_binds21711173,desugar_DASH_scope_DASH_block9165,l19510501,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrapper17110464,_plus9) {
var if_helper44511201 = R.makeFunction(function(if_helper_arg44611220) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1306],1,arguments);
}
var ann_DASH_check_DASH_temp38811221 = if_helper_arg44611220;
return ann_DASH_check_DASH_temp38811221;
});
var anf_if44911219 = R.isBoolean(if_DASH_2911185);
if(R.isPyretTrue(anf_if44911219)) {
if(R.isPyretTrue(if_DASH_2911185)) {
var anf_fun45711199 = G(list3375,"make",L[1309]);
var anf_fun45811200 = G(A119,"s-block",L[1308]);
var anf_fun45911197 = G(list3375,"make",L[1307]);
var $z1118911190 = D;
var $f1119511196 = function(_) {
return R.isFunction(anf_fun45911197)?anf_fun45911197.app([]):R.ffi.throwNonFunApp(L[1307],anf_fun45911197,[[]]);
};
try {
if(--R.GAS > 0) {
$z1118911190 = $f1119511196();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1119511196,
"from":L[1307]});
}
} catch($e1118711188) {
if(R.isCont($e1118711188)) {
var $ss1119111192 = {"from":L[1307],
"go":function(anf_arg46011198) {
return $Hanf_arg243111202(anf_arg46011198,all_DASH_binds21711173,anf_fun45711199,anf_fun45811200,desugar_DASH_scope_DASH_block9165,if_helper44511201,l19510501,list3375,rest_DASH_stmts15910383,wrapper17110464);
}};
$e1118711188.stack[R.EXN_STACKHEIGHT++] = $ss1119111192;
}
if(R.isPyretException($e1118711188)) {
$e1118711188.pyretStack.push(L[1307]);
}
throw $e1118711188;
}
var $ret1119311194 = $Hanf_arg243111202($z1118911190,all_DASH_binds21711173,anf_fun45711199,anf_fun45811200,desugar_DASH_scope_DASH_block9165,if_helper44511201,l19510501,list3375,rest_DASH_stmts15910383,wrapper17110464);
++R.GAS;
return $ret1119311194;
} else {
var anf_fun45011213 = G(list3375,"make",L[1310]);
var $z1120511206 = D;
var $f1121111212 = function(_) {
return R.isFunction(anf_fun45011213)?anf_fun45011213.app([]):R.ffi.throwNonFunApp(L[1310],anf_fun45011213,[[]]);
};
try {
if(--R.GAS > 0) {
$z1120511206 = $f1121111212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1121111212,
"from":L[1310]});
}
} catch($e1120311204) {
if(R.isCont($e1120311204)) {
var $ss1120711208 = {"from":L[1310],
"go":function(anf_arg45111214) {
return $Hanf_arg243511215(anf_arg45111214,all_DASH_binds21711173,desugar_DASH_scope_DASH_block9165,if_helper44511201,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,_plus9);
}};
$e1120311204.stack[R.EXN_STACKHEIGHT++] = $ss1120711208;
}
if(R.isPyretException($e1120311204)) {
$e1120311204.pyretStack.push(L[1310]);
}
throw $e1120311204;
}
var $ret1120911210 = $Hanf_arg243511215($z1120511206,all_DASH_binds21711173,desugar_DASH_scope_DASH_block9165,if_helper44511201,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,_plus9);
++R.GAS;
return $ret1120911210;
}
} else {
var cont_tail_arg44711218 = R.throwNonBooleanCondition(L[1306],("if"),if_DASH_2911185);
if(--R.GAS > 0) {
$z1121611217 = R.isFunction(if_helper44511201)?if_helper44511201.app(cont_tail_arg44711218):R.ffi.throwNonFunApp(L[1306],if_helper44511201,[cont_tail_arg44711218]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper44511201)?if_helper44511201.app(cont_tail_arg44711218):R.ffi.throwNonFunApp(L[1306],if_helper44511201,[cont_tail_arg44711218]);
},
"from":L[1306]});
}
++R.GAS;
return $z1121611217;
}
};
var $Hanf_arg243111202 = function(anf_arg46011198,all_DASH_binds21711173,anf_fun45711199,anf_fun45811200,desugar_DASH_scope_DASH_block9165,if_helper44511201,l19510501,list3375,rest_DASH_stmts15910383,wrapper17110464) {
var anf_fun46111232 = G(list3375,"make",L[1311]);
var $z1122411225 = D;
var $f1123011231 = function(_) {
return R.isFunction(anf_fun46111232)?anf_fun46111232.app([]):R.ffi.throwNonFunApp(L[1311],anf_fun46111232,[[]]);
};
try {
if(--R.GAS > 0) {
$z1122411225 = $f1123011231();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1123011231,
"from":L[1311]});
}
} catch($e1122211223) {
if(R.isCont($e1122211223)) {
var $ss1122611227 = {"from":L[1311],
"go":function(anf_arg46211233) {
return $Hanf_arg243011234(anf_arg46211233,all_DASH_binds21711173,anf_arg46011198,anf_fun45711199,anf_fun45811200,desugar_DASH_scope_DASH_block9165,if_helper44511201,l19510501,rest_DASH_stmts15910383,wrapper17110464);
}};
$e1122211223.stack[R.EXN_STACKHEIGHT++] = $ss1122611227;
}
if(R.isPyretException($e1122211223)) {
$e1122211223.pyretStack.push(L[1311]);
}
throw $e1122211223;
}
var $ret1122811229 = $Hanf_arg243011234($z1122411225,all_DASH_binds21711173,anf_arg46011198,anf_fun45711199,anf_fun45811200,desugar_DASH_scope_DASH_block9165,if_helper44511201,l19510501,rest_DASH_stmts15910383,wrapper17110464);
++R.GAS;
return $ret1122811229;
};
var $Hanf_arg243011234 = function(anf_arg46211233,all_DASH_binds21711173,anf_arg46011198,anf_fun45711199,anf_fun45811200,desugar_DASH_scope_DASH_block9165,if_helper44511201,l19510501,rest_DASH_stmts15910383,wrapper17110464) {
var $z1123711238 = D;
var $f1124311244 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(rest_DASH_stmts15910383,anf_arg46011198,all_DASH_binds21711173,anf_arg46211233):R.ffi.throwNonFunApp(L[1312],desugar_DASH_scope_DASH_block9165.$var,[rest_DASH_stmts15910383,anf_arg46011198,all_DASH_binds21711173,anf_arg46211233]);
};
try {
if(--R.GAS > 0) {
$z1123711238 = $f1124311244();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1124311244,
"from":L[1312]});
}
} catch($e1123511236) {
if(R.isCont($e1123511236)) {
var $ss1123911240 = {"from":L[1312],
"go":function(anf_arg46311245) {
return $Hanf_arg242911246(anf_arg46311245,anf_fun45711199,anf_fun45811200,if_helper44511201,l19510501,wrapper17110464);
}};
$e1123511236.stack[R.EXN_STACKHEIGHT++] = $ss1123911240;
}
if(R.isPyretException($e1123511236)) {
$e1123511236.pyretStack.push(L[1312]);
}
throw $e1123511236;
}
var $ret1124111242 = $Hanf_arg242911246($z1123711238,anf_fun45711199,anf_fun45811200,if_helper44511201,l19510501,wrapper17110464);
++R.GAS;
return $ret1124111242;
};
var $Hanf_arg242911246 = function(anf_arg46311245,anf_fun45711199,anf_fun45811200,if_helper44511201,l19510501,wrapper17110464) {
var $z1124911250 = D;
var $f1125511256 = function(_) {
return R.isFunction(anf_fun45811200)?anf_fun45811200.app(l19510501,anf_arg46311245):R.ffi.throwNonFunApp(L[1313],anf_fun45811200,[l19510501,anf_arg46311245]);
};
try {
if(--R.GAS > 0) {
$z1124911250 = $f1125511256();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1125511256,
"from":L[1313]});
}
} catch($e1124711248) {
if(R.isCont($e1124711248)) {
var $ss1125111252 = {"from":L[1313],
"go":function(anf_arg46411257) {
return $Hanf_arg242811258(anf_arg46411257,anf_fun45711199,if_helper44511201,wrapper17110464);
}};
$e1124711248.stack[R.EXN_STACKHEIGHT++] = $ss1125111252;
}
if(R.isPyretException($e1124711248)) {
$e1124711248.pyretStack.push(L[1313]);
}
throw $e1124711248;
}
var $ret1125311254 = $Hanf_arg242811258($z1124911250,anf_fun45711199,if_helper44511201,wrapper17110464);
++R.GAS;
return $ret1125311254;
};
var $Hanf_arg242811258 = function(anf_arg46411257,anf_fun45711199,if_helper44511201,wrapper17110464) {
var $z1126111262 = D;
var $f1126711268 = function(_) {
return R.isFunction(wrapper17110464)?wrapper17110464.app(anf_arg46411257):R.ffi.throwNonFunApp(L[1314],wrapper17110464,[anf_arg46411257]);
};
try {
if(--R.GAS > 0) {
$z1126111262 = $f1126711268();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1126711268,
"from":L[1314]});
}
} catch($e1125911260) {
if(R.isCont($e1125911260)) {
var $ss1126311264 = {"from":L[1314],
"go":function(anf_array_val46511269) {
return $Hanf_array_val242711270(anf_array_val46511269,anf_fun45711199,if_helper44511201);
}};
$e1125911260.stack[R.EXN_STACKHEIGHT++] = $ss1126311264;
}
if(R.isPyretException($e1125911260)) {
$e1125911260.pyretStack.push(L[1314]);
}
throw $e1125911260;
}
var $ret1126511266 = $Hanf_array_val242711270($z1126111262,anf_fun45711199,if_helper44511201);
++R.GAS;
return $ret1126511266;
};
var $Hanf_array_val242711270 = function(anf_array_val46511269,anf_fun45711199,if_helper44511201) {
var $z1127311274 = D;
var $f1127911280 = function(_) {
return R.isFunction(anf_fun45711199)?anf_fun45711199.app([anf_array_val46511269]):R.ffi.throwNonFunApp(L[1309],anf_fun45711199,[[anf_array_val46511269]]);
};
try {
if(--R.GAS > 0) {
$z1127311274 = $f1127911280();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1127911280,
"from":L[1309]});
}
} catch($e1127111272) {
if(R.isCont($e1127111272)) {
var $ss1127511276 = {"from":L[1309],
"go":function(cont_tail_arg46611281) {
return $Hcont_tail_arg242611282(cont_tail_arg46611281,if_helper44511201);
}};
$e1127111272.stack[R.EXN_STACKHEIGHT++] = $ss1127511276;
}
if(R.isPyretException($e1127111272)) {
$e1127111272.pyretStack.push(L[1309]);
}
throw $e1127111272;
}
var $ret1127711278 = $Hcont_tail_arg242611282($z1127311274,if_helper44511201);
++R.GAS;
return $ret1127711278;
};
var $Hcont_tail_arg242611282 = function(cont_tail_arg46611281,if_helper44511201) {
if(--R.GAS > 0) {
$z1128311284 = R.isFunction(if_helper44511201)?if_helper44511201.app(cont_tail_arg46611281):R.ffi.throwNonFunApp(L[1309],if_helper44511201,[cont_tail_arg46611281]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper44511201)?if_helper44511201.app(cont_tail_arg46611281):R.ffi.throwNonFunApp(L[1309],if_helper44511201,[cont_tail_arg46611281]);
},
"from":L[1309]});
}
++R.GAS;
return $z1128311284;
};
var $Hanf_arg243511215 = function(anf_arg45111214,all_DASH_binds21711173,desugar_DASH_scope_DASH_block9165,if_helper44511201,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,_plus9) {
var $z1128711288 = D;
var $f1129311294 = function(_) {
return R.isFunction(_plus9)?_plus9.app(all_DASH_binds21711173,letrec_DASH_binds15610382):R.ffi.throwNonFunApp(L[1315],_plus9,[all_DASH_binds21711173,letrec_DASH_binds15610382]);
};
try {
if(--R.GAS > 0) {
$z1128711288 = $f1129311294();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1129311294,
"from":L[1315]});
}
} catch($e1128511286) {
if(R.isCont($e1128511286)) {
var $ss1128911290 = {"from":L[1315],
"go":function(anf_arg45211295) {
return $Hanf_arg243411296(anf_arg45211295,anf_arg45111214,desugar_DASH_scope_DASH_block9165,if_helper44511201,list3375,rest_DASH_stmts15910383);
}};
$e1128511286.stack[R.EXN_STACKHEIGHT++] = $ss1128911290;
}
if(R.isPyretException($e1128511286)) {
$e1128511286.pyretStack.push(L[1315]);
}
throw $e1128511286;
}
var $ret1129111292 = $Hanf_arg243411296($z1128711288,anf_arg45111214,desugar_DASH_scope_DASH_block9165,if_helper44511201,list3375,rest_DASH_stmts15910383);
++R.GAS;
return $ret1129111292;
};
var $Hanf_arg243411296 = function(anf_arg45211295,anf_arg45111214,desugar_DASH_scope_DASH_block9165,if_helper44511201,list3375,rest_DASH_stmts15910383) {
var anf_fun45311307 = G(list3375,"make",L[1316]);
var $z1129911300 = D;
var $f1130511306 = function(_) {
return R.isFunction(anf_fun45311307)?anf_fun45311307.app([]):R.ffi.throwNonFunApp(L[1316],anf_fun45311307,[[]]);
};
try {
if(--R.GAS > 0) {
$z1129911300 = $f1130511306();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1130511306,
"from":L[1316]});
}
} catch($e1129711298) {
if(R.isCont($e1129711298)) {
var $ss1130111302 = {"from":L[1316],
"go":function(anf_arg45411308) {
return $Hanf_arg243311309(anf_arg45411308,anf_arg45111214,anf_arg45211295,desugar_DASH_scope_DASH_block9165,if_helper44511201,rest_DASH_stmts15910383);
}};
$e1129711298.stack[R.EXN_STACKHEIGHT++] = $ss1130111302;
}
if(R.isPyretException($e1129711298)) {
$e1129711298.pyretStack.push(L[1316]);
}
throw $e1129711298;
}
var $ret1130311304 = $Hanf_arg243311309($z1129911300,anf_arg45111214,anf_arg45211295,desugar_DASH_scope_DASH_block9165,if_helper44511201,rest_DASH_stmts15910383);
++R.GAS;
return $ret1130311304;
};
var $Hanf_arg243311309 = function(anf_arg45411308,anf_arg45111214,anf_arg45211295,desugar_DASH_scope_DASH_block9165,if_helper44511201,rest_DASH_stmts15910383) {
var $z1131211313 = D;
var $f1131811319 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(rest_DASH_stmts15910383,anf_arg45111214,anf_arg45211295,anf_arg45411308):R.ffi.throwNonFunApp(L[1317],desugar_DASH_scope_DASH_block9165.$var,[rest_DASH_stmts15910383,anf_arg45111214,anf_arg45211295,anf_arg45411308]);
};
try {
if(--R.GAS > 0) {
$z1131211313 = $f1131811319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1131811319,
"from":L[1317]});
}
} catch($e1131011311) {
if(R.isCont($e1131011311)) {
var $ss1131411315 = {"from":L[1317],
"go":function(cont_tail_arg45511320) {
return $Hcont_tail_arg243211321(cont_tail_arg45511320,if_helper44511201);
}};
$e1131011311.stack[R.EXN_STACKHEIGHT++] = $ss1131411315;
}
if(R.isPyretException($e1131011311)) {
$e1131011311.pyretStack.push(L[1317]);
}
throw $e1131011311;
}
var $ret1131611317 = $Hcont_tail_arg243211321($z1131211313,if_helper44511201);
++R.GAS;
return $ret1131611317;
};
var $Hcont_tail_arg243211321 = function(cont_tail_arg45511320,if_helper44511201) {
if(--R.GAS > 0) {
$z1132211323 = R.isFunction(if_helper44511201)?if_helper44511201.app(cont_tail_arg45511320):R.ffi.throwNonFunApp(L[1317],if_helper44511201,[cont_tail_arg45511320]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper44511201)?if_helper44511201.app(cont_tail_arg45511320):R.ffi.throwNonFunApp(L[1317],if_helper44511201,[cont_tail_arg45511320]);
},
"from":L[1317]});
}
++R.GAS;
return $z1132211323;
};
var $Hanf_arg242511162 = function(anf_arg43911160,acc21811147,anf_fun43711161,l19510501,v21911148,variant_DASH_binds20410511,_plus9) {
var $z1132611327 = D;
var $f1133211333 = function(_) {
return R.isFunction(anf_fun43711161)?anf_fun43711161.app(l19510501,anf_arg43911160):R.ffi.throwNonFunApp(L[1318],anf_fun43711161,[l19510501,anf_arg43911160]);
};
try {
if(--R.GAS > 0) {
$z1132611327 = $f1133211333();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1133211333,
"from":L[1318]});
}
} catch($e1132411325) {
if(R.isCont($e1132411325)) {
var $ss1132811329 = {"from":L[1318],
"go":function(anf_arg44011334) {
return $Hanf_arg242411335(anf_arg44011334,acc21811147,v21911148,variant_DASH_binds20410511,_plus9);
}};
$e1132411325.stack[R.EXN_STACKHEIGHT++] = $ss1132811329;
}
if(R.isPyretException($e1132411325)) {
$e1132411325.pyretStack.push(L[1318]);
}
throw $e1132411325;
}
var $ret1133011331 = $Hanf_arg242411335($z1132611327,acc21811147,v21911148,variant_DASH_binds20410511,_plus9);
++R.GAS;
return $ret1133011331;
};
var $Hanf_arg242411335 = function(anf_arg44011334,acc21811147,v21911148,variant_DASH_binds20410511,_plus9) {
var $z1133811339 = D;
var $f1134411345 = function(_) {
return R.isFunction(variant_DASH_binds20410511.$var)?variant_DASH_binds20410511.$var.app(anf_arg44011334,v21911148):R.ffi.throwNonFunApp(L[1319],variant_DASH_binds20410511.$var,[anf_arg44011334,v21911148]);
};
try {
if(--R.GAS > 0) {
$z1133811339 = $f1134411345();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1134411345,
"from":L[1319]});
}
} catch($e1133611337) {
if(R.isCont($e1133611337)) {
var $ss1134011341 = {"from":L[1319],
"go":function(anf_arg44111346) {
return $Hanf_arg242311347(anf_arg44111346,acc21811147,_plus9);
}};
$e1133611337.stack[R.EXN_STACKHEIGHT++] = $ss1134011341;
}
if(R.isPyretException($e1133611337)) {
$e1133611337.pyretStack.push(L[1319]);
}
throw $e1133611337;
}
var $ret1134211343 = $Hanf_arg242311347($z1133811339,acc21811147,_plus9);
++R.GAS;
return $ret1134211343;
};
var $Hanf_arg242311347 = function(anf_arg44111346,acc21811147,_plus9) {
var $z1135011351 = D;
var $f1135611357 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg44111346,acc21811147):R.ffi.throwNonFunApp(L[1301],_plus9,[anf_arg44111346,acc21811147]);
};
try {
if(--R.GAS > 0) {
$z1135011351 = $f1135611357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1135611357,
"from":L[1301]});
}
} catch($e1134811349) {
if(R.isCont($e1134811349)) {
var $ss1135211353 = {"from":L[1301],
"go":function(ann_DASH_check_DASH_temp43611358) {
return $Hann_DASH_check_DASH_temp242211359(ann_DASH_check_DASH_temp43611358);
}};
$e1134811349.stack[R.EXN_STACKHEIGHT++] = $ss1135211353;
}
if(R.isPyretException($e1134811349)) {
$e1134811349.pyretStack.push(L[1301]);
}
throw $e1134811349;
}
var $ret1135411355 = $Hann_DASH_check_DASH_temp242211359($z1135011351);
++R.GAS;
return $ret1135411355;
};
var $Hann_DASH_check_DASH_temp242211359 = function(ann_DASH_check_DASH_temp43611358) {
return ann_DASH_check_DASH_temp43611358;
};
var $Hchecker_DASH_name242110541 = function(checker_DASH_name21010540,A119,b20310509,data_DASH_blob_DASH_id20710526,list3375,v20810527,vname20910539) {
var get_DASH_part21111375 = R.makeFunction(function(arg_DASH_2811377) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1325],1,arguments);
}
var anf_fun39811388 = G(A119,"s-dot",L[1327]);
var anf_arg39911389 = G(v20810527,"l",L[1326]);
var $z1138011381 = D;
var $f1138611387 = function(_) {
return R.isFunction(anf_fun39811388)?anf_fun39811388.app(anf_arg39911389,data_DASH_blob_DASH_id20710526,arg_DASH_2811377):R.ffi.throwNonFunApp(L[1325],anf_fun39811388,[anf_arg39911389,data_DASH_blob_DASH_id20710526,arg_DASH_2811377]);
};
try {
if(--R.GAS > 0) {
$z1138011381 = $f1138611387();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1138611387,
"from":L[1325]});
}
} catch($e1137811379) {
if(R.isCont($e1137811379)) {
var $ss1138211383 = {"from":L[1325],
"go":function(ann_DASH_check_DASH_temp39711390) {
return $Hann_DASH_check_DASH_temp241311391(ann_DASH_check_DASH_temp39711390);
}};
$e1137811379.stack[R.EXN_STACKHEIGHT++] = $ss1138211383;
}
if(R.isPyretException($e1137811379)) {
$e1137811379.pyretStack.push(L[1325]);
}
throw $e1137811379;
}
var $ret1138411385 = $Hann_DASH_check_DASH_temp241311391($z1138011381);
++R.GAS;
return $ret1138411385;
});
var anf_fun40011373 = G(list3375,"make",L[1324]);
var anf_fun40111374 = G(A119,"s-letrec-bind",L[1323]);
var anf_arg40211372 = G(v20810527,"l",L[1322]);
var anf_arg40311370 = G(v20810527,"l",L[1321]);
var $z1136211363 = D;
var $f1136811369 = function(_) {
return R.isFunction(b20310509.$var)?b20310509.$var.app(anf_arg40311370,vname20910539):R.ffi.throwNonFunApp(L[1320],b20310509.$var,[anf_arg40311370,vname20910539]);
};
try {
if(--R.GAS > 0) {
$z1136211363 = $f1136811369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1136811369,
"from":L[1320]});
}
} catch($e1136011361) {
if(R.isCont($e1136011361)) {
var $ss1136411365 = {"from":L[1320],
"go":function(anf_arg40411371) {
return $Hanf_arg242011376(anf_arg40411371,A119,anf_arg40211372,anf_fun40011373,anf_fun40111374,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527,vname20910539);
}};
$e1136011361.stack[R.EXN_STACKHEIGHT++] = $ss1136411365;
}
if(R.isPyretException($e1136011361)) {
$e1136011361.pyretStack.push(L[1320]);
}
throw $e1136011361;
}
var $ret1136611367 = $Hanf_arg242011376($z1136211363,A119,anf_arg40211372,anf_fun40011373,anf_fun40111374,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527,vname20910539);
++R.GAS;
return $ret1136611367;
};
var $Hanf_arg242011376 = function(anf_arg40411371,A119,anf_arg40211372,anf_fun40011373,anf_fun40111374,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527,vname20910539) {
var $z1139411395 = D;
var $f1140011401 = function(_) {
return R.isFunction(get_DASH_part21111375)?get_DASH_part21111375.app(vname20910539):R.ffi.throwNonFunApp(L[1328],get_DASH_part21111375,[vname20910539]);
};
try {
if(--R.GAS > 0) {
$z1139411395 = $f1140011401();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1140011401,
"from":L[1328]});
}
} catch($e1139211393) {
if(R.isCont($e1139211393)) {
var $ss1139611397 = {"from":L[1328],
"go":function(anf_arg40511402) {
return $Hanf_arg241911403(anf_arg40511402,A119,anf_arg40211372,anf_arg40411371,anf_fun40011373,anf_fun40111374,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527);
}};
$e1139211393.stack[R.EXN_STACKHEIGHT++] = $ss1139611397;
}
if(R.isPyretException($e1139211393)) {
$e1139211393.pyretStack.push(L[1328]);
}
throw $e1139211393;
}
var $ret1139811399 = $Hanf_arg241911403($z1139411395,A119,anf_arg40211372,anf_arg40411371,anf_fun40011373,anf_fun40111374,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527);
++R.GAS;
return $ret1139811399;
};
var $Hanf_arg241911403 = function(anf_arg40511402,A119,anf_arg40211372,anf_arg40411371,anf_fun40011373,anf_fun40111374,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527) {
var $z1140611407 = D;
var $f1141211413 = function(_) {
return R.isFunction(anf_fun40111374)?anf_fun40111374.app(anf_arg40211372,anf_arg40411371,anf_arg40511402):R.ffi.throwNonFunApp(L[1329],anf_fun40111374,[anf_arg40211372,anf_arg40411371,anf_arg40511402]);
};
try {
if(--R.GAS > 0) {
$z1140611407 = $f1141211413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1141211413,
"from":L[1329]});
}
} catch($e1140411405) {
if(R.isCont($e1140411405)) {
var $ss1140811409 = {"from":L[1329],
"go":function(anf_array_val40611414) {
return $Hanf_array_val241811415(anf_array_val40611414,A119,anf_fun40011373,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527);
}};
$e1140411405.stack[R.EXN_STACKHEIGHT++] = $ss1140811409;
}
if(R.isPyretException($e1140411405)) {
$e1140411405.pyretStack.push(L[1329]);
}
throw $e1140411405;
}
var $ret1141011411 = $Hanf_array_val241811415($z1140611407,A119,anf_fun40011373,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527);
++R.GAS;
return $ret1141011411;
};
var $Hanf_array_val241811415 = function(anf_array_val40611414,A119,anf_fun40011373,b20310509,checker_DASH_name21010540,get_DASH_part21111375,v20810527) {
var anf_fun40711429 = G(A119,"s-letrec-bind",L[1333]);
var anf_arg40811428 = G(v20810527,"l",L[1332]);
var anf_arg40911426 = G(v20810527,"l",L[1331]);
var $z1141811419 = D;
var $f1142411425 = function(_) {
return R.isFunction(b20310509.$var)?b20310509.$var.app(anf_arg40911426,checker_DASH_name21010540):R.ffi.throwNonFunApp(L[1330],b20310509.$var,[anf_arg40911426,checker_DASH_name21010540]);
};
try {
if(--R.GAS > 0) {
$z1141811419 = $f1142411425();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1142411425,
"from":L[1330]});
}
} catch($e1141611417) {
if(R.isCont($e1141611417)) {
var $ss1142011421 = {"from":L[1330],
"go":function(anf_arg41011427) {
return $Hanf_arg241711430(anf_arg41011427,anf_arg40811428,anf_array_val40611414,anf_fun40011373,anf_fun40711429,checker_DASH_name21010540,get_DASH_part21111375);
}};
$e1141611417.stack[R.EXN_STACKHEIGHT++] = $ss1142011421;
}
if(R.isPyretException($e1141611417)) {
$e1141611417.pyretStack.push(L[1330]);
}
throw $e1141611417;
}
var $ret1142211423 = $Hanf_arg241711430($z1141811419,anf_arg40811428,anf_array_val40611414,anf_fun40011373,anf_fun40711429,checker_DASH_name21010540,get_DASH_part21111375);
++R.GAS;
return $ret1142211423;
};
var $Hanf_arg241711430 = function(anf_arg41011427,anf_arg40811428,anf_array_val40611414,anf_fun40011373,anf_fun40711429,checker_DASH_name21010540,get_DASH_part21111375) {
var $z1143311434 = D;
var $f1143911440 = function(_) {
return R.isFunction(get_DASH_part21111375)?get_DASH_part21111375.app(checker_DASH_name21010540):R.ffi.throwNonFunApp(L[1334],get_DASH_part21111375,[checker_DASH_name21010540]);
};
try {
if(--R.GAS > 0) {
$z1143311434 = $f1143911440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1143911440,
"from":L[1334]});
}
} catch($e1143111432) {
if(R.isCont($e1143111432)) {
var $ss1143511436 = {"from":L[1334],
"go":function(anf_arg41111441) {
return $Hanf_arg241611442(anf_arg41111441,anf_arg40811428,anf_arg41011427,anf_array_val40611414,anf_fun40011373,anf_fun40711429);
}};
$e1143111432.stack[R.EXN_STACKHEIGHT++] = $ss1143511436;
}
if(R.isPyretException($e1143111432)) {
$e1143111432.pyretStack.push(L[1334]);
}
throw $e1143111432;
}
var $ret1143711438 = $Hanf_arg241611442($z1143311434,anf_arg40811428,anf_arg41011427,anf_array_val40611414,anf_fun40011373,anf_fun40711429);
++R.GAS;
return $ret1143711438;
};
var $Hanf_arg241611442 = function(anf_arg41111441,anf_arg40811428,anf_arg41011427,anf_array_val40611414,anf_fun40011373,anf_fun40711429) {
var $z1144511446 = D;
var $f1145111452 = function(_) {
return R.isFunction(anf_fun40711429)?anf_fun40711429.app(anf_arg40811428,anf_arg41011427,anf_arg41111441):R.ffi.throwNonFunApp(L[1335],anf_fun40711429,[anf_arg40811428,anf_arg41011427,anf_arg41111441]);
};
try {
if(--R.GAS > 0) {
$z1144511446 = $f1145111452();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1145111452,
"from":L[1335]});
}
} catch($e1144311444) {
if(R.isCont($e1144311444)) {
var $ss1144711448 = {"from":L[1335],
"go":function(anf_array_val41211453) {
return $Hanf_array_val241511454(anf_array_val41211453,anf_array_val40611414,anf_fun40011373);
}};
$e1144311444.stack[R.EXN_STACKHEIGHT++] = $ss1144711448;
}
if(R.isPyretException($e1144311444)) {
$e1144311444.pyretStack.push(L[1335]);
}
throw $e1144311444;
}
var $ret1144911450 = $Hanf_array_val241511454($z1144511446,anf_array_val40611414,anf_fun40011373);
++R.GAS;
return $ret1144911450;
};
var $Hanf_array_val241511454 = function(anf_array_val41211453,anf_array_val40611414,anf_fun40011373) {
var $z1145711458 = D;
var $f1146311464 = function(_) {
return R.isFunction(anf_fun40011373)?anf_fun40011373.app([anf_array_val40611414,anf_array_val41211453]):R.ffi.throwNonFunApp(L[1227],anf_fun40011373,[[anf_array_val40611414,anf_array_val41211453]]);
};
try {
if(--R.GAS > 0) {
$z1145711458 = $f1146311464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1146311464,
"from":L[1227]});
}
} catch($e1145511456) {
if(R.isCont($e1145511456)) {
var $ss1145911460 = {"from":L[1227],
"go":function(ann_DASH_check_DASH_temp39511465) {
return $Hann_DASH_check_DASH_temp241411466(ann_DASH_check_DASH_temp39511465);
}};
$e1145511456.stack[R.EXN_STACKHEIGHT++] = $ss1145911460;
}
if(R.isPyretException($e1145511456)) {
$e1145511456.pyretStack.push(L[1227]);
}
throw $e1145511456;
}
var $ret1146111462 = $Hann_DASH_check_DASH_temp241411466($z1145711458);
++R.GAS;
return $ret1146111462;
};
var $Hann_DASH_check_DASH_temp241411466 = function(ann_DASH_check_DASH_temp39511465) {
return ann_DASH_check_DASH_temp39511465;
};
var $Hann_DASH_check_DASH_temp241311391 = function(ann_DASH_check_DASH_temp39711390) {
return ann_DASH_check_DASH_temp39711390;
};
var $Hanf_arg241210557 = function(anf_arg39210555,A119,anf_fun39010556,loc20510542) {
var anf_arg39311477 = G(A119,"a-blank",L[1336]);
var $z1146911470 = D;
var $f1147511476 = function(_) {
return R.isFunction(anf_fun39010556)?anf_fun39010556.app(loc20510542,(false),anf_arg39210555,anf_arg39311477):R.ffi.throwNonFunApp(L[1231],anf_fun39010556,[loc20510542,(false),anf_arg39210555,anf_arg39311477]);
};
try {
if(--R.GAS > 0) {
$z1146911470 = $f1147511476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1147511476,
"from":L[1231]});
}
} catch($e1146711468) {
if(R.isCont($e1146711468)) {
var $ss1147111472 = {"from":L[1231],
"go":function(ann_DASH_check_DASH_temp38911478) {
return $Hann_DASH_check_DASH_temp241111479(ann_DASH_check_DASH_temp38911478);
}};
$e1146711468.stack[R.EXN_STACKHEIGHT++] = $ss1147111472;
}
if(R.isPyretException($e1146711468)) {
$e1146711468.pyretStack.push(L[1231]);
}
throw $e1146711468;
}
var $ret1147311474 = $Hann_DASH_check_DASH_temp241111479($z1146911470);
++R.GAS;
return $ret1147311474;
};
var $Hann_DASH_check_DASH_temp241111479 = function(ann_DASH_check_DASH_temp38911478) {
return ann_DASH_check_DASH_temp38911478;
};
var $Hanf_arg241010580 = function(anf_arg35410577,A119,_check19210565,anf_fun35110578,anf_fun35210579,ann18910562,args18810561,body19110564,desugar_DASH_scope_DASH_block9165,doc19010563,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,params18710560,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var anf_arg35511490 = G(A119,"a-blank",L[1338]);
var $z1148211483 = D;
var $f1148811489 = function(_) {
return R.isFunction(anf_fun35210579)?anf_fun35210579.app(l18510558,(false),anf_arg35410577,anf_arg35511490):R.ffi.throwNonFunApp(L[1337],anf_fun35210579,[l18510558,(false),anf_arg35410577,anf_arg35511490]);
};
try {
if(--R.GAS > 0) {
$z1148211483 = $f1148811489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1148811489,
"from":L[1337]});
}
} catch($e1148011481) {
if(R.isCont($e1148011481)) {
var $ss1148411485 = {"from":L[1337],
"go":function(anf_arg35611491) {
return $Hanf_arg240911492(anf_arg35611491,A119,_check19210565,anf_fun35110578,ann18910562,args18810561,body19110564,desugar_DASH_scope_DASH_block9165,doc19010563,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,params18710560,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1148011481.stack[R.EXN_STACKHEIGHT++] = $ss1148411485;
}
if(R.isPyretException($e1148011481)) {
$e1148011481.pyretStack.push(L[1337]);
}
throw $e1148011481;
}
var $ret1148611487 = $Hanf_arg240911492($z1148211483,A119,_check19210565,anf_fun35110578,ann18910562,args18810561,body19110564,desugar_DASH_scope_DASH_block9165,doc19010563,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,params18710560,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1148611487;
};
var $Hanf_arg240911492 = function(anf_arg35611491,A119,_check19210565,anf_fun35110578,ann18910562,args18810561,body19110564,desugar_DASH_scope_DASH_block9165,doc19010563,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,params18710560,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var anf_fun35711503 = G(A119,"s-lam",L[1340]);
var $z1149511496 = D;
var $f1150111502 = function(_) {
return R.isFunction(anf_fun35711503)?anf_fun35711503.app(l18510558,params18710560,args18810561,ann18910562,doc19010563,body19110564,_check19210565):R.ffi.throwNonFunApp(L[1339],anf_fun35711503,[l18510558,params18710560,args18810561,ann18910562,doc19010563,body19110564,_check19210565]);
};
try {
if(--R.GAS > 0) {
$z1149511496 = $f1150111502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1150111502,
"from":L[1339]});
}
} catch($e1149311494) {
if(R.isCont($e1149311494)) {
var $ss1149711498 = {"from":L[1339],
"go":function(anf_arg35811504) {
return $Hanf_arg240811505(anf_arg35811504,A119,anf_arg35611491,anf_fun35110578,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1149311494.stack[R.EXN_STACKHEIGHT++] = $ss1149711498;
}
if(R.isPyretException($e1149311494)) {
$e1149311494.pyretStack.push(L[1339]);
}
throw $e1149311494;
}
var $ret1149911500 = $Hanf_arg240811505($z1149511496,A119,anf_arg35611491,anf_fun35110578,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1149911500;
};
var $Hanf_arg240811505 = function(anf_arg35811504,A119,anf_arg35611491,anf_fun35110578,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1150811509 = D;
var $f1151411515 = function(_) {
return R.isFunction(anf_fun35110578)?anf_fun35110578.app(l18510558,anf_arg35611491,anf_arg35811504):R.ffi.throwNonFunApp(L[1341],anf_fun35110578,[l18510558,anf_arg35611491,anf_arg35811504]);
};
try {
if(--R.GAS > 0) {
$z1150811509 = $f1151411515();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1151411515,
"from":L[1341]});
}
} catch($e1150611507) {
if(R.isCont($e1150611507)) {
var $ss1151011511 = {"from":L[1341],
"go":function(anf_arg35911516) {
return $Hanf_arg240711517(anf_arg35911516,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1150611507.stack[R.EXN_STACKHEIGHT++] = $ss1151011511;
}
if(R.isPyretException($e1150611507)) {
$e1150611507.pyretStack.push(L[1341]);
}
throw $e1150611507;
}
var $ret1151211513 = $Hanf_arg240711517($z1150811509,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1151211513;
};
var $Hanf_arg240711517 = function(anf_arg35911516,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1152011521 = D;
var $f1152611527 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg35911516,letrec_DASH_binds15610382):R.ffi.throwNonFunApp(L[1342],link3774,[anf_arg35911516,letrec_DASH_binds15610382]);
};
try {
if(--R.GAS > 0) {
$z1152011521 = $f1152611527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1152611527,
"from":L[1342]});
}
} catch($e1151811519) {
if(R.isCont($e1151811519)) {
var $ss1152211523 = {"from":L[1342],
"go":function(new_DASH_letrecs19311528) {
return $Hnew_DASH_letrecs240611529(new_DASH_letrecs19311528,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1151811519.stack[R.EXN_STACKHEIGHT++] = $ss1152211523;
}
if(R.isPyretException($e1151811519)) {
$e1151811519.pyretStack.push(L[1342]);
}
throw $e1151811519;
}
var $ret1152411525 = $Hnew_DASH_letrecs240611529($z1152011521,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1152411525;
};
var $Hnew_DASH_letrecs240611529 = function(new_DASH_letrecs19311528,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var anf_fun36011540 = G(list3375,"make",L[1343]);
var $z1153211533 = D;
var $f1153811539 = function(_) {
return R.isFunction(anf_fun36011540)?anf_fun36011540.app([]):R.ffi.throwNonFunApp(L[1343],anf_fun36011540,[[]]);
};
try {
if(--R.GAS > 0) {
$z1153211533 = $f1153811539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1153811539,
"from":L[1343]});
}
} catch($e1153011531) {
if(R.isCont($e1153011531)) {
var $ss1153411535 = {"from":L[1343],
"go":function(anf_arg36111541) {
return $Hanf_arg240511542(anf_arg36111541,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,new_DASH_letrecs19311528,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1153011531.stack[R.EXN_STACKHEIGHT++] = $ss1153411535;
}
if(R.isPyretException($e1153011531)) {
$e1153011531.pyretStack.push(L[1343]);
}
throw $e1153011531;
}
var $ret1153611537 = $Hanf_arg240511542($z1153211533,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,new_DASH_letrecs19311528,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1153611537;
};
var $Hanf_arg240511542 = function(anf_arg36111541,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,new_DASH_letrecs19311528,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var anf_fun36211553 = G(list3375,"make",L[1344]);
var $z1154511546 = D;
var $f1155111552 = function(_) {
return R.isFunction(anf_fun36211553)?anf_fun36211553.app([]):R.ffi.throwNonFunApp(L[1344],anf_fun36211553,[[]]);
};
try {
if(--R.GAS > 0) {
$z1154511546 = $f1155111552();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1155111552,
"from":L[1344]});
}
} catch($e1154311544) {
if(R.isCont($e1154311544)) {
var $ss1154711548 = {"from":L[1344],
"go":function(anf_arg36311554) {
return $Hanf_arg240411555(anf_arg36311554,A119,anf_arg36111541,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,new_DASH_letrecs19311528,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1154311544.stack[R.EXN_STACKHEIGHT++] = $ss1154711548;
}
if(R.isPyretException($e1154311544)) {
$e1154311544.pyretStack.push(L[1344]);
}
throw $e1154311544;
}
var $ret1154911550 = $Hanf_arg240411555($z1154511546,A119,anf_arg36111541,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,new_DASH_letrecs19311528,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1154911550;
};
var $Hanf_arg240411555 = function(anf_arg36311554,A119,anf_arg36111541,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,new_DASH_letrecs19311528,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1155811559 = D;
var $f1156411565 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(rest_DASH_stmts15910383,anf_arg36111541,new_DASH_letrecs19311528,anf_arg36311554):R.ffi.throwNonFunApp(L[1345],desugar_DASH_scope_DASH_block9165.$var,[rest_DASH_stmts15910383,anf_arg36111541,new_DASH_letrecs19311528,anf_arg36311554]);
};
try {
if(--R.GAS > 0) {
$z1155811559 = $f1156411565();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1156411565,
"from":L[1345]});
}
} catch($e1155611557) {
if(R.isCont($e1155611557)) {
var $ss1156011561 = {"from":L[1345],
"go":function(resolved_DASH_inner19411566) {
return $Hresolved_DASH_inner240311567(resolved_DASH_inner19411566,A119,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1155611557.stack[R.EXN_STACKHEIGHT++] = $ss1156011561;
}
if(R.isPyretException($e1155611557)) {
$e1155611557.pyretStack.push(L[1345]);
}
throw $e1155611557;
}
var $ret1156211563 = $Hresolved_DASH_inner240311567($z1155811559,A119,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1156211563;
};
var $Hresolved_DASH_inner240311567 = function(resolved_DASH_inner19411566,A119,is_DASH_empty3410379,l18510558,let_DASH_binds15510381,list3375,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1157011571 = D;
var $f1157611577 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(let_DASH_binds15510381):R.ffi.throwNonFunApp(L[1346],is_DASH_empty3410379,[let_DASH_binds15510381]);
};
try {
if(--R.GAS > 0) {
$z1157011571 = $f1157611577();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1157611577,
"from":L[1346]});
}
} catch($e1156811569) {
if(R.isCont($e1156811569)) {
var $ss1157211573 = {"from":L[1346],
"go":function(anf_arg36411578) {
return $Hanf_arg240211579(anf_arg36411578,A119,is_DASH_empty3410379,l18510558,list3375,resolved_DASH_inner19411566,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1156811569.stack[R.EXN_STACKHEIGHT++] = $ss1157211573;
}
if(R.isPyretException($e1156811569)) {
$e1156811569.pyretStack.push(L[1346]);
}
throw $e1156811569;
}
var $ret1157411575 = $Hanf_arg240211579($z1157011571,A119,is_DASH_empty3410379,l18510558,list3375,resolved_DASH_inner19411566,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1157411575;
};
var $Hanf_arg240211579 = function(anf_arg36411578,A119,is_DASH_empty3410379,l18510558,list3375,resolved_DASH_inner19411566,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1158211583 = D;
var $f1158811589 = function(_) {
return R.isFunction(not11)?not11.app(anf_arg36411578):R.ffi.throwNonFunApp(L[1347],not11,[anf_arg36411578]);
};
try {
if(--R.GAS > 0) {
$z1158211583 = $f1158811589();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1158811589,
"from":L[1347]});
}
} catch($e1158011581) {
if(R.isCont($e1158011581)) {
var $ss1158411585 = {"from":L[1347],
"go":function(if_DASH_2711590) {
return $Hif_DASH_240111591(if_DASH_2711590,A119,is_DASH_empty3410379,l18510558,list3375,resolved_DASH_inner19411566,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1158011581.stack[R.EXN_STACKHEIGHT++] = $ss1158411585;
}
if(R.isPyretException($e1158011581)) {
$e1158011581.pyretStack.push(L[1347]);
}
throw $e1158011581;
}
var $ret1158611587 = $Hif_DASH_240111591($z1158211583,A119,is_DASH_empty3410379,l18510558,list3375,resolved_DASH_inner19411566,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1158611587;
};
var $Hif_DASH_240111591 = function(if_DASH_2711590,A119,is_DASH_empty3410379,l18510558,list3375,resolved_DASH_inner19411566,type_DASH_let_DASH_binds15710384,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,not11) {
var if_helper36511605 = R.makeFunction(function(if_helper_arg36611623) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1347],1,arguments);
}
var ann_DASH_check_DASH_temp35011624 = if_helper_arg36611623;
return ann_DASH_check_DASH_temp35011624;
});
var anf_if36911622 = R.isBoolean(if_DASH_2711590);
if(R.isPyretTrue(anf_if36911622)) {
if(R.isPyretTrue(if_DASH_2711590)) {
var anf_fun38111604 = G(list3375,"make",L[1350]);
var anf_fun38211602 = G(A119,"s-block",L[1349]);
var $z1159411595 = D;
var $f1160011601 = function(_) {
return R.isFunction(anf_fun38211602)?anf_fun38211602.app(l18510558,resolved_DASH_inner19411566):R.ffi.throwNonFunApp(L[1348],anf_fun38211602,[l18510558,resolved_DASH_inner19411566]);
};
try {
if(--R.GAS > 0) {
$z1159411595 = $f1160011601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1160011601,
"from":L[1348]});
}
} catch($e1159211593) {
if(R.isCont($e1159211593)) {
var $ss1159611597 = {"from":L[1348],
"go":function(anf_arg38311603) {
return $Hanf_arg239411606(anf_arg38311603,anf_fun38111604,if_helper36511605,wrap_DASH_lets16110386);
}};
$e1159211593.stack[R.EXN_STACKHEIGHT++] = $ss1159611597;
}
if(R.isPyretException($e1159211593)) {
$e1159211593.pyretStack.push(L[1348]);
}
throw $e1159211593;
}
var $ret1159811599 = $Hanf_arg239411606($z1159411595,anf_fun38111604,if_helper36511605,wrap_DASH_lets16110386);
++R.GAS;
return $ret1159811599;
} else {
var $z1160911610 = D;
var $f1161511616 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(type_DASH_let_DASH_binds15710384):R.ffi.throwNonFunApp(L[1351],is_DASH_empty3410379,[type_DASH_let_DASH_binds15710384]);
};
try {
if(--R.GAS > 0) {
$z1160911610 = $f1161511616();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1161511616,
"from":L[1351]});
}
} catch($e1160711608) {
if(R.isCont($e1160711608)) {
var $ss1161111612 = {"from":L[1351],
"go":function(anf_arg37011617) {
return $Hanf_arg240011618(anf_arg37011617,A119,if_helper36511605,l18510558,list3375,resolved_DASH_inner19411566,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1160711608.stack[R.EXN_STACKHEIGHT++] = $ss1161111612;
}
if(R.isPyretException($e1160711608)) {
$e1160711608.pyretStack.push(L[1351]);
}
throw $e1160711608;
}
var $ret1161311614 = $Hanf_arg240011618($z1160911610,A119,if_helper36511605,l18510558,list3375,resolved_DASH_inner19411566,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1161311614;
}
} else {
var cont_tail_arg36711621 = R.throwNonBooleanCondition(L[1347],("if"),if_DASH_2711590);
if(--R.GAS > 0) {
$z1161911620 = R.isFunction(if_helper36511605)?if_helper36511605.app(cont_tail_arg36711621):R.ffi.throwNonFunApp(L[1347],if_helper36511605,[cont_tail_arg36711621]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper36511605)?if_helper36511605.app(cont_tail_arg36711621):R.ffi.throwNonFunApp(L[1347],if_helper36511605,[cont_tail_arg36711621]);
},
"from":L[1347]});
}
++R.GAS;
return $z1161911620;
}
};
var $Hanf_arg239411606 = function(anf_arg38311603,anf_fun38111604,if_helper36511605,wrap_DASH_lets16110386) {
var $z1162711628 = D;
var $f1163311634 = function(_) {
return R.isFunction(wrap_DASH_lets16110386.$var)?wrap_DASH_lets16110386.$var.app(anf_arg38311603):R.ffi.throwNonFunApp(L[1352],wrap_DASH_lets16110386.$var,[anf_arg38311603]);
};
try {
if(--R.GAS > 0) {
$z1162711628 = $f1163311634();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1163311634,
"from":L[1352]});
}
} catch($e1162511626) {
if(R.isCont($e1162511626)) {
var $ss1162911630 = {"from":L[1352],
"go":function(anf_array_val38411635) {
return $Hanf_array_val239311636(anf_array_val38411635,anf_fun38111604,if_helper36511605);
}};
$e1162511626.stack[R.EXN_STACKHEIGHT++] = $ss1162911630;
}
if(R.isPyretException($e1162511626)) {
$e1162511626.pyretStack.push(L[1352]);
}
throw $e1162511626;
}
var $ret1163111632 = $Hanf_array_val239311636($z1162711628,anf_fun38111604,if_helper36511605);
++R.GAS;
return $ret1163111632;
};
var $Hanf_array_val239311636 = function(anf_array_val38411635,anf_fun38111604,if_helper36511605) {
var $z1163911640 = D;
var $f1164511646 = function(_) {
return R.isFunction(anf_fun38111604)?anf_fun38111604.app([anf_array_val38411635]):R.ffi.throwNonFunApp(L[1350],anf_fun38111604,[[anf_array_val38411635]]);
};
try {
if(--R.GAS > 0) {
$z1163911640 = $f1164511646();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1164511646,
"from":L[1350]});
}
} catch($e1163711638) {
if(R.isCont($e1163711638)) {
var $ss1164111642 = {"from":L[1350],
"go":function(cont_tail_arg38511647) {
return $Hcont_tail_arg239211648(cont_tail_arg38511647,if_helper36511605);
}};
$e1163711638.stack[R.EXN_STACKHEIGHT++] = $ss1164111642;
}
if(R.isPyretException($e1163711638)) {
$e1163711638.pyretStack.push(L[1350]);
}
throw $e1163711638;
}
var $ret1164311644 = $Hcont_tail_arg239211648($z1163911640,if_helper36511605);
++R.GAS;
return $ret1164311644;
};
var $Hcont_tail_arg239211648 = function(cont_tail_arg38511647,if_helper36511605) {
if(--R.GAS > 0) {
$z1164911650 = R.isFunction(if_helper36511605)?if_helper36511605.app(cont_tail_arg38511647):R.ffi.throwNonFunApp(L[1350],if_helper36511605,[cont_tail_arg38511647]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper36511605)?if_helper36511605.app(cont_tail_arg38511647):R.ffi.throwNonFunApp(L[1350],if_helper36511605,[cont_tail_arg38511647]);
},
"from":L[1350]});
}
++R.GAS;
return $z1164911650;
};
var $Hanf_arg240011618 = function(anf_arg37011617,A119,if_helper36511605,l18510558,list3375,resolved_DASH_inner19411566,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1165311654 = D;
var $f1165911660 = function(_) {
return R.isFunction(not11)?not11.app(anf_arg37011617):R.ffi.throwNonFunApp(L[1353],not11,[anf_arg37011617]);
};
try {
if(--R.GAS > 0) {
$z1165311654 = $f1165911660();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1165911660,
"from":L[1353]});
}
} catch($e1165111652) {
if(R.isCont($e1165111652)) {
var $ss1165511656 = {"from":L[1353],
"go":function(if_DASH_2611661) {
return $Hif_DASH_239911662(if_DASH_2611661,A119,if_helper36511605,l18510558,list3375,resolved_DASH_inner19411566,wrap_DASH_type_DASH_lets16210387);
}};
$e1165111652.stack[R.EXN_STACKHEIGHT++] = $ss1165511656;
}
if(R.isPyretException($e1165111652)) {
$e1165111652.pyretStack.push(L[1353]);
}
throw $e1165111652;
}
var $ret1165711658 = $Hif_DASH_239911662($z1165311654,A119,if_helper36511605,l18510558,list3375,resolved_DASH_inner19411566,wrap_DASH_type_DASH_lets16210387);
++R.GAS;
return $ret1165711658;
};
var $Hif_DASH_239911662 = function(if_DASH_2611661,A119,if_helper36511605,l18510558,list3375,resolved_DASH_inner19411566,wrap_DASH_type_DASH_lets16210387) {
var anf_if37311692 = R.isBoolean(if_DASH_2611661);
if(R.isPyretTrue(anf_if37311692)) {
if(R.isPyretTrue(if_DASH_2611661)) {
var anf_fun37511675 = G(list3375,"make",L[1356]);
var anf_fun37611673 = G(A119,"s-block",L[1355]);
var $z1166511666 = D;
var $f1167111672 = function(_) {
return R.isFunction(anf_fun37611673)?anf_fun37611673.app(l18510558,resolved_DASH_inner19411566):R.ffi.throwNonFunApp(L[1354],anf_fun37611673,[l18510558,resolved_DASH_inner19411566]);
};
try {
if(--R.GAS > 0) {
$z1166511666 = $f1167111672();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1167111672,
"from":L[1354]});
}
} catch($e1166311664) {
if(R.isCont($e1166311664)) {
var $ss1166711668 = {"from":L[1354],
"go":function(anf_arg37711674) {
return $Hanf_arg239711676(anf_arg37711674,anf_fun37511675,if_helper36511605,wrap_DASH_type_DASH_lets16210387);
}};
$e1166311664.stack[R.EXN_STACKHEIGHT++] = $ss1166711668;
}
if(R.isPyretException($e1166311664)) {
$e1166311664.pyretStack.push(L[1354]);
}
throw $e1166311664;
}
var $ret1166911670 = $Hanf_arg239711676($z1166511666,anf_fun37511675,if_helper36511605,wrap_DASH_type_DASH_lets16210387);
++R.GAS;
return $ret1166911670;
} else {
var $z1167911680 = D;
var $f1168511686 = function(_) {
return R.isFunction(if_helper36511605)?if_helper36511605.app(resolved_DASH_inner19411566):R.ffi.throwNonFunApp(L[1357],if_helper36511605,[resolved_DASH_inner19411566]);
};
try {
if(--R.GAS > 0) {
$z1167911680 = $f1168511686();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1168511686,
"from":L[1357]});
}
} catch($e1167711678) {
if(R.isCont($e1167711678)) {
var $ss1168111682 = {"from":L[1357],
"go":function(cont_tail_app37411687) {
return $Hcont_tail_app239811688(cont_tail_app37411687);
}};
$e1167711678.stack[R.EXN_STACKHEIGHT++] = $ss1168111682;
}
if(R.isPyretException($e1167711678)) {
$e1167711678.pyretStack.push(L[1357]);
}
throw $e1167711678;
}
var $ret1168311684 = $Hcont_tail_app239811688($z1167911680);
++R.GAS;
return $ret1168311684;
}
} else {
var cont_tail_arg37111691 = R.throwNonBooleanCondition(L[1358],("if"),if_DASH_2611661);
if(--R.GAS > 0) {
$z1168911690 = R.isFunction(if_helper36511605)?if_helper36511605.app(cont_tail_arg37111691):R.ffi.throwNonFunApp(L[1358],if_helper36511605,[cont_tail_arg37111691]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper36511605)?if_helper36511605.app(cont_tail_arg37111691):R.ffi.throwNonFunApp(L[1358],if_helper36511605,[cont_tail_arg37111691]);
},
"from":L[1358]});
}
++R.GAS;
return $z1168911690;
}
};
var $Hanf_arg239711676 = function(anf_arg37711674,anf_fun37511675,if_helper36511605,wrap_DASH_type_DASH_lets16210387) {
var $z1169511696 = D;
var $f1170111702 = function(_) {
return R.isFunction(wrap_DASH_type_DASH_lets16210387.$var)?wrap_DASH_type_DASH_lets16210387.$var.app(anf_arg37711674):R.ffi.throwNonFunApp(L[1359],wrap_DASH_type_DASH_lets16210387.$var,[anf_arg37711674]);
};
try {
if(--R.GAS > 0) {
$z1169511696 = $f1170111702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1170111702,
"from":L[1359]});
}
} catch($e1169311694) {
if(R.isCont($e1169311694)) {
var $ss1169711698 = {"from":L[1359],
"go":function(anf_array_val37811703) {
return $Hanf_array_val239611704(anf_array_val37811703,anf_fun37511675,if_helper36511605);
}};
$e1169311694.stack[R.EXN_STACKHEIGHT++] = $ss1169711698;
}
if(R.isPyretException($e1169311694)) {
$e1169311694.pyretStack.push(L[1359]);
}
throw $e1169311694;
}
var $ret1169911700 = $Hanf_array_val239611704($z1169511696,anf_fun37511675,if_helper36511605);
++R.GAS;
return $ret1169911700;
};
var $Hanf_array_val239611704 = function(anf_array_val37811703,anf_fun37511675,if_helper36511605) {
var $z1170711708 = D;
var $f1171311714 = function(_) {
return R.isFunction(anf_fun37511675)?anf_fun37511675.app([anf_array_val37811703]):R.ffi.throwNonFunApp(L[1356],anf_fun37511675,[[anf_array_val37811703]]);
};
try {
if(--R.GAS > 0) {
$z1170711708 = $f1171311714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1171311714,
"from":L[1356]});
}
} catch($e1170511706) {
if(R.isCont($e1170511706)) {
var $ss1170911710 = {"from":L[1356],
"go":function(cont_tail_arg37911715) {
return $Hcont_tail_arg239511716(cont_tail_arg37911715,if_helper36511605);
}};
$e1170511706.stack[R.EXN_STACKHEIGHT++] = $ss1170911710;
}
if(R.isPyretException($e1170511706)) {
$e1170511706.pyretStack.push(L[1356]);
}
throw $e1170511706;
}
var $ret1171111712 = $Hcont_tail_arg239511716($z1170711708,if_helper36511605);
++R.GAS;
return $ret1171111712;
};
var $Hcont_tail_arg239511716 = function(cont_tail_arg37911715,if_helper36511605) {
if(--R.GAS > 0) {
$z1171711718 = R.isFunction(if_helper36511605)?if_helper36511605.app(cont_tail_arg37911715):R.ffi.throwNonFunApp(L[1356],if_helper36511605,[cont_tail_arg37911715]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper36511605)?if_helper36511605.app(cont_tail_arg37911715):R.ffi.throwNonFunApp(L[1356],if_helper36511605,[cont_tail_arg37911715]);
},
"from":L[1356]});
}
++R.GAS;
return $z1171711718;
};
var $Hcont_tail_app239811688 = function(cont_tail_app37411687) {
return cont_tail_app37411687;
};
var $Hanf_arg239110596 = function(anf_arg34810595,handle_DASH_let_DASH_bind16310378,l18210581) {
var $z1172111722 = D;
var $f1172711728 = function(_) {
return R.isFunction(handle_DASH_let_DASH_bind16310378.$var)?handle_DASH_let_DASH_bind16310378.$var.app(l18210581,anf_arg34810595):R.ffi.throwNonFunApp(L[1241],handle_DASH_let_DASH_bind16310378.$var,[l18210581,anf_arg34810595]);
};
try {
if(--R.GAS > 0) {
$z1172111722 = $f1172711728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1172711728,
"from":L[1241]});
}
} catch($e1171911720) {
if(R.isCont($e1171911720)) {
var $ss1172311724 = {"from":L[1241],
"go":function(ann_DASH_check_DASH_temp34611729) {
return $Hann_DASH_check_DASH_temp239011730(ann_DASH_check_DASH_temp34611729);
}};
$e1171911720.stack[R.EXN_STACKHEIGHT++] = $ss1172311724;
}
if(R.isPyretException($e1171911720)) {
$e1171911720.pyretStack.push(L[1241]);
}
throw $e1171911720;
}
var $ret1172511726 = $Hann_DASH_check_DASH_temp239011730($z1172111722);
++R.GAS;
return $ret1172511726;
};
var $Hann_DASH_check_DASH_temp239011730 = function(ann_DASH_check_DASH_temp34611729) {
return ann_DASH_check_DASH_temp34611729;
};
var $Hanf_arg238910613 = function(anf_arg34410612,handle_DASH_let_DASH_bind16310378,l17810597) {
var $z1173311734 = D;
var $f1173911740 = function(_) {
return R.isFunction(handle_DASH_let_DASH_bind16310378.$var)?handle_DASH_let_DASH_bind16310378.$var.app(l17810597,anf_arg34410612):R.ffi.throwNonFunApp(L[1244],handle_DASH_let_DASH_bind16310378.$var,[l17810597,anf_arg34410612]);
};
try {
if(--R.GAS > 0) {
$z1173311734 = $f1173911740();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1173911740,
"from":L[1244]});
}
} catch($e1173111732) {
if(R.isCont($e1173111732)) {
var $ss1173511736 = {"from":L[1244],
"go":function(ann_DASH_check_DASH_temp34211741) {
return $Hann_DASH_check_DASH_temp238811742(ann_DASH_check_DASH_temp34211741);
}};
$e1173111732.stack[R.EXN_STACKHEIGHT++] = $ss1173511736;
}
if(R.isPyretException($e1173111732)) {
$e1173111732.pyretStack.push(L[1244]);
}
throw $e1173111732;
}
var $ret1173711738 = $Hann_DASH_check_DASH_temp238811742($z1173311734);
++R.GAS;
return $ret1173711738;
};
var $Hann_DASH_check_DASH_temp238811742 = function(ann_DASH_check_DASH_temp34211741) {
return ann_DASH_check_DASH_temp34211741;
};
var $Hanf_arg238710629 = function(anf_arg31310628,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11) {
var $z1174511746 = D;
var $f1175111752 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg31310628,type_DASH_let_DASH_binds15710384):R.ffi.throwNonFunApp(L[1360],link3774,[anf_arg31310628,type_DASH_let_DASH_binds15710384]);
};
try {
if(--R.GAS > 0) {
$z1174511746 = $f1175111752();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1175111752,
"from":L[1360]});
}
} catch($e1174311744) {
if(R.isCont($e1174311744)) {
var $ss1174711748 = {"from":L[1360],
"go":function(new_DASH_type_DASH_lets17611753) {
return $Hnew_DASH_type_DASH_lets238611754(new_DASH_type_DASH_lets17611753,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
}};
$e1174311744.stack[R.EXN_STACKHEIGHT++] = $ss1174711748;
}
if(R.isPyretException($e1174311744)) {
$e1174311744.pyretStack.push(L[1360]);
}
throw $e1174311744;
}
var $ret1174911750 = $Hnew_DASH_type_DASH_lets238611754($z1174511746,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
++R.GAS;
return $ret1174911750;
};
var $Hnew_DASH_type_DASH_lets238611754 = function(new_DASH_type_DASH_lets17611753,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11) {
var anf_fun31411765 = G(list3375,"make",L[1361]);
var $z1175711758 = D;
var $f1176311764 = function(_) {
return R.isFunction(anf_fun31411765)?anf_fun31411765.app([]):R.ffi.throwNonFunApp(L[1361],anf_fun31411765,[[]]);
};
try {
if(--R.GAS > 0) {
$z1175711758 = $f1176311764();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1176311764,
"from":L[1361]});
}
} catch($e1175511756) {
if(R.isCont($e1175511756)) {
var $ss1175911760 = {"from":L[1361],
"go":function(anf_arg31511766) {
return $Hanf_arg238511767(anf_arg31511766,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,new_DASH_type_DASH_lets17611753,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
}};
$e1175511756.stack[R.EXN_STACKHEIGHT++] = $ss1175911760;
}
if(R.isPyretException($e1175511756)) {
$e1175511756.pyretStack.push(L[1361]);
}
throw $e1175511756;
}
var $ret1176111762 = $Hanf_arg238511767($z1175711758,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,new_DASH_type_DASH_lets17611753,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
++R.GAS;
return $ret1176111762;
};
var $Hanf_arg238511767 = function(anf_arg31511766,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,new_DASH_type_DASH_lets17611753,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11) {
var anf_fun31611778 = G(list3375,"make",L[1362]);
var $z1177011771 = D;
var $f1177611777 = function(_) {
return R.isFunction(anf_fun31611778)?anf_fun31611778.app([]):R.ffi.throwNonFunApp(L[1362],anf_fun31611778,[[]]);
};
try {
if(--R.GAS > 0) {
$z1177011771 = $f1177611777();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1177611777,
"from":L[1362]});
}
} catch($e1176811769) {
if(R.isCont($e1176811769)) {
var $ss1177211773 = {"from":L[1362],
"go":function(anf_arg31711779) {
return $Hanf_arg238411780(anf_arg31711779,A119,anf_arg31511766,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,new_DASH_type_DASH_lets17611753,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
}};
$e1176811769.stack[R.EXN_STACKHEIGHT++] = $ss1177211773;
}
if(R.isPyretException($e1176811769)) {
$e1176811769.pyretStack.push(L[1362]);
}
throw $e1176811769;
}
var $ret1177411775 = $Hanf_arg238411780($z1177011771,A119,anf_arg31511766,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,new_DASH_type_DASH_lets17611753,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
++R.GAS;
return $ret1177411775;
};
var $Hanf_arg238411780 = function(anf_arg31711779,A119,anf_arg31511766,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,new_DASH_type_DASH_lets17611753,rest_DASH_stmts15910383,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11) {
var $z1178311784 = D;
var $f1178911790 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(rest_DASH_stmts15910383,anf_arg31511766,anf_arg31711779,new_DASH_type_DASH_lets17611753):R.ffi.throwNonFunApp(L[1363],desugar_DASH_scope_DASH_block9165.$var,[rest_DASH_stmts15910383,anf_arg31511766,anf_arg31711779,new_DASH_type_DASH_lets17611753]);
};
try {
if(--R.GAS > 0) {
$z1178311784 = $f1178911790();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1178911790,
"from":L[1363]});
}
} catch($e1178111782) {
if(R.isCont($e1178111782)) {
var $ss1178511786 = {"from":L[1363],
"go":function(resolved_DASH_inner17711791) {
return $Hresolved_DASH_inner238311792(resolved_DASH_inner17711791,A119,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
}};
$e1178111782.stack[R.EXN_STACKHEIGHT++] = $ss1178511786;
}
if(R.isPyretException($e1178111782)) {
$e1178111782.pyretStack.push(L[1363]);
}
throw $e1178111782;
}
var $ret1178711788 = $Hresolved_DASH_inner238311792($z1178311784,A119,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
++R.GAS;
return $ret1178711788;
};
var $Hresolved_DASH_inner238311792 = function(resolved_DASH_inner17711791,A119,is_DASH_empty3410379,l17310614,let_DASH_binds15510381,letrec_DASH_binds15610382,list3375,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11) {
var $z1179511796 = D;
var $f1180111802 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(let_DASH_binds15510381):R.ffi.throwNonFunApp(L[1364],is_DASH_empty3410379,[let_DASH_binds15510381]);
};
try {
if(--R.GAS > 0) {
$z1179511796 = $f1180111802();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1180111802,
"from":L[1364]});
}
} catch($e1179311794) {
if(R.isCont($e1179311794)) {
var $ss1179711798 = {"from":L[1364],
"go":function(anf_arg31811803) {
return $Hanf_arg238211804(anf_arg31811803,A119,is_DASH_empty3410379,l17310614,letrec_DASH_binds15610382,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
}};
$e1179311794.stack[R.EXN_STACKHEIGHT++] = $ss1179711798;
}
if(R.isPyretException($e1179311794)) {
$e1179311794.pyretStack.push(L[1364]);
}
throw $e1179311794;
}
var $ret1179911800 = $Hanf_arg238211804($z1179511796,A119,is_DASH_empty3410379,l17310614,letrec_DASH_binds15610382,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
++R.GAS;
return $ret1179911800;
};
var $Hanf_arg238211804 = function(anf_arg31811803,A119,is_DASH_empty3410379,l17310614,letrec_DASH_binds15610382,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11) {
var $z1180711808 = D;
var $f1181311814 = function(_) {
return R.isFunction(not11)?not11.app(anf_arg31811803):R.ffi.throwNonFunApp(L[1365],not11,[anf_arg31811803]);
};
try {
if(--R.GAS > 0) {
$z1180711808 = $f1181311814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1181311814,
"from":L[1365]});
}
} catch($e1180511806) {
if(R.isCont($e1180511806)) {
var $ss1180911810 = {"from":L[1365],
"go":function(if_DASH_2511815) {
return $Hif_DASH_238111816(if_DASH_2511815,A119,is_DASH_empty3410379,l17310614,letrec_DASH_binds15610382,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
}};
$e1180511806.stack[R.EXN_STACKHEIGHT++] = $ss1180911810;
}
if(R.isPyretException($e1180511806)) {
$e1180511806.pyretStack.push(L[1365]);
}
throw $e1180511806;
}
var $ret1181111812 = $Hif_DASH_238111816($z1180711808,A119,is_DASH_empty3410379,l17310614,letrec_DASH_binds15610382,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11);
++R.GAS;
return $ret1181111812;
};
var $Hif_DASH_238111816 = function(if_DASH_2511815,A119,is_DASH_empty3410379,l17310614,letrec_DASH_binds15610382,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,not11) {
var if_helper31911830 = R.makeFunction(function(if_helper_arg32011848) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1365],1,arguments);
}
var ann_DASH_check_DASH_temp31111849 = if_helper_arg32011848;
return ann_DASH_check_DASH_temp31111849;
});
var anf_if32311847 = R.isBoolean(if_DASH_2511815);
if(R.isPyretTrue(anf_if32311847)) {
if(R.isPyretTrue(if_DASH_2511815)) {
var anf_fun33511829 = G(list3375,"make",L[1368]);
var anf_fun33611827 = G(A119,"s-block",L[1367]);
var $z1181911820 = D;
var $f1182511826 = function(_) {
return R.isFunction(anf_fun33611827)?anf_fun33611827.app(l17310614,resolved_DASH_inner17711791):R.ffi.throwNonFunApp(L[1366],anf_fun33611827,[l17310614,resolved_DASH_inner17711791]);
};
try {
if(--R.GAS > 0) {
$z1181911820 = $f1182511826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1182511826,
"from":L[1366]});
}
} catch($e1181711818) {
if(R.isCont($e1181711818)) {
var $ss1182111822 = {"from":L[1366],
"go":function(anf_arg33711828) {
return $Hanf_arg237411831(anf_arg33711828,anf_fun33511829,if_helper31911830,wrap_DASH_lets16110386);
}};
$e1181711818.stack[R.EXN_STACKHEIGHT++] = $ss1182111822;
}
if(R.isPyretException($e1181711818)) {
$e1181711818.pyretStack.push(L[1366]);
}
throw $e1181711818;
}
var $ret1182311824 = $Hanf_arg237411831($z1181911820,anf_fun33511829,if_helper31911830,wrap_DASH_lets16110386);
++R.GAS;
return $ret1182311824;
} else {
var $z1183411835 = D;
var $f1184011841 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(letrec_DASH_binds15610382):R.ffi.throwNonFunApp(L[1369],is_DASH_empty3410379,[letrec_DASH_binds15610382]);
};
try {
if(--R.GAS > 0) {
$z1183411835 = $f1184011841();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1184011841,
"from":L[1369]});
}
} catch($e1183211833) {
if(R.isCont($e1183211833)) {
var $ss1183611837 = {"from":L[1369],
"go":function(anf_arg32411842) {
return $Hanf_arg238011843(anf_arg32411842,A119,if_helper31911830,l17310614,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,not11);
}};
$e1183211833.stack[R.EXN_STACKHEIGHT++] = $ss1183611837;
}
if(R.isPyretException($e1183211833)) {
$e1183211833.pyretStack.push(L[1369]);
}
throw $e1183211833;
}
var $ret1183811839 = $Hanf_arg238011843($z1183411835,A119,if_helper31911830,l17310614,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,not11);
++R.GAS;
return $ret1183811839;
}
} else {
var cont_tail_arg32111846 = R.throwNonBooleanCondition(L[1365],("if"),if_DASH_2511815);
if(--R.GAS > 0) {
$z1184411845 = R.isFunction(if_helper31911830)?if_helper31911830.app(cont_tail_arg32111846):R.ffi.throwNonFunApp(L[1365],if_helper31911830,[cont_tail_arg32111846]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper31911830)?if_helper31911830.app(cont_tail_arg32111846):R.ffi.throwNonFunApp(L[1365],if_helper31911830,[cont_tail_arg32111846]);
},
"from":L[1365]});
}
++R.GAS;
return $z1184411845;
}
};
var $Hanf_arg237411831 = function(anf_arg33711828,anf_fun33511829,if_helper31911830,wrap_DASH_lets16110386) {
var $z1185211853 = D;
var $f1185811859 = function(_) {
return R.isFunction(wrap_DASH_lets16110386.$var)?wrap_DASH_lets16110386.$var.app(anf_arg33711828):R.ffi.throwNonFunApp(L[1370],wrap_DASH_lets16110386.$var,[anf_arg33711828]);
};
try {
if(--R.GAS > 0) {
$z1185211853 = $f1185811859();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1185811859,
"from":L[1370]});
}
} catch($e1185011851) {
if(R.isCont($e1185011851)) {
var $ss1185411855 = {"from":L[1370],
"go":function(anf_array_val33811860) {
return $Hanf_array_val237311861(anf_array_val33811860,anf_fun33511829,if_helper31911830);
}};
$e1185011851.stack[R.EXN_STACKHEIGHT++] = $ss1185411855;
}
if(R.isPyretException($e1185011851)) {
$e1185011851.pyretStack.push(L[1370]);
}
throw $e1185011851;
}
var $ret1185611857 = $Hanf_array_val237311861($z1185211853,anf_fun33511829,if_helper31911830);
++R.GAS;
return $ret1185611857;
};
var $Hanf_array_val237311861 = function(anf_array_val33811860,anf_fun33511829,if_helper31911830) {
var $z1186411865 = D;
var $f1187011871 = function(_) {
return R.isFunction(anf_fun33511829)?anf_fun33511829.app([anf_array_val33811860]):R.ffi.throwNonFunApp(L[1368],anf_fun33511829,[[anf_array_val33811860]]);
};
try {
if(--R.GAS > 0) {
$z1186411865 = $f1187011871();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1187011871,
"from":L[1368]});
}
} catch($e1186211863) {
if(R.isCont($e1186211863)) {
var $ss1186611867 = {"from":L[1368],
"go":function(cont_tail_arg33911872) {
return $Hcont_tail_arg237211873(cont_tail_arg33911872,if_helper31911830);
}};
$e1186211863.stack[R.EXN_STACKHEIGHT++] = $ss1186611867;
}
if(R.isPyretException($e1186211863)) {
$e1186211863.pyretStack.push(L[1368]);
}
throw $e1186211863;
}
var $ret1186811869 = $Hcont_tail_arg237211873($z1186411865,if_helper31911830);
++R.GAS;
return $ret1186811869;
};
var $Hcont_tail_arg237211873 = function(cont_tail_arg33911872,if_helper31911830) {
if(--R.GAS > 0) {
$z1187411875 = R.isFunction(if_helper31911830)?if_helper31911830.app(cont_tail_arg33911872):R.ffi.throwNonFunApp(L[1368],if_helper31911830,[cont_tail_arg33911872]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper31911830)?if_helper31911830.app(cont_tail_arg33911872):R.ffi.throwNonFunApp(L[1368],if_helper31911830,[cont_tail_arg33911872]);
},
"from":L[1368]});
}
++R.GAS;
return $z1187411875;
};
var $Hanf_arg238011843 = function(anf_arg32411842,A119,if_helper31911830,l17310614,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385,not11) {
var $z1187811879 = D;
var $f1188411885 = function(_) {
return R.isFunction(not11)?not11.app(anf_arg32411842):R.ffi.throwNonFunApp(L[1371],not11,[anf_arg32411842]);
};
try {
if(--R.GAS > 0) {
$z1187811879 = $f1188411885();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1188411885,
"from":L[1371]});
}
} catch($e1187611877) {
if(R.isCont($e1187611877)) {
var $ss1188011881 = {"from":L[1371],
"go":function(if_DASH_2411886) {
return $Hif_DASH_237911887(if_DASH_2411886,A119,if_helper31911830,l17310614,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385);
}};
$e1187611877.stack[R.EXN_STACKHEIGHT++] = $ss1188011881;
}
if(R.isPyretException($e1187611877)) {
$e1187611877.pyretStack.push(L[1371]);
}
throw $e1187611877;
}
var $ret1188211883 = $Hif_DASH_237911887($z1187811879,A119,if_helper31911830,l17310614,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385);
++R.GAS;
return $ret1188211883;
};
var $Hif_DASH_237911887 = function(if_DASH_2411886,A119,if_helper31911830,l17310614,list3375,resolved_DASH_inner17711791,wrap_DASH_letrecs16010385) {
var anf_if32711917 = R.isBoolean(if_DASH_2411886);
if(R.isPyretTrue(anf_if32711917)) {
if(R.isPyretTrue(if_DASH_2411886)) {
var anf_fun32911900 = G(list3375,"make",L[1374]);
var anf_fun33011898 = G(A119,"s-block",L[1373]);
var $z1189011891 = D;
var $f1189611897 = function(_) {
return R.isFunction(anf_fun33011898)?anf_fun33011898.app(l17310614,resolved_DASH_inner17711791):R.ffi.throwNonFunApp(L[1372],anf_fun33011898,[l17310614,resolved_DASH_inner17711791]);
};
try {
if(--R.GAS > 0) {
$z1189011891 = $f1189611897();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1189611897,
"from":L[1372]});
}
} catch($e1188811889) {
if(R.isCont($e1188811889)) {
var $ss1189211893 = {"from":L[1372],
"go":function(anf_arg33111899) {
return $Hanf_arg237711901(anf_arg33111899,anf_fun32911900,if_helper31911830,wrap_DASH_letrecs16010385);
}};
$e1188811889.stack[R.EXN_STACKHEIGHT++] = $ss1189211893;
}
if(R.isPyretException($e1188811889)) {
$e1188811889.pyretStack.push(L[1372]);
}
throw $e1188811889;
}
var $ret1189411895 = $Hanf_arg237711901($z1189011891,anf_fun32911900,if_helper31911830,wrap_DASH_letrecs16010385);
++R.GAS;
return $ret1189411895;
} else {
var $z1190411905 = D;
var $f1191011911 = function(_) {
return R.isFunction(if_helper31911830)?if_helper31911830.app(resolved_DASH_inner17711791):R.ffi.throwNonFunApp(L[1375],if_helper31911830,[resolved_DASH_inner17711791]);
};
try {
if(--R.GAS > 0) {
$z1190411905 = $f1191011911();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1191011911,
"from":L[1375]});
}
} catch($e1190211903) {
if(R.isCont($e1190211903)) {
var $ss1190611907 = {"from":L[1375],
"go":function(cont_tail_app32811912) {
return $Hcont_tail_app237811913(cont_tail_app32811912);
}};
$e1190211903.stack[R.EXN_STACKHEIGHT++] = $ss1190611907;
}
if(R.isPyretException($e1190211903)) {
$e1190211903.pyretStack.push(L[1375]);
}
throw $e1190211903;
}
var $ret1190811909 = $Hcont_tail_app237811913($z1190411905);
++R.GAS;
return $ret1190811909;
}
} else {
var cont_tail_arg32511916 = R.throwNonBooleanCondition(L[1376],("if"),if_DASH_2411886);
if(--R.GAS > 0) {
$z1191411915 = R.isFunction(if_helper31911830)?if_helper31911830.app(cont_tail_arg32511916):R.ffi.throwNonFunApp(L[1376],if_helper31911830,[cont_tail_arg32511916]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper31911830)?if_helper31911830.app(cont_tail_arg32511916):R.ffi.throwNonFunApp(L[1376],if_helper31911830,[cont_tail_arg32511916]);
},
"from":L[1376]});
}
++R.GAS;
return $z1191411915;
}
};
var $Hanf_arg237711901 = function(anf_arg33111899,anf_fun32911900,if_helper31911830,wrap_DASH_letrecs16010385) {
var $z1192011921 = D;
var $f1192611927 = function(_) {
return R.isFunction(wrap_DASH_letrecs16010385.$var)?wrap_DASH_letrecs16010385.$var.app(anf_arg33111899):R.ffi.throwNonFunApp(L[1377],wrap_DASH_letrecs16010385.$var,[anf_arg33111899]);
};
try {
if(--R.GAS > 0) {
$z1192011921 = $f1192611927();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1192611927,
"from":L[1377]});
}
} catch($e1191811919) {
if(R.isCont($e1191811919)) {
var $ss1192211923 = {"from":L[1377],
"go":function(anf_array_val33211928) {
return $Hanf_array_val237611929(anf_array_val33211928,anf_fun32911900,if_helper31911830);
}};
$e1191811919.stack[R.EXN_STACKHEIGHT++] = $ss1192211923;
}
if(R.isPyretException($e1191811919)) {
$e1191811919.pyretStack.push(L[1377]);
}
throw $e1191811919;
}
var $ret1192411925 = $Hanf_array_val237611929($z1192011921,anf_fun32911900,if_helper31911830);
++R.GAS;
return $ret1192411925;
};
var $Hanf_array_val237611929 = function(anf_array_val33211928,anf_fun32911900,if_helper31911830) {
var $z1193211933 = D;
var $f1193811939 = function(_) {
return R.isFunction(anf_fun32911900)?anf_fun32911900.app([anf_array_val33211928]):R.ffi.throwNonFunApp(L[1374],anf_fun32911900,[[anf_array_val33211928]]);
};
try {
if(--R.GAS > 0) {
$z1193211933 = $f1193811939();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1193811939,
"from":L[1374]});
}
} catch($e1193011931) {
if(R.isCont($e1193011931)) {
var $ss1193411935 = {"from":L[1374],
"go":function(cont_tail_arg33311940) {
return $Hcont_tail_arg237511941(cont_tail_arg33311940,if_helper31911830);
}};
$e1193011931.stack[R.EXN_STACKHEIGHT++] = $ss1193411935;
}
if(R.isPyretException($e1193011931)) {
$e1193011931.pyretStack.push(L[1374]);
}
throw $e1193011931;
}
var $ret1193611937 = $Hcont_tail_arg237511941($z1193211933,if_helper31911830);
++R.GAS;
return $ret1193611937;
};
var $Hcont_tail_arg237511941 = function(cont_tail_arg33311940,if_helper31911830) {
if(--R.GAS > 0) {
$z1194211943 = R.isFunction(if_helper31911830)?if_helper31911830.app(cont_tail_arg33311940):R.ffi.throwNonFunApp(L[1374],if_helper31911830,[cont_tail_arg33311940]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper31911830)?if_helper31911830.app(cont_tail_arg33311940):R.ffi.throwNonFunApp(L[1374],if_helper31911830,[cont_tail_arg33311940]);
},
"from":L[1374]});
}
++R.GAS;
return $z1194211943;
};
var $Hcont_tail_app237811913 = function(cont_tail_app32811912) {
return cont_tail_app32811912;
};
var $Hnew_DASH_binds237111944 = function(new_DASH_binds16911945,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11) {
var anf_fun28011957 = G(list3375,"make",L[1378]);
var $z1194911950 = D;
var $f1195511956 = function(_) {
return R.isFunction(anf_fun28011957)?anf_fun28011957.app([]):R.ffi.throwNonFunApp(L[1378],anf_fun28011957,[[]]);
};
try {
if(--R.GAS > 0) {
$z1194911950 = $f1195511956();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1195511956,
"from":L[1378]});
}
} catch($e1194711948) {
if(R.isCont($e1194711948)) {
var $ss1195111952 = {"from":L[1378],
"go":function(anf_arg28111958) {
return $Hanf_arg237011959(anf_arg28111958,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,new_DASH_binds16911945,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1194711948.stack[R.EXN_STACKHEIGHT++] = $ss1195111952;
}
if(R.isPyretException($e1194711948)) {
$e1194711948.pyretStack.push(L[1378]);
}
throw $e1194711948;
}
var $ret1195311954 = $Hanf_arg237011959($z1194911950,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,new_DASH_binds16911945,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1195311954;
};
var $Hanf_arg237011959 = function(anf_arg28111958,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,new_DASH_binds16911945,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11) {
var anf_fun28211970 = G(list3375,"make",L[1379]);
var $z1196211963 = D;
var $f1196811969 = function(_) {
return R.isFunction(anf_fun28211970)?anf_fun28211970.app([]):R.ffi.throwNonFunApp(L[1379],anf_fun28211970,[[]]);
};
try {
if(--R.GAS > 0) {
$z1196211963 = $f1196811969();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1196811969,
"from":L[1379]});
}
} catch($e1196011961) {
if(R.isCont($e1196011961)) {
var $ss1196411965 = {"from":L[1379],
"go":function(anf_arg28311971) {
return $Hanf_arg236911972(anf_arg28311971,A119,anf_arg28111958,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,new_DASH_binds16911945,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1196011961.stack[R.EXN_STACKHEIGHT++] = $ss1196411965;
}
if(R.isPyretException($e1196011961)) {
$e1196011961.pyretStack.push(L[1379]);
}
throw $e1196011961;
}
var $ret1196611967 = $Hanf_arg236911972($z1196211963,A119,anf_arg28111958,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,new_DASH_binds16911945,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1196611967;
};
var $Hanf_arg236911972 = function(anf_arg28311971,A119,anf_arg28111958,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,new_DASH_binds16911945,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1197511976 = D;
var $f1198111982 = function(_) {
return R.isFunction(desugar_DASH_scope_DASH_block9165.$var)?desugar_DASH_scope_DASH_block9165.$var.app(rest_DASH_stmts15910383,new_DASH_binds16911945,anf_arg28111958,anf_arg28311971):R.ffi.throwNonFunApp(L[1380],desugar_DASH_scope_DASH_block9165.$var,[rest_DASH_stmts15910383,new_DASH_binds16911945,anf_arg28111958,anf_arg28311971]);
};
try {
if(--R.GAS > 0) {
$z1197511976 = $f1198111982();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1198111982,
"from":L[1380]});
}
} catch($e1197311974) {
if(R.isCont($e1197311974)) {
var $ss1197711978 = {"from":L[1380],
"go":function(resolved_DASH_inner17011983) {
return $Hresolved_DASH_inner236811984(resolved_DASH_inner17011983,A119,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1197311974.stack[R.EXN_STACKHEIGHT++] = $ss1197711978;
}
if(R.isPyretException($e1197311974)) {
$e1197311974.pyretStack.push(L[1380]);
}
throw $e1197311974;
}
var $ret1197911980 = $Hresolved_DASH_inner236811984($z1197511976,A119,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1197911980;
};
var $Hresolved_DASH_inner236811984 = function(resolved_DASH_inner17011983,A119,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1198711988 = D;
var $f1199311994 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(letrec_DASH_binds15610382):R.ffi.throwNonFunApp(L[1381],is_DASH_empty3410379,[letrec_DASH_binds15610382]);
};
try {
if(--R.GAS > 0) {
$z1198711988 = $f1199311994();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1199311994,
"from":L[1381]});
}
} catch($e1198511986) {
if(R.isCont($e1198511986)) {
var $ss1198911990 = {"from":L[1381],
"go":function(anf_arg28411995) {
return $Hanf_arg236711996(anf_arg28411995,A119,is_DASH_empty3410379,l16711946,list3375,resolved_DASH_inner17011983,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1198511986.stack[R.EXN_STACKHEIGHT++] = $ss1198911990;
}
if(R.isPyretException($e1198511986)) {
$e1198511986.pyretStack.push(L[1381]);
}
throw $e1198511986;
}
var $ret1199111992 = $Hanf_arg236711996($z1198711988,A119,is_DASH_empty3410379,l16711946,list3375,resolved_DASH_inner17011983,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1199111992;
};
var $Hanf_arg236711996 = function(anf_arg28411995,A119,is_DASH_empty3410379,l16711946,list3375,resolved_DASH_inner17011983,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1199912000 = D;
var $f1200512006 = function(_) {
return R.isFunction(not11)?not11.app(anf_arg28411995):R.ffi.throwNonFunApp(L[1382],not11,[anf_arg28411995]);
};
try {
if(--R.GAS > 0) {
$z1199912000 = $f1200512006();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1200512006,
"from":L[1382]});
}
} catch($e1199711998) {
if(R.isCont($e1199711998)) {
var $ss1200112002 = {"from":L[1382],
"go":function(if_DASH_2012007) {
return $Hif_DASH_236612008(if_DASH_2012007,A119,is_DASH_empty3410379,l16711946,list3375,resolved_DASH_inner17011983,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1199711998.stack[R.EXN_STACKHEIGHT++] = $ss1200112002;
}
if(R.isPyretException($e1199711998)) {
$e1199711998.pyretStack.push(L[1382]);
}
throw $e1199711998;
}
var $ret1200312004 = $Hif_DASH_236612008($z1199912000,A119,is_DASH_empty3410379,l16711946,list3375,resolved_DASH_inner17011983,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1200312004;
};
var $Hif_DASH_236612008 = function(if_DASH_2012007,A119,is_DASH_empty3410379,l16711946,list3375,resolved_DASH_inner17011983,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11) {
var if_helper28512022 = R.makeFunction(function(if_helper_arg28612040) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1382],1,arguments);
}
var ann_DASH_check_DASH_temp27912041 = if_helper_arg28612040;
return ann_DASH_check_DASH_temp27912041;
});
var anf_if28912039 = R.isBoolean(if_DASH_2012007);
if(R.isPyretTrue(anf_if28912039)) {
if(R.isPyretTrue(if_DASH_2012007)) {
var anf_fun30112021 = G(list3375,"make",L[1385]);
var anf_fun30212019 = G(A119,"s-block",L[1384]);
var $z1201112012 = D;
var $f1201712018 = function(_) {
return R.isFunction(anf_fun30212019)?anf_fun30212019.app(l16711946,resolved_DASH_inner17011983):R.ffi.throwNonFunApp(L[1383],anf_fun30212019,[l16711946,resolved_DASH_inner17011983]);
};
try {
if(--R.GAS > 0) {
$z1201112012 = $f1201712018();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1201712018,
"from":L[1383]});
}
} catch($e1200912010) {
if(R.isCont($e1200912010)) {
var $ss1201312014 = {"from":L[1383],
"go":function(anf_arg30312020) {
return $Hanf_arg235912023(anf_arg30312020,anf_fun30112021,if_helper28512022,wrap_DASH_letrecs16010385);
}};
$e1200912010.stack[R.EXN_STACKHEIGHT++] = $ss1201312014;
}
if(R.isPyretException($e1200912010)) {
$e1200912010.pyretStack.push(L[1383]);
}
throw $e1200912010;
}
var $ret1201512016 = $Hanf_arg235912023($z1201112012,anf_fun30112021,if_helper28512022,wrap_DASH_letrecs16010385);
++R.GAS;
return $ret1201512016;
} else {
var $z1202612027 = D;
var $f1203212033 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(type_DASH_let_DASH_binds15710384):R.ffi.throwNonFunApp(L[1386],is_DASH_empty3410379,[type_DASH_let_DASH_binds15710384]);
};
try {
if(--R.GAS > 0) {
$z1202612027 = $f1203212033();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1203212033,
"from":L[1386]});
}
} catch($e1202412025) {
if(R.isCont($e1202412025)) {
var $ss1202812029 = {"from":L[1386],
"go":function(anf_arg29012034) {
return $Hanf_arg236512035(anf_arg29012034,A119,if_helper28512022,l16711946,list3375,resolved_DASH_inner17011983,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1202412025.stack[R.EXN_STACKHEIGHT++] = $ss1202812029;
}
if(R.isPyretException($e1202412025)) {
$e1202412025.pyretStack.push(L[1386]);
}
throw $e1202412025;
}
var $ret1203012031 = $Hanf_arg236512035($z1202612027,A119,if_helper28512022,l16711946,list3375,resolved_DASH_inner17011983,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1203012031;
}
} else {
var cont_tail_arg28712038 = R.throwNonBooleanCondition(L[1382],("if"),if_DASH_2012007);
if(--R.GAS > 0) {
$z1203612037 = R.isFunction(if_helper28512022)?if_helper28512022.app(cont_tail_arg28712038):R.ffi.throwNonFunApp(L[1382],if_helper28512022,[cont_tail_arg28712038]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper28512022)?if_helper28512022.app(cont_tail_arg28712038):R.ffi.throwNonFunApp(L[1382],if_helper28512022,[cont_tail_arg28712038]);
},
"from":L[1382]});
}
++R.GAS;
return $z1203612037;
}
};
var $Hanf_arg235912023 = function(anf_arg30312020,anf_fun30112021,if_helper28512022,wrap_DASH_letrecs16010385) {
var $z1204412045 = D;
var $f1205012051 = function(_) {
return R.isFunction(wrap_DASH_letrecs16010385.$var)?wrap_DASH_letrecs16010385.$var.app(anf_arg30312020):R.ffi.throwNonFunApp(L[1387],wrap_DASH_letrecs16010385.$var,[anf_arg30312020]);
};
try {
if(--R.GAS > 0) {
$z1204412045 = $f1205012051();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1205012051,
"from":L[1387]});
}
} catch($e1204212043) {
if(R.isCont($e1204212043)) {
var $ss1204612047 = {"from":L[1387],
"go":function(anf_array_val30412052) {
return $Hanf_array_val235812053(anf_array_val30412052,anf_fun30112021,if_helper28512022);
}};
$e1204212043.stack[R.EXN_STACKHEIGHT++] = $ss1204612047;
}
if(R.isPyretException($e1204212043)) {
$e1204212043.pyretStack.push(L[1387]);
}
throw $e1204212043;
}
var $ret1204812049 = $Hanf_array_val235812053($z1204412045,anf_fun30112021,if_helper28512022);
++R.GAS;
return $ret1204812049;
};
var $Hanf_array_val235812053 = function(anf_array_val30412052,anf_fun30112021,if_helper28512022) {
var $z1205612057 = D;
var $f1206212063 = function(_) {
return R.isFunction(anf_fun30112021)?anf_fun30112021.app([anf_array_val30412052]):R.ffi.throwNonFunApp(L[1385],anf_fun30112021,[[anf_array_val30412052]]);
};
try {
if(--R.GAS > 0) {
$z1205612057 = $f1206212063();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1206212063,
"from":L[1385]});
}
} catch($e1205412055) {
if(R.isCont($e1205412055)) {
var $ss1205812059 = {"from":L[1385],
"go":function(cont_tail_arg30512064) {
return $Hcont_tail_arg235712065(cont_tail_arg30512064,if_helper28512022);
}};
$e1205412055.stack[R.EXN_STACKHEIGHT++] = $ss1205812059;
}
if(R.isPyretException($e1205412055)) {
$e1205412055.pyretStack.push(L[1385]);
}
throw $e1205412055;
}
var $ret1206012061 = $Hcont_tail_arg235712065($z1205612057,if_helper28512022);
++R.GAS;
return $ret1206012061;
};
var $Hcont_tail_arg235712065 = function(cont_tail_arg30512064,if_helper28512022) {
if(--R.GAS > 0) {
$z1206612067 = R.isFunction(if_helper28512022)?if_helper28512022.app(cont_tail_arg30512064):R.ffi.throwNonFunApp(L[1385],if_helper28512022,[cont_tail_arg30512064]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper28512022)?if_helper28512022.app(cont_tail_arg30512064):R.ffi.throwNonFunApp(L[1385],if_helper28512022,[cont_tail_arg30512064]);
},
"from":L[1385]});
}
++R.GAS;
return $z1206612067;
};
var $Hanf_arg236512035 = function(anf_arg29012034,A119,if_helper28512022,l16711946,list3375,resolved_DASH_inner17011983,wrap_DASH_type_DASH_lets16210387,not11) {
var $z1207012071 = D;
var $f1207612077 = function(_) {
return R.isFunction(not11)?not11.app(anf_arg29012034):R.ffi.throwNonFunApp(L[1388],not11,[anf_arg29012034]);
};
try {
if(--R.GAS > 0) {
$z1207012071 = $f1207612077();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1207612077,
"from":L[1388]});
}
} catch($e1206812069) {
if(R.isCont($e1206812069)) {
var $ss1207212073 = {"from":L[1388],
"go":function(if_DASH_1912078) {
return $Hif_DASH_236412079(if_DASH_1912078,A119,if_helper28512022,l16711946,list3375,resolved_DASH_inner17011983,wrap_DASH_type_DASH_lets16210387);
}};
$e1206812069.stack[R.EXN_STACKHEIGHT++] = $ss1207212073;
}
if(R.isPyretException($e1206812069)) {
$e1206812069.pyretStack.push(L[1388]);
}
throw $e1206812069;
}
var $ret1207412075 = $Hif_DASH_236412079($z1207012071,A119,if_helper28512022,l16711946,list3375,resolved_DASH_inner17011983,wrap_DASH_type_DASH_lets16210387);
++R.GAS;
return $ret1207412075;
};
var $Hif_DASH_236412079 = function(if_DASH_1912078,A119,if_helper28512022,l16711946,list3375,resolved_DASH_inner17011983,wrap_DASH_type_DASH_lets16210387) {
var anf_if29312109 = R.isBoolean(if_DASH_1912078);
if(R.isPyretTrue(anf_if29312109)) {
if(R.isPyretTrue(if_DASH_1912078)) {
var anf_fun29512092 = G(list3375,"make",L[1391]);
var anf_fun29612090 = G(A119,"s-block",L[1390]);
var $z1208212083 = D;
var $f1208812089 = function(_) {
return R.isFunction(anf_fun29612090)?anf_fun29612090.app(l16711946,resolved_DASH_inner17011983):R.ffi.throwNonFunApp(L[1389],anf_fun29612090,[l16711946,resolved_DASH_inner17011983]);
};
try {
if(--R.GAS > 0) {
$z1208212083 = $f1208812089();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1208812089,
"from":L[1389]});
}
} catch($e1208012081) {
if(R.isCont($e1208012081)) {
var $ss1208412085 = {"from":L[1389],
"go":function(anf_arg29712091) {
return $Hanf_arg236212093(anf_arg29712091,anf_fun29512092,if_helper28512022,wrap_DASH_type_DASH_lets16210387);
}};
$e1208012081.stack[R.EXN_STACKHEIGHT++] = $ss1208412085;
}
if(R.isPyretException($e1208012081)) {
$e1208012081.pyretStack.push(L[1389]);
}
throw $e1208012081;
}
var $ret1208612087 = $Hanf_arg236212093($z1208212083,anf_fun29512092,if_helper28512022,wrap_DASH_type_DASH_lets16210387);
++R.GAS;
return $ret1208612087;
} else {
var $z1209612097 = D;
var $f1210212103 = function(_) {
return R.isFunction(if_helper28512022)?if_helper28512022.app(resolved_DASH_inner17011983):R.ffi.throwNonFunApp(L[1392],if_helper28512022,[resolved_DASH_inner17011983]);
};
try {
if(--R.GAS > 0) {
$z1209612097 = $f1210212103();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1210212103,
"from":L[1392]});
}
} catch($e1209412095) {
if(R.isCont($e1209412095)) {
var $ss1209812099 = {"from":L[1392],
"go":function(cont_tail_app29412104) {
return $Hcont_tail_app236312105(cont_tail_app29412104);
}};
$e1209412095.stack[R.EXN_STACKHEIGHT++] = $ss1209812099;
}
if(R.isPyretException($e1209412095)) {
$e1209412095.pyretStack.push(L[1392]);
}
throw $e1209412095;
}
var $ret1210012101 = $Hcont_tail_app236312105($z1209612097);
++R.GAS;
return $ret1210012101;
}
} else {
var cont_tail_arg29112108 = R.throwNonBooleanCondition(L[1393],("if"),if_DASH_1912078);
if(--R.GAS > 0) {
$z1210612107 = R.isFunction(if_helper28512022)?if_helper28512022.app(cont_tail_arg29112108):R.ffi.throwNonFunApp(L[1393],if_helper28512022,[cont_tail_arg29112108]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper28512022)?if_helper28512022.app(cont_tail_arg29112108):R.ffi.throwNonFunApp(L[1393],if_helper28512022,[cont_tail_arg29112108]);
},
"from":L[1393]});
}
++R.GAS;
return $z1210612107;
}
};
var $Hanf_arg236212093 = function(anf_arg29712091,anf_fun29512092,if_helper28512022,wrap_DASH_type_DASH_lets16210387) {
var $z1211212113 = D;
var $f1211812119 = function(_) {
return R.isFunction(wrap_DASH_type_DASH_lets16210387.$var)?wrap_DASH_type_DASH_lets16210387.$var.app(anf_arg29712091):R.ffi.throwNonFunApp(L[1394],wrap_DASH_type_DASH_lets16210387.$var,[anf_arg29712091]);
};
try {
if(--R.GAS > 0) {
$z1211212113 = $f1211812119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1211812119,
"from":L[1394]});
}
} catch($e1211012111) {
if(R.isCont($e1211012111)) {
var $ss1211412115 = {"from":L[1394],
"go":function(anf_array_val29812120) {
return $Hanf_array_val236112121(anf_array_val29812120,anf_fun29512092,if_helper28512022);
}};
$e1211012111.stack[R.EXN_STACKHEIGHT++] = $ss1211412115;
}
if(R.isPyretException($e1211012111)) {
$e1211012111.pyretStack.push(L[1394]);
}
throw $e1211012111;
}
var $ret1211612117 = $Hanf_array_val236112121($z1211212113,anf_fun29512092,if_helper28512022);
++R.GAS;
return $ret1211612117;
};
var $Hanf_array_val236112121 = function(anf_array_val29812120,anf_fun29512092,if_helper28512022) {
var $z1212412125 = D;
var $f1213012131 = function(_) {
return R.isFunction(anf_fun29512092)?anf_fun29512092.app([anf_array_val29812120]):R.ffi.throwNonFunApp(L[1391],anf_fun29512092,[[anf_array_val29812120]]);
};
try {
if(--R.GAS > 0) {
$z1212412125 = $f1213012131();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1213012131,
"from":L[1391]});
}
} catch($e1212212123) {
if(R.isCont($e1212212123)) {
var $ss1212612127 = {"from":L[1391],
"go":function(cont_tail_arg29912132) {
return $Hcont_tail_arg236012133(cont_tail_arg29912132,if_helper28512022);
}};
$e1212212123.stack[R.EXN_STACKHEIGHT++] = $ss1212612127;
}
if(R.isPyretException($e1212212123)) {
$e1212212123.pyretStack.push(L[1391]);
}
throw $e1212212123;
}
var $ret1212812129 = $Hcont_tail_arg236012133($z1212412125,if_helper28512022);
++R.GAS;
return $ret1212812129;
};
var $Hcont_tail_arg236012133 = function(cont_tail_arg29912132,if_helper28512022) {
if(--R.GAS > 0) {
$z1213412135 = R.isFunction(if_helper28512022)?if_helper28512022.app(cont_tail_arg29912132):R.ffi.throwNonFunApp(L[1391],if_helper28512022,[cont_tail_arg29912132]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper28512022)?if_helper28512022.app(cont_tail_arg29912132):R.ffi.throwNonFunApp(L[1391],if_helper28512022,[cont_tail_arg29912132]);
},
"from":L[1391]});
}
++R.GAS;
return $z1213412135;
};
var $Hcont_tail_app236312105 = function(cont_tail_app29412104) {
return cont_tail_app29412104;
};
var $Hanf_arg235612136 = function(anf_arg27712137,anf_arg27512138,anf_fun27312139,expr16612140) {
var $z1214312144 = D;
var $f1214912150 = function(_) {
return R.isFunction(anf_fun27312139)?anf_fun27312139.app(anf_arg27512138,anf_arg27712137,expr16612140):R.ffi.throwNonFunApp(L[1395],anf_fun27312139,[anf_arg27512138,anf_arg27712137,expr16612140]);
};
try {
if(--R.GAS > 0) {
$z1214312144 = $f1214912150();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1214912150,
"from":L[1395]});
}
} catch($e1214112142) {
if(R.isCont($e1214112142)) {
var $ss1214512146 = {"from":L[1395],
"go":function(ann_DASH_check_DASH_temp27212151) {
return $Hann_DASH_check_DASH_temp235512152(ann_DASH_check_DASH_temp27212151);
}};
$e1214112142.stack[R.EXN_STACKHEIGHT++] = $ss1214512146;
}
if(R.isPyretException($e1214112142)) {
$e1214112142.pyretStack.push(L[1395]);
}
throw $e1214112142;
}
var $ret1214712148 = $Hann_DASH_check_DASH_temp235512152($z1214312144);
++R.GAS;
return $ret1214712148;
};
var $Hann_DASH_check_DASH_temp235512152 = function(ann_DASH_check_DASH_temp27212151) {
return ann_DASH_check_DASH_temp27212151;
};
var $Hanf_arg235412153 = function(anf_arg27012154,anf_arg26812155,anf_fun26612156,expr16512157) {
var $z1216012161 = D;
var $f1216612167 = function(_) {
return R.isFunction(anf_fun26612156)?anf_fun26612156.app(anf_arg26812155,anf_arg27012154,expr16512157):R.ffi.throwNonFunApp(L[1396],anf_fun26612156,[anf_arg26812155,anf_arg27012154,expr16512157]);
};
try {
if(--R.GAS > 0) {
$z1216012161 = $f1216612167();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1216612167,
"from":L[1396]});
}
} catch($e1215812159) {
if(R.isCont($e1215812159)) {
var $ss1216212163 = {"from":L[1396],
"go":function(ann_DASH_check_DASH_temp26512168) {
return $Hann_DASH_check_DASH_temp235312169(ann_DASH_check_DASH_temp26512168);
}};
$e1215812159.stack[R.EXN_STACKHEIGHT++] = $ss1216212163;
}
if(R.isPyretException($e1215812159)) {
$e1215812159.pyretStack.push(L[1396]);
}
throw $e1215812159;
}
var $ret1216412165 = $Hann_DASH_check_DASH_temp235312169($z1216012161);
++R.GAS;
return $ret1216412165;
};
var $Hann_DASH_check_DASH_temp235312169 = function(ann_DASH_check_DASH_temp26512168) {
return ann_DASH_check_DASH_temp26512168;
};
var $Hanf_arg235212170 = function(anf_arg26312171,anf_arg26112172,anf_fun25912173,expr16412174) {
var $z1217712178 = D;
var $f1218312184 = function(_) {
return R.isFunction(anf_fun25912173)?anf_fun25912173.app(anf_arg26112172,anf_arg26312171,expr16412174):R.ffi.throwNonFunApp(L[1397],anf_fun25912173,[anf_arg26112172,anf_arg26312171,expr16412174]);
};
try {
if(--R.GAS > 0) {
$z1217712178 = $f1218312184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1218312184,
"from":L[1397]});
}
} catch($e1217512176) {
if(R.isCont($e1217512176)) {
var $ss1217912180 = {"from":L[1397],
"go":function(ann_DASH_check_DASH_temp25812185) {
return $Hann_DASH_check_DASH_temp235112186(ann_DASH_check_DASH_temp25812185);
}};
$e1217512176.stack[R.EXN_STACKHEIGHT++] = $ss1217912180;
}
if(R.isPyretException($e1217512176)) {
$e1217512176.pyretStack.push(L[1397]);
}
throw $e1217512176;
}
var $ret1218112182 = $Hann_DASH_check_DASH_temp235112186($z1217712178);
++R.GAS;
return $ret1218112182;
};
var $Hann_DASH_check_DASH_temp235112186 = function(ann_DASH_check_DASH_temp25812185) {
return ann_DASH_check_DASH_temp25812185;
};
var $Hor_DASH_oper_DASH_235012187 = function(or_DASH_oper_DASH_1512188,A119,A231,G1325,List2510374,empty3670,is_DASH_empty3410379,link3774,list3375,lists1727,stmts13412189,_plus9,not11,nothing12,raise14,torepr16) {
var if_helper18212200 = R.makeFunction(function(if_helper_arg18312219) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1398],1,arguments);
}
var $z1222212223 = D;
var $f1222812229 = function(_) {
return R.isFunction(not11)?not11.app(if_helper_arg18312219):R.ffi.throwNonFunApp(L[1400],not11,[if_helper_arg18312219]);
};
try {
if(--R.GAS > 0) {
$z1222212223 = $f1222812229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1222812229,
"from":L[1400]});
}
} catch($e1222012221) {
if(R.isCont($e1222012221)) {
var $ss1222412225 = {"from":L[1400],
"go":function(when_DASH_1412230) {
return $Hwhen_DASH_234612231(when_DASH_1412230,A119,A231,G1325,List2510374,empty3670,is_DASH_empty3410379,link3774,list3375,lists1727,stmts13412189,_plus9,nothing12,raise14,torepr16);
}};
$e1222012221.stack[R.EXN_STACKHEIGHT++] = $ss1222412225;
}
if(R.isPyretException($e1222012221)) {
$e1222012221.pyretStack.push(L[1400]);
}
throw $e1222012221;
}
var $ret1222612227 = $Hwhen_DASH_234612231($z1222212223,A119,A231,G1325,List2510374,empty3670,is_DASH_empty3410379,link3774,list3375,lists1727,stmts13412189,_plus9,nothing12,raise14,torepr16);
++R.GAS;
return $ret1222612227;
});
var anf_if24612218 = R.isBoolean(or_DASH_oper_DASH_1512188);
if(R.isPyretTrue(anf_if24612218)) {
if(R.isPyretTrue(or_DASH_oper_DASH_1512188)) {
var $z1219212193 = D;
var $f1219812199 = function(_) {
return R.isFunction(if_helper18212200)?if_helper18212200.app((true)):R.ffi.throwNonFunApp(L[1398],if_helper18212200,[(true)]);
};
try {
if(--R.GAS > 0) {
$z1219212193 = $f1219812199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1219812199,
"from":L[1398]});
}
} catch($e1219012191) {
if(R.isCont($e1219012191)) {
var $ss1219412195 = {"from":L[1398],
"go":function(cont_tail_app25112201) {
return $Hcont_tail_app234712202(cont_tail_app25112201);
}};
$e1219012191.stack[R.EXN_STACKHEIGHT++] = $ss1219412195;
}
if(R.isPyretException($e1219012191)) {
$e1219012191.pyretStack.push(L[1398]);
}
throw $e1219012191;
}
var $ret1219612197 = $Hcont_tail_app234712202($z1219212193);
++R.GAS;
return $ret1219612197;
} else {
var $z1220512206 = D;
var $f1221112212 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(stmts13412189):R.ffi.throwNonFunApp(L[1398],is_DASH_empty3410379,[stmts13412189]);
};
try {
if(--R.GAS > 0) {
$z1220512206 = $f1221112212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1221112212,
"from":L[1398]});
}
} catch($e1220312204) {
if(R.isCont($e1220312204)) {
var $ss1220712208 = {"from":L[1398],
"go":function(or_DASH_oper_DASH_1612213) {
return $Hor_DASH_oper_DASH_234912214(or_DASH_oper_DASH_1612213,if_helper18212200);
}};
$e1220312204.stack[R.EXN_STACKHEIGHT++] = $ss1220712208;
}
if(R.isPyretException($e1220312204)) {
$e1220312204.pyretStack.push(L[1398]);
}
throw $e1220312204;
}
var $ret1220912210 = $Hor_DASH_oper_DASH_234912214($z1220512206,if_helper18212200);
++R.GAS;
return $ret1220912210;
}
} else {
var cont_tail_arg24412217 = R.throwNonBooleanOp(L[1399],("first"),("or"),or_DASH_oper_DASH_1512188);
if(--R.GAS > 0) {
$z1221512216 = R.isFunction(if_helper18212200)?if_helper18212200.app(cont_tail_arg24412217):R.ffi.throwNonFunApp(L[1399],if_helper18212200,[cont_tail_arg24412217]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper18212200)?if_helper18212200.app(cont_tail_arg24412217):R.ffi.throwNonFunApp(L[1399],if_helper18212200,[cont_tail_arg24412217]);
},
"from":L[1399]});
}
++R.GAS;
return $z1221512216;
}
};
var $Hcont_tail_app234712202 = function(cont_tail_app25112201) {
return cont_tail_app25112201;
};
var $Hor_DASH_oper_DASH_234912214 = function(or_DASH_oper_DASH_1612213,if_helper18212200) {
var anf_if24912247 = R.isBoolean(or_DASH_oper_DASH_1612213);
if(R.isPyretTrue(anf_if24912247)) {
var $z1223412235 = D;
var $f1224012241 = function(_) {
return R.isFunction(if_helper18212200)?if_helper18212200.app(or_DASH_oper_DASH_1612213):R.ffi.throwNonFunApp(L[1398],if_helper18212200,[or_DASH_oper_DASH_1612213]);
};
try {
if(--R.GAS > 0) {
$z1223412235 = $f1224012241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1224012241,
"from":L[1398]});
}
} catch($e1223212233) {
if(R.isCont($e1223212233)) {
var $ss1223612237 = {"from":L[1398],
"go":function(cont_tail_app25012242) {
return $Hcont_tail_app234812243(cont_tail_app25012242);
}};
$e1223212233.stack[R.EXN_STACKHEIGHT++] = $ss1223612237;
}
if(R.isPyretException($e1223212233)) {
$e1223212233.pyretStack.push(L[1398]);
}
throw $e1223212233;
}
var $ret1223812239 = $Hcont_tail_app234812243($z1223412235);
++R.GAS;
return $ret1223812239;
} else {
var cont_tail_arg24712246 = R.throwNonBooleanOp(L[1401],("second"),("or"),or_DASH_oper_DASH_1612213);
if(--R.GAS > 0) {
$z1224412245 = R.isFunction(if_helper18212200)?if_helper18212200.app(cont_tail_arg24712246):R.ffi.throwNonFunApp(L[1401],if_helper18212200,[cont_tail_arg24712246]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper18212200)?if_helper18212200.app(cont_tail_arg24712246):R.ffi.throwNonFunApp(L[1401],if_helper18212200,[cont_tail_arg24712246]);
},
"from":L[1401]});
}
++R.GAS;
return $z1224412245;
}
};
var $Hcont_tail_app234812243 = function(cont_tail_app25012242) {
return cont_tail_app25012242;
};
var $Hwhen_DASH_234612231 = function(when_DASH_1412230,A119,A231,G1325,List2510374,empty3670,is_DASH_empty3410379,link3774,list3375,lists1727,stmts13412189,_plus9,nothing12,raise14,torepr16) {
var if_helper18412259 = R.makeFunction(function(if_helper_arg18512277) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1400],1,arguments);
}
if_helper_arg18512277;
var rev_DASH_type_DASH_binds13512292 = {"$var":empty3670,
"$name":"rev-type-binds"};
var rev_DASH_stmts13612291 = {"$var":empty3670,
"$name":"rev-stmts"};
var anf_fun18612288 = G(lists1727,"each",L[1415]);
var anf_arg21712289 = R.makeFunction(function(s13712294) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1404],1,arguments);
}
var cases_DASH_val1712376 = s13712294;
var anf_fun18812305 = G(cases_DASH_val1712376,"_match",L[1405]);
var anf_obj19112322 = R.makeFunction(function(l13812361,name13912362,ann14012363) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1413],3,arguments);
}
var $z1236612367 = D;
var $f1237212373 = function(_) {
return R.isFunction(link3774)?link3774.app(s13712294,rev_DASH_stmts13612291.$var):R.ffi.throwNonFunApp(L[1414],link3774,[s13712294,rev_DASH_stmts13612291.$var]);
};
try {
if(--R.GAS > 0) {
$z1236612367 = $f1237212373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1237212373,
"from":L[1414]});
}
} catch($e1236412365) {
if(R.isCont($e1236412365)) {
var $ss1236812369 = {"from":L[1414],
"go":function(anf_assign19012374) {
return $Hanf_assign231712375(anf_assign19012374,rev_DASH_stmts13612291);
}};
$e1236412365.stack[R.EXN_STACKHEIGHT++] = $ss1236812369;
}
if(R.isPyretException($e1236412365)) {
$e1236412365.pyretStack.push(L[1414]);
}
throw $e1236412365;
}
var $ret1237012371 = $Hanf_assign231712375($z1236612367,rev_DASH_stmts13612291);
++R.GAS;
return $ret1237012371;
});
var anf_obj19612323 = R.makeFunction(function(l14112345,name14212346,namet14312347) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1410],3,arguments);
}
var anf_fun19312358 = G(A119,"s-newtype-bind",L[1412]);
var $z1235012351 = D;
var $f1235612357 = function(_) {
return R.isFunction(anf_fun19312358)?anf_fun19312358.app(l14112345,name14212346,namet14312347):R.ffi.throwNonFunApp(L[1411],anf_fun19312358,[l14112345,name14212346,namet14312347]);
};
try {
if(--R.GAS > 0) {
$z1235012351 = $f1235612357();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1235612357,
"from":L[1411]});
}
} catch($e1234812349) {
if(R.isCont($e1234812349)) {
var $ss1235212353 = {"from":L[1411],
"go":function(anf_arg19412359) {
return $Hanf_arg231912360(anf_arg19412359,link3774,rev_DASH_type_DASH_binds13512292);
}};
$e1234812349.stack[R.EXN_STACKHEIGHT++] = $ss1235212353;
}
if(R.isPyretException($e1234812349)) {
$e1234812349.pyretStack.push(L[1411]);
}
throw $e1234812349;
}
var $ret1235412355 = $Hanf_arg231912360($z1235012351,link3774,rev_DASH_type_DASH_binds13512292);
++R.GAS;
return $ret1235412355;
});
var anf_obj21212324 = R.makeFunction(function(l14412325,name14512326,params14612327,mixins14712328,variants14812329,shared14912330,_check15012331) {
if(arguments.length !== 7) {
throw R.ffi.throwArityErrorC(L[1407],7,arguments);
}
var anf_fun19812343 = G(G1325,"make-name",L[1409]);
var $z1233412335 = D;
var $f1234012341 = function(_) {
return R.isFunction(_plus9)?_plus9.app(name14512326,("T")):R.ffi.throwNonFunApp(L[1408],_plus9,[name14512326,("T")]);
};
try {
if(--R.GAS > 0) {
$z1233412335 = $f1234012341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1234012341,
"from":L[1408]});
}
} catch($e1233212333) {
if(R.isCont($e1233212333)) {
var $ss1233612337 = {"from":L[1408],
"go":function(anf_arg19912342) {
return $Hanf_arg232812344(anf_arg19912342,A119,_check15012331,anf_fun19812343,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
}};
$e1233212333.stack[R.EXN_STACKHEIGHT++] = $ss1233612337;
}
if(R.isPyretException($e1233212333)) {
$e1233212333.pyretStack.push(L[1408]);
}
throw $e1233212333;
}
var $ret1233812339 = $Hanf_arg232812344($z1233412335,A119,_check15012331,anf_fun19812343,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
++R.GAS;
return $ret1233812339;
});
var anf_arg21312306 = R.makeObject({"s-type":anf_obj19112322,
"s-newtype":anf_obj19612323,
"s-data":anf_obj21212324});
var anf_arg21612307 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1405],0,arguments);
}
var $z1231212313 = D;
var $f1231812319 = function(_) {
return R.isFunction(link3774)?link3774.app(s13712294,rev_DASH_stmts13612291.$var):R.ffi.throwNonFunApp(L[1406],link3774,[s13712294,rev_DASH_stmts13612291.$var]);
};
try {
if(--R.GAS > 0) {
$z1231212313 = $f1231812319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1231812319,
"from":L[1406]});
}
} catch($e1231012311) {
if(R.isCont($e1231012311)) {
var $ss1231412315 = {"from":L[1406],
"go":function(anf_assign21512320) {
return $Hanf_assign232912321(anf_assign21512320,rev_DASH_stmts13612291);
}};
$e1231012311.stack[R.EXN_STACKHEIGHT++] = $ss1231412315;
}
if(R.isPyretException($e1231012311)) {
$e1231012311.pyretStack.push(L[1406]);
}
throw $e1231012311;
}
var $ret1231612317 = $Hanf_assign232912321($z1231212313,rev_DASH_stmts13612291);
++R.GAS;
return $ret1231612317;
});
var $z1229712298 = D;
var $f1230312304 = function(_) {
return R.isFunction(anf_fun18812305)?anf_fun18812305.app(anf_arg21312306,anf_arg21612307):R.ffi.throwNonFunApp(L[1404],anf_fun18812305,[anf_arg21312306,anf_arg21612307]);
};
try {
if(--R.GAS > 0) {
$z1229712298 = $f1230312304();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1230312304,
"from":L[1404]});
}
} catch($e1229512296) {
if(R.isCont($e1229512296)) {
var $ss1229912300 = {"from":L[1404],
"go":function(ann_DASH_check_DASH_temp18712308) {
return $Hann_DASH_check_DASH_temp233012309(ann_DASH_check_DASH_temp18712308);
}};
$e1229512296.stack[R.EXN_STACKHEIGHT++] = $ss1229912300;
}
if(R.isPyretException($e1229512296)) {
$e1229512296.pyretStack.push(L[1404]);
}
throw $e1229512296;
}
var $ret1230112302 = $Hann_DASH_check_DASH_temp233012309($z1229712298);
++R.GAS;
return $ret1230112302;
});
var $z1228012281 = D;
var $f1228612287 = function(_) {
return R.isFunction(anf_fun18612288)?anf_fun18612288.app(anf_arg21712289,stmts13412189):R.ffi.throwNonFunApp(L[1404],anf_fun18612288,[anf_arg21712289,stmts13412189]);
};
try {
if(--R.GAS > 0) {
$z1228012281 = $f1228612287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1228612287,
"from":L[1404]});
}
} catch($e1227812279) {
if(R.isCont($e1227812279)) {
var $ss1228212283 = {"from":L[1404],
"go":function(anf_begin_app_dropped233112290) {
return $Hanf_begin_app_dropped233912293(anf_begin_app_dropped233112290,A119,A231,List2510374,is_DASH_empty3410379,list3375,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,stmts13412189);
}};
$e1227812279.stack[R.EXN_STACKHEIGHT++] = $ss1228212283;
}
if(R.isPyretException($e1227812279)) {
$e1227812279.pyretStack.push(L[1404]);
}
throw $e1227812279;
}
var $ret1228412285 = $Hanf_begin_app_dropped233912293($z1228012281,A119,A231,List2510374,is_DASH_empty3410379,list3375,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,stmts13412189);
++R.GAS;
return $ret1228412285;
});
var anf_if23912276 = R.isBoolean(when_DASH_1412230);
if(R.isPyretTrue(anf_if23912276)) {
if(R.isPyretTrue(when_DASH_1412230)) {
var $z1225012251 = D;
var $f1225612257 = function(_) {
return R.isFunction(torepr16)?torepr16.app(stmts13412189):R.ffi.throwNonFunApp(L[1402],torepr16,[stmts13412189]);
};
try {
if(--R.GAS > 0) {
$z1225012251 = $f1225612257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1225612257,
"from":L[1402]});
}
} catch($e1224812249) {
if(R.isCont($e1224812249)) {
var $ss1225212253 = {"from":L[1402],
"go":function(anf_arg24112258) {
return $Hanf_arg234412260(anf_arg24112258,if_helper18412259,_plus9,nothing12,raise14);
}};
$e1224812249.stack[R.EXN_STACKHEIGHT++] = $ss1225212253;
}
if(R.isPyretException($e1224812249)) {
$e1224812249.pyretStack.push(L[1402]);
}
throw $e1224812249;
}
var $ret1225412255 = $Hanf_arg234412260($z1225012251,if_helper18412259,_plus9,nothing12,raise14);
++R.GAS;
return $ret1225412255;
} else {
var $z1226312264 = D;
var $f1226912270 = function(_) {
return R.isFunction(if_helper18412259)?if_helper18412259.app(nothing12):R.ffi.throwNonFunApp(L[1400],if_helper18412259,[nothing12]);
};
try {
if(--R.GAS > 0) {
$z1226312264 = $f1226912270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1226912270,
"from":L[1400]});
}
} catch($e1226112262) {
if(R.isCont($e1226112262)) {
var $ss1226512266 = {"from":L[1400],
"go":function(cont_tail_app24012271) {
return $Hcont_tail_app234512272(cont_tail_app24012271);
}};
$e1226112262.stack[R.EXN_STACKHEIGHT++] = $ss1226512266;
}
if(R.isPyretException($e1226112262)) {
$e1226112262.pyretStack.push(L[1400]);
}
throw $e1226112262;
}
var $ret1226712268 = $Hcont_tail_app234512272($z1226312264);
++R.GAS;
return $ret1226712268;
}
} else {
var cont_tail_arg23712275 = R.throwNonBooleanCondition(L[1403],("when"),when_DASH_1412230);
if(--R.GAS > 0) {
$z1227312274 = R.isFunction(if_helper18412259)?if_helper18412259.app(cont_tail_arg23712275):R.ffi.throwNonFunApp(L[1403],if_helper18412259,[cont_tail_arg23712275]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper18412259)?if_helper18412259.app(cont_tail_arg23712275):R.ffi.throwNonFunApp(L[1403],if_helper18412259,[cont_tail_arg23712275]);
},
"from":L[1403]});
}
++R.GAS;
return $z1227312274;
}
};
var $Hanf_arg234412260 = function(anf_arg24112258,if_helper18412259,_plus9,nothing12,raise14) {
var $z1237912380 = D;
var $f1238512386 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("Expected list of statements, got "),anf_arg24112258):R.ffi.throwNonFunApp(L[1416],_plus9,[("Expected list of statements, got "),anf_arg24112258]);
};
try {
if(--R.GAS > 0) {
$z1237912380 = $f1238512386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1238512386,
"from":L[1416]});
}
} catch($e1237712378) {
if(R.isCont($e1237712378)) {
var $ss1238112382 = {"from":L[1416],
"go":function(anf_arg24212387) {
return $Hanf_arg234312388(anf_arg24212387,if_helper18412259,nothing12,raise14);
}};
$e1237712378.stack[R.EXN_STACKHEIGHT++] = $ss1238112382;
}
if(R.isPyretException($e1237712378)) {
$e1237712378.pyretStack.push(L[1416]);
}
throw $e1237712378;
}
var $ret1238312384 = $Hanf_arg234312388($z1237912380,if_helper18412259,nothing12,raise14);
++R.GAS;
return $ret1238312384;
};
var $Hanf_arg234312388 = function(anf_arg24212387,if_helper18412259,nothing12,raise14) {
var $z1239112392 = D;
var $f1239712398 = function(_) {
return R.isFunction(raise14)?raise14.app(anf_arg24212387):R.ffi.throwNonFunApp(L[1417],raise14,[anf_arg24212387]);
};
try {
if(--R.GAS > 0) {
$z1239112392 = $f1239712398();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1239712398,
"from":L[1417]});
}
} catch($e1238912390) {
if(R.isCont($e1238912390)) {
var $ss1239312394 = {"from":L[1417],
"go":function(anf_begin_app_dropped234012399) {
return $Hanf_begin_app_dropped234212400(anf_begin_app_dropped234012399,if_helper18412259,nothing12);
}};
$e1238912390.stack[R.EXN_STACKHEIGHT++] = $ss1239312394;
}
if(R.isPyretException($e1238912390)) {
$e1238912390.pyretStack.push(L[1417]);
}
throw $e1238912390;
}
var $ret1239512396 = $Hanf_begin_app_dropped234212400($z1239112392,if_helper18412259,nothing12);
++R.GAS;
return $ret1239512396;
};
var $Hanf_begin_app_dropped234212400 = function(anf_begin_app_dropped234012399,if_helper18412259,nothing12) {
var $z1240312404 = D;
var $f1240912410 = function(_) {
return R.isFunction(if_helper18412259)?if_helper18412259.app(nothing12):R.ffi.throwNonFunApp(L[1400],if_helper18412259,[nothing12]);
};
try {
if(--R.GAS > 0) {
$z1240312404 = $f1240912410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1240912410,
"from":L[1400]});
}
} catch($e1240112402) {
if(R.isCont($e1240112402)) {
var $ss1240512406 = {"from":L[1400],
"go":function(cont_tail_app24312411) {
return $Hcont_tail_app234112412(cont_tail_app24312411);
}};
$e1240112402.stack[R.EXN_STACKHEIGHT++] = $ss1240512406;
}
if(R.isPyretException($e1240112402)) {
$e1240112402.pyretStack.push(L[1400]);
}
throw $e1240112402;
}
var $ret1240712408 = $Hcont_tail_app234112412($z1240312404);
++R.GAS;
return $ret1240712408;
};
var $Hcont_tail_app234112412 = function(cont_tail_app24312411) {
return cont_tail_app24312411;
};
var $Hcont_tail_app234512272 = function(cont_tail_app24012271) {
return cont_tail_app24012271;
};
var $Hanf_begin_app_dropped233912293 = function(anf_begin_app_dropped233112290,A119,A231,List2510374,is_DASH_empty3410379,list3375,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,stmts13412189) {
var $z1241512416 = D;
var $f1242112422 = function(_) {
return R.isFunction(is_DASH_empty3410379)?is_DASH_empty3410379.app(rev_DASH_type_DASH_binds13512292.$var):R.ffi.throwNonFunApp(L[1418],is_DASH_empty3410379,[rev_DASH_type_DASH_binds13512292.$var]);
};
try {
if(--R.GAS > 0) {
$z1241512416 = $f1242112422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1242112422,
"from":L[1418]});
}
} catch($e1241312414) {
if(R.isCont($e1241312414)) {
var $ss1241712418 = {"from":L[1418],
"go":function(if_DASH_1812423) {
return $Hif_DASH_233812424(if_DASH_1812423,A119,A231,List2510374,list3375,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,stmts13412189);
}};
$e1241312414.stack[R.EXN_STACKHEIGHT++] = $ss1241712418;
}
if(R.isPyretException($e1241312414)) {
$e1241312414.pyretStack.push(L[1418]);
}
throw $e1241312414;
}
var $ret1241912420 = $Hif_DASH_233812424($z1241512416,A119,A231,List2510374,list3375,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,stmts13412189);
++R.GAS;
return $ret1241912420;
};
var $Hif_DASH_233812424 = function(if_DASH_1812423,A119,A231,List2510374,list3375,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,stmts13412189) {
var if_helper21812435 = R.makeFunction(function(if_helper_arg21912455) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1418],1,arguments);
}
var ann_DASH_check_DASH_temp18112456 = if_helper_arg21912455;
return R.checkAnn(L[1422],List2510374,ann_DASH_check_DASH_temp18112456,function() {
return ann_DASH_check_DASH_temp18112456;
});
});
var anf_if22212454 = R.isBoolean(if_DASH_1812423);
if(R.isPyretTrue(anf_if22212454)) {
if(R.isPyretTrue(if_DASH_1812423)) {
var $z1242712428 = D;
var $f1243312434 = function(_) {
return R.isFunction(if_helper21812435)?if_helper21812435.app(stmts13412189):R.ffi.throwNonFunApp(L[1419],if_helper21812435,[stmts13412189]);
};
try {
if(--R.GAS > 0) {
$z1242712428 = $f1243312434();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1243312434,
"from":L[1419]});
}
} catch($e1242512426) {
if(R.isCont($e1242512426)) {
var $ss1242912430 = {"from":L[1419],
"go":function(cont_tail_app23612436) {
return $Hcont_tail_app233212437(cont_tail_app23612436);
}};
$e1242512426.stack[R.EXN_STACKHEIGHT++] = $ss1242912430;
}
if(R.isPyretException($e1242512426)) {
$e1242512426.pyretStack.push(L[1419]);
}
throw $e1242512426;
}
var $ret1243112432 = $Hcont_tail_app233212437($z1242712428);
++R.GAS;
return $ret1243112432;
} else {
var anf_fun22312448 = G(rev_DASH_type_DASH_binds13512292.$var,"reverse",L[1421]);
var $z1244012441 = D;
var $f1244612447 = function(_) {
return R.isFunction(anf_fun22312448)?anf_fun22312448.app():R.ffi.throwNonFunApp(L[1420],anf_fun22312448,[]);
};
try {
if(--R.GAS > 0) {
$z1244012441 = $f1244612447();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1244612447,
"from":L[1420]});
}
} catch($e1243812439) {
if(R.isCont($e1243812439)) {
var $ss1244212443 = {"from":L[1420],
"go":function(type_DASH_binds15212449) {
return $Htype_DASH_binds233712450(type_DASH_binds15212449,A119,if_helper21812435,list3375,rev_DASH_stmts13612291);
}};
$e1243812439.stack[R.EXN_STACKHEIGHT++] = $ss1244212443;
}
if(R.isPyretException($e1243812439)) {
$e1243812439.pyretStack.push(L[1420]);
}
throw $e1243812439;
}
var $ret1244412445 = $Htype_DASH_binds233712450($z1244012441,A119,if_helper21812435,list3375,rev_DASH_stmts13612291);
++R.GAS;
return $ret1244412445;
}
} else {
var cont_tail_arg22012453 = R.throwNonBooleanCondition(L[1418],("if"),if_DASH_1812423);
if(--R.GAS > 0) {
$z1245112452 = R.isFunction(if_helper21812435)?if_helper21812435.app(cont_tail_arg22012453):R.ffi.throwNonFunApp(L[1418],if_helper21812435,[cont_tail_arg22012453]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper21812435)?if_helper21812435.app(cont_tail_arg22012453):R.ffi.throwNonFunApp(L[1418],if_helper21812435,[cont_tail_arg22012453]);
},
"from":L[1418]});
}
++R.GAS;
return $z1245112452;
}
};
var $Hcont_tail_app233212437 = function(cont_tail_app23612436) {
return cont_tail_app23612436;
};
var $Htype_DASH_binds233712450 = function(type_DASH_binds15212449,A119,if_helper21812435,list3375,rev_DASH_stmts13612291) {
var anf_fun22412467 = G(rev_DASH_stmts13612291.$var,"reverse",L[1424]);
var $z1245912460 = D;
var $f1246512466 = function(_) {
return R.isFunction(anf_fun22412467)?anf_fun22412467.app():R.ffi.throwNonFunApp(L[1423],anf_fun22412467,[]);
};
try {
if(--R.GAS > 0) {
$z1245912460 = $f1246512466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1246512466,
"from":L[1423]});
}
} catch($e1245712458) {
if(R.isCont($e1245712458)) {
var $ss1246112462 = {"from":L[1423],
"go":function(new_DASH_stmts15312468) {
return $Hnew_DASH_stmts233612469(new_DASH_stmts15312468,A119,if_helper21812435,list3375,type_DASH_binds15212449);
}};
$e1245712458.stack[R.EXN_STACKHEIGHT++] = $ss1246112462;
}
if(R.isPyretException($e1245712458)) {
$e1245712458.pyretStack.push(L[1423]);
}
throw $e1245712458;
}
var $ret1246312464 = $Hnew_DASH_stmts233612469($z1245912460,A119,if_helper21812435,list3375,type_DASH_binds15212449);
++R.GAS;
return $ret1246312464;
};
var $Hnew_DASH_stmts233612469 = function(new_DASH_stmts15312468,A119,if_helper21812435,list3375,type_DASH_binds15212449) {
var anf_fun22512484 = G(list3375,"make",L[1432]);
var anf_fun22612485 = G(A119,"s-type-let-expr",L[1431]);
var anf_bracket22712488 = G(type_DASH_binds15212449,"first",L[1430]);
var anf_arg22812483 = G(anf_bracket22712488,"l",L[1429]);
var anf_fun22912480 = G(A119,"s-block",L[1428]);
var anf_bracket23012487 = G(type_DASH_binds15212449,"first",L[1427]);
var anf_arg23112481 = G(anf_bracket23012487,"l",L[1426]);
var $z1247212473 = D;
var $f1247812479 = function(_) {
return R.isFunction(anf_fun22912480)?anf_fun22912480.app(anf_arg23112481,new_DASH_stmts15312468):R.ffi.throwNonFunApp(L[1425],anf_fun22912480,[anf_arg23112481,new_DASH_stmts15312468]);
};
try {
if(--R.GAS > 0) {
$z1247212473 = $f1247812479();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1247812479,
"from":L[1425]});
}
} catch($e1247012471) {
if(R.isCont($e1247012471)) {
var $ss1247412475 = {"from":L[1425],
"go":function(anf_arg23212482) {
return $Hanf_arg233512486(anf_arg23212482,anf_arg22812483,anf_fun22512484,anf_fun22612485,if_helper21812435,type_DASH_binds15212449);
}};
$e1247012471.stack[R.EXN_STACKHEIGHT++] = $ss1247412475;
}
if(R.isPyretException($e1247012471)) {
$e1247012471.pyretStack.push(L[1425]);
}
throw $e1247012471;
}
var $ret1247612477 = $Hanf_arg233512486($z1247212473,anf_arg22812483,anf_fun22512484,anf_fun22612485,if_helper21812435,type_DASH_binds15212449);
++R.GAS;
return $ret1247612477;
};
var $Hanf_arg233512486 = function(anf_arg23212482,anf_arg22812483,anf_fun22512484,anf_fun22612485,if_helper21812435,type_DASH_binds15212449) {
var $z1249112492 = D;
var $f1249712498 = function(_) {
return R.isFunction(anf_fun22612485)?anf_fun22612485.app(anf_arg22812483,type_DASH_binds15212449,anf_arg23212482):R.ffi.throwNonFunApp(L[1433],anf_fun22612485,[anf_arg22812483,type_DASH_binds15212449,anf_arg23212482]);
};
try {
if(--R.GAS > 0) {
$z1249112492 = $f1249712498();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1249712498,
"from":L[1433]});
}
} catch($e1248912490) {
if(R.isCont($e1248912490)) {
var $ss1249312494 = {"from":L[1433],
"go":function(anf_array_val23312499) {
return $Hanf_array_val233412500(anf_array_val23312499,anf_fun22512484,if_helper21812435);
}};
$e1248912490.stack[R.EXN_STACKHEIGHT++] = $ss1249312494;
}
if(R.isPyretException($e1248912490)) {
$e1248912490.pyretStack.push(L[1433]);
}
throw $e1248912490;
}
var $ret1249512496 = $Hanf_array_val233412500($z1249112492,anf_fun22512484,if_helper21812435);
++R.GAS;
return $ret1249512496;
};
var $Hanf_array_val233412500 = function(anf_array_val23312499,anf_fun22512484,if_helper21812435) {
var $z1250312504 = D;
var $f1250912510 = function(_) {
return R.isFunction(anf_fun22512484)?anf_fun22512484.app([anf_array_val23312499]):R.ffi.throwNonFunApp(L[1432],anf_fun22512484,[[anf_array_val23312499]]);
};
try {
if(--R.GAS > 0) {
$z1250312504 = $f1250912510();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1250912510,
"from":L[1432]});
}
} catch($e1250112502) {
if(R.isCont($e1250112502)) {
var $ss1250512506 = {"from":L[1432],
"go":function(cont_tail_arg23412511) {
return $Hcont_tail_arg233312512(cont_tail_arg23412511,if_helper21812435);
}};
$e1250112502.stack[R.EXN_STACKHEIGHT++] = $ss1250512506;
}
if(R.isPyretException($e1250112502)) {
$e1250112502.pyretStack.push(L[1432]);
}
throw $e1250112502;
}
var $ret1250712508 = $Hcont_tail_arg233312512($z1250312504,if_helper21812435);
++R.GAS;
return $ret1250712508;
};
var $Hcont_tail_arg233312512 = function(cont_tail_arg23412511,if_helper21812435) {
if(--R.GAS > 0) {
$z1251312514 = R.isFunction(if_helper21812435)?if_helper21812435.app(cont_tail_arg23412511):R.ffi.throwNonFunApp(L[1432],if_helper21812435,[cont_tail_arg23412511]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper21812435)?if_helper21812435.app(cont_tail_arg23412511):R.ffi.throwNonFunApp(L[1432],if_helper21812435,[cont_tail_arg23412511]);
},
"from":L[1432]});
}
++R.GAS;
return $z1251312514;
};
var $Hann_DASH_check_DASH_temp233012309 = function(ann_DASH_check_DASH_temp18712308) {
return ann_DASH_check_DASH_temp18712308;
};
var $Hanf_assign232912321 = function(anf_assign21512320,rev_DASH_stmts13612291) {
var ann_DASH_check_DASH_temp21412515 = rev_DASH_stmts13612291.$var = anf_assign21512320;
return ann_DASH_check_DASH_temp21412515;
};
var $Hanf_arg232812344 = function(anf_arg19912342,A119,_check15012331,anf_fun19812343,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329) {
var $z1251812519 = D;
var $f1252412525 = function(_) {
return R.isFunction(anf_fun19812343)?anf_fun19812343.app(anf_arg19912342):R.ffi.throwNonFunApp(L[1434],anf_fun19812343,[anf_arg19912342]);
};
try {
if(--R.GAS > 0) {
$z1251812519 = $f1252412525();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1252412525,
"from":L[1434]});
}
} catch($e1251612517) {
if(R.isCont($e1251612517)) {
var $ss1252012521 = {"from":L[1434],
"go":function(namet15112526) {
return $Hnamet232712527(namet15112526,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
}};
$e1251612517.stack[R.EXN_STACKHEIGHT++] = $ss1252012521;
}
if(R.isPyretException($e1251612517)) {
$e1251612517.pyretStack.push(L[1434]);
}
throw $e1251612517;
}
var $ret1252212523 = $Hnamet232712527($z1251812519,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
++R.GAS;
return $ret1252212523;
};
var $Hnamet232712527 = function(namet15112526,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329) {
var anf_fun20012540 = G(A119,"s-newtype-bind",L[1437]);
var anf_fun20112538 = G(A119,"s-name",L[1436]);
var $z1253012531 = D;
var $f1253612537 = function(_) {
return R.isFunction(anf_fun20112538)?anf_fun20112538.app(l14412325,name14512326):R.ffi.throwNonFunApp(L[1435],anf_fun20112538,[l14412325,name14512326]);
};
try {
if(--R.GAS > 0) {
$z1253012531 = $f1253612537();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1253612537,
"from":L[1435]});
}
} catch($e1252812529) {
if(R.isCont($e1252812529)) {
var $ss1253212533 = {"from":L[1435],
"go":function(anf_arg20212539) {
return $Hanf_arg232612541(anf_arg20212539,A119,_check15012331,anf_fun20012540,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
}};
$e1252812529.stack[R.EXN_STACKHEIGHT++] = $ss1253212533;
}
if(R.isPyretException($e1252812529)) {
$e1252812529.pyretStack.push(L[1435]);
}
throw $e1252812529;
}
var $ret1253412535 = $Hanf_arg232612541($z1253012531,A119,_check15012331,anf_fun20012540,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
++R.GAS;
return $ret1253412535;
};
var $Hanf_arg232612541 = function(anf_arg20212539,A119,_check15012331,anf_fun20012540,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329) {
var anf_fun20312552 = G(A119,"s-name",L[1439]);
var $z1254412545 = D;
var $f1255012551 = function(_) {
return R.isFunction(anf_fun20312552)?anf_fun20312552.app(l14412325,namet15112526):R.ffi.throwNonFunApp(L[1438],anf_fun20312552,[l14412325,namet15112526]);
};
try {
if(--R.GAS > 0) {
$z1254412545 = $f1255012551();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1255012551,
"from":L[1438]});
}
} catch($e1254212543) {
if(R.isCont($e1254212543)) {
var $ss1254612547 = {"from":L[1438],
"go":function(anf_arg20412553) {
return $Hanf_arg232512554(anf_arg20412553,A119,_check15012331,anf_arg20212539,anf_fun20012540,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
}};
$e1254212543.stack[R.EXN_STACKHEIGHT++] = $ss1254612547;
}
if(R.isPyretException($e1254212543)) {
$e1254212543.pyretStack.push(L[1438]);
}
throw $e1254212543;
}
var $ret1254812549 = $Hanf_arg232512554($z1254412545,A119,_check15012331,anf_arg20212539,anf_fun20012540,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
++R.GAS;
return $ret1254812549;
};
var $Hanf_arg232512554 = function(anf_arg20412553,A119,_check15012331,anf_arg20212539,anf_fun20012540,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329) {
var $z1255712558 = D;
var $f1256312564 = function(_) {
return R.isFunction(anf_fun20012540)?anf_fun20012540.app(l14412325,anf_arg20212539,anf_arg20412553):R.ffi.throwNonFunApp(L[1440],anf_fun20012540,[l14412325,anf_arg20212539,anf_arg20412553]);
};
try {
if(--R.GAS > 0) {
$z1255712558 = $f1256312564();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1256312564,
"from":L[1440]});
}
} catch($e1255512556) {
if(R.isCont($e1255512556)) {
var $ss1255912560 = {"from":L[1440],
"go":function(anf_arg20512565) {
return $Hanf_arg232412566(anf_arg20512565,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
}};
$e1255512556.stack[R.EXN_STACKHEIGHT++] = $ss1255912560;
}
if(R.isPyretException($e1255512556)) {
$e1255512556.pyretStack.push(L[1440]);
}
throw $e1255512556;
}
var $ret1256112562 = $Hanf_arg232412566($z1255712558,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
++R.GAS;
return $ret1256112562;
};
var $Hanf_arg232412566 = function(anf_arg20512565,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329) {
var $z1256912570 = D;
var $f1257512576 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg20512565,rev_DASH_type_DASH_binds13512292.$var):R.ffi.throwNonFunApp(L[1441],link3774,[anf_arg20512565,rev_DASH_type_DASH_binds13512292.$var]);
};
try {
if(--R.GAS > 0) {
$z1256912570 = $f1257512576();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1257512576,
"from":L[1441]});
}
} catch($e1256712568) {
if(R.isCont($e1256712568)) {
var $ss1257112572 = {"from":L[1441],
"go":function(anf_assign20612577) {
return $Hanf_assign232312578(anf_assign20612577,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
}};
$e1256712568.stack[R.EXN_STACKHEIGHT++] = $ss1257112572;
}
if(R.isPyretException($e1256712568)) {
$e1256712568.pyretStack.push(L[1441]);
}
throw $e1256712568;
}
var $ret1257312574 = $Hanf_assign232312578($z1256912570,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329);
++R.GAS;
return $ret1257312574;
};
var $Hanf_assign232312578 = function(anf_assign20612577,A119,_check15012331,l14412325,link3774,mixins14712328,name14512326,namet15112526,params14612327,rev_DASH_stmts13612291,rev_DASH_type_DASH_binds13512292,shared14912330,variants14812329) {
rev_DASH_type_DASH_binds13512292.$var = anf_assign20612577;
var anf_fun20712591 = G(A119,"s-data-expr",L[1444]);
var anf_fun20812589 = G(A119,"s-name",L[1443]);
var $z1258112582 = D;
var $f1258712588 = function(_) {
return R.isFunction(anf_fun20812589)?anf_fun20812589.app(l14412325,namet15112526):R.ffi.throwNonFunApp(L[1442],anf_fun20812589,[l14412325,namet15112526]);
};
try {
if(--R.GAS > 0) {
$z1258112582 = $f1258712588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1258712588,
"from":L[1442]});
}
} catch($e1257912580) {
if(R.isCont($e1257912580)) {
var $ss1258312584 = {"from":L[1442],
"go":function(anf_arg20912590) {
return $Hanf_arg232212592(anf_arg20912590,_check15012331,anf_fun20712591,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,shared14912330,variants14812329);
}};
$e1257912580.stack[R.EXN_STACKHEIGHT++] = $ss1258312584;
}
if(R.isPyretException($e1257912580)) {
$e1257912580.pyretStack.push(L[1442]);
}
throw $e1257912580;
}
var $ret1258512586 = $Hanf_arg232212592($z1258112582,_check15012331,anf_fun20712591,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,shared14912330,variants14812329);
++R.GAS;
return $ret1258512586;
};
var $Hanf_arg232212592 = function(anf_arg20912590,_check15012331,anf_fun20712591,l14412325,link3774,mixins14712328,name14512326,params14612327,rev_DASH_stmts13612291,shared14912330,variants14812329) {
var $z1259512596 = D;
var $f1260112602 = function(_) {
return R.isFunction(anf_fun20712591)?anf_fun20712591.app(l14412325,name14512326,anf_arg20912590,params14612327,mixins14712328,variants14812329,shared14912330,_check15012331):R.ffi.throwNonFunApp(L[1445],anf_fun20712591,[l14412325,name14512326,anf_arg20912590,params14612327,mixins14712328,variants14812329,shared14912330,_check15012331]);
};
try {
if(--R.GAS > 0) {
$z1259512596 = $f1260112602();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1260112602,
"from":L[1445]});
}
} catch($e1259312594) {
if(R.isCont($e1259312594)) {
var $ss1259712598 = {"from":L[1445],
"go":function(anf_arg21012603) {
return $Hanf_arg232112604(anf_arg21012603,link3774,rev_DASH_stmts13612291);
}};
$e1259312594.stack[R.EXN_STACKHEIGHT++] = $ss1259712598;
}
if(R.isPyretException($e1259312594)) {
$e1259312594.pyretStack.push(L[1445]);
}
throw $e1259312594;
}
var $ret1259912600 = $Hanf_arg232112604($z1259512596,link3774,rev_DASH_stmts13612291);
++R.GAS;
return $ret1259912600;
};
var $Hanf_arg232112604 = function(anf_arg21012603,link3774,rev_DASH_stmts13612291) {
var $z1260712608 = D;
var $f1261312614 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg21012603,rev_DASH_stmts13612291.$var):R.ffi.throwNonFunApp(L[1446],link3774,[anf_arg21012603,rev_DASH_stmts13612291.$var]);
};
try {
if(--R.GAS > 0) {
$z1260712608 = $f1261312614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1261312614,
"from":L[1446]});
}
} catch($e1260512606) {
if(R.isCont($e1260512606)) {
var $ss1260912610 = {"from":L[1446],
"go":function(anf_assign21112615) {
return $Hanf_assign232012616(anf_assign21112615,rev_DASH_stmts13612291);
}};
$e1260512606.stack[R.EXN_STACKHEIGHT++] = $ss1260912610;
}
if(R.isPyretException($e1260512606)) {
$e1260512606.pyretStack.push(L[1446]);
}
throw $e1260512606;
}
var $ret1261112612 = $Hanf_assign232012616($z1260712608,rev_DASH_stmts13612291);
++R.GAS;
return $ret1261112612;
};
var $Hanf_assign232012616 = function(anf_assign21112615,rev_DASH_stmts13612291) {
var ann_DASH_check_DASH_temp19712617 = rev_DASH_stmts13612291.$var = anf_assign21112615;
return ann_DASH_check_DASH_temp19712617;
};
var $Hanf_arg231912360 = function(anf_arg19412359,link3774,rev_DASH_type_DASH_binds13512292) {
var $z1262012621 = D;
var $f1262612627 = function(_) {
return R.isFunction(link3774)?link3774.app(anf_arg19412359,rev_DASH_type_DASH_binds13512292.$var):R.ffi.throwNonFunApp(L[1447],link3774,[anf_arg19412359,rev_DASH_type_DASH_binds13512292.$var]);
};
try {
if(--R.GAS > 0) {
$z1262012621 = $f1262612627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1262612627,
"from":L[1447]});
}
} catch($e1261812619) {
if(R.isCont($e1261812619)) {
var $ss1262212623 = {"from":L[1447],
"go":function(anf_assign19512628) {
return $Hanf_assign231812629(anf_assign19512628,rev_DASH_type_DASH_binds13512292);
}};
$e1261812619.stack[R.EXN_STACKHEIGHT++] = $ss1262212623;
}
if(R.isPyretException($e1261812619)) {
$e1261812619.pyretStack.push(L[1447]);
}
throw $e1261812619;
}
var $ret1262412625 = $Hanf_assign231812629($z1262012621,rev_DASH_type_DASH_binds13512292);
++R.GAS;
return $ret1262412625;
};
var $Hanf_assign231812629 = function(anf_assign19512628,rev_DASH_type_DASH_binds13512292) {
var ann_DASH_check_DASH_temp19212630 = rev_DASH_type_DASH_binds13512292.$var = anf_assign19512628;
return ann_DASH_check_DASH_temp19212630;
};
var $Hanf_assign231712375 = function(anf_assign19012374,rev_DASH_stmts13612291) {
var ann_DASH_check_DASH_temp18912631 = rev_DASH_stmts13612291.$var = anf_assign19012374;
return ann_DASH_check_DASH_temp18912631;
};
var $Hanf_obj231612632 = function(anf_obj17012633,anf_arg16812634,fold6171,imports11212635,list3375) {
var anf_fun17112646 = G(list3375,"make",L[1448]);
var $z1263812639 = D;
var $f1264412645 = function(_) {
return R.isFunction(anf_fun17112646)?anf_fun17112646.app([]):R.ffi.throwNonFunApp(L[1448],anf_fun17112646,[[]]);
};
try {
if(--R.GAS > 0) {
$z1263812639 = $f1264412645();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1264412645,
"from":L[1448]});
}
} catch($e1263612637) {
if(R.isCont($e1263612637)) {
var $ss1264012641 = {"from":L[1448],
"go":function(anf_obj17212647) {
return $Hanf_obj231512648(anf_obj17212647,anf_arg16812634,anf_obj17012633,fold6171,imports11212635);
}};
$e1263612637.stack[R.EXN_STACKHEIGHT++] = $ss1264012641;
}
if(R.isPyretException($e1263612637)) {
$e1263612637.pyretStack.push(L[1448]);
}
throw $e1263612637;
}
var $ret1264212643 = $Hanf_obj231512648($z1263812639,anf_arg16812634,anf_obj17012633,fold6171,imports11212635);
++R.GAS;
return $ret1264212643;
};
var $Hanf_obj231512648 = function(anf_obj17212647,anf_arg16812634,anf_obj17012633,fold6171,imports11212635) {
var anf_arg17312659 = R.makeObject({"imports":anf_obj17012633,
"lets":anf_obj17212647});
var $z1265112652 = D;
var $f1265712658 = function(_) {
return R.isFunction(fold6171)?fold6171.app(anf_arg16812634,anf_arg17312659,imports11212635):R.ffi.throwNonFunApp(L[1449],fold6171,[anf_arg16812634,anf_arg17312659,imports11212635]);
};
try {
if(--R.GAS > 0) {
$z1265112652 = $f1265712658();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1265712658,
"from":L[1449]});
}
} catch($e1264912650) {
if(R.isCont($e1264912650)) {
var $ss1265312654 = {"from":L[1449],
"go":function(ret11912660) {
return $Hret231412661(ret11912660);
}};
$e1264912650.stack[R.EXN_STACKHEIGHT++] = $ss1265312654;
}
if(R.isPyretException($e1264912650)) {
$e1264912650.pyretStack.push(L[1449]);
}
throw $e1264912650;
}
var $ret1265512656 = $Hret231412661($z1265112652);
++R.GAS;
return $ret1265512656;
};
var $Hret231412661 = function(ret11912660) {
var anf_bracket17412675 = G(ret11912660,"imports",L[1452]);
var anf_fun17512672 = G(anf_bracket17412675,"reverse",L[1451]);
var $z1266412665 = D;
var $f1267012671 = function(_) {
return R.isFunction(anf_fun17512672)?anf_fun17512672.app():R.ffi.throwNonFunApp(L[1450],anf_fun17512672,[]);
};
try {
if(--R.GAS > 0) {
$z1266412665 = $f1267012671();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1267012671,
"from":L[1450]});
}
} catch($e1266212663) {
if(R.isCont($e1266212663)) {
var $ss1266612667 = {"from":L[1450],
"go":function(anf_obj17612673) {
return $Hanf_obj231312674(anf_obj17612673,ret11912660);
}};
$e1266212663.stack[R.EXN_STACKHEIGHT++] = $ss1266612667;
}
if(R.isPyretException($e1266212663)) {
$e1266212663.pyretStack.push(L[1450]);
}
throw $e1266212663;
}
var $ret1266812669 = $Hanf_obj231312674($z1266412665,ret11912660);
++R.GAS;
return $ret1266812669;
};
var $Hanf_obj231312674 = function(anf_obj17612673,ret11912660) {
var anf_bracket17712689 = G(ret11912660,"lets",L[1455]);
var anf_fun17812686 = G(anf_bracket17712689,"reverse",L[1454]);
var $z1267812679 = D;
var $f1268412685 = function(_) {
return R.isFunction(anf_fun17812686)?anf_fun17812686.app():R.ffi.throwNonFunApp(L[1453],anf_fun17812686,[]);
};
try {
if(--R.GAS > 0) {
$z1267812679 = $f1268412685();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1268412685,
"from":L[1453]});
}
} catch($e1267612677) {
if(R.isCont($e1267612677)) {
var $ss1268012681 = {"from":L[1453],
"go":function(anf_obj17912687) {
return $Hanf_obj231212688(anf_obj17912687,anf_obj17612673);
}};
$e1267612677.stack[R.EXN_STACKHEIGHT++] = $ss1268012681;
}
if(R.isPyretException($e1267612677)) {
$e1267612677.pyretStack.push(L[1453]);
}
throw $e1267612677;
}
var $ret1268212683 = $Hanf_obj231212688($z1267812679,anf_obj17612673);
++R.GAS;
return $ret1268212683;
};
var $Hanf_obj231212688 = function(anf_obj17912687,anf_obj17612673) {
var ann_DASH_check_DASH_temp10012690 = R.makeObject({"imports":anf_obj17612673,
"lets":anf_obj17912687});
return ann_DASH_check_DASH_temp10012690;
};
var $Hann_DASH_check_DASH_temp231112691 = function(ann_DASH_check_DASH_temp12112692) {
return ann_DASH_check_DASH_temp12112692;
};
var $Hif_DASH_231012693 = function(if_DASH_1212694,A119,G1325,acc12012695,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9) {
var if_helper13112702 = R.makeFunction(function(if_helper_arg13212720) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1458],1,arguments);
}
var imp_DASH_str12912732 = if_helper_arg13212720;
var anf_fun13312735 = G(A119,"s-name",L[1462]);
var anf_arg13412734 = G(imp12812697,"l",L[1461]);
var anf_fun13512731 = G(G1325,"make-name",L[1460]);
var $z1272312724 = D;
var $f1272912730 = function(_) {
return R.isFunction(anf_fun13512731)?anf_fun13512731.app(imp_DASH_str12912732):R.ffi.throwNonFunApp(L[1459],anf_fun13512731,[imp_DASH_str12912732]);
};
try {
if(--R.GAS > 0) {
$z1272312724 = $f1272912730();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1272912730,
"from":L[1459]});
}
} catch($e1272112722) {
if(R.isCont($e1272112722)) {
var $ss1272512726 = {"from":L[1459],
"go":function(anf_arg13612733) {
return $Hanf_arg230812736(anf_arg13612733,A119,acc12012695,anf_arg13412734,anf_fun13312735,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9);
}};
$e1272112722.stack[R.EXN_STACKHEIGHT++] = $ss1272512726;
}
if(R.isPyretException($e1272112722)) {
$e1272112722.pyretStack.push(L[1459]);
}
throw $e1272112722;
}
var $ret1272712728 = $Hanf_arg230812736($z1272312724,A119,acc12012695,anf_arg13412734,anf_fun13312735,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9);
++R.GAS;
return $ret1272712728;
});
var anf_if16012719 = R.isBoolean(if_DASH_1212694);
if(R.isPyretTrue(anf_if16012719)) {
if(R.isPyretTrue(if_DASH_1212694)) {
var cont_tail_arg16212703 = G(imp12812697,"mod",L[1456]);
if(--R.GAS > 0) {
$z1270012701 = R.isFunction(if_helper13112702)?if_helper13112702.app(cont_tail_arg16212703):R.ffi.throwNonFunApp(L[1456],if_helper13112702,[cont_tail_arg16212703]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper13112702)?if_helper13112702.app(cont_tail_arg16212703):R.ffi.throwNonFunApp(L[1456],if_helper13112702,[cont_tail_arg16212703]);
},
"from":L[1456]});
}
++R.GAS;
return $z1270012701;
} else {
var $z1270612707 = D;
var $f1271212713 = function(_) {
return R.isFunction(if_helper13112702)?if_helper13112702.app(("mod-import")):R.ffi.throwNonFunApp(L[1457],if_helper13112702,[("mod-import")]);
};
try {
if(--R.GAS > 0) {
$z1270612707 = $f1271212713();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1271212713,
"from":L[1457]});
}
} catch($e1270412705) {
if(R.isCont($e1270412705)) {
var $ss1270812709 = {"from":L[1457],
"go":function(cont_tail_app16112714) {
return $Hcont_tail_app230912715(cont_tail_app16112714);
}};
$e1270412705.stack[R.EXN_STACKHEIGHT++] = $ss1270812709;
}
if(R.isPyretException($e1270412705)) {
$e1270412705.pyretStack.push(L[1457]);
}
throw $e1270412705;
}
var $ret1271012711 = $Hcont_tail_app230912715($z1270612707);
++R.GAS;
return $ret1271012711;
}
} else {
var cont_tail_arg15812718 = R.throwNonBooleanCondition(L[1458],("if"),if_DASH_1212694);
if(--R.GAS > 0) {
$z1271612717 = R.isFunction(if_helper13112702)?if_helper13112702.app(cont_tail_arg15812718):R.ffi.throwNonFunApp(L[1458],if_helper13112702,[cont_tail_arg15812718]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper13112702)?if_helper13112702.app(cont_tail_arg15812718):R.ffi.throwNonFunApp(L[1458],if_helper13112702,[cont_tail_arg15812718]);
},
"from":L[1458]});
}
++R.GAS;
return $z1271612717;
}
};
var $Hcont_tail_app230912715 = function(cont_tail_app16112714) {
return cont_tail_app16112714;
};
var $Hanf_arg230812736 = function(anf_arg13612733,A119,acc12012695,anf_arg13412734,anf_fun13312735,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9) {
var $z1273912740 = D;
var $f1274512746 = function(_) {
return R.isFunction(anf_fun13312735)?anf_fun13312735.app(anf_arg13412734,anf_arg13612733):R.ffi.throwNonFunApp(L[1463],anf_fun13312735,[anf_arg13412734,anf_arg13612733]);
};
try {
if(--R.GAS > 0) {
$z1273912740 = $f1274512746();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1274512746,
"from":L[1463]});
}
} catch($e1273712738) {
if(R.isCont($e1273712738)) {
var $ss1274112742 = {"from":L[1463],
"go":function(imp_DASH_name13012747) {
return $Himp_DASH_name230712748(imp_DASH_name13012747,A119,acc12012695,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9);
}};
$e1273712738.stack[R.EXN_STACKHEIGHT++] = $ss1274112742;
}
if(R.isPyretException($e1273712738)) {
$e1273712738.pyretStack.push(L[1463]);
}
throw $e1273712738;
}
var $ret1274312744 = $Himp_DASH_name230712748($z1273912740,A119,acc12012695,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9);
++R.GAS;
return $ret1274312744;
};
var $Himp_DASH_name230712748 = function(imp_DASH_name13012747,A119,acc12012695,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9) {
var anf_fun13712760 = G(A119,"s-import",L[1465]);
var $z1275112752 = D;
var $f1275712758 = function(_) {
return R.isFunction(resolve_DASH_import_DASH_type11312699.$var)?resolve_DASH_import_DASH_type11312699.$var.app(imp12812697):R.ffi.throwNonFunApp(L[1464],resolve_DASH_import_DASH_type11312699.$var,[imp12812697]);
};
try {
if(--R.GAS > 0) {
$z1275112752 = $f1275712758();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1275712758,
"from":L[1464]});
}
} catch($e1274912750) {
if(R.isCont($e1274912750)) {
var $ss1275312754 = {"from":L[1464],
"go":function(anf_arg13812759) {
return $Hanf_arg230612761(anf_arg13812759,A119,acc12012695,anf_fun13712760,fields12712696,imp_DASH_name13012747,l12612698,link3774,map459174,_plus9);
}};
$e1274912750.stack[R.EXN_STACKHEIGHT++] = $ss1275312754;
}
if(R.isPyretException($e1274912750)) {
$e1274912750.pyretStack.push(L[1464]);
}
throw $e1274912750;
}
var $ret1275512756 = $Hanf_arg230612761($z1275112752,A119,acc12012695,anf_fun13712760,fields12712696,imp_DASH_name13012747,l12612698,link3774,map459174,_plus9);
++R.GAS;
return $ret1275512756;
};
var $Hanf_arg230612761 = function(anf_arg13812759,A119,acc12012695,anf_fun13712760,fields12712696,imp_DASH_name13012747,l12612698,link3774,map459174,_plus9) {
var $z1276412765 = D;
var $f1277012771 = function(_) {
return R.isFunction(anf_fun13712760)?anf_fun13712760.app(l12612698,anf_arg13812759,imp_DASH_name13012747):R.ffi.throwNonFunApp(L[1466],anf_fun13712760,[l12612698,anf_arg13812759,imp_DASH_name13012747]);
};
try {
if(--R.GAS > 0) {
$z1276412765 = $f1277012771();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1277012771,
"from":L[1466]});
}
} catch($e1276212763) {
if(R.isCont($e1276212763)) {
var $ss1276612767 = {"from":L[1466],
"go":function(new_DASH_i13112772) {
return $Hnew_DASH_i230512773(new_DASH_i13112772,A119,acc12012695,fields12712696,imp_DASH_name13012747,l12612698,link3774,map459174,_plus9);
}};
$e1276212763.stack[R.EXN_STACKHEIGHT++] = $ss1276612767;
}
if(R.isPyretException($e1276212763)) {
$e1276212763.pyretStack.push(L[1466]);
}
throw $e1276212763;
}
var $ret1276812769 = $Hnew_DASH_i230512773($z1276412765,A119,acc12012695,fields12712696,imp_DASH_name13012747,l12612698,link3774,map459174,_plus9);
++R.GAS;
return $ret1276812769;
};
var $Hnew_DASH_i230512773 = function(new_DASH_i13112772,A119,acc12012695,fields12712696,imp_DASH_name13012747,l12612698,link3774,map459174,_plus9) {
var anf_arg15112786 = R.makeFunction(function(f13312788) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1469],1,arguments);
}
var anf_fun14012803 = G(A119,"s-let",L[1474]);
var anf_arg14112802 = G(f13312788,"l",L[1473]);
var anf_fun14212799 = G(A119,"s-bind",L[1472]);
var anf_arg14312800 = G(A119,"a-blank",L[1471]);
var $z1279112792 = D;
var $f1279712798 = function(_) {
return R.isFunction(anf_fun14212799)?anf_fun14212799.app(l12612698,(false),f13312788,anf_arg14312800):R.ffi.throwNonFunApp(L[1470],anf_fun14212799,[l12612698,(false),f13312788,anf_arg14312800]);
};
try {
if(--R.GAS > 0) {
$z1279112792 = $f1279712798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1279712798,
"from":L[1470]});
}
} catch($e1278912790) {
if(R.isCont($e1278912790)) {
var $ss1279312794 = {"from":L[1470],
"go":function(anf_arg14412801) {
return $Hanf_arg230012804(anf_arg14412801,A119,anf_arg14112802,anf_fun14012803,f13312788,imp_DASH_name13012747,l12612698);
}};
$e1278912790.stack[R.EXN_STACKHEIGHT++] = $ss1279312794;
}
if(R.isPyretException($e1278912790)) {
$e1278912790.pyretStack.push(L[1470]);
}
throw $e1278912790;
}
var $ret1279512796 = $Hanf_arg230012804($z1279112792,A119,anf_arg14112802,anf_fun14012803,f13312788,imp_DASH_name13012747,l12612698);
++R.GAS;
return $ret1279512796;
});
var anf_fun15212784 = G(fields12712696,"reverse",L[1468]);
var $z1277612777 = D;
var $f1278212783 = function(_) {
return R.isFunction(anf_fun15212784)?anf_fun15212784.app():R.ffi.throwNonFunApp(L[1467],anf_fun15212784,[]);
};
try {
if(--R.GAS > 0) {
$z1277612777 = $f1278212783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1278212783,
"from":L[1467]});
}
} catch($e1277412775) {
if(R.isCont($e1277412775)) {
var $ss1277812779 = {"from":L[1467],
"go":function(anf_arg15312785) {
return $Hanf_arg230412787(anf_arg15312785,acc12012695,anf_arg15112786,link3774,map459174,new_DASH_i13112772,_plus9);
}};
$e1277412775.stack[R.EXN_STACKHEIGHT++] = $ss1277812779;
}
if(R.isPyretException($e1277412775)) {
$e1277412775.pyretStack.push(L[1467]);
}
throw $e1277412775;
}
var $ret1278012781 = $Hanf_arg230412787($z1277612777,acc12012695,anf_arg15112786,link3774,map459174,new_DASH_i13112772,_plus9);
++R.GAS;
return $ret1278012781;
};
var $Hanf_arg230412787 = function(anf_arg15312785,acc12012695,anf_arg15112786,link3774,map459174,new_DASH_i13112772,_plus9) {
var $z1280712808 = D;
var $f1281312814 = function(_) {
return R.isFunction(map459174)?map459174.app(anf_arg15112786,anf_arg15312785):R.ffi.throwNonFunApp(L[1475],map459174,[anf_arg15112786,anf_arg15312785]);
};
try {
if(--R.GAS > 0) {
$z1280712808 = $f1281312814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1281312814,
"from":L[1475]});
}
} catch($e1280512806) {
if(R.isCont($e1280512806)) {
var $ss1280912810 = {"from":L[1475],
"go":function(new_DASH_lets13212815) {
return $Hnew_DASH_lets230312816(new_DASH_lets13212815,acc12012695,link3774,new_DASH_i13112772,_plus9);
}};
$e1280512806.stack[R.EXN_STACKHEIGHT++] = $ss1280912810;
}
if(R.isPyretException($e1280512806)) {
$e1280512806.pyretStack.push(L[1475]);
}
throw $e1280512806;
}
var $ret1281112812 = $Hnew_DASH_lets230312816($z1280712808,acc12012695,link3774,new_DASH_i13112772,_plus9);
++R.GAS;
return $ret1281112812;
};
var $Hnew_DASH_lets230312816 = function(new_DASH_lets13212815,acc12012695,link3774,new_DASH_i13112772,_plus9) {
var anf_arg15412827 = G(acc12012695,"imports",L[1477]);
var $z1281912820 = D;
var $f1282512826 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_i13112772,anf_arg15412827):R.ffi.throwNonFunApp(L[1476],link3774,[new_DASH_i13112772,anf_arg15412827]);
};
try {
if(--R.GAS > 0) {
$z1281912820 = $f1282512826();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1282512826,
"from":L[1476]});
}
} catch($e1281712818) {
if(R.isCont($e1281712818)) {
var $ss1282112822 = {"from":L[1476],
"go":function(anf_extend15512828) {
return $Hanf_extend230212829(anf_extend15512828,acc12012695,new_DASH_lets13212815,_plus9);
}};
$e1281712818.stack[R.EXN_STACKHEIGHT++] = $ss1282112822;
}
if(R.isPyretException($e1281712818)) {
$e1281712818.pyretStack.push(L[1476]);
}
throw $e1281712818;
}
var $ret1282312824 = $Hanf_extend230212829($z1281912820,acc12012695,new_DASH_lets13212815,_plus9);
++R.GAS;
return $ret1282312824;
};
var $Hanf_extend230212829 = function(anf_extend15512828,acc12012695,new_DASH_lets13212815,_plus9) {
var anf_arg15612840 = G(acc12012695,"lets",L[1479]);
var $z1283212833 = D;
var $f1283812839 = function(_) {
return R.isFunction(_plus9)?_plus9.app(new_DASH_lets13212815,anf_arg15612840):R.ffi.throwNonFunApp(L[1478],_plus9,[new_DASH_lets13212815,anf_arg15612840]);
};
try {
if(--R.GAS > 0) {
$z1283212833 = $f1283812839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1283812839,
"from":L[1478]});
}
} catch($e1283012831) {
if(R.isCont($e1283012831)) {
var $ss1283412835 = {"from":L[1478],
"go":function(anf_extend15712841) {
return $Hanf_extend230112842(anf_extend15712841,acc12012695,anf_extend15512828);
}};
$e1283012831.stack[R.EXN_STACKHEIGHT++] = $ss1283412835;
}
if(R.isPyretException($e1283012831)) {
$e1283012831.pyretStack.push(L[1478]);
}
throw $e1283012831;
}
var $ret1283612837 = $Hanf_extend230112842($z1283212833,acc12012695,anf_extend15512828);
++R.GAS;
return $ret1283612837;
};
var $Hanf_extend230112842 = function(anf_extend15712841,acc12012695,anf_extend15512828) {
var ann_DASH_check_DASH_temp12912843 = acc12012695.extendWith({"imports":anf_extend15512828,
"lets":anf_extend15712841});
return ann_DASH_check_DASH_temp12912843;
};
var $Hanf_arg230012804 = function(anf_arg14412801,A119,anf_arg14112802,anf_fun14012803,f13312788,imp_DASH_name13012747,l12612698) {
var anf_fun14512856 = G(A119,"s-dot",L[1482]);
var anf_fun14612854 = G(A119,"s-id",L[1481]);
var $z1284612847 = D;
var $f1285212853 = function(_) {
return R.isFunction(anf_fun14612854)?anf_fun14612854.app(l12612698,imp_DASH_name13012747):R.ffi.throwNonFunApp(L[1480],anf_fun14612854,[l12612698,imp_DASH_name13012747]);
};
try {
if(--R.GAS > 0) {
$z1284612847 = $f1285212853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1285212853,
"from":L[1480]});
}
} catch($e1284412845) {
if(R.isCont($e1284412845)) {
var $ss1284812849 = {"from":L[1480],
"go":function(anf_arg14712855) {
return $Hanf_arg229912857(anf_arg14712855,anf_arg14112802,anf_arg14412801,anf_fun14012803,anf_fun14512856,f13312788,l12612698);
}};
$e1284412845.stack[R.EXN_STACKHEIGHT++] = $ss1284812849;
}
if(R.isPyretException($e1284412845)) {
$e1284412845.pyretStack.push(L[1480]);
}
throw $e1284412845;
}
var $ret1285012851 = $Hanf_arg229912857($z1284612847,anf_arg14112802,anf_arg14412801,anf_fun14012803,anf_fun14512856,f13312788,l12612698);
++R.GAS;
return $ret1285012851;
};
var $Hanf_arg229912857 = function(anf_arg14712855,anf_arg14112802,anf_arg14412801,anf_fun14012803,anf_fun14512856,f13312788,l12612698) {
var anf_fun14812868 = G(f13312788,"tostring",L[1484]);
var $z1286012861 = D;
var $f1286612867 = function(_) {
return R.isFunction(anf_fun14812868)?anf_fun14812868.app():R.ffi.throwNonFunApp(L[1483],anf_fun14812868,[]);
};
try {
if(--R.GAS > 0) {
$z1286012861 = $f1286612867();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1286612867,
"from":L[1483]});
}
} catch($e1285812859) {
if(R.isCont($e1285812859)) {
var $ss1286212863 = {"from":L[1483],
"go":function(anf_arg14912869) {
return $Hanf_arg229812870(anf_arg14912869,anf_arg14112802,anf_arg14412801,anf_arg14712855,anf_fun14012803,anf_fun14512856,l12612698);
}};
$e1285812859.stack[R.EXN_STACKHEIGHT++] = $ss1286212863;
}
if(R.isPyretException($e1285812859)) {
$e1285812859.pyretStack.push(L[1483]);
}
throw $e1285812859;
}
var $ret1286412865 = $Hanf_arg229812870($z1286012861,anf_arg14112802,anf_arg14412801,anf_arg14712855,anf_fun14012803,anf_fun14512856,l12612698);
++R.GAS;
return $ret1286412865;
};
var $Hanf_arg229812870 = function(anf_arg14912869,anf_arg14112802,anf_arg14412801,anf_arg14712855,anf_fun14012803,anf_fun14512856,l12612698) {
var $z1287312874 = D;
var $f1287912880 = function(_) {
return R.isFunction(anf_fun14512856)?anf_fun14512856.app(l12612698,anf_arg14712855,anf_arg14912869):R.ffi.throwNonFunApp(L[1485],anf_fun14512856,[l12612698,anf_arg14712855,anf_arg14912869]);
};
try {
if(--R.GAS > 0) {
$z1287312874 = $f1287912880();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1287912880,
"from":L[1485]});
}
} catch($e1287112872) {
if(R.isCont($e1287112872)) {
var $ss1287512876 = {"from":L[1485],
"go":function(anf_arg15012881) {
return $Hanf_arg229712882(anf_arg15012881,anf_arg14112802,anf_arg14412801,anf_fun14012803);
}};
$e1287112872.stack[R.EXN_STACKHEIGHT++] = $ss1287512876;
}
if(R.isPyretException($e1287112872)) {
$e1287112872.pyretStack.push(L[1485]);
}
throw $e1287112872;
}
var $ret1287712878 = $Hanf_arg229712882($z1287312874,anf_arg14112802,anf_arg14412801,anf_fun14012803);
++R.GAS;
return $ret1287712878;
};
var $Hanf_arg229712882 = function(anf_arg15012881,anf_arg14112802,anf_arg14412801,anf_fun14012803) {
var $z1288512886 = D;
var $f1289112892 = function(_) {
return R.isFunction(anf_fun14012803)?anf_fun14012803.app(anf_arg14112802,anf_arg14412801,anf_arg15012881,(false)):R.ffi.throwNonFunApp(L[1469],anf_fun14012803,[anf_arg14112802,anf_arg14412801,anf_arg15012881,(false)]);
};
try {
if(--R.GAS > 0) {
$z1288512886 = $f1289112892();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1289112892,
"from":L[1469]});
}
} catch($e1288312884) {
if(R.isCont($e1288312884)) {
var $ss1288712888 = {"from":L[1469],
"go":function(ann_DASH_check_DASH_temp13912893) {
return $Hann_DASH_check_DASH_temp229612894(ann_DASH_check_DASH_temp13912893);
}};
$e1288312884.stack[R.EXN_STACKHEIGHT++] = $ss1288712888;
}
if(R.isPyretException($e1288312884)) {
$e1288312884.pyretStack.push(L[1469]);
}
throw $e1288312884;
}
var $ret1288912890 = $Hann_DASH_check_DASH_temp229612894($z1288512886);
++R.GAS;
return $ret1288912890;
};
var $Hann_DASH_check_DASH_temp229612894 = function(ann_DASH_check_DASH_temp13912893) {
return ann_DASH_check_DASH_temp13912893;
};
var $Hanf_arg229512895 = function(anf_arg12512896,acc12012695,anf_fun12412897,l12212898,link3774,name12412899) {
var $z1290212903 = D;
var $f1290812909 = function(_) {
return R.isFunction(anf_fun12412897)?anf_fun12412897.app(l12212898,anf_arg12512896,name12412899):R.ffi.throwNonFunApp(L[1486],anf_fun12412897,[l12212898,anf_arg12512896,name12412899]);
};
try {
if(--R.GAS > 0) {
$z1290212903 = $f1290812909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1290812909,
"from":L[1486]});
}
} catch($e1290012901) {
if(R.isCont($e1290012901)) {
var $ss1290412905 = {"from":L[1486],
"go":function(new_DASH_i12512910) {
return $Hnew_DASH_i229412911(new_DASH_i12512910,acc12012695,link3774);
}};
$e1290012901.stack[R.EXN_STACKHEIGHT++] = $ss1290412905;
}
if(R.isPyretException($e1290012901)) {
$e1290012901.pyretStack.push(L[1486]);
}
throw $e1290012901;
}
var $ret1290612907 = $Hnew_DASH_i229412911($z1290212903,acc12012695,link3774);
++R.GAS;
return $ret1290612907;
};
var $Hnew_DASH_i229412911 = function(new_DASH_i12512910,acc12012695,link3774) {
var anf_arg12612922 = G(acc12012695,"imports",L[1488]);
var $z1291412915 = D;
var $f1292012921 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_i12512910,anf_arg12612922):R.ffi.throwNonFunApp(L[1487],link3774,[new_DASH_i12512910,anf_arg12612922]);
};
try {
if(--R.GAS > 0) {
$z1291412915 = $f1292012921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1292012921,
"from":L[1487]});
}
} catch($e1291212913) {
if(R.isCont($e1291212913)) {
var $ss1291612917 = {"from":L[1487],
"go":function(anf_extend12712923) {
return $Hanf_extend229312924(anf_extend12712923,acc12012695);
}};
$e1291212913.stack[R.EXN_STACKHEIGHT++] = $ss1291612917;
}
if(R.isPyretException($e1291212913)) {
$e1291212913.pyretStack.push(L[1487]);
}
throw $e1291212913;
}
var $ret1291812919 = $Hanf_extend229312924($z1291412915,acc12012695);
++R.GAS;
return $ret1291812919;
};
var $Hanf_extend229312924 = function(anf_extend12712923,acc12012695) {
var ann_DASH_check_DASH_temp12312925 = acc12012695.extendWith({"imports":anf_extend12712923});
return ann_DASH_check_DASH_temp12312925;
};
var $Hann_DASH_check_DASH_temp229212926 = function(ann_DASH_check_DASH_temp10112927) {
return ann_DASH_check_DASH_temp10112927;
};
var $Hif_DASH_229112928 = function(if_DASH_1012929,A119,file11612930,imp11412931,l11512932,_plus9) {
var if_helper10412943 = R.makeFunction(function(if_helper_arg10512963) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1492],1,arguments);
}
var ann_DASH_check_DASH_temp10312964 = if_helper_arg10512963;
return ann_DASH_check_DASH_temp10312964;
});
var anf_if10812962 = R.isBoolean(if_DASH_1012929);
if(R.isPyretTrue(anf_if10812962)) {
if(R.isPyretTrue(if_DASH_1012929)) {
var $z1293512936 = D;
var $f1294112942 = function(_) {
return R.isFunction(if_helper10412943)?if_helper10412943.app(imp11412931):R.ffi.throwNonFunApp(L[1489],if_helper10412943,[imp11412931]);
};
try {
if(--R.GAS > 0) {
$z1293512936 = $f1294112942();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1294112942,
"from":L[1489]});
}
} catch($e1293312934) {
if(R.isCont($e1293312934)) {
var $ss1293712938 = {"from":L[1489],
"go":function(cont_tail_app11312944) {
return $Hcont_tail_app228812945(cont_tail_app11312944);
}};
$e1293312934.stack[R.EXN_STACKHEIGHT++] = $ss1293712938;
}
if(R.isPyretException($e1293312934)) {
$e1293312934.pyretStack.push(L[1489]);
}
throw $e1293312934;
}
var $ret1293912940 = $Hcont_tail_app228812945($z1293512936);
++R.GAS;
return $ret1293912940;
} else {
var anf_fun10912957 = G(A119,"s-file-import",L[1491]);
var $z1294812949 = D;
var $f1295412955 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("./"),file11612930):R.ffi.throwNonFunApp(L[1490],_plus9,[("./"),file11612930]);
};
try {
if(--R.GAS > 0) {
$z1294812949 = $f1295412955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1295412955,
"from":L[1490]});
}
} catch($e1294612947) {
if(R.isCont($e1294612947)) {
var $ss1295012951 = {"from":L[1490],
"go":function(anf_arg11012956) {
return $Hanf_arg229012958(anf_arg11012956,anf_fun10912957,if_helper10412943,l11512932);
}};
$e1294612947.stack[R.EXN_STACKHEIGHT++] = $ss1295012951;
}
if(R.isPyretException($e1294612947)) {
$e1294612947.pyretStack.push(L[1490]);
}
throw $e1294612947;
}
var $ret1295212953 = $Hanf_arg229012958($z1294812949,anf_fun10912957,if_helper10412943,l11512932);
++R.GAS;
return $ret1295212953;
}
} else {
var cont_tail_arg10612961 = R.throwNonBooleanCondition(L[1492],("if"),if_DASH_1012929);
if(--R.GAS > 0) {
$z1295912960 = R.isFunction(if_helper10412943)?if_helper10412943.app(cont_tail_arg10612961):R.ffi.throwNonFunApp(L[1492],if_helper10412943,[cont_tail_arg10612961]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper10412943)?if_helper10412943.app(cont_tail_arg10612961):R.ffi.throwNonFunApp(L[1492],if_helper10412943,[cont_tail_arg10612961]);
},
"from":L[1492]});
}
++R.GAS;
return $z1295912960;
}
};
var $Hcont_tail_app228812945 = function(cont_tail_app11312944) {
return cont_tail_app11312944;
};
var $Hanf_arg229012958 = function(anf_arg11012956,anf_fun10912957,if_helper10412943,l11512932) {
var $z1296712968 = D;
var $f1297312974 = function(_) {
return R.isFunction(anf_fun10912957)?anf_fun10912957.app(l11512932,anf_arg11012956):R.ffi.throwNonFunApp(L[1493],anf_fun10912957,[l11512932,anf_arg11012956]);
};
try {
if(--R.GAS > 0) {
$z1296712968 = $f1297312974();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1297312974,
"from":L[1493]});
}
} catch($e1296512966) {
if(R.isCont($e1296512966)) {
var $ss1296912970 = {"from":L[1493],
"go":function(cont_tail_arg11112975) {
return $Hcont_tail_arg228912976(cont_tail_arg11112975,if_helper10412943);
}};
$e1296512966.stack[R.EXN_STACKHEIGHT++] = $ss1296912970;
}
if(R.isPyretException($e1296512966)) {
$e1296512966.pyretStack.push(L[1493]);
}
throw $e1296512966;
}
var $ret1297112972 = $Hcont_tail_arg228912976($z1296712968,if_helper10412943);
++R.GAS;
return $ret1297112972;
};
var $Hcont_tail_arg228912976 = function(cont_tail_arg11112975,if_helper10412943) {
if(--R.GAS > 0) {
$z1297712978 = R.isFunction(if_helper10412943)?if_helper10412943.app(cont_tail_arg11112975):R.ffi.throwNonFunApp(L[1493],if_helper10412943,[cont_tail_arg11112975]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper10412943)?if_helper10412943.app(cont_tail_arg11112975):R.ffi.throwNonFunApp(L[1493],if_helper10412943,[cont_tail_arg11112975]);
},
"from":L[1493]});
}
++R.GAS;
return $z1297712978;
};
var $Hann_DASH_check_DASH_temp228712979 = function(ann_DASH_check_DASH_temp6412980) {
return ann_DASH_check_DASH_temp6412980;
};
var $Hids228612981 = function(ids10912982,A119,l10812983,map459174) {
var anf_arg9312994 = R.makeFunction(function(id11112997) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1495],1,arguments);
}
var anf_arg6913036 = G(id11112997,"bind-type",L[1505]);
var if_DASH_813029 = R.equiv(anf_arg6913036,("data"));
var if_helper7013011 = R.makeFunction(function(if_helper_arg7113034) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1504],1,arguments);
}
var ann_DASH_check_DASH_temp6813035 = if_helper_arg7113034;
return ann_DASH_check_DASH_temp6813035;
});
var anf_if7413033 = R.isBoolean(if_DASH_813029);
if(R.isPyretTrue(anf_if7413033)) {
if(R.isPyretTrue(if_DASH_813029)) {
var anf_fun8413010 = G(A119,"a-field",L[1499]);
var anf_bracket8513013 = G(id11112997,"name",L[1498]);
var anf_fun8613008 = G(anf_bracket8513013,"toname",L[1497]);
var $z1300013001 = D;
var $f1300613007 = function(_) {
return R.isFunction(anf_fun8613008)?anf_fun8613008.app():R.ffi.throwNonFunApp(L[1496],anf_fun8613008,[]);
};
try {
if(--R.GAS > 0) {
$z1300013001 = $f1300613007();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1300613007,
"from":L[1496]});
}
} catch($e1299812999) {
if(R.isCont($e1299812999)) {
var $ss1300213003 = {"from":L[1496],
"go":function(anf_arg8713009) {
return $Hanf_arg228013012(anf_arg8713009,A119,anf_fun8413010,id11112997,if_helper7013011,l10812983);
}};
$e1299812999.stack[R.EXN_STACKHEIGHT++] = $ss1300213003;
}
if(R.isPyretException($e1299812999)) {
$e1299812999.pyretStack.push(L[1496]);
}
throw $e1299812999;
}
var $ret1300413005 = $Hanf_arg228013012($z1300013001,A119,anf_fun8413010,id11112997,if_helper7013011,l10812983);
++R.GAS;
return $ret1300413005;
} else {
var anf_fun7513026 = G(A119,"a-field",L[1503]);
var anf_bracket7613028 = G(id11112997,"name",L[1502]);
var anf_fun7713024 = G(anf_bracket7613028,"toname",L[1501]);
var $z1301613017 = D;
var $f1302213023 = function(_) {
return R.isFunction(anf_fun7713024)?anf_fun7713024.app():R.ffi.throwNonFunApp(L[1500],anf_fun7713024,[]);
};
try {
if(--R.GAS > 0) {
$z1301613017 = $f1302213023();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1302213023,
"from":L[1500]});
}
} catch($e1301413015) {
if(R.isCont($e1301413015)) {
var $ss1301813019 = {"from":L[1500],
"go":function(anf_arg7813025) {
return $Hanf_arg228313027(anf_arg7813025,A119,anf_fun7513026,id11112997,if_helper7013011,l10812983);
}};
$e1301413015.stack[R.EXN_STACKHEIGHT++] = $ss1301813019;
}
if(R.isPyretException($e1301413015)) {
$e1301413015.pyretStack.push(L[1500]);
}
throw $e1301413015;
}
var $ret1302013021 = $Hanf_arg228313027($z1301613017,A119,anf_fun7513026,id11112997,if_helper7013011,l10812983);
++R.GAS;
return $ret1302013021;
}
} else {
var cont_tail_arg7213032 = R.throwNonBooleanCondition(L[1504],("if"),if_DASH_813029);
if(--R.GAS > 0) {
$z1303013031 = R.isFunction(if_helper7013011)?if_helper7013011.app(cont_tail_arg7213032):R.ffi.throwNonFunApp(L[1504],if_helper7013011,[cont_tail_arg7213032]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper7013011)?if_helper7013011.app(cont_tail_arg7213032):R.ffi.throwNonFunApp(L[1504],if_helper7013011,[cont_tail_arg7213032]);
},
"from":L[1504]});
}
++R.GAS;
return $z1303013031;
}
});
var $z1298612987 = D;
var $f1299212993 = function(_) {
return R.isFunction(map459174)?map459174.app(anf_arg9312994,ids10912982):R.ffi.throwNonFunApp(L[1494],map459174,[anf_arg9312994,ids10912982]);
};
try {
if(--R.GAS > 0) {
$z1298612987 = $f1299212993();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1299212993,
"from":L[1494]});
}
} catch($e1298412985) {
if(R.isCont($e1298412985)) {
var $ss1298812989 = {"from":L[1494],
"go":function(type_DASH_fields11012995) {
return $Htype_DASH_fields228512996(type_DASH_fields11012995,A119,l10812983);
}};
$e1298412985.stack[R.EXN_STACKHEIGHT++] = $ss1298812989;
}
if(R.isPyretException($e1298412985)) {
$e1298412985.pyretStack.push(L[1494]);
}
throw $e1298412985;
}
var $ret1299012991 = $Htype_DASH_fields228512996($z1298612987,A119,l10812983);
++R.GAS;
return $ret1299012991;
};
var $Htype_DASH_fields228512996 = function(type_DASH_fields11012995,A119,l10812983) {
var anf_fun9413047 = G(A119,"s-provide-types",L[1507]);
var $z1303913040 = D;
var $f1304513046 = function(_) {
return R.isFunction(anf_fun9413047)?anf_fun9413047.app(l10812983,type_DASH_fields11012995):R.ffi.throwNonFunApp(L[1506],anf_fun9413047,[l10812983,type_DASH_fields11012995]);
};
try {
if(--R.GAS > 0) {
$z1303913040 = $f1304513046();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1304513046,
"from":L[1506]});
}
} catch($e1303713038) {
if(R.isCont($e1303713038)) {
var $ss1304113042 = {"from":L[1506],
"go":function(ann_DASH_check_DASH_temp6613048) {
return $Hann_DASH_check_DASH_temp228413049(ann_DASH_check_DASH_temp6613048);
}};
$e1303713038.stack[R.EXN_STACKHEIGHT++] = $ss1304113042;
}
if(R.isPyretException($e1303713038)) {
$e1303713038.pyretStack.push(L[1506]);
}
throw $e1303713038;
}
var $ret1304313044 = $Hann_DASH_check_DASH_temp228413049($z1303913040);
++R.GAS;
return $ret1304313044;
};
var $Hann_DASH_check_DASH_temp228413049 = function(ann_DASH_check_DASH_temp6613048) {
return ann_DASH_check_DASH_temp6613048;
};
var $Hanf_arg228013012 = function(anf_arg8713009,A119,anf_fun8413010,id11112997,if_helper7013011,l10812983) {
var anf_fun8813060 = G(A119,"a-name",L[1510]);
var anf_arg8913061 = G(id11112997,"name",L[1509]);
var $z1305213053 = D;
var $f1305813059 = function(_) {
return R.isFunction(anf_fun8813060)?anf_fun8813060.app(l10812983,anf_arg8913061):R.ffi.throwNonFunApp(L[1508],anf_fun8813060,[l10812983,anf_arg8913061]);
};
try {
if(--R.GAS > 0) {
$z1305213053 = $f1305813059();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1305813059,
"from":L[1508]});
}
} catch($e1305013051) {
if(R.isCont($e1305013051)) {
var $ss1305413055 = {"from":L[1508],
"go":function(anf_arg9013062) {
return $Hanf_arg227913063(anf_arg9013062,anf_arg8713009,anf_fun8413010,if_helper7013011,l10812983);
}};
$e1305013051.stack[R.EXN_STACKHEIGHT++] = $ss1305413055;
}
if(R.isPyretException($e1305013051)) {
$e1305013051.pyretStack.push(L[1508]);
}
throw $e1305013051;
}
var $ret1305613057 = $Hanf_arg227913063($z1305213053,anf_arg8713009,anf_fun8413010,if_helper7013011,l10812983);
++R.GAS;
return $ret1305613057;
};
var $Hanf_arg227913063 = function(anf_arg9013062,anf_arg8713009,anf_fun8413010,if_helper7013011,l10812983) {
var $z1306613067 = D;
var $f1307213073 = function(_) {
return R.isFunction(anf_fun8413010)?anf_fun8413010.app(l10812983,anf_arg8713009,anf_arg9013062):R.ffi.throwNonFunApp(L[1511],anf_fun8413010,[l10812983,anf_arg8713009,anf_arg9013062]);
};
try {
if(--R.GAS > 0) {
$z1306613067 = $f1307213073();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1307213073,
"from":L[1511]});
}
} catch($e1306413065) {
if(R.isCont($e1306413065)) {
var $ss1306813069 = {"from":L[1511],
"go":function(cont_tail_arg9113074) {
return $Hcont_tail_arg227813075(cont_tail_arg9113074,if_helper7013011);
}};
$e1306413065.stack[R.EXN_STACKHEIGHT++] = $ss1306813069;
}
if(R.isPyretException($e1306413065)) {
$e1306413065.pyretStack.push(L[1511]);
}
throw $e1306413065;
}
var $ret1307013071 = $Hcont_tail_arg227813075($z1306613067,if_helper7013011);
++R.GAS;
return $ret1307013071;
};
var $Hcont_tail_arg227813075 = function(cont_tail_arg9113074,if_helper7013011) {
if(--R.GAS > 0) {
$z1307613077 = R.isFunction(if_helper7013011)?if_helper7013011.app(cont_tail_arg9113074):R.ffi.throwNonFunApp(L[1511],if_helper7013011,[cont_tail_arg9113074]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper7013011)?if_helper7013011.app(cont_tail_arg9113074):R.ffi.throwNonFunApp(L[1511],if_helper7013011,[cont_tail_arg9113074]);
},
"from":L[1511]});
}
++R.GAS;
return $z1307613077;
};
var $Hanf_arg228313027 = function(anf_arg7813025,A119,anf_fun7513026,id11112997,if_helper7013011,l10812983) {
var anf_fun7913088 = G(A119,"a-name",L[1514]);
var anf_arg8013089 = G(id11112997,"name",L[1513]);
var $z1308013081 = D;
var $f1308613087 = function(_) {
return R.isFunction(anf_fun7913088)?anf_fun7913088.app(l10812983,anf_arg8013089):R.ffi.throwNonFunApp(L[1512],anf_fun7913088,[l10812983,anf_arg8013089]);
};
try {
if(--R.GAS > 0) {
$z1308013081 = $f1308613087();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1308613087,
"from":L[1512]});
}
} catch($e1307813079) {
if(R.isCont($e1307813079)) {
var $ss1308213083 = {"from":L[1512],
"go":function(anf_arg8113090) {
return $Hanf_arg228213091(anf_arg8113090,anf_arg7813025,anf_fun7513026,if_helper7013011,l10812983);
}};
$e1307813079.stack[R.EXN_STACKHEIGHT++] = $ss1308213083;
}
if(R.isPyretException($e1307813079)) {
$e1307813079.pyretStack.push(L[1512]);
}
throw $e1307813079;
}
var $ret1308413085 = $Hanf_arg228213091($z1308013081,anf_arg7813025,anf_fun7513026,if_helper7013011,l10812983);
++R.GAS;
return $ret1308413085;
};
var $Hanf_arg228213091 = function(anf_arg8113090,anf_arg7813025,anf_fun7513026,if_helper7013011,l10812983) {
var $z1309413095 = D;
var $f1310013101 = function(_) {
return R.isFunction(anf_fun7513026)?anf_fun7513026.app(l10812983,anf_arg7813025,anf_arg8113090):R.ffi.throwNonFunApp(L[1515],anf_fun7513026,[l10812983,anf_arg7813025,anf_arg8113090]);
};
try {
if(--R.GAS > 0) {
$z1309413095 = $f1310013101();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1310013101,
"from":L[1515]});
}
} catch($e1309213093) {
if(R.isCont($e1309213093)) {
var $ss1309613097 = {"from":L[1515],
"go":function(cont_tail_arg8213102) {
return $Hcont_tail_arg228113103(cont_tail_arg8213102,if_helper7013011);
}};
$e1309213093.stack[R.EXN_STACKHEIGHT++] = $ss1309613097;
}
if(R.isPyretException($e1309213093)) {
$e1309213093.pyretStack.push(L[1515]);
}
throw $e1309213093;
}
var $ret1309813099 = $Hcont_tail_arg228113103($z1309413095,if_helper7013011);
++R.GAS;
return $ret1309813099;
};
var $Hcont_tail_arg228113103 = function(cont_tail_arg8213102,if_helper7013011) {
if(--R.GAS > 0) {
$z1310413105 = R.isFunction(if_helper7013011)?if_helper7013011.app(cont_tail_arg8213102):R.ffi.throwNonFunApp(L[1515],if_helper7013011,[cont_tail_arg8213102]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper7013011)?if_helper7013011.app(cont_tail_arg8213102):R.ffi.throwNonFunApp(L[1515],if_helper7013011,[cont_tail_arg8213102]);
},
"from":L[1515]});
}
++R.GAS;
return $z1310413105;
};
var $Hann_DASH_check_DASH_temp227713106 = function(ann_DASH_check_DASH_temp4413107) {
return ann_DASH_check_DASH_temp4413107;
};
var $Hids227613108 = function(ids10313109,A119,l10213110,map459174,tostring17) {
var anf_fun4813123 = G(A119,"s-obj",L[1520]);
var anf_arg5613121 = R.makeFunction(function(id10513125) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1516],1,arguments);
}
var anf_fun5013137 = G(A119,"s-data-field",L[1519]);
var anf_fun5113138 = G(A119,"s-str",L[1518]);
var $z1312813129 = D;
var $f1313413135 = function(_) {
return R.isFunction(tostring17)?tostring17.app(id10513125):R.ffi.throwNonFunApp(L[1517],tostring17,[id10513125]);
};
try {
if(--R.GAS > 0) {
$z1312813129 = $f1313413135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1313413135,
"from":L[1517]});
}
} catch($e1312613127) {
if(R.isCont($e1312613127)) {
var $ss1313013131 = {"from":L[1517],
"go":function(anf_arg5213136) {
return $Hanf_arg227213139(anf_arg5213136,A119,anf_fun5013137,anf_fun5113138,id10513125,l10213110);
}};
$e1312613127.stack[R.EXN_STACKHEIGHT++] = $ss1313013131;
}
if(R.isPyretException($e1312613127)) {
$e1312613127.pyretStack.push(L[1517]);
}
throw $e1312613127;
}
var $ret1313213133 = $Hanf_arg227213139($z1312813129,A119,anf_fun5013137,anf_fun5113138,id10513125,l10213110);
++R.GAS;
return $ret1313213133;
});
var $z1311313114 = D;
var $f1311913120 = function(_) {
return R.isFunction(map459174)?map459174.app(anf_arg5613121,ids10313109):R.ffi.throwNonFunApp(L[1516],map459174,[anf_arg5613121,ids10313109]);
};
try {
if(--R.GAS > 0) {
$z1311313114 = $f1311913120();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1311913120,
"from":L[1516]});
}
} catch($e1311113112) {
if(R.isCont($e1311113112)) {
var $ss1311513116 = {"from":L[1516],
"go":function(anf_arg5713122) {
return $Hanf_arg227513124(anf_arg5713122,A119,anf_fun4813123,l10213110);
}};
$e1311113112.stack[R.EXN_STACKHEIGHT++] = $ss1311513116;
}
if(R.isPyretException($e1311113112)) {
$e1311113112.pyretStack.push(L[1516]);
}
throw $e1311113112;
}
var $ret1311713118 = $Hanf_arg227513124($z1311313114,A119,anf_fun4813123,l10213110);
++R.GAS;
return $ret1311713118;
};
var $Hanf_arg227513124 = function(anf_arg5713122,A119,anf_fun4813123,l10213110) {
var $z1314213143 = D;
var $f1314813149 = function(_) {
return R.isFunction(anf_fun4813123)?anf_fun4813123.app(l10213110,anf_arg5713122):R.ffi.throwNonFunApp(L[1521],anf_fun4813123,[l10213110,anf_arg5713122]);
};
try {
if(--R.GAS > 0) {
$z1314213143 = $f1314813149();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1314813149,
"from":L[1521]});
}
} catch($e1314013141) {
if(R.isCont($e1314013141)) {
var $ss1314413145 = {"from":L[1521],
"go":function(obj10413150) {
return $Hobj227413151(obj10413150,A119,l10213110);
}};
$e1314013141.stack[R.EXN_STACKHEIGHT++] = $ss1314413145;
}
if(R.isPyretException($e1314013141)) {
$e1314013141.pyretStack.push(L[1521]);
}
throw $e1314013141;
}
var $ret1314613147 = $Hobj227413151($z1314213143,A119,l10213110);
++R.GAS;
return $ret1314613147;
};
var $Hobj227413151 = function(obj10413150,A119,l10213110) {
var anf_fun5813162 = G(A119,"s-provide",L[1523]);
var $z1315413155 = D;
var $f1316013161 = function(_) {
return R.isFunction(anf_fun5813162)?anf_fun5813162.app(l10213110,obj10413150):R.ffi.throwNonFunApp(L[1522],anf_fun5813162,[l10213110,obj10413150]);
};
try {
if(--R.GAS > 0) {
$z1315413155 = $f1316013161();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1316013161,
"from":L[1522]});
}
} catch($e1315213153) {
if(R.isCont($e1315213153)) {
var $ss1315613157 = {"from":L[1522],
"go":function(ann_DASH_check_DASH_temp4613163) {
return $Hann_DASH_check_DASH_temp227313164(ann_DASH_check_DASH_temp4613163);
}};
$e1315213153.stack[R.EXN_STACKHEIGHT++] = $ss1315613157;
}
if(R.isPyretException($e1315213153)) {
$e1315213153.pyretStack.push(L[1522]);
}
throw $e1315213153;
}
var $ret1315813159 = $Hann_DASH_check_DASH_temp227313164($z1315413155);
++R.GAS;
return $ret1315813159;
};
var $Hann_DASH_check_DASH_temp227313164 = function(ann_DASH_check_DASH_temp4613163) {
return ann_DASH_check_DASH_temp4613163;
};
var $Hanf_arg227213139 = function(anf_arg5213136,A119,anf_fun5013137,anf_fun5113138,id10513125,l10213110) {
var $z1316713168 = D;
var $f1317313174 = function(_) {
return R.isFunction(anf_fun5113138)?anf_fun5113138.app(l10213110,anf_arg5213136):R.ffi.throwNonFunApp(L[1524],anf_fun5113138,[l10213110,anf_arg5213136]);
};
try {
if(--R.GAS > 0) {
$z1316713168 = $f1317313174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1317313174,
"from":L[1524]});
}
} catch($e1316513166) {
if(R.isCont($e1316513166)) {
var $ss1316913170 = {"from":L[1524],
"go":function(anf_arg5313175) {
return $Hanf_arg227113176(anf_arg5313175,A119,anf_fun5013137,id10513125,l10213110);
}};
$e1316513166.stack[R.EXN_STACKHEIGHT++] = $ss1316913170;
}
if(R.isPyretException($e1316513166)) {
$e1316513166.pyretStack.push(L[1524]);
}
throw $e1316513166;
}
var $ret1317113172 = $Hanf_arg227113176($z1316713168,A119,anf_fun5013137,id10513125,l10213110);
++R.GAS;
return $ret1317113172;
};
var $Hanf_arg227113176 = function(anf_arg5313175,A119,anf_fun5013137,id10513125,l10213110) {
var anf_fun5413187 = G(A119,"s-id",L[1526]);
var $z1317913180 = D;
var $f1318513186 = function(_) {
return R.isFunction(anf_fun5413187)?anf_fun5413187.app(l10213110,id10513125):R.ffi.throwNonFunApp(L[1525],anf_fun5413187,[l10213110,id10513125]);
};
try {
if(--R.GAS > 0) {
$z1317913180 = $f1318513186();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1318513186,
"from":L[1525]});
}
} catch($e1317713178) {
if(R.isCont($e1317713178)) {
var $ss1318113182 = {"from":L[1525],
"go":function(anf_arg5513188) {
return $Hanf_arg227013189(anf_arg5513188,anf_arg5313175,anf_fun5013137,l10213110);
}};
$e1317713178.stack[R.EXN_STACKHEIGHT++] = $ss1318113182;
}
if(R.isPyretException($e1317713178)) {
$e1317713178.pyretStack.push(L[1525]);
}
throw $e1317713178;
}
var $ret1318313184 = $Hanf_arg227013189($z1317913180,anf_arg5313175,anf_fun5013137,l10213110);
++R.GAS;
return $ret1318313184;
};
var $Hanf_arg227013189 = function(anf_arg5513188,anf_arg5313175,anf_fun5013137,l10213110) {
var $z1319213193 = D;
var $f1319813199 = function(_) {
return R.isFunction(anf_fun5013137)?anf_fun5013137.app(l10213110,anf_arg5313175,anf_arg5513188):R.ffi.throwNonFunApp(L[1516],anf_fun5013137,[l10213110,anf_arg5313175,anf_arg5513188]);
};
try {
if(--R.GAS > 0) {
$z1319213193 = $f1319813199();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1319813199,
"from":L[1516]});
}
} catch($e1319013191) {
if(R.isCont($e1319013191)) {
var $ss1319413195 = {"from":L[1516],
"go":function(ann_DASH_check_DASH_temp4913200) {
return $Hann_DASH_check_DASH_temp226913201(ann_DASH_check_DASH_temp4913200);
}};
$e1319013191.stack[R.EXN_STACKHEIGHT++] = $ss1319413195;
}
if(R.isPyretException($e1319013191)) {
$e1319013191.pyretStack.push(L[1516]);
}
throw $e1319013191;
}
var $ret1319613197 = $Hann_DASH_check_DASH_temp226913201($z1319213193);
++R.GAS;
return $ret1319613197;
};
var $Hann_DASH_check_DASH_temp226913201 = function(ann_DASH_check_DASH_temp4913200) {
return ann_DASH_check_DASH_temp4913200;
};
var $Ht226813202 = function(t9913203,A119,loc9713204,mk_DASH_bind8577) {
var $z1320713208 = D;
var $f1321313214 = function(_) {
return R.isFunction(mk_DASH_bind8577.$var)?mk_DASH_bind8577.$var.app(loc9713204,t9913203):R.ffi.throwNonFunApp(L[1527],mk_DASH_bind8577.$var,[loc9713204,t9913203]);
};
try {
if(--R.GAS > 0) {
$z1320713208 = $f1321313214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1321313214,
"from":L[1527]});
}
} catch($e1320513206) {
if(R.isCont($e1320513206)) {
var $ss1320913210 = {"from":L[1527],
"go":function(anf_obj4013215) {
return $Hanf_obj226713216(anf_obj4013215,A119,loc9713204,t9913203);
}};
$e1320513206.stack[R.EXN_STACKHEIGHT++] = $ss1320913210;
}
if(R.isPyretException($e1320513206)) {
$e1320513206.pyretStack.push(L[1527]);
}
throw $e1320513206;
}
var $ret1321113212 = $Hanf_obj226713216($z1320713208,A119,loc9713204,t9913203);
++R.GAS;
return $ret1321113212;
};
var $Hanf_obj226713216 = function(anf_obj4013215,A119,loc9713204,t9913203) {
var anf_fun4113227 = G(A119,"s-id",L[1529]);
var $z1321913220 = D;
var $f1322513226 = function(_) {
return R.isFunction(anf_fun4113227)?anf_fun4113227.app(loc9713204,t9913203):R.ffi.throwNonFunApp(L[1528],anf_fun4113227,[loc9713204,t9913203]);
};
try {
if(--R.GAS > 0) {
$z1321913220 = $f1322513226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1322513226,
"from":L[1528]});
}
} catch($e1321713218) {
if(R.isCont($e1321713218)) {
var $ss1322113222 = {"from":L[1528],
"go":function(anf_obj4213228) {
return $Hanf_obj226613229(anf_obj4213228,anf_obj4013215,t9913203);
}};
$e1321713218.stack[R.EXN_STACKHEIGHT++] = $ss1322113222;
}
if(R.isPyretException($e1321713218)) {
$e1321713218.pyretStack.push(L[1528]);
}
throw $e1321713218;
}
var $ret1322313224 = $Hanf_obj226613229($z1321913220,anf_obj4013215,t9913203);
++R.GAS;
return $ret1322313224;
};
var $Hanf_obj226613229 = function(anf_obj4213228,anf_obj4013215,t9913203) {
var ann_DASH_check_DASH_temp3813230 = R.makeObject({"id":t9913203,
"id-b":anf_obj4013215,
"id-e":anf_obj4213228});
return ann_DASH_check_DASH_temp3813230;
};
var $Hann_DASH_check_DASH_temp226513231 = function(ann_DASH_check_DASH_temp3413232) {
return ann_DASH_check_DASH_temp3413232;
};
var $Hanf_arg226413233 = function(anf_arg1713234,self513235,_plus9,torepr16) {
var anf_arg1813246 = G(self513235,"errors",L[1530]);
var $z1323813239 = D;
var $f1324413245 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg1813246):R.ffi.throwNonFunApp(L[1530],torepr16,[anf_arg1813246]);
};
try {
if(--R.GAS > 0) {
$z1323813239 = $f1324413245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1324413245,
"from":L[1530]});
}
} catch($e1323613237) {
if(R.isCont($e1323613237)) {
var $ss1324013241 = {"from":L[1530],
"go":function(anf_arg1913247) {
return $Hanf_arg226313248(anf_arg1913247,anf_arg1713234,self513235,_plus9,torepr16);
}};
$e1323613237.stack[R.EXN_STACKHEIGHT++] = $ss1324013241;
}
if(R.isPyretException($e1323613237)) {
$e1323613237.pyretStack.push(L[1530]);
}
throw $e1323613237;
}
var $ret1324213243 = $Hanf_arg226313248($z1323813239,anf_arg1713234,self513235,_plus9,torepr16);
++R.GAS;
return $ret1324213243;
};
var $Hanf_arg226313248 = function(anf_arg1913247,anf_arg1713234,self513235,_plus9,torepr16) {
var $z1325113252 = D;
var $f1325713258 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg1913247):R.ffi.throwNonFunApp(L[1530],_plus9,[(", "),anf_arg1913247]);
};
try {
if(--R.GAS > 0) {
$z1325113252 = $f1325713258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1325713258,
"from":L[1530]});
}
} catch($e1324913250) {
if(R.isCont($e1324913250)) {
var $ss1325313254 = {"from":L[1530],
"go":function(anf_arg2013259) {
return $Hanf_arg226213260(anf_arg2013259,anf_arg1713234,self513235,_plus9,torepr16);
}};
$e1324913250.stack[R.EXN_STACKHEIGHT++] = $ss1325313254;
}
if(R.isPyretException($e1324913250)) {
$e1324913250.pyretStack.push(L[1530]);
}
throw $e1324913250;
}
var $ret1325513256 = $Hanf_arg226213260($z1325113252,anf_arg1713234,self513235,_plus9,torepr16);
++R.GAS;
return $ret1325513256;
};
var $Hanf_arg226213260 = function(anf_arg2013259,anf_arg1713234,self513235,_plus9,torepr16) {
var $z1326313264 = D;
var $f1326913270 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg1713234,anf_arg2013259):R.ffi.throwNonFunApp(L[1530],_plus9,[anf_arg1713234,anf_arg2013259]);
};
try {
if(--R.GAS > 0) {
$z1326313264 = $f1326913270();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1326913270,
"from":L[1530]});
}
} catch($e1326113262) {
if(R.isCont($e1326113262)) {
var $ss1326513266 = {"from":L[1530],
"go":function(anf_arg2113271) {
return $Hanf_arg226113272(anf_arg2113271,self513235,_plus9,torepr16);
}};
$e1326113262.stack[R.EXN_STACKHEIGHT++] = $ss1326513266;
}
if(R.isPyretException($e1326113262)) {
$e1326113262.pyretStack.push(L[1530]);
}
throw $e1326113262;
}
var $ret1326713268 = $Hanf_arg226113272($z1326313264,self513235,_plus9,torepr16);
++R.GAS;
return $ret1326713268;
};
var $Hanf_arg226113272 = function(anf_arg2113271,self513235,_plus9,torepr16) {
var anf_arg2213283 = G(self513235,"bindings",L[1530]);
var $z1327513276 = D;
var $f1328113282 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg2213283):R.ffi.throwNonFunApp(L[1530],torepr16,[anf_arg2213283]);
};
try {
if(--R.GAS > 0) {
$z1327513276 = $f1328113282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1328113282,
"from":L[1530]});
}
} catch($e1327313274) {
if(R.isCont($e1327313274)) {
var $ss1327713278 = {"from":L[1530],
"go":function(anf_arg2313284) {
return $Hanf_arg226013285(anf_arg2313284,anf_arg2113271,_plus9);
}};
$e1327313274.stack[R.EXN_STACKHEIGHT++] = $ss1327713278;
}
if(R.isPyretException($e1327313274)) {
$e1327313274.pyretStack.push(L[1530]);
}
throw $e1327313274;
}
var $ret1327913280 = $Hanf_arg226013285($z1327513276,anf_arg2113271,_plus9);
++R.GAS;
return $ret1327913280;
};
var $Hanf_arg226013285 = function(anf_arg2313284,anf_arg2113271,_plus9) {
var $z1328813289 = D;
var $f1329413295 = function(_) {
return R.isFunction(_plus9)?_plus9.app((", "),anf_arg2313284):R.ffi.throwNonFunApp(L[1530],_plus9,[(", "),anf_arg2313284]);
};
try {
if(--R.GAS > 0) {
$z1328813289 = $f1329413295();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1329413295,
"from":L[1530]});
}
} catch($e1328613287) {
if(R.isCont($e1328613287)) {
var $ss1329013291 = {"from":L[1530],
"go":function(anf_arg2413296) {
return $Hanf_arg225913297(anf_arg2413296,anf_arg2113271,_plus9);
}};
$e1328613287.stack[R.EXN_STACKHEIGHT++] = $ss1329013291;
}
if(R.isPyretException($e1328613287)) {
$e1328613287.pyretStack.push(L[1530]);
}
throw $e1328613287;
}
var $ret1329213293 = $Hanf_arg225913297($z1328813289,anf_arg2113271,_plus9);
++R.GAS;
return $ret1329213293;
};
var $Hanf_arg225913297 = function(anf_arg2413296,anf_arg2113271,_plus9) {
var $z1330013301 = D;
var $f1330613307 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg2113271,anf_arg2413296):R.ffi.throwNonFunApp(L[1530],_plus9,[anf_arg2113271,anf_arg2413296]);
};
try {
if(--R.GAS > 0) {
$z1330013301 = $f1330613307();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1330613307,
"from":L[1530]});
}
} catch($e1329813299) {
if(R.isCont($e1329813299)) {
var $ss1330213303 = {"from":L[1530],
"go":function(anf_arg2513308) {
return $Hanf_arg225813309(anf_arg2513308,_plus9);
}};
$e1329813299.stack[R.EXN_STACKHEIGHT++] = $ss1330213303;
}
if(R.isPyretException($e1329813299)) {
$e1329813299.pyretStack.push(L[1530]);
}
throw $e1329813299;
}
var $ret1330413305 = $Hanf_arg225813309($z1330013301,_plus9);
++R.GAS;
return $ret1330413305;
};
var $Hanf_arg225813309 = function(anf_arg2513308,_plus9) {
var $z1331213313 = D;
var $f1331813319 = function(_) {
return R.isFunction(_plus9)?_plus9.app(anf_arg2513308,(")")):R.ffi.throwNonFunApp(L[1530],_plus9,[anf_arg2513308,(")")]);
};
try {
if(--R.GAS > 0) {
$z1331213313 = $f1331813319();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1331813319,
"from":L[1530]});
}
} catch($e1331013311) {
if(R.isCont($e1331013311)) {
var $ss1331413315 = {"from":L[1530],
"go":function(anf_arg2613320) {
return $Hanf_arg225713321(anf_arg2613320,_plus9);
}};
$e1331013311.stack[R.EXN_STACKHEIGHT++] = $ss1331413315;
}
if(R.isPyretException($e1331013311)) {
$e1331013311.pyretStack.push(L[1530]);
}
throw $e1331013311;
}
var $ret1331613317 = $Hanf_arg225713321($z1331213313,_plus9);
++R.GAS;
return $ret1331613317;
};
var $Hanf_arg225713321 = function(anf_arg2613320,_plus9) {
var $z1332413325 = D;
var $f1333013331 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("("),anf_arg2613320):R.ffi.throwNonFunApp(L[1530],_plus9,[("("),anf_arg2613320]);
};
try {
if(--R.GAS > 0) {
$z1332413325 = $f1333013331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1333013331,
"from":L[1530]});
}
} catch($e1332213323) {
if(R.isCont($e1332213323)) {
var $ss1332613327 = {"from":L[1530],
"go":function(anf_arg2713332) {
return $Hanf_arg225613333(anf_arg2713332,_plus9);
}};
$e1332213323.stack[R.EXN_STACKHEIGHT++] = $ss1332613327;
}
if(R.isPyretException($e1332213323)) {
$e1332213323.pyretStack.push(L[1530]);
}
throw $e1332213323;
}
var $ret1332813329 = $Hanf_arg225613333($z1332413325,_plus9);
++R.GAS;
return $ret1332813329;
};
var $Hanf_arg225613333 = function(anf_arg2713332,_plus9) {
var $z1333613337 = D;
var $f1334213343 = function(_) {
return R.isFunction(_plus9)?_plus9.app(("resolved"),anf_arg2713332):R.ffi.throwNonFunApp(L[1530],_plus9,[("resolved"),anf_arg2713332]);
};
try {
if(--R.GAS > 0) {
$z1333613337 = $f1334213343();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1334213343,
"from":L[1530]});
}
} catch($e1333413335) {
if(R.isCont($e1333413335)) {
var $ss1333813339 = {"from":L[1530],
"go":function(ann_DASH_check_DASH_temp1513344) {
return $Hann_DASH_check_DASH_temp225513345(ann_DASH_check_DASH_temp1513344);
}};
$e1333413335.stack[R.EXN_STACKHEIGHT++] = $ss1333813339;
}
if(R.isPyretException($e1333413335)) {
$e1333413335.pyretStack.push(L[1530]);
}
throw $e1333413335;
}
var $ret1334013341 = $Hann_DASH_check_DASH_temp225513345($z1333613337);
++R.GAS;
return $ret1334013341;
};
var $Hann_DASH_check_DASH_temp225513345 = function(ann_DASH_check_DASH_temp1513344) {
return ann_DASH_check_DASH_temp1513344;
};
var $Hcont_tail_arg225313346 = function(cont_tail_arg1213347,if_helper213348) {
if(--R.GAS > 0) {
$z1334913350 = R.isFunction(if_helper213348)?if_helper213348.app(cont_tail_arg1213347):R.ffi.throwNonFunApp(L[1530],if_helper213348,[cont_tail_arg1213347]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper213348)?if_helper213348.app(cont_tail_arg1213347):R.ffi.throwNonFunApp(L[1530],if_helper213348,[cont_tail_arg1213347]);
},
"from":L[1530]});
}
++R.GAS;
return $z1334913350;
};
var $Hcont_tail_arg225413351 = function(cont_tail_arg713352,if_helper213348) {
if(--R.GAS > 0) {
$z1335313354 = R.isFunction(if_helper213348)?if_helper213348.app(cont_tail_arg713352):R.ffi.throwNonFunApp(L[1530],if_helper213348,[cont_tail_arg713352]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper213348)?if_helper213348.app(cont_tail_arg713352):R.ffi.throwNonFunApp(L[1530],if_helper213348,[cont_tail_arg713352]);
},
"from":L[1530]});
}
++R.GAS;
return $z1335313354;
};
return R.loadModulesNew(NAMESPACE,[$A11944,$S32045,$PP52146,$SD72247,$C92348,$U112449,$G132550,$arrays152651,$lists172752,$option192853,$error212954,$sets233055],function($A11944,$S32045,$PP52146,$SD72247,$C92348,$U112449,$G132550,$arrays152651,$lists172752,$option192853,$error212954,$sets233055) {
var A119 = R.getField($A11944,"values");
var S320 = R.getField($S32045,"values");
var PP521 = R.getField($PP52146,"values");
var SD722 = R.getField($SD72247,"values");
var C923 = R.getField($C92348,"values");
var U1124 = R.getField($U112449,"values");
var G1325 = R.getField($G132550,"values");
var arrays1526 = R.getField($arrays152651,"values");
var lists1727 = R.getField($lists172752,"values");
var option1928 = R.getField($option192853,"values");
var error2129 = R.getField($error212954,"values");
var sets2330 = R.getField($sets233055,"values");
var A231 = R.getField($A11944,"types");
var S432 = R.getField($S32045,"types");
var PP633 = R.getField($PP52146,"types");
var SD834 = R.getField($SD72247,"types");
var C1035 = R.getField($C92348,"types");
var U1236 = R.getField($U112449,"types");
var G1437 = R.getField($G132550,"types");
var arrays1638 = R.getField($arrays152651,"types");
var lists1839 = R.getField($lists172752,"types");
var option2040 = R.getField($option192853,"types");
var error2241 = R.getField($error212954,"types");
var sets2442 = R.getField($sets233055,"types");
return R.safeCall(function() {
var List2510374 = R.getDotAnn(L[1531],"lists",lists1839,"List");
var Option2660 = R.getDotAnn(L[1531],"option",option2040,"Option");
var Array2713355 = R.getDotAnn(L[1531],"arrays",arrays1638,"Array");
var Set2813356 = R.getDotAnn(L[1531],"sets",sets2442,"Set");
var array2913852 = G(arrays1526,"array",L[1531]);
var build_DASH_array3013851 = G(arrays1526,"build-array",L[1531]);
var array_DASH_from_DASH_list3113850 = G(arrays1526,"array-from-list",L[1531]);
var is_DASH_array3213849 = G(arrays1526,"is-array",L[1531]);
var list3375 = G(lists1727,"list",L[1531]);
var is_DASH_empty3410379 = G(lists1727,"is-empty",L[1531]);
var is_DASH_link3510380 = G(lists1727,"is-link",L[1531]);
var empty3670 = G(lists1727,"empty",L[1531]);
var link3774 = G(lists1727,"link",L[1531]);
var range3813848 = G(lists1727,"range",L[1531]);
var repeat3913847 = G(lists1727,"repeat",L[1531]);
var filter4013846 = G(lists1727,"filter",L[1531]);
var partition4113845 = G(lists1727,"partition",L[1531]);
var split_DASH_at4213844 = G(lists1727,"split-at",L[1531]);
var any4313843 = G(lists1727,"any",L[1531]);
var find4413842 = G(lists1727,"find",L[1531]);
var map459174 = G(lists1727,"map",L[1531]);
var map24676 = G(lists1727,"map2",L[1531]);
var map34713841 = G(lists1727,"map3",L[1531]);
var map44813840 = G(lists1727,"map4",L[1531]);
var map_n4913839 = G(lists1727,"map_n",L[1531]);
var map2_n5013838 = G(lists1727,"map2_n",L[1531]);
var map3_n5113837 = G(lists1727,"map3_n",L[1531]);
var map4_n5213836 = G(lists1727,"map4_n",L[1531]);
var each5313835 = G(lists1727,"each",L[1531]);
var each25469 = G(lists1727,"each2",L[1531]);
var each35513834 = G(lists1727,"each3",L[1531]);
var each45613833 = G(lists1727,"each4",L[1531]);
var each_n5713832 = G(lists1727,"each_n",L[1531]);
var each2_n5813831 = G(lists1727,"each2_n",L[1531]);
var each3_n5913830 = G(lists1727,"each3_n",L[1531]);
var each4_n6013829 = G(lists1727,"each4_n",L[1531]);
var fold6171 = G(lists1727,"fold",L[1531]);
var fold26213828 = G(lists1727,"fold2",L[1531]);
var fold36313827 = G(lists1727,"fold3",L[1531]);
var fold46413826 = G(lists1727,"fold4",L[1531]);
var index6513825 = G(lists1727,"index",L[1531]);
var Option6613824 = G(option1928,"Option",L[1531]);
var is_DASH_none6713823 = G(option1928,"is-none",L[1531]);
var is_DASH_some6813822 = G(option1928,"is-some",L[1531]);
var none6979 = G(option1928,"none",L[1531]);
var some7084 = G(option1928,"some",L[1531]);
var set7113821 = G(sets2330,"set",L[1531]);
var tree_DASH_set7213820 = G(sets2330,"tree-set",L[1531]);
var list_DASH_set7313819 = G(sets2330,"list-set",L[1531]);
var NameResolutionT27513357 = R.namedBrander("NameResolution");
var NameResolution7458 = R.makeBranderAnn(NameResolutionT27513357,"NameResolution");
var ScopeBindingT37762 = R.namedBrander("ScopeBinding");
var ScopeBinding7661 = R.makeBranderAnn(ScopeBindingT37762,"ScopeBinding");
var TypeBindingT47964 = R.namedBrander("TypeBinding");
var TypeBinding7863 = R.makeBranderAnn(TypeBindingT47964,"TypeBinding");
var NameResolution58013358 = {"$var":D,
"$name":"NameResolution5"};
var NameResolution8159 = {"$var":D,
"$name":"NameResolution"};
var is_DASH_NameResolution8272 = {"$var":D,
"$name":"is-NameResolution"};
var is_DASH_resolved8373 = {"$var":D,
"$name":"is-resolved"};
var resolved8483 = {"$var":D,
"$name":"resolved"};
var mk_DASH_bind8577 = {"$var":D,
"$name":"mk-bind"};
var mk_DASH_id8678 = {"$var":D,
"$name":"mk-id"};
var resolve_DASH_provide8781 = {"$var":D,
"$name":"resolve-provide"};
var resolve_DASH_type_DASH_provide8882 = {"$var":D,
"$name":"resolve-type-provide"};
var resolve_DASH_imports8980 = {"$var":D,
"$name":"resolve-imports"};
var desugar_DASH_toplevel_DASH_types9068 = {"$var":D,
"$name":"desugar-toplevel-types"};
var desugar_DASH_scope_DASH_block9165 = {"$var":D,
"$name":"desugar-scope-block"};
var anf_variant_member1413769 = R.makeMethod(function(self213799) {
return function(cases_DASH_funs313800,else_DASH_clause413811) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1530],2,arguments);
}
var if_DASH_613812 = R.hasField(cases_DASH_funs313800,("resolved"));
var if_helper213348 = R.makeFunction(function(if_helper_arg313817) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1530],1,arguments);
}
var ann_DASH_check_DASH_temp113818 = if_helper_arg313817;
return ann_DASH_check_DASH_temp113818;
});
var anf_if613816 = R.isBoolean(if_DASH_613812);
if(R.isPyretTrue(anf_if613816)) {
if(R.isPyretTrue(if_DASH_613812)) {
var call_DASH_resolved113795 = G(cases_DASH_funs313800,"resolved",L[1530]);
var anf_arg913796 = G(self213799,"ast",L[1613]);
var anf_arg1013797 = G(self213799,"errors",L[1612]);
var anf_arg1113798 = G(self213799,"bindings",L[1611]);
var $z1378713788 = D;
var $f1379313794 = function(_) {
return R.isFunction(call_DASH_resolved113795)?call_DASH_resolved113795.app(anf_arg913796,anf_arg1013797,anf_arg1113798):R.ffi.throwNonFunApp(L[1530],call_DASH_resolved113795,[anf_arg913796,anf_arg1013797,anf_arg1113798]);
};
try {
if(--R.GAS > 0) {
$z1378713788 = $f1379313794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1379313794,
"from":L[1530]});
}
} catch($e1378513786) {
if(R.isCont($e1378513786)) {
var $ss1378913790 = {"from":L[1530],
"go":function(cont_tail_arg1213347) {
return $Hcont_tail_arg225313346(cont_tail_arg1213347,if_helper213348);
}};
$e1378513786.stack[R.EXN_STACKHEIGHT++] = $ss1378913790;
}
if(R.isPyretException($e1378513786)) {
$e1378513786.pyretStack.push(L[1530]);
}
throw $e1378513786;
}
var $ret1379113792 = $Hcont_tail_arg225313346($z1378713788,if_helper213348);
++R.GAS;
return $ret1379113792;
} else {
var $z1380313804 = D;
var $f1380913810 = function(_) {
return R.isFunction(else_DASH_clause413811)?else_DASH_clause413811.app():R.ffi.throwNonFunApp(L[1530],else_DASH_clause413811,[]);
};
try {
if(--R.GAS > 0) {
$z1380313804 = $f1380913810();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1380913810,
"from":L[1530]});
}
} catch($e1380113802) {
if(R.isCont($e1380113802)) {
var $ss1380513806 = {"from":L[1530],
"go":function(cont_tail_arg713352) {
return $Hcont_tail_arg225413351(cont_tail_arg713352,if_helper213348);
}};
$e1380113802.stack[R.EXN_STACKHEIGHT++] = $ss1380513806;
}
if(R.isPyretException($e1380113802)) {
$e1380113802.pyretStack.push(L[1530]);
}
throw $e1380113802;
}
var $ret1380713808 = $Hcont_tail_arg225413351($z1380313804,if_helper213348);
++R.GAS;
return $ret1380713808;
}
} else {
var cont_tail_arg413815 = R.throwNonBooleanCondition(L[1530],("if"),if_DASH_613812);
if(--R.GAS > 0) {
$z1381313814 = R.isFunction(if_helper213348)?if_helper213348.app(cont_tail_arg413815):R.ffi.throwNonFunApp(L[1530],if_helper213348,[cont_tail_arg413815]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored349) {
return R.isFunction(if_helper213348)?if_helper213348.app(cont_tail_arg413815):R.ffi.throwNonFunApp(L[1530],if_helper213348,[cont_tail_arg413815]);
},
"from":L[1530]});
}
++R.GAS;
return $z1381313814;
}
};
},{"length":3});
var anf_variant_member2813770 = R.makeMethod(function(self513235) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1530],0,arguments);
}
var anf_arg1613784 = G(self513235,"ast",L[1530]);
var $z1377613777 = D;
var $f1378213783 = function(_) {
return R.isFunction(torepr16)?torepr16.app(anf_arg1613784):R.ffi.throwNonFunApp(L[1530],torepr16,[anf_arg1613784]);
};
try {
if(--R.GAS > 0) {
$z1377613777 = $f1378213783();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1378213783,
"from":L[1530]});
}
} catch($e1377413775) {
if(R.isCont($e1377413775)) {
var $ss1377813779 = {"from":L[1530],
"go":function(anf_arg1713234) {
return $Hanf_arg226413233(anf_arg1713234,self513235,_plus9,torepr16);
}};
$e1377413775.stack[R.EXN_STACKHEIGHT++] = $ss1377813779;
}
if(R.isPyretException($e1377413775)) {
$e1377413775.pyretStack.push(L[1530]);
}
throw $e1377413775;
}
var $ret1378013781 = $Hanf_arg226413233($z1377613777,self513235,_plus9,torepr16);
++R.GAS;
return $ret1378013781;
};
},{"length":1});
var anf_assign2913359 = (function() {
var $resolved_DASH_base1376413765 = {"_match":anf_variant_member1413769,
"_torepr":anf_variant_member2813770};
var $resolved_DASH_brands1376713768 = {"$brand-resolved13766":true};
$resolved_DASH_brands1376713768[NameResolutionT27513357._brand] = true
return R.makeObject({"NameResolution":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[120],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,NameResolutionT27513357._brand));
}),
"is-resolved":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1530],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-resolved13766"));
}),
"resolved":R.makeFunction(function(ast9213771,errors9313772,bindings9413773) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1607],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[1608],"A",A231,"Program"),List2510374,R.getDotAnn(L[1609],"SD",SD834,"StringDict")],[ast9213771,errors9313772,bindings9413773],[L[1608],L[1610],L[1609]],function() {
var dict = R.create($resolved_DASH_base1376413765);
dict["ast"] = ast9213771
dict["errors"] = errors9313772
dict["bindings"] = bindings9413773
return R.makeBrandedObject(dict,$resolved_DASH_brands1376713768);
});
})});
})();
NameResolution58013358.$var = anf_assign2913359;
var anf_assign3013360 = G(NameResolution58013358.$var,"NameResolution",L[120]);
NameResolution8159.$var = anf_assign3013360;
var anf_assign3113361 = G(NameResolution58013358.$var,"NameResolution",L[120]);
is_DASH_NameResolution8272.$var = anf_assign3113361;
var anf_assign3213362 = G(NameResolution58013358.$var,"is-resolved",L[1530]);
is_DASH_resolved8373.$var = anf_assign3213362;
var anf_assign3313363 = G(NameResolution58013358.$var,"resolved",L[1530]);
resolved8483.$var = anf_assign3313363;
var anf_assign3713364 = R.makeFunction(function(l9513750,id9613751) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1604],2,arguments);
}
var anf_fun3513762 = G(A119,"s-bind",L[1606]);
var anf_arg3613763 = G(A119,"a-blank",L[1605]);
var $z1375413755 = D;
var $f1376013761 = function(_) {
return R.isFunction(anf_fun3513762)?anf_fun3513762.app(l9513750,(false),id9613751,anf_arg3613763):R.ffi.throwNonFunApp(L[1604],anf_fun3513762,[l9513750,(false),id9613751,anf_arg3613763]);
};
try {
if(--R.GAS > 0) {
$z1375413755 = $f1376013761();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1376013761,
"from":L[1604]});
}
} catch($e1375213753) {
if(R.isCont($e1375213753)) {
var $ss1375613757 = {"from":L[1604],
"go":function(ann_DASH_check_DASH_temp3413232) {
return $Hann_DASH_check_DASH_temp226513231(ann_DASH_check_DASH_temp3413232);
}};
$e1375213753.stack[R.EXN_STACKHEIGHT++] = $ss1375613757;
}
if(R.isPyretException($e1375213753)) {
$e1375213753.pyretStack.push(L[1604]);
}
throw $e1375213753;
}
var $ret1375813759 = $Hann_DASH_check_DASH_temp226513231($z1375413755);
++R.GAS;
return $ret1375813759;
});
mk_DASH_bind8577.$var = anf_assign3713364;
var anf_assign4313365 = R.makeFunction(function(loc9713204,base9813738) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1601],2,arguments);
}
var anf_fun3913749 = G(A119,"s-name",L[1603]);
var $z1374113742 = D;
var $f1374713748 = function(_) {
return R.isFunction(anf_fun3913749)?anf_fun3913749.app(loc9713204,base9813738):R.ffi.throwNonFunApp(L[1602],anf_fun3913749,[loc9713204,base9813738]);
};
try {
if(--R.GAS > 0) {
$z1374113742 = $f1374713748();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1374713748,
"from":L[1602]});
}
} catch($e1373913740) {
if(R.isCont($e1373913740)) {
var $ss1374313744 = {"from":L[1602],
"go":function(t9913203) {
return $Ht226813202(t9913203,A119,loc9713204,mk_DASH_bind8577);
}};
$e1373913740.stack[R.EXN_STACKHEIGHT++] = $ss1374313744;
}
if(R.isPyretException($e1373913740)) {
$e1373913740.pyretStack.push(L[1602]);
}
throw $e1373913740;
}
var $ret1374513746 = $Ht226813202($z1374113742,A119,loc9713204,mk_DASH_bind8577);
++R.GAS;
return $ret1374513746;
});
mk_DASH_id8678.$var = anf_assign4313365;
var anf_assign6313366 = R.makeFunction(function(p10013709,b10113710) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1595],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[1599],"A",A231,"Provide"),R.getDotAnn(L[1600],"A",A231,"Expr")],[p10013709,b10113710],[L[1599],L[1600]],function() {
var cases_DASH_val713737 = p10013709;
var anf_fun4513721 = G(cases_DASH_val713737,"_match",L[1596]);
var anf_obj5913725 = R.makeFunction(function(l10213110) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1522],1,arguments);
}
var anf_fun4713736 = G(A119,"block-ids",L[1598]);
var $z1372813729 = D;
var $f1373413735 = function(_) {
return R.isFunction(anf_fun4713736)?anf_fun4713736.app(b10113710):R.ffi.throwNonFunApp(L[1597],anf_fun4713736,[b10113710]);
};
try {
if(--R.GAS > 0) {
$z1372813729 = $f1373413735();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1373413735,
"from":L[1597]});
}
} catch($e1372613727) {
if(R.isCont($e1372613727)) {
var $ss1373013731 = {"from":L[1597],
"go":function(ids10313109) {
return $Hids227613108(ids10313109,A119,l10213110,map459174,tostring17);
}};
$e1372613727.stack[R.EXN_STACKHEIGHT++] = $ss1373013731;
}
if(R.isPyretException($e1372613727)) {
$e1372613727.pyretStack.push(L[1597]);
}
throw $e1372613727;
}
var $ret1373213733 = $Hids227613108($z1372813729,A119,l10213110,map459174,tostring17);
++R.GAS;
return $ret1373213733;
});
var anf_arg6013722 = R.makeObject({"s-provide-all":anf_obj5913725});
var anf_arg6213723 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1596],0,arguments);
}
var ann_DASH_check_DASH_temp6113724 = p10013709;
return ann_DASH_check_DASH_temp6113724;
});
var $z1371313714 = D;
var $f1371913720 = function(_) {
return R.isFunction(anf_fun4513721)?anf_fun4513721.app(anf_arg6013722,anf_arg6213723):R.ffi.throwNonFunApp(L[1595],anf_fun4513721,[anf_arg6013722,anf_arg6213723]);
};
try {
if(--R.GAS > 0) {
$z1371313714 = $f1371913720();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1371913720,
"from":L[1595]});
}
} catch($e1371113712) {
if(R.isCont($e1371113712)) {
var $ss1371513716 = {"from":L[1595],
"go":function(ann_DASH_check_DASH_temp4413107) {
return $Hann_DASH_check_DASH_temp227713106(ann_DASH_check_DASH_temp4413107);
}};
$e1371113712.stack[R.EXN_STACKHEIGHT++] = $ss1371513716;
}
if(R.isPyretException($e1371113712)) {
$e1371113712.pyretStack.push(L[1595]);
}
throw $e1371113712;
}
var $ret1371713718 = $Hann_DASH_check_DASH_temp227713106($z1371313714);
++R.GAS;
return $ret1371713718;
});
});
resolve_DASH_provide8781.$var = anf_assign6313366;
var anf_assign9913367 = R.makeFunction(function(p10613680,b10713681) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1589],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[1593],"A",A231,"ProvideTypes"),R.getDotAnn(L[1594],"A",A231,"Expr")],[p10613680,b10713681],[L[1593],L[1594]],function() {
var cases_DASH_val913708 = p10613680;
var anf_fun6513692 = G(cases_DASH_val913708,"_match",L[1590]);
var anf_obj9513696 = R.makeFunction(function(l10812983) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1506],1,arguments);
}
var anf_fun6713707 = G(A119,"block-type-ids",L[1592]);
var $z1369913700 = D;
var $f1370513706 = function(_) {
return R.isFunction(anf_fun6713707)?anf_fun6713707.app(b10713681):R.ffi.throwNonFunApp(L[1591],anf_fun6713707,[b10713681]);
};
try {
if(--R.GAS > 0) {
$z1369913700 = $f1370513706();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1370513706,
"from":L[1591]});
}
} catch($e1369713698) {
if(R.isCont($e1369713698)) {
var $ss1370113702 = {"from":L[1591],
"go":function(ids10912982) {
return $Hids228612981(ids10912982,A119,l10812983,map459174);
}};
$e1369713698.stack[R.EXN_STACKHEIGHT++] = $ss1370113702;
}
if(R.isPyretException($e1369713698)) {
$e1369713698.pyretStack.push(L[1591]);
}
throw $e1369713698;
}
var $ret1370313704 = $Hids228612981($z1369913700,A119,l10812983,map459174);
++R.GAS;
return $ret1370313704;
});
var anf_arg9613693 = R.makeObject({"s-provide-types-all":anf_obj9513696});
var anf_arg9813694 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1590],0,arguments);
}
var ann_DASH_check_DASH_temp9713695 = p10613680;
return ann_DASH_check_DASH_temp9713695;
});
var $z1368413685 = D;
var $f1369013691 = function(_) {
return R.isFunction(anf_fun6513692)?anf_fun6513692.app(anf_arg9613693,anf_arg9813694):R.ffi.throwNonFunApp(L[1589],anf_fun6513692,[anf_arg9613693,anf_arg9813694]);
};
try {
if(--R.GAS > 0) {
$z1368413685 = $f1369013691();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1369013691,
"from":L[1589]});
}
} catch($e1368213683) {
if(R.isCont($e1368213683)) {
var $ss1368613687 = {"from":L[1589],
"go":function(ann_DASH_check_DASH_temp6412980) {
return $Hann_DASH_check_DASH_temp228712979(ann_DASH_check_DASH_temp6412980);
}};
$e1368213683.stack[R.EXN_STACKHEIGHT++] = $ss1368613687;
}
if(R.isPyretException($e1368213683)) {
$e1368213683.pyretStack.push(L[1589]);
}
throw $e1368213683;
}
var $ret1368813689 = $Hann_DASH_check_DASH_temp228712979($z1368413685);
++R.GAS;
return $ret1368813689;
});
});
resolve_DASH_type_DASH_provide8882.$var = anf_assign9913367;
var anf_assign18013368 = R.makeFunction(function(imports11212635) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1574],1,arguments);
}
return R.checkAnnArgs([List2510374],[imports11212635],[L[1588]],function() {
var resolve_DASH_import_DASH_type11312699 = {"$var":D,
"$name":"resolve-import-type"};
var anf_assign12013598 = R.makeFunction(function(imp11412931) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1583],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[1587],"A",A231,"ImportType")],[imp11412931],[L[1587]],function() {
var cases_DASH_val1113679 = imp11412931;
var anf_fun10213660 = G(cases_DASH_val1113679,"_match",L[1584]);
var anf_obj11413664 = R.makeFunction(function(l11512932,file11612930) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1586],2,arguments);
}
var $z1367113672 = D;
var $f1367713678 = function(_) {
return R.isFunction(string_DASH_contains15)?string_DASH_contains15.app(file11612930,("/")):R.ffi.throwNonFunApp(L[1492],string_DASH_contains15,[file11612930,("/")]);
};
try {
if(--R.GAS > 0) {
$z1367113672 = $f1367713678();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1367713678,
"from":L[1492]});
}
} catch($e1366913670) {
if(R.isCont($e1366913670)) {
var $ss1367313674 = {"from":L[1492],
"go":function(if_DASH_1012929) {
return $Hif_DASH_229112928(if_DASH_1012929,A119,file11612930,imp11412931,l11512932,_plus9);
}};
$e1366913670.stack[R.EXN_STACKHEIGHT++] = $ss1367313674;
}
if(R.isPyretException($e1366913670)) {
$e1366913670.pyretStack.push(L[1492]);
}
throw $e1366913670;
}
var $ret1367513676 = $Hif_DASH_229112928($z1367113672,A119,file11612930,imp11412931,l11512932,_plus9);
++R.GAS;
return $ret1367513676;
});
var anf_obj11613665 = R.makeFunction(function($underscore11713666,$underscore11813667) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1585],2,arguments);
}
var ann_DASH_check_DASH_temp11513668 = imp11412931;
return ann_DASH_check_DASH_temp11513668;
});
var anf_arg11713661 = R.makeObject({"s-file-import":anf_obj11413664,
"s-const-import":anf_obj11613665});
var anf_arg11913662 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1584],0,arguments);
}
var ann_DASH_check_DASH_temp11813663 = R.throwNoBranchesMatched(L[1584],("cases"));
return ann_DASH_check_DASH_temp11813663;
});
var $z1365213653 = D;
var $f1365813659 = function(_) {
return R.isFunction(anf_fun10213660)?anf_fun10213660.app(anf_arg11713661,anf_arg11913662):R.ffi.throwNonFunApp(L[1583],anf_fun10213660,[anf_arg11713661,anf_arg11913662]);
};
try {
if(--R.GAS > 0) {
$z1365213653 = $f1365813659();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1365813659,
"from":L[1583]});
}
} catch($e1365013651) {
if(R.isCont($e1365013651)) {
var $ss1365413655 = {"from":L[1583],
"go":function(ann_DASH_check_DASH_temp10112927) {
return $Hann_DASH_check_DASH_temp229212926(ann_DASH_check_DASH_temp10112927);
}};
$e1365013651.stack[R.EXN_STACKHEIGHT++] = $ss1365413655;
}
if(R.isPyretException($e1365013651)) {
$e1365013651.pyretStack.push(L[1583]);
}
throw $e1365013651;
}
var $ret1365613657 = $Hann_DASH_check_DASH_temp229212926($z1365213653);
++R.GAS;
return $ret1365613657;
});
});
resolve_DASH_import_DASH_type11312699.$var = anf_assign12013598;
var anf_arg16812634 = R.makeFunction(function(acc12012695,i12113610) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1576],2,arguments);
}
var cases_DASH_val1313649 = i12113610;
var anf_fun12213621 = G(cases_DASH_val1313649,"_match",L[1577]);
var anf_obj12813625 = R.makeFunction(function(l12212898,imp12313638,name12412899) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1580],3,arguments);
}
var anf_fun12412897 = G(A119,"s-import",L[1582]);
var $z1364113642 = D;
var $f1364713648 = function(_) {
return R.isFunction(resolve_DASH_import_DASH_type11312699.$var)?resolve_DASH_import_DASH_type11312699.$var.app(imp12313638):R.ffi.throwNonFunApp(L[1581],resolve_DASH_import_DASH_type11312699.$var,[imp12313638]);
};
try {
if(--R.GAS > 0) {
$z1364113642 = $f1364713648();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1364713648,
"from":L[1581]});
}
} catch($e1363913640) {
if(R.isCont($e1363913640)) {
var $ss1364313644 = {"from":L[1581],
"go":function(anf_arg12512896) {
return $Hanf_arg229512895(anf_arg12512896,acc12012695,anf_fun12412897,l12212898,link3774,name12412899);
}};
$e1363913640.stack[R.EXN_STACKHEIGHT++] = $ss1364313644;
}
if(R.isPyretException($e1363913640)) {
$e1363913640.pyretStack.push(L[1581]);
}
throw $e1363913640;
}
var $ret1364513646 = $Hanf_arg229512895($z1364113642,acc12012695,anf_fun12412897,l12212898,link3774,name12412899);
++R.GAS;
return $ret1364513646;
});
var anf_obj16413626 = R.makeFunction(function(l12612698,fields12712696,imp12812697) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1578],3,arguments);
}
var anf_fun13013637 = G(A119,"is-s-const-import",L[1579]);
var $z1362913630 = D;
var $f1363513636 = function(_) {
return R.isFunction(anf_fun13013637)?anf_fun13013637.app(imp12812697):R.ffi.throwNonFunApp(L[1458],anf_fun13013637,[imp12812697]);
};
try {
if(--R.GAS > 0) {
$z1362913630 = $f1363513636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1363513636,
"from":L[1458]});
}
} catch($e1362713628) {
if(R.isCont($e1362713628)) {
var $ss1363113632 = {"from":L[1458],
"go":function(if_DASH_1212694) {
return $Hif_DASH_231012693(if_DASH_1212694,A119,G1325,acc12012695,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9);
}};
$e1362713628.stack[R.EXN_STACKHEIGHT++] = $ss1363113632;
}
if(R.isPyretException($e1362713628)) {
$e1362713628.pyretStack.push(L[1458]);
}
throw $e1362713628;
}
var $ret1363313634 = $Hif_DASH_231012693($z1362913630,A119,G1325,acc12012695,fields12712696,imp12812697,l12612698,link3774,map459174,resolve_DASH_import_DASH_type11312699,_plus9);
++R.GAS;
return $ret1363313634;
});
var anf_arg16513622 = R.makeObject({"s-import":anf_obj12813625,
"s-import-fields":anf_obj16413626});
var anf_arg16713623 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1577],0,arguments);
}
var ann_DASH_check_DASH_temp16613624 = R.throwNoBranchesMatched(L[1577],("cases"));
return ann_DASH_check_DASH_temp16613624;
});
var $z1361313614 = D;
var $f1361913620 = function(_) {
return R.isFunction(anf_fun12213621)?anf_fun12213621.app(anf_arg16513622,anf_arg16713623):R.ffi.throwNonFunApp(L[1576],anf_fun12213621,[anf_arg16513622,anf_arg16713623]);
};
try {
if(--R.GAS > 0) {
$z1361313614 = $f1361913620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1361913620,
"from":L[1576]});
}
} catch($e1361113612) {
if(R.isCont($e1361113612)) {
var $ss1361513616 = {"from":L[1576],
"go":function(ann_DASH_check_DASH_temp12112692) {
return $Hann_DASH_check_DASH_temp231112691(ann_DASH_check_DASH_temp12112692);
}};
$e1361113612.stack[R.EXN_STACKHEIGHT++] = $ss1361513616;
}
if(R.isPyretException($e1361113612)) {
$e1361113612.pyretStack.push(L[1576]);
}
throw $e1361113612;
}
var $ret1361713618 = $Hann_DASH_check_DASH_temp231112691($z1361313614);
++R.GAS;
return $ret1361713618;
});
var anf_fun16913609 = G(list3375,"make",L[1575]);
var $z1360113602 = D;
var $f1360713608 = function(_) {
return R.isFunction(anf_fun16913609)?anf_fun16913609.app([]):R.ffi.throwNonFunApp(L[1575],anf_fun16913609,[[]]);
};
try {
if(--R.GAS > 0) {
$z1360113602 = $f1360713608();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1360713608,
"from":L[1575]});
}
} catch($e1359913600) {
if(R.isCont($e1359913600)) {
var $ss1360313604 = {"from":L[1575],
"go":function(anf_obj17012633) {
return $Hanf_obj231612632(anf_obj17012633,anf_arg16812634,fold6171,imports11212635,list3375);
}};
$e1359913600.stack[R.EXN_STACKHEIGHT++] = $ss1360313604;
}
if(R.isPyretException($e1359913600)) {
$e1359913600.pyretStack.push(L[1575]);
}
throw $e1359913600;
}
var $ret1360513606 = $Hanf_obj231612632($z1360113602,anf_arg16812634,fold6171,imports11212635,list3375);
++R.GAS;
return $ret1360513606;
});
});
resolve_DASH_imports8980.$var = anf_assign18013368;
var anf_assign25213369 = R.makeFunction(function(stmts13412189) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1573],1,arguments);
}
var $z1359013591 = D;
var $f1359613597 = function(_) {
return R.isFunction(is_DASH_link3510380)?is_DASH_link3510380.app(stmts13412189):R.ffi.throwNonFunApp(L[1398],is_DASH_link3510380,[stmts13412189]);
};
try {
if(--R.GAS > 0) {
$z1359013591 = $f1359613597();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1359613597,
"from":L[1398]});
}
} catch($e1358813589) {
if(R.isCont($e1358813589)) {
var $ss1359213593 = {"from":L[1398],
"go":function(or_DASH_oper_DASH_1512188) {
return $Hor_DASH_oper_DASH_235012187(or_DASH_oper_DASH_1512188,A119,A231,G1325,List2510374,empty3670,is_DASH_empty3410379,link3774,list3375,lists1727,stmts13412189,_plus9,not11,nothing12,raise14,torepr16);
}};
$e1358813589.stack[R.EXN_STACKHEIGHT++] = $ss1359213593;
}
if(R.isPyretException($e1358813589)) {
$e1358813589.pyretStack.push(L[1398]);
}
throw $e1358813589;
}
var $ret1359413595 = $Hor_DASH_oper_DASH_235012187($z1359013591,A119,A231,G1325,List2510374,empty3670,is_DASH_empty3410379,link3774,list3375,lists1727,stmts13412189,_plus9,not11,nothing12,raise14,torepr16);
++R.GAS;
return $ret1359413595;
});
desugar_DASH_toplevel_DASH_types9068.$var = anf_assign25213369;
var anf_assign54613370 = R.makeFunction(function(stmts15413508,let_DASH_binds15510381,letrec_DASH_binds15610382,type_DASH_let_DASH_binds15710384) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[94],4,arguments);
}
var cases_DASH_val3613587 = stmts15413508;
var anf_fun25413519 = G(cases_DASH_val3613587,"_match",L[1554]);
var anf_obj25613523 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1572],0,arguments);
}
var ann_DASH_check_DASH_temp25513586 = empty3670;
return ann_DASH_check_DASH_temp25513586;
});
var anf_obj54213524 = R.makeFunction(function(f15810377,rest_DASH_stmts15910383) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1215],2,arguments);
}
var wrap_DASH_letrecs16010385 = {"$var":D,
"$name":"wrap-letrecs"};
var wrap_DASH_lets16110386 = {"$var":D,
"$name":"wrap-lets"};
var wrap_DASH_type_DASH_lets16210387 = {"$var":D,
"$name":"wrap-type-lets"};
var handle_DASH_let_DASH_bind16310378 = {"$var":D,
"$name":"handle-let-bind"};
var anf_assign26413525 = R.makeFunction(function(expr16412174) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1397],1,arguments);
}
var anf_fun25912173 = G(A119,"s-letrec",L[1571]);
var anf_bracket26013585 = G(letrec_DASH_binds15610382,"first",L[1570]);
var anf_arg26112172 = G(anf_bracket26013585,"l",L[1569]);
var anf_fun26213584 = G(letrec_DASH_binds15610382,"reverse",L[1568]);
var $z1357613577 = D;
var $f1358213583 = function(_) {
return R.isFunction(anf_fun26213584)?anf_fun26213584.app():R.ffi.throwNonFunApp(L[1567],anf_fun26213584,[]);
};
try {
if(--R.GAS > 0) {
$z1357613577 = $f1358213583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1358213583,
"from":L[1567]});
}
} catch($e1357413575) {
if(R.isCont($e1357413575)) {
var $ss1357813579 = {"from":L[1567],
"go":function(anf_arg26312171) {
return $Hanf_arg235212170(anf_arg26312171,anf_arg26112172,anf_fun25912173,expr16412174);
}};
$e1357413575.stack[R.EXN_STACKHEIGHT++] = $ss1357813579;
}
if(R.isPyretException($e1357413575)) {
$e1357413575.pyretStack.push(L[1567]);
}
throw $e1357413575;
}
var $ret1358013581 = $Hanf_arg235212170($z1357613577,anf_arg26112172,anf_fun25912173,expr16412174);
++R.GAS;
return $ret1358013581;
});
wrap_DASH_letrecs16010385.$var = anf_assign26413525;
var anf_assign27113526 = R.makeFunction(function(expr16512157) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1396],1,arguments);
}
var anf_fun26612156 = G(A119,"s-let-expr",L[1566]);
var anf_bracket26713573 = G(let_DASH_binds15510381,"first",L[1565]);
var anf_arg26812155 = G(anf_bracket26713573,"l",L[1564]);
var anf_fun26913572 = G(let_DASH_binds15510381,"reverse",L[1563]);
var $z1356413565 = D;
var $f1357013571 = function(_) {
return R.isFunction(anf_fun26913572)?anf_fun26913572.app():R.ffi.throwNonFunApp(L[1562],anf_fun26913572,[]);
};
try {
if(--R.GAS > 0) {
$z1356413565 = $f1357013571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1357013571,
"from":L[1562]});
}
} catch($e1356213563) {
if(R.isCont($e1356213563)) {
var $ss1356613567 = {"from":L[1562],
"go":function(anf_arg27012154) {
return $Hanf_arg235412153(anf_arg27012154,anf_arg26812155,anf_fun26612156,expr16512157);
}};
$e1356213563.stack[R.EXN_STACKHEIGHT++] = $ss1356613567;
}
if(R.isPyretException($e1356213563)) {
$e1356213563.pyretStack.push(L[1562]);
}
throw $e1356213563;
}
var $ret1356813569 = $Hanf_arg235412153($z1356413565,anf_arg26812155,anf_fun26612156,expr16512157);
++R.GAS;
return $ret1356813569;
});
wrap_DASH_lets16110386.$var = anf_assign27113526;
var anf_assign27813527 = R.makeFunction(function(expr16612140) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1395],1,arguments);
}
var anf_fun27312139 = G(A119,"s-type-let-expr",L[1561]);
var anf_bracket27413561 = G(type_DASH_let_DASH_binds15710384,"first",L[1560]);
var anf_arg27512138 = G(anf_bracket27413561,"l",L[1559]);
var anf_fun27613560 = G(type_DASH_let_DASH_binds15710384,"reverse",L[1558]);
var $z1355213553 = D;
var $f1355813559 = function(_) {
return R.isFunction(anf_fun27613560)?anf_fun27613560.app():R.ffi.throwNonFunApp(L[1557],anf_fun27613560,[]);
};
try {
if(--R.GAS > 0) {
$z1355213553 = $f1355813559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1355813559,
"from":L[1557]});
}
} catch($e1355013551) {
if(R.isCont($e1355013551)) {
var $ss1355413555 = {"from":L[1557],
"go":function(anf_arg27712137) {
return $Hanf_arg235612136(anf_arg27712137,anf_arg27512138,anf_fun27312139,expr16612140);
}};
$e1355013551.stack[R.EXN_STACKHEIGHT++] = $ss1355413555;
}
if(R.isPyretException($e1355013551)) {
$e1355013551.pyretStack.push(L[1557]);
}
throw $e1355013551;
}
var $ret1355613557 = $Hanf_arg235612136($z1355213553,anf_arg27512138,anf_fun27312139,expr16612140);
++R.GAS;
return $ret1355613557;
});
wrap_DASH_type_DASH_lets16210387.$var = anf_assign27813527;
var anf_assign30713528 = R.makeFunction(function(l16711946,new_DASH_bind16813539) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1555],2,arguments);
}
var $z1354213543 = D;
var $f1354813549 = function(_) {
return R.isFunction(link3774)?link3774.app(new_DASH_bind16813539,let_DASH_binds15510381):R.ffi.throwNonFunApp(L[1556],link3774,[new_DASH_bind16813539,let_DASH_binds15510381]);
};
try {
if(--R.GAS > 0) {
$z1354213543 = $f1354813549();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1354813549,
"from":L[1556]});
}
} catch($e1354013541) {
if(R.isCont($e1354013541)) {
var $ss1354413545 = {"from":L[1556],
"go":function(new_DASH_binds16911945) {
return $Hnew_DASH_binds237111944(new_DASH_binds16911945,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
}};
$e1354013541.stack[R.EXN_STACKHEIGHT++] = $ss1354413545;
}
if(R.isPyretException($e1354013541)) {
$e1354013541.pyretStack.push(L[1556]);
}
throw $e1354013541;
}
var $ret1354613547 = $Hnew_DASH_binds237111944($z1354213543,A119,desugar_DASH_scope_DASH_block9165,is_DASH_empty3410379,l16711946,letrec_DASH_binds15610382,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_type_DASH_lets16210387,not11);
++R.GAS;
return $ret1354613547;
});
handle_DASH_let_DASH_bind16310378.$var = anf_assign30713528;
var $z1353113532 = D;
var $f1353713538 = function(_) {
return R.isFunction(is_DASH_link3510380)?is_DASH_link3510380.app(let_DASH_binds15510381):R.ffi.throwNonFunApp(L[1214],is_DASH_link3510380,[let_DASH_binds15510381]);
};
try {
if(--R.GAS > 0) {
$z1353113532 = $f1353713538();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1353713538,
"from":L[1214]});
}
} catch($e1352913530) {
if(R.isCont($e1352913530)) {
var $ss1353313534 = {"from":L[1214],
"go":function(if_DASH_2310376) {
return $Hif_DASH_248410375(if_DASH_2310376,A119,G1325,desugar_DASH_scope_DASH_block9165,f15810377,fold6171,handle_DASH_let_DASH_bind16310378,is_DASH_empty3410379,is_DASH_link3510380,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,_plus9,not11,$type$String18);
}};
$e1352913530.stack[R.EXN_STACKHEIGHT++] = $ss1353313534;
}
if(R.isPyretException($e1352913530)) {
$e1352913530.pyretStack.push(L[1214]);
}
throw $e1352913530;
}
var $ret1353513536 = $Hif_DASH_248410375($z1353113532,A119,G1325,desugar_DASH_scope_DASH_block9165,f15810377,fold6171,handle_DASH_let_DASH_bind16310378,is_DASH_empty3410379,is_DASH_link3510380,let_DASH_binds15510381,letrec_DASH_binds15610382,link3774,list3375,rest_DASH_stmts15910383,type_DASH_let_DASH_binds15710384,wrap_DASH_letrecs16010385,wrap_DASH_lets16110386,wrap_DASH_type_DASH_lets16210387,_plus9,not11,$type$String18);
++R.GAS;
return $ret1353513536;
});
var anf_arg54313520 = R.makeObject({"empty":anf_obj25613523,
"link":anf_obj54213524});
var anf_arg54513521 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1554],0,arguments);
}
var ann_DASH_check_DASH_temp54413522 = R.throwNoBranchesMatched(L[1554],("cases"));
return ann_DASH_check_DASH_temp54413522;
});
var $z1351113512 = D;
var $f1351713518 = function(_) {
return R.isFunction(anf_fun25413519)?anf_fun25413519.app(anf_arg54313520,anf_arg54513521):R.ffi.throwNonFunApp(L[94],anf_fun25413519,[anf_arg54313520,anf_arg54513521]);
};
try {
if(--R.GAS > 0) {
$z1351113512 = $f1351713518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1351713518,
"from":L[94]});
}
} catch($e1350913510) {
if(R.isCont($e1350913510)) {
var $ss1351313514 = {"from":L[94],
"go":function(ann_DASH_check_DASH_temp25310373) {
return $Hann_DASH_check_DASH_temp248510372(ann_DASH_check_DASH_temp25310373,A231,List2510374);
}};
$e1350913510.stack[R.EXN_STACKHEIGHT++] = $ss1351313514;
}
if(R.isPyretException($e1350913510)) {
$e1350913510.pyretStack.push(L[94]);
}
throw $e1350913510;
}
var $ret1351513516 = $Hann_DASH_check_DASH_temp248510372($z1351113512,A231,List2510374);
++R.GAS;
return $ret1351513516;
});
desugar_DASH_scope_DASH_block9165.$var = anf_assign54613370;
var anf_extend54713480 = G(A119,"default-map-visitor",L[1553]);
var anf_extend56213481 = R.makeMethod(function(self22613506) {
return function(l22710306,stmts22813507) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1211],2,arguments);
}
var anf_fun54910305 = G(A119,"s-block",L[1552]);
var anf_fun55013492 = G(stmts22813507,"map",L[1551]);
var anf_arg55313493 = R.makeFunction(function(recv_DASH_3713494) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1550],1,arguments);
}
var anf_fun55213505 = G(recv_DASH_3713494,"visit",L[1550]);
var $z1349713498 = D;
var $f1350313504 = function(_) {
return R.isFunction(anf_fun55213505)?anf_fun55213505.app(self22613506):R.ffi.throwNonFunApp(L[1550],anf_fun55213505,[self22613506]);
};
try {
if(--R.GAS > 0) {
$z1349713498 = $f1350313504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1350313504,
"from":L[1550]});
}
} catch($e1349513496) {
if(R.isCont($e1349513496)) {
var $ss1349913500 = {"from":L[1550],
"go":function(ann_DASH_check_DASH_temp55110371) {
return $Hann_DASH_check_DASH_temp248610370(ann_DASH_check_DASH_temp55110371);
}};
$e1349513496.stack[R.EXN_STACKHEIGHT++] = $ss1349913500;
}
if(R.isPyretException($e1349513496)) {
$e1349513496.pyretStack.push(L[1550]);
}
throw $e1349513496;
}
var $ret1350113502 = $Hann_DASH_check_DASH_temp248610370($z1349713498);
++R.GAS;
return $ret1350113502;
});
var $z1348413485 = D;
var $f1349013491 = function(_) {
return R.isFunction(anf_fun55013492)?anf_fun55013492.app(anf_arg55313493):R.ffi.throwNonFunApp(L[1549],anf_fun55013492,[anf_arg55313493]);
};
try {
if(--R.GAS > 0) {
$z1348413485 = $f1349013491();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1349013491,
"from":L[1549]});
}
} catch($e1348213483) {
if(R.isCont($e1348213483)) {
var $ss1348613487 = {"from":L[1549],
"go":function(anf_arg55410304) {
return $Hanf_arg249210303(anf_arg55410304,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375);
}};
$e1348213483.stack[R.EXN_STACKHEIGHT++] = $ss1348613487;
}
if(R.isPyretException($e1348213483)) {
$e1348213483.pyretStack.push(L[1549]);
}
throw $e1348213483;
}
var $ret1348813489 = $Hanf_arg249210303($z1348413485,anf_fun54910305,desugar_DASH_scope_DASH_block9165,l22710306,list3375);
++R.GAS;
return $ret1348813489;
};
},{"length":3});
var desugar_DASH_scope_DASH_visitor22566 = anf_extend54713480.extendWith({"s-block":anf_extend56213481});
var wrap_DASH_env_DASH_imports22985 = {"$var":D,
"$name":"wrap-env-imports"};
var desugar_DASH_scope23067 = {"$var":D,
"$name":"desugar-scope"};
var anf_assign62313371 = R.makeFunction(function(l23110022,expr23210021,env23313412) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[1538],3,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[1547],"A",A231,"Expr"),R.getDotAnn(L[1548],"C",C1035,"CompileEnvironment")],[expr23210021,env23313412],[L[1547],L[1548]],function() {
var cases_DASH_val4013479 = env23313412;
var anf_fun56413423 = G(cases_DASH_val4013479,"_match",L[1539]);
var anf_obj61913427 = R.makeFunction(function(compile_DASH_bindings23410020,type_DASH_env23510023) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1192],2,arguments);
}
var anf_arg58810019 = R.makeFunction(function(lst23710220,b23813439) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1541],2,arguments);
}
var cases_DASH_val3813478 = b23813439;
var anf_fun56713450 = G(cases_DASH_val3813478,"_match",L[1542]);
var anf_obj58413454 = R.makeFunction(function(mname23910237,bindings24013455) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1197],2,arguments);
}
var anf_arg58213466 = R.makeFunction(function(name24110238) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[1206],1,arguments);
}
var anf_fun57010235 = G(A119,"s-let",L[1546]);
var anf_fun57110236 = G(A119,"s-bind",L[1545]);
var anf_fun57213477 = G(A119,"s-name",L[1544]);
var $z1346913470 = D;
var $f1347513476 = function(_) {
return R.isFunction(anf_fun57213477)?anf_fun57213477.app(l23110022,name24110238):R.ffi.throwNonFunApp(L[1543],anf_fun57213477,[l23110022,name24110238]);
};
try {
if(--R.GAS > 0) {
$z1346913470 = $f1347513476();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1347513476,
"from":L[1543]});
}
} catch($e1346713468) {
if(R.isCont($e1346713468)) {
var $ss1347113472 = {"from":L[1543],
"go":function(anf_arg57310234) {
return $Hanf_arg249810233(anf_arg57310234,A119,anf_fun57010235,anf_fun57110236,l23110022,mname23910237,name24110238);
}};
$e1346713468.stack[R.EXN_STACKHEIGHT++] = $ss1347113472;
}
if(R.isPyretException($e1346713468)) {
$e1346713468.pyretStack.push(L[1543]);
}
throw $e1346713468;
}
var $ret1347313474 = $Hanf_arg249810233($z1346913470,A119,anf_fun57010235,anf_fun57110236,l23110022,mname23910237,name24110238);
++R.GAS;
return $ret1347313474;
});
var $z1345813459 = D;
var $f1346413465 = function(_) {
return R.isFunction(map459174)?map459174.app(anf_arg58213466,bindings24013455):R.ffi.throwNonFunApp(L[1206],map459174,[anf_arg58213466,bindings24013455]);
};
try {
if(--R.GAS > 0) {
$z1345813459 = $f1346413465();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1346413465,
"from":L[1206]});
}
} catch($e1345613457) {
if(R.isCont($e1345613457)) {
var $ss1346013461 = {"from":L[1206],
"go":function(anf_arg58310219) {
return $Hanf_arg250010218(anf_arg58310219,lst23710220,_plus9);
}};
$e1345613457.stack[R.EXN_STACKHEIGHT++] = $ss1346013461;
}
if(R.isPyretException($e1345613457)) {
$e1345613457.pyretStack.push(L[1206]);
}
throw $e1345613457;
}
var $ret1346213463 = $Hanf_arg250010218($z1345813459,lst23710220,_plus9);
++R.GAS;
return $ret1346213463;
});
var anf_arg58513451 = R.makeObject({"module-bindings":anf_obj58413454});
var anf_arg58713452 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1542],0,arguments);
}
var ann_DASH_check_DASH_temp58613453 = lst23710220;
return ann_DASH_check_DASH_temp58613453;
});
var $z1344213443 = D;
var $f1344813449 = function(_) {
return R.isFunction(anf_fun56713450)?anf_fun56713450.app(anf_arg58513451,anf_arg58713452):R.ffi.throwNonFunApp(L[1541],anf_fun56713450,[anf_arg58513451,anf_arg58713452]);
};
try {
if(--R.GAS > 0) {
$z1344213443 = $f1344813449();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1344813449,
"from":L[1541]});
}
} catch($e1344013441) {
if(R.isCont($e1344013441)) {
var $ss1344413445 = {"from":L[1541],
"go":function(ann_DASH_check_DASH_temp56610217) {
return $Hann_DASH_check_DASH_temp250110216(ann_DASH_check_DASH_temp56610217);
}};
$e1344013441.stack[R.EXN_STACKHEIGHT++] = $ss1344413445;
}
if(R.isPyretException($e1344013441)) {
$e1344013441.pyretStack.push(L[1541]);
}
throw $e1344013441;
}
var $ret1344613447 = $Hann_DASH_check_DASH_temp250110216($z1344213443);
++R.GAS;
return $ret1344613447;
});
var anf_fun58913438 = G(list3375,"make",L[1540]);
var $z1343013431 = D;
var $f1343613437 = function(_) {
return R.isFunction(anf_fun58913438)?anf_fun58913438.app([]):R.ffi.throwNonFunApp(L[1540],anf_fun58913438,[[]]);
};
try {
if(--R.GAS > 0) {
$z1343013431 = $f1343613437();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1343613437,
"from":L[1540]});
}
} catch($e1342813429) {
if(R.isCont($e1342813429)) {
var $ss1343213433 = {"from":L[1540],
"go":function(anf_arg59010018) {
return $Hanf_arg251610017(anf_arg59010018,A119,anf_arg58810019,compile_DASH_bindings23410020,expr23210021,fold6171,l23110022,list3375,map459174,type_DASH_env23510023,_plus9);
}};
$e1342813429.stack[R.EXN_STACKHEIGHT++] = $ss1343213433;
}
if(R.isPyretException($e1342813429)) {
$e1342813429.pyretStack.push(L[1540]);
}
throw $e1342813429;
}
var $ret1343413435 = $Hanf_arg251610017($z1343013431,A119,anf_arg58810019,compile_DASH_bindings23410020,expr23210021,fold6171,l23110022,list3375,map459174,type_DASH_env23510023,_plus9);
++R.GAS;
return $ret1343413435;
});
var anf_arg62013424 = R.makeObject({"compile-env":anf_obj61913427});
var anf_arg62213425 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1539],0,arguments);
}
var ann_DASH_check_DASH_temp62113426 = R.throwNoBranchesMatched(L[1539],("cases"));
return ann_DASH_check_DASH_temp62113426;
});
var $z1341513416 = D;
var $f1342113422 = function(_) {
return R.isFunction(anf_fun56413423)?anf_fun56413423.app(anf_arg62013424,anf_arg62213425):R.ffi.throwNonFunApp(L[1538],anf_fun56413423,[anf_arg62013424,anf_arg62213425]);
};
try {
if(--R.GAS > 0) {
$z1341513416 = $f1342113422();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1342113422,
"from":L[1538]});
}
} catch($e1341313414) {
if(R.isCont($e1341313414)) {
var $ss1341713418 = {"from":L[1538],
"go":function(ann_DASH_check_DASH_temp56310016) {
return $Hann_DASH_check_DASH_temp251710015(ann_DASH_check_DASH_temp56310016);
}};
$e1341313414.stack[R.EXN_STACKHEIGHT++] = $ss1341713418;
}
if(R.isPyretException($e1341313414)) {
$e1341313414.pyretStack.push(L[1538]);
}
throw $e1341313414;
}
var $ret1341913420 = $Hann_DASH_check_DASH_temp251710015($z1341513416);
++R.GAS;
return $ret1341913420;
});
});
wrap_DASH_env_DASH_imports22985.$var = anf_assign62313371;
var anf_assign75113372 = R.makeFunction(function(prog24913384,compile_DASH_env2509172) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[80],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[1536],"A",A231,"Program"),R.getDotAnn(L[1537],"C",C1035,"CompileEnvironment")],[prog24913384,compile_DASH_env2509172],[L[1536],L[1537]],function() {
var cases_DASH_val4813411 = prog24913384;
var anf_fun62513395 = G(cases_DASH_val4813411,"_match",L[1534]);
var anf_obj74713399 = R.makeFunction(function(l2519173,_provide_DASH_raw2529170,provide_DASH_types_DASH_raw2539175,imports_DASH_raw25413400,body2559171) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[1130],5,arguments);
}
var $z1340313404 = D;
var $f1340913410 = function(_) {
return R.isFunction(resolve_DASH_imports8980.$var)?resolve_DASH_imports8980.$var.app(imports_DASH_raw25413400):R.ffi.throwNonFunApp(L[1535],resolve_DASH_imports8980.$var,[imports_DASH_raw25413400]);
};
try {
if(--R.GAS > 0) {
$z1340313404 = $f1340913410();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1340913410,
"from":L[1535]});
}
} catch($e1340113402) {
if(R.isCont($e1340113402)) {
var $ss1340513406 = {"from":L[1535],
"go":function(imports_DASH_and_DASH_lets2569169) {
return $Himports_DASH_and_DASH_lets25809168(imports_DASH_and_DASH_lets2569169,A119,C923,U1124,_provide_DASH_raw2529170,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16);
}};
$e1340113402.stack[R.EXN_STACKHEIGHT++] = $ss1340513406;
}
if(R.isPyretException($e1340113402)) {
$e1340113402.pyretStack.push(L[1535]);
}
throw $e1340113402;
}
var $ret1340713408 = $Himports_DASH_and_DASH_lets25809168($z1340313404,A119,C923,U1124,_provide_DASH_raw2529170,body2559171,compile_DASH_env2509172,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_toplevel_DASH_types9068,empty3670,l2519173,list3375,map459174,provide_DASH_types_DASH_raw2539175,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,wrap_DASH_env_DASH_imports22985,_minus8,_plus9,raise14,torepr16);
++R.GAS;
return $ret1340713408;
});
var anf_arg74813396 = R.makeObject({"s-program":anf_obj74713399});
var anf_arg75013397 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[1534],0,arguments);
}
var ann_DASH_check_DASH_temp74913398 = R.throwNoBranchesMatched(L[1534],("cases"));
return ann_DASH_check_DASH_temp74913398;
});
var $z1338713388 = D;
var $f1339313394 = function(_) {
return R.isFunction(anf_fun62513395)?anf_fun62513395.app(anf_arg74813396,anf_arg75013397):R.ffi.throwNonFunApp(L[80],anf_fun62513395,[anf_arg74813396,anf_arg75013397]);
};
try {
if(--R.GAS > 0) {
$z1338713388 = $f1339313394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1339313394,
"from":L[80]});
}
} catch($e1338513386) {
if(R.isCont($e1338513386)) {
var $ss1338913390 = {"from":L[80],
"go":function(ann_DASH_check_DASH_temp6249167) {
return $Hann_DASH_check_DASH_temp25819166(ann_DASH_check_DASH_temp6249167);
}};
$e1338513386.stack[R.EXN_STACKHEIGHT++] = $ss1338913390;
}
if(R.isPyretException($e1338513386)) {
$e1338513386.pyretStack.push(L[80]);
}
throw $e1338513386;
}
var $ret1339113392 = $Hann_DASH_check_DASH_temp25819166($z1338713388);
++R.GAS;
return $ret1339113392;
});
});
desugar_DASH_scope23067.$var = anf_assign75113372;
var anf_fun75213383 = G(A119,"MakeName",L[1533]);
var $z1337513376 = D;
var $f1338113382 = function(_) {
return R.isFunction(anf_fun75213383)?anf_fun75213383.app((0)):R.ffi.throwNonFunApp(L[1532],anf_fun75213383,[(0)]);
};
try {
if(--R.GAS > 0) {
$z1337513376 = $f1338113382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f1338113382,
"from":L[1532]});
}
} catch($e1337313374) {
if(R.isCont($e1337313374)) {
var $ss1337713378 = {"from":L[1532],
"go":function(names28657) {
return $Hnames323856(names28657,A119,A231,C1035,C923,NameResolution7458,NameResolution8159,Option2660,PP521,S320,SD722,ScopeBinding7661,ScopeBindingT37762,TypeBinding7863,TypeBindingT47964,U1124,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,each25469,empty3670,fold6171,is_DASH_NameResolution8272,is_DASH_resolved8373,link3774,list3375,map24676,mk_DASH_bind8577,mk_DASH_id8678,none6979,resolve_DASH_imports8980,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,some7084,wrap_DASH_env_DASH_imports22985,_plus9,builtins10,not11,nothing12,print13,raise14,torepr16);
}};
$e1337313374.stack[R.EXN_STACKHEIGHT++] = $ss1337713378;
}
if(R.isPyretException($e1337313374)) {
$e1337313374.pyretStack.push(L[1532]);
}
throw $e1337313374;
}
var $ret1337913380 = $Hnames323856($z1337513376,A119,A231,C1035,C923,NameResolution7458,NameResolution8159,Option2660,PP521,S320,SD722,ScopeBinding7661,ScopeBindingT37762,TypeBinding7863,TypeBindingT47964,U1124,desugar_DASH_scope_DASH_block9165,desugar_DASH_scope_DASH_visitor22566,desugar_DASH_scope23067,desugar_DASH_toplevel_DASH_types9068,each25469,empty3670,fold6171,is_DASH_NameResolution8272,is_DASH_resolved8373,link3774,list3375,map24676,mk_DASH_bind8577,mk_DASH_id8678,none6979,resolve_DASH_imports8980,resolve_DASH_provide8781,resolve_DASH_type_DASH_provide8882,resolved8483,some7084,wrap_DASH_env_DASH_imports22985,_plus9,builtins10,not11,nothing12,print13,raise14,torepr16);
++R.GAS;
return $ret1337913380;
},function(moduleVal) {
R.modules["$src/arr/compiler/resolve-scope.arr43"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/compile.arr',["trove/file",
"trove/ast",
"trove/parse-pyret",
"compiler/js-of-pyret.arr",
"compiler/compile-structs.arr",
"compiler/well-formed.arr",
"compiler/ast-util.arr",
"compiler/resolve-scope.arr",
"compiler/desugar.arr",
"compiler/desugar-check.arr",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($F1839,$A3940,$PP51041,$P71142,$C91243,$W111344,$U131445,$R151546,$D171647,$CH191748,$arrays211849,$lists231950,$option252051,$error272152,$sets292253) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/compile.arr38"]) {
return R.modules["$src/arr/compiler/compile.arr38"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/compile.arr";
var D = R.undefined;
var L = [[M,16,0,373,28,3,711],
[M,97,0,3893,103,3,4206],
[M,99,2,4088,102,5,4202],
[M,101,4,4178,101,22,4196],
[M,100,4,4124,100,53,4173],
[M,100,23,4143,100,52,4172],
[M,100,23,4143,100,50,4170],
[M,100,18,4138,100,22,4142],
[M,98,11,3990,98,106,4085],
[M,94,2,3827,94,23,3848],
[M,92,0,3678,95,3,3891],
[M,87,0,3467,90,3,3676],
[M,83,0,3224,85,3,3465],
[M,84,2,3334,84,127,3459],
[M,84,2,3334,84,106,3438],
[M,79,41,3121,79,76,3156],
[M,79,2,3082,79,90,3170],
[M,79,7,3087,79,26,3106],
[M,75,0,2890,81,3,3222],
[M,79,35,3115,79,86,3166],
[M,34,4,887,34,84,967],
[M,33,2,857,35,5,973],
[M,33,7,862,33,26,881],
[M,36,27,1001,36,49,1023],
[M,36,27,1001,36,44,1018],
[M,36,7,981,36,26,1000],
[M,34,36,919,34,80,963],
[M,34,59,942,34,74,957],
[M,34,9,892,34,27,910],
[M,36,2,976,36,50,1024],
[M,37,35,1060,37,76,1101],
[M,37,2,1027,37,80,1105],
[M,37,7,1032,37,26,1051],
[M,38,35,1141,38,51,1157],
[M,38,58,1164,38,78,1184],
[M,38,15,1121,38,33,1139],
[M,30,0,713,73,3,2888],
[M,39,2,1188,72,5,2884],
[M,71,4,2842,71,40,2878],
[M,40,4,1219,70,9,2837],
[M,41,6,1241,41,31,1266],
[M,43,44,1343,43,69,1368],
[M,43,76,1375,43,105,1404],
[M,43,24,1323,43,42,1341],
[M,43,15,1314,44,23,1433],
[M,42,6,1273,45,9,1443],
[M,42,11,1278,42,30,1297],
[M,46,6,1450,46,45,1489],
[M,46,15,1459,46,30,1474],
[M,47,39,1529,47,76,1566],
[M,47,6,1496,47,80,1570],
[M,47,11,1501,47,30,1520],
[M,48,6,1577,48,50,1621],
[M,48,21,1592,48,36,1607],
[M,49,39,1661,49,81,1703],
[M,49,6,1628,49,85,1707],
[M,49,11,1633,49,30,1652],
[M,52,6,1790,52,44,1828],
[M,52,18,1802,52,27,1811],
[M,51,21,1764,51,40,1783],
[M,50,18,1726,50,34,1742],
[M,53,39,1868,53,79,1908],
[M,53,6,1835,53,83,1912],
[M,53,11,1840,53,30,1859],
[M,54,16,1929,54,54,1967],
[M,54,32,1945,54,53,1966],
[M,54,16,1929,54,31,1944],
[M,54,16,1929,55,52,2020],
[M,55,28,1996,55,51,2019],
[M,54,16,1929,55,27,1995],
[M,56,28,2049,56,53,2074],
[M,56,28,2049,56,47,2068],
[M,54,16,1929,56,27,2048],
[M,54,16,1929,56,54,2075],
[M,54,6,1919,57,45,2121],
[M,57,28,2104,57,44,2120],
[M,54,16,1929,57,27,2103],
[M,58,39,2161,58,73,2195],
[M,58,6,2128,58,77,2199],
[M,58,11,2133,58,30,2152],
[M,59,6,2206,59,44,2244],
[M,59,30,2230,59,43,2243],
[M,59,16,2216,59,29,2229],
[M,60,39,2284,60,77,2322],
[M,60,6,2251,60,81,2326],
[M,60,11,2256,60,30,2275],
[M,61,34,2361,61,64,2391],
[M,61,34,2361,61,49,2376],
[M,61,19,2346,61,99,2426],
[M,61,67,2394,61,99,2426],
[M,61,67,2394,61,84,2411],
[M,61,6,2333,61,99,2426],
[M,62,9,2436,62,29,2456],
[M,63,32,2490,63,86,2544],
[M,63,32,2490,63,59,2517],
[M,64,35,2580,64,71,2616],
[M,64,35,2580,64,56,2601],
[M,64,30,2575,64,34,2579],
[M,63,11,2469,63,30,2488],
[M,67,11,2659,67,58,2706],
[M,67,35,2683,67,57,2705],
[M,67,11,2659,67,30,2678],
[M,67,59,2707,67,113,2761],
[M,67,59,2707,67,86,2734],
[M,68,30,2792,68,47,2809],
[M,68,30,2792,68,35,2797],
[M,64,30,2575,64,72,2617],
[M,64,14,2559,64,78,2623],
[M,68,14,2776,68,53,2815],
[M,18,2,408,18,66,472],
[M,17,2,398,17,9,405],
[M,22,30,558,22,33,561],
[M,23,86,648,23,98,660],
[M,23,66,628,23,82,644],
[M,23,41,603,23,55,617],
[M,23,17,579,23,31,593],
[M,22,9,537,22,28,556],
[M,23,12,574,23,99,661],
[M,3,0,13,103,3,4206],
[M,98,11,3990,98,99,4078],
[M,93,2,3792,93,34,3824],
[M,93,9,3799,93,25,3815],
[M,88,2,3579,88,34,3611],
[M,88,9,3586,88,25,3602],
[M,84,2,3334,84,99,3431],
[M,78,2,3036,78,45,3079],
[M,78,8,3042,78,24,3058],
[M,32,2,808,32,48,854],
[M,32,14,820,32,43,849],
[M,18,4,410,18,66,472],
[M,18,18,424,18,24,430],
[M,18,49,455,18,65,471],
[M,18,41,447,18,65,471],
[M,18,26,432,18,39,445],
[M,18,10,416,18,24,430],
[M,20,2,484,27,5,707],
[M,21,4,502,25,7,679],
[M,22,9,537,22,17,545]];
var _plus3 = NAMESPACE.get("_plus");
var builtins4 = NAMESPACE.get("builtins");
var nothing5 = NAMESPACE.get("nothing");
var torepr6 = NAMESPACE.get("torepr");
var $type$String7 = NAMESPACE.get("$type$String");
var $Hanf_bracket37054 = function(anf_bracket27155,CompilationPhase8056,provides26957,nothing5) {
var anf_fun27268 = G(anf_bracket27155,"results",L[0]);
var $z6061 = D;
var $f6667 = function(_) {
return R.isFunction(anf_fun27268)?anf_fun27268.app():R.ffi.throwNonFunApp(L[0],anf_fun27268,[]);
};
try {
if(--R.GAS > 0) {
$z6061 = $f6667();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6667,
"from":L[0]});
}
} catch($e5859) {
if(R.isCont($e5859)) {
var $ss6263 = {"from":L[0],
"go":function(checks27369) {
return $Hchecks36970(checks27369,CompilationPhase8056,provides26957,nothing5);
}};
$e5859.stack[R.EXN_STACKHEIGHT++] = $ss6263;
}
if(R.isPyretException($e5859)) {
$e5859.pyretStack.push(L[0]);
}
throw $e5859;
}
var $ret6465 = $Hchecks36970($z6061,CompilationPhase8056,provides26957,nothing5);
++R.GAS;
return $ret6465;
};
var $Hchecks36970 = function(checks27369,CompilationPhase8056,provides26957,nothing5) {
return R.makeObject({"answer":nothing5,
"provide-plus-types":R.makeObject({"values":provides26957,
"types":{"CompilationPhase":CompilationPhase8056}}),
"checks":checks27369});
};
var $Hanf_bracket36871 = function(anf_bracket25672,C1027,C912,$type$String7) {
var result14993 = G(anf_bracket25672,"result",L[8]);
var cases_DASH_val33109 = result14993;
var anf_fun25783 = G(cases_DASH_val33109,"_match",L[2]);
var anf_obj26289 = R.makeFunction(function(comp15094) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[4],1,arguments);
}
var anf_fun259107 = G(C912,"ok",L[7]);
var anf_fun260105 = G(comp15094,"pyret-to-js-standalone",L[6]);
var $z9798 = D;
var $f103104 = function(_) {
return R.isFunction(anf_fun260105)?anf_fun260105.app():R.ffi.throwNonFunApp(L[5],anf_fun260105,[]);
};
try {
if(--R.GAS > 0) {
$z9798 = $f103104();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f103104,
"from":L[5]});
}
} catch($e9596) {
if(R.isCont($e9596)) {
var $ss99100 = {"from":L[5],
"go":function(anf_arg261106) {
return $Hanf_arg366108(anf_arg261106,anf_fun259107);
}};
$e9596.stack[R.EXN_STACKHEIGHT++] = $ss99100;
}
if(R.isPyretException($e9596)) {
$e9596.pyretStack.push(L[5]);
}
throw $e9596;
}
var $ret101102 = $Hanf_arg366108($z9798,anf_fun259107);
++R.GAS;
return $ret101102;
});
var anf_obj26490 = R.makeFunction(function($underscore15191) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[3],1,arguments);
}
var ann_DASH_check_DASH_temp26392 = result14993;
return ann_DASH_check_DASH_temp26392;
});
var anf_arg26584 = R.makeObject({"ok":anf_obj26289,
"err":anf_obj26490});
var anf_arg26785 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2],0,arguments);
}
var ann_DASH_check_DASH_temp26688 = R.throwNoBranchesMatched(L[2],("cases"));
return ann_DASH_check_DASH_temp26688;
});
var $z7576 = D;
var $f8182 = function(_) {
return R.isFunction(anf_fun25783)?anf_fun25783.app(anf_arg26584,anf_arg26785):R.ffi.throwNonFunApp(L[1],anf_fun25783,[anf_arg26584,anf_arg26785]);
};
try {
if(--R.GAS > 0) {
$z7576 = $f8182();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f8182,
"from":L[1]});
}
} catch($e7374) {
if(R.isCont($e7374)) {
var $ss7778 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp25486) {
return $Hann_DASH_check_DASH_temp36787(ann_DASH_check_DASH_temp25486,C1027,$type$String7);
}};
$e7374.stack[R.EXN_STACKHEIGHT++] = $ss7778;
}
if(R.isPyretException($e7374)) {
$e7374.pyretStack.push(L[1]);
}
throw $e7374;
}
var $ret7980 = $Hann_DASH_check_DASH_temp36787($z7576,C1027,$type$String7);
++R.GAS;
return $ret7980;
};
var $Hann_DASH_check_DASH_temp36787 = function(ann_DASH_check_DASH_temp25486,C1027,$type$String7) {
return ann_DASH_check_DASH_temp25486;
};
var $Hanf_arg366108 = function(anf_arg261106,anf_fun259107) {
var $z112113 = D;
var $f118119 = function(_) {
return R.isFunction(anf_fun259107)?anf_fun259107.app(anf_arg261106):R.ffi.throwNonFunApp(L[4],anf_fun259107,[anf_arg261106]);
};
try {
if(--R.GAS > 0) {
$z112113 = $f118119();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f118119,
"from":L[4]});
}
} catch($e110111) {
if(R.isCont($e110111)) {
var $ss114115 = {"from":L[4],
"go":function(ann_DASH_check_DASH_temp258120) {
return $Hann_DASH_check_DASH_temp365121(ann_DASH_check_DASH_temp258120);
}};
$e110111.stack[R.EXN_STACKHEIGHT++] = $ss114115;
}
if(R.isPyretException($e110111)) {
$e110111.pyretStack.push(L[4]);
}
throw $e110111;
}
var $ret116117 = $Hann_DASH_check_DASH_temp365121($z112113);
++R.GAS;
return $ret116117;
};
var $Hann_DASH_check_DASH_temp365121 = function(ann_DASH_check_DASH_temp258120) {
return ann_DASH_check_DASH_temp258120;
};
var $Hcode364122 = function(code144123,C1027,P826,compile_DASH_standalone_DASH_js94124,dialect140125,js_DASH_file141126,libs142127,options143128) {
var $z131132 = D;
var $f137138 = function(_) {
return R.isFunction(compile_DASH_standalone_DASH_js94124.$var === D?U(L[9],"compile-standalone-js"):compile_DASH_standalone_DASH_js94124.$var)?compile_DASH_standalone_DASH_js94124.$var === D?U(L[9],"compile-standalone-js"):compile_DASH_standalone_DASH_js94124.$var.app(dialect140125,code144123,js_DASH_file141126,libs142127,options143128):R.ffi.throwNonFunApp(L[10],compile_DASH_standalone_DASH_js94124.$var === D?U(L[9],"compile-standalone-js"):compile_DASH_standalone_DASH_js94124.$var,[dialect140125,code144123,js_DASH_file141126,libs142127,options143128]);
};
try {
if(--R.GAS > 0) {
$z131132 = $f137138();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f137138,
"from":L[10]});
}
} catch($e129130) {
if(R.isCont($e129130)) {
var $ss133134 = {"from":L[10],
"go":function(ann_DASH_check_DASH_temp251139) {
return $Hann_DASH_check_DASH_temp363140(ann_DASH_check_DASH_temp251139,C1027,P826);
}};
$e129130.stack[R.EXN_STACKHEIGHT++] = $ss133134;
}
if(R.isPyretException($e129130)) {
$e129130.pyretStack.push(L[10]);
}
throw $e129130;
}
var $ret135136 = $Hann_DASH_check_DASH_temp363140($z131132,C1027,P826);
++R.GAS;
return $ret135136;
};
var $Hann_DASH_check_DASH_temp363140 = function(ann_DASH_check_DASH_temp251139,C1027,P826) {
return ann_DASH_check_DASH_temp251139;
};
var $Hcode362141 = function(code139142,C1027,P826,compile_DASH_runnable_DASH_js91143,dialect135144,js_DASH_file136145,libs137146,options138147) {
var $z150151 = D;
var $f156157 = function(_) {
return R.isFunction(compile_DASH_runnable_DASH_js91143.$var)?compile_DASH_runnable_DASH_js91143.$var.app(dialect135144,code139142,js_DASH_file136145,libs137146,options138147):R.ffi.throwNonFunApp(L[11],compile_DASH_runnable_DASH_js91143.$var,[dialect135144,code139142,js_DASH_file136145,libs137146,options138147]);
};
try {
if(--R.GAS > 0) {
$z150151 = $f156157();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f156157,
"from":L[11]});
}
} catch($e148149) {
if(R.isCont($e148149)) {
var $ss152153 = {"from":L[11],
"go":function(ann_DASH_check_DASH_temp248158) {
return $Hann_DASH_check_DASH_temp361159(ann_DASH_check_DASH_temp248158,C1027,P826);
}};
$e148149.stack[R.EXN_STACKHEIGHT++] = $ss152153;
}
if(R.isPyretException($e148149)) {
$e148149.pyretStack.push(L[11]);
}
throw $e148149;
}
var $ret154155 = $Hann_DASH_check_DASH_temp361159($z150151,C1027,P826);
++R.GAS;
return $ret154155;
};
var $Hann_DASH_check_DASH_temp361159 = function(ann_DASH_check_DASH_temp248158,C1027,P826) {
return ann_DASH_check_DASH_temp248158;
};
var $Hanf_bracket360160 = function(anf_bracket244161,C1027,P826) {
var anf_bracket245175 = G(anf_bracket244161,"result",L[14]);
var anf_fun246172 = G(anf_bracket245175,"pyret-to-js-runnable",L[13]);
var $z164165 = D;
var $f170171 = function(_) {
return R.isFunction(anf_fun246172)?anf_fun246172.app():R.ffi.throwNonFunApp(L[12],anf_fun246172,[]);
};
try {
if(--R.GAS > 0) {
$z164165 = $f170171();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f170171,
"from":L[12]});
}
} catch($e162163) {
if(R.isCont($e162163)) {
var $ss166167 = {"from":L[12],
"go":function(ann_DASH_check_DASH_temp242173) {
return $Hann_DASH_check_DASH_temp359174(ann_DASH_check_DASH_temp242173,C1027,P826);
}};
$e162163.stack[R.EXN_STACKHEIGHT++] = $ss166167;
}
if(R.isPyretException($e162163)) {
$e162163.pyretStack.push(L[12]);
}
throw $e162163;
}
var $ret168169 = $Hann_DASH_check_DASH_temp359174($z164165,C1027,P826);
++R.GAS;
return $ret168169;
};
var $Hann_DASH_check_DASH_temp359174 = function(ann_DASH_check_DASH_temp242173,C1027,P826) {
return ann_DASH_check_DASH_temp242173;
};
var $Hast358176 = function(ast129177,C1027,CompilationPhase8056,P826,compile_DASH_js_DASH_ast89178,dialect123179,libs126180,name125181,options127182,phase88183,ret128184,_plus3,nothing5) {
var when_DASH_32210 = G(options127182,"collect-all",L[17]);
var if_helper231196 = R.makeFunction(function(if_helper_arg232216) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[16],1,arguments);
}
if_helper_arg232216;
var $z219220 = D;
var $f225226 = function(_) {
return R.isFunction(compile_DASH_js_DASH_ast89178.$var)?compile_DASH_js_DASH_ast89178.$var.app(ret128184.$var,ast129177,name125181,libs126180,options127182):R.ffi.throwNonFunApp(L[18],compile_DASH_js_DASH_ast89178.$var,[ret128184.$var,ast129177,name125181,libs126180,options127182]);
};
try {
if(--R.GAS > 0) {
$z219220 = $f225226();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f225226,
"from":L[18]});
}
} catch($e217218) {
if(R.isCont($e217218)) {
var $ss221222 = {"from":L[18],
"go":function(ann_DASH_check_DASH_temp229227) {
return $Hann_DASH_check_DASH_temp352228(ann_DASH_check_DASH_temp229227,C1027,CompilationPhase8056,P826);
}};
$e217218.stack[R.EXN_STACKHEIGHT++] = $ss221222;
}
if(R.isPyretException($e217218)) {
$e217218.pyretStack.push(L[18]);
}
throw $e217218;
}
var $ret223224 = $Hann_DASH_check_DASH_temp352228($z219220,C1027,CompilationPhase8056,P826);
++R.GAS;
return $ret223224;
});
var anf_if235215 = R.isBoolean(when_DASH_32210);
if(R.isPyretTrue(anf_if235215)) {
if(R.isPyretTrue(when_DASH_32210)) {
var $z187188 = D;
var $f193194 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("Parsed ("),dialect123179):R.ffi.throwNonFunApp(L[15],_plus3,[("Parsed ("),dialect123179]);
};
try {
if(--R.GAS > 0) {
$z187188 = $f193194();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f193194,
"from":L[15]});
}
} catch($e185186) {
if(R.isCont($e185186)) {
var $ss189190 = {"from":L[15],
"go":function(anf_arg237195) {
return $Hanf_arg356197(anf_arg237195,ast129177,if_helper231196,phase88183,ret128184,_plus3,nothing5);
}};
$e185186.stack[R.EXN_STACKHEIGHT++] = $ss189190;
}
if(R.isPyretException($e185186)) {
$e185186.pyretStack.push(L[15]);
}
throw $e185186;
}
var $ret191192 = $Hanf_arg356197($z187188,ast129177,if_helper231196,phase88183,ret128184,_plus3,nothing5);
++R.GAS;
return $ret191192;
} else {
var $z200201 = D;
var $f206207 = function(_) {
return R.isFunction(if_helper231196)?if_helper231196.app(nothing5):R.ffi.throwNonFunApp(L[16],if_helper231196,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z200201 = $f206207();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f206207,
"from":L[16]});
}
} catch($e198199) {
if(R.isCont($e198199)) {
var $ss202203 = {"from":L[16],
"go":function(cont_tail_app236208) {
return $Hcont_tail_app357209(cont_tail_app236208);
}};
$e198199.stack[R.EXN_STACKHEIGHT++] = $ss202203;
}
if(R.isPyretException($e198199)) {
$e198199.pyretStack.push(L[16]);
}
throw $e198199;
}
var $ret204205 = $Hcont_tail_app357209($z200201);
++R.GAS;
return $ret204205;
}
} else {
var cont_tail_arg233213 = R.throwNonBooleanCondition(L[17],("when"),when_DASH_32210);
if(--R.GAS > 0) {
$z211212 = R.isFunction(if_helper231196)?if_helper231196.app(cont_tail_arg233213):R.ffi.throwNonFunApp(L[17],if_helper231196,[cont_tail_arg233213]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper231196)?if_helper231196.app(cont_tail_arg233213):R.ffi.throwNonFunApp(L[17],if_helper231196,[cont_tail_arg233213]);
},
"from":L[17]});
}
++R.GAS;
return $z211212;
}
};
var $Hanf_arg356197 = function(anf_arg237195,ast129177,if_helper231196,phase88183,ret128184,_plus3,nothing5) {
var $z231232 = D;
var $f237238 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg237195,(" dialect)")):R.ffi.throwNonFunApp(L[15],_plus3,[anf_arg237195,(" dialect)")]);
};
try {
if(--R.GAS > 0) {
$z231232 = $f237238();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f237238,
"from":L[15]});
}
} catch($e229230) {
if(R.isCont($e229230)) {
var $ss233234 = {"from":L[15],
"go":function(anf_arg238239) {
return $Hanf_arg355240(anf_arg238239,ast129177,if_helper231196,phase88183,ret128184,nothing5);
}};
$e229230.stack[R.EXN_STACKHEIGHT++] = $ss233234;
}
if(R.isPyretException($e229230)) {
$e229230.pyretStack.push(L[15]);
}
throw $e229230;
}
var $ret235236 = $Hanf_arg355240($z231232,ast129177,if_helper231196,phase88183,ret128184,nothing5);
++R.GAS;
return $ret235236;
};
var $Hanf_arg355240 = function(anf_arg238239,ast129177,if_helper231196,phase88183,ret128184,nothing5) {
var $z243244 = D;
var $f249250 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(anf_arg238239,ast129177,ret128184.$var):R.ffi.throwNonFunApp(L[19],phase88183.$var,[anf_arg238239,ast129177,ret128184.$var]);
};
try {
if(--R.GAS > 0) {
$z243244 = $f249250();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f249250,
"from":L[19]});
}
} catch($e241242) {
if(R.isCont($e241242)) {
var $ss245246 = {"from":L[19],
"go":function(anf_assign239251) {
return $Hanf_assign354252(anf_assign239251,if_helper231196,ret128184,nothing5);
}};
$e241242.stack[R.EXN_STACKHEIGHT++] = $ss245246;
}
if(R.isPyretException($e241242)) {
$e241242.pyretStack.push(L[19]);
}
throw $e241242;
}
var $ret247248 = $Hanf_assign354252($z243244,if_helper231196,ret128184,nothing5);
++R.GAS;
return $ret247248;
};
var $Hanf_assign354252 = function(anf_assign239251,if_helper231196,ret128184,nothing5) {
ret128184.$var = anf_assign239251;
var $z255256 = D;
var $f261262 = function(_) {
return R.isFunction(if_helper231196)?if_helper231196.app(nothing5):R.ffi.throwNonFunApp(L[16],if_helper231196,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z255256 = $f261262();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f261262,
"from":L[16]});
}
} catch($e253254) {
if(R.isCont($e253254)) {
var $ss257258 = {"from":L[16],
"go":function(cont_tail_app240263) {
return $Hcont_tail_app353264(cont_tail_app240263);
}};
$e253254.stack[R.EXN_STACKHEIGHT++] = $ss257258;
}
if(R.isPyretException($e253254)) {
$e253254.pyretStack.push(L[16]);
}
throw $e253254;
}
var $ret259260 = $Hcont_tail_app353264($z255256);
++R.GAS;
return $ret259260;
};
var $Hcont_tail_app353264 = function(cont_tail_app240263) {
return cont_tail_app240263;
};
var $Hcont_tail_app357209 = function(cont_tail_app236208) {
return cont_tail_app236208;
};
var $Hann_DASH_check_DASH_temp352228 = function(ann_DASH_check_DASH_temp229227,C1027,CompilationPhase8056,P826) {
return ann_DASH_check_DASH_temp229227;
};
var $Hast_DASH_ended351265 = function(ast_DASH_ended108266,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,W1113,ast103267,is_DASH_empty40268,is_DASH_some74269,libs105270,options106271,phase88183,ret107272,_plus3,nothing5) {
var when_DASH_15298 = G(options106271,"collect-all",L[22]);
var if_helper70284 = R.makeFunction(function(if_helper_arg71303) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[21],1,arguments);
}
if_helper_arg71303;
var anf_fun72316 = G(W1113,"check-well-formed",L[25]);
var anf_fun73314 = G(ast_DASH_ended108266,"or-else",L[24]);
var $z306307 = D;
var $f312313 = function(_) {
return R.isFunction(anf_fun73314)?anf_fun73314.app(ast103267):R.ffi.throwNonFunApp(L[23],anf_fun73314,[ast103267]);
};
try {
if(--R.GAS > 0) {
$z306307 = $f312313();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f312313,
"from":L[23]});
}
} catch($e304305) {
if(R.isCont($e304305)) {
var $ss308309 = {"from":L[23],
"go":function(anf_arg74315) {
return $Hanf_arg344317(anf_arg74315,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,anf_fun72316,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e304305.stack[R.EXN_STACKHEIGHT++] = $ss308309;
}
if(R.isPyretException($e304305)) {
$e304305.pyretStack.push(L[23]);
}
throw $e304305;
}
var $ret310311 = $Hanf_arg344317($z306307,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,anf_fun72316,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret310311;
});
var anf_if216302 = R.isBoolean(when_DASH_15298);
if(R.isPyretTrue(anf_if216302)) {
if(R.isPyretTrue(when_DASH_15298)) {
var $z275276 = D;
var $f281282 = function(_) {
return R.isFunction(is_DASH_some74269)?is_DASH_some74269.app(ast_DASH_ended108266):R.ffi.throwNonFunApp(L[20],is_DASH_some74269,[ast_DASH_ended108266]);
};
try {
if(--R.GAS > 0) {
$z275276 = $f281282();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f281282,
"from":L[20]});
}
} catch($e273274) {
if(R.isCont($e273274)) {
var $ss277278 = {"from":L[20],
"go":function(when_DASH_16283) {
return $Hwhen_DASH_349285(when_DASH_16283,ast_DASH_ended108266,if_helper70284,phase88183,ret107272,nothing5);
}};
$e273274.stack[R.EXN_STACKHEIGHT++] = $ss277278;
}
if(R.isPyretException($e273274)) {
$e273274.pyretStack.push(L[20]);
}
throw $e273274;
}
var $ret279280 = $Hwhen_DASH_349285($z275276,ast_DASH_ended108266,if_helper70284,phase88183,ret107272,nothing5);
++R.GAS;
return $ret279280;
} else {
var $z288289 = D;
var $f294295 = function(_) {
return R.isFunction(if_helper70284)?if_helper70284.app(nothing5):R.ffi.throwNonFunApp(L[21],if_helper70284,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z288289 = $f294295();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f294295,
"from":L[21]});
}
} catch($e286287) {
if(R.isCont($e286287)) {
var $ss290291 = {"from":L[21],
"go":function(cont_tail_app217296) {
return $Hcont_tail_app350297(cont_tail_app217296);
}};
$e286287.stack[R.EXN_STACKHEIGHT++] = $ss290291;
}
if(R.isPyretException($e286287)) {
$e286287.pyretStack.push(L[21]);
}
throw $e286287;
}
var $ret292293 = $Hcont_tail_app350297($z288289);
++R.GAS;
return $ret292293;
}
} else {
var cont_tail_arg214301 = R.throwNonBooleanCondition(L[22],("when"),when_DASH_15298);
if(--R.GAS > 0) {
$z299300 = R.isFunction(if_helper70284)?if_helper70284.app(cont_tail_arg214301):R.ffi.throwNonFunApp(L[22],if_helper70284,[cont_tail_arg214301]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper70284)?if_helper70284.app(cont_tail_arg214301):R.ffi.throwNonFunApp(L[22],if_helper70284,[cont_tail_arg214301]);
},
"from":L[22]});
}
++R.GAS;
return $z299300;
}
};
var $Hwhen_DASH_349285 = function(when_DASH_16283,ast_DASH_ended108266,if_helper70284,phase88183,ret107272,nothing5) {
var if_helper218330 = R.makeFunction(function(if_helper_arg219348) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[20],1,arguments);
}
if_helper_arg219348;
var $z351352 = D;
var $f357358 = function(_) {
return R.isFunction(if_helper70284)?if_helper70284.app(nothing5):R.ffi.throwNonFunApp(L[21],if_helper70284,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z351352 = $f357358();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f357358,
"from":L[21]});
}
} catch($e349350) {
if(R.isCont($e349350)) {
var $ss353354 = {"from":L[21],
"go":function(cont_tail_app220359) {
return $Hcont_tail_app345360(cont_tail_app220359);
}};
$e349350.stack[R.EXN_STACKHEIGHT++] = $ss353354;
}
if(R.isPyretException($e349350)) {
$e349350.pyretStack.push(L[21]);
}
throw $e349350;
}
var $ret355356 = $Hcont_tail_app345360($z351352);
++R.GAS;
return $ret355356;
});
var anf_if223347 = R.isBoolean(when_DASH_16283);
if(R.isPyretTrue(anf_if223347)) {
if(R.isPyretTrue(when_DASH_16283)) {
var anf_arg225328 = G(ast_DASH_ended108266,"value",L[27]);
var $z320321 = D;
var $f326327 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Added nothing"),anf_arg225328,ret107272.$var):R.ffi.throwNonFunApp(L[26],phase88183.$var,[("Added nothing"),anf_arg225328,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z320321 = $f326327();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f326327,
"from":L[26]});
}
} catch($e318319) {
if(R.isCont($e318319)) {
var $ss322323 = {"from":L[26],
"go":function(anf_assign226329) {
return $Hanf_assign347331(anf_assign226329,if_helper218330,ret107272,nothing5);
}};
$e318319.stack[R.EXN_STACKHEIGHT++] = $ss322323;
}
if(R.isPyretException($e318319)) {
$e318319.pyretStack.push(L[26]);
}
throw $e318319;
}
var $ret324325 = $Hanf_assign347331($z320321,if_helper218330,ret107272,nothing5);
++R.GAS;
return $ret324325;
} else {
var $z334335 = D;
var $f340341 = function(_) {
return R.isFunction(if_helper218330)?if_helper218330.app(nothing5):R.ffi.throwNonFunApp(L[20],if_helper218330,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z334335 = $f340341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f340341,
"from":L[20]});
}
} catch($e332333) {
if(R.isCont($e332333)) {
var $ss336337 = {"from":L[20],
"go":function(cont_tail_app224342) {
return $Hcont_tail_app348343(cont_tail_app224342);
}};
$e332333.stack[R.EXN_STACKHEIGHT++] = $ss336337;
}
if(R.isPyretException($e332333)) {
$e332333.pyretStack.push(L[20]);
}
throw $e332333;
}
var $ret338339 = $Hcont_tail_app348343($z334335);
++R.GAS;
return $ret338339;
}
} else {
var cont_tail_arg221346 = R.throwNonBooleanCondition(L[28],("when"),when_DASH_16283);
if(--R.GAS > 0) {
$z344345 = R.isFunction(if_helper218330)?if_helper218330.app(cont_tail_arg221346):R.ffi.throwNonFunApp(L[28],if_helper218330,[cont_tail_arg221346]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper218330)?if_helper218330.app(cont_tail_arg221346):R.ffi.throwNonFunApp(L[28],if_helper218330,[cont_tail_arg221346]);
},
"from":L[28]});
}
++R.GAS;
return $z344345;
}
};
var $Hanf_assign347331 = function(anf_assign226329,if_helper218330,ret107272,nothing5) {
ret107272.$var = anf_assign226329;
var $z363364 = D;
var $f369370 = function(_) {
return R.isFunction(if_helper218330)?if_helper218330.app(nothing5):R.ffi.throwNonFunApp(L[20],if_helper218330,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z363364 = $f369370();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f369370,
"from":L[20]});
}
} catch($e361362) {
if(R.isCont($e361362)) {
var $ss365366 = {"from":L[20],
"go":function(cont_tail_app227371) {
return $Hcont_tail_app346372(cont_tail_app227371);
}};
$e361362.stack[R.EXN_STACKHEIGHT++] = $ss365366;
}
if(R.isPyretException($e361362)) {
$e361362.pyretStack.push(L[20]);
}
throw $e361362;
}
var $ret367368 = $Hcont_tail_app346372($z363364);
++R.GAS;
return $ret367368;
};
var $Hcont_tail_app346372 = function(cont_tail_app227371) {
return cont_tail_app227371;
};
var $Hcont_tail_app348343 = function(cont_tail_app224342) {
return cont_tail_app224342;
};
var $Hcont_tail_app345360 = function(cont_tail_app220359) {
return cont_tail_app220359;
};
var $Hcont_tail_app350297 = function(cont_tail_app217296) {
return cont_tail_app217296;
};
var $Hanf_arg344317 = function(anf_arg74315,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,anf_fun72316,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5) {
var $z375376 = D;
var $f381382 = function(_) {
return R.isFunction(anf_fun72316)?anf_fun72316.app(anf_arg74315):R.ffi.throwNonFunApp(L[29],anf_fun72316,[anf_arg74315]);
};
try {
if(--R.GAS > 0) {
$z375376 = $f381382();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f381382,
"from":L[29]});
}
} catch($e373374) {
if(R.isCont($e373374)) {
var $ss377378 = {"from":L[29],
"go":function(wf109383) {
return $Hwf343384(wf109383,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e373374.stack[R.EXN_STACKHEIGHT++] = $ss377378;
}
if(R.isPyretException($e373374)) {
$e373374.pyretStack.push(L[29]);
}
throw $e373374;
}
var $ret379380 = $Hwf343384($z375376,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret379380;
};
var $Hwf343384 = function(wf109383,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5) {
var when_DASH_17410 = G(options106271,"collect-all",L[32]);
var if_helper75396 = R.makeFunction(function(if_helper_arg76415) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[31],1,arguments);
}
if_helper_arg76415;
var if_DASH_18423 = G(options106271,"check-mode",L[35]);
var if_helper77418 = R.makeFunction(function(if_helper_arg78428) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[35],1,arguments);
}
var checker110471 = if_helper_arg78428;
var cases_DASH_val31474 = wf109383;
var anf_fun79439 = G(cases_DASH_val31474,"_match",L[37]);
var anf_obj195445 = R.makeFunction(function(wf_DASH_ast111460) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[39],1,arguments);
}
var $z463464 = D;
var $f469470 = function(_) {
return R.isFunction(checker110471)?checker110471.app(wf_DASH_ast111460):R.ffi.throwNonFunApp(L[40],checker110471,[wf_DASH_ast111460]);
};
try {
if(--R.GAS > 0) {
$z463464 = $f469470();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f469470,
"from":L[40]});
}
} catch($e461462) {
if(R.isCont($e461462)) {
var $ss465466 = {"from":L[40],
"go":function(checked112472) {
return $Hchecked337473(checked112472,C912,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e461462.stack[R.EXN_STACKHEIGHT++] = $ss465466;
}
if(R.isPyretException($e461462)) {
$e461462.pyretStack.push(L[40]);
}
throw $e461462;
}
var $ret467468 = $Hchecked337473($z463464,C912,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret467468;
});
var anf_obj197446 = R.makeFunction(function($underscore121447) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[38],1,arguments);
}
var $z450451 = D;
var $f456457 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Result"),wf109383,ret107272.$var):R.ffi.throwNonFunApp(L[38],phase88183.$var,[("Result"),wf109383,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z450451 = $f456457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f456457,
"from":L[38]});
}
} catch($e448449) {
if(R.isCont($e448449)) {
var $ss452453 = {"from":L[38],
"go":function(ann_DASH_check_DASH_temp196458) {
return $Hann_DASH_check_DASH_temp338459(ann_DASH_check_DASH_temp196458);
}};
$e448449.stack[R.EXN_STACKHEIGHT++] = $ss452453;
}
if(R.isPyretException($e448449)) {
$e448449.pyretStack.push(L[38]);
}
throw $e448449;
}
var $ret454455 = $Hann_DASH_check_DASH_temp338459($z450451);
++R.GAS;
return $ret454455;
});
var anf_arg198440 = R.makeObject({"ok":anf_obj195445,
"err":anf_obj197446});
var anf_arg200441 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[37],0,arguments);
}
var ann_DASH_check_DASH_temp199444 = R.throwNoBranchesMatched(L[37],("cases"));
return ann_DASH_check_DASH_temp199444;
});
var $z431432 = D;
var $f437438 = function(_) {
return R.isFunction(anf_fun79439)?anf_fun79439.app(anf_arg198440,anf_arg200441):R.ffi.throwNonFunApp(L[36],anf_fun79439,[anf_arg198440,anf_arg200441]);
};
try {
if(--R.GAS > 0) {
$z431432 = $f437438();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f437438,
"from":L[36]});
}
} catch($e429430) {
if(R.isCont($e429430)) {
var $ss433434 = {"from":L[36],
"go":function(ann_DASH_check_DASH_temp68442) {
return $Hann_DASH_check_DASH_temp339443(ann_DASH_check_DASH_temp68442,CompilationPhase8056);
}};
$e429430.stack[R.EXN_STACKHEIGHT++] = $ss433434;
}
if(R.isPyretException($e429430)) {
$e429430.pyretStack.push(L[36]);
}
throw $e429430;
}
var $ret435436 = $Hann_DASH_check_DASH_temp339443($z431432,CompilationPhase8056);
++R.GAS;
return $ret435436;
});
var anf_if203427 = R.isBoolean(if_DASH_18423);
if(R.isPyretTrue(anf_if203427)) {
if(R.isPyretTrue(if_DASH_18423)) {
var cont_tail_arg206419 = G(CH1917,"desugar-check",L[33]);
if(--R.GAS > 0) {
$z416417 = R.isFunction(if_helper77418)?if_helper77418.app(cont_tail_arg206419):R.ffi.throwNonFunApp(L[33],if_helper77418,[cont_tail_arg206419]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper77418)?if_helper77418.app(cont_tail_arg206419):R.ffi.throwNonFunApp(L[33],if_helper77418,[cont_tail_arg206419]);
},
"from":L[33]});
}
++R.GAS;
return $z416417;
} else {
var cont_tail_arg204422 = G(CH1917,"desugar-no-checks",L[34]);
if(--R.GAS > 0) {
$z420421 = R.isFunction(if_helper77418)?if_helper77418.app(cont_tail_arg204422):R.ffi.throwNonFunApp(L[34],if_helper77418,[cont_tail_arg204422]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper77418)?if_helper77418.app(cont_tail_arg204422):R.ffi.throwNonFunApp(L[34],if_helper77418,[cont_tail_arg204422]);
},
"from":L[34]});
}
++R.GAS;
return $z420421;
}
} else {
var cont_tail_arg201426 = R.throwNonBooleanCondition(L[35],("if"),if_DASH_18423);
if(--R.GAS > 0) {
$z424425 = R.isFunction(if_helper77418)?if_helper77418.app(cont_tail_arg201426):R.ffi.throwNonFunApp(L[35],if_helper77418,[cont_tail_arg201426]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper77418)?if_helper77418.app(cont_tail_arg201426):R.ffi.throwNonFunApp(L[35],if_helper77418,[cont_tail_arg201426]);
},
"from":L[35]});
}
++R.GAS;
return $z424425;
}
});
var anf_if210414 = R.isBoolean(when_DASH_17410);
if(R.isPyretTrue(anf_if210414)) {
if(R.isPyretTrue(when_DASH_17410)) {
var $z387388 = D;
var $f393394 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Checked well-formedness"),wf109383,ret107272.$var):R.ffi.throwNonFunApp(L[30],phase88183.$var,[("Checked well-formedness"),wf109383,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z387388 = $f393394();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f393394,
"from":L[30]});
}
} catch($e385386) {
if(R.isCont($e385386)) {
var $ss389390 = {"from":L[30],
"go":function(anf_assign212395) {
return $Hanf_assign341397(anf_assign212395,if_helper75396,ret107272,nothing5);
}};
$e385386.stack[R.EXN_STACKHEIGHT++] = $ss389390;
}
if(R.isPyretException($e385386)) {
$e385386.pyretStack.push(L[30]);
}
throw $e385386;
}
var $ret391392 = $Hanf_assign341397($z387388,if_helper75396,ret107272,nothing5);
++R.GAS;
return $ret391392;
} else {
var $z400401 = D;
var $f406407 = function(_) {
return R.isFunction(if_helper75396)?if_helper75396.app(nothing5):R.ffi.throwNonFunApp(L[31],if_helper75396,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z400401 = $f406407();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f406407,
"from":L[31]});
}
} catch($e398399) {
if(R.isCont($e398399)) {
var $ss402403 = {"from":L[31],
"go":function(cont_tail_app211408) {
return $Hcont_tail_app342409(cont_tail_app211408);
}};
$e398399.stack[R.EXN_STACKHEIGHT++] = $ss402403;
}
if(R.isPyretException($e398399)) {
$e398399.pyretStack.push(L[31]);
}
throw $e398399;
}
var $ret404405 = $Hcont_tail_app342409($z400401);
++R.GAS;
return $ret404405;
}
} else {
var cont_tail_arg208413 = R.throwNonBooleanCondition(L[32],("when"),when_DASH_17410);
if(--R.GAS > 0) {
$z411412 = R.isFunction(if_helper75396)?if_helper75396.app(cont_tail_arg208413):R.ffi.throwNonFunApp(L[32],if_helper75396,[cont_tail_arg208413]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper75396)?if_helper75396.app(cont_tail_arg208413):R.ffi.throwNonFunApp(L[32],if_helper75396,[cont_tail_arg208413]);
},
"from":L[32]});
}
++R.GAS;
return $z411412;
}
};
var $Hanf_assign341397 = function(anf_assign212395,if_helper75396,ret107272,nothing5) {
ret107272.$var = anf_assign212395;
var $z477478 = D;
var $f483484 = function(_) {
return R.isFunction(if_helper75396)?if_helper75396.app(nothing5):R.ffi.throwNonFunApp(L[31],if_helper75396,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z477478 = $f483484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f483484,
"from":L[31]});
}
} catch($e475476) {
if(R.isCont($e475476)) {
var $ss479480 = {"from":L[31],
"go":function(cont_tail_app213485) {
return $Hcont_tail_app340486(cont_tail_app213485);
}};
$e475476.stack[R.EXN_STACKHEIGHT++] = $ss479480;
}
if(R.isPyretException($e475476)) {
$e475476.pyretStack.push(L[31]);
}
throw $e475476;
}
var $ret481482 = $Hcont_tail_app340486($z477478);
++R.GAS;
return $ret481482;
};
var $Hcont_tail_app340486 = function(cont_tail_app213485) {
return cont_tail_app213485;
};
var $Hcont_tail_app342409 = function(cont_tail_app211408) {
return cont_tail_app211408;
};
var $Hann_DASH_check_DASH_temp339443 = function(ann_DASH_check_DASH_temp68442,CompilationPhase8056) {
return ann_DASH_check_DASH_temp68442;
};
var $Hann_DASH_check_DASH_temp338459 = function(ann_DASH_check_DASH_temp196458) {
return ann_DASH_check_DASH_temp196458;
};
var $Hchecked337473 = function(checked112472,C912,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5) {
var when_DASH_19543 = G(options106271,"collect-all",L[46]);
var if_helper81529 = R.makeFunction(function(if_helper_arg82548) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[45],1,arguments);
}
if_helper_arg82548;
var anf_fun83559 = G(R1515,"desugar-scope",L[48]);
var $z551552 = D;
var $f557558 = function(_) {
return R.isFunction(anf_fun83559)?anf_fun83559.app(checked112472,libs105270):R.ffi.throwNonFunApp(L[47],anf_fun83559,[checked112472,libs105270]);
};
try {
if(--R.GAS > 0) {
$z551552 = $f557558();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f557558,
"from":L[47]});
}
} catch($e549550) {
if(R.isCont($e549550)) {
var $ss553554 = {"from":L[47],
"go":function(scoped113560) {
return $Hscoped331561(scoped113560,C912,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e549550.stack[R.EXN_STACKHEIGHT++] = $ss553554;
}
if(R.isPyretException($e549550)) {
$e549550.pyretStack.push(L[47]);
}
throw $e549550;
}
var $ret555556 = $Hscoped331561($z551552,C912,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret555556;
});
var anf_if184547 = R.isBoolean(when_DASH_19543);
if(R.isPyretTrue(anf_if184547)) {
if(R.isPyretTrue(when_DASH_19543)) {
var if_DASH_20512 = G(options106271,"check-mode",L[43]);
var if_helper186497 = R.makeFunction(function(if_helper_arg187517) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[43],1,arguments);
}
var $z520521 = D;
var $f526527 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(if_helper_arg187517,checked112472,ret107272.$var):R.ffi.throwNonFunApp(L[44],phase88183.$var,[if_helper_arg187517,checked112472,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z520521 = $f526527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f526527,
"from":L[44]});
}
} catch($e518519) {
if(R.isCont($e518519)) {
var $ss522523 = {"from":L[44],
"go":function(anf_assign188528) {
return $Hanf_assign333530(anf_assign188528,if_helper81529,ret107272,nothing5);
}};
$e518519.stack[R.EXN_STACKHEIGHT++] = $ss522523;
}
if(R.isPyretException($e518519)) {
$e518519.pyretStack.push(L[44]);
}
throw $e518519;
}
var $ret524525 = $Hanf_assign333530($z520521,if_helper81529,ret107272,nothing5);
++R.GAS;
return $ret524525;
});
var anf_if192516 = R.isBoolean(if_DASH_20512);
if(R.isPyretTrue(anf_if192516)) {
if(R.isPyretTrue(if_DASH_20512)) {
var $z489490 = D;
var $f495496 = function(_) {
return R.isFunction(if_helper186497)?if_helper186497.app(("Desugared (with checks)")):R.ffi.throwNonFunApp(L[41],if_helper186497,[("Desugared (with checks)")]);
};
try {
if(--R.GAS > 0) {
$z489490 = $f495496();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f495496,
"from":L[41]});
}
} catch($e487488) {
if(R.isCont($e487488)) {
var $ss491492 = {"from":L[41],
"go":function(cont_tail_app194498) {
return $Hcont_tail_app334499(cont_tail_app194498);
}};
$e487488.stack[R.EXN_STACKHEIGHT++] = $ss491492;
}
if(R.isPyretException($e487488)) {
$e487488.pyretStack.push(L[41]);
}
throw $e487488;
}
var $ret493494 = $Hcont_tail_app334499($z489490);
++R.GAS;
return $ret493494;
} else {
var $z502503 = D;
var $f508509 = function(_) {
return R.isFunction(if_helper186497)?if_helper186497.app(("Desugared (skipping checks)")):R.ffi.throwNonFunApp(L[42],if_helper186497,[("Desugared (skipping checks)")]);
};
try {
if(--R.GAS > 0) {
$z502503 = $f508509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f508509,
"from":L[42]});
}
} catch($e500501) {
if(R.isCont($e500501)) {
var $ss504505 = {"from":L[42],
"go":function(cont_tail_app193510) {
return $Hcont_tail_app335511(cont_tail_app193510);
}};
$e500501.stack[R.EXN_STACKHEIGHT++] = $ss504505;
}
if(R.isPyretException($e500501)) {
$e500501.pyretStack.push(L[42]);
}
throw $e500501;
}
var $ret506507 = $Hcont_tail_app335511($z502503);
++R.GAS;
return $ret506507;
}
} else {
var cont_tail_arg190515 = R.throwNonBooleanCondition(L[43],("if"),if_DASH_20512);
if(--R.GAS > 0) {
$z513514 = R.isFunction(if_helper186497)?if_helper186497.app(cont_tail_arg190515):R.ffi.throwNonFunApp(L[43],if_helper186497,[cont_tail_arg190515]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper186497)?if_helper186497.app(cont_tail_arg190515):R.ffi.throwNonFunApp(L[43],if_helper186497,[cont_tail_arg190515]);
},
"from":L[43]});
}
++R.GAS;
return $z513514;
}
} else {
var $z533534 = D;
var $f539540 = function(_) {
return R.isFunction(if_helper81529)?if_helper81529.app(nothing5):R.ffi.throwNonFunApp(L[45],if_helper81529,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z533534 = $f539540();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f539540,
"from":L[45]});
}
} catch($e531532) {
if(R.isCont($e531532)) {
var $ss535536 = {"from":L[45],
"go":function(cont_tail_app185541) {
return $Hcont_tail_app336542(cont_tail_app185541);
}};
$e531532.stack[R.EXN_STACKHEIGHT++] = $ss535536;
}
if(R.isPyretException($e531532)) {
$e531532.pyretStack.push(L[45]);
}
throw $e531532;
}
var $ret537538 = $Hcont_tail_app336542($z533534);
++R.GAS;
return $ret537538;
}
} else {
var cont_tail_arg182546 = R.throwNonBooleanCondition(L[46],("when"),when_DASH_19543);
if(--R.GAS > 0) {
$z544545 = R.isFunction(if_helper81529)?if_helper81529.app(cont_tail_arg182546):R.ffi.throwNonFunApp(L[46],if_helper81529,[cont_tail_arg182546]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper81529)?if_helper81529.app(cont_tail_arg182546):R.ffi.throwNonFunApp(L[46],if_helper81529,[cont_tail_arg182546]);
},
"from":L[46]});
}
++R.GAS;
return $z544545;
}
};
var $Hcont_tail_app334499 = function(cont_tail_app194498) {
return cont_tail_app194498;
};
var $Hcont_tail_app335511 = function(cont_tail_app193510) {
return cont_tail_app193510;
};
var $Hanf_assign333530 = function(anf_assign188528,if_helper81529,ret107272,nothing5) {
ret107272.$var = anf_assign188528;
var $z564565 = D;
var $f570571 = function(_) {
return R.isFunction(if_helper81529)?if_helper81529.app(nothing5):R.ffi.throwNonFunApp(L[45],if_helper81529,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z564565 = $f570571();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f570571,
"from":L[45]});
}
} catch($e562563) {
if(R.isCont($e562563)) {
var $ss566567 = {"from":L[45],
"go":function(cont_tail_app189572) {
return $Hcont_tail_app332573(cont_tail_app189572);
}};
$e562563.stack[R.EXN_STACKHEIGHT++] = $ss566567;
}
if(R.isPyretException($e562563)) {
$e562563.pyretStack.push(L[45]);
}
throw $e562563;
}
var $ret568569 = $Hcont_tail_app332573($z564565);
++R.GAS;
return $ret568569;
};
var $Hcont_tail_app332573 = function(cont_tail_app189572) {
return cont_tail_app189572;
};
var $Hcont_tail_app336542 = function(cont_tail_app185541) {
return cont_tail_app185541;
};
var $Hscoped331561 = function(scoped113560,C912,D1716,P711,R1515,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5) {
var when_DASH_21599 = G(options106271,"collect-all",L[51]);
var if_helper84585 = R.makeFunction(function(if_helper_arg85604) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[50],1,arguments);
}
if_helper_arg85604;
var anf_fun86615 = G(R1515,"resolve-names",L[53]);
var $z607608 = D;
var $f613614 = function(_) {
return R.isFunction(anf_fun86615)?anf_fun86615.app(scoped113560,libs105270):R.ffi.throwNonFunApp(L[52],anf_fun86615,[scoped113560,libs105270]);
};
try {
if(--R.GAS > 0) {
$z607608 = $f613614();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f613614,
"from":L[52]});
}
} catch($e605606) {
if(R.isCont($e605606)) {
var $ss609610 = {"from":L[52],
"go":function(named_DASH_result114616) {
return $Hnamed_DASH_result327617(named_DASH_result114616,C912,D1716,P711,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e605606.stack[R.EXN_STACKHEIGHT++] = $ss609610;
}
if(R.isPyretException($e605606)) {
$e605606.pyretStack.push(L[52]);
}
throw $e605606;
}
var $ret611612 = $Hnamed_DASH_result327617($z607608,C912,D1716,P711,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret611612;
});
var anf_if178603 = R.isBoolean(when_DASH_21599);
if(R.isPyretTrue(anf_if178603)) {
if(R.isPyretTrue(when_DASH_21599)) {
var $z576577 = D;
var $f582583 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Desugared scope"),scoped113560,ret107272.$var):R.ffi.throwNonFunApp(L[49],phase88183.$var,[("Desugared scope"),scoped113560,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z576577 = $f582583();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f582583,
"from":L[49]});
}
} catch($e574575) {
if(R.isCont($e574575)) {
var $ss578579 = {"from":L[49],
"go":function(anf_assign180584) {
return $Hanf_assign329586(anf_assign180584,if_helper84585,ret107272,nothing5);
}};
$e574575.stack[R.EXN_STACKHEIGHT++] = $ss578579;
}
if(R.isPyretException($e574575)) {
$e574575.pyretStack.push(L[49]);
}
throw $e574575;
}
var $ret580581 = $Hanf_assign329586($z576577,if_helper84585,ret107272,nothing5);
++R.GAS;
return $ret580581;
} else {
var $z589590 = D;
var $f595596 = function(_) {
return R.isFunction(if_helper84585)?if_helper84585.app(nothing5):R.ffi.throwNonFunApp(L[50],if_helper84585,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z589590 = $f595596();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f595596,
"from":L[50]});
}
} catch($e587588) {
if(R.isCont($e587588)) {
var $ss591592 = {"from":L[50],
"go":function(cont_tail_app179597) {
return $Hcont_tail_app330598(cont_tail_app179597);
}};
$e587588.stack[R.EXN_STACKHEIGHT++] = $ss591592;
}
if(R.isPyretException($e587588)) {
$e587588.pyretStack.push(L[50]);
}
throw $e587588;
}
var $ret593594 = $Hcont_tail_app330598($z589590);
++R.GAS;
return $ret593594;
}
} else {
var cont_tail_arg176602 = R.throwNonBooleanCondition(L[51],("when"),when_DASH_21599);
if(--R.GAS > 0) {
$z600601 = R.isFunction(if_helper84585)?if_helper84585.app(cont_tail_arg176602):R.ffi.throwNonFunApp(L[51],if_helper84585,[cont_tail_arg176602]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper84585)?if_helper84585.app(cont_tail_arg176602):R.ffi.throwNonFunApp(L[51],if_helper84585,[cont_tail_arg176602]);
},
"from":L[51]});
}
++R.GAS;
return $z600601;
}
};
var $Hanf_assign329586 = function(anf_assign180584,if_helper84585,ret107272,nothing5) {
ret107272.$var = anf_assign180584;
var $z620621 = D;
var $f626627 = function(_) {
return R.isFunction(if_helper84585)?if_helper84585.app(nothing5):R.ffi.throwNonFunApp(L[50],if_helper84585,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z620621 = $f626627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f626627,
"from":L[50]});
}
} catch($e618619) {
if(R.isCont($e618619)) {
var $ss622623 = {"from":L[50],
"go":function(cont_tail_app181628) {
return $Hcont_tail_app328629(cont_tail_app181628);
}};
$e618619.stack[R.EXN_STACKHEIGHT++] = $ss622623;
}
if(R.isPyretException($e618619)) {
$e618619.pyretStack.push(L[50]);
}
throw $e618619;
}
var $ret624625 = $Hcont_tail_app328629($z620621);
++R.GAS;
return $ret624625;
};
var $Hcont_tail_app328629 = function(cont_tail_app181628) {
return cont_tail_app181628;
};
var $Hcont_tail_app330598 = function(cont_tail_app179597) {
return cont_tail_app179597;
};
var $Hnamed_DASH_result327617 = function(named_DASH_result114616,C912,D1716,P711,U1314,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3,nothing5) {
var when_DASH_22655 = G(options106271,"collect-all",L[56]);
var if_helper87641 = R.makeFunction(function(if_helper_arg88660) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[55],1,arguments);
}
if_helper_arg88660;
var named_DASH_ast115672 = G(named_DASH_result114616,"ast",L[60]);
var named_DASH_errors116674 = G(named_DASH_result114616,"errors",L[59]);
var anf_fun89671 = G(D1716,"desugar",L[58]);
var $z663664 = D;
var $f669670 = function(_) {
return R.isFunction(anf_fun89671)?anf_fun89671.app(named_DASH_ast115672,libs105270):R.ffi.throwNonFunApp(L[57],anf_fun89671,[named_DASH_ast115672,libs105270]);
};
try {
if(--R.GAS > 0) {
$z663664 = $f669670();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f669670,
"from":L[57]});
}
} catch($e661662) {
if(R.isCont($e661662)) {
var $ss665666 = {"from":L[57],
"go":function(desugared117673) {
return $Hdesugared323675(desugared117673,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e661662.stack[R.EXN_STACKHEIGHT++] = $ss665666;
}
if(R.isPyretException($e661662)) {
$e661662.pyretStack.push(L[57]);
}
throw $e661662;
}
var $ret667668 = $Hdesugared323675($z663664,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret667668;
});
var anf_if172659 = R.isBoolean(when_DASH_22655);
if(R.isPyretTrue(anf_if172659)) {
if(R.isPyretTrue(when_DASH_22655)) {
var $z632633 = D;
var $f638639 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Resolved names"),named_DASH_result114616,ret107272.$var):R.ffi.throwNonFunApp(L[54],phase88183.$var,[("Resolved names"),named_DASH_result114616,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z632633 = $f638639();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f638639,
"from":L[54]});
}
} catch($e630631) {
if(R.isCont($e630631)) {
var $ss634635 = {"from":L[54],
"go":function(anf_assign174640) {
return $Hanf_assign325642(anf_assign174640,if_helper87641,ret107272,nothing5);
}};
$e630631.stack[R.EXN_STACKHEIGHT++] = $ss634635;
}
if(R.isPyretException($e630631)) {
$e630631.pyretStack.push(L[54]);
}
throw $e630631;
}
var $ret636637 = $Hanf_assign325642($z632633,if_helper87641,ret107272,nothing5);
++R.GAS;
return $ret636637;
} else {
var $z645646 = D;
var $f651652 = function(_) {
return R.isFunction(if_helper87641)?if_helper87641.app(nothing5):R.ffi.throwNonFunApp(L[55],if_helper87641,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z645646 = $f651652();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f651652,
"from":L[55]});
}
} catch($e643644) {
if(R.isCont($e643644)) {
var $ss647648 = {"from":L[55],
"go":function(cont_tail_app173653) {
return $Hcont_tail_app326654(cont_tail_app173653);
}};
$e643644.stack[R.EXN_STACKHEIGHT++] = $ss647648;
}
if(R.isPyretException($e643644)) {
$e643644.pyretStack.push(L[55]);
}
throw $e643644;
}
var $ret649650 = $Hcont_tail_app326654($z645646);
++R.GAS;
return $ret649650;
}
} else {
var cont_tail_arg170658 = R.throwNonBooleanCondition(L[56],("when"),when_DASH_22655);
if(--R.GAS > 0) {
$z656657 = R.isFunction(if_helper87641)?if_helper87641.app(cont_tail_arg170658):R.ffi.throwNonFunApp(L[56],if_helper87641,[cont_tail_arg170658]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper87641)?if_helper87641.app(cont_tail_arg170658):R.ffi.throwNonFunApp(L[56],if_helper87641,[cont_tail_arg170658]);
},
"from":L[56]});
}
++R.GAS;
return $z656657;
}
};
var $Hanf_assign325642 = function(anf_assign174640,if_helper87641,ret107272,nothing5) {
ret107272.$var = anf_assign174640;
var $z678679 = D;
var $f684685 = function(_) {
return R.isFunction(if_helper87641)?if_helper87641.app(nothing5):R.ffi.throwNonFunApp(L[55],if_helper87641,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z678679 = $f684685();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f684685,
"from":L[55]});
}
} catch($e676677) {
if(R.isCont($e676677)) {
var $ss680681 = {"from":L[55],
"go":function(cont_tail_app175686) {
return $Hcont_tail_app324687(cont_tail_app175686);
}};
$e676677.stack[R.EXN_STACKHEIGHT++] = $ss680681;
}
if(R.isPyretException($e676677)) {
$e676677.pyretStack.push(L[55]);
}
throw $e676677;
}
var $ret682683 = $Hcont_tail_app324687($z678679);
++R.GAS;
return $ret682683;
};
var $Hcont_tail_app324687 = function(cont_tail_app175686) {
return cont_tail_app175686;
};
var $Hcont_tail_app326654 = function(cont_tail_app173653) {
return cont_tail_app173653;
};
var $Hdesugared323675 = function(desugared117673,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5) {
var when_DASH_23713 = G(options106271,"collect-all",L[63]);
var if_helper90699 = R.makeFunction(function(if_helper_arg91718) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[62],1,arguments);
}
if_helper_arg91718;
var anf_fun92729 = G(desugared117673,"visit",L[66]);
var anf_arg93730 = G(U1314,"merge-nested-blocks",L[65]);
var $z721722 = D;
var $f727728 = function(_) {
return R.isFunction(anf_fun92729)?anf_fun92729.app(anf_arg93730):R.ffi.throwNonFunApp(L[64],anf_fun92729,[anf_arg93730]);
};
try {
if(--R.GAS > 0) {
$z721722 = $f727728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f727728,
"from":L[64]});
}
} catch($e719720) {
if(R.isCont($e719720)) {
var $ss723724 = {"from":L[64],
"go":function(anf_bracket94731) {
return $Hanf_bracket319732(anf_bracket94731,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e719720.stack[R.EXN_STACKHEIGHT++] = $ss723724;
}
if(R.isPyretException($e719720)) {
$e719720.pyretStack.push(L[64]);
}
throw $e719720;
}
var $ret725726 = $Hanf_bracket319732($z721722,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret725726;
});
var anf_if166717 = R.isBoolean(when_DASH_23713);
if(R.isPyretTrue(anf_if166717)) {
if(R.isPyretTrue(when_DASH_23713)) {
var $z690691 = D;
var $f696697 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Fully desugared"),desugared117673,ret107272.$var):R.ffi.throwNonFunApp(L[61],phase88183.$var,[("Fully desugared"),desugared117673,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z690691 = $f696697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f696697,
"from":L[61]});
}
} catch($e688689) {
if(R.isCont($e688689)) {
var $ss692693 = {"from":L[61],
"go":function(anf_assign168698) {
return $Hanf_assign321700(anf_assign168698,if_helper90699,ret107272,nothing5);
}};
$e688689.stack[R.EXN_STACKHEIGHT++] = $ss692693;
}
if(R.isPyretException($e688689)) {
$e688689.pyretStack.push(L[61]);
}
throw $e688689;
}
var $ret694695 = $Hanf_assign321700($z690691,if_helper90699,ret107272,nothing5);
++R.GAS;
return $ret694695;
} else {
var $z703704 = D;
var $f709710 = function(_) {
return R.isFunction(if_helper90699)?if_helper90699.app(nothing5):R.ffi.throwNonFunApp(L[62],if_helper90699,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z703704 = $f709710();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f709710,
"from":L[62]});
}
} catch($e701702) {
if(R.isCont($e701702)) {
var $ss705706 = {"from":L[62],
"go":function(cont_tail_app167711) {
return $Hcont_tail_app322712(cont_tail_app167711);
}};
$e701702.stack[R.EXN_STACKHEIGHT++] = $ss705706;
}
if(R.isPyretException($e701702)) {
$e701702.pyretStack.push(L[62]);
}
throw $e701702;
}
var $ret707708 = $Hcont_tail_app322712($z703704);
++R.GAS;
return $ret707708;
}
} else {
var cont_tail_arg164716 = R.throwNonBooleanCondition(L[63],("when"),when_DASH_23713);
if(--R.GAS > 0) {
$z714715 = R.isFunction(if_helper90699)?if_helper90699.app(cont_tail_arg164716):R.ffi.throwNonFunApp(L[63],if_helper90699,[cont_tail_arg164716]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper90699)?if_helper90699.app(cont_tail_arg164716):R.ffi.throwNonFunApp(L[63],if_helper90699,[cont_tail_arg164716]);
},
"from":L[63]});
}
++R.GAS;
return $z714715;
}
};
var $Hanf_assign321700 = function(anf_assign168698,if_helper90699,ret107272,nothing5) {
ret107272.$var = anf_assign168698;
var $z735736 = D;
var $f741742 = function(_) {
return R.isFunction(if_helper90699)?if_helper90699.app(nothing5):R.ffi.throwNonFunApp(L[62],if_helper90699,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z735736 = $f741742();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f741742,
"from":L[62]});
}
} catch($e733734) {
if(R.isCont($e733734)) {
var $ss737738 = {"from":L[62],
"go":function(cont_tail_app169743) {
return $Hcont_tail_app320744(cont_tail_app169743);
}};
$e733734.stack[R.EXN_STACKHEIGHT++] = $ss737738;
}
if(R.isPyretException($e733734)) {
$e733734.pyretStack.push(L[62]);
}
throw $e733734;
}
var $ret739740 = $Hcont_tail_app320744($z735736);
++R.GAS;
return $ret739740;
};
var $Hcont_tail_app320744 = function(cont_tail_app169743) {
return cont_tail_app169743;
};
var $Hcont_tail_app322712 = function(cont_tail_app167711) {
return cont_tail_app167711;
};
var $Hanf_bracket319732 = function(anf_bracket94731,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5) {
var anf_fun95755 = G(anf_bracket94731,"visit",L[69]);
var anf_arg96756 = G(U1314,"flatten-single-blocks",L[68]);
var $z747748 = D;
var $f753754 = function(_) {
return R.isFunction(anf_fun95755)?anf_fun95755.app(anf_arg96756):R.ffi.throwNonFunApp(L[67],anf_fun95755,[anf_arg96756]);
};
try {
if(--R.GAS > 0) {
$z747748 = $f753754();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f753754,
"from":L[67]});
}
} catch($e745746) {
if(R.isCont($e745746)) {
var $ss749750 = {"from":L[67],
"go":function(anf_bracket97757) {
return $Hanf_bracket318758(anf_bracket97757,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e745746.stack[R.EXN_STACKHEIGHT++] = $ss749750;
}
if(R.isPyretException($e745746)) {
$e745746.pyretStack.push(L[67]);
}
throw $e745746;
}
var $ret751752 = $Hanf_bracket318758($z747748,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret751752;
};
var $Hanf_bracket318758 = function(anf_bracket97757,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5) {
var anf_fun98771 = G(anf_bracket97757,"visit",L[72]);
var anf_fun99769 = G(U1314,"link-list-visitor",L[71]);
var $z761762 = D;
var $f767768 = function(_) {
return R.isFunction(anf_fun99769)?anf_fun99769.app(libs105270):R.ffi.throwNonFunApp(L[70],anf_fun99769,[libs105270]);
};
try {
if(--R.GAS > 0) {
$z761762 = $f767768();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f767768,
"from":L[70]});
}
} catch($e759760) {
if(R.isCont($e759760)) {
var $ss763764 = {"from":L[70],
"go":function(anf_arg100770) {
return $Hanf_arg317772(anf_arg100770,C912,P711,U1314,anf_fun98771,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e759760.stack[R.EXN_STACKHEIGHT++] = $ss763764;
}
if(R.isPyretException($e759760)) {
$e759760.pyretStack.push(L[70]);
}
throw $e759760;
}
var $ret765766 = $Hanf_arg317772($z761762,C912,P711,U1314,anf_fun98771,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret765766;
};
var $Hanf_arg317772 = function(anf_arg100770,C912,P711,U1314,anf_fun98771,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5) {
var $z775776 = D;
var $f781782 = function(_) {
return R.isFunction(anf_fun98771)?anf_fun98771.app(anf_arg100770):R.ffi.throwNonFunApp(L[73],anf_fun98771,[anf_arg100770]);
};
try {
if(--R.GAS > 0) {
$z775776 = $f781782();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f781782,
"from":L[73]});
}
} catch($e773774) {
if(R.isCont($e773774)) {
var $ss777778 = {"from":L[73],
"go":function(anf_bracket101783) {
return $Hanf_bracket316784(anf_bracket101783,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e773774.stack[R.EXN_STACKHEIGHT++] = $ss777778;
}
if(R.isPyretException($e773774)) {
$e773774.pyretStack.push(L[73]);
}
throw $e773774;
}
var $ret779780 = $Hanf_bracket316784($z775776,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret779780;
};
var $Hanf_bracket316784 = function(anf_bracket101783,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5) {
var anf_fun102795 = G(anf_bracket101783,"visit",L[76]);
var anf_arg103796 = G(U1314,"letrec-visitor",L[75]);
var $z787788 = D;
var $f793794 = function(_) {
return R.isFunction(anf_fun102795)?anf_fun102795.app(anf_arg103796):R.ffi.throwNonFunApp(L[74],anf_fun102795,[anf_arg103796]);
};
try {
if(--R.GAS > 0) {
$z787788 = $f793794();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f793794,
"from":L[74]});
}
} catch($e785786) {
if(R.isCont($e785786)) {
var $ss789790 = {"from":L[74],
"go":function(cleaned118797) {
return $Hcleaned315798(cleaned118797,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e785786.stack[R.EXN_STACKHEIGHT++] = $ss789790;
}
if(R.isPyretException($e785786)) {
$e785786.pyretStack.push(L[74]);
}
throw $e785786;
}
var $ret791792 = $Hcleaned315798($z787788,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret791792;
};
var $Hcleaned315798 = function(cleaned118797,C912,P711,U1314,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5) {
var when_DASH_24824 = G(options106271,"collect-all",L[79]);
var if_helper104810 = R.makeFunction(function(if_helper_arg105829) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[78],1,arguments);
}
if_helper_arg105829;
var anf_fun106840 = G(cleaned118797,"visit",L[82]);
var anf_arg107841 = G(U1314,"inline-lams",L[81]);
var $z832833 = D;
var $f838839 = function(_) {
return R.isFunction(anf_fun106840)?anf_fun106840.app(anf_arg107841):R.ffi.throwNonFunApp(L[80],anf_fun106840,[anf_arg107841]);
};
try {
if(--R.GAS > 0) {
$z832833 = $f838839();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f838839,
"from":L[80]});
}
} catch($e830831) {
if(R.isCont($e830831)) {
var $ss834835 = {"from":L[80],
"go":function(inlined119842) {
return $Hinlined311843(inlined119842,C912,P711,U1314,cleaned118797,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e830831.stack[R.EXN_STACKHEIGHT++] = $ss834835;
}
if(R.isPyretException($e830831)) {
$e830831.pyretStack.push(L[80]);
}
throw $e830831;
}
var $ret836837 = $Hinlined311843($z832833,C912,P711,U1314,cleaned118797,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret836837;
});
var anf_if160828 = R.isBoolean(when_DASH_24824);
if(R.isPyretTrue(anf_if160828)) {
if(R.isPyretTrue(when_DASH_24824)) {
var $z801802 = D;
var $f807808 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Cleaned AST"),cleaned118797,ret107272.$var):R.ffi.throwNonFunApp(L[77],phase88183.$var,[("Cleaned AST"),cleaned118797,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z801802 = $f807808();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f807808,
"from":L[77]});
}
} catch($e799800) {
if(R.isCont($e799800)) {
var $ss803804 = {"from":L[77],
"go":function(anf_assign162809) {
return $Hanf_assign313811(anf_assign162809,if_helper104810,ret107272,nothing5);
}};
$e799800.stack[R.EXN_STACKHEIGHT++] = $ss803804;
}
if(R.isPyretException($e799800)) {
$e799800.pyretStack.push(L[77]);
}
throw $e799800;
}
var $ret805806 = $Hanf_assign313811($z801802,if_helper104810,ret107272,nothing5);
++R.GAS;
return $ret805806;
} else {
var $z814815 = D;
var $f820821 = function(_) {
return R.isFunction(if_helper104810)?if_helper104810.app(nothing5):R.ffi.throwNonFunApp(L[78],if_helper104810,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z814815 = $f820821();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f820821,
"from":L[78]});
}
} catch($e812813) {
if(R.isCont($e812813)) {
var $ss816817 = {"from":L[78],
"go":function(cont_tail_app161822) {
return $Hcont_tail_app314823(cont_tail_app161822);
}};
$e812813.stack[R.EXN_STACKHEIGHT++] = $ss816817;
}
if(R.isPyretException($e812813)) {
$e812813.pyretStack.push(L[78]);
}
throw $e812813;
}
var $ret818819 = $Hcont_tail_app314823($z814815);
++R.GAS;
return $ret818819;
}
} else {
var cont_tail_arg158827 = R.throwNonBooleanCondition(L[79],("when"),when_DASH_24824);
if(--R.GAS > 0) {
$z825826 = R.isFunction(if_helper104810)?if_helper104810.app(cont_tail_arg158827):R.ffi.throwNonFunApp(L[79],if_helper104810,[cont_tail_arg158827]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper104810)?if_helper104810.app(cont_tail_arg158827):R.ffi.throwNonFunApp(L[79],if_helper104810,[cont_tail_arg158827]);
},
"from":L[79]});
}
++R.GAS;
return $z825826;
}
};
var $Hanf_assign313811 = function(anf_assign162809,if_helper104810,ret107272,nothing5) {
ret107272.$var = anf_assign162809;
var $z846847 = D;
var $f852853 = function(_) {
return R.isFunction(if_helper104810)?if_helper104810.app(nothing5):R.ffi.throwNonFunApp(L[78],if_helper104810,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z846847 = $f852853();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f852853,
"from":L[78]});
}
} catch($e844845) {
if(R.isCont($e844845)) {
var $ss848849 = {"from":L[78],
"go":function(cont_tail_app163854) {
return $Hcont_tail_app312855(cont_tail_app163854);
}};
$e844845.stack[R.EXN_STACKHEIGHT++] = $ss848849;
}
if(R.isPyretException($e844845)) {
$e844845.pyretStack.push(L[78]);
}
throw $e844845;
}
var $ret850851 = $Hcont_tail_app312855($z846847);
++R.GAS;
return $ret850851;
};
var $Hcont_tail_app312855 = function(cont_tail_app163854) {
return cont_tail_app163854;
};
var $Hcont_tail_app314823 = function(cont_tail_app161822) {
return cont_tail_app161822;
};
var $Hinlined311843 = function(inlined119842,C912,P711,U1314,cleaned118797,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3,nothing5) {
var when_DASH_25881 = G(options106271,"collect-all",L[85]);
var if_helper108867 = R.makeFunction(function(if_helper_arg109886) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[84],1,arguments);
}
if_helper_arg109886;
var anf_fun110897 = G(U1314,"check-unbound",L[87]);
var $z889890 = D;
var $f895896 = function(_) {
return R.isFunction(anf_fun110897)?anf_fun110897.app(libs105270,inlined119842):R.ffi.throwNonFunApp(L[86],anf_fun110897,[libs105270,inlined119842]);
};
try {
if(--R.GAS > 0) {
$z889890 = $f895896();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f895896,
"from":L[86]});
}
} catch($e887888) {
if(R.isCont($e887888)) {
var $ss891892 = {"from":L[86],
"go":function(anf_arg111898) {
return $Hanf_arg307899(anf_arg111898,C912,P711,U1314,cleaned118797,inlined119842,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3);
}};
$e887888.stack[R.EXN_STACKHEIGHT++] = $ss891892;
}
if(R.isPyretException($e887888)) {
$e887888.pyretStack.push(L[86]);
}
throw $e887888;
}
var $ret893894 = $Hanf_arg307899($z889890,C912,P711,U1314,cleaned118797,inlined119842,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3);
++R.GAS;
return $ret893894;
});
var anf_if154885 = R.isBoolean(when_DASH_25881);
if(R.isPyretTrue(anf_if154885)) {
if(R.isPyretTrue(when_DASH_25881)) {
var $z858859 = D;
var $f864865 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Inlined lambdas"),inlined119842,ret107272.$var):R.ffi.throwNonFunApp(L[83],phase88183.$var,[("Inlined lambdas"),inlined119842,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z858859 = $f864865();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f864865,
"from":L[83]});
}
} catch($e856857) {
if(R.isCont($e856857)) {
var $ss860861 = {"from":L[83],
"go":function(anf_assign156866) {
return $Hanf_assign309868(anf_assign156866,if_helper108867,ret107272,nothing5);
}};
$e856857.stack[R.EXN_STACKHEIGHT++] = $ss860861;
}
if(R.isPyretException($e856857)) {
$e856857.pyretStack.push(L[83]);
}
throw $e856857;
}
var $ret862863 = $Hanf_assign309868($z858859,if_helper108867,ret107272,nothing5);
++R.GAS;
return $ret862863;
} else {
var $z871872 = D;
var $f877878 = function(_) {
return R.isFunction(if_helper108867)?if_helper108867.app(nothing5):R.ffi.throwNonFunApp(L[84],if_helper108867,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z871872 = $f877878();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f877878,
"from":L[84]});
}
} catch($e869870) {
if(R.isCont($e869870)) {
var $ss873874 = {"from":L[84],
"go":function(cont_tail_app155879) {
return $Hcont_tail_app310880(cont_tail_app155879);
}};
$e869870.stack[R.EXN_STACKHEIGHT++] = $ss873874;
}
if(R.isPyretException($e869870)) {
$e869870.pyretStack.push(L[84]);
}
throw $e869870;
}
var $ret875876 = $Hcont_tail_app310880($z871872);
++R.GAS;
return $ret875876;
}
} else {
var cont_tail_arg152884 = R.throwNonBooleanCondition(L[85],("when"),when_DASH_25881);
if(--R.GAS > 0) {
$z882883 = R.isFunction(if_helper108867)?if_helper108867.app(cont_tail_arg152884):R.ffi.throwNonFunApp(L[85],if_helper108867,[cont_tail_arg152884]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper108867)?if_helper108867.app(cont_tail_arg152884):R.ffi.throwNonFunApp(L[85],if_helper108867,[cont_tail_arg152884]);
},
"from":L[85]});
}
++R.GAS;
return $z882883;
}
};
var $Hanf_assign309868 = function(anf_assign156866,if_helper108867,ret107272,nothing5) {
ret107272.$var = anf_assign156866;
var $z902903 = D;
var $f908909 = function(_) {
return R.isFunction(if_helper108867)?if_helper108867.app(nothing5):R.ffi.throwNonFunApp(L[84],if_helper108867,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z902903 = $f908909();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f908909,
"from":L[84]});
}
} catch($e900901) {
if(R.isCont($e900901)) {
var $ss904905 = {"from":L[84],
"go":function(cont_tail_app157910) {
return $Hcont_tail_app308911(cont_tail_app157910);
}};
$e900901.stack[R.EXN_STACKHEIGHT++] = $ss904905;
}
if(R.isPyretException($e900901)) {
$e900901.pyretStack.push(L[84]);
}
throw $e900901;
}
var $ret906907 = $Hcont_tail_app308911($z902903);
++R.GAS;
return $ret906907;
};
var $Hcont_tail_app308911 = function(cont_tail_app157910) {
return cont_tail_app157910;
};
var $Hcont_tail_app310880 = function(cont_tail_app155879) {
return cont_tail_app155879;
};
var $Hanf_arg307899 = function(anf_arg111898,C912,P711,U1314,cleaned118797,inlined119842,is_DASH_empty40268,libs105270,named_DASH_errors116674,options106271,phase88183,ret107272,_plus3) {
var $z914915 = D;
var $f920921 = function(_) {
return R.isFunction(_plus3)?_plus3.app(named_DASH_errors116674,anf_arg111898):R.ffi.throwNonFunApp(L[88],_plus3,[named_DASH_errors116674,anf_arg111898]);
};
try {
if(--R.GAS > 0) {
$z914915 = $f920921();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f920921,
"from":L[88]});
}
} catch($e912913) {
if(R.isCont($e912913)) {
var $ss916917 = {"from":L[88],
"go":function(anf_arg112922) {
return $Hanf_arg306923(anf_arg112922,C912,P711,U1314,cleaned118797,inlined119842,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3);
}};
$e912913.stack[R.EXN_STACKHEIGHT++] = $ss916917;
}
if(R.isPyretException($e912913)) {
$e912913.pyretStack.push(L[88]);
}
throw $e912913;
}
var $ret918919 = $Hanf_arg306923($z914915,C912,P711,U1314,cleaned118797,inlined119842,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3);
++R.GAS;
return $ret918919;
};
var $Hanf_arg306923 = function(anf_arg112922,C912,P711,U1314,cleaned118797,inlined119842,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3) {
var anf_fun113934 = G(U1314,"bad-assignments",L[90]);
var $z926927 = D;
var $f932933 = function(_) {
return R.isFunction(anf_fun113934)?anf_fun113934.app(libs105270,inlined119842):R.ffi.throwNonFunApp(L[89],anf_fun113934,[libs105270,inlined119842]);
};
try {
if(--R.GAS > 0) {
$z926927 = $f932933();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f932933,
"from":L[89]});
}
} catch($e924925) {
if(R.isCont($e924925)) {
var $ss928929 = {"from":L[89],
"go":function(anf_arg114935) {
return $Hanf_arg305936(anf_arg114935,C912,P711,anf_arg112922,cleaned118797,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3);
}};
$e924925.stack[R.EXN_STACKHEIGHT++] = $ss928929;
}
if(R.isPyretException($e924925)) {
$e924925.pyretStack.push(L[89]);
}
throw $e924925;
}
var $ret930931 = $Hanf_arg305936($z926927,C912,P711,anf_arg112922,cleaned118797,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3);
++R.GAS;
return $ret930931;
};
var $Hanf_arg305936 = function(anf_arg114935,C912,P711,anf_arg112922,cleaned118797,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272,_plus3) {
var $z939940 = D;
var $f945946 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg112922,anf_arg114935):R.ffi.throwNonFunApp(L[91],_plus3,[anf_arg112922,anf_arg114935]);
};
try {
if(--R.GAS > 0) {
$z939940 = $f945946();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f945946,
"from":L[91]});
}
} catch($e937938) {
if(R.isCont($e937938)) {
var $ss941942 = {"from":L[91],
"go":function(any_DASH_errors120947) {
return $Hany_DASH_errors304948(any_DASH_errors120947,C912,P711,cleaned118797,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272);
}};
$e937938.stack[R.EXN_STACKHEIGHT++] = $ss941942;
}
if(R.isPyretException($e937938)) {
$e937938.pyretStack.push(L[91]);
}
throw $e937938;
}
var $ret943944 = $Hany_DASH_errors304948($z939940,C912,P711,cleaned118797,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272);
++R.GAS;
return $ret943944;
};
var $Hany_DASH_errors304948 = function(any_DASH_errors120947,C912,P711,cleaned118797,is_DASH_empty40268,libs105270,options106271,phase88183,ret107272) {
var $z951952 = D;
var $f957958 = function(_) {
return R.isFunction(is_DASH_empty40268)?is_DASH_empty40268.app(any_DASH_errors120947):R.ffi.throwNonFunApp(L[92],is_DASH_empty40268,[any_DASH_errors120947]);
};
try {
if(--R.GAS > 0) {
$z951952 = $f957958();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f957958,
"from":L[92]});
}
} catch($e949950) {
if(R.isCont($e949950)) {
var $ss953954 = {"from":L[92],
"go":function(if_DASH_29959) {
return $Hif_DASH_303960(if_DASH_29959,C912,P711,any_DASH_errors120947,cleaned118797,libs105270,options106271,phase88183,ret107272);
}};
$e949950.stack[R.EXN_STACKHEIGHT++] = $ss953954;
}
if(R.isPyretException($e949950)) {
$e949950.pyretStack.push(L[92]);
}
throw $e949950;
}
var $ret955956 = $Hif_DASH_303960($z951952,C912,P711,any_DASH_errors120947,cleaned118797,libs105270,options106271,phase88183,ret107272);
++R.GAS;
return $ret955956;
};
var $Hif_DASH_303960 = function(if_DASH_29959,C912,P711,any_DASH_errors120947,cleaned118797,libs105270,options106271,phase88183,ret107272) {
var if_helper115973 = R.makeFunction(function(if_helper_arg1161065) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[92],1,arguments);
}
var ann_DASH_check_DASH_temp801066 = if_helper_arg1161065;
return ann_DASH_check_DASH_temp801066;
});
var anf_if1191064 = R.isBoolean(if_DASH_29959);
if(R.isPyretTrue(anf_if1191064)) {
if(R.isPyretTrue(if_DASH_29959)) {
var if_DASH_30989 = G(options106271,"collect-all",L[98]);
var anf_if142993 = R.isBoolean(if_DASH_30989);
if(R.isPyretTrue(anf_if142993)) {
if(R.isPyretTrue(if_DASH_30989)) {
var anf_fun149971 = G(P711,"trace-make-compiled-pyret",L[94]);
var $z963964 = D;
var $f969970 = function(_) {
return R.isFunction(anf_fun149971)?anf_fun149971.app(ret107272.$var,phase88183.$var,cleaned118797,libs105270):R.ffi.throwNonFunApp(L[93],anf_fun149971,[ret107272.$var,phase88183.$var,cleaned118797,libs105270]);
};
try {
if(--R.GAS > 0) {
$z963964 = $f969970();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f969970,
"from":L[93]});
}
} catch($e961962) {
if(R.isCont($e961962)) {
var $ss965966 = {"from":L[93],
"go":function(cont_tail_arg150972) {
return $Hcont_tail_arg294974(cont_tail_arg150972,if_helper115973);
}};
$e961962.stack[R.EXN_STACKHEIGHT++] = $ss965966;
}
if(R.isPyretException($e961962)) {
$e961962.pyretStack.push(L[93]);
}
throw $e961962;
}
var $ret967968 = $Hcont_tail_arg294974($z963964,if_helper115973);
++R.GAS;
return $ret967968;
} else {
var anf_fun143987 = G(C912,"ok",L[97]);
var anf_fun144985 = G(P711,"make-compiled-pyret",L[96]);
var $z977978 = D;
var $f983984 = function(_) {
return R.isFunction(anf_fun144985)?anf_fun144985.app(cleaned118797,libs105270):R.ffi.throwNonFunApp(L[95],anf_fun144985,[cleaned118797,libs105270]);
};
try {
if(--R.GAS > 0) {
$z977978 = $f983984();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f983984,
"from":L[95]});
}
} catch($e975976) {
if(R.isCont($e975976)) {
var $ss979980 = {"from":L[95],
"go":function(anf_arg145986) {
return $Hanf_arg297988(anf_arg145986,anf_fun143987,if_helper115973,phase88183,ret107272);
}};
$e975976.stack[R.EXN_STACKHEIGHT++] = $ss979980;
}
if(R.isPyretException($e975976)) {
$e975976.pyretStack.push(L[95]);
}
throw $e975976;
}
var $ret981982 = $Hanf_arg297988($z977978,anf_fun143987,if_helper115973,phase88183,ret107272);
++R.GAS;
return $ret981982;
}
} else {
var cont_tail_arg140992 = R.throwNonBooleanCondition(L[98],("if"),if_DASH_30989);
if(--R.GAS > 0) {
$z990991 = R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg140992):R.ffi.throwNonFunApp(L[98],if_helper115973,[cont_tail_arg140992]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg140992):R.ffi.throwNonFunApp(L[98],if_helper115973,[cont_tail_arg140992]);
},
"from":L[98]});
}
++R.GAS;
return $z990991;
}
} else {
var and_DASH_oper_DASH_271024 = G(options106271,"collect-all",L[101]);
var if_helper1201004 = R.makeFunction(function(if_helper_arg1211029) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[99],1,arguments);
}
var if_DASH_261056 = if_helper_arg1211029;
var anf_if1241060 = R.isBoolean(if_DASH_261056);
if(R.isPyretTrue(anf_if1241060)) {
if(R.isPyretTrue(if_DASH_261056)) {
var anf_fun1291040 = G(P711,"trace-make-compiled-pyret",L[103]);
var $z10321033 = D;
var $f10381039 = function(_) {
return R.isFunction(anf_fun1291040)?anf_fun1291040.app(ret107272.$var,phase88183.$var,cleaned118797,libs105270):R.ffi.throwNonFunApp(L[102],anf_fun1291040,[ret107272.$var,phase88183.$var,cleaned118797,libs105270]);
};
try {
if(--R.GAS > 0) {
$z10321033 = $f10381039();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10381039,
"from":L[102]});
}
} catch($e10301031) {
if(R.isCont($e10301031)) {
var $ss10341035 = {"from":L[102],
"go":function(cont_tail_arg1301041) {
return $Hcont_tail_arg2981042(cont_tail_arg1301041,if_helper115973);
}};
$e10301031.stack[R.EXN_STACKHEIGHT++] = $ss10341035;
}
if(R.isPyretException($e10301031)) {
$e10301031.pyretStack.push(L[102]);
}
throw $e10301031;
}
var $ret10361037 = $Hcont_tail_arg2981042($z10321033,if_helper115973);
++R.GAS;
return $ret10361037;
} else {
var anf_fun1251053 = G(C912,"err",L[105]);
var $z10451046 = D;
var $f10511052 = function(_) {
return R.isFunction(anf_fun1251053)?anf_fun1251053.app(any_DASH_errors120947):R.ffi.throwNonFunApp(L[104],anf_fun1251053,[any_DASH_errors120947]);
};
try {
if(--R.GAS > 0) {
$z10451046 = $f10511052();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10511052,
"from":L[104]});
}
} catch($e10431044) {
if(R.isCont($e10431044)) {
var $ss10471048 = {"from":L[104],
"go":function(anf_arg1261054) {
return $Hanf_arg3001055(anf_arg1261054,if_helper115973,phase88183,ret107272);
}};
$e10431044.stack[R.EXN_STACKHEIGHT++] = $ss10471048;
}
if(R.isPyretException($e10431044)) {
$e10431044.pyretStack.push(L[104]);
}
throw $e10431044;
}
var $ret10491050 = $Hanf_arg3001055($z10451046,if_helper115973,phase88183,ret107272);
++R.GAS;
return $ret10491050;
}
} else {
var cont_tail_arg1221059 = R.throwNonBooleanCondition(L[99],("if"),if_DASH_261056);
if(--R.GAS > 0) {
$z10571058 = R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1221059):R.ffi.throwNonFunApp(L[99],if_helper115973,[cont_tail_arg1221059]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1221059):R.ffi.throwNonFunApp(L[99],if_helper115973,[cont_tail_arg1221059]);
},
"from":L[99]});
}
++R.GAS;
return $z10571058;
}
});
var anf_if1341028 = R.isBoolean(and_DASH_oper_DASH_271024);
if(R.isPyretTrue(anf_if1341028)) {
if(R.isPyretTrue(and_DASH_oper_DASH_271024)) {
var and_DASH_oper_DASH_281005 = G(options106271,"ignore-unbound",L[100]);
var anf_if1381011 = R.isBoolean(and_DASH_oper_DASH_281005);
if(R.isPyretTrue(anf_if1381011)) {
var $z996997 = D;
var $f10021003 = function(_) {
return R.isFunction(if_helper1201004)?if_helper1201004.app(and_DASH_oper_DASH_281005):R.ffi.throwNonFunApp(L[99],if_helper1201004,[and_DASH_oper_DASH_281005]);
};
try {
if(--R.GAS > 0) {
$z996997 = $f10021003();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10021003,
"from":L[99]});
}
} catch($e994995) {
if(R.isCont($e994995)) {
var $ss998999 = {"from":L[99],
"go":function(cont_tail_app1391006) {
return $Hcont_tail_app3011007(cont_tail_app1391006);
}};
$e994995.stack[R.EXN_STACKHEIGHT++] = $ss998999;
}
if(R.isPyretException($e994995)) {
$e994995.pyretStack.push(L[99]);
}
throw $e994995;
}
var $ret10001001 = $Hcont_tail_app3011007($z996997);
++R.GAS;
return $ret10001001;
} else {
var cont_tail_arg1361010 = R.throwNonBooleanOp(L[100],("second"),("and"),and_DASH_oper_DASH_281005);
if(--R.GAS > 0) {
$z10081009 = R.isFunction(if_helper1201004)?if_helper1201004.app(cont_tail_arg1361010):R.ffi.throwNonFunApp(L[100],if_helper1201004,[cont_tail_arg1361010]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper1201004)?if_helper1201004.app(cont_tail_arg1361010):R.ffi.throwNonFunApp(L[100],if_helper1201004,[cont_tail_arg1361010]);
},
"from":L[100]});
}
++R.GAS;
return $z10081009;
}
} else {
var $z10141015 = D;
var $f10201021 = function(_) {
return R.isFunction(if_helper1201004)?if_helper1201004.app((false)):R.ffi.throwNonFunApp(L[99],if_helper1201004,[(false)]);
};
try {
if(--R.GAS > 0) {
$z10141015 = $f10201021();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10201021,
"from":L[99]});
}
} catch($e10121013) {
if(R.isCont($e10121013)) {
var $ss10161017 = {"from":L[99],
"go":function(cont_tail_app1351022) {
return $Hcont_tail_app3021023(cont_tail_app1351022);
}};
$e10121013.stack[R.EXN_STACKHEIGHT++] = $ss10161017;
}
if(R.isPyretException($e10121013)) {
$e10121013.pyretStack.push(L[99]);
}
throw $e10121013;
}
var $ret10181019 = $Hcont_tail_app3021023($z10141015);
++R.GAS;
return $ret10181019;
}
} else {
var cont_tail_arg1321027 = R.throwNonBooleanOp(L[101],("first"),("and"),and_DASH_oper_DASH_271024);
if(--R.GAS > 0) {
$z10251026 = R.isFunction(if_helper1201004)?if_helper1201004.app(cont_tail_arg1321027):R.ffi.throwNonFunApp(L[101],if_helper1201004,[cont_tail_arg1321027]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper1201004)?if_helper1201004.app(cont_tail_arg1321027):R.ffi.throwNonFunApp(L[101],if_helper1201004,[cont_tail_arg1321027]);
},
"from":L[101]});
}
++R.GAS;
return $z10251026;
}
}
} else {
var cont_tail_arg1171063 = R.throwNonBooleanCondition(L[92],("if"),if_DASH_29959);
if(--R.GAS > 0) {
$z10611062 = R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1171063):R.ffi.throwNonFunApp(L[92],if_helper115973,[cont_tail_arg1171063]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1171063):R.ffi.throwNonFunApp(L[92],if_helper115973,[cont_tail_arg1171063]);
},
"from":L[92]});
}
++R.GAS;
return $z10611062;
}
};
var $Hcont_tail_arg294974 = function(cont_tail_arg150972,if_helper115973) {
if(--R.GAS > 0) {
$z10671068 = R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg150972):R.ffi.throwNonFunApp(L[93],if_helper115973,[cont_tail_arg150972]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg150972):R.ffi.throwNonFunApp(L[93],if_helper115973,[cont_tail_arg150972]);
},
"from":L[93]});
}
++R.GAS;
return $z10671068;
};
var $Hanf_arg297988 = function(anf_arg145986,anf_fun143987,if_helper115973,phase88183,ret107272) {
var $z10711072 = D;
var $f10771078 = function(_) {
return R.isFunction(anf_fun143987)?anf_fun143987.app(anf_arg145986):R.ffi.throwNonFunApp(L[106],anf_fun143987,[anf_arg145986]);
};
try {
if(--R.GAS > 0) {
$z10711072 = $f10771078();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10771078,
"from":L[106]});
}
} catch($e10691070) {
if(R.isCont($e10691070)) {
var $ss10731074 = {"from":L[106],
"go":function(anf_arg1461079) {
return $Hanf_arg2961080(anf_arg1461079,if_helper115973,phase88183,ret107272);
}};
$e10691070.stack[R.EXN_STACKHEIGHT++] = $ss10731074;
}
if(R.isPyretException($e10691070)) {
$e10691070.pyretStack.push(L[106]);
}
throw $e10691070;
}
var $ret10751076 = $Hanf_arg2961080($z10711072,if_helper115973,phase88183,ret107272);
++R.GAS;
return $ret10751076;
};
var $Hanf_arg2961080 = function(anf_arg1461079,if_helper115973,phase88183,ret107272) {
var $z10831084 = D;
var $f10891090 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Result"),anf_arg1461079,ret107272.$var):R.ffi.throwNonFunApp(L[107],phase88183.$var,[("Result"),anf_arg1461079,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z10831084 = $f10891090();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10891090,
"from":L[107]});
}
} catch($e10811082) {
if(R.isCont($e10811082)) {
var $ss10851086 = {"from":L[107],
"go":function(cont_tail_arg1471091) {
return $Hcont_tail_arg2951092(cont_tail_arg1471091,if_helper115973);
}};
$e10811082.stack[R.EXN_STACKHEIGHT++] = $ss10851086;
}
if(R.isPyretException($e10811082)) {
$e10811082.pyretStack.push(L[107]);
}
throw $e10811082;
}
var $ret10871088 = $Hcont_tail_arg2951092($z10831084,if_helper115973);
++R.GAS;
return $ret10871088;
};
var $Hcont_tail_arg2951092 = function(cont_tail_arg1471091,if_helper115973) {
if(--R.GAS > 0) {
$z10931094 = R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1471091):R.ffi.throwNonFunApp(L[107],if_helper115973,[cont_tail_arg1471091]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1471091):R.ffi.throwNonFunApp(L[107],if_helper115973,[cont_tail_arg1471091]);
},
"from":L[107]});
}
++R.GAS;
return $z10931094;
};
var $Hcont_tail_app3011007 = function(cont_tail_app1391006) {
return cont_tail_app1391006;
};
var $Hcont_tail_app3021023 = function(cont_tail_app1351022) {
return cont_tail_app1351022;
};
var $Hcont_tail_arg2981042 = function(cont_tail_arg1301041,if_helper115973) {
if(--R.GAS > 0) {
$z10951096 = R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1301041):R.ffi.throwNonFunApp(L[102],if_helper115973,[cont_tail_arg1301041]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1301041):R.ffi.throwNonFunApp(L[102],if_helper115973,[cont_tail_arg1301041]);
},
"from":L[102]});
}
++R.GAS;
return $z10951096;
};
var $Hanf_arg3001055 = function(anf_arg1261054,if_helper115973,phase88183,ret107272) {
var $z10991100 = D;
var $f11051106 = function(_) {
return R.isFunction(phase88183.$var)?phase88183.$var.app(("Result"),anf_arg1261054,ret107272.$var):R.ffi.throwNonFunApp(L[108],phase88183.$var,[("Result"),anf_arg1261054,ret107272.$var]);
};
try {
if(--R.GAS > 0) {
$z10991100 = $f11051106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11051106,
"from":L[108]});
}
} catch($e10971098) {
if(R.isCont($e10971098)) {
var $ss11011102 = {"from":L[108],
"go":function(cont_tail_arg1271107) {
return $Hcont_tail_arg2991108(cont_tail_arg1271107,if_helper115973);
}};
$e10971098.stack[R.EXN_STACKHEIGHT++] = $ss11011102;
}
if(R.isPyretException($e10971098)) {
$e10971098.pyretStack.push(L[108]);
}
throw $e10971098;
}
var $ret11031104 = $Hcont_tail_arg2991108($z10991100,if_helper115973);
++R.GAS;
return $ret11031104;
};
var $Hcont_tail_arg2991108 = function(cont_tail_arg1271107,if_helper115973) {
if(--R.GAS > 0) {
$z11091110 = R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1271107):R.ffi.throwNonFunApp(L[108],if_helper115973,[cont_tail_arg1271107]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper115973)?if_helper115973.app(cont_tail_arg1271107):R.ffi.throwNonFunApp(L[108],if_helper115973,[cont_tail_arg1271107]);
},
"from":L[108]});
}
++R.GAS;
return $z11091110;
};
var $Hanf_arg2931111 = function(anf_arg491112,self111113,_plus3,torepr6) {
var anf_arg501124 = G(self111113,"result",L[109]);
var $z11161117 = D;
var $f11221123 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg501124):R.ffi.throwNonFunApp(L[109],torepr6,[anf_arg501124]);
};
try {
if(--R.GAS > 0) {
$z11161117 = $f11221123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11221123,
"from":L[109]});
}
} catch($e11141115) {
if(R.isCont($e11141115)) {
var $ss11181119 = {"from":L[109],
"go":function(anf_arg511125) {
return $Hanf_arg2921126(anf_arg511125,anf_arg491112,self111113,_plus3,torepr6);
}};
$e11141115.stack[R.EXN_STACKHEIGHT++] = $ss11181119;
}
if(R.isPyretException($e11141115)) {
$e11141115.pyretStack.push(L[109]);
}
throw $e11141115;
}
var $ret11201121 = $Hanf_arg2921126($z11161117,anf_arg491112,self111113,_plus3,torepr6);
++R.GAS;
return $ret11201121;
};
var $Hanf_arg2921126 = function(anf_arg511125,anf_arg491112,self111113,_plus3,torepr6) {
var $z11291130 = D;
var $f11351136 = function(_) {
return R.isFunction(_plus3)?_plus3.app((", "),anf_arg511125):R.ffi.throwNonFunApp(L[109],_plus3,[(", "),anf_arg511125]);
};
try {
if(--R.GAS > 0) {
$z11291130 = $f11351136();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11351136,
"from":L[109]});
}
} catch($e11271128) {
if(R.isCont($e11271128)) {
var $ss11311132 = {"from":L[109],
"go":function(anf_arg521137) {
return $Hanf_arg2911138(anf_arg521137,anf_arg491112,self111113,_plus3,torepr6);
}};
$e11271128.stack[R.EXN_STACKHEIGHT++] = $ss11311132;
}
if(R.isPyretException($e11271128)) {
$e11271128.pyretStack.push(L[109]);
}
throw $e11271128;
}
var $ret11331134 = $Hanf_arg2911138($z11291130,anf_arg491112,self111113,_plus3,torepr6);
++R.GAS;
return $ret11331134;
};
var $Hanf_arg2911138 = function(anf_arg521137,anf_arg491112,self111113,_plus3,torepr6) {
var $z11411142 = D;
var $f11471148 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg491112,anf_arg521137):R.ffi.throwNonFunApp(L[109],_plus3,[anf_arg491112,anf_arg521137]);
};
try {
if(--R.GAS > 0) {
$z11411142 = $f11471148();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11471148,
"from":L[109]});
}
} catch($e11391140) {
if(R.isCont($e11391140)) {
var $ss11431144 = {"from":L[109],
"go":function(anf_arg531149) {
return $Hanf_arg2901150(anf_arg531149,self111113,_plus3,torepr6);
}};
$e11391140.stack[R.EXN_STACKHEIGHT++] = $ss11431144;
}
if(R.isPyretException($e11391140)) {
$e11391140.pyretStack.push(L[109]);
}
throw $e11391140;
}
var $ret11451146 = $Hanf_arg2901150($z11411142,self111113,_plus3,torepr6);
++R.GAS;
return $ret11451146;
};
var $Hanf_arg2901150 = function(anf_arg531149,self111113,_plus3,torepr6) {
var anf_arg541161 = G(self111113,"prev",L[109]);
var $z11531154 = D;
var $f11591160 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg541161):R.ffi.throwNonFunApp(L[109],torepr6,[anf_arg541161]);
};
try {
if(--R.GAS > 0) {
$z11531154 = $f11591160();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11591160,
"from":L[109]});
}
} catch($e11511152) {
if(R.isCont($e11511152)) {
var $ss11551156 = {"from":L[109],
"go":function(anf_arg551162) {
return $Hanf_arg2891163(anf_arg551162,anf_arg531149,_plus3);
}};
$e11511152.stack[R.EXN_STACKHEIGHT++] = $ss11551156;
}
if(R.isPyretException($e11511152)) {
$e11511152.pyretStack.push(L[109]);
}
throw $e11511152;
}
var $ret11571158 = $Hanf_arg2891163($z11531154,anf_arg531149,_plus3);
++R.GAS;
return $ret11571158;
};
var $Hanf_arg2891163 = function(anf_arg551162,anf_arg531149,_plus3) {
var $z11661167 = D;
var $f11721173 = function(_) {
return R.isFunction(_plus3)?_plus3.app((", "),anf_arg551162):R.ffi.throwNonFunApp(L[109],_plus3,[(", "),anf_arg551162]);
};
try {
if(--R.GAS > 0) {
$z11661167 = $f11721173();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11721173,
"from":L[109]});
}
} catch($e11641165) {
if(R.isCont($e11641165)) {
var $ss11681169 = {"from":L[109],
"go":function(anf_arg561174) {
return $Hanf_arg2881175(anf_arg561174,anf_arg531149,_plus3);
}};
$e11641165.stack[R.EXN_STACKHEIGHT++] = $ss11681169;
}
if(R.isPyretException($e11641165)) {
$e11641165.pyretStack.push(L[109]);
}
throw $e11641165;
}
var $ret11701171 = $Hanf_arg2881175($z11661167,anf_arg531149,_plus3);
++R.GAS;
return $ret11701171;
};
var $Hanf_arg2881175 = function(anf_arg561174,anf_arg531149,_plus3) {
var $z11781179 = D;
var $f11841185 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg531149,anf_arg561174):R.ffi.throwNonFunApp(L[109],_plus3,[anf_arg531149,anf_arg561174]);
};
try {
if(--R.GAS > 0) {
$z11781179 = $f11841185();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11841185,
"from":L[109]});
}
} catch($e11761177) {
if(R.isCont($e11761177)) {
var $ss11801181 = {"from":L[109],
"go":function(anf_arg571186) {
return $Hanf_arg2871187(anf_arg571186,_plus3);
}};
$e11761177.stack[R.EXN_STACKHEIGHT++] = $ss11801181;
}
if(R.isPyretException($e11761177)) {
$e11761177.pyretStack.push(L[109]);
}
throw $e11761177;
}
var $ret11821183 = $Hanf_arg2871187($z11781179,_plus3);
++R.GAS;
return $ret11821183;
};
var $Hanf_arg2871187 = function(anf_arg571186,_plus3) {
var $z11901191 = D;
var $f11961197 = function(_) {
return R.isFunction(_plus3)?_plus3.app(anf_arg571186,(")")):R.ffi.throwNonFunApp(L[109],_plus3,[anf_arg571186,(")")]);
};
try {
if(--R.GAS > 0) {
$z11901191 = $f11961197();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11961197,
"from":L[109]});
}
} catch($e11881189) {
if(R.isCont($e11881189)) {
var $ss11921193 = {"from":L[109],
"go":function(anf_arg581198) {
return $Hanf_arg2861199(anf_arg581198,_plus3);
}};
$e11881189.stack[R.EXN_STACKHEIGHT++] = $ss11921193;
}
if(R.isPyretException($e11881189)) {
$e11881189.pyretStack.push(L[109]);
}
throw $e11881189;
}
var $ret11941195 = $Hanf_arg2861199($z11901191,_plus3);
++R.GAS;
return $ret11941195;
};
var $Hanf_arg2861199 = function(anf_arg581198,_plus3) {
var $z12021203 = D;
var $f12081209 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("("),anf_arg581198):R.ffi.throwNonFunApp(L[109],_plus3,[("("),anf_arg581198]);
};
try {
if(--R.GAS > 0) {
$z12021203 = $f12081209();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12081209,
"from":L[109]});
}
} catch($e12001201) {
if(R.isCont($e12001201)) {
var $ss12041205 = {"from":L[109],
"go":function(anf_arg591210) {
return $Hanf_arg2851211(anf_arg591210,_plus3);
}};
$e12001201.stack[R.EXN_STACKHEIGHT++] = $ss12041205;
}
if(R.isPyretException($e12001201)) {
$e12001201.pyretStack.push(L[109]);
}
throw $e12001201;
}
var $ret12061207 = $Hanf_arg2851211($z12021203,_plus3);
++R.GAS;
return $ret12061207;
};
var $Hanf_arg2851211 = function(anf_arg591210,_plus3) {
var $z12141215 = D;
var $f12201221 = function(_) {
return R.isFunction(_plus3)?_plus3.app(("phase"),anf_arg591210):R.ffi.throwNonFunApp(L[109],_plus3,[("phase"),anf_arg591210]);
};
try {
if(--R.GAS > 0) {
$z12141215 = $f12201221();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12201221,
"from":L[109]});
}
} catch($e12121213) {
if(R.isCont($e12121213)) {
var $ss12161217 = {"from":L[109],
"go":function(ann_DASH_check_DASH_temp471222) {
return $Hann_DASH_check_DASH_temp2841223(ann_DASH_check_DASH_temp471222);
}};
$e12121213.stack[R.EXN_STACKHEIGHT++] = $ss12161217;
}
if(R.isPyretException($e12121213)) {
$e12121213.pyretStack.push(L[109]);
}
throw $e12121213;
}
var $ret12181219 = $Hann_DASH_check_DASH_temp2841223($z12141215);
++R.GAS;
return $ret12181219;
};
var $Hann_DASH_check_DASH_temp2841223 = function(ann_DASH_check_DASH_temp471222) {
return ann_DASH_check_DASH_temp471222;
};
var $Hcont_tail_arg2821224 = function(cont_tail_arg441225,if_helper341226) {
if(--R.GAS > 0) {
$z12271228 = R.isFunction(if_helper341226)?if_helper341226.app(cont_tail_arg441225):R.ffi.throwNonFunApp(L[109],if_helper341226,[cont_tail_arg441225]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper341226)?if_helper341226.app(cont_tail_arg441225):R.ffi.throwNonFunApp(L[109],if_helper341226,[cont_tail_arg441225]);
},
"from":L[109]});
}
++R.GAS;
return $z12271228;
};
var $Hcont_tail_arg2831229 = function(cont_tail_arg391230,if_helper341226) {
if(--R.GAS > 0) {
$z12311232 = R.isFunction(if_helper341226)?if_helper341226.app(cont_tail_arg391230):R.ffi.throwNonFunApp(L[109],if_helper341226,[cont_tail_arg391230]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper341226)?if_helper341226.app(cont_tail_arg391230):R.ffi.throwNonFunApp(L[109],if_helper341226,[cont_tail_arg391230]);
},
"from":L[109]});
}
++R.GAS;
return $z12311232;
};
var $Hcont_tail_arg2801233 = function(cont_tail_arg281234,if_helper211235) {
if(--R.GAS > 0) {
$z12361237 = R.isFunction(if_helper211235)?if_helper211235.app(cont_tail_arg281234):R.ffi.throwNonFunApp(L[110],if_helper211235,[cont_tail_arg281234]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper211235)?if_helper211235.app(cont_tail_arg281234):R.ffi.throwNonFunApp(L[110],if_helper211235,[cont_tail_arg281234]);
},
"from":L[110]});
}
++R.GAS;
return $z12361237;
};
var $Hcont_tail_arg2811238 = function(cont_tail_arg261239,if_helper211235) {
if(--R.GAS > 0) {
$z12401241 = R.isFunction(if_helper211235)?if_helper211235.app(cont_tail_arg261239):R.ffi.throwNonFunApp(L[110],if_helper211235,[cont_tail_arg261239]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper211235)?if_helper211235.app(cont_tail_arg261239):R.ffi.throwNonFunApp(L[110],if_helper211235,[cont_tail_arg261239]);
},
"from":L[110]});
}
++R.GAS;
return $z12401241;
};
var $Hann_DASH_check_DASH_temp2791242 = function(ann_DASH_check_DASH_temp11243) {
return ann_DASH_check_DASH_temp11243;
};
var $Hif_DASH_2781244 = function(if_DASH_141245,acc1011246,help991247,link431248,the_DASH_phase1001249) {
var if_helper31260 = R.makeFunction(function(if_helper_arg41297) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[116],1,arguments);
}
var ann_DASH_check_DASH_temp21298 = if_helper_arg41297;
return ann_DASH_check_DASH_temp21298;
});
var anf_if71296 = R.isBoolean(if_DASH_141245);
if(R.isPyretTrue(anf_if71296)) {
if(R.isPyretTrue(if_DASH_141245)) {
var $z12521253 = D;
var $f12581259 = function(_) {
return R.isFunction(if_helper31260)?if_helper31260.app(acc1011246):R.ffi.throwNonFunApp(L[111],if_helper31260,[acc1011246]);
};
try {
if(--R.GAS > 0) {
$z12521253 = $f12581259();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12581259,
"from":L[111]});
}
} catch($e12501251) {
if(R.isCont($e12501251)) {
var $ss12541255 = {"from":L[111],
"go":function(cont_tail_app171261) {
return $Hcont_tail_app2741262(cont_tail_app171261);
}};
$e12501251.stack[R.EXN_STACKHEIGHT++] = $ss12541255;
}
if(R.isPyretException($e12501251)) {
$e12501251.pyretStack.push(L[111]);
}
throw $e12501251;
}
var $ret12561257 = $Hcont_tail_app2741262($z12521253);
++R.GAS;
return $ret12561257;
} else {
var anf_arg81276 = G(the_DASH_phase1001249,"prev",L[115]);
var anf_fun101273 = R.makeFunction(function(arg_DASH_131280) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[112],1,arguments);
}
var $z12831284 = D;
var $f12891290 = function(_) {
return R.isFunction(link431248)?link431248.app(arg_DASH_131280,acc1011246):R.ffi.throwNonFunApp(L[112],link431248,[arg_DASH_131280,acc1011246]);
};
try {
if(--R.GAS > 0) {
$z12831284 = $f12891290();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12891290,
"from":L[112]});
}
} catch($e12811282) {
if(R.isCont($e12811282)) {
var $ss12851286 = {"from":L[112],
"go":function(ann_DASH_check_DASH_temp91291) {
return $Hann_DASH_check_DASH_temp2751292(ann_DASH_check_DASH_temp91291);
}};
$e12811282.stack[R.EXN_STACKHEIGHT++] = $ss12851286;
}
if(R.isPyretException($e12811282)) {
$e12811282.pyretStack.push(L[112]);
}
throw $e12811282;
}
var $ret12871288 = $Hann_DASH_check_DASH_temp2751292($z12831284);
++R.GAS;
return $ret12871288;
});
var anf_obj111278 = G(the_DASH_phase1001249,"name",L[114]);
var anf_obj121279 = G(the_DASH_phase1001249,"result",L[113]);
var anf_arg131274 = R.makeObject({"name":anf_obj111278,
"result":anf_obj121279});
var $z12651266 = D;
var $f12711272 = function(_) {
return R.isFunction(anf_fun101273)?anf_fun101273.app(anf_arg131274):R.ffi.throwNonFunApp(L[112],anf_fun101273,[anf_arg131274]);
};
try {
if(--R.GAS > 0) {
$z12651266 = $f12711272();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12711272,
"from":L[112]});
}
} catch($e12631264) {
if(R.isCont($e12631264)) {
var $ss12671268 = {"from":L[112],
"go":function(anf_arg141275) {
return $Hanf_arg2771277(anf_arg141275,anf_arg81276,help991247,if_helper31260);
}};
$e12631264.stack[R.EXN_STACKHEIGHT++] = $ss12671268;
}
if(R.isPyretException($e12631264)) {
$e12631264.pyretStack.push(L[112]);
}
throw $e12631264;
}
var $ret12691270 = $Hanf_arg2771277($z12651266,anf_arg81276,help991247,if_helper31260);
++R.GAS;
return $ret12691270;
}
} else {
var cont_tail_arg51295 = R.throwNonBooleanCondition(L[116],("if"),if_DASH_141245);
if(--R.GAS > 0) {
$z12931294 = R.isFunction(if_helper31260)?if_helper31260.app(cont_tail_arg51295):R.ffi.throwNonFunApp(L[116],if_helper31260,[cont_tail_arg51295]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper31260)?if_helper31260.app(cont_tail_arg51295):R.ffi.throwNonFunApp(L[116],if_helper31260,[cont_tail_arg51295]);
},
"from":L[116]});
}
++R.GAS;
return $z12931294;
}
};
var $Hcont_tail_app2741262 = function(cont_tail_app171261) {
return cont_tail_app171261;
};
var $Hanf_arg2771277 = function(anf_arg141275,anf_arg81276,help991247,if_helper31260) {
var $z13011302 = D;
var $f13071308 = function(_) {
return R.isFunction(help991247.$var)?help991247.$var.app(anf_arg81276,anf_arg141275):R.ffi.throwNonFunApp(L[117],help991247.$var,[anf_arg81276,anf_arg141275]);
};
try {
if(--R.GAS > 0) {
$z13011302 = $f13071308();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13071308,
"from":L[117]});
}
} catch($e12991300) {
if(R.isCont($e12991300)) {
var $ss13031304 = {"from":L[117],
"go":function(cont_tail_arg151309) {
return $Hcont_tail_arg2761310(cont_tail_arg151309,if_helper31260);
}};
$e12991300.stack[R.EXN_STACKHEIGHT++] = $ss13031304;
}
if(R.isPyretException($e12991300)) {
$e12991300.pyretStack.push(L[117]);
}
throw $e12991300;
}
var $ret13051306 = $Hcont_tail_arg2761310($z13011302,if_helper31260);
++R.GAS;
return $ret13051306;
};
var $Hcont_tail_arg2761310 = function(cont_tail_arg151309,if_helper31260) {
if(--R.GAS > 0) {
$z13111312 = R.isFunction(if_helper31260)?if_helper31260.app(cont_tail_arg151309):R.ffi.throwNonFunApp(L[117],if_helper31260,[cont_tail_arg151309]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper31260)?if_helper31260.app(cont_tail_arg151309):R.ffi.throwNonFunApp(L[117],if_helper31260,[cont_tail_arg151309]);
},
"from":L[117]});
}
++R.GAS;
return $z13111312;
};
var $Hann_DASH_check_DASH_temp2751292 = function(ann_DASH_check_DASH_temp91291) {
return ann_DASH_check_DASH_temp91291;
};
return R.loadModulesNew(NAMESPACE,[$F1839,$A3940,$PP51041,$P71142,$C91243,$W111344,$U131445,$R151546,$D171647,$CH191748,$arrays211849,$lists231950,$option252051,$error272152,$sets292253],function($F1839,$A3940,$PP51041,$P71142,$C91243,$W111344,$U131445,$R151546,$D171647,$CH191748,$arrays211849,$lists231950,$option252051,$error272152,$sets292253) {
var F18 = R.getField($F1839,"values");
var A39 = R.getField($A3940,"values");
var PP510 = R.getField($PP51041,"values");
var P711 = R.getField($P71142,"values");
var C912 = R.getField($C91243,"values");
var W1113 = R.getField($W111344,"values");
var U1314 = R.getField($U131445,"values");
var R1515 = R.getField($R151546,"values");
var D1716 = R.getField($D171647,"values");
var CH1917 = R.getField($CH191748,"values");
var arrays2118 = R.getField($arrays211849,"values");
var lists2319 = R.getField($lists231950,"values");
var option2520 = R.getField($option252051,"values");
var error2721 = R.getField($error272152,"values");
var sets2922 = R.getField($sets292253,"values");
var F223 = R.getField($F1839,"types");
var A424 = R.getField($A3940,"types");
var PP625 = R.getField($PP51041,"types");
var P826 = R.getField($P71142,"types");
var C1027 = R.getField($C91243,"types");
var W1228 = R.getField($W111344,"types");
var U1429 = R.getField($U131445,"types");
var R1630 = R.getField($R151546,"types");
var D1831 = R.getField($D171647,"types");
var CH2032 = R.getField($CH191748,"types");
var arrays2233 = R.getField($arrays211849,"types");
var lists2434 = R.getField($lists231950,"types");
var option2635 = R.getField($option252051,"types");
var error2836 = R.getField($error272152,"types");
var sets3037 = R.getField($sets292253,"types");
return R.safeCall(function() {
var List311313 = R.getDotAnn(L[118],"lists",lists2434,"List");
var Option321314 = R.getDotAnn(L[118],"option",option2635,"Option");
var Array331315 = R.getDotAnn(L[118],"arrays",arrays2233,"Array");
var Set341316 = R.getDotAnn(L[118],"sets",sets3037,"Set");
var array351589 = G(arrays2118,"array",L[118]);
var build_DASH_array361588 = G(arrays2118,"build-array",L[118]);
var array_DASH_from_DASH_list371587 = G(arrays2118,"array-from-list",L[118]);
var is_DASH_array381586 = G(arrays2118,"is-array",L[118]);
var list391585 = G(lists2319,"list",L[118]);
var is_DASH_empty40268 = G(lists2319,"is-empty",L[118]);
var is_DASH_link411584 = G(lists2319,"is-link",L[118]);
var empty421538 = G(lists2319,"empty",L[118]);
var link431248 = G(lists2319,"link",L[118]);
var range441583 = G(lists2319,"range",L[118]);
var repeat451582 = G(lists2319,"repeat",L[118]);
var filter461581 = G(lists2319,"filter",L[118]);
var partition471580 = G(lists2319,"partition",L[118]);
var split_DASH_at481579 = G(lists2319,"split-at",L[118]);
var any491578 = G(lists2319,"any",L[118]);
var find501577 = G(lists2319,"find",L[118]);
var map511576 = G(lists2319,"map",L[118]);
var map2521575 = G(lists2319,"map2",L[118]);
var map3531574 = G(lists2319,"map3",L[118]);
var map4541573 = G(lists2319,"map4",L[118]);
var map_n551572 = G(lists2319,"map_n",L[118]);
var map2_n561571 = G(lists2319,"map2_n",L[118]);
var map3_n571570 = G(lists2319,"map3_n",L[118]);
var map4_n581569 = G(lists2319,"map4_n",L[118]);
var each591568 = G(lists2319,"each",L[118]);
var each2601567 = G(lists2319,"each2",L[118]);
var each3611566 = G(lists2319,"each3",L[118]);
var each4621565 = G(lists2319,"each4",L[118]);
var each_n631564 = G(lists2319,"each_n",L[118]);
var each2_n641563 = G(lists2319,"each2_n",L[118]);
var each3_n651562 = G(lists2319,"each3_n",L[118]);
var each4_n661561 = G(lists2319,"each4_n",L[118]);
var fold671560 = G(lists2319,"fold",L[118]);
var fold2681559 = G(lists2319,"fold2",L[118]);
var fold3691558 = G(lists2319,"fold3",L[118]);
var fold4701557 = G(lists2319,"fold4",L[118]);
var index711556 = G(lists2319,"index",L[118]);
var Option721555 = G(option2520,"Option",L[118]);
var is_DASH_none731554 = G(option2520,"is-none",L[118]);
var is_DASH_some74269 = G(option2520,"is-some",L[118]);
var none751553 = G(option2520,"none",L[118]);
var some761552 = G(option2520,"some",L[118]);
var set771551 = G(sets2922,"set",L[118]);
var tree_DASH_set781550 = G(sets2922,"tree-set",L[118]);
var list_DASH_set791549 = G(sets2922,"list-set",L[118]);
var CompilationPhaseT1811317 = R.namedBrander("CompilationPhase");
var CompilationPhase8056 = R.makeBranderAnn(CompilationPhaseT1811317,"CompilationPhase");
var CompilationPhase2821318 = {"$var":D,
"$name":"CompilationPhase2"};
var CompilationPhase831320 = {"$var":D,
"$name":"CompilationPhase"};
var is_DASH_CompilationPhase841322 = {"$var":D,
"$name":"is-CompilationPhase"};
var is_DASH_start851324 = {"$var":D,
"$name":"is-start"};
var start861326 = {"$var":D,
"$name":"start"};
var is_DASH_phase871328 = {"$var":D,
"$name":"is-phase"};
var phase88183 = {"$var":D,
"$name":"phase"};
var compile_DASH_js_DASH_ast89178 = {"$var":D,
"$name":"compile-js-ast"};
var compile_DASH_js901332 = {"$var":D,
"$name":"compile-js"};
var compile_DASH_runnable_DASH_js91143 = {"$var":D,
"$name":"compile-runnable-js"};
var compile_DASH_runnable_DASH_js_DASH_file921335 = {"$var":D,
"$name":"compile-runnable-js-file"};
var compile_DASH_standalone_DASH_js_DASH_file931337 = {"$var":D,
"$name":"compile-standalone-js-file"};
var compile_DASH_standalone_DASH_js94124 = {"$var":D,
"$name":"compile-standalone-js"};
var anf_shared191430 = R.makeMethod(function(self981537) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[135],0,arguments);
}
var help991247 = {"$var":D,
"$name":"help"};
var anf_assign181526 = R.makeFunction(function(the_DASH_phase1001249,acc1011246) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[136],2,arguments);
}
var $z15411542 = D;
var $f15471548 = function(_) {
return R.isFunction(is_DASH_start851324.$var === D?U(L[137],"is-start"):is_DASH_start851324.$var)?is_DASH_start851324.$var === D?U(L[137],"is-start"):is_DASH_start851324.$var.app(the_DASH_phase1001249):R.ffi.throwNonFunApp(L[116],is_DASH_start851324.$var === D?U(L[137],"is-start"):is_DASH_start851324.$var,[the_DASH_phase1001249]);
};
try {
if(--R.GAS > 0) {
$z15411542 = $f15471548();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15471548,
"from":L[116]});
}
} catch($e15391540) {
if(R.isCont($e15391540)) {
var $ss15431544 = {"from":L[116],
"go":function(if_DASH_141245) {
return $Hif_DASH_2781244(if_DASH_141245,acc1011246,help991247,link431248,the_DASH_phase1001249);
}};
$e15391540.stack[R.EXN_STACKHEIGHT++] = $ss15431544;
}
if(R.isPyretException($e15391540)) {
$e15391540.pyretStack.push(L[116]);
}
throw $e15391540;
}
var $ret15451546 = $Hif_DASH_2781244($z15411542,acc1011246,help991247,link431248,the_DASH_phase1001249);
++R.GAS;
return $ret15451546;
});
help991247.$var = anf_assign181526;
var $z15291530 = D;
var $f15351536 = function(_) {
return R.isFunction(help991247.$var)?help991247.$var.app(self981537,empty421538):R.ffi.throwNonFunApp(L[135],help991247.$var,[self981537,empty421538]);
};
try {
if(--R.GAS > 0) {
$z15291530 = $f15351536();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15351536,
"from":L[135]});
}
} catch($e15271528) {
if(R.isCont($e15271528)) {
var $ss15311532 = {"from":L[135],
"go":function(ann_DASH_check_DASH_temp11243) {
return $Hann_DASH_check_DASH_temp2791242(ann_DASH_check_DASH_temp11243);
}};
$e15271528.stack[R.EXN_STACKHEIGHT++] = $ss15311532;
}
if(R.isPyretException($e15271528)) {
$e15271528.pyretStack.push(L[135]);
}
throw $e15271528;
}
var $ret15331534 = $Hann_DASH_check_DASH_temp2791242($z15291530);
++R.GAS;
return $ret15331534;
};
},{"length":1});
var anf_singleton_variant_member301436 = R.makeMethod(function(self21525) {
return function(cases_DASH_funs31506,else_DASH_clause41517) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[110],2,arguments);
}
var if_DASH_61518 = R.hasField(cases_DASH_funs31506,("start"));
var if_helper211235 = R.makeFunction(function(if_helper_arg221523) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[110],1,arguments);
}
var ann_DASH_check_DASH_temp201524 = if_helper_arg221523;
return ann_DASH_check_DASH_temp201524;
});
var anf_if251522 = R.isBoolean(if_DASH_61518);
if(R.isPyretTrue(anf_if251522)) {
if(R.isPyretTrue(if_DASH_61518)) {
var call_DASH_start11505 = G(cases_DASH_funs31506,"start",L[110]);
var $z14971498 = D;
var $f15031504 = function(_) {
return R.isFunction(call_DASH_start11505)?call_DASH_start11505.app():R.ffi.throwNonFunApp(L[110],call_DASH_start11505,[]);
};
try {
if(--R.GAS > 0) {
$z14971498 = $f15031504();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15031504,
"from":L[110]});
}
} catch($e14951496) {
if(R.isCont($e14951496)) {
var $ss14991500 = {"from":L[110],
"go":function(cont_tail_arg281234) {
return $Hcont_tail_arg2801233(cont_tail_arg281234,if_helper211235);
}};
$e14951496.stack[R.EXN_STACKHEIGHT++] = $ss14991500;
}
if(R.isPyretException($e14951496)) {
$e14951496.pyretStack.push(L[110]);
}
throw $e14951496;
}
var $ret15011502 = $Hcont_tail_arg2801233($z14971498,if_helper211235);
++R.GAS;
return $ret15011502;
} else {
var $z15091510 = D;
var $f15151516 = function(_) {
return R.isFunction(else_DASH_clause41517)?else_DASH_clause41517.app():R.ffi.throwNonFunApp(L[110],else_DASH_clause41517,[]);
};
try {
if(--R.GAS > 0) {
$z15091510 = $f15151516();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15151516,
"from":L[110]});
}
} catch($e15071508) {
if(R.isCont($e15071508)) {
var $ss15111512 = {"from":L[110],
"go":function(cont_tail_arg261239) {
return $Hcont_tail_arg2811238(cont_tail_arg261239,if_helper211235);
}};
$e15071508.stack[R.EXN_STACKHEIGHT++] = $ss15111512;
}
if(R.isPyretException($e15071508)) {
$e15071508.pyretStack.push(L[110]);
}
throw $e15071508;
}
var $ret15131514 = $Hcont_tail_arg2811238($z15091510,if_helper211235);
++R.GAS;
return $ret15131514;
}
} else {
var cont_tail_arg231521 = R.throwNonBooleanCondition(L[110],("if"),if_DASH_61518);
if(--R.GAS > 0) {
$z15191520 = R.isFunction(if_helper211235)?if_helper211235.app(cont_tail_arg231521):R.ffi.throwNonFunApp(L[110],if_helper211235,[cont_tail_arg231521]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper211235)?if_helper211235.app(cont_tail_arg231521):R.ffi.throwNonFunApp(L[110],if_helper211235,[cont_tail_arg231521]);
},
"from":L[110]});
}
++R.GAS;
return $z15191520;
}
};
},{"length":3});
var anf_singleton_variant_member321437 = R.makeMethod(function(self51494) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[110],0,arguments);
}
var ann_DASH_check_DASH_temp311493 = ("start");
return ann_DASH_check_DASH_temp311493;
};
},{"length":1});
var anf_variant_member461443 = R.makeMethod(function(self81473) {
return function(cases_DASH_funs91474,else_DASH_clause101485) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[109],2,arguments);
}
var if_DASH_121486 = R.hasField(cases_DASH_funs91474,("phase"));
var if_helper341226 = R.makeFunction(function(if_helper_arg351491) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[109],1,arguments);
}
var ann_DASH_check_DASH_temp331492 = if_helper_arg351491;
return ann_DASH_check_DASH_temp331492;
});
var anf_if381490 = R.isBoolean(if_DASH_121486);
if(R.isPyretTrue(anf_if381490)) {
if(R.isPyretTrue(if_DASH_121486)) {
var call_DASH_phase71469 = G(cases_DASH_funs91474,"phase",L[109]);
var anf_arg411470 = G(self81473,"name",L[134]);
var anf_arg421471 = G(self81473,"result",L[133]);
var anf_arg431472 = G(self81473,"prev",L[132]);
var $z14611462 = D;
var $f14671468 = function(_) {
return R.isFunction(call_DASH_phase71469)?call_DASH_phase71469.app(anf_arg411470,anf_arg421471,anf_arg431472):R.ffi.throwNonFunApp(L[109],call_DASH_phase71469,[anf_arg411470,anf_arg421471,anf_arg431472]);
};
try {
if(--R.GAS > 0) {
$z14611462 = $f14671468();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14671468,
"from":L[109]});
}
} catch($e14591460) {
if(R.isCont($e14591460)) {
var $ss14631464 = {"from":L[109],
"go":function(cont_tail_arg441225) {
return $Hcont_tail_arg2821224(cont_tail_arg441225,if_helper341226);
}};
$e14591460.stack[R.EXN_STACKHEIGHT++] = $ss14631464;
}
if(R.isPyretException($e14591460)) {
$e14591460.pyretStack.push(L[109]);
}
throw $e14591460;
}
var $ret14651466 = $Hcont_tail_arg2821224($z14611462,if_helper341226);
++R.GAS;
return $ret14651466;
} else {
var $z14771478 = D;
var $f14831484 = function(_) {
return R.isFunction(else_DASH_clause101485)?else_DASH_clause101485.app():R.ffi.throwNonFunApp(L[109],else_DASH_clause101485,[]);
};
try {
if(--R.GAS > 0) {
$z14771478 = $f14831484();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14831484,
"from":L[109]});
}
} catch($e14751476) {
if(R.isCont($e14751476)) {
var $ss14791480 = {"from":L[109],
"go":function(cont_tail_arg391230) {
return $Hcont_tail_arg2831229(cont_tail_arg391230,if_helper341226);
}};
$e14751476.stack[R.EXN_STACKHEIGHT++] = $ss14791480;
}
if(R.isPyretException($e14751476)) {
$e14751476.pyretStack.push(L[109]);
}
throw $e14751476;
}
var $ret14811482 = $Hcont_tail_arg2831229($z14771478,if_helper341226);
++R.GAS;
return $ret14811482;
}
} else {
var cont_tail_arg361489 = R.throwNonBooleanCondition(L[109],("if"),if_DASH_121486);
if(--R.GAS > 0) {
$z14871488 = R.isFunction(if_helper341226)?if_helper341226.app(cont_tail_arg361489):R.ffi.throwNonFunApp(L[109],if_helper341226,[cont_tail_arg361489]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored214) {
return R.isFunction(if_helper341226)?if_helper341226.app(cont_tail_arg361489):R.ffi.throwNonFunApp(L[109],if_helper341226,[cont_tail_arg361489]);
},
"from":L[109]});
}
++R.GAS;
return $z14871488;
}
};
},{"length":3});
var anf_variant_member601444 = R.makeMethod(function(self111113) {
return function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[109],0,arguments);
}
var anf_arg481458 = G(self111113,"name",L[109]);
var $z14501451 = D;
var $f14561457 = function(_) {
return R.isFunction(torepr6)?torepr6.app(anf_arg481458):R.ffi.throwNonFunApp(L[109],torepr6,[anf_arg481458]);
};
try {
if(--R.GAS > 0) {
$z14501451 = $f14561457();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14561457,
"from":L[109]});
}
} catch($e14481449) {
if(R.isCont($e14481449)) {
var $ss14521453 = {"from":L[109],
"go":function(anf_arg491112) {
return $Hanf_arg2931111(anf_arg491112,self111113,_plus3,torepr6);
}};
$e14481449.stack[R.EXN_STACKHEIGHT++] = $ss14521453;
}
if(R.isPyretException($e14481449)) {
$e14481449.pyretStack.push(L[109]);
}
throw $e14481449;
}
var $ret14541455 = $Hanf_arg2931111($z14501451,self111113,_plus3,torepr6);
++R.GAS;
return $ret14541455;
};
},{"length":1});
var anf_assign611319 = (function() {
var $start_DASH_base14311432 = {"tolist":anf_shared191430,
"_match":anf_singleton_variant_member301436,
"_torepr":anf_singleton_variant_member321437};
var $start_DASH_brands14341435 = {"$brand-start1433":true};
$start_DASH_brands14341435[CompilationPhaseT1811317._brand] = true
var $phase_DASH_base14381439 = {"tolist":anf_shared191430,
"_match":anf_variant_member461443,
"_torepr":anf_variant_member601444};
var $phase_DASH_brands14411442 = {"$brand-phase1440":true};
$phase_DASH_brands14411442[CompilationPhaseT1811317._brand] = true
return R.makeObject({"CompilationPhase":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[0],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,CompilationPhaseT1811317._brand));
}),
"is-start":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[110],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-start1433"));
}),
"start":R.makeBrandedObject($start_DASH_base14311432,$start_DASH_brands14341435),
"is-phase":R.makeFunction(function(val) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[109],1,arguments);
}
return R.makeBoolean(R.hasBrand(val,"$brand-phase1440"));
}),
"phase":R.makeFunction(function(name951445,result961446,prev971447) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[129],3,arguments);
}
return R.checkAnnArgs([$type$String7,CompilationPhase8056],[name951445,prev971447],[L[130],L[131]],function() {
var dict = R.create($phase_DASH_base14381439);
dict["name"] = name951445
dict["result"] = result961446
dict["prev"] = prev971447
return R.makeBrandedObject(dict,$phase_DASH_brands14411442);
});
})});
})();
CompilationPhase2821318.$var = anf_assign611319;
var anf_assign621321 = G(CompilationPhase2821318.$var,"CompilationPhase",L[0]);
CompilationPhase831320.$var = anf_assign621321;
var anf_assign631323 = G(CompilationPhase2821318.$var,"CompilationPhase",L[0]);
is_DASH_CompilationPhase841322.$var = anf_assign631323;
var anf_assign641325 = G(CompilationPhase2821318.$var,"is-start",L[110]);
is_DASH_start851324.$var = anf_assign641325;
var anf_assign651327 = G(CompilationPhase2821318.$var,"start",L[110]);
start861326.$var = anf_assign651327;
var anf_assign661329 = G(CompilationPhase2821318.$var,"is-phase",L[109]);
is_DASH_phase871328.$var = anf_assign661329;
var anf_assign671330 = G(CompilationPhase2821318.$var,"phase",L[109]);
phase88183.$var = anf_assign671330;
var anf_assign2281331 = R.makeFunction(function(phases1021417,ast103267,name1041418,libs105270,options106271) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[36],5,arguments);
}
var ret107272 = {"$var":phases1021417,
"$name":"ret"};
var anf_fun691429 = G(U1314,"append-nothing-if-necessary",L[128]);
var $z14211422 = D;
var $f14271428 = function(_) {
return R.isFunction(anf_fun691429)?anf_fun691429.app(ast103267):R.ffi.throwNonFunApp(L[127],anf_fun691429,[ast103267]);
};
try {
if(--R.GAS > 0) {
$z14211422 = $f14271428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14271428,
"from":L[127]});
}
} catch($e14191420) {
if(R.isCont($e14191420)) {
var $ss14231424 = {"from":L[127],
"go":function(ast_DASH_ended108266) {
return $Hast_DASH_ended351265(ast_DASH_ended108266,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,W1113,ast103267,is_DASH_empty40268,is_DASH_some74269,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
}};
$e14191420.stack[R.EXN_STACKHEIGHT++] = $ss14231424;
}
if(R.isPyretException($e14191420)) {
$e14191420.pyretStack.push(L[127]);
}
throw $e14191420;
}
var $ret14251426 = $Hast_DASH_ended351265($z14211422,C912,CH1917,CompilationPhase8056,D1716,P711,R1515,U1314,W1113,ast103267,is_DASH_empty40268,is_DASH_some74269,libs105270,options106271,phase88183,ret107272,_plus3,nothing5);
++R.GAS;
return $ret14251426;
});
compile_DASH_js_DASH_ast89178.$var = anf_assign2281331;
var anf_assign2411333 = R.makeFunction(function(trace1221404,dialect123179,code1241405,name125181,libs126180,options127182) {
if(arguments.length !== 6) {
throw R.ffi.throwArityErrorC(L[18],6,arguments);
}
var ret128184 = {"$var":trace1221404,
"$name":"ret"};
var anf_fun2301416 = G(PP510,"parse-dialect",L[126]);
var $z14081409 = D;
var $f14141415 = function(_) {
return R.isFunction(anf_fun2301416)?anf_fun2301416.app(dialect123179,code1241405,name125181):R.ffi.throwNonFunApp(L[125],anf_fun2301416,[dialect123179,code1241405,name125181]);
};
try {
if(--R.GAS > 0) {
$z14081409 = $f14141415();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14141415,
"from":L[125]});
}
} catch($e14061407) {
if(R.isCont($e14061407)) {
var $ss14101411 = {"from":L[125],
"go":function(ast129177) {
return $Hast358176(ast129177,C1027,CompilationPhase8056,P826,compile_DASH_js_DASH_ast89178,dialect123179,libs126180,name125181,options127182,phase88183,ret128184,_plus3,nothing5);
}};
$e14061407.stack[R.EXN_STACKHEIGHT++] = $ss14101411;
}
if(R.isPyretException($e14061407)) {
$e14061407.pyretStack.push(L[125]);
}
throw $e14061407;
}
var $ret14121413 = $Hast358176($z14081409,C1027,CompilationPhase8056,P826,compile_DASH_js_DASH_ast89178,dialect123179,libs126180,name125181,options127182,phase88183,ret128184,_plus3,nothing5);
++R.GAS;
return $ret14121413;
});
compile_DASH_js901332.$var = anf_assign2411333;
var anf_assign2471334 = R.makeFunction(function(dialect1301388,code1311389,name1321390,libs1331391,options1341392) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[12],5,arguments);
}
var anf_arg2431403 = options1341392.extendWith({"collect-all":(false),
"ignore-unbound":(false)});
var $z13951396 = D;
var $f14011402 = function(_) {
return R.isFunction(compile_DASH_js901332.$var)?compile_DASH_js901332.$var.app(start861326.$var,dialect1301388,code1311389,name1321390,libs1331391,anf_arg2431403):R.ffi.throwNonFunApp(L[124],compile_DASH_js901332.$var,[start861326.$var,dialect1301388,code1311389,name1321390,libs1331391,anf_arg2431403]);
};
try {
if(--R.GAS > 0) {
$z13951396 = $f14011402();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14011402,
"from":L[124]});
}
} catch($e13931394) {
if(R.isCont($e13931394)) {
var $ss13971398 = {"from":L[124],
"go":function(anf_bracket244161) {
return $Hanf_bracket360160(anf_bracket244161,C1027,P826);
}};
$e13931394.stack[R.EXN_STACKHEIGHT++] = $ss13971398;
}
if(R.isPyretException($e13931394)) {
$e13931394.pyretStack.push(L[124]);
}
throw $e13931394;
}
var $ret13991400 = $Hanf_bracket360160($z13951396,C1027,P826);
++R.GAS;
return $ret13991400;
});
compile_DASH_runnable_DASH_js91143.$var = anf_assign2471334;
var anf_assign2501336 = R.makeFunction(function(dialect135144,js_DASH_file136145,libs137146,options138147) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[11],4,arguments);
}
var anf_fun2491387 = G(F18,"file-to-string",L[123]);
var $z13791380 = D;
var $f13851386 = function(_) {
return R.isFunction(anf_fun2491387)?anf_fun2491387.app(js_DASH_file136145):R.ffi.throwNonFunApp(L[122],anf_fun2491387,[js_DASH_file136145]);
};
try {
if(--R.GAS > 0) {
$z13791380 = $f13851386();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13851386,
"from":L[122]});
}
} catch($e13771378) {
if(R.isCont($e13771378)) {
var $ss13811382 = {"from":L[122],
"go":function(code139142) {
return $Hcode362141(code139142,C1027,P826,compile_DASH_runnable_DASH_js91143,dialect135144,js_DASH_file136145,libs137146,options138147);
}};
$e13771378.stack[R.EXN_STACKHEIGHT++] = $ss13811382;
}
if(R.isPyretException($e13771378)) {
$e13771378.pyretStack.push(L[122]);
}
throw $e13771378;
}
var $ret13831384 = $Hcode362141($z13791380,C1027,P826,compile_DASH_runnable_DASH_js91143,dialect135144,js_DASH_file136145,libs137146,options138147);
++R.GAS;
return $ret13831384;
});
compile_DASH_runnable_DASH_js_DASH_file921335.$var = anf_assign2501336;
var anf_assign2531338 = R.makeFunction(function(dialect140125,js_DASH_file141126,libs142127,options143128) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[10],4,arguments);
}
var anf_fun2521376 = G(F18,"file-to-string",L[121]);
var $z13681369 = D;
var $f13741375 = function(_) {
return R.isFunction(anf_fun2521376)?anf_fun2521376.app(js_DASH_file141126):R.ffi.throwNonFunApp(L[120],anf_fun2521376,[js_DASH_file141126]);
};
try {
if(--R.GAS > 0) {
$z13681369 = $f13741375();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13741375,
"from":L[120]});
}
} catch($e13661367) {
if(R.isCont($e13661367)) {
var $ss13701371 = {"from":L[120],
"go":function(code144123) {
return $Hcode364122(code144123,C1027,P826,compile_DASH_standalone_DASH_js94124,dialect140125,js_DASH_file141126,libs142127,options143128);
}};
$e13661367.stack[R.EXN_STACKHEIGHT++] = $ss13701371;
}
if(R.isPyretException($e13661367)) {
$e13661367.pyretStack.push(L[120]);
}
throw $e13661367;
}
var $ret13721373 = $Hcode364122($z13681369,C1027,P826,compile_DASH_standalone_DASH_js94124,dialect140125,js_DASH_file141126,libs142127,options143128);
++R.GAS;
return $ret13721373;
});
compile_DASH_standalone_DASH_js_DASH_file931337.$var = anf_assign2531338;
var anf_assign2681339 = R.makeFunction(function(code1451351,name1461352,libs1471353,options1481354) {
if(arguments.length !== 4) {
throw R.ffi.throwArityErrorC(L[1],4,arguments);
}
var anf_arg2551365 = options1481354.extendWith({"collect-all":(false),
"ignore-unbound":(false)});
var $z13571358 = D;
var $f13631364 = function(_) {
return R.isFunction(compile_DASH_js901332.$var)?compile_DASH_js901332.$var.app(start861326.$var,code1451351,name1461352,libs1471353,anf_arg2551365):R.ffi.throwNonFunApp(L[119],compile_DASH_js901332.$var,[start861326.$var,code1451351,name1461352,libs1471353,anf_arg2551365]);
};
try {
if(--R.GAS > 0) {
$z13571358 = $f13631364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13631364,
"from":L[119]});
}
} catch($e13551356) {
if(R.isCont($e13551356)) {
var $ss13591360 = {"from":L[119],
"go":function(anf_bracket25672) {
return $Hanf_bracket36871(anf_bracket25672,C1027,C912,$type$String7);
}};
$e13551356.stack[R.EXN_STACKHEIGHT++] = $ss13591360;
}
if(R.isPyretException($e13551356)) {
$e13551356.pyretStack.push(L[119]);
}
throw $e13551356;
}
var $ret13611362 = $Hanf_bracket36871($z13571358,C1027,C912,$type$String7);
++R.GAS;
return $ret13611362;
});
compile_DASH_standalone_DASH_js94124.$var = anf_assign2681339;
var provides26957 = R.makeObject({"CompilationPhase":CompilationPhase831320.$var,
"is-CompilationPhase":is_DASH_CompilationPhase841322.$var,
"start":start861326.$var,
"is-start":is_DASH_start851324.$var,
"phase":phase88183.$var,
"is-phase":is_DASH_phase871328.$var,
"compile-js-ast":compile_DASH_js_DASH_ast89178.$var,
"compile-js":compile_DASH_js901332.$var,
"compile-runnable-js":compile_DASH_runnable_DASH_js91143.$var,
"compile-runnable-js-file":compile_DASH_runnable_DASH_js_DASH_file921335.$var,
"compile-standalone-js-file":compile_DASH_standalone_DASH_js_DASH_file931337.$var,
"compile-standalone-js":compile_DASH_standalone_DASH_js94124.$var});
var anf_fun2701350 = G(builtins4,"current-checker",L[0]);
var $z13421343 = D;
var $f13481349 = function(_) {
return R.isFunction(anf_fun2701350)?anf_fun2701350.app():R.ffi.throwNonFunApp(L[0],anf_fun2701350,[]);
};
try {
if(--R.GAS > 0) {
$z13421343 = $f13481349();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13481349,
"from":L[0]});
}
} catch($e13401341) {
if(R.isCont($e13401341)) {
var $ss13441345 = {"from":L[0],
"go":function(anf_bracket27155) {
return $Hanf_bracket37054(anf_bracket27155,CompilationPhase8056,provides26957,nothing5);
}};
$e13401341.stack[R.EXN_STACKHEIGHT++] = $ss13441345;
}
if(R.isPyretException($e13401341)) {
$e13401341.pyretStack.push(L[0]);
}
throw $e13401341;
}
var $ret13461347 = $Hanf_bracket37054($z13421343,CompilationPhase8056,provides26957,nothing5);
++R.GAS;
return $ret13461347;
},function(moduleVal) {
R.modules["$src/arr/compiler/compile.arr38"] = moduleVal
return moduleVal;
});
});
}
};
});
define('compiler/pyret.arr',["trove/cmdline",
"trove/file",
"trove/exec",
"trove/string-dict",
"compiler/compile.arr",
"compiler/compile-structs.arr",
"trove/format",
"trove/either",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($C11239,$F31340,$X51441,$D71542,$CM91643,$CS111744,$Format131845,$E151946,$arrays172047,$lists192148,$option212249,$error232350,$sets252451) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/pyret.arr38"]) {
return R.modules["$src/arr/compiler/pyret.arr38"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/pyret.arr";
var D = R.undefined;
var L = [[M,11,0,214,147,16,4841],
[M,28,6,633,28,66,693],
[M,28,27,654,28,33,660],
[M,28,17,644,28,25,652],
[M,28,6,633,28,16,643],
[M,30,6,714,30,72,780],
[M,30,13,721,30,19,727],
[M,30,6,714,30,12,720],
[M,32,6,798,32,84,876],
[M,32,27,819,32,33,825],
[M,32,17,809,32,25,817],
[M,32,6,798,32,16,808],
[M,34,6,905,34,93,992],
[M,34,46,945,34,52,951],
[M,34,25,924,34,33,932],
[M,34,6,905,34,24,923],
[M,36,6,1015,36,73,1082],
[M,36,13,1022,36,19,1028],
[M,36,6,1015,36,12,1021],
[M,38,6,1109,38,35,1138],
[M,38,13,1116,38,19,1122],
[M,38,6,1109,38,12,1115],
[M,40,6,1164,40,67,1225],
[M,40,13,1171,40,19,1177],
[M,40,6,1164,40,12,1170],
[M,42,27,1267,42,70,1310],
[M,42,27,1267,42,35,1275],
[M,42,8,1248,42,26,1266],
[M,43,19,1331,43,28,1340],
[M,42,8,1248,43,79,1391],
[M,43,30,1342,43,36,1348],
[M,46,2,1401,46,45,1444],
[M,46,18,1417,46,30,1429],
[M,23,0,479,145,3,4823],
[M,55,2,1606,144,5,4819],
[M,141,4,4710,143,49,4813],
[M,142,6,4749,142,20,4763],
[M,56,4,1650,140,9,4705],
[M,57,23,1696,57,74,1747],
[M,57,23,1696,57,32,1705],
[M,48,2,1448,53,5,1600],
[M,49,6,1476,49,30,1500],
[M,49,22,1492,49,28,1498],
[M,49,8,1478,49,21,1491],
[M,49,8,1478,49,14,1484],
[M,143,12,4776,143,33,4797],
[M,143,12,4776,143,24,4788],
[M,143,12,4776,143,48,4812],
[M,143,12,4776,143,42,4806],
[M,57,53,1726,57,62,1735],
[M,57,23,1696,57,49,1722],
[M,57,6,1679,57,74,1747],
[M,57,53,1726,57,73,1746],
[M,58,6,1754,58,48,1796],
[M,58,23,1771,58,32,1780],
[M,60,11,1821,60,31,1841],
[M,60,11,1821,60,20,1830],
[M,60,33,1843,60,52,1862],
[M,61,16,1879,61,32,1895],
[M,61,16,1879,61,21,1884],
[M,63,6,1979,63,43,2016],
[M,63,19,1992,63,24,1997],
[M,61,49,1912,61,70,1933],
[M,62,14,1948,62,34,1968],
[M,61,16,1879,61,48,1911],
[M,64,6,2023,64,40,2057],
[M,64,18,2035,64,27,2044],
[M,65,13,2071,65,27,2085],
[M,65,9,2067,65,28,2086],
[M,69,10,2184,69,26,2200],
[M,69,10,2184,69,15,2189],
[M,68,10,2164,68,18,2172],
[M,67,17,2139,67,30,2152],
[M,66,23,2111,66,33,2121],
[M,104,20,3511,104,54,3545],
[M,104,20,3511,104,29,3520],
[M,70,10,2212,70,40,2242],
[M,70,10,2212,70,26,2228],
[M,67,17,2139,79,11,2467],
[M,80,8,2483,102,11,3478],
[M,96,10,3254,101,50,3466],
[M,97,12,3283,97,46,3317],
[M,81,10,2525,95,15,3243],
[M,82,33,2579,82,67,2613],
[M,82,33,2579,82,65,2611],
[M,82,26,2572,82,32,2578],
[M,67,17,2139,79,18,2474],
[M,98,12,3330,100,15,3415],
[M,99,26,3387,99,37,3398],
[M,98,16,3334,98,26,3344],
[M,82,106,2652,82,122,2668],
[M,82,106,2652,82,111,2657],
[M,82,12,2558,82,129,2675],
[M,85,16,2761,85,64,2809],
[M,85,30,2775,85,62,2807],
[M,84,14,2728,91,17,3102],
[M,84,19,2733,84,29,2743],
[M,93,20,3141,93,54,3175],
[M,93,20,3141,93,52,3173],
[M,83,14,2690,83,36,2712],
[M,83,16,2692,83,35,2711],
[M,86,16,2826,86,34,2844],
[M,87,25,2870,87,72,2917],
[M,87,21,2866,88,91,3014],
[M,88,22,2945,88,89,3012],
[M,87,21,2866,87,73,2918],
[M,89,18,3033,89,49,3064],
[M,87,16,2861,90,19,3084],
[M,88,18,2941,88,90,3013],
[M,93,14,3135,93,55,3176],
[M,94,14,3191,94,50,3227],
[M,106,12,3600,106,42,3630],
[M,106,12,3600,106,17,3605],
[M,105,10,3557,105,39,3586],
[M,113,8,3785,126,20,4222],
[M,113,16,3793,113,25,3802],
[M,131,8,4359,139,11,4695],
[M,133,10,4471,138,50,4683],
[M,134,12,4500,134,46,4534],
[M,132,10,4401,132,69,4460],
[M,132,31,4422,132,60,4451],
[M,105,10,3557,112,13,3776],
[M,116,12,3884,116,28,3900],
[M,116,12,3884,116,17,3889],
[M,115,12,3862,115,20,3870],
[M,114,10,3835,114,23,3848],
[M,128,16,4253,128,37,4274],
[M,128,16,4253,128,28,4265],
[M,113,16,3793,113,46,3823],
[M,117,29,3931,117,55,3957],
[M,117,29,3931,117,34,3936],
[M,117,12,3914,117,28,3930],
[M,117,12,3914,117,56,3958],
[M,118,12,3972,118,38,3998],
[M,118,12,3972,118,17,3977],
[M,114,10,3835,126,13,4215],
[M,114,10,3835,126,20,4222],
[M,128,16,4253,128,52,4289],
[M,128,16,4253,128,46,4283],
[M,128,10,4247,128,53,4290],
[M,129,10,4301,129,47,4338],
[M,135,12,4547,137,15,4632],
[M,136,26,4604,136,37,4615],
[M,135,16,4551,135,26,4561],
[M,49,32,1502,49,36,1506],
[M,50,4,1511,50,41,1548],
[M,50,26,1533,50,32,1539],
[M,50,13,1520,50,25,1532],
[M,50,13,1520,50,19,1526],
[M,50,36,1543,50,41,1548],
[M,51,10,1559,51,22,1571],
[M,50,11,1518,50,34,1541],
[M,51,25,1574,51,37,1586],
[M,51,10,1559,51,37,1586],
[M,18,47,376,18,56,385],
[M,19,54,440,19,79,465],
[M,19,14,400,19,80,466],
[M,19,8,394,19,81,467],
[M,3,0,13,147,16,4841],
[M,147,0,4825,147,16,4841],
[M,147,9,4834,147,15,4840],
[M,26,6,542,26,66,602],
[M,26,27,563,26,33,569],
[M,26,17,553,26,25,561],
[M,26,6,542,26,16,552],
[M,17,0,287,21,3,477],
[M,18,4,333,18,46,375],
[M,18,24,353,18,45,374],
[M,18,4,333,18,21,350],
[M,19,67,453,19,78,464],
[M,14,8,277,14,15,284],
[M,13,7,262,13,13,268],
[M,12,9,246,12,17,254],
[M,11,9,223,11,22,236]];
var _lessthan1 = NAMESPACE.get("_lessthan");
var builtins2 = NAMESPACE.get("builtins");
var display3 = NAMESPACE.get("display");
var not4 = NAMESPACE.get("not");
var nothing5 = NAMESPACE.get("nothing");
var print6 = NAMESPACE.get("print");
var print_DASH_error7 = NAMESPACE.get("print-error");
var raise8 = NAMESPACE.get("raise");
var string_DASH_contains9 = NAMESPACE.get("string-contains");
var torepr10 = NAMESPACE.get("torepr");
var tostring11 = NAMESPACE.get("tostring");
var $H$underscore35552 = function($underscore11153,builtins2,nothing5) {
var provides24866 = R.makeObject({});
var anf_fun24964 = G(builtins2,"current-checker",L[0]);
var $z5657 = D;
var $f6263 = function(_) {
return R.isFunction(anf_fun24964)?anf_fun24964.app():R.ffi.throwNonFunApp(L[0],anf_fun24964,[]);
};
try {
if(--R.GAS > 0) {
$z5657 = $f6263();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6263,
"from":L[0]});
}
} catch($e5455) {
if(R.isCont($e5455)) {
var $ss5859 = {"from":L[0],
"go":function(anf_bracket25065) {
return $Hanf_bracket35467(anf_bracket25065,provides24866,nothing5);
}};
$e5455.stack[R.EXN_STACKHEIGHT++] = $ss5859;
}
if(R.isPyretException($e5455)) {
$e5455.pyretStack.push(L[0]);
}
throw $e5455;
}
var $ret6061 = $Hanf_bracket35467($z5657,provides24866,nothing5);
++R.GAS;
return $ret6061;
};
var $Hanf_bracket35467 = function(anf_bracket25065,provides24866,nothing5) {
var anf_fun25178 = G(anf_bracket25065,"results",L[0]);
var $z7071 = D;
var $f7677 = function(_) {
return R.isFunction(anf_fun25178)?anf_fun25178.app():R.ffi.throwNonFunApp(L[0],anf_fun25178,[]);
};
try {
if(--R.GAS > 0) {
$z7071 = $f7677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f7677,
"from":L[0]});
}
} catch($e6869) {
if(R.isCont($e6869)) {
var $ss7273 = {"from":L[0],
"go":function(checks25279) {
return $Hchecks35380(checks25279,provides24866,nothing5);
}};
$e6869.stack[R.EXN_STACKHEIGHT++] = $ss7273;
}
if(R.isPyretException($e6869)) {
$e6869.pyretStack.push(L[0]);
}
throw $e6869;
}
var $ret7475 = $Hchecks35380($z7071,provides24866,nothing5);
++R.GAS;
return $ret7475;
};
var $Hchecks35380 = function(checks25279,provides24866,nothing5) {
return R.makeObject({"answer":nothing5,
"provide-plus-types":R.makeObject({"values":provides24866,
"types":{}}),
"checks":checks25279});
};
var $Hanf_obj35281 = function(anf_obj3082,C112,CM916,CS1117,F313,X514,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun3198 = G(C112,"next-val",L[4]);
var anf_arg3299 = G(C112,"String",L[3]);
var anf_arg33100 = G(C112,"once",L[2]);
var $z9091 = D;
var $f9697 = function(_) {
return R.isFunction(anf_fun3198)?anf_fun3198.app(anf_arg3299,anf_arg33100,("Pyret (.arr) file to compile")):R.ffi.throwNonFunApp(L[1],anf_fun3198,[anf_arg3299,anf_arg33100,("Pyret (.arr) file to compile")]);
};
try {
if(--R.GAS > 0) {
$z9091 = $f9697();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9697,
"from":L[1]});
}
} catch($e8889) {
if(R.isCont($e8889)) {
var $ss9293 = {"from":L[1],
"go":function(anf_obj34101) {
return $Hanf_obj351102(anf_obj34101,C112,CM916,CS1117,F313,X514,anf_obj3082,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e8889.stack[R.EXN_STACKHEIGHT++] = $ss9293;
}
if(R.isPyretException($e8889)) {
$e8889.pyretStack.push(L[1]);
}
throw $e8889;
}
var $ret9495 = $Hanf_obj351102($z9091,C112,CM916,CS1117,F313,X514,anf_obj3082,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret9495;
};
var $Hanf_obj351102 = function(anf_obj34101,C112,CM916,CS1117,F313,X514,anf_obj3082,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun35113 = G(C112,"flag",L[7]);
var anf_arg36114 = G(C112,"once",L[6]);
var $z105106 = D;
var $f111112 = function(_) {
return R.isFunction(anf_fun35113)?anf_fun35113.app(anf_arg36114,("Don't auto-import basics like list, option, etc.")):R.ffi.throwNonFunApp(L[5],anf_fun35113,[anf_arg36114,("Don't auto-import basics like list, option, etc.")]);
};
try {
if(--R.GAS > 0) {
$z105106 = $f111112();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f111112,
"from":L[5]});
}
} catch($e103104) {
if(R.isCont($e103104)) {
var $ss107108 = {"from":L[5],
"go":function(anf_obj37115) {
return $Hanf_obj350116(anf_obj37115,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e103104.stack[R.EXN_STACKHEIGHT++] = $ss107108;
}
if(R.isPyretException($e103104)) {
$e103104.pyretStack.push(L[5]);
}
throw $e103104;
}
var $ret109110 = $Hanf_obj350116($z105106,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret109110;
};
var $Hanf_obj350116 = function(anf_obj37115,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun38127 = G(C112,"next-val",L[11]);
var anf_arg39128 = G(C112,"String",L[10]);
var anf_arg40129 = G(C112,"many",L[9]);
var $z119120 = D;
var $f125126 = function(_) {
return R.isFunction(anf_fun38127)?anf_fun38127.app(anf_arg39128,anf_arg40129,("Paths to files to include as builtin libraries")):R.ffi.throwNonFunApp(L[8],anf_fun38127,[anf_arg39128,anf_arg40129,("Paths to files to include as builtin libraries")]);
};
try {
if(--R.GAS > 0) {
$z119120 = $f125126();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f125126,
"from":L[8]});
}
} catch($e117118) {
if(R.isCont($e117118)) {
var $ss121122 = {"from":L[8],
"go":function(anf_obj41130) {
return $Hanf_obj349131(anf_obj41130,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e117118.stack[R.EXN_STACKHEIGHT++] = $ss121122;
}
if(R.isPyretException($e117118)) {
$e117118.pyretStack.push(L[8]);
}
throw $e117118;
}
var $ret123124 = $Hanf_obj349131($z119120,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret123124;
};
var $Hanf_obj349131 = function(anf_obj41130,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun42142 = G(C112,"next-val-default",L[15]);
var anf_arg43143 = G(C112,"String",L[14]);
var anf_arg44144 = G(C112,"once",L[13]);
var $z134135 = D;
var $f140141 = function(_) {
return R.isFunction(anf_fun42142)?anf_fun42142.app(anf_arg43143,("."),none7185,anf_arg44144,("Base directory to search for modules")):R.ffi.throwNonFunApp(L[12],anf_fun42142,[anf_arg43143,("."),none7185,anf_arg44144,("Base directory to search for modules")]);
};
try {
if(--R.GAS > 0) {
$z134135 = $f140141();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f140141,
"from":L[12]});
}
} catch($e132133) {
if(R.isCont($e132133)) {
var $ss136137 = {"from":L[12],
"go":function(anf_obj45145) {
return $Hanf_obj348146(anf_obj45145,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e132133.stack[R.EXN_STACKHEIGHT++] = $ss136137;
}
if(R.isPyretException($e132133)) {
$e132133.pyretStack.push(L[12]);
}
throw $e132133;
}
var $ret138139 = $Hanf_obj348146($z134135,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret138139;
};
var $Hanf_obj348146 = function(anf_obj45145,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun46157 = G(C112,"flag",L[18]);
var anf_arg47158 = G(C112,"once",L[17]);
var $z149150 = D;
var $f155156 = function(_) {
return R.isFunction(anf_fun46157)?anf_fun46157.app(anf_arg47158,("Run checks all modules (not just the main module)")):R.ffi.throwNonFunApp(L[16],anf_fun46157,[anf_arg47158,("Run checks all modules (not just the main module)")]);
};
try {
if(--R.GAS > 0) {
$z149150 = $f155156();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f155156,
"from":L[16]});
}
} catch($e147148) {
if(R.isCont($e147148)) {
var $ss151152 = {"from":L[16],
"go":function(anf_obj48159) {
return $Hanf_obj347160(anf_obj48159,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e147148.stack[R.EXN_STACKHEIGHT++] = $ss151152;
}
if(R.isPyretException($e147148)) {
$e147148.pyretStack.push(L[16]);
}
throw $e147148;
}
var $ret153154 = $Hanf_obj347160($z149150,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret153154;
};
var $Hanf_obj347160 = function(anf_obj48159,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun49171 = G(C112,"flag",L[21]);
var anf_arg50172 = G(C112,"once",L[20]);
var $z163164 = D;
var $f169170 = function(_) {
return R.isFunction(anf_fun49171)?anf_fun49171.app(anf_arg50172,("Skip checks")):R.ffi.throwNonFunApp(L[19],anf_fun49171,[anf_arg50172,("Skip checks")]);
};
try {
if(--R.GAS > 0) {
$z163164 = $f169170();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f169170,
"from":L[19]});
}
} catch($e161162) {
if(R.isCont($e161162)) {
var $ss165166 = {"from":L[19],
"go":function(anf_obj51173) {
return $Hanf_obj346174(anf_obj51173,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e161162.stack[R.EXN_STACKHEIGHT++] = $ss165166;
}
if(R.isPyretException($e161162)) {
$e161162.pyretStack.push(L[19]);
}
throw $e161162;
}
var $ret167168 = $Hanf_obj346174($z163164,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret167168;
};
var $Hanf_obj346174 = function(anf_obj51173,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun52185 = G(C112,"flag",L[24]);
var anf_arg53186 = G(C112,"once",L[23]);
var $z177178 = D;
var $f183184 = function(_) {
return R.isFunction(anf_fun52185)?anf_fun52185.app(anf_arg53186,("Run without checking for shadowed variables")):R.ffi.throwNonFunApp(L[22],anf_fun52185,[anf_arg53186,("Run without checking for shadowed variables")]);
};
try {
if(--R.GAS > 0) {
$z177178 = $f183184();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f183184,
"from":L[22]});
}
} catch($e175176) {
if(R.isCont($e175176)) {
var $ss179180 = {"from":L[22],
"go":function(anf_obj54187) {
return $Hanf_obj345188(anf_obj54187,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e175176.stack[R.EXN_STACKHEIGHT++] = $ss179180;
}
if(R.isPyretException($e175176)) {
$e175176.pyretStack.push(L[22]);
}
throw $e175176;
}
var $ret181182 = $Hanf_obj345188($z177178,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret181182;
};
var $Hanf_obj345188 = function(anf_obj54187,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,args8583,is_DASH_empty3684,lists1921,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun55201 = G(C112,"next-val-default",L[27]);
var anf_fun56199 = G(C112,"Custom",L[26]);
var $z191192 = D;
var $f197198 = function(_) {
return R.isFunction(anf_fun56199)?anf_fun56199.app(("Pyret|Bootstrap"),parse_DASH_dialects8086.$var):R.ffi.throwNonFunApp(L[25],anf_fun56199,[("Pyret|Bootstrap"),parse_DASH_dialects8086.$var]);
};
try {
if(--R.GAS > 0) {
$z191192 = $f197198();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f197198,
"from":L[25]});
}
} catch($e189190) {
if(R.isCont($e189190)) {
var $ss193194 = {"from":L[25],
"go":function(anf_arg57200) {
return $Hanf_arg344202(anf_arg57200,C112,CM916,CS1117,F313,X514,anf_fun55201,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e189190.stack[R.EXN_STACKHEIGHT++] = $ss193194;
}
if(R.isPyretException($e189190)) {
$e189190.pyretStack.push(L[25]);
}
throw $e189190;
}
var $ret195196 = $Hanf_arg344202($z191192,C112,CM916,CS1117,F313,X514,anf_fun55201,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret195196;
};
var $Hanf_arg344202 = function(anf_arg57200,C112,CM916,CS1117,F313,X514,anf_fun55201,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var $z205206 = D;
var $f211212 = function(_) {
return R.isFunction(some7287)?some7287.app(("d")):R.ffi.throwNonFunApp(L[28],some7287,[("d")]);
};
try {
if(--R.GAS > 0) {
$z205206 = $f211212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f211212,
"from":L[28]});
}
} catch($e203204) {
if(R.isCont($e203204)) {
var $ss207208 = {"from":L[28],
"go":function(anf_arg58213) {
return $Hanf_arg343214(anf_arg58213,C112,CM916,CS1117,F313,X514,anf_arg57200,anf_fun55201,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e203204.stack[R.EXN_STACKHEIGHT++] = $ss207208;
}
if(R.isPyretException($e203204)) {
$e203204.pyretStack.push(L[28]);
}
throw $e203204;
}
var $ret209210 = $Hanf_arg343214($z205206,C112,CM916,CS1117,F313,X514,anf_arg57200,anf_fun55201,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret209210;
};
var $Hanf_arg343214 = function(anf_arg58213,C112,CM916,CS1117,F313,X514,anf_arg57200,anf_fun55201,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_arg59225 = G(C112,"once",L[30]);
var $z217218 = D;
var $f223224 = function(_) {
return R.isFunction(anf_fun55201)?anf_fun55201.app(anf_arg57200,("Pyret"),anf_arg58213,anf_arg59225,("Dialect of Pyret to use when compiling")):R.ffi.throwNonFunApp(L[29],anf_fun55201,[anf_arg57200,("Pyret"),anf_arg58213,anf_arg59225,("Dialect of Pyret to use when compiling")]);
};
try {
if(--R.GAS > 0) {
$z217218 = $f223224();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f223224,
"from":L[29]});
}
} catch($e215216) {
if(R.isCont($e215216)) {
var $ss219220 = {"from":L[29],
"go":function(anf_obj60226) {
return $Hanf_obj342227(anf_obj60226,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e215216.stack[R.EXN_STACKHEIGHT++] = $ss219220;
}
if(R.isPyretException($e215216)) {
$e215216.pyretStack.push(L[29]);
}
throw $e215216;
}
var $ret221222 = $Hanf_obj342227($z217218,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret221222;
};
var $Hanf_obj342227 = function(anf_obj60226,C112,CM916,CS1117,F313,X514,anf_obj3082,anf_obj34101,anf_obj37115,anf_obj41130,anf_obj45145,anf_obj48159,anf_obj51173,anf_obj54187,args8583,is_DASH_empty3684,lists1921,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var options86239 = R.makeObject({"compile-standalone-js":anf_obj3082,
"compile-module-js":anf_obj34101,
"library":anf_obj37115,
"libs":anf_obj41130,
"module-load-dir":anf_obj45145,
"check-all":anf_obj48159,
"no-check-mode":anf_obj51173,
"allow-shadow":anf_obj54187,
"dialect":anf_obj60226});
var anf_fun61238 = G(C112,"parse-args",L[32]);
var $z230231 = D;
var $f236237 = function(_) {
return R.isFunction(anf_fun61238)?anf_fun61238.app(options86239,args8583):R.ffi.throwNonFunApp(L[31],anf_fun61238,[options86239,args8583]);
};
try {
if(--R.GAS > 0) {
$z230231 = $f236237();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f236237,
"from":L[31]});
}
} catch($e228229) {
if(R.isCont($e228229)) {
var $ss232233 = {"from":L[31],
"go":function(params_DASH_parsed87240) {
return $Hparams_DASH_parsed341241(params_DASH_parsed87240,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e228229.stack[R.EXN_STACKHEIGHT++] = $ss232233;
}
if(R.isPyretException($e228229)) {
$e228229.pyretStack.push(L[31]);
}
throw $e228229;
}
var $ret234235 = $Hparams_DASH_parsed341241($z230231,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret234235;
};
var $Hparams_DASH_parsed341241 = function(params_DASH_parsed87240,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var err_DASH_less88242 = {"$var":D,
"$name":"err-less"};
var anf_assign83243 = R.makeFunction(function(e189292,e290293) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[40],2,arguments);
}
var anf_bracket63308 = G(e189292,"loc",L[44]);
var anf_fun64304 = G(anf_bracket63308,"before",L[43]);
var anf_arg65305 = G(e290293,"loc",L[42]);
var $z296297 = D;
var $f302303 = function(_) {
return R.isFunction(anf_fun64304)?anf_fun64304.app(anf_arg65305):R.ffi.throwNonFunApp(L[41],anf_fun64304,[anf_arg65305]);
};
try {
if(--R.GAS > 0) {
$z296297 = $f302303();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f302303,
"from":L[41]});
}
} catch($e294295) {
if(R.isCont($e294295)) {
var $ss298299 = {"from":L[41],
"go":function(if_DASH_5306) {
return $Hif_DASH_266307(if_DASH_5306,e189292,e290293,_lessthan1,tostring11);
}};
$e294295.stack[R.EXN_STACKHEIGHT++] = $ss298299;
}
if(R.isPyretException($e294295)) {
$e294295.pyretStack.push(L[41]);
}
throw $e294295;
}
var $ret300301 = $Hif_DASH_266307($z296297,e189292,e290293,_lessthan1,tostring11);
++R.GAS;
return $ret300301;
});
err_DASH_less88242.$var = anf_assign83243;
var cases_DASH_val20291 = params_DASH_parsed87240;
var anf_fun84254 = G(cases_DASH_val20291,"_match",L[34]);
var anf_obj236260 = R.makeFunction(function(r91276,rest92277) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[37],2,arguments);
}
var anf_fun86288 = G(r91276,"has-key",L[39]);
var $z280281 = D;
var $f286287 = function(_) {
return R.isFunction(anf_fun86288)?anf_fun86288.app(("no-check-mode")):R.ffi.throwNonFunApp(L[38],anf_fun86288,[("no-check-mode")]);
};
try {
if(--R.GAS > 0) {
$z280281 = $f286287();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f286287,
"from":L[38]});
}
} catch($e278279) {
if(R.isCont($e278279)) {
var $ss282283 = {"from":L[38],
"go":function(or_DASH_oper_DASH_6289) {
return $Hor_DASH_oper_DASH_334290(or_DASH_oper_DASH_6289,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e278279.stack[R.EXN_STACKHEIGHT++] = $ss282283;
}
if(R.isPyretException($e278279)) {
$e278279.pyretStack.push(L[38]);
}
throw $e278279;
}
var $ret284285 = $Hor_DASH_oper_DASH_334290($z280281,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret284285;
});
var anf_obj242261 = R.makeFunction(function(message109262,partial110263) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[35],2,arguments);
}
var $z266267 = D;
var $f272273 = function(_) {
return R.isFunction(print6)?print6.app(message109262):R.ffi.throwNonFunApp(L[36],print6,[message109262]);
};
try {
if(--R.GAS > 0) {
$z266267 = $f272273();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f272273,
"from":L[36]});
}
} catch($e264265) {
if(R.isCont($e264265)) {
var $ss268269 = {"from":L[36],
"go":function(anf_begin_app_dropped335274) {
return $Hanf_begin_app_dropped339275(anf_begin_app_dropped335274,C112,options86239,print6);
}};
$e264265.stack[R.EXN_STACKHEIGHT++] = $ss268269;
}
if(R.isPyretException($e264265)) {
$e264265.pyretStack.push(L[36]);
}
throw $e264265;
}
var $ret270271 = $Hanf_begin_app_dropped339275($z266267,C112,options86239,print6);
++R.GAS;
return $ret270271;
});
var anf_arg243255 = R.makeObject({"success":anf_obj236260,
"arg-error":anf_obj242261});
var anf_arg245256 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[34],0,arguments);
}
var ann_DASH_check_DASH_temp244259 = R.throwNoBranchesMatched(L[34],("cases"));
return ann_DASH_check_DASH_temp244259;
});
var $z246247 = D;
var $f252253 = function(_) {
return R.isFunction(anf_fun84254)?anf_fun84254.app(anf_arg243255,anf_arg245256):R.ffi.throwNonFunApp(L[33],anf_fun84254,[anf_arg243255,anf_arg245256]);
};
try {
if(--R.GAS > 0) {
$z246247 = $f252253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f252253,
"from":L[33]});
}
} catch($e244245) {
if(R.isCont($e244245)) {
var $ss248249 = {"from":L[33],
"go":function(ann_DASH_check_DASH_temp26257) {
return $Hann_DASH_check_DASH_temp340258(ann_DASH_check_DASH_temp26257);
}};
$e244245.stack[R.EXN_STACKHEIGHT++] = $ss248249;
}
if(R.isPyretException($e244245)) {
$e244245.pyretStack.push(L[33]);
}
throw $e244245;
}
var $ret250251 = $Hann_DASH_check_DASH_temp340258($z246247);
++R.GAS;
return $ret250251;
};
var $Hann_DASH_check_DASH_temp340258 = function(ann_DASH_check_DASH_temp26257) {
return ann_DASH_check_DASH_temp26257;
};
var $Hanf_begin_app_dropped339275 = function(anf_begin_app_dropped335274,C112,options86239,print6) {
var anf_fun238319 = G(C112,"usage-info",L[46]);
var $z311312 = D;
var $f317318 = function(_) {
return R.isFunction(anf_fun238319)?anf_fun238319.app(options86239):R.ffi.throwNonFunApp(L[45],anf_fun238319,[options86239]);
};
try {
if(--R.GAS > 0) {
$z311312 = $f317318();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f317318,
"from":L[45]});
}
} catch($e309310) {
if(R.isCont($e309310)) {
var $ss313314 = {"from":L[45],
"go":function(anf_bracket239320) {
return $Hanf_bracket338321(anf_bracket239320,print6);
}};
$e309310.stack[R.EXN_STACKHEIGHT++] = $ss313314;
}
if(R.isPyretException($e309310)) {
$e309310.pyretStack.push(L[45]);
}
throw $e309310;
}
var $ret315316 = $Hanf_bracket338321($z311312,print6);
++R.GAS;
return $ret315316;
};
var $Hanf_bracket338321 = function(anf_bracket239320,print6) {
var anf_fun240332 = G(anf_bracket239320,"join-str",L[48]);
var $z324325 = D;
var $f330331 = function(_) {
return R.isFunction(anf_fun240332)?anf_fun240332.app(("\n")):R.ffi.throwNonFunApp(L[47],anf_fun240332,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z324325 = $f330331();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f330331,
"from":L[47]});
}
} catch($e322323) {
if(R.isCont($e322323)) {
var $ss326327 = {"from":L[47],
"go":function(anf_arg241333) {
return $Hanf_arg337334(anf_arg241333,print6);
}};
$e322323.stack[R.EXN_STACKHEIGHT++] = $ss326327;
}
if(R.isPyretException($e322323)) {
$e322323.pyretStack.push(L[47]);
}
throw $e322323;
}
var $ret328329 = $Hanf_arg337334($z324325,print6);
++R.GAS;
return $ret328329;
};
var $Hanf_arg337334 = function(anf_arg241333,print6) {
var $z337338 = D;
var $f343344 = function(_) {
return R.isFunction(print6)?print6.app(anf_arg241333):R.ffi.throwNonFunApp(L[35],print6,[anf_arg241333]);
};
try {
if(--R.GAS > 0) {
$z337338 = $f343344();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f343344,
"from":L[35]});
}
} catch($e335336) {
if(R.isCont($e335336)) {
var $ss339340 = {"from":L[35],
"go":function(ann_DASH_check_DASH_temp237345) {
return $Hann_DASH_check_DASH_temp336346(ann_DASH_check_DASH_temp237345);
}};
$e335336.stack[R.EXN_STACKHEIGHT++] = $ss339340;
}
if(R.isPyretException($e335336)) {
$e335336.pyretStack.push(L[35]);
}
throw $e335336;
}
var $ret341342 = $Hann_DASH_check_DASH_temp336346($z337338);
++R.GAS;
return $ret341342;
};
var $Hann_DASH_check_DASH_temp336346 = function(ann_DASH_check_DASH_temp237345) {
return ann_DASH_check_DASH_temp237345;
};
var $Hor_DASH_oper_DASH_334290 = function(or_DASH_oper_DASH_6289,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var if_helper87357 = R.makeFunction(function(if_helper_arg88378) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[38],1,arguments);
}
var $z381382 = D;
var $f387388 = function(_) {
return R.isFunction(not4)?not4.app(if_helper_arg88378):R.ffi.throwNonFunApp(L[51],not4,[if_helper_arg88378]);
};
try {
if(--R.GAS > 0) {
$z381382 = $f387388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f387388,
"from":L[51]});
}
} catch($e379380) {
if(R.isCont($e379380)) {
var $ss383384 = {"from":L[51],
"go":function(check_DASH_mode93389) {
return $Hcheck_DASH_mode330390(check_DASH_mode93389,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e379380.stack[R.EXN_STACKHEIGHT++] = $ss383384;
}
if(R.isPyretException($e379380)) {
$e379380.pyretStack.push(L[51]);
}
throw $e379380;
}
var $ret385386 = $Hcheck_DASH_mode330390($z381382,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret385386;
});
var anf_if229377 = R.isBoolean(or_DASH_oper_DASH_6289);
if(R.isPyretTrue(anf_if229377)) {
if(R.isPyretTrue(or_DASH_oper_DASH_6289)) {
var $z349350 = D;
var $f355356 = function(_) {
return R.isFunction(if_helper87357)?if_helper87357.app((true)):R.ffi.throwNonFunApp(L[38],if_helper87357,[(true)]);
};
try {
if(--R.GAS > 0) {
$z349350 = $f355356();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f355356,
"from":L[38]});
}
} catch($e347348) {
if(R.isCont($e347348)) {
var $ss351352 = {"from":L[38],
"go":function(cont_tail_app235358) {
return $Hcont_tail_app331359(cont_tail_app235358);
}};
$e347348.stack[R.EXN_STACKHEIGHT++] = $ss351352;
}
if(R.isPyretException($e347348)) {
$e347348.pyretStack.push(L[38]);
}
throw $e347348;
}
var $ret353354 = $Hcont_tail_app331359($z349350);
++R.GAS;
return $ret353354;
} else {
var anf_fun230370 = G(r91276,"has-key",L[49]);
var $z362363 = D;
var $f368369 = function(_) {
return R.isFunction(anf_fun230370)?anf_fun230370.app(("library")):R.ffi.throwNonFunApp(L[38],anf_fun230370,[("library")]);
};
try {
if(--R.GAS > 0) {
$z362363 = $f368369();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f368369,
"from":L[38]});
}
} catch($e360361) {
if(R.isCont($e360361)) {
var $ss364365 = {"from":L[38],
"go":function(or_DASH_oper_DASH_7371) {
return $Hor_DASH_oper_DASH_333372(or_DASH_oper_DASH_7371,if_helper87357);
}};
$e360361.stack[R.EXN_STACKHEIGHT++] = $ss364365;
}
if(R.isPyretException($e360361)) {
$e360361.pyretStack.push(L[38]);
}
throw $e360361;
}
var $ret366367 = $Hor_DASH_oper_DASH_333372($z362363,if_helper87357);
++R.GAS;
return $ret366367;
}
} else {
var cont_tail_arg227375 = R.throwNonBooleanOp(L[50],("first"),("or"),or_DASH_oper_DASH_6289);
if(--R.GAS > 0) {
$z373374 = R.isFunction(if_helper87357)?if_helper87357.app(cont_tail_arg227375):R.ffi.throwNonFunApp(L[50],if_helper87357,[cont_tail_arg227375]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper87357)?if_helper87357.app(cont_tail_arg227375):R.ffi.throwNonFunApp(L[50],if_helper87357,[cont_tail_arg227375]);
},
"from":L[50]});
}
++R.GAS;
return $z373374;
}
};
var $Hcont_tail_app331359 = function(cont_tail_app235358) {
return cont_tail_app235358;
};
var $Hor_DASH_oper_DASH_333372 = function(or_DASH_oper_DASH_7371,if_helper87357) {
var anf_if233406 = R.isBoolean(or_DASH_oper_DASH_7371);
if(R.isPyretTrue(anf_if233406)) {
var $z393394 = D;
var $f399400 = function(_) {
return R.isFunction(if_helper87357)?if_helper87357.app(or_DASH_oper_DASH_7371):R.ffi.throwNonFunApp(L[38],if_helper87357,[or_DASH_oper_DASH_7371]);
};
try {
if(--R.GAS > 0) {
$z393394 = $f399400();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f399400,
"from":L[38]});
}
} catch($e391392) {
if(R.isCont($e391392)) {
var $ss395396 = {"from":L[38],
"go":function(cont_tail_app234401) {
return $Hcont_tail_app332402(cont_tail_app234401);
}};
$e391392.stack[R.EXN_STACKHEIGHT++] = $ss395396;
}
if(R.isPyretException($e391392)) {
$e391392.pyretStack.push(L[38]);
}
throw $e391392;
}
var $ret397398 = $Hcont_tail_app332402($z393394);
++R.GAS;
return $ret397398;
} else {
var cont_tail_arg231405 = R.throwNonBooleanOp(L[52],("second"),("or"),or_DASH_oper_DASH_7371);
if(--R.GAS > 0) {
$z403404 = R.isFunction(if_helper87357)?if_helper87357.app(cont_tail_arg231405):R.ffi.throwNonFunApp(L[52],if_helper87357,[cont_tail_arg231405]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper87357)?if_helper87357.app(cont_tail_arg231405):R.ffi.throwNonFunApp(L[52],if_helper87357,[cont_tail_arg231405]);
},
"from":L[52]});
}
++R.GAS;
return $z403404;
}
};
var $Hcont_tail_app332402 = function(cont_tail_app234401) {
return cont_tail_app234401;
};
var $Hcheck_DASH_mode330390 = function(check_DASH_mode93389,C112,CM916,CS1117,F313,X514,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun89417 = G(r91276,"has-key",L[54]);
var $z409410 = D;
var $f415416 = function(_) {
return R.isFunction(anf_fun89417)?anf_fun89417.app(("allow-shadow")):R.ffi.throwNonFunApp(L[53],anf_fun89417,[("allow-shadow")]);
};
try {
if(--R.GAS > 0) {
$z409410 = $f415416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f415416,
"from":L[53]});
}
} catch($e407408) {
if(R.isCont($e407408)) {
var $ss411412 = {"from":L[53],
"go":function(allow_DASH_shadowed94418) {
return $Hallow_DASH_shadowed329419(allow_DASH_shadowed94418,C112,CM916,CS1117,F313,X514,check_DASH_mode93389,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e407408.stack[R.EXN_STACKHEIGHT++] = $ss411412;
}
if(R.isPyretException($e407408)) {
$e407408.pyretStack.push(L[53]);
}
throw $e407408;
}
var $ret413414 = $Hallow_DASH_shadowed329419($z409410,C112,CM916,CS1117,F313,X514,check_DASH_mode93389,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret413414;
};
var $Hallow_DASH_shadowed329419 = function(allow_DASH_shadowed94418,C112,CM916,CS1117,F313,X514,check_DASH_mode93389,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun90430 = G(r91276,"has-key",L[56]);
var $z422423 = D;
var $f428429 = function(_) {
return R.isFunction(anf_fun90430)?anf_fun90430.app(("library")):R.ffi.throwNonFunApp(L[55],anf_fun90430,[("library")]);
};
try {
if(--R.GAS > 0) {
$z422423 = $f428429();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f428429,
"from":L[55]});
}
} catch($e420421) {
if(R.isCont($e420421)) {
var $ss424425 = {"from":L[55],
"go":function(if_DASH_9431) {
return $Hif_DASH_328432(if_DASH_9431,C112,CM916,CS1117,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e420421.stack[R.EXN_STACKHEIGHT++] = $ss424425;
}
if(R.isPyretException($e420421)) {
$e420421.pyretStack.push(L[55]);
}
throw $e420421;
}
var $ret426427 = $Hif_DASH_328432($z422423,C112,CM916,CS1117,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret426427;
};
var $Hif_DASH_328432 = function(if_DASH_9431,C112,CM916,CS1117,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var if_helper91435 = R.makeFunction(function(if_helper_arg92454) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[55],1,arguments);
}
var libs95467 = if_helper_arg92454;
var anf_fun93465 = G(r91276,"get",L[61]);
var $z457458 = D;
var $f463464 = function(_) {
return R.isFunction(anf_fun93465)?anf_fun93465.app(("module-load-dir")):R.ffi.throwNonFunApp(L[60],anf_fun93465,[("module-load-dir")]);
};
try {
if(--R.GAS > 0) {
$z457458 = $f463464();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f463464,
"from":L[60]});
}
} catch($e455456) {
if(R.isCont($e455456)) {
var $ss459460 = {"from":L[60],
"go":function(module_DASH_dir96466) {
return $Hmodule_DASH_dir326468(module_DASH_dir96466,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,libs95467,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e455456.stack[R.EXN_STACKHEIGHT++] = $ss459460;
}
if(R.isPyretException($e455456)) {
$e455456.pyretStack.push(L[60]);
}
throw $e455456;
}
var $ret461462 = $Hmodule_DASH_dir326468($z457458,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,libs95467,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret461462;
});
var anf_if215453 = R.isBoolean(if_DASH_9431);
if(R.isPyretTrue(anf_if215453)) {
if(R.isPyretTrue(if_DASH_9431)) {
var cont_tail_arg225436 = G(CS1117,"minimal-builtins",L[57]);
if(--R.GAS > 0) {
$z433434 = R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg225436):R.ffi.throwNonFunApp(L[57],if_helper91435,[cont_tail_arg225436]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg225436):R.ffi.throwNonFunApp(L[57],if_helper91435,[cont_tail_arg225436]);
},
"from":L[57]});
}
++R.GAS;
return $z433434;
} else {
var anf_fun216447 = G(r91276,"get",L[59]);
var $z439440 = D;
var $f445446 = function(_) {
return R.isFunction(anf_fun216447)?anf_fun216447.app(("dialect")):R.ffi.throwNonFunApp(L[58],anf_fun216447,[("dialect")]);
};
try {
if(--R.GAS > 0) {
$z439440 = $f445446();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f445446,
"from":L[58]});
}
} catch($e437438) {
if(R.isCont($e437438)) {
var $ss441442 = {"from":L[58],
"go":function(anf_arg217448) {
return $Hanf_arg327449(anf_arg217448,CS1117,if_helper91435);
}};
$e437438.stack[R.EXN_STACKHEIGHT++] = $ss441442;
}
if(R.isPyretException($e437438)) {
$e437438.pyretStack.push(L[58]);
}
throw $e437438;
}
var $ret443444 = $Hanf_arg327449($z439440,CS1117,if_helper91435);
++R.GAS;
return $ret443444;
}
} else {
var cont_tail_arg213452 = R.throwNonBooleanCondition(L[55],("if"),if_DASH_9431);
if(--R.GAS > 0) {
$z450451 = R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg213452):R.ffi.throwNonFunApp(L[55],if_helper91435,[cont_tail_arg213452]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg213452):R.ffi.throwNonFunApp(L[55],if_helper91435,[cont_tail_arg213452]);
},
"from":L[55]});
}
++R.GAS;
return $z450451;
}
};
var $Hanf_arg327449 = function(anf_arg217448,CS1117,if_helper91435) {
var if_DASH_8475 = R.equiv(anf_arg217448,("Bootstrap"));
var anf_if220479 = R.isBoolean(if_DASH_8475);
if(R.isPyretTrue(anf_if220479)) {
if(R.isPyretTrue(if_DASH_8475)) {
var cont_tail_arg223471 = G(CS1117,"bootstrap-builtins",L[62]);
if(--R.GAS > 0) {
$z469470 = R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg223471):R.ffi.throwNonFunApp(L[62],if_helper91435,[cont_tail_arg223471]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg223471):R.ffi.throwNonFunApp(L[62],if_helper91435,[cont_tail_arg223471]);
},
"from":L[62]});
}
++R.GAS;
return $z469470;
} else {
var cont_tail_arg221474 = G(CS1117,"standard-builtins",L[63]);
if(--R.GAS > 0) {
$z472473 = R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg221474):R.ffi.throwNonFunApp(L[63],if_helper91435,[cont_tail_arg221474]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg221474):R.ffi.throwNonFunApp(L[63],if_helper91435,[cont_tail_arg221474]);
},
"from":L[63]});
}
++R.GAS;
return $z472473;
}
} else {
var cont_tail_arg218478 = R.throwNonBooleanCondition(L[64],("if"),if_DASH_8475);
if(--R.GAS > 0) {
$z476477 = R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg218478):R.ffi.throwNonFunApp(L[64],if_helper91435,[cont_tail_arg218478]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper91435)?if_helper91435.app(cont_tail_arg218478):R.ffi.throwNonFunApp(L[64],if_helper91435,[cont_tail_arg218478]);
},
"from":L[64]});
}
++R.GAS;
return $z476477;
}
};
var $Hmodule_DASH_dir326468 = function(module_DASH_dir96466,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,libs95467,lists1921,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun94490 = G(r91276,"has-key",L[66]);
var $z482483 = D;
var $f488489 = function(_) {
return R.isFunction(anf_fun94490)?anf_fun94490.app(("check-all")):R.ffi.throwNonFunApp(L[65],anf_fun94490,[("check-all")]);
};
try {
if(--R.GAS > 0) {
$z482483 = $f488489();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f488489,
"from":L[65]});
}
} catch($e480481) {
if(R.isCont($e480481)) {
var $ss484485 = {"from":L[65],
"go":function(check_DASH_all97491) {
return $Hcheck_DASH_all325492(check_DASH_all97491,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e480481.stack[R.EXN_STACKHEIGHT++] = $ss484485;
}
if(R.isPyretException($e480481)) {
$e480481.pyretStack.push(L[65]);
}
throw $e480481;
}
var $ret486487 = $Hcheck_DASH_all325492($z482483,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret486487;
};
var $Hcheck_DASH_all325492 = function(check_DASH_all97491,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_mode93389,is_DASH_empty3684,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var $z495496 = D;
var $f501502 = function(_) {
return R.isFunction(is_DASH_empty3684)?is_DASH_empty3684.app(rest92277):R.ffi.throwNonFunApp(L[67],is_DASH_empty3684,[rest92277]);
};
try {
if(--R.GAS > 0) {
$z495496 = $f501502();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f501502,
"from":L[67]});
}
} catch($e493494) {
if(R.isCont($e493494)) {
var $ss497498 = {"from":L[67],
"go":function(anf_arg95503) {
return $Hanf_arg324504(anf_arg95503,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_all97491,check_DASH_mode93389,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e493494.stack[R.EXN_STACKHEIGHT++] = $ss497498;
}
if(R.isPyretException($e493494)) {
$e493494.pyretStack.push(L[67]);
}
throw $e493494;
}
var $ret499500 = $Hanf_arg324504($z495496,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_all97491,check_DASH_mode93389,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret499500;
};
var $Hanf_arg324504 = function(anf_arg95503,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_all97491,check_DASH_mode93389,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var $z507508 = D;
var $f513514 = function(_) {
return R.isFunction(not4)?not4.app(anf_arg95503):R.ffi.throwNonFunApp(L[68],not4,[anf_arg95503]);
};
try {
if(--R.GAS > 0) {
$z507508 = $f513514();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f513514,
"from":L[68]});
}
} catch($e505506) {
if(R.isCont($e505506)) {
var $ss509510 = {"from":L[68],
"go":function(if_DASH_13515) {
return $Hif_DASH_323516(if_DASH_13515,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_all97491,check_DASH_mode93389,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e505506.stack[R.EXN_STACKHEIGHT++] = $ss509510;
}
if(R.isPyretException($e505506)) {
$e505506.pyretStack.push(L[68]);
}
throw $e505506;
}
var $ret511512 = $Hif_DASH_323516($z507508,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_all97491,check_DASH_mode93389,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret511512;
};
var $Hif_DASH_323516 = function(if_DASH_13515,C112,CM916,F313,X514,allow_DASH_shadowed94418,check_DASH_all97491,check_DASH_mode93389,libs95467,lists1921,module_DASH_dir96466,options86239,r91276,rest92277,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var if_helper96531 = R.makeFunction(function(if_helper_arg97551) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[68],1,arguments);
}
var ann_DASH_check_DASH_temp85552 = if_helper_arg97551;
return ann_DASH_check_DASH_temp85552;
});
var anf_if100550 = R.isBoolean(if_DASH_13515);
if(R.isPyretTrue(anf_if100550)) {
if(R.isPyretTrue(if_DASH_13515)) {
var program_DASH_name98532 = G(rest92277,"first",L[73]);
var anf_fun152530 = G(CM916,"compile-js",L[72]);
var anf_arg153529 = G(CM916,"start",L[71]);
var anf_fun154527 = G(r91276,"get",L[70]);
var $z519520 = D;
var $f525526 = function(_) {
return R.isFunction(anf_fun154527)?anf_fun154527.app(("dialect")):R.ffi.throwNonFunApp(L[69],anf_fun154527,[("dialect")]);
};
try {
if(--R.GAS > 0) {
$z519520 = $f525526();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f525526,
"from":L[69]});
}
} catch($e517518) {
if(R.isCont($e517518)) {
var $ss521522 = {"from":L[69],
"go":function(anf_arg155528) {
return $Hanf_arg299533(anf_arg155528,F313,X514,allow_DASH_shadowed94418,anf_arg153529,anf_fun152530,check_DASH_all97491,check_DASH_mode93389,if_helper96531,libs95467,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e517518.stack[R.EXN_STACKHEIGHT++] = $ss521522;
}
if(R.isPyretException($e517518)) {
$e517518.pyretStack.push(L[69]);
}
throw $e517518;
}
var $ret523524 = $Hanf_arg299533($z519520,F313,X514,allow_DASH_shadowed94418,anf_arg153529,anf_fun152530,check_DASH_all97491,check_DASH_mode93389,if_helper96531,libs95467,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret523524;
} else {
var anf_fun101544 = G(r91276,"has-key",L[75]);
var $z536537 = D;
var $f542543 = function(_) {
return R.isFunction(anf_fun101544)?anf_fun101544.app(("compile-standalone-js")):R.ffi.throwNonFunApp(L[74],anf_fun101544,[("compile-standalone-js")]);
};
try {
if(--R.GAS > 0) {
$z536537 = $f542543();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f542543,
"from":L[74]});
}
} catch($e534535) {
if(R.isCont($e534535)) {
var $ss538539 = {"from":L[74],
"go":function(if_DASH_11545) {
return $Hif_DASH_322546(if_DASH_11545,C112,CM916,F313,allow_DASH_shadowed94418,check_DASH_mode93389,if_helper96531,libs95467,lists1921,options86239,r91276,display3,print6,print_DASH_error7,raise8,tostring11);
}};
$e534535.stack[R.EXN_STACKHEIGHT++] = $ss538539;
}
if(R.isPyretException($e534535)) {
$e534535.pyretStack.push(L[74]);
}
throw $e534535;
}
var $ret540541 = $Hif_DASH_322546($z536537,C112,CM916,F313,allow_DASH_shadowed94418,check_DASH_mode93389,if_helper96531,libs95467,lists1921,options86239,r91276,display3,print6,print_DASH_error7,raise8,tostring11);
++R.GAS;
return $ret540541;
}
} else {
var cont_tail_arg98549 = R.throwNonBooleanCondition(L[68],("if"),if_DASH_13515);
if(--R.GAS > 0) {
$z547548 = R.isFunction(if_helper96531)?if_helper96531.app(cont_tail_arg98549):R.ffi.throwNonFunApp(L[68],if_helper96531,[cont_tail_arg98549]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper96531)?if_helper96531.app(cont_tail_arg98549):R.ffi.throwNonFunApp(L[68],if_helper96531,[cont_tail_arg98549]);
},
"from":L[68]});
}
++R.GAS;
return $z547548;
}
};
var $Hanf_arg299533 = function(anf_arg155528,F313,X514,allow_DASH_shadowed94418,anf_arg153529,anf_fun152530,check_DASH_all97491,check_DASH_mode93389,if_helper96531,libs95467,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_fun156563 = G(F313,"file-to-string",L[77]);
var $z555556 = D;
var $f561562 = function(_) {
return R.isFunction(anf_fun156563)?anf_fun156563.app(program_DASH_name98532):R.ffi.throwNonFunApp(L[76],anf_fun156563,[program_DASH_name98532]);
};
try {
if(--R.GAS > 0) {
$z555556 = $f561562();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f561562,
"from":L[76]});
}
} catch($e553554) {
if(R.isCont($e553554)) {
var $ss557558 = {"from":L[76],
"go":function(anf_arg157564) {
return $Hanf_arg298565(anf_arg157564,X514,allow_DASH_shadowed94418,anf_arg153529,anf_arg155528,anf_fun152530,check_DASH_all97491,check_DASH_mode93389,if_helper96531,libs95467,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e553554.stack[R.EXN_STACKHEIGHT++] = $ss557558;
}
if(R.isPyretException($e553554)) {
$e553554.pyretStack.push(L[76]);
}
throw $e553554;
}
var $ret559560 = $Hanf_arg298565($z555556,X514,allow_DASH_shadowed94418,anf_arg153529,anf_arg155528,anf_fun152530,check_DASH_all97491,check_DASH_mode93389,if_helper96531,libs95467,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret559560;
};
var $Hanf_arg298565 = function(anf_arg157564,X514,allow_DASH_shadowed94418,anf_arg153529,anf_arg155528,anf_fun152530,check_DASH_all97491,check_DASH_mode93389,if_helper96531,libs95467,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var anf_arg158576 = R.makeObject({"check-mode":check_DASH_mode93389,
"allow-shadowed":allow_DASH_shadowed94418,
"collect-all":(false),
"ignore-unbound":(false)});
var $z568569 = D;
var $f574575 = function(_) {
return R.isFunction(anf_fun152530)?anf_fun152530.app(anf_arg153529,anf_arg155528,anf_arg157564,program_DASH_name98532,libs95467,anf_arg158576):R.ffi.throwNonFunApp(L[78],anf_fun152530,[anf_arg153529,anf_arg155528,anf_arg157564,program_DASH_name98532,libs95467,anf_arg158576]);
};
try {
if(--R.GAS > 0) {
$z568569 = $f574575();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f574575,
"from":L[78]});
}
} catch($e566567) {
if(R.isCont($e566567)) {
var $ss570571 = {"from":L[78],
"go":function(anf_bracket159577) {
return $Hanf_bracket297578(anf_bracket159577,X514,check_DASH_all97491,check_DASH_mode93389,if_helper96531,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e566567.stack[R.EXN_STACKHEIGHT++] = $ss570571;
}
if(R.isPyretException($e566567)) {
$e566567.pyretStack.push(L[78]);
}
throw $e566567;
}
var $ret572573 = $Hanf_bracket297578($z568569,X514,check_DASH_all97491,check_DASH_mode93389,if_helper96531,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret572573;
};
var $Hanf_bracket297578 = function(anf_bracket159577,X514,check_DASH_all97491,check_DASH_mode93389,if_helper96531,lists1921,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11) {
var result99626 = G(anf_bracket159577,"result",L[86]);
var cases_DASH_val19625 = result99626;
var anf_fun160589 = G(cases_DASH_val19625,"_match",L[79]);
var anf_obj201595 = R.makeFunction(function(comp_DASH_object100610) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[82],1,arguments);
}
var anf_fun162623 = G(X514,"exec",L[85]);
var anf_fun163621 = G(comp_DASH_object100610,"pyret-to-js-runnable",L[84]);
var $z613614 = D;
var $f619620 = function(_) {
return R.isFunction(anf_fun163621)?anf_fun163621.app():R.ffi.throwNonFunApp(L[83],anf_fun163621,[]);
};
try {
if(--R.GAS > 0) {
$z613614 = $f619620();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f619620,
"from":L[83]});
}
} catch($e611612) {
if(R.isCont($e611612)) {
var $ss615616 = {"from":L[83],
"go":function(anf_arg164622) {
return $Hanf_arg288624(anf_arg164622,anf_fun162623,check_DASH_all97491,check_DASH_mode93389,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,raise8,string_DASH_contains9);
}};
$e611612.stack[R.EXN_STACKHEIGHT++] = $ss615616;
}
if(R.isPyretException($e611612)) {
$e611612.pyretStack.push(L[83]);
}
throw $e611612;
}
var $ret617618 = $Hanf_arg288624($z613614,anf_fun162623,check_DASH_all97491,check_DASH_mode93389,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,raise8,string_DASH_contains9);
++R.GAS;
return $ret617618;
});
var anf_obj207596 = R.makeFunction(function(errors103597) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[80],1,arguments);
}
var $z600601 = D;
var $f606607 = function(_) {
return R.isFunction(print_DASH_error7)?print_DASH_error7.app(("Compilation errors:")):R.ffi.throwNonFunApp(L[81],print_DASH_error7,[("Compilation errors:")]);
};
try {
if(--R.GAS > 0) {
$z600601 = $f606607();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f606607,
"from":L[81]});
}
} catch($e598599) {
if(R.isCont($e598599)) {
var $ss602603 = {"from":L[81],
"go":function(anf_begin_app_dropped289608) {
return $Hanf_begin_app_dropped295609(anf_begin_app_dropped289608,errors103597,lists1921,print_DASH_error7,raise8,tostring11);
}};
$e598599.stack[R.EXN_STACKHEIGHT++] = $ss602603;
}
if(R.isPyretException($e598599)) {
$e598599.pyretStack.push(L[81]);
}
throw $e598599;
}
var $ret604605 = $Hanf_begin_app_dropped295609($z600601,errors103597,lists1921,print_DASH_error7,raise8,tostring11);
++R.GAS;
return $ret604605;
});
var anf_arg208590 = R.makeObject({"ok":anf_obj201595,
"err":anf_obj207596});
var anf_arg210591 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[79],0,arguments);
}
var ann_DASH_check_DASH_temp209594 = R.throwNoBranchesMatched(L[79],("cases"));
return ann_DASH_check_DASH_temp209594;
});
var $z581582 = D;
var $f587588 = function(_) {
return R.isFunction(anf_fun160589)?anf_fun160589.app(anf_arg208590,anf_arg210591):R.ffi.throwNonFunApp(L[79],anf_fun160589,[anf_arg208590,anf_arg210591]);
};
try {
if(--R.GAS > 0) {
$z581582 = $f587588();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f587588,
"from":L[79]});
}
} catch($e579580) {
if(R.isCont($e579580)) {
var $ss583584 = {"from":L[79],
"go":function(cont_tail_arg211592) {
return $Hcont_tail_arg296593(cont_tail_arg211592,if_helper96531);
}};
$e579580.stack[R.EXN_STACKHEIGHT++] = $ss583584;
}
if(R.isPyretException($e579580)) {
$e579580.pyretStack.push(L[79]);
}
throw $e579580;
}
var $ret585586 = $Hcont_tail_arg296593($z581582,if_helper96531);
++R.GAS;
return $ret585586;
};
var $Hcont_tail_arg296593 = function(cont_tail_arg211592,if_helper96531) {
if(--R.GAS > 0) {
$z627628 = R.isFunction(if_helper96531)?if_helper96531.app(cont_tail_arg211592):R.ffi.throwNonFunApp(L[79],if_helper96531,[cont_tail_arg211592]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper96531)?if_helper96531.app(cont_tail_arg211592):R.ffi.throwNonFunApp(L[79],if_helper96531,[cont_tail_arg211592]);
},
"from":L[79]});
}
++R.GAS;
return $z627628;
};
var $Hanf_begin_app_dropped295609 = function(anf_begin_app_dropped289608,errors103597,lists1921,print_DASH_error7,raise8,tostring11) {
var anf_fun203639 = G(lists1921,"each",L[89]);
var anf_arg206640 = R.makeFunction(function(e104643) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[87],1,arguments);
}
var $z646647 = D;
var $f652653 = function(_) {
return R.isFunction(tostring11)?tostring11.app(e104643):R.ffi.throwNonFunApp(L[88],tostring11,[e104643]);
};
try {
if(--R.GAS > 0) {
$z646647 = $f652653();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f652653,
"from":L[88]});
}
} catch($e644645) {
if(R.isCont($e644645)) {
var $ss648649 = {"from":L[88],
"go":function(anf_arg205654) {
return $Hanf_arg291655(anf_arg205654,print_DASH_error7);
}};
$e644645.stack[R.EXN_STACKHEIGHT++] = $ss648649;
}
if(R.isPyretException($e644645)) {
$e644645.pyretStack.push(L[88]);
}
throw $e644645;
}
var $ret650651 = $Hanf_arg291655($z646647,print_DASH_error7);
++R.GAS;
return $ret650651;
});
var $z631632 = D;
var $f637638 = function(_) {
return R.isFunction(anf_fun203639)?anf_fun203639.app(anf_arg206640,errors103597):R.ffi.throwNonFunApp(L[87],anf_fun203639,[anf_arg206640,errors103597]);
};
try {
if(--R.GAS > 0) {
$z631632 = $f637638();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f637638,
"from":L[87]});
}
} catch($e629630) {
if(R.isCont($e629630)) {
var $ss633634 = {"from":L[87],
"go":function(anf_begin_app_dropped292641) {
return $Hanf_begin_app_dropped294642(anf_begin_app_dropped292641,raise8);
}};
$e629630.stack[R.EXN_STACKHEIGHT++] = $ss633634;
}
if(R.isPyretException($e629630)) {
$e629630.pyretStack.push(L[87]);
}
throw $e629630;
}
var $ret635636 = $Hanf_begin_app_dropped294642($z631632,raise8);
++R.GAS;
return $ret635636;
};
var $Hanf_begin_app_dropped294642 = function(anf_begin_app_dropped292641,raise8) {
var $z658659 = D;
var $f664665 = function(_) {
return R.isFunction(raise8)?raise8.app(("There were compilation errors")):R.ffi.throwNonFunApp(L[80],raise8,[("There were compilation errors")]);
};
try {
if(--R.GAS > 0) {
$z658659 = $f664665();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f664665,
"from":L[80]});
}
} catch($e656657) {
if(R.isCont($e656657)) {
var $ss660661 = {"from":L[80],
"go":function(ann_DASH_check_DASH_temp202666) {
return $Hann_DASH_check_DASH_temp293667(ann_DASH_check_DASH_temp202666);
}};
$e656657.stack[R.EXN_STACKHEIGHT++] = $ss660661;
}
if(R.isPyretException($e656657)) {
$e656657.pyretStack.push(L[80]);
}
throw $e656657;
}
var $ret662663 = $Hann_DASH_check_DASH_temp293667($z658659);
++R.GAS;
return $ret662663;
};
var $Hann_DASH_check_DASH_temp293667 = function(ann_DASH_check_DASH_temp202666) {
return ann_DASH_check_DASH_temp202666;
};
var $Hanf_arg291655 = function(anf_arg205654,print_DASH_error7) {
var $z670671 = D;
var $f676677 = function(_) {
return R.isFunction(print_DASH_error7)?print_DASH_error7.app(anf_arg205654):R.ffi.throwNonFunApp(L[87],print_DASH_error7,[anf_arg205654]);
};
try {
if(--R.GAS > 0) {
$z670671 = $f676677();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f676677,
"from":L[87]});
}
} catch($e668669) {
if(R.isCont($e668669)) {
var $ss672673 = {"from":L[87],
"go":function(ann_DASH_check_DASH_temp204678) {
return $Hann_DASH_check_DASH_temp290679(ann_DASH_check_DASH_temp204678);
}};
$e668669.stack[R.EXN_STACKHEIGHT++] = $ss672673;
}
if(R.isPyretException($e668669)) {
$e668669.pyretStack.push(L[87]);
}
throw $e668669;
}
var $ret674675 = $Hann_DASH_check_DASH_temp290679($z670671);
++R.GAS;
return $ret674675;
};
var $Hann_DASH_check_DASH_temp290679 = function(ann_DASH_check_DASH_temp204678) {
return ann_DASH_check_DASH_temp204678;
};
var $Hanf_arg288624 = function(anf_arg164622,anf_fun162623,check_DASH_all97491,check_DASH_mode93389,module_DASH_dir96466,program_DASH_name98532,r91276,rest92277,not4,nothing5,print6,raise8,string_DASH_contains9) {
var anf_fun165690 = G(r91276,"get",L[91]);
var $z682683 = D;
var $f688689 = function(_) {
return R.isFunction(anf_fun165690)?anf_fun165690.app(("dialect")):R.ffi.throwNonFunApp(L[90],anf_fun165690,[("dialect")]);
};
try {
if(--R.GAS > 0) {
$z682683 = $f688689();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f688689,
"from":L[90]});
}
} catch($e680681) {
if(R.isCont($e680681)) {
var $ss684685 = {"from":L[90],
"go":function(anf_arg166691) {
return $Hanf_arg287692(anf_arg166691,anf_arg164622,anf_fun162623,check_DASH_all97491,check_DASH_mode93389,module_DASH_dir96466,program_DASH_name98532,rest92277,not4,nothing5,print6,raise8,string_DASH_contains9);
}};
$e680681.stack[R.EXN_STACKHEIGHT++] = $ss684685;
}
if(R.isPyretException($e680681)) {
$e680681.pyretStack.push(L[90]);
}
throw $e680681;
}
var $ret686687 = $Hanf_arg287692($z682683,anf_arg164622,anf_fun162623,check_DASH_all97491,check_DASH_mode93389,module_DASH_dir96466,program_DASH_name98532,rest92277,not4,nothing5,print6,raise8,string_DASH_contains9);
++R.GAS;
return $ret686687;
};
var $Hanf_arg287692 = function(anf_arg166691,anf_arg164622,anf_fun162623,check_DASH_all97491,check_DASH_mode93389,module_DASH_dir96466,program_DASH_name98532,rest92277,not4,nothing5,print6,raise8,string_DASH_contains9) {
var $z695696 = D;
var $f701702 = function(_) {
return R.isFunction(anf_fun162623)?anf_fun162623.app(anf_arg164622,program_DASH_name98532,module_DASH_dir96466,check_DASH_all97491,anf_arg166691,rest92277):R.ffi.throwNonFunApp(L[92],anf_fun162623,[anf_arg164622,program_DASH_name98532,module_DASH_dir96466,check_DASH_all97491,anf_arg166691,rest92277]);
};
try {
if(--R.GAS > 0) {
$z695696 = $f701702();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f701702,
"from":L[92]});
}
} catch($e693694) {
if(R.isCont($e693694)) {
var $ss697698 = {"from":L[92],
"go":function(exec_DASH_result101703) {
return $Hexec_DASH_result286704(exec_DASH_result101703,check_DASH_mode93389,not4,nothing5,print6,raise8,string_DASH_contains9);
}};
$e693694.stack[R.EXN_STACKHEIGHT++] = $ss697698;
}
if(R.isPyretException($e693694)) {
$e693694.pyretStack.push(L[92]);
}
throw $e693694;
}
var $ret699700 = $Hexec_DASH_result286704($z695696,check_DASH_mode93389,not4,nothing5,print6,raise8,string_DASH_contains9);
++R.GAS;
return $ret699700;
};
var $Hexec_DASH_result286704 = function(exec_DASH_result101703,check_DASH_mode93389,not4,nothing5,print6,raise8,string_DASH_contains9) {
var if_DASH_14749 = G(exec_DASH_result101703,"success",L[100]);
var if_helper167717 = R.makeFunction(function(if_helper_arg168754) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[99],1,arguments);
}
var ann_DASH_check_DASH_temp161755 = if_helper_arg168754;
return ann_DASH_check_DASH_temp161755;
});
var anf_if171753 = R.isBoolean(if_DASH_14749);
if(R.isPyretTrue(anf_if171753)) {
if(R.isPyretTrue(if_DASH_14749)) {
var when_DASH_15731 = check_DASH_mode93389;
var anf_if178735 = R.isBoolean(when_DASH_15731);
if(R.isPyretTrue(anf_if178735)) {
if(R.isPyretTrue(when_DASH_15731)) {
var anf_fun180715 = G(exec_DASH_result101703,"render-check-results",L[94]);
var $z707708 = D;
var $f713714 = function(_) {
return R.isFunction(anf_fun180715)?anf_fun180715.app():R.ffi.throwNonFunApp(L[93],anf_fun180715,[]);
};
try {
if(--R.GAS > 0) {
$z707708 = $f713714();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f713714,
"from":L[93]});
}
} catch($e705706) {
if(R.isCont($e705706)) {
var $ss709710 = {"from":L[93],
"go":function(results_DASH_str102716) {
return $Hresults_DASH_str280718(results_DASH_str102716,if_helper167717,not4,nothing5,print6,raise8,string_DASH_contains9);
}};
$e705706.stack[R.EXN_STACKHEIGHT++] = $ss709710;
}
if(R.isPyretException($e705706)) {
$e705706.pyretStack.push(L[93]);
}
throw $e705706;
}
var $ret711712 = $Hresults_DASH_str280718($z707708,if_helper167717,not4,nothing5,print6,raise8,string_DASH_contains9);
++R.GAS;
return $ret711712;
} else {
var $z721722 = D;
var $f727728 = function(_) {
return R.isFunction(if_helper167717)?if_helper167717.app(nothing5):R.ffi.throwNonFunApp(L[95],if_helper167717,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z721722 = $f727728();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f727728,
"from":L[95]});
}
} catch($e719720) {
if(R.isCont($e719720)) {
var $ss723724 = {"from":L[95],
"go":function(cont_tail_app179729) {
return $Hcont_tail_app281730(cont_tail_app179729);
}};
$e719720.stack[R.EXN_STACKHEIGHT++] = $ss723724;
}
if(R.isPyretException($e719720)) {
$e719720.pyretStack.push(L[95]);
}
throw $e719720;
}
var $ret725726 = $Hcont_tail_app281730($z721722);
++R.GAS;
return $ret725726;
}
} else {
var cont_tail_arg176734 = R.throwNonBooleanCondition(L[96],("when"),when_DASH_15731);
if(--R.GAS > 0) {
$z732733 = R.isFunction(if_helper167717)?if_helper167717.app(cont_tail_arg176734):R.ffi.throwNonFunApp(L[96],if_helper167717,[cont_tail_arg176734]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper167717)?if_helper167717.app(cont_tail_arg176734):R.ffi.throwNonFunApp(L[96],if_helper167717,[cont_tail_arg176734]);
},
"from":L[96]});
}
++R.GAS;
return $z732733;
}
} else {
var anf_fun172746 = G(exec_DASH_result101703,"render-error-message",L[98]);
var $z738739 = D;
var $f744745 = function(_) {
return R.isFunction(anf_fun172746)?anf_fun172746.app():R.ffi.throwNonFunApp(L[97],anf_fun172746,[]);
};
try {
if(--R.GAS > 0) {
$z738739 = $f744745();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f744745,
"from":L[97]});
}
} catch($e736737) {
if(R.isCont($e736737)) {
var $ss740741 = {"from":L[97],
"go":function(anf_arg173747) {
return $Hanf_arg285748(anf_arg173747,if_helper167717,print6,raise8);
}};
$e736737.stack[R.EXN_STACKHEIGHT++] = $ss740741;
}
if(R.isPyretException($e736737)) {
$e736737.pyretStack.push(L[97]);
}
throw $e736737;
}
var $ret742743 = $Hanf_arg285748($z738739,if_helper167717,print6,raise8);
++R.GAS;
return $ret742743;
}
} else {
var cont_tail_arg169752 = R.throwNonBooleanCondition(L[99],("if"),if_DASH_14749);
if(--R.GAS > 0) {
$z750751 = R.isFunction(if_helper167717)?if_helper167717.app(cont_tail_arg169752):R.ffi.throwNonFunApp(L[99],if_helper167717,[cont_tail_arg169752]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper167717)?if_helper167717.app(cont_tail_arg169752):R.ffi.throwNonFunApp(L[99],if_helper167717,[cont_tail_arg169752]);
},
"from":L[99]});
}
++R.GAS;
return $z750751;
}
};
var $Hresults_DASH_str280718 = function(results_DASH_str102716,if_helper167717,not4,nothing5,print6,raise8,string_DASH_contains9) {
var $z758759 = D;
var $f764765 = function(_) {
return R.isFunction(print6)?print6.app(results_DASH_str102716):R.ffi.throwNonFunApp(L[101],print6,[results_DASH_str102716]);
};
try {
if(--R.GAS > 0) {
$z758759 = $f764765();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f764765,
"from":L[101]});
}
} catch($e756757) {
if(R.isCont($e756757)) {
var $ss760761 = {"from":L[101],
"go":function(anf_begin_app_dropped267766) {
return $Hanf_begin_app_dropped279767(anf_begin_app_dropped267766,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9);
}};
$e756757.stack[R.EXN_STACKHEIGHT++] = $ss760761;
}
if(R.isPyretException($e756757)) {
$e756757.pyretStack.push(L[101]);
}
throw $e756757;
}
var $ret762763 = $Hanf_begin_app_dropped279767($z758759,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9);
++R.GAS;
return $ret762763;
};
var $Hanf_begin_app_dropped279767 = function(anf_begin_app_dropped267766,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9) {
var $z770771 = D;
var $f776777 = function(_) {
return R.isFunction(string_DASH_contains9)?string_DASH_contains9.app(results_DASH_str102716,("Looks shipshape")):R.ffi.throwNonFunApp(L[102],string_DASH_contains9,[results_DASH_str102716,("Looks shipshape")]);
};
try {
if(--R.GAS > 0) {
$z770771 = $f776777();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f776777,
"from":L[102]});
}
} catch($e768769) {
if(R.isCont($e768769)) {
var $ss772773 = {"from":L[102],
"go":function(anf_arg181778) {
return $Hanf_arg278779(anf_arg181778,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9);
}};
$e768769.stack[R.EXN_STACKHEIGHT++] = $ss772773;
}
if(R.isPyretException($e768769)) {
$e768769.pyretStack.push(L[102]);
}
throw $e768769;
}
var $ret774775 = $Hanf_arg278779($z770771,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9);
++R.GAS;
return $ret774775;
};
var $Hanf_arg278779 = function(anf_arg181778,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9) {
var $z782783 = D;
var $f788789 = function(_) {
return R.isFunction(not4)?not4.app(anf_arg181778):R.ffi.throwNonFunApp(L[103],not4,[anf_arg181778]);
};
try {
if(--R.GAS > 0) {
$z782783 = $f788789();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f788789,
"from":L[103]});
}
} catch($e780781) {
if(R.isCont($e780781)) {
var $ss784785 = {"from":L[103],
"go":function(and_DASH_oper_DASH_17790) {
return $Hand_DASH_oper_DASH_277791(and_DASH_oper_DASH_17790,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9);
}};
$e780781.stack[R.EXN_STACKHEIGHT++] = $ss784785;
}
if(R.isPyretException($e780781)) {
$e780781.pyretStack.push(L[103]);
}
throw $e780781;
}
var $ret786787 = $Hand_DASH_oper_DASH_277791($z782783,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9);
++R.GAS;
return $ret786787;
};
var $Hand_DASH_oper_DASH_277791 = function(and_DASH_oper_DASH_17790,if_helper167717,results_DASH_str102716,not4,nothing5,raise8,string_DASH_contains9) {
var if_helper182803 = R.makeFunction(function(if_helper_arg183821) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[103],1,arguments);
}
var when_DASH_16847 = if_helper_arg183821;
var if_helper184833 = R.makeFunction(function(if_helper_arg185852) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[107],1,arguments);
}
if_helper_arg185852;
var $z855856 = D;
var $f861862 = function(_) {
return R.isFunction(if_helper167717)?if_helper167717.app(nothing5):R.ffi.throwNonFunApp(L[95],if_helper167717,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z855856 = $f861862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f861862,
"from":L[95]});
}
} catch($e853854) {
if(R.isCont($e853854)) {
var $ss857858 = {"from":L[95],
"go":function(cont_tail_app186863) {
return $Hcont_tail_app268864(cont_tail_app186863);
}};
$e853854.stack[R.EXN_STACKHEIGHT++] = $ss857858;
}
if(R.isPyretException($e853854)) {
$e853854.pyretStack.push(L[95]);
}
throw $e853854;
}
var $ret859860 = $Hcont_tail_app268864($z855856);
++R.GAS;
return $ret859860;
});
var anf_if189851 = R.isBoolean(when_DASH_16847);
if(R.isPyretTrue(anf_if189851)) {
if(R.isPyretTrue(when_DASH_16847)) {
var $z824825 = D;
var $f830831 = function(_) {
return R.isFunction(raise8)?raise8.app(("There were test errors")):R.ffi.throwNonFunApp(L[106],raise8,[("There were test errors")]);
};
try {
if(--R.GAS > 0) {
$z824825 = $f830831();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f830831,
"from":L[106]});
}
} catch($e822823) {
if(R.isCont($e822823)) {
var $ss826827 = {"from":L[106],
"go":function(anf_begin_app_dropped269832) {
return $Hanf_begin_app_dropped271834(anf_begin_app_dropped269832,if_helper184833,nothing5);
}};
$e822823.stack[R.EXN_STACKHEIGHT++] = $ss826827;
}
if(R.isPyretException($e822823)) {
$e822823.pyretStack.push(L[106]);
}
throw $e822823;
}
var $ret828829 = $Hanf_begin_app_dropped271834($z824825,if_helper184833,nothing5);
++R.GAS;
return $ret828829;
} else {
var $z837838 = D;
var $f843844 = function(_) {
return R.isFunction(if_helper184833)?if_helper184833.app(nothing5):R.ffi.throwNonFunApp(L[107],if_helper184833,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z837838 = $f843844();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f843844,
"from":L[107]});
}
} catch($e835836) {
if(R.isCont($e835836)) {
var $ss839840 = {"from":L[107],
"go":function(cont_tail_app190845) {
return $Hcont_tail_app272846(cont_tail_app190845);
}};
$e835836.stack[R.EXN_STACKHEIGHT++] = $ss839840;
}
if(R.isPyretException($e835836)) {
$e835836.pyretStack.push(L[107]);
}
throw $e835836;
}
var $ret841842 = $Hcont_tail_app272846($z837838);
++R.GAS;
return $ret841842;
}
} else {
var cont_tail_arg187850 = R.throwNonBooleanCondition(L[103],("when"),when_DASH_16847);
if(--R.GAS > 0) {
$z848849 = R.isFunction(if_helper184833)?if_helper184833.app(cont_tail_arg187850):R.ffi.throwNonFunApp(L[103],if_helper184833,[cont_tail_arg187850]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper184833)?if_helper184833.app(cont_tail_arg187850):R.ffi.throwNonFunApp(L[103],if_helper184833,[cont_tail_arg187850]);
},
"from":L[103]});
}
++R.GAS;
return $z848849;
}
});
var anf_if194820 = R.isBoolean(and_DASH_oper_DASH_17790);
if(R.isPyretTrue(anf_if194820)) {
if(R.isPyretTrue(and_DASH_oper_DASH_17790)) {
var $z794795 = D;
var $f800801 = function(_) {
return R.isFunction(string_DASH_contains9)?string_DASH_contains9.app(results_DASH_str102716,("The program didn't define any tests")):R.ffi.throwNonFunApp(L[104],string_DASH_contains9,[results_DASH_str102716,("The program didn't define any tests")]);
};
try {
if(--R.GAS > 0) {
$z794795 = $f800801();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f800801,
"from":L[104]});
}
} catch($e792793) {
if(R.isCont($e792793)) {
var $ss796797 = {"from":L[104],
"go":function(anf_arg196802) {
return $Hanf_arg275804(anf_arg196802,if_helper182803,not4);
}};
$e792793.stack[R.EXN_STACKHEIGHT++] = $ss796797;
}
if(R.isPyretException($e792793)) {
$e792793.pyretStack.push(L[104]);
}
throw $e792793;
}
var $ret798799 = $Hanf_arg275804($z794795,if_helper182803,not4);
++R.GAS;
return $ret798799;
} else {
var $z807808 = D;
var $f813814 = function(_) {
return R.isFunction(if_helper182803)?if_helper182803.app((false)):R.ffi.throwNonFunApp(L[103],if_helper182803,[(false)]);
};
try {
if(--R.GAS > 0) {
$z807808 = $f813814();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f813814,
"from":L[103]});
}
} catch($e805806) {
if(R.isCont($e805806)) {
var $ss809810 = {"from":L[103],
"go":function(cont_tail_app195815) {
return $Hcont_tail_app276816(cont_tail_app195815);
}};
$e805806.stack[R.EXN_STACKHEIGHT++] = $ss809810;
}
if(R.isPyretException($e805806)) {
$e805806.pyretStack.push(L[103]);
}
throw $e805806;
}
var $ret811812 = $Hcont_tail_app276816($z807808);
++R.GAS;
return $ret811812;
}
} else {
var cont_tail_arg192819 = R.throwNonBooleanOp(L[105],("first"),("and"),and_DASH_oper_DASH_17790);
if(--R.GAS > 0) {
$z817818 = R.isFunction(if_helper182803)?if_helper182803.app(cont_tail_arg192819):R.ffi.throwNonFunApp(L[105],if_helper182803,[cont_tail_arg192819]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper182803)?if_helper182803.app(cont_tail_arg192819):R.ffi.throwNonFunApp(L[105],if_helper182803,[cont_tail_arg192819]);
},
"from":L[105]});
}
++R.GAS;
return $z817818;
}
};
var $Hanf_arg275804 = function(anf_arg196802,if_helper182803,not4) {
var $z867868 = D;
var $f873874 = function(_) {
return R.isFunction(not4)?not4.app(anf_arg196802):R.ffi.throwNonFunApp(L[103],not4,[anf_arg196802]);
};
try {
if(--R.GAS > 0) {
$z867868 = $f873874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f873874,
"from":L[103]});
}
} catch($e865866) {
if(R.isCont($e865866)) {
var $ss869870 = {"from":L[103],
"go":function(and_DASH_oper_DASH_18875) {
return $Hand_DASH_oper_DASH_274876(and_DASH_oper_DASH_18875,if_helper182803);
}};
$e865866.stack[R.EXN_STACKHEIGHT++] = $ss869870;
}
if(R.isPyretException($e865866)) {
$e865866.pyretStack.push(L[103]);
}
throw $e865866;
}
var $ret871872 = $Hand_DASH_oper_DASH_274876($z867868,if_helper182803);
++R.GAS;
return $ret871872;
};
var $Hand_DASH_oper_DASH_274876 = function(and_DASH_oper_DASH_18875,if_helper182803) {
var anf_if199892 = R.isBoolean(and_DASH_oper_DASH_18875);
if(R.isPyretTrue(anf_if199892)) {
var $z879880 = D;
var $f885886 = function(_) {
return R.isFunction(if_helper182803)?if_helper182803.app(and_DASH_oper_DASH_18875):R.ffi.throwNonFunApp(L[103],if_helper182803,[and_DASH_oper_DASH_18875]);
};
try {
if(--R.GAS > 0) {
$z879880 = $f885886();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f885886,
"from":L[103]});
}
} catch($e877878) {
if(R.isCont($e877878)) {
var $ss881882 = {"from":L[103],
"go":function(cont_tail_app200887) {
return $Hcont_tail_app273888(cont_tail_app200887);
}};
$e877878.stack[R.EXN_STACKHEIGHT++] = $ss881882;
}
if(R.isPyretException($e877878)) {
$e877878.pyretStack.push(L[103]);
}
throw $e877878;
}
var $ret883884 = $Hcont_tail_app273888($z879880);
++R.GAS;
return $ret883884;
} else {
var cont_tail_arg197891 = R.throwNonBooleanOp(L[108],("second"),("and"),and_DASH_oper_DASH_18875);
if(--R.GAS > 0) {
$z889890 = R.isFunction(if_helper182803)?if_helper182803.app(cont_tail_arg197891):R.ffi.throwNonFunApp(L[108],if_helper182803,[cont_tail_arg197891]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper182803)?if_helper182803.app(cont_tail_arg197891):R.ffi.throwNonFunApp(L[108],if_helper182803,[cont_tail_arg197891]);
},
"from":L[108]});
}
++R.GAS;
return $z889890;
}
};
var $Hcont_tail_app273888 = function(cont_tail_app200887) {
return cont_tail_app200887;
};
var $Hcont_tail_app276816 = function(cont_tail_app195815) {
return cont_tail_app195815;
};
var $Hanf_begin_app_dropped271834 = function(anf_begin_app_dropped269832,if_helper184833,nothing5) {
var $z895896 = D;
var $f901902 = function(_) {
return R.isFunction(if_helper184833)?if_helper184833.app(nothing5):R.ffi.throwNonFunApp(L[107],if_helper184833,[nothing5]);
};
try {
if(--R.GAS > 0) {
$z895896 = $f901902();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f901902,
"from":L[107]});
}
} catch($e893894) {
if(R.isCont($e893894)) {
var $ss897898 = {"from":L[107],
"go":function(cont_tail_app191903) {
return $Hcont_tail_app270904(cont_tail_app191903);
}};
$e893894.stack[R.EXN_STACKHEIGHT++] = $ss897898;
}
if(R.isPyretException($e893894)) {
$e893894.pyretStack.push(L[107]);
}
throw $e893894;
}
var $ret899900 = $Hcont_tail_app270904($z895896);
++R.GAS;
return $ret899900;
};
var $Hcont_tail_app270904 = function(cont_tail_app191903) {
return cont_tail_app191903;
};
var $Hcont_tail_app272846 = function(cont_tail_app190845) {
return cont_tail_app190845;
};
var $Hcont_tail_app268864 = function(cont_tail_app186863) {
return cont_tail_app186863;
};
var $Hcont_tail_app281730 = function(cont_tail_app179729) {
return cont_tail_app179729;
};
var $Hanf_arg285748 = function(anf_arg173747,if_helper167717,print6,raise8) {
var $z907908 = D;
var $f913914 = function(_) {
return R.isFunction(print6)?print6.app(anf_arg173747):R.ffi.throwNonFunApp(L[109],print6,[anf_arg173747]);
};
try {
if(--R.GAS > 0) {
$z907908 = $f913914();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f913914,
"from":L[109]});
}
} catch($e905906) {
if(R.isCont($e905906)) {
var $ss909910 = {"from":L[109],
"go":function(anf_begin_app_dropped282915) {
return $Hanf_begin_app_dropped284916(anf_begin_app_dropped282915,if_helper167717,raise8);
}};
$e905906.stack[R.EXN_STACKHEIGHT++] = $ss909910;
}
if(R.isPyretException($e905906)) {
$e905906.pyretStack.push(L[109]);
}
throw $e905906;
}
var $ret911912 = $Hanf_begin_app_dropped284916($z907908,if_helper167717,raise8);
++R.GAS;
return $ret911912;
};
var $Hanf_begin_app_dropped284916 = function(anf_begin_app_dropped282915,if_helper167717,raise8) {
var $z919920 = D;
var $f925926 = function(_) {
return R.isFunction(raise8)?raise8.app(("There were execution errors")):R.ffi.throwNonFunApp(L[110],raise8,[("There were execution errors")]);
};
try {
if(--R.GAS > 0) {
$z919920 = $f925926();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f925926,
"from":L[110]});
}
} catch($e917918) {
if(R.isCont($e917918)) {
var $ss921922 = {"from":L[110],
"go":function(cont_tail_arg174927) {
return $Hcont_tail_arg283928(cont_tail_arg174927,if_helper167717);
}};
$e917918.stack[R.EXN_STACKHEIGHT++] = $ss921922;
}
if(R.isPyretException($e917918)) {
$e917918.pyretStack.push(L[110]);
}
throw $e917918;
}
var $ret923924 = $Hcont_tail_arg283928($z919920,if_helper167717);
++R.GAS;
return $ret923924;
};
var $Hcont_tail_arg283928 = function(cont_tail_arg174927,if_helper167717) {
if(--R.GAS > 0) {
$z929930 = R.isFunction(if_helper167717)?if_helper167717.app(cont_tail_arg174927):R.ffi.throwNonFunApp(L[110],if_helper167717,[cont_tail_arg174927]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper167717)?if_helper167717.app(cont_tail_arg174927):R.ffi.throwNonFunApp(L[110],if_helper167717,[cont_tail_arg174927]);
},
"from":L[110]});
}
++R.GAS;
return $z929930;
};
var $Hif_DASH_322546 = function(if_DASH_11545,C112,CM916,F313,allow_DASH_shadowed94418,check_DASH_mode93389,if_helper96531,libs95467,lists1921,options86239,r91276,display3,print6,print_DASH_error7,raise8,tostring11) {
var if_helper102944 = R.makeFunction(function(if_helper_arg103963) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[74],1,arguments);
}
var result1051010 = if_helper_arg103963;
var cases_DASH_val121009 = result1051010;
var anf_fun104974 = G(cases_DASH_val121009,"_match",L[116]);
var anf_obj107980 = R.makeFunction(function(comp_DASH_object106995) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[119],1,arguments);
}
var anf_fun1061006 = G(comp_DASH_object106995,"print-js-runnable",L[120]);
var $z998999 = D;
var $f10041005 = function(_) {
return R.isFunction(anf_fun1061006)?anf_fun1061006.app(display3):R.ffi.throwNonFunApp(L[119],anf_fun1061006,[display3]);
};
try {
if(--R.GAS > 0) {
$z998999 = $f10041005();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10041005,
"from":L[119]});
}
} catch($e996997) {
if(R.isCont($e996997)) {
var $ss10001001 = {"from":L[119],
"go":function(ann_DASH_check_DASH_temp1051007) {
return $Hann_DASH_check_DASH_temp3001008(ann_DASH_check_DASH_temp1051007);
}};
$e996997.stack[R.EXN_STACKHEIGHT++] = $ss10001001;
}
if(R.isPyretException($e996997)) {
$e996997.pyretStack.push(L[119]);
}
throw $e996997;
}
var $ret10021003 = $Hann_DASH_check_DASH_temp3001008($z998999);
++R.GAS;
return $ret10021003;
});
var anf_obj113981 = R.makeFunction(function(errors107982) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
var $z985986 = D;
var $f991992 = function(_) {
return R.isFunction(print_DASH_error7)?print_DASH_error7.app(("Compilation errors:")):R.ffi.throwNonFunApp(L[118],print_DASH_error7,[("Compilation errors:")]);
};
try {
if(--R.GAS > 0) {
$z985986 = $f991992();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f991992,
"from":L[118]});
}
} catch($e983984) {
if(R.isCont($e983984)) {
var $ss987988 = {"from":L[118],
"go":function(anf_begin_app_dropped301993) {
return $Hanf_begin_app_dropped307994(anf_begin_app_dropped301993,errors107982,lists1921,print_DASH_error7,raise8,tostring11);
}};
$e983984.stack[R.EXN_STACKHEIGHT++] = $ss987988;
}
if(R.isPyretException($e983984)) {
$e983984.pyretStack.push(L[118]);
}
throw $e983984;
}
var $ret989990 = $Hanf_begin_app_dropped307994($z985986,errors107982,lists1921,print_DASH_error7,raise8,tostring11);
++R.GAS;
return $ret989990;
});
var anf_arg114975 = R.makeObject({"ok":anf_obj107980,
"err":anf_obj113981});
var anf_arg116976 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[116],0,arguments);
}
var ann_DASH_check_DASH_temp115979 = R.throwNoBranchesMatched(L[116],("cases"));
return ann_DASH_check_DASH_temp115979;
});
var $z966967 = D;
var $f972973 = function(_) {
return R.isFunction(anf_fun104974)?anf_fun104974.app(anf_arg114975,anf_arg116976):R.ffi.throwNonFunApp(L[116],anf_fun104974,[anf_arg114975,anf_arg116976]);
};
try {
if(--R.GAS > 0) {
$z966967 = $f972973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f972973,
"from":L[116]});
}
} catch($e964965) {
if(R.isCont($e964965)) {
var $ss968969 = {"from":L[116],
"go":function(cont_tail_arg117977) {
return $Hcont_tail_arg308978(cont_tail_arg117977,if_helper96531);
}};
$e964965.stack[R.EXN_STACKHEIGHT++] = $ss968969;
}
if(R.isPyretException($e964965)) {
$e964965.pyretStack.push(L[116]);
}
throw $e964965;
}
var $ret970971 = $Hcont_tail_arg308978($z966967,if_helper96531);
++R.GAS;
return $ret970971;
});
var anf_if121962 = R.isBoolean(if_DASH_11545);
if(R.isPyretTrue(anf_if121962)) {
if(R.isPyretTrue(if_DASH_11545)) {
var anf_fun146943 = G(CM916,"compile-standalone-js-file",L[113]);
var anf_fun147941 = G(r91276,"get",L[112]);
var $z933934 = D;
var $f939940 = function(_) {
return R.isFunction(anf_fun147941)?anf_fun147941.app(("compile-standalone-js")):R.ffi.throwNonFunApp(L[111],anf_fun147941,[("compile-standalone-js")]);
};
try {
if(--R.GAS > 0) {
$z933934 = $f939940();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f939940,
"from":L[111]});
}
} catch($e931932) {
if(R.isCont($e931932)) {
var $ss935936 = {"from":L[111],
"go":function(anf_arg148942) {
return $Hanf_arg310945(anf_arg148942,allow_DASH_shadowed94418,anf_fun146943,check_DASH_mode93389,if_helper102944,libs95467);
}};
$e931932.stack[R.EXN_STACKHEIGHT++] = $ss935936;
}
if(R.isPyretException($e931932)) {
$e931932.pyretStack.push(L[111]);
}
throw $e931932;
}
var $ret937938 = $Hanf_arg310945($z933934,allow_DASH_shadowed94418,anf_fun146943,check_DASH_mode93389,if_helper102944,libs95467);
++R.GAS;
return $ret937938;
} else {
var anf_fun122956 = G(r91276,"has-key",L[115]);
var $z948949 = D;
var $f954955 = function(_) {
return R.isFunction(anf_fun122956)?anf_fun122956.app(("compile-module-js")):R.ffi.throwNonFunApp(L[114],anf_fun122956,[("compile-module-js")]);
};
try {
if(--R.GAS > 0) {
$z948949 = $f954955();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f954955,
"from":L[114]});
}
} catch($e946947) {
if(R.isCont($e946947)) {
var $ss950951 = {"from":L[114],
"go":function(if_DASH_10957) {
return $Hif_DASH_321958(if_DASH_10957,C112,CM916,F313,allow_DASH_shadowed94418,check_DASH_mode93389,if_helper102944,libs95467,options86239,r91276,print6,raise8);
}};
$e946947.stack[R.EXN_STACKHEIGHT++] = $ss950951;
}
if(R.isPyretException($e946947)) {
$e946947.pyretStack.push(L[114]);
}
throw $e946947;
}
var $ret952953 = $Hif_DASH_321958($z948949,C112,CM916,F313,allow_DASH_shadowed94418,check_DASH_mode93389,if_helper102944,libs95467,options86239,r91276,print6,raise8);
++R.GAS;
return $ret952953;
}
} else {
var cont_tail_arg119961 = R.throwNonBooleanCondition(L[74],("if"),if_DASH_11545);
if(--R.GAS > 0) {
$z959960 = R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg119961):R.ffi.throwNonFunApp(L[74],if_helper102944,[cont_tail_arg119961]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg119961):R.ffi.throwNonFunApp(L[74],if_helper102944,[cont_tail_arg119961]);
},
"from":L[74]});
}
++R.GAS;
return $z959960;
}
};
var $Hanf_arg310945 = function(anf_arg148942,allow_DASH_shadowed94418,anf_fun146943,check_DASH_mode93389,if_helper102944,libs95467) {
var anf_arg1491021 = R.makeObject({"check-mode":check_DASH_mode93389,
"allow-shadowed":allow_DASH_shadowed94418});
var $z10131014 = D;
var $f10191020 = function(_) {
return R.isFunction(anf_fun146943)?anf_fun146943.app(anf_arg148942,libs95467,anf_arg1491021):R.ffi.throwNonFunApp(L[121],anf_fun146943,[anf_arg148942,libs95467,anf_arg1491021]);
};
try {
if(--R.GAS > 0) {
$z10131014 = $f10191020();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10191020,
"from":L[121]});
}
} catch($e10111012) {
if(R.isCont($e10111012)) {
var $ss10151016 = {"from":L[121],
"go":function(cont_tail_arg1501022) {
return $Hcont_tail_arg3091023(cont_tail_arg1501022,if_helper102944);
}};
$e10111012.stack[R.EXN_STACKHEIGHT++] = $ss10151016;
}
if(R.isPyretException($e10111012)) {
$e10111012.pyretStack.push(L[121]);
}
throw $e10111012;
}
var $ret10171018 = $Hcont_tail_arg3091023($z10131014,if_helper102944);
++R.GAS;
return $ret10171018;
};
var $Hcont_tail_arg3091023 = function(cont_tail_arg1501022,if_helper102944) {
if(--R.GAS > 0) {
$z10241025 = R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg1501022):R.ffi.throwNonFunApp(L[121],if_helper102944,[cont_tail_arg1501022]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg1501022):R.ffi.throwNonFunApp(L[121],if_helper102944,[cont_tail_arg1501022]);
},
"from":L[121]});
}
++R.GAS;
return $z10241025;
};
var $Hif_DASH_321958 = function(if_DASH_10957,C112,CM916,F313,allow_DASH_shadowed94418,check_DASH_mode93389,if_helper102944,libs95467,options86239,r91276,print6,raise8) {
var anf_if1251057 = R.isBoolean(if_DASH_10957);
if(R.isPyretTrue(anf_if1251057)) {
if(R.isPyretTrue(if_DASH_10957)) {
var anf_fun1321039 = G(CM916,"compile-js",L[125]);
var anf_arg1331038 = G(CM916,"start",L[124]);
var anf_fun1341036 = G(r91276,"get",L[123]);
var $z10281029 = D;
var $f10341035 = function(_) {
return R.isFunction(anf_fun1341036)?anf_fun1341036.app(("dialect")):R.ffi.throwNonFunApp(L[122],anf_fun1341036,[("dialect")]);
};
try {
if(--R.GAS > 0) {
$z10281029 = $f10341035();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10341035,
"from":L[122]});
}
} catch($e10261027) {
if(R.isCont($e10261027)) {
var $ss10301031 = {"from":L[122],
"go":function(anf_arg1351037) {
return $Hanf_arg3151040(anf_arg1351037,F313,allow_DASH_shadowed94418,anf_arg1331038,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467,r91276);
}};
$e10261027.stack[R.EXN_STACKHEIGHT++] = $ss10301031;
}
if(R.isPyretException($e10261027)) {
$e10261027.pyretStack.push(L[122]);
}
throw $e10261027;
}
var $ret10321033 = $Hanf_arg3151040($z10281029,F313,allow_DASH_shadowed94418,anf_arg1331038,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467,r91276);
++R.GAS;
return $ret10321033;
} else {
var anf_fun1261051 = G(C112,"usage-info",L[127]);
var $z10431044 = D;
var $f10491050 = function(_) {
return R.isFunction(anf_fun1261051)?anf_fun1261051.app(options86239):R.ffi.throwNonFunApp(L[126],anf_fun1261051,[options86239]);
};
try {
if(--R.GAS > 0) {
$z10431044 = $f10491050();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10491050,
"from":L[126]});
}
} catch($e10411042) {
if(R.isCont($e10411042)) {
var $ss10451046 = {"from":L[126],
"go":function(anf_bracket1271052) {
return $Hanf_bracket3201053(anf_bracket1271052,if_helper102944,print6,raise8);
}};
$e10411042.stack[R.EXN_STACKHEIGHT++] = $ss10451046;
}
if(R.isPyretException($e10411042)) {
$e10411042.pyretStack.push(L[126]);
}
throw $e10411042;
}
var $ret10471048 = $Hanf_bracket3201053($z10431044,if_helper102944,print6,raise8);
++R.GAS;
return $ret10471048;
}
} else {
var cont_tail_arg1231056 = R.throwNonBooleanCondition(L[128],("if"),if_DASH_10957);
if(--R.GAS > 0) {
$z10541055 = R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg1231056):R.ffi.throwNonFunApp(L[128],if_helper102944,[cont_tail_arg1231056]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg1231056):R.ffi.throwNonFunApp(L[128],if_helper102944,[cont_tail_arg1231056]);
},
"from":L[128]});
}
++R.GAS;
return $z10541055;
}
};
var $Hanf_arg3151040 = function(anf_arg1351037,F313,allow_DASH_shadowed94418,anf_arg1331038,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467,r91276) {
var anf_fun1361070 = G(F313,"file-to-string",L[131]);
var anf_fun1371068 = G(r91276,"get",L[130]);
var $z10601061 = D;
var $f10661067 = function(_) {
return R.isFunction(anf_fun1371068)?anf_fun1371068.app(("compile-module-js")):R.ffi.throwNonFunApp(L[129],anf_fun1371068,[("compile-module-js")]);
};
try {
if(--R.GAS > 0) {
$z10601061 = $f10661067();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10661067,
"from":L[129]});
}
} catch($e10581059) {
if(R.isCont($e10581059)) {
var $ss10621063 = {"from":L[129],
"go":function(anf_arg1381069) {
return $Hanf_arg3141071(anf_arg1381069,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_fun1321039,anf_fun1361070,check_DASH_mode93389,if_helper102944,libs95467,r91276);
}};
$e10581059.stack[R.EXN_STACKHEIGHT++] = $ss10621063;
}
if(R.isPyretException($e10581059)) {
$e10581059.pyretStack.push(L[129]);
}
throw $e10581059;
}
var $ret10641065 = $Hanf_arg3141071($z10601061,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_fun1321039,anf_fun1361070,check_DASH_mode93389,if_helper102944,libs95467,r91276);
++R.GAS;
return $ret10641065;
};
var $Hanf_arg3141071 = function(anf_arg1381069,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_fun1321039,anf_fun1361070,check_DASH_mode93389,if_helper102944,libs95467,r91276) {
var $z10741075 = D;
var $f10801081 = function(_) {
return R.isFunction(anf_fun1361070)?anf_fun1361070.app(anf_arg1381069):R.ffi.throwNonFunApp(L[132],anf_fun1361070,[anf_arg1381069]);
};
try {
if(--R.GAS > 0) {
$z10741075 = $f10801081();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10801081,
"from":L[132]});
}
} catch($e10721073) {
if(R.isCont($e10721073)) {
var $ss10761077 = {"from":L[132],
"go":function(anf_arg1391082) {
return $Hanf_arg3131083(anf_arg1391082,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467,r91276);
}};
$e10721073.stack[R.EXN_STACKHEIGHT++] = $ss10761077;
}
if(R.isPyretException($e10721073)) {
$e10721073.pyretStack.push(L[132]);
}
throw $e10721073;
}
var $ret10781079 = $Hanf_arg3131083($z10741075,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467,r91276);
++R.GAS;
return $ret10781079;
};
var $Hanf_arg3131083 = function(anf_arg1391082,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467,r91276) {
var anf_fun1401094 = G(r91276,"get",L[134]);
var $z10861087 = D;
var $f10921093 = function(_) {
return R.isFunction(anf_fun1401094)?anf_fun1401094.app(("compile-module-js")):R.ffi.throwNonFunApp(L[133],anf_fun1401094,[("compile-module-js")]);
};
try {
if(--R.GAS > 0) {
$z10861087 = $f10921093();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10921093,
"from":L[133]});
}
} catch($e10841085) {
if(R.isCont($e10841085)) {
var $ss10881089 = {"from":L[133],
"go":function(anf_arg1411095) {
return $Hanf_arg3121096(anf_arg1411095,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_arg1391082,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467);
}};
$e10841085.stack[R.EXN_STACKHEIGHT++] = $ss10881089;
}
if(R.isPyretException($e10841085)) {
$e10841085.pyretStack.push(L[133]);
}
throw $e10841085;
}
var $ret10901091 = $Hanf_arg3121096($z10861087,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_arg1391082,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467);
++R.GAS;
return $ret10901091;
};
var $Hanf_arg3121096 = function(anf_arg1411095,allow_DASH_shadowed94418,anf_arg1331038,anf_arg1351037,anf_arg1391082,anf_fun1321039,check_DASH_mode93389,if_helper102944,libs95467) {
var anf_arg1421107 = R.makeObject({"check-mode":check_DASH_mode93389,
"allow-shadowed":allow_DASH_shadowed94418,
"collect-all":(false),
"ignore-unbound":(false)});
var $z10991100 = D;
var $f11051106 = function(_) {
return R.isFunction(anf_fun1321039)?anf_fun1321039.app(anf_arg1331038,anf_arg1351037,anf_arg1391082,anf_arg1411095,libs95467,anf_arg1421107):R.ffi.throwNonFunApp(L[135],anf_fun1321039,[anf_arg1331038,anf_arg1351037,anf_arg1391082,anf_arg1411095,libs95467,anf_arg1421107]);
};
try {
if(--R.GAS > 0) {
$z10991100 = $f11051106();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11051106,
"from":L[135]});
}
} catch($e10971098) {
if(R.isCont($e10971098)) {
var $ss11011102 = {"from":L[135],
"go":function(anf_bracket1431108) {
return $Hanf_bracket3111109(anf_bracket1431108,if_helper102944);
}};
$e10971098.stack[R.EXN_STACKHEIGHT++] = $ss11011102;
}
if(R.isPyretException($e10971098)) {
$e10971098.pyretStack.push(L[135]);
}
throw $e10971098;
}
var $ret11031104 = $Hanf_bracket3111109($z10991100,if_helper102944);
++R.GAS;
return $ret11031104;
};
var $Hanf_bracket3111109 = function(anf_bracket1431108,if_helper102944) {
var cont_tail_arg1441112 = G(anf_bracket1431108,"result",L[136]);
if(--R.GAS > 0) {
$z11101111 = R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg1441112):R.ffi.throwNonFunApp(L[136],if_helper102944,[cont_tail_arg1441112]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg1441112):R.ffi.throwNonFunApp(L[136],if_helper102944,[cont_tail_arg1441112]);
},
"from":L[136]});
}
++R.GAS;
return $z11101111;
};
var $Hanf_bracket3201053 = function(anf_bracket1271052,if_helper102944,print6,raise8) {
var anf_fun1281123 = G(anf_bracket1271052,"join-str",L[138]);
var $z11151116 = D;
var $f11211122 = function(_) {
return R.isFunction(anf_fun1281123)?anf_fun1281123.app(("\n")):R.ffi.throwNonFunApp(L[137],anf_fun1281123,[("\n")]);
};
try {
if(--R.GAS > 0) {
$z11151116 = $f11211122();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11211122,
"from":L[137]});
}
} catch($e11131114) {
if(R.isCont($e11131114)) {
var $ss11171118 = {"from":L[137],
"go":function(anf_arg1291124) {
return $Hanf_arg3191125(anf_arg1291124,if_helper102944,print6,raise8);
}};
$e11131114.stack[R.EXN_STACKHEIGHT++] = $ss11171118;
}
if(R.isPyretException($e11131114)) {
$e11131114.pyretStack.push(L[137]);
}
throw $e11131114;
}
var $ret11191120 = $Hanf_arg3191125($z11151116,if_helper102944,print6,raise8);
++R.GAS;
return $ret11191120;
};
var $Hanf_arg3191125 = function(anf_arg1291124,if_helper102944,print6,raise8) {
var $z11281129 = D;
var $f11341135 = function(_) {
return R.isFunction(print6)?print6.app(anf_arg1291124):R.ffi.throwNonFunApp(L[139],print6,[anf_arg1291124]);
};
try {
if(--R.GAS > 0) {
$z11281129 = $f11341135();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11341135,
"from":L[139]});
}
} catch($e11261127) {
if(R.isCont($e11261127)) {
var $ss11301131 = {"from":L[139],
"go":function(anf_begin_app_dropped3161136) {
return $Hanf_begin_app_dropped3181137(anf_begin_app_dropped3161136,if_helper102944,raise8);
}};
$e11261127.stack[R.EXN_STACKHEIGHT++] = $ss11301131;
}
if(R.isPyretException($e11261127)) {
$e11261127.pyretStack.push(L[139]);
}
throw $e11261127;
}
var $ret11321133 = $Hanf_begin_app_dropped3181137($z11281129,if_helper102944,raise8);
++R.GAS;
return $ret11321133;
};
var $Hanf_begin_app_dropped3181137 = function(anf_begin_app_dropped3161136,if_helper102944,raise8) {
var $z11401141 = D;
var $f11461147 = function(_) {
return R.isFunction(raise8)?raise8.app(("Unknown command line options")):R.ffi.throwNonFunApp(L[140],raise8,[("Unknown command line options")]);
};
try {
if(--R.GAS > 0) {
$z11401141 = $f11461147();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11461147,
"from":L[140]});
}
} catch($e11381139) {
if(R.isCont($e11381139)) {
var $ss11421143 = {"from":L[140],
"go":function(cont_tail_arg1301148) {
return $Hcont_tail_arg3171149(cont_tail_arg1301148,if_helper102944);
}};
$e11381139.stack[R.EXN_STACKHEIGHT++] = $ss11421143;
}
if(R.isPyretException($e11381139)) {
$e11381139.pyretStack.push(L[140]);
}
throw $e11381139;
}
var $ret11441145 = $Hcont_tail_arg3171149($z11401141,if_helper102944);
++R.GAS;
return $ret11441145;
};
var $Hcont_tail_arg3171149 = function(cont_tail_arg1301148,if_helper102944) {
if(--R.GAS > 0) {
$z11501151 = R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg1301148):R.ffi.throwNonFunApp(L[140],if_helper102944,[cont_tail_arg1301148]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper102944)?if_helper102944.app(cont_tail_arg1301148):R.ffi.throwNonFunApp(L[140],if_helper102944,[cont_tail_arg1301148]);
},
"from":L[140]});
}
++R.GAS;
return $z11501151;
};
var $Hcont_tail_arg308978 = function(cont_tail_arg117977,if_helper96531) {
if(--R.GAS > 0) {
$z11521153 = R.isFunction(if_helper96531)?if_helper96531.app(cont_tail_arg117977):R.ffi.throwNonFunApp(L[116],if_helper96531,[cont_tail_arg117977]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper96531)?if_helper96531.app(cont_tail_arg117977):R.ffi.throwNonFunApp(L[116],if_helper96531,[cont_tail_arg117977]);
},
"from":L[116]});
}
++R.GAS;
return $z11521153;
};
var $Hanf_begin_app_dropped307994 = function(anf_begin_app_dropped301993,errors107982,lists1921,print_DASH_error7,raise8,tostring11) {
var anf_fun1091164 = G(lists1921,"each",L[143]);
var anf_arg1121165 = R.makeFunction(function(e1081168) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[141],1,arguments);
}
var $z11711172 = D;
var $f11771178 = function(_) {
return R.isFunction(tostring11)?tostring11.app(e1081168):R.ffi.throwNonFunApp(L[142],tostring11,[e1081168]);
};
try {
if(--R.GAS > 0) {
$z11711172 = $f11771178();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11771178,
"from":L[142]});
}
} catch($e11691170) {
if(R.isCont($e11691170)) {
var $ss11731174 = {"from":L[142],
"go":function(anf_arg1111179) {
return $Hanf_arg3031180(anf_arg1111179,print_DASH_error7);
}};
$e11691170.stack[R.EXN_STACKHEIGHT++] = $ss11731174;
}
if(R.isPyretException($e11691170)) {
$e11691170.pyretStack.push(L[142]);
}
throw $e11691170;
}
var $ret11751176 = $Hanf_arg3031180($z11711172,print_DASH_error7);
++R.GAS;
return $ret11751176;
});
var $z11561157 = D;
var $f11621163 = function(_) {
return R.isFunction(anf_fun1091164)?anf_fun1091164.app(anf_arg1121165,errors107982):R.ffi.throwNonFunApp(L[141],anf_fun1091164,[anf_arg1121165,errors107982]);
};
try {
if(--R.GAS > 0) {
$z11561157 = $f11621163();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11621163,
"from":L[141]});
}
} catch($e11541155) {
if(R.isCont($e11541155)) {
var $ss11581159 = {"from":L[141],
"go":function(anf_begin_app_dropped3041166) {
return $Hanf_begin_app_dropped3061167(anf_begin_app_dropped3041166,raise8);
}};
$e11541155.stack[R.EXN_STACKHEIGHT++] = $ss11581159;
}
if(R.isPyretException($e11541155)) {
$e11541155.pyretStack.push(L[141]);
}
throw $e11541155;
}
var $ret11601161 = $Hanf_begin_app_dropped3061167($z11561157,raise8);
++R.GAS;
return $ret11601161;
};
var $Hanf_begin_app_dropped3061167 = function(anf_begin_app_dropped3041166,raise8) {
var $z11831184 = D;
var $f11891190 = function(_) {
return R.isFunction(raise8)?raise8.app(("There were compilation errors")):R.ffi.throwNonFunApp(L[117],raise8,[("There were compilation errors")]);
};
try {
if(--R.GAS > 0) {
$z11831184 = $f11891190();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11891190,
"from":L[117]});
}
} catch($e11811182) {
if(R.isCont($e11811182)) {
var $ss11851186 = {"from":L[117],
"go":function(ann_DASH_check_DASH_temp1081191) {
return $Hann_DASH_check_DASH_temp3051192(ann_DASH_check_DASH_temp1081191);
}};
$e11811182.stack[R.EXN_STACKHEIGHT++] = $ss11851186;
}
if(R.isPyretException($e11811182)) {
$e11811182.pyretStack.push(L[117]);
}
throw $e11811182;
}
var $ret11871188 = $Hann_DASH_check_DASH_temp3051192($z11831184);
++R.GAS;
return $ret11871188;
};
var $Hann_DASH_check_DASH_temp3051192 = function(ann_DASH_check_DASH_temp1081191) {
return ann_DASH_check_DASH_temp1081191;
};
var $Hanf_arg3031180 = function(anf_arg1111179,print_DASH_error7) {
var $z11951196 = D;
var $f12011202 = function(_) {
return R.isFunction(print_DASH_error7)?print_DASH_error7.app(anf_arg1111179):R.ffi.throwNonFunApp(L[141],print_DASH_error7,[anf_arg1111179]);
};
try {
if(--R.GAS > 0) {
$z11951196 = $f12011202();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12011202,
"from":L[141]});
}
} catch($e11931194) {
if(R.isCont($e11931194)) {
var $ss11971198 = {"from":L[141],
"go":function(ann_DASH_check_DASH_temp1101203) {
return $Hann_DASH_check_DASH_temp3021204(ann_DASH_check_DASH_temp1101203);
}};
$e11931194.stack[R.EXN_STACKHEIGHT++] = $ss11971198;
}
if(R.isPyretException($e11931194)) {
$e11931194.pyretStack.push(L[141]);
}
throw $e11931194;
}
var $ret11991200 = $Hann_DASH_check_DASH_temp3021204($z11951196);
++R.GAS;
return $ret11991200;
};
var $Hann_DASH_check_DASH_temp3021204 = function(ann_DASH_check_DASH_temp1101203) {
return ann_DASH_check_DASH_temp1101203;
};
var $Hann_DASH_check_DASH_temp3001008 = function(ann_DASH_check_DASH_temp1051007) {
return ann_DASH_check_DASH_temp1051007;
};
var $Hif_DASH_266307 = function(if_DASH_5306,e189292,e290293,_lessthan1,tostring11) {
var if_helper661215 = R.makeFunction(function(if_helper_arg671237) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[41],1,arguments);
}
var ann_DASH_check_DASH_temp621238 = if_helper_arg671237;
return ann_DASH_check_DASH_temp621238;
});
var anf_if701236 = R.isBoolean(if_DASH_5306);
if(R.isPyretTrue(anf_if701236)) {
if(R.isPyretTrue(if_DASH_5306)) {
var $z12071208 = D;
var $f12131214 = function(_) {
return R.isFunction(if_helper661215)?if_helper661215.app((true)):R.ffi.throwNonFunApp(L[144],if_helper661215,[(true)]);
};
try {
if(--R.GAS > 0) {
$z12071208 = $f12131214();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12131214,
"from":L[144]});
}
} catch($e12051206) {
if(R.isCont($e12051206)) {
var $ss12091210 = {"from":L[144],
"go":function(cont_tail_app821216) {
return $Hcont_tail_app2601217(cont_tail_app821216);
}};
$e12051206.stack[R.EXN_STACKHEIGHT++] = $ss12091210;
}
if(R.isPyretException($e12051206)) {
$e12051206.pyretStack.push(L[144]);
}
throw $e12051206;
}
var $ret12111212 = $Hcont_tail_app2601217($z12071208);
++R.GAS;
return $ret12111212;
} else {
var anf_bracket711232 = G(e189292,"loc",L[148]);
var anf_fun721228 = G(anf_bracket711232,"after",L[147]);
var anf_arg731229 = G(e290293,"loc",L[146]);
var $z12201221 = D;
var $f12261227 = function(_) {
return R.isFunction(anf_fun721228)?anf_fun721228.app(anf_arg731229):R.ffi.throwNonFunApp(L[145],anf_fun721228,[anf_arg731229]);
};
try {
if(--R.GAS > 0) {
$z12201221 = $f12261227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12261227,
"from":L[145]});
}
} catch($e12181219) {
if(R.isCont($e12181219)) {
var $ss12221223 = {"from":L[145],
"go":function(if_DASH_41230) {
return $Hif_DASH_2651231(if_DASH_41230,e189292,e290293,if_helper661215,_lessthan1,tostring11);
}};
$e12181219.stack[R.EXN_STACKHEIGHT++] = $ss12221223;
}
if(R.isPyretException($e12181219)) {
$e12181219.pyretStack.push(L[145]);
}
throw $e12181219;
}
var $ret12241225 = $Hif_DASH_2651231($z12201221,e189292,e290293,if_helper661215,_lessthan1,tostring11);
++R.GAS;
return $ret12241225;
}
} else {
var cont_tail_arg681235 = R.throwNonBooleanCondition(L[41],("if"),if_DASH_5306);
if(--R.GAS > 0) {
$z12331234 = R.isFunction(if_helper661215)?if_helper661215.app(cont_tail_arg681235):R.ffi.throwNonFunApp(L[41],if_helper661215,[cont_tail_arg681235]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper661215)?if_helper661215.app(cont_tail_arg681235):R.ffi.throwNonFunApp(L[41],if_helper661215,[cont_tail_arg681235]);
},
"from":L[41]});
}
++R.GAS;
return $z12331234;
}
};
var $Hcont_tail_app2601217 = function(cont_tail_app821216) {
return cont_tail_app821216;
};
var $Hif_DASH_2651231 = function(if_DASH_41230,e189292,e290293,if_helper661215,_lessthan1,tostring11) {
var anf_if761266 = R.isBoolean(if_DASH_41230);
if(R.isPyretTrue(anf_if761266)) {
if(R.isPyretTrue(if_DASH_41230)) {
var $z12411242 = D;
var $f12471248 = function(_) {
return R.isFunction(if_helper661215)?if_helper661215.app((false)):R.ffi.throwNonFunApp(L[149],if_helper661215,[(false)]);
};
try {
if(--R.GAS > 0) {
$z12411242 = $f12471248();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12471248,
"from":L[149]});
}
} catch($e12391240) {
if(R.isCont($e12391240)) {
var $ss12431244 = {"from":L[149],
"go":function(cont_tail_app811249) {
return $Hcont_tail_app2611250(cont_tail_app811249);
}};
$e12391240.stack[R.EXN_STACKHEIGHT++] = $ss12431244;
}
if(R.isPyretException($e12391240)) {
$e12391240.pyretStack.push(L[149]);
}
throw $e12391240;
}
var $ret12451246 = $Hcont_tail_app2611250($z12411242);
++R.GAS;
return $ret12451246;
} else {
var $z12531254 = D;
var $f12591260 = function(_) {
return R.isFunction(tostring11)?tostring11.app(e189292):R.ffi.throwNonFunApp(L[150],tostring11,[e189292]);
};
try {
if(--R.GAS > 0) {
$z12531254 = $f12591260();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12591260,
"from":L[150]});
}
} catch($e12511252) {
if(R.isCont($e12511252)) {
var $ss12551256 = {"from":L[150],
"go":function(anf_arg771261) {
return $Hanf_arg2641262(anf_arg771261,e290293,if_helper661215,_lessthan1,tostring11);
}};
$e12511252.stack[R.EXN_STACKHEIGHT++] = $ss12551256;
}
if(R.isPyretException($e12511252)) {
$e12511252.pyretStack.push(L[150]);
}
throw $e12511252;
}
var $ret12571258 = $Hanf_arg2641262($z12531254,e290293,if_helper661215,_lessthan1,tostring11);
++R.GAS;
return $ret12571258;
}
} else {
var cont_tail_arg741265 = R.throwNonBooleanCondition(L[151],("if"),if_DASH_41230);
if(--R.GAS > 0) {
$z12631264 = R.isFunction(if_helper661215)?if_helper661215.app(cont_tail_arg741265):R.ffi.throwNonFunApp(L[151],if_helper661215,[cont_tail_arg741265]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper661215)?if_helper661215.app(cont_tail_arg741265):R.ffi.throwNonFunApp(L[151],if_helper661215,[cont_tail_arg741265]);
},
"from":L[151]});
}
++R.GAS;
return $z12631264;
}
};
var $Hcont_tail_app2611250 = function(cont_tail_app811249) {
return cont_tail_app811249;
};
var $Hanf_arg2641262 = function(anf_arg771261,e290293,if_helper661215,_lessthan1,tostring11) {
var $z12691270 = D;
var $f12751276 = function(_) {
return R.isFunction(tostring11)?tostring11.app(e290293):R.ffi.throwNonFunApp(L[152],tostring11,[e290293]);
};
try {
if(--R.GAS > 0) {
$z12691270 = $f12751276();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12751276,
"from":L[152]});
}
} catch($e12671268) {
if(R.isCont($e12671268)) {
var $ss12711272 = {"from":L[152],
"go":function(anf_arg781277) {
return $Hanf_arg2631278(anf_arg781277,anf_arg771261,if_helper661215,_lessthan1);
}};
$e12671268.stack[R.EXN_STACKHEIGHT++] = $ss12711272;
}
if(R.isPyretException($e12671268)) {
$e12671268.pyretStack.push(L[152]);
}
throw $e12671268;
}
var $ret12731274 = $Hanf_arg2631278($z12691270,anf_arg771261,if_helper661215,_lessthan1);
++R.GAS;
return $ret12731274;
};
var $Hanf_arg2631278 = function(anf_arg781277,anf_arg771261,if_helper661215,_lessthan1) {
var $z12811282 = D;
var $f12871288 = function(_) {
return R.isFunction(_lessthan1)?_lessthan1.app(anf_arg771261,anf_arg781277):R.ffi.throwNonFunApp(L[153],_lessthan1,[anf_arg771261,anf_arg781277]);
};
try {
if(--R.GAS > 0) {
$z12811282 = $f12871288();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12871288,
"from":L[153]});
}
} catch($e12791280) {
if(R.isCont($e12791280)) {
var $ss12831284 = {"from":L[153],
"go":function(cont_tail_arg791289) {
return $Hcont_tail_arg2621290(cont_tail_arg791289,if_helper661215);
}};
$e12791280.stack[R.EXN_STACKHEIGHT++] = $ss12831284;
}
if(R.isPyretException($e12791280)) {
$e12791280.pyretStack.push(L[153]);
}
throw $e12791280;
}
var $ret12851286 = $Hcont_tail_arg2621290($z12811282,if_helper661215);
++R.GAS;
return $ret12851286;
};
var $Hcont_tail_arg2621290 = function(cont_tail_arg791289,if_helper661215) {
if(--R.GAS > 0) {
$z12911292 = R.isFunction(if_helper661215)?if_helper661215.app(cont_tail_arg791289):R.ffi.throwNonFunApp(L[153],if_helper661215,[cont_tail_arg791289]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper661215)?if_helper661215.app(cont_tail_arg791289):R.ffi.throwNonFunApp(L[153],if_helper661215,[cont_tail_arg791289]);
},
"from":L[153]});
}
++R.GAS;
return $z12911292;
};
var $Hcont_tail_app2581293 = function(cont_tail_app241294) {
return cont_tail_app241294;
};
var $Hcont_tail_app2591295 = function(cont_tail_app231296) {
return cont_tail_app231296;
};
var $Hcont_tail_arg2531297 = function(cont_tail_arg151298,if_helper41299) {
if(--R.GAS > 0) {
$z13001301 = R.isFunction(if_helper41299)?if_helper41299.app(cont_tail_arg151298):R.ffi.throwNonFunApp(L[154],if_helper41299,[cont_tail_arg151298]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper41299)?if_helper41299.app(cont_tail_arg151298):R.ffi.throwNonFunApp(L[154],if_helper41299,[cont_tail_arg151298]);
},
"from":L[154]});
}
++R.GAS;
return $z13001301;
};
var $Hanf_array_val2571302 = function(anf_array_val101303,anf_fun91304,format761305,if_helper41299,name831306,right791307) {
var $z13101311 = D;
var $f13161317 = function(_) {
return R.isFunction(anf_fun91304)?anf_fun91304.app([name831306,anf_array_val101303]):R.ffi.throwNonFunApp(L[155],anf_fun91304,[[name831306,anf_array_val101303]]);
};
try {
if(--R.GAS > 0) {
$z13101311 = $f13161317();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13161317,
"from":L[155]});
}
} catch($e13081309) {
if(R.isCont($e13081309)) {
var $ss13121313 = {"from":L[155],
"go":function(anf_arg111318) {
return $Hanf_arg2561319(anf_arg111318,format761305,if_helper41299,right791307);
}};
$e13081309.stack[R.EXN_STACKHEIGHT++] = $ss13121313;
}
if(R.isPyretException($e13081309)) {
$e13081309.pyretStack.push(L[155]);
}
throw $e13081309;
}
var $ret13141315 = $Hanf_arg2561319($z13101311,format761305,if_helper41299,right791307);
++R.GAS;
return $ret13141315;
};
var $Hanf_arg2561319 = function(anf_arg111318,format761305,if_helper41299,right791307) {
var $z13221323 = D;
var $f13281329 = function(_) {
return R.isFunction(format761305)?format761305.app(("~a expected a dialect, got ~a"),anf_arg111318):R.ffi.throwNonFunApp(L[156],format761305,[("~a expected a dialect, got ~a"),anf_arg111318]);
};
try {
if(--R.GAS > 0) {
$z13221323 = $f13281329();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13281329,
"from":L[156]});
}
} catch($e13201321) {
if(R.isCont($e13201321)) {
var $ss13241325 = {"from":L[156],
"go":function(anf_arg121330) {
return $Hanf_arg2551331(anf_arg121330,if_helper41299,right791307);
}};
$e13201321.stack[R.EXN_STACKHEIGHT++] = $ss13241325;
}
if(R.isPyretException($e13201321)) {
$e13201321.pyretStack.push(L[156]);
}
throw $e13201321;
}
var $ret13261327 = $Hanf_arg2551331($z13221323,if_helper41299,right791307);
++R.GAS;
return $ret13261327;
};
var $Hanf_arg2551331 = function(anf_arg121330,if_helper41299,right791307) {
var $z13341335 = D;
var $f13401341 = function(_) {
return R.isFunction(right791307)?right791307.app(anf_arg121330):R.ffi.throwNonFunApp(L[157],right791307,[anf_arg121330]);
};
try {
if(--R.GAS > 0) {
$z13341335 = $f13401341();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13401341,
"from":L[157]});
}
} catch($e13321333) {
if(R.isCont($e13321333)) {
var $ss13361337 = {"from":L[157],
"go":function(cont_tail_arg131342) {
return $Hcont_tail_arg2541343(cont_tail_arg131342,if_helper41299);
}};
$e13321333.stack[R.EXN_STACKHEIGHT++] = $ss13361337;
}
if(R.isPyretException($e13321333)) {
$e13321333.pyretStack.push(L[157]);
}
throw $e13321333;
}
var $ret13381339 = $Hcont_tail_arg2541343($z13341335,if_helper41299);
++R.GAS;
return $ret13381339;
};
var $Hcont_tail_arg2541343 = function(cont_tail_arg131342,if_helper41299) {
if(--R.GAS > 0) {
$z13441345 = R.isFunction(if_helper41299)?if_helper41299.app(cont_tail_arg131342):R.ffi.throwNonFunApp(L[157],if_helper41299,[cont_tail_arg131342]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper41299)?if_helper41299.app(cont_tail_arg131342):R.ffi.throwNonFunApp(L[157],if_helper41299,[cont_tail_arg131342]);
},
"from":L[157]});
}
++R.GAS;
return $z13441345;
};
return R.loadModulesNew(NAMESPACE,[$C11239,$F31340,$X51441,$D71542,$CM91643,$CS111744,$Format131845,$E151946,$arrays172047,$lists192148,$option212249,$error232350,$sets252451],function($C11239,$F31340,$X51441,$D71542,$CM91643,$CS111744,$Format131845,$E151946,$arrays172047,$lists192148,$option212249,$error232350,$sets252451) {
var C112 = R.getField($C11239,"values");
var F313 = R.getField($F31340,"values");
var X514 = R.getField($X51441,"values");
var D715 = R.getField($D71542,"values");
var CM916 = R.getField($CM91643,"values");
var CS1117 = R.getField($CS111744,"values");
var Format1318 = R.getField($Format131845,"values");
var E1519 = R.getField($E151946,"values");
var arrays1720 = R.getField($arrays172047,"values");
var lists1921 = R.getField($lists192148,"values");
var option2122 = R.getField($option212249,"values");
var error2323 = R.getField($error232350,"values");
var sets2524 = R.getField($sets252451,"values");
var C225 = R.getField($C11239,"types");
var F426 = R.getField($F31340,"types");
var X627 = R.getField($X51441,"types");
var D828 = R.getField($D71542,"types");
var CM1029 = R.getField($CM91643,"types");
var CS1230 = R.getField($CS111744,"types");
var Format1431 = R.getField($Format131845,"types");
var E1632 = R.getField($E151946,"types");
var arrays1833 = R.getField($arrays172047,"types");
var lists2034 = R.getField($lists192148,"types");
var option2235 = R.getField($option212249,"types");
var error2436 = R.getField($error232350,"types");
var sets2637 = R.getField($sets252451,"types");
return R.safeCall(function() {
var List271346 = R.getDotAnn(L[158],"lists",lists2034,"List");
var Option281347 = R.getDotAnn(L[158],"option",option2235,"Option");
var Array291348 = R.getDotAnn(L[158],"arrays",arrays1833,"Array");
var Set301349 = R.getDotAnn(L[158],"sets",sets2637,"Set");
var array311481 = G(arrays1720,"array",L[158]);
var build_DASH_array321480 = G(arrays1720,"build-array",L[158]);
var array_DASH_from_DASH_list331479 = G(arrays1720,"array-from-list",L[158]);
var is_DASH_array341478 = G(arrays1720,"is-array",L[158]);
var list351432 = G(lists1921,"list",L[158]);
var is_DASH_empty3684 = G(lists1921,"is-empty",L[158]);
var is_DASH_link371477 = G(lists1921,"is-link",L[158]);
var empty381476 = G(lists1921,"empty",L[158]);
var link391475 = G(lists1921,"link",L[158]);
var range401474 = G(lists1921,"range",L[158]);
var repeat411473 = G(lists1921,"repeat",L[158]);
var filter421472 = G(lists1921,"filter",L[158]);
var partition431471 = G(lists1921,"partition",L[158]);
var split_DASH_at441470 = G(lists1921,"split-at",L[158]);
var any451469 = G(lists1921,"any",L[158]);
var find461468 = G(lists1921,"find",L[158]);
var map471467 = G(lists1921,"map",L[158]);
var map2481466 = G(lists1921,"map2",L[158]);
var map3491465 = G(lists1921,"map3",L[158]);
var map4501464 = G(lists1921,"map4",L[158]);
var map_n511463 = G(lists1921,"map_n",L[158]);
var map2_n521462 = G(lists1921,"map2_n",L[158]);
var map3_n531461 = G(lists1921,"map3_n",L[158]);
var map4_n541460 = G(lists1921,"map4_n",L[158]);
var each551459 = G(lists1921,"each",L[158]);
var each2561458 = G(lists1921,"each2",L[158]);
var each3571457 = G(lists1921,"each3",L[158]);
var each4581456 = G(lists1921,"each4",L[158]);
var each_n591455 = G(lists1921,"each_n",L[158]);
var each2_n601454 = G(lists1921,"each2_n",L[158]);
var each3_n611453 = G(lists1921,"each3_n",L[158]);
var each4_n621452 = G(lists1921,"each4_n",L[158]);
var fold631451 = G(lists1921,"fold",L[158]);
var fold2641450 = G(lists1921,"fold2",L[158]);
var fold3651449 = G(lists1921,"fold3",L[158]);
var fold4661448 = G(lists1921,"fold4",L[158]);
var index671447 = G(lists1921,"index",L[158]);
var Option681446 = G(option2122,"Option",L[158]);
var is_DASH_none691445 = G(option2122,"is-none",L[158]);
var is_DASH_some701444 = G(option2122,"is-some",L[158]);
var none7185 = G(option2122,"none",L[158]);
var some7287 = G(option2122,"some",L[158]);
var set731443 = G(sets2524,"set",L[158]);
var tree_DASH_set741442 = G(sets2524,"tree-set",L[158]);
var list_DASH_set751441 = G(sets2524,"list-set",L[158]);
var format761305 = G(Format1318,"format",L[173]);
var Either771440 = G(E1519,"Either",L[172]);
var left781421 = G(E1519,"left",L[171]);
var right791307 = G(E1519,"right",L[170]);
var parse_DASH_dialects8086 = {"$var":D,
"$name":"parse-dialects"};
var main811351 = {"$var":D,
"$name":"main"};
var anf_assign251350 = R.makeFunction(function(arg_DASH_index821377,name831306,val841378) {
if(arguments.length !== 3) {
throw R.ffi.throwArityErrorC(L[165],3,arguments);
}
var or_DASH_oper_DASH_21405 = R.equiv(val841378,("Pyret"));
var if_helper21389 = R.makeFunction(function(if_helper_arg31410) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[166],1,arguments);
}
var if_DASH_11433 = if_helper_arg31410;
var if_helper41299 = R.makeFunction(function(if_helper_arg51438) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[166],1,arguments);
}
var ann_DASH_check_DASH_temp11439 = if_helper_arg51438;
return ann_DASH_check_DASH_temp11439;
});
var anf_if81437 = R.isBoolean(if_DASH_11433);
if(R.isPyretTrue(anf_if81437)) {
if(R.isPyretTrue(if_DASH_11433)) {
var $z14131414 = D;
var $f14191420 = function(_) {
return R.isFunction(left781421)?left781421.app(val841378):R.ffi.throwNonFunApp(L[154],left781421,[val841378]);
};
try {
if(--R.GAS > 0) {
$z14131414 = $f14191420();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14191420,
"from":L[154]});
}
} catch($e14111412) {
if(R.isCont($e14111412)) {
var $ss14151416 = {"from":L[154],
"go":function(cont_tail_arg151298) {
return $Hcont_tail_arg2531297(cont_tail_arg151298,if_helper41299);
}};
$e14111412.stack[R.EXN_STACKHEIGHT++] = $ss14151416;
}
if(R.isPyretException($e14111412)) {
$e14111412.pyretStack.push(L[154]);
}
throw $e14111412;
}
var $ret14171418 = $Hcont_tail_arg2531297($z14131414,if_helper41299);
++R.GAS;
return $ret14171418;
} else {
var anf_fun91304 = G(list351432,"make",L[155]);
var $z14241425 = D;
var $f14301431 = function(_) {
return R.isFunction(torepr10)?torepr10.app(val841378):R.ffi.throwNonFunApp(L[169],torepr10,[val841378]);
};
try {
if(--R.GAS > 0) {
$z14241425 = $f14301431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14301431,
"from":L[169]});
}
} catch($e14221423) {
if(R.isCont($e14221423)) {
var $ss14261427 = {"from":L[169],
"go":function(anf_array_val101303) {
return $Hanf_array_val2571302(anf_array_val101303,anf_fun91304,format761305,if_helper41299,name831306,right791307);
}};
$e14221423.stack[R.EXN_STACKHEIGHT++] = $ss14261427;
}
if(R.isPyretException($e14221423)) {
$e14221423.pyretStack.push(L[169]);
}
throw $e14221423;
}
var $ret14281429 = $Hanf_array_val2571302($z14241425,anf_fun91304,format761305,if_helper41299,name831306,right791307);
++R.GAS;
return $ret14281429;
}
} else {
var cont_tail_arg61436 = R.throwNonBooleanCondition(L[166],("if"),if_DASH_11433);
if(--R.GAS > 0) {
$z14341435 = R.isFunction(if_helper41299)?if_helper41299.app(cont_tail_arg61436):R.ffi.throwNonFunApp(L[166],if_helper41299,[cont_tail_arg61436]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper41299)?if_helper41299.app(cont_tail_arg61436):R.ffi.throwNonFunApp(L[166],if_helper41299,[cont_tail_arg61436]);
},
"from":L[166]});
}
++R.GAS;
return $z14341435;
}
});
var anf_if191409 = R.isBoolean(or_DASH_oper_DASH_21405);
if(R.isPyretTrue(anf_if191409)) {
if(R.isPyretTrue(or_DASH_oper_DASH_21405)) {
var $z13811382 = D;
var $f13871388 = function(_) {
return R.isFunction(if_helper21389)?if_helper21389.app((true)):R.ffi.throwNonFunApp(L[166],if_helper21389,[(true)]);
};
try {
if(--R.GAS > 0) {
$z13811382 = $f13871388();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13871388,
"from":L[166]});
}
} catch($e13791380) {
if(R.isCont($e13791380)) {
var $ss13831384 = {"from":L[166],
"go":function(cont_tail_app241294) {
return $Hcont_tail_app2581293(cont_tail_app241294);
}};
$e13791380.stack[R.EXN_STACKHEIGHT++] = $ss13831384;
}
if(R.isPyretException($e13791380)) {
$e13791380.pyretStack.push(L[166]);
}
throw $e13791380;
}
var $ret13851386 = $Hcont_tail_app2581293($z13811382);
++R.GAS;
return $ret13851386;
} else {
var or_DASH_oper_DASH_31400 = R.equiv(val841378,("Bootstrap"));
var anf_if221404 = R.isBoolean(or_DASH_oper_DASH_31400);
if(R.isPyretTrue(anf_if221404)) {
var $z13921393 = D;
var $f13981399 = function(_) {
return R.isFunction(if_helper21389)?if_helper21389.app(or_DASH_oper_DASH_31400):R.ffi.throwNonFunApp(L[166],if_helper21389,[or_DASH_oper_DASH_31400]);
};
try {
if(--R.GAS > 0) {
$z13921393 = $f13981399();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13981399,
"from":L[166]});
}
} catch($e13901391) {
if(R.isCont($e13901391)) {
var $ss13941395 = {"from":L[166],
"go":function(cont_tail_app231296) {
return $Hcont_tail_app2591295(cont_tail_app231296);
}};
$e13901391.stack[R.EXN_STACKHEIGHT++] = $ss13941395;
}
if(R.isPyretException($e13901391)) {
$e13901391.pyretStack.push(L[166]);
}
throw $e13901391;
}
var $ret13961397 = $Hcont_tail_app2591295($z13921393);
++R.GAS;
return $ret13961397;
} else {
var cont_tail_arg201403 = R.throwNonBooleanOp(L[167],("second"),("or"),or_DASH_oper_DASH_31400);
if(--R.GAS > 0) {
$z14011402 = R.isFunction(if_helper21389)?if_helper21389.app(cont_tail_arg201403):R.ffi.throwNonFunApp(L[167],if_helper21389,[cont_tail_arg201403]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper21389)?if_helper21389.app(cont_tail_arg201403):R.ffi.throwNonFunApp(L[167],if_helper21389,[cont_tail_arg201403]);
},
"from":L[167]});
}
++R.GAS;
return $z14011402;
}
}
} else {
var cont_tail_arg171408 = R.throwNonBooleanOp(L[168],("first"),("or"),or_DASH_oper_DASH_21405);
if(--R.GAS > 0) {
$z14061407 = R.isFunction(if_helper21389)?if_helper21389.app(cont_tail_arg171408):R.ffi.throwNonFunApp(L[168],if_helper21389,[cont_tail_arg171408]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored376) {
return R.isFunction(if_helper21389)?if_helper21389.app(cont_tail_arg171408):R.ffi.throwNonFunApp(L[168],if_helper21389,[cont_tail_arg171408]);
},
"from":L[168]});
}
++R.GAS;
return $z14061407;
}
});
parse_DASH_dialects8086.$var = anf_assign251350;
var anf_assign2461352 = R.makeFunction(function(args8583) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[33],1,arguments);
}
var anf_fun271374 = G(C112,"next-val",L[164]);
var anf_arg281375 = G(C112,"String",L[163]);
var anf_arg291376 = G(C112,"once",L[162]);
var $z13661367 = D;
var $f13721373 = function(_) {
return R.isFunction(anf_fun271374)?anf_fun271374.app(anf_arg281375,anf_arg291376,("Pyret (.arr) file to compile")):R.ffi.throwNonFunApp(L[161],anf_fun271374,[anf_arg281375,anf_arg291376,("Pyret (.arr) file to compile")]);
};
try {
if(--R.GAS > 0) {
$z13661367 = $f13721373();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13721373,
"from":L[161]});
}
} catch($e13641365) {
if(R.isCont($e13641365)) {
var $ss13681369 = {"from":L[161],
"go":function(anf_obj3082) {
return $Hanf_obj35281(anf_obj3082,C112,CM916,CS1117,F313,X514,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
}};
$e13641365.stack[R.EXN_STACKHEIGHT++] = $ss13681369;
}
if(R.isPyretException($e13641365)) {
$e13641365.pyretStack.push(L[161]);
}
throw $e13641365;
}
var $ret13701371 = $Hanf_obj35281($z13661367,C112,CM916,CS1117,F313,X514,args8583,is_DASH_empty3684,lists1921,none7185,parse_DASH_dialects8086,some7287,_lessthan1,display3,not4,nothing5,print6,print_DASH_error7,raise8,string_DASH_contains9,tostring11);
++R.GAS;
return $ret13701371;
});
main811351.$var = anf_assign2461352;
var anf_arg2471363 = G(C112,"args",L[160]);
var $z13551356 = D;
var $f13611362 = function(_) {
return R.isFunction(main811351.$var)?main811351.$var.app(anf_arg2471363):R.ffi.throwNonFunApp(L[159],main811351.$var,[anf_arg2471363]);
};
try {
if(--R.GAS > 0) {
$z13551356 = $f13611362();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13611362,
"from":L[159]});
}
} catch($e13531354) {
if(R.isCont($e13531354)) {
var $ss13571358 = {"from":L[159],
"go":function($underscore11153) {
return $H$underscore35552($underscore11153,builtins2,nothing5);
}};
$e13531354.stack[R.EXN_STACKHEIGHT++] = $ss13571358;
}
if(R.isPyretException($e13531354)) {
$e13531354.pyretStack.push(L[159]);
}
throw $e13531354;
}
var $ret13591360 = $H$underscore35552($z13551356,builtins2,nothing5);
++R.GAS;
return $ret13591360;
},function(moduleVal) {
R.modules["$src/arr/compiler/pyret.arr38"] = moduleVal
return moduleVal;
});
});
}
};
});
define('pyret',["requirejs", "js/runtime-anf", "compiler/pyret.arr"], function(r, RT, pyret) {
  var rt = RT.makeRuntime({
    initialGas: 500,
    stdout: function(str) { process.stdout.write(str); },
    stderr: function(str) { process.stderr.write(str); }
  });
  rt.setParam("command-line-arguments", process.argv.slice(1));
  rt.run(pyret, rt.namespace, {sync: true}, function(result) {
     if(rt.isSuccessResult(result)) {
        process.exit(0);
     } else if (rt.isFailureResult(result)) {
        var exnStack = result.exn.stack; result.exn.stack = undefined;
        var pyretStack = result.exn.pyretStack; result.exn.pyretStack = undefined;
        console.error('Pyret terminated with an error:\n' + JSON.stringify(result) + "\nStack:\n" 
                      + JSON.stringify(exnStack) + "\nPyret stack:\n" + rt.printPyretStack(pyretStack));
        process.exit(1);
     }
  });
});

define('js/eval-lib',[
    "js/secure-loader",
    "js/runtime-anf",
    "js/dialects-lib",
    "js/ffi-helpers",
    "compiler/compile-structs.arr",
    "compiler/compile.arr",
    "trove/parse-pyret",
    "trove/checker"],
function(loader, rtLib, dialectsLib, ffiHelpersLib, csLib, compLib, parseLib, checkerLib) {
  if(requirejs.isBrowser) {
    var r = requirejs;
    var define = window.define;
  }
  else {
    var r = require("requirejs");
    var define = r.define;
  }
  function randomName() { 
    return "anon" + Math.floor(Math.random() * 10000000);
  }

  function compilePyret(runtime, ast, options, ondone) {
    function s(str) { return runtime.makeString(str); }
    function gf(obj, fld) { return runtime.getField(obj, fld); }

    return runtime.safeCall(function() {
      return ffiHelpersLib(runtime, runtime.namespace);
    }, function(ffi) {
      return runtime.safeCall(function() {
        return dialectsLib(runtime, runtime.namespace);
      },
      function(dialects) {
        runtime.loadModules(runtime.namespace, [csLib, compLib], function(cs, comp) {
          var name = options.name || randomName();
          var compileEnv = options.compileEnv || gf(cs, "standard-builtins");

          runtime.run(function(_, namespace) {
              return runtime.safeCall(function() {
                  return gf(comp, "compile-js-ast").app(
                      gf(comp, "start"),
                      ast,
                      s(name),
                      compileEnv,
                      runtime.makeObject({
                        "check-mode": runtime.pyretTrue,
                        "allow-shadowed": runtime.pyretFalse,
                        "collect-all": runtime.pyretFalse,
                        "ignore-unbound": runtime.pyretFalse
                      })
                    );
                },
                function(compPhase) {
                  var compiled = gf(compPhase, "result");
                  return runtime.safeTail(function() {
                      if (runtime.unwrap(gf(cs, "is-ok").app(compiled)) === true) {
                        return runtime.unwrap(gf(gf(compiled, "code"), "pyret-to-js-runnable").app());
                      }
                      else if (runtime.unwrap(gf(cs, "is-err").app(compiled)) === true) {
                        throw ffi.toArray(gf(compiled, "problems"));
                      }
                      else {
                        throw new Error("Unknown result type while compiling: ", compiled);
                      }
                    });

                });
              },
              runtime.namespace,
              { sync: ('sync' in options) ? options.sync : true, initialGas: 500 },
              ondone)
        });

      });
    });
  }

  function compileSrcPyret(runtime, src, options, ondone) {
    parsePyret(runtime, src, options, function(parsed) {
      if(runtime.isSuccessResult(parsed)) {
        compilePyret(runtime, parsed.result, options, ondone);
      } else {
        ondone(parsed);
      }
    });
  }

  function parsePyret(runtime, src, options, ondone) {
    return runtime.runThunk(function() {
      return runtime.loadModulesNew(runtime.namespace, [parseLib], function(parseLib) {
        var pp = runtime.getField(parseLib, "values");
        return runtime.safeCall(function() {
          return dialectsLib(runtime, runtime.namespace);
        }, function(dialects) {
          if (!options.name) { options.name = randomName(); }
            return runtime.getField(pp, "parse-dialect").app(
                      runtime.makeString(options.dialect || dialects.defaultDialect), 
                      runtime.makeString(src), 
                      runtime.makeString(options.name));
        });
      });
    }, ondone);
  }

  function evalPyret(runtime, src, options, ondone) {
    parsePyret(runtime, src, options, function(parsed) {
      if(runtime.isSuccessResult(parsed)) {
        evalParsedPyret(runtime, parsed.result, options, ondone);
      } else {
        ondone(parsed);
      }
    });
  }

  function evalParsedPyret(runtime, ast, options, ondone) {
    if (!options.name) { options.name = randomName(); }
    var modname = randomName();
    var namespace = options.namespace || runtime.namespace;
    runtime.loadModules(runtime.namespace, [checkerLib], function(checker) {
      var currentChecker = runtime.getField(checker, "make-check-context").app(runtime.makeString(options.name), runtime.makeBoolean(false));
      runtime.setParam("current-checker", currentChecker);

      compilePyret(
          runtime,
          ast,
          options,
          function(result) {
            if(runtime.isFailureResult(result)) {
              ondone(result);
            }
            else {
              if (typeof result.result !== 'string') {
                throw new Error("Non-string result from compilation: " + result.result);
              }
              var compiledModule = loader.goodIdea(runtime, modname, result.result);
              compiledModule.then(function(mod) {
                var sync = false;
                var gas = options.gas || 500;
                runtime.run(mod, namespace, {sync: sync, initialGas: gas}, ondone);
              });
              compiledModule.fail(function(err) {
                ondone(runtime.makeFailureResult(err));
              });
            }
          }
        );
    });
  }

  return {
    compilePyret: compilePyret,
    evalPyret: evalPyret,
    parsePyret: parsePyret,
    compileSrcPyret: compileSrcPyret,
    evalParsedPyret: evalParsedPyret
  };
  
});

define('compiler/repl-support.arr',["compiler/compile-structs.arr",
"trove/ast",
"trove/arrays",
"trove/lists",
"trove/option",
"trove/error",
"trove/sets"],function($C1722,$A3823,$arrays5924,$lists71025,$option91126,$error111227,$sets131328) {
return function(R,NAMESPACE) {
if(R.modules["$src/arr/compiler/repl-support.arr21"]) {
return R.modules["$src/arr/compiler/repl-support.arr21"];
} else {
var G = R.getFieldLoc;
var U = function(loc,name) {
R.ffi.throwUninitializedIdMkLoc(loc,name)
};
var M = "src/arr/compiler/repl-support.arr";
var D = R.undefined;
var L = [[M,7,0,83,125,3,3967],
[M,75,0,2115,125,3,3967],
[M,77,2,2262,124,5,3963],
[M,78,4,2286,123,15,3957],
[M,85,6,2516,85,47,2557],
[M,82,6,2431,84,9,2509],
[M,83,21,2466,83,34,2479],
[M,83,21,2466,83,32,2477],
[M,83,8,2453,83,17,2462],
[M,79,6,2331,81,9,2424],
[M,80,37,2382,80,50,2395],
[M,80,37,2382,80,48,2393],
[M,80,26,2371,80,33,2378],
[M,80,8,2353,80,22,2367],
[M,75,36,2151,75,45,2160],
[M,75,62,2177,75,82,2197],
[M,46,0,1196,73,3,2113],
[M,47,2,1241,72,5,2109],
[M,48,4,1265,71,15,2103],
[M,55,6,1495,55,29,1518],
[M,55,12,1501,55,26,1515],
[M,52,6,1410,54,9,1488],
[M,53,21,1445,53,34,1458],
[M,53,21,1445,53,32,1456],
[M,53,8,1432,53,17,1441],
[M,49,6,1310,51,9,1403],
[M,50,37,1361,50,50,1374],
[M,50,37,1361,50,48,1372],
[M,50,26,1350,50,33,1357],
[M,50,8,1332,50,22,1346],
[M,46,31,1227,46,40,1236],
[M,40,0,1061,44,3,1194],
[M,41,14,1104,43,5,1189],
[M,42,8,1120,42,71,1183],
[M,42,28,1140,42,34,1146],
[M,42,8,1120,42,27,1139],
[M,41,2,1092,41,13,1103],
[M,7,0,83,23,3,596],
[M,14,2,316,21,73,591],
[M,15,4,362,15,21,379],
[M,15,4,362,15,16,374],
[M,14,37,351,17,3,423],
[M,14,23,337,14,36,350],
[M,16,30,411,16,37,418],
[M,16,4,385,16,21,402],
[M,16,4,385,16,38,419],
[M,18,4,436,18,23,455],
[M,18,4,436,18,13,445],
[M,17,5,425,20,3,512],
[M,19,36,493,19,50,507],
[M,19,4,461,19,26,483],
[M,19,4,461,19,51,508],
[M,14,23,337,20,4,513],
[M,14,2,316,20,5,514],
[M,21,25,543,21,42,560],
[M,21,25,543,21,37,555],
[M,21,18,536,21,43,561],
[M,21,4,522,21,17,535],
[M,21,52,570,21,71,589],
[M,21,52,570,21,61,579],
[M,21,45,563,21,72,590],
[M,21,4,522,21,73,591],
[M,86,6,2564,86,29,2587],
[M,86,12,2570,86,26,2584],
[M,87,30,2618,87,54,2642],
[M,87,47,2635,87,53,2641],
[M,87,30,2618,87,46,2634],
[M,87,6,2594,87,60,2648],
[M,88,6,2655,90,9,2734],
[M,88,21,2670,90,9,2734],
[M,91,6,2741,101,9,3145],
[M,91,62,2797,91,82,2817],
[M,91,20,2755,101,9,3145],
[M,92,8,2828,100,11,3135],
[M,94,10,2933,99,18,3123],
[M,95,22,2990,95,39,3007],
[M,95,22,2990,95,30,2998],
[M,95,12,2980,95,41,3009],
[M,93,10,2867,93,65,2922],
[M,93,40,2897,93,57,2914],
[M,93,40,2897,93,48,2905],
[M,102,6,3152,102,39,3185],
[M,102,17,3163,102,33,3179],
[M,103,35,3221,103,59,3245],
[M,103,52,3238,103,58,3244],
[M,103,35,3221,103,51,3237],
[M,103,62,3248,103,82,3268],
[M,103,75,3261,103,81,3267],
[M,103,62,3248,103,74,3260],
[M,103,6,3192,103,82,3268],
[M,104,6,3275,106,9,3364],
[M,104,26,3295,106,9,3364],
[M,107,6,3371,117,9,3788],
[M,107,72,3437,107,89,3454],
[M,107,25,3390,117,9,3788],
[M,108,8,3465,116,11,3778],
[M,110,10,3571,115,18,3766],
[M,111,22,3633,111,39,3650],
[M,111,22,3633,111,30,3641],
[M,111,12,3623,111,41,3652],
[M,109,10,3508,109,62,3560],
[M,109,37,3535,109,54,3552],
[M,109,37,3535,109,45,3543],
[M,120,25,3842,120,48,3865],
[M,120,25,3842,120,32,3849],
[M,120,10,3827,120,21,3838],
[M,119,6,3802,119,17,3813],
[M,120,10,3827,120,49,3866],
[M,121,10,3878,121,48,3916],
[M,121,10,3878,121,27,3895],
[M,111,19,3630,111,40,3651],
[M,112,14,3669,114,17,3745],
[M,113,19,3712,113,33,3726],
[M,113,19,3712,113,27,3720],
[M,111,12,3623,115,18,3766],
[M,109,34,3532,109,55,3553],
[M,95,19,2987,95,40,3008],
[M,96,14,3026,98,17,3102],
[M,97,19,3069,97,33,3083],
[M,97,19,3069,97,27,3077],
[M,95,12,2980,99,18,3123],
[M,93,37,2894,93,58,2915],
[M,83,36,2481,83,53,2498],
[M,83,36,2481,83,44,2489],
[M,80,26,2371,80,51,2396],
[M,80,53,2398,80,68,2413],
[M,80,53,2398,80,59,2404],
[M,56,6,1525,56,47,1566],
[M,57,30,1597,57,54,1621],
[M,57,47,1614,57,53,1620],
[M,57,30,1597,57,46,1613],
[M,57,6,1573,57,60,1627],
[M,58,6,1634,60,9,1713],
[M,58,21,1649,60,9,1713],
[M,61,6,1720,61,39,1753],
[M,61,17,1731,61,33,1747],
[M,62,35,1789,62,59,1813],
[M,62,52,1806,62,58,1812],
[M,62,35,1789,62,51,1805],
[M,62,62,1816,62,82,1836],
[M,62,75,1829,62,81,1835],
[M,62,62,1816,62,74,1828],
[M,62,6,1760,62,82,1836],
[M,63,6,1843,65,9,1932],
[M,63,26,1863,65,9,1932],
[M,68,25,1986,68,49,2010],
[M,68,25,1986,68,32,1993],
[M,68,10,1971,68,21,1982],
[M,67,6,1946,67,17,1957],
[M,68,10,1971,68,50,2011],
[M,69,10,2023,69,49,2062],
[M,69,10,2023,69,27,2040],
[M,53,36,1460,53,53,1477],
[M,53,36,1460,53,44,1468],
[M,50,26,1350,50,51,1375],
[M,50,53,1377,50,68,1392],
[M,50,53,1377,50,59,1383],
[M,42,59,1171,42,69,1181],
[M,42,59,1171,42,65,1177],
[M,42,40,1152,42,58,1170],
[M,42,8,1120,42,35,1147],
[M,42,40,1152,42,70,1182],
[M,35,30,991,35,58,1019],
[M,34,4,927,35,59,1020],
[M,28,20,760,28,54,794],
[M,27,4,706,28,62,802],
[M,10,4,196,10,53,245],
[M,11,21,268,11,54,301],
[M,11,28,275,11,53,300],
[M,11,4,251,11,20,267],
[M,11,4,251,11,13,260],
[M,11,4,251,11,55,302],
[M,8,17,155,8,35,173],
[M,3,0,13,125,3,3967],
[M,39,0,1032,39,28,1060],
[M,39,14,1046,39,28,1060],
[M,32,0,814,37,3,1030],
[M,33,2,890,36,5,1026],
[M,35,35,996,35,50,1011],
[M,35,35,996,35,44,1005],
[M,35,6,967,35,19,980],
[M,32,35,849,32,55,869],
[M,32,65,879,32,71,885],
[M,25,0,598,30,3,812],
[M,26,2,669,29,5,808],
[M,28,25,765,28,43,783],
[M,28,25,765,28,37,777],
[M,28,6,746,28,19,759],
[M,25,30,628,25,50,648],
[M,25,60,658,25,66,664],
[M,10,24,216,10,52,244],
[M,10,31,223,10,51,243],
[M,10,4,196,10,23,215],
[M,10,4,196,10,16,208],
[M,9,2,177,9,15,190],
[M,8,2,140,8,36,174],
[M,8,29,167,8,33,171],
[M,7,32,115,7,52,135]];
var _plus2 = NAMESPACE.get("_plus");
var builtins3 = NAMESPACE.get("builtins");
var not4 = NAMESPACE.get("not");
var nothing5 = NAMESPACE.get("nothing");
var $type$String6 = NAMESPACE.get("$type$String");
var $Hbad_DASH_imports37629 = function(bad_DASH_imports7930,A38,A415,C17,C214,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,drop_DASH_module_DASH_bindings6433,fold5134,link2735,list2336,map3537,_plus2,builtins3,not4,nothing5) {
var make_DASH_safe_DASH_imports8038 = {"$var":D,
"$name":"make-safe-imports"};
var make_DASH_provide_DASH_for_DASH_repl8140 = {"$var":D,
"$name":"make-provide-for-repl"};
var make_DASH_provide_DASH_for_DASH_repl_DASH_main8242 = {"$var":D,
"$name":"make-provide-for-repl-main"};
var anf_assign6239 = R.makeFunction(function(imps83202) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[31],1,arguments);
}
var anf_fun44213 = G(imps83202,"filter",L[36]);
var anf_arg61214 = R.makeFunction(function(i84217) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[32],1,arguments);
}
var anf_fun46228 = G(A38,"is-s-const-import",L[35]);
var anf_arg47229 = G(i84217,"file",L[34]);
var $z220221 = D;
var $f226227 = function(_) {
return R.isFunction(anf_fun46228)?anf_fun46228.app(anf_arg47229):R.ffi.throwNonFunApp(L[33],anf_fun46228,[anf_arg47229]);
};
try {
if(--R.GAS > 0) {
$z220221 = $f226227();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f226227,
"from":L[33]});
}
} catch($e218219) {
if(R.isCont($e218219)) {
var $ss222223 = {"from":L[33],
"go":function(and_DASH_oper_DASH_3230) {
return $Hand_DASH_oper_DASH_277231(and_DASH_oper_DASH_3230,bad_DASH_imports7930,i84217,not4);
}};
$e218219.stack[R.EXN_STACKHEIGHT++] = $ss222223;
}
if(R.isPyretException($e218219)) {
$e218219.pyretStack.push(L[33]);
}
throw $e218219;
}
var $ret224225 = $Hand_DASH_oper_DASH_277231($z220221,bad_DASH_imports7930,i84217,not4);
++R.GAS;
return $ret224225;
});
var $z205206 = D;
var $f211212 = function(_) {
return R.isFunction(anf_fun44213)?anf_fun44213.app(anf_arg61214):R.ffi.throwNonFunApp(L[31],anf_fun44213,[anf_arg61214]);
};
try {
if(--R.GAS > 0) {
$z205206 = $f211212();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f211212,
"from":L[31]});
}
} catch($e203204) {
if(R.isCont($e203204)) {
var $ss207208 = {"from":L[31],
"go":function(ann_DASH_check_DASH_temp43215) {
return $Hann_DASH_check_DASH_temp278216(ann_DASH_check_DASH_temp43215);
}};
$e203204.stack[R.EXN_STACKHEIGHT++] = $ss207208;
}
if(R.isPyretException($e203204)) {
$e203204.pyretStack.push(L[31]);
}
throw $e203204;
}
var $ret209210 = $Hann_DASH_check_DASH_temp278216($z205206);
++R.GAS;
return $ret209210;
});
make_DASH_safe_DASH_imports8038.$var = anf_assign6239;
var anf_assign11141 = R.makeFunction(function(p85130) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[16],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[30],"A",A415,"Program")],[p85130],[L[30]],function() {
var cases_DASH_val8201 = p85130;
var anf_fun64141 = G(cases_DASH_val8201,"_match",L[17]);
var anf_obj107147 = R.makeFunction(function(l86148,$underscore87149,$underscore88150,imports89151,body90152) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[18],5,arguments);
}
var df91153 = {"$var":D,
"$name":"df"};
var af92155 = {"$var":D,
"$name":"af"};
var anf_assign74154 = R.makeFunction(function(name93185) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[25],1,arguments);
}
var anf_fun67198 = G(A38,"s-data-field",L[29]);
var anf_fun68199 = G(A38,"s-str",L[28]);
var anf_fun69196 = G(name93185,"toname",L[27]);
var $z188189 = D;
var $f194195 = function(_) {
return R.isFunction(anf_fun69196)?anf_fun69196.app():R.ffi.throwNonFunApp(L[26],anf_fun69196,[]);
};
try {
if(--R.GAS > 0) {
$z188189 = $f194195();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f194195,
"from":L[26]});
}
} catch($e186187) {
if(R.isCont($e186187)) {
var $ss190191 = {"from":L[26],
"go":function(anf_arg70197) {
return $Hanf_arg282200(anf_arg70197,A38,anf_fun67198,anf_fun68199,l86148,name93185);
}};
$e186187.stack[R.EXN_STACKHEIGHT++] = $ss190191;
}
if(R.isPyretException($e186187)) {
$e186187.pyretStack.push(L[26]);
}
throw $e186187;
}
var $ret192193 = $Hanf_arg282200($z188189,A38,anf_fun67198,anf_fun68199,l86148,name93185);
++R.GAS;
return $ret192193;
});
df91153.$var = anf_assign74154;
var anf_assign81156 = R.makeFunction(function(name94170) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[21],1,arguments);
}
var anf_fun76183 = G(A38,"a-field",L[24]);
var anf_fun77181 = G(name94170,"toname",L[23]);
var $z173174 = D;
var $f179180 = function(_) {
return R.isFunction(anf_fun77181)?anf_fun77181.app():R.ffi.throwNonFunApp(L[22],anf_fun77181,[]);
};
try {
if(--R.GAS > 0) {
$z173174 = $f179180();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f179180,
"from":L[22]});
}
} catch($e171172) {
if(R.isCont($e171172)) {
var $ss175176 = {"from":L[22],
"go":function(anf_arg78182) {
return $Hanf_arg285184(anf_arg78182,A38,anf_fun76183,l86148,name94170);
}};
$e171172.stack[R.EXN_STACKHEIGHT++] = $ss175176;
}
if(R.isPyretException($e171172)) {
$e171172.pyretStack.push(L[22]);
}
throw $e171172;
}
var $ret177178 = $Hanf_arg285184($z173174,A38,anf_fun76183,l86148,name94170);
++R.GAS;
return $ret177178;
});
af92155.$var = anf_assign81156;
var anf_fun82167 = G(A38,"toplevel-ids",L[20]);
var $z159160 = D;
var $f165166 = function(_) {
return R.isFunction(anf_fun82167)?anf_fun82167.app(p85130):R.ffi.throwNonFunApp(L[19],anf_fun82167,[p85130]);
};
try {
if(--R.GAS > 0) {
$z159160 = $f165166();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f165166,
"from":L[19]});
}
} catch($e157158) {
if(R.isCont($e157158)) {
var $ss161162 = {"from":L[19],
"go":function(ids95168) {
return $Hids301169(ids95168,A38,af92155,body90152,df91153,imports89151,l86148,make_DASH_safe_DASH_imports8038,map3537,_plus2);
}};
$e157158.stack[R.EXN_STACKHEIGHT++] = $ss161162;
}
if(R.isPyretException($e157158)) {
$e157158.pyretStack.push(L[19]);
}
throw $e157158;
}
var $ret163164 = $Hids301169($z159160,A38,af92155,body90152,df91153,imports89151,l86148,make_DASH_safe_DASH_imports8038,map3537,_plus2);
++R.GAS;
return $ret163164;
});
var anf_arg108142 = R.makeObject({"s-program":anf_obj107147});
var anf_arg110143 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[17],0,arguments);
}
var ann_DASH_check_DASH_temp109146 = R.throwNoBranchesMatched(L[17],("cases"));
return ann_DASH_check_DASH_temp109146;
});
var $z133134 = D;
var $f139140 = function(_) {
return R.isFunction(anf_fun64141)?anf_fun64141.app(anf_arg108142,anf_arg110143):R.ffi.throwNonFunApp(L[16],anf_fun64141,[anf_arg108142,anf_arg110143]);
};
try {
if(--R.GAS > 0) {
$z133134 = $f139140();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f139140,
"from":L[16]});
}
} catch($e131132) {
if(R.isCont($e131132)) {
var $ss135136 = {"from":L[16],
"go":function(ann_DASH_check_DASH_temp63144) {
return $Hann_DASH_check_DASH_temp302145(ann_DASH_check_DASH_temp63144);
}};
$e131132.stack[R.EXN_STACKHEIGHT++] = $ss135136;
}
if(R.isPyretException($e131132)) {
$e131132.pyretStack.push(L[16]);
}
throw $e131132;
}
var $ret137138 = $Hann_DASH_check_DASH_temp302145($z133134);
++R.GAS;
return $ret137138;
});
});
make_DASH_provide_DASH_for_DASH_repl8140.$var = anf_assign11141;
var anf_assign21043 = R.makeFunction(function(p10458,compile_DASH_env10559) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[1],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[14],"A",A415,"Program"),R.getDotAnn(L[15],"C",C214,"CompileEnvironment")],[p10458,compile_DASH_env10559],[L[14],L[15]],function() {
var cases_DASH_val14129 = p10458;
var anf_fun11370 = G(cases_DASH_val14129,"_match",L[2]);
var anf_obj20676 = R.makeFunction(function(l10677,$underscore10778,$underscore10879,imports10980,body11081) {
if(arguments.length !== 5) {
throw R.ffi.throwArityErrorC(L[3],5,arguments);
}
var df11182 = {"$var":D,
"$name":"df"};
var af11284 = {"$var":D,
"$name":"af"};
var anf_assign12383 = R.makeFunction(function(name113113) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[9],1,arguments);
}
var anf_fun116126 = G(A38,"s-data-field",L[13]);
var anf_fun117127 = G(A38,"s-str",L[12]);
var anf_fun118124 = G(name113113,"toname",L[11]);
var $z116117 = D;
var $f122123 = function(_) {
return R.isFunction(anf_fun118124)?anf_fun118124.app():R.ffi.throwNonFunApp(L[10],anf_fun118124,[]);
};
try {
if(--R.GAS > 0) {
$z116117 = $f122123();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f122123,
"from":L[10]});
}
} catch($e114115) {
if(R.isCont($e114115)) {
var $ss118119 = {"from":L[10],
"go":function(anf_arg119125) {
return $Hanf_arg306128(anf_arg119125,A38,anf_fun116126,anf_fun117127,l10677,name113113);
}};
$e114115.stack[R.EXN_STACKHEIGHT++] = $ss118119;
}
if(R.isPyretException($e114115)) {
$e114115.pyretStack.push(L[10]);
}
throw $e114115;
}
var $ret120121 = $Hanf_arg306128($z116117,A38,anf_fun116126,anf_fun117127,l10677,name113113);
++R.GAS;
return $ret120121;
});
df11182.$var = anf_assign12383;
var anf_assign13085 = R.makeFunction(function(name11498) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[5],1,arguments);
}
var anf_fun125111 = G(A38,"a-field",L[8]);
var anf_fun126109 = G(name11498,"toname",L[7]);
var $z101102 = D;
var $f107108 = function(_) {
return R.isFunction(anf_fun126109)?anf_fun126109.app():R.ffi.throwNonFunApp(L[6],anf_fun126109,[]);
};
try {
if(--R.GAS > 0) {
$z101102 = $f107108();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f107108,
"from":L[6]});
}
} catch($e99100) {
if(R.isCont($e99100)) {
var $ss103104 = {"from":L[6],
"go":function(anf_arg127110) {
return $Hanf_arg309112(anf_arg127110,A38,anf_fun125111,l10677,name11498);
}};
$e99100.stack[R.EXN_STACKHEIGHT++] = $ss103104;
}
if(R.isPyretException($e99100)) {
$e99100.pyretStack.push(L[6]);
}
throw $e99100;
}
var $ret105106 = $Hanf_arg309112($z101102,A38,anf_fun125111,l10677,name11498);
++R.GAS;
return $ret105106;
});
af11284.$var = anf_assign13085;
var $z8889 = D;
var $f9495 = function(_) {
return R.isFunction(make_DASH_safe_DASH_imports8038.$var)?make_DASH_safe_DASH_imports8038.$var.app(imports10980):R.ffi.throwNonFunApp(L[4],make_DASH_safe_DASH_imports8038.$var,[imports10980]);
};
try {
if(--R.GAS > 0) {
$z8889 = $f9495();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f9495,
"from":L[4]});
}
} catch($e8687) {
if(R.isCont($e8687)) {
var $ss9091 = {"from":L[4],
"go":function(safe_DASH_imports11596) {
return $Hsafe_DASH_imports35197(safe_DASH_imports11596,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,p10458,_plus2);
}};
$e8687.stack[R.EXN_STACKHEIGHT++] = $ss9091;
}
if(R.isPyretException($e8687)) {
$e8687.pyretStack.push(L[4]);
}
throw $e8687;
}
var $ret9293 = $Hsafe_DASH_imports35197($z8889,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,p10458,_plus2);
++R.GAS;
return $ret9293;
});
var anf_arg20771 = R.makeObject({"s-program":anf_obj20676});
var anf_arg20972 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[2],0,arguments);
}
var ann_DASH_check_DASH_temp20875 = R.throwNoBranchesMatched(L[2],("cases"));
return ann_DASH_check_DASH_temp20875;
});
var $z6263 = D;
var $f6869 = function(_) {
return R.isFunction(anf_fun11370)?anf_fun11370.app(anf_arg20771,anf_arg20972):R.ffi.throwNonFunApp(L[1],anf_fun11370,[anf_arg20771,anf_arg20972]);
};
try {
if(--R.GAS > 0) {
$z6263 = $f6869();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f6869,
"from":L[1]});
}
} catch($e6061) {
if(R.isCont($e6061)) {
var $ss6465 = {"from":L[1],
"go":function(ann_DASH_check_DASH_temp11273) {
return $Hann_DASH_check_DASH_temp35274(ann_DASH_check_DASH_temp11273);
}};
$e6061.stack[R.EXN_STACKHEIGHT++] = $ss6465;
}
if(R.isPyretException($e6061)) {
$e6061.pyretStack.push(L[1]);
}
throw $e6061;
}
var $ret6667 = $Hann_DASH_check_DASH_temp35274($z6263);
++R.GAS;
return $ret6667;
});
});
make_DASH_provide_DASH_for_DASH_repl_DASH_main8242.$var = anf_assign21043;
var result_DASH_after_DASH_checks113856 = nothing5;
var anf_fun21154 = G(builtins3,"current-checker",L[0]);
var $z4647 = D;
var $f5253 = function(_) {
return R.isFunction(anf_fun21154)?anf_fun21154.app():R.ffi.throwNonFunApp(L[0],anf_fun21154,[]);
};
try {
if(--R.GAS > 0) {
$z4647 = $f5253();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f5253,
"from":L[0]});
}
} catch($e4445) {
if(R.isCont($e4445)) {
var $ss4849 = {"from":L[0],
"go":function(anf_bracket21255) {
return $Hanf_bracket37557(anf_bracket21255,C17,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,list2336,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3);
}};
$e4445.stack[R.EXN_STACKHEIGHT++] = $ss4849;
}
if(R.isPyretException($e4445)) {
$e4445.pyretStack.push(L[0]);
}
throw $e4445;
}
var $ret5051 = $Hanf_bracket37557($z4647,C17,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,list2336,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3);
++R.GAS;
return $ret5051;
};
var $Hanf_bracket37557 = function(anf_bracket21255,C17,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,list2336,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3) {
var anf_fun213245 = G(anf_bracket21255,"run-checks",L[0]);
var anf_fun214242 = G(list2336,"make",L[0]);
var anf_obj249247 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[37],0,arguments);
}
var anf_fun216259 = G(builtins3,"current-checker",L[38]);
var $z251252 = D;
var $f257258 = function(_) {
return R.isFunction(anf_fun216259)?anf_fun216259.app():R.ffi.throwNonFunApp(L[38],anf_fun216259,[]);
};
try {
if(--R.GAS > 0) {
$z251252 = $f257258();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f257258,
"from":L[38]});
}
} catch($e249250) {
if(R.isCont($e249250)) {
var $ss253254 = {"from":L[38],
"go":function(anf_bracket217260) {
return $Hanf_bracket369261(anf_bracket217260,C17,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e249250.stack[R.EXN_STACKHEIGHT++] = $ss253254;
}
if(R.isPyretException($e249250)) {
$e249250.pyretStack.push(L[38]);
}
throw $e249250;
}
var $ret255256 = $Hanf_bracket369261($z251252,C17,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret255256;
});
var anf_obj250248 = R.makeSrcloc(L[37]);
var anf_array_val251243 = R.makeObject({"name":("drop-module-bindings"),
"run":anf_obj249247,
"location":anf_obj250248});
var $z234235 = D;
var $f240241 = function(_) {
return R.isFunction(anf_fun214242)?anf_fun214242.app([anf_array_val251243]):R.ffi.throwNonFunApp(L[0],anf_fun214242,[[anf_array_val251243]]);
};
try {
if(--R.GAS > 0) {
$z234235 = $f240241();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f240241,
"from":L[0]});
}
} catch($e232233) {
if(R.isCont($e232233)) {
var $ss236237 = {"from":L[0],
"go":function(anf_arg252244) {
return $Hanf_arg374246(anf_arg252244,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,anf_fun213245,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3);
}};
$e232233.stack[R.EXN_STACKHEIGHT++] = $ss236237;
}
if(R.isPyretException($e232233)) {
$e232233.pyretStack.push(L[0]);
}
throw $e232233;
}
var $ret238239 = $Hanf_arg374246($z234235,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,anf_fun213245,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3);
++R.GAS;
return $ret238239;
};
var $Hanf_arg374246 = function(anf_arg252244,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,anf_fun213245,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3) {
var $z264265 = D;
var $f270271 = function(_) {
return R.isFunction(anf_fun213245)?anf_fun213245.app(("src/arr/compiler/repl-support.arr"),anf_arg252244):R.ffi.throwNonFunApp(L[0],anf_fun213245,[("src/arr/compiler/repl-support.arr"),anf_arg252244]);
};
try {
if(--R.GAS > 0) {
$z264265 = $f270271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f270271,
"from":L[0]});
}
} catch($e262263) {
if(R.isCont($e262263)) {
var $ss266267 = {"from":L[0],
"go":function(anf_begin_app_dropped370272) {
return $Hanf_begin_app_dropped373273(anf_begin_app_dropped370272,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3);
}};
$e262263.stack[R.EXN_STACKHEIGHT++] = $ss266267;
}
if(R.isPyretException($e262263)) {
$e262263.pyretStack.push(L[0]);
}
throw $e262263;
}
var $ret268269 = $Hanf_begin_app_dropped373273($z264265,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3);
++R.GAS;
return $ret268269;
};
var $Hanf_begin_app_dropped373273 = function(anf_begin_app_dropped370272,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,bad_DASH_imports7930,drop_DASH_module_DASH_bindings6433,make_DASH_provide_DASH_for_DASH_repl_DASH_main8242,make_DASH_provide_DASH_for_DASH_repl8140,make_DASH_safe_DASH_imports8038,result_DASH_after_DASH_checks113856,builtins3) {
var provides253286 = R.makeObject({"drop-module-bindings":drop_DASH_module_DASH_bindings6433.$var,
"add-global-binding":add_DASH_global_DASH_binding6531.$var,
"add-global-type-binding":add_DASH_global_DASH_type_DASH_binding6632.$var,
"bad-imports":bad_DASH_imports7930,
"make-safe-imports":make_DASH_safe_DASH_imports8038.$var,
"make-provide-for-repl":make_DASH_provide_DASH_for_DASH_repl8140.$var,
"make-provide-for-repl-main":make_DASH_provide_DASH_for_DASH_repl_DASH_main8242.$var,
"result-after-checks1":result_DASH_after_DASH_checks113856});
var anf_fun254284 = G(builtins3,"current-checker",L[0]);
var $z276277 = D;
var $f282283 = function(_) {
return R.isFunction(anf_fun254284)?anf_fun254284.app():R.ffi.throwNonFunApp(L[0],anf_fun254284,[]);
};
try {
if(--R.GAS > 0) {
$z276277 = $f282283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f282283,
"from":L[0]});
}
} catch($e274275) {
if(R.isCont($e274275)) {
var $ss278279 = {"from":L[0],
"go":function(anf_bracket255285) {
return $Hanf_bracket372287(anf_bracket255285,provides253286,result_DASH_after_DASH_checks113856);
}};
$e274275.stack[R.EXN_STACKHEIGHT++] = $ss278279;
}
if(R.isPyretException($e274275)) {
$e274275.pyretStack.push(L[0]);
}
throw $e274275;
}
var $ret280281 = $Hanf_bracket372287($z276277,provides253286,result_DASH_after_DASH_checks113856);
++R.GAS;
return $ret280281;
};
var $Hanf_bracket372287 = function(anf_bracket255285,provides253286,result_DASH_after_DASH_checks113856) {
var anf_fun256298 = G(anf_bracket255285,"results",L[0]);
var $z290291 = D;
var $f296297 = function(_) {
return R.isFunction(anf_fun256298)?anf_fun256298.app():R.ffi.throwNonFunApp(L[0],anf_fun256298,[]);
};
try {
if(--R.GAS > 0) {
$z290291 = $f296297();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f296297,
"from":L[0]});
}
} catch($e288289) {
if(R.isCont($e288289)) {
var $ss292293 = {"from":L[0],
"go":function(checks257299) {
return $Hchecks371300(checks257299,provides253286,result_DASH_after_DASH_checks113856);
}};
$e288289.stack[R.EXN_STACKHEIGHT++] = $ss292293;
}
if(R.isPyretException($e288289)) {
$e288289.pyretStack.push(L[0]);
}
throw $e288289;
}
var $ret294295 = $Hchecks371300($z290291,provides253286,result_DASH_after_DASH_checks113856);
++R.GAS;
return $ret294295;
};
var $Hchecks371300 = function(checks257299,provides253286,result_DASH_after_DASH_checks113856) {
return R.makeObject({"answer":result_DASH_after_DASH_checks113856,
"provide-plus-types":R.makeObject({"values":provides253286,
"types":{}}),
"checks":checks257299});
};
var $Hanf_bracket369261 = function(anf_bracket217260,C17,drop_DASH_module_DASH_bindings6433,list2336) {
var anf_fun218313 = G(anf_bracket217260,"check-is",L[38]);
var anf_fun219314 = G(C17,"compile-env",L[42]);
var anf_fun220315 = G(list2336,"make",L[41]);
var anf_fun221311 = G(C17,"builtin-id",L[40]);
var $z303304 = D;
var $f309310 = function(_) {
return R.isFunction(anf_fun221311)?anf_fun221311.app(("x")):R.ffi.throwNonFunApp(L[39],anf_fun221311,[("x")]);
};
try {
if(--R.GAS > 0) {
$z303304 = $f309310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f309310,
"from":L[39]});
}
} catch($e301302) {
if(R.isCont($e301302)) {
var $ss305306 = {"from":L[39],
"go":function(anf_array_val222312) {
return $Hanf_array_val368316(anf_array_val222312,C17,anf_fun218313,anf_fun219314,anf_fun220315,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e301302.stack[R.EXN_STACKHEIGHT++] = $ss305306;
}
if(R.isPyretException($e301302)) {
$e301302.pyretStack.push(L[39]);
}
throw $e301302;
}
var $ret307308 = $Hanf_array_val368316($z303304,C17,anf_fun218313,anf_fun219314,anf_fun220315,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret307308;
};
var $Hanf_array_val368316 = function(anf_array_val222312,C17,anf_fun218313,anf_fun219314,anf_fun220315,drop_DASH_module_DASH_bindings6433,list2336) {
var anf_fun223329 = G(C17,"module-bindings",L[44]);
var anf_fun224327 = G(list2336,"make",L[43]);
var $z319320 = D;
var $f325326 = function(_) {
return R.isFunction(anf_fun224327)?anf_fun224327.app([]):R.ffi.throwNonFunApp(L[43],anf_fun224327,[[]]);
};
try {
if(--R.GAS > 0) {
$z319320 = $f325326();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f325326,
"from":L[43]});
}
} catch($e317318) {
if(R.isCont($e317318)) {
var $ss321322 = {"from":L[43],
"go":function(anf_arg225328) {
return $Hanf_arg367330(anf_arg225328,C17,anf_array_val222312,anf_fun218313,anf_fun219314,anf_fun220315,anf_fun223329,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e317318.stack[R.EXN_STACKHEIGHT++] = $ss321322;
}
if(R.isPyretException($e317318)) {
$e317318.pyretStack.push(L[43]);
}
throw $e317318;
}
var $ret323324 = $Hanf_arg367330($z319320,C17,anf_array_val222312,anf_fun218313,anf_fun219314,anf_fun220315,anf_fun223329,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret323324;
};
var $Hanf_arg367330 = function(anf_arg225328,C17,anf_array_val222312,anf_fun218313,anf_fun219314,anf_fun220315,anf_fun223329,drop_DASH_module_DASH_bindings6433,list2336) {
var $z333334 = D;
var $f339340 = function(_) {
return R.isFunction(anf_fun223329)?anf_fun223329.app(("list"),anf_arg225328):R.ffi.throwNonFunApp(L[45],anf_fun223329,[("list"),anf_arg225328]);
};
try {
if(--R.GAS > 0) {
$z333334 = $f339340();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f339340,
"from":L[45]});
}
} catch($e331332) {
if(R.isCont($e331332)) {
var $ss335336 = {"from":L[45],
"go":function(anf_array_val226341) {
return $Hanf_array_val366342(anf_array_val226341,C17,anf_array_val222312,anf_fun218313,anf_fun219314,anf_fun220315,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e331332.stack[R.EXN_STACKHEIGHT++] = $ss335336;
}
if(R.isPyretException($e331332)) {
$e331332.pyretStack.push(L[45]);
}
throw $e331332;
}
var $ret337338 = $Hanf_array_val366342($z333334,C17,anf_array_val222312,anf_fun218313,anf_fun219314,anf_fun220315,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret337338;
};
var $Hanf_array_val366342 = function(anf_array_val226341,C17,anf_array_val222312,anf_fun218313,anf_fun219314,anf_fun220315,drop_DASH_module_DASH_bindings6433,list2336) {
var $z345346 = D;
var $f351352 = function(_) {
return R.isFunction(anf_fun220315)?anf_fun220315.app([anf_array_val222312,anf_array_val226341]):R.ffi.throwNonFunApp(L[41],anf_fun220315,[[anf_array_val222312,anf_array_val226341]]);
};
try {
if(--R.GAS > 0) {
$z345346 = $f351352();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f351352,
"from":L[41]});
}
} catch($e343344) {
if(R.isCont($e343344)) {
var $ss347348 = {"from":L[41],
"go":function(anf_arg227353) {
return $Hanf_arg365354(anf_arg227353,C17,anf_fun218313,anf_fun219314,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e343344.stack[R.EXN_STACKHEIGHT++] = $ss347348;
}
if(R.isPyretException($e343344)) {
$e343344.pyretStack.push(L[41]);
}
throw $e343344;
}
var $ret349350 = $Hanf_arg365354($z345346,C17,anf_fun218313,anf_fun219314,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret349350;
};
var $Hanf_arg365354 = function(anf_arg227353,C17,anf_fun218313,anf_fun219314,drop_DASH_module_DASH_bindings6433,list2336) {
var anf_fun228367 = G(list2336,"make",L[48]);
var anf_fun229365 = G(C17,"type-id",L[47]);
var $z357358 = D;
var $f363364 = function(_) {
return R.isFunction(anf_fun229365)?anf_fun229365.app(("Number")):R.ffi.throwNonFunApp(L[46],anf_fun229365,[("Number")]);
};
try {
if(--R.GAS > 0) {
$z357358 = $f363364();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f363364,
"from":L[46]});
}
} catch($e355356) {
if(R.isCont($e355356)) {
var $ss359360 = {"from":L[46],
"go":function(anf_array_val230366) {
return $Hanf_array_val364368(anf_array_val230366,C17,anf_arg227353,anf_fun218313,anf_fun219314,anf_fun228367,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e355356.stack[R.EXN_STACKHEIGHT++] = $ss359360;
}
if(R.isPyretException($e355356)) {
$e355356.pyretStack.push(L[46]);
}
throw $e355356;
}
var $ret361362 = $Hanf_array_val364368($z357358,C17,anf_arg227353,anf_fun218313,anf_fun219314,anf_fun228367,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret361362;
};
var $Hanf_array_val364368 = function(anf_array_val230366,C17,anf_arg227353,anf_fun218313,anf_fun219314,anf_fun228367,drop_DASH_module_DASH_bindings6433,list2336) {
var anf_fun231381 = G(C17,"type-module-bindings",L[50]);
var anf_fun232379 = G(list2336,"make",L[49]);
var $z371372 = D;
var $f377378 = function(_) {
return R.isFunction(anf_fun232379)?anf_fun232379.app([("List")]):R.ffi.throwNonFunApp(L[49],anf_fun232379,[[("List")]]);
};
try {
if(--R.GAS > 0) {
$z371372 = $f377378();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f377378,
"from":L[49]});
}
} catch($e369370) {
if(R.isCont($e369370)) {
var $ss373374 = {"from":L[49],
"go":function(anf_arg233380) {
return $Hanf_arg363382(anf_arg233380,C17,anf_arg227353,anf_array_val230366,anf_fun218313,anf_fun219314,anf_fun228367,anf_fun231381,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e369370.stack[R.EXN_STACKHEIGHT++] = $ss373374;
}
if(R.isPyretException($e369370)) {
$e369370.pyretStack.push(L[49]);
}
throw $e369370;
}
var $ret375376 = $Hanf_arg363382($z371372,C17,anf_arg227353,anf_array_val230366,anf_fun218313,anf_fun219314,anf_fun228367,anf_fun231381,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret375376;
};
var $Hanf_arg363382 = function(anf_arg233380,C17,anf_arg227353,anf_array_val230366,anf_fun218313,anf_fun219314,anf_fun228367,anf_fun231381,drop_DASH_module_DASH_bindings6433,list2336) {
var $z385386 = D;
var $f391392 = function(_) {
return R.isFunction(anf_fun231381)?anf_fun231381.app(("lists"),anf_arg233380):R.ffi.throwNonFunApp(L[51],anf_fun231381,[("lists"),anf_arg233380]);
};
try {
if(--R.GAS > 0) {
$z385386 = $f391392();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f391392,
"from":L[51]});
}
} catch($e383384) {
if(R.isCont($e383384)) {
var $ss387388 = {"from":L[51],
"go":function(anf_array_val234393) {
return $Hanf_array_val362394(anf_array_val234393,C17,anf_arg227353,anf_array_val230366,anf_fun218313,anf_fun219314,anf_fun228367,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e383384.stack[R.EXN_STACKHEIGHT++] = $ss387388;
}
if(R.isPyretException($e383384)) {
$e383384.pyretStack.push(L[51]);
}
throw $e383384;
}
var $ret389390 = $Hanf_array_val362394($z385386,C17,anf_arg227353,anf_array_val230366,anf_fun218313,anf_fun219314,anf_fun228367,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret389390;
};
var $Hanf_array_val362394 = function(anf_array_val234393,C17,anf_arg227353,anf_array_val230366,anf_fun218313,anf_fun219314,anf_fun228367,drop_DASH_module_DASH_bindings6433,list2336) {
var $z397398 = D;
var $f403404 = function(_) {
return R.isFunction(anf_fun228367)?anf_fun228367.app([anf_array_val230366,anf_array_val234393]):R.ffi.throwNonFunApp(L[48],anf_fun228367,[[anf_array_val230366,anf_array_val234393]]);
};
try {
if(--R.GAS > 0) {
$z397398 = $f403404();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f403404,
"from":L[48]});
}
} catch($e395396) {
if(R.isCont($e395396)) {
var $ss399400 = {"from":L[48],
"go":function(anf_arg235405) {
return $Hanf_arg361406(anf_arg235405,C17,anf_arg227353,anf_fun218313,anf_fun219314,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e395396.stack[R.EXN_STACKHEIGHT++] = $ss399400;
}
if(R.isPyretException($e395396)) {
$e395396.pyretStack.push(L[48]);
}
throw $e395396;
}
var $ret401402 = $Hanf_arg361406($z397398,C17,anf_arg227353,anf_fun218313,anf_fun219314,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret401402;
};
var $Hanf_arg361406 = function(anf_arg235405,C17,anf_arg227353,anf_fun218313,anf_fun219314,drop_DASH_module_DASH_bindings6433,list2336) {
var $z409410 = D;
var $f415416 = function(_) {
return R.isFunction(anf_fun219314)?anf_fun219314.app(anf_arg227353,anf_arg235405):R.ffi.throwNonFunApp(L[52],anf_fun219314,[anf_arg227353,anf_arg235405]);
};
try {
if(--R.GAS > 0) {
$z409410 = $f415416();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f415416,
"from":L[52]});
}
} catch($e407408) {
if(R.isCont($e407408)) {
var $ss411412 = {"from":L[52],
"go":function(anf_arg236417) {
return $Hanf_arg360418(anf_arg236417,C17,anf_fun218313,drop_DASH_module_DASH_bindings6433,list2336);
}};
$e407408.stack[R.EXN_STACKHEIGHT++] = $ss411412;
}
if(R.isPyretException($e407408)) {
$e407408.pyretStack.push(L[52]);
}
throw $e407408;
}
var $ret413414 = $Hanf_arg360418($z409410,C17,anf_fun218313,drop_DASH_module_DASH_bindings6433,list2336);
++R.GAS;
return $ret413414;
};
var $Hanf_arg360418 = function(anf_arg236417,C17,anf_fun218313,drop_DASH_module_DASH_bindings6433,list2336) {
var $z421422 = D;
var $f427428 = function(_) {
return R.isFunction(drop_DASH_module_DASH_bindings6433.$var)?drop_DASH_module_DASH_bindings6433.$var.app(anf_arg236417):R.ffi.throwNonFunApp(L[53],drop_DASH_module_DASH_bindings6433.$var,[anf_arg236417]);
};
try {
if(--R.GAS > 0) {
$z421422 = $f427428();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f427428,
"from":L[53]});
}
} catch($e419420) {
if(R.isCont($e419420)) {
var $ss423424 = {"from":L[53],
"go":function(anf_arg237429) {
return $Hanf_arg359430(anf_arg237429,C17,anf_fun218313,list2336);
}};
$e419420.stack[R.EXN_STACKHEIGHT++] = $ss423424;
}
if(R.isPyretException($e419420)) {
$e419420.pyretStack.push(L[53]);
}
throw $e419420;
}
var $ret425426 = $Hanf_arg359430($z421422,C17,anf_fun218313,list2336);
++R.GAS;
return $ret425426;
};
var $Hanf_arg359430 = function(anf_arg237429,C17,anf_fun218313,list2336) {
var anf_fun238443 = G(C17,"compile-env",L[57]);
var anf_fun239444 = G(list2336,"make",L[56]);
var anf_fun240441 = G(C17,"builtin-id",L[55]);
var $z433434 = D;
var $f439440 = function(_) {
return R.isFunction(anf_fun240441)?anf_fun240441.app(("x")):R.ffi.throwNonFunApp(L[54],anf_fun240441,[("x")]);
};
try {
if(--R.GAS > 0) {
$z433434 = $f439440();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f439440,
"from":L[54]});
}
} catch($e431432) {
if(R.isCont($e431432)) {
var $ss435436 = {"from":L[54],
"go":function(anf_array_val241442) {
return $Hanf_array_val358445(anf_array_val241442,C17,anf_arg237429,anf_fun218313,anf_fun238443,anf_fun239444,list2336);
}};
$e431432.stack[R.EXN_STACKHEIGHT++] = $ss435436;
}
if(R.isPyretException($e431432)) {
$e431432.pyretStack.push(L[54]);
}
throw $e431432;
}
var $ret437438 = $Hanf_array_val358445($z433434,C17,anf_arg237429,anf_fun218313,anf_fun238443,anf_fun239444,list2336);
++R.GAS;
return $ret437438;
};
var $Hanf_array_val358445 = function(anf_array_val241442,C17,anf_arg237429,anf_fun218313,anf_fun238443,anf_fun239444,list2336) {
var $z448449 = D;
var $f454455 = function(_) {
return R.isFunction(anf_fun239444)?anf_fun239444.app([anf_array_val241442]):R.ffi.throwNonFunApp(L[56],anf_fun239444,[[anf_array_val241442]]);
};
try {
if(--R.GAS > 0) {
$z448449 = $f454455();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f454455,
"from":L[56]});
}
} catch($e446447) {
if(R.isCont($e446447)) {
var $ss450451 = {"from":L[56],
"go":function(anf_arg242456) {
return $Hanf_arg357457(anf_arg242456,C17,anf_arg237429,anf_fun218313,anf_fun238443,list2336);
}};
$e446447.stack[R.EXN_STACKHEIGHT++] = $ss450451;
}
if(R.isPyretException($e446447)) {
$e446447.pyretStack.push(L[56]);
}
throw $e446447;
}
var $ret452453 = $Hanf_arg357457($z448449,C17,anf_arg237429,anf_fun218313,anf_fun238443,list2336);
++R.GAS;
return $ret452453;
};
var $Hanf_arg357457 = function(anf_arg242456,C17,anf_arg237429,anf_fun218313,anf_fun238443,list2336) {
var anf_fun243470 = G(list2336,"make",L[60]);
var anf_fun244468 = G(C17,"type-id",L[59]);
var $z460461 = D;
var $f466467 = function(_) {
return R.isFunction(anf_fun244468)?anf_fun244468.app(("Number")):R.ffi.throwNonFunApp(L[58],anf_fun244468,[("Number")]);
};
try {
if(--R.GAS > 0) {
$z460461 = $f466467();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f466467,
"from":L[58]});
}
} catch($e458459) {
if(R.isCont($e458459)) {
var $ss462463 = {"from":L[58],
"go":function(anf_array_val245469) {
return $Hanf_array_val356471(anf_array_val245469,anf_arg237429,anf_arg242456,anf_fun218313,anf_fun238443,anf_fun243470);
}};
$e458459.stack[R.EXN_STACKHEIGHT++] = $ss462463;
}
if(R.isPyretException($e458459)) {
$e458459.pyretStack.push(L[58]);
}
throw $e458459;
}
var $ret464465 = $Hanf_array_val356471($z460461,anf_arg237429,anf_arg242456,anf_fun218313,anf_fun238443,anf_fun243470);
++R.GAS;
return $ret464465;
};
var $Hanf_array_val356471 = function(anf_array_val245469,anf_arg237429,anf_arg242456,anf_fun218313,anf_fun238443,anf_fun243470) {
var $z474475 = D;
var $f480481 = function(_) {
return R.isFunction(anf_fun243470)?anf_fun243470.app([anf_array_val245469]):R.ffi.throwNonFunApp(L[60],anf_fun243470,[[anf_array_val245469]]);
};
try {
if(--R.GAS > 0) {
$z474475 = $f480481();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f480481,
"from":L[60]});
}
} catch($e472473) {
if(R.isCont($e472473)) {
var $ss476477 = {"from":L[60],
"go":function(anf_arg246482) {
return $Hanf_arg355483(anf_arg246482,anf_arg237429,anf_arg242456,anf_fun218313,anf_fun238443);
}};
$e472473.stack[R.EXN_STACKHEIGHT++] = $ss476477;
}
if(R.isPyretException($e472473)) {
$e472473.pyretStack.push(L[60]);
}
throw $e472473;
}
var $ret478479 = $Hanf_arg355483($z474475,anf_arg237429,anf_arg242456,anf_fun218313,anf_fun238443);
++R.GAS;
return $ret478479;
};
var $Hanf_arg355483 = function(anf_arg246482,anf_arg237429,anf_arg242456,anf_fun218313,anf_fun238443) {
var $z486487 = D;
var $f492493 = function(_) {
return R.isFunction(anf_fun238443)?anf_fun238443.app(anf_arg242456,anf_arg246482):R.ffi.throwNonFunApp(L[61],anf_fun238443,[anf_arg242456,anf_arg246482]);
};
try {
if(--R.GAS > 0) {
$z486487 = $f492493();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f492493,
"from":L[61]});
}
} catch($e484485) {
if(R.isCont($e484485)) {
var $ss488489 = {"from":L[61],
"go":function(anf_arg247494) {
return $Hanf_arg354495(anf_arg247494,anf_arg237429,anf_fun218313);
}};
$e484485.stack[R.EXN_STACKHEIGHT++] = $ss488489;
}
if(R.isPyretException($e484485)) {
$e484485.pyretStack.push(L[61]);
}
throw $e484485;
}
var $ret490491 = $Hanf_arg354495($z486487,anf_arg237429,anf_fun218313);
++R.GAS;
return $ret490491;
};
var $Hanf_arg354495 = function(anf_arg247494,anf_arg237429,anf_fun218313) {
var anf_arg248506 = R.makeSrcloc(L[38]);
var $z498499 = D;
var $f504505 = function(_) {
return R.isFunction(anf_fun218313)?anf_fun218313.app(("drop-module-bindings(C.compile-env([list: \n      C.builtin-id(\"x\"),\n      C.module-bindings(\"list\", [list: ])\n    ],\n    [list: C.type-id(\"Number\"), C.type-module-bindings(\"lists\", [list: \"List\"])])) is\n  C.compile-env([list: C.builtin-id(\"x\")], [list: C.type-id(\"Number\")])"),anf_arg237429,anf_arg247494,anf_arg248506):R.ffi.throwNonFunApp(L[37],anf_fun218313,[("drop-module-bindings(C.compile-env([list: \n      C.builtin-id(\"x\"),\n      C.module-bindings(\"list\", [list: ])\n    ],\n    [list: C.type-id(\"Number\"), C.type-module-bindings(\"lists\", [list: \"List\"])])) is\n  C.compile-env([list: C.builtin-id(\"x\")], [list: C.type-id(\"Number\")])"),anf_arg237429,anf_arg247494,anf_arg248506]);
};
try {
if(--R.GAS > 0) {
$z498499 = $f504505();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f504505,
"from":L[37]});
}
} catch($e496497) {
if(R.isCont($e496497)) {
var $ss500501 = {"from":L[37],
"go":function(ann_DASH_check_DASH_temp215507) {
return $Hann_DASH_check_DASH_temp353508(ann_DASH_check_DASH_temp215507);
}};
$e496497.stack[R.EXN_STACKHEIGHT++] = $ss500501;
}
if(R.isPyretException($e496497)) {
$e496497.pyretStack.push(L[37]);
}
throw $e496497;
}
var $ret502503 = $Hann_DASH_check_DASH_temp353508($z498499);
++R.GAS;
return $ret502503;
};
var $Hann_DASH_check_DASH_temp353508 = function(ann_DASH_check_DASH_temp215507) {
return ann_DASH_check_DASH_temp215507;
};
var $Hann_DASH_check_DASH_temp35274 = function(ann_DASH_check_DASH_temp11273) {
return ann_DASH_check_DASH_temp11273;
};
var $Hsafe_DASH_imports35197 = function(safe_DASH_imports11596,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,p10458,_plus2) {
var anf_fun131519 = G(A38,"toplevel-ids",L[63]);
var $z511512 = D;
var $f517518 = function(_) {
return R.isFunction(anf_fun131519)?anf_fun131519.app(p10458):R.ffi.throwNonFunApp(L[62],anf_fun131519,[p10458]);
};
try {
if(--R.GAS > 0) {
$z511512 = $f517518();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f517518,
"from":L[62]});
}
} catch($e509510) {
if(R.isCont($e509510)) {
var $ss513514 = {"from":L[62],
"go":function(ids116520) {
return $Hids350521(ids116520,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e509510.stack[R.EXN_STACKHEIGHT++] = $ss513514;
}
if(R.isPyretException($e509510)) {
$e509510.pyretStack.push(L[62]);
}
throw $e509510;
}
var $ret515516 = $Hids350521($z511512,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret515516;
};
var $Hids350521 = function(ids116520,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var anf_fun132532 = G(safe_DASH_imports11596,"map",L[66]);
var anf_arg134533 = R.makeFunction(function(recv_DASH_9536) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[65],1,arguments);
}
var ann_DASH_check_DASH_temp133537 = G(recv_DASH_9536,"name",L[65]);
return ann_DASH_check_DASH_temp133537;
});
var $z524525 = D;
var $f530531 = function(_) {
return R.isFunction(anf_fun132532)?anf_fun132532.app(anf_arg134533):R.ffi.throwNonFunApp(L[64],anf_fun132532,[anf_arg134533]);
};
try {
if(--R.GAS > 0) {
$z524525 = $f530531();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f530531,
"from":L[64]});
}
} catch($e522523) {
if(R.isCont($e522523)) {
var $ss526527 = {"from":L[64],
"go":function(anf_arg135534) {
return $Hanf_arg349535(anf_arg135534,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,ids116520,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e522523.stack[R.EXN_STACKHEIGHT++] = $ss526527;
}
if(R.isPyretException($e522523)) {
$e522523.pyretStack.push(L[64]);
}
throw $e522523;
}
var $ret528529 = $Hanf_arg349535($z524525,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,ids116520,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret528529;
};
var $Hanf_arg349535 = function(anf_arg135534,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,ids116520,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var $z540541 = D;
var $f546547 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg135534,ids116520):R.ffi.throwNonFunApp(L[67],_plus2,[anf_arg135534,ids116520]);
};
try {
if(--R.GAS > 0) {
$z540541 = $f546547();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f546547,
"from":L[67]});
}
} catch($e538539) {
if(R.isCont($e538539)) {
var $ss542543 = {"from":L[67],
"go":function(ids_DASH_plus_DASH_import_DASH_names117548) {
return $Hids_DASH_plus_DASH_import_DASH_names348549(ids_DASH_plus_DASH_import_DASH_names117548,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e538539.stack[R.EXN_STACKHEIGHT++] = $ss542543;
}
if(R.isPyretException($e538539)) {
$e538539.pyretStack.push(L[67]);
}
throw $e538539;
}
var $ret544545 = $Hids_DASH_plus_DASH_import_DASH_names348549($z540541,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret544545;
};
var $Hids_DASH_plus_DASH_import_DASH_names348549 = function(ids_DASH_plus_DASH_import_DASH_names117548,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var anf_arg137560 = R.makeFunction(function(id119563) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[69],1,arguments);
}
var $z566567 = D;
var $f572573 = function(_) {
return R.isFunction(df11182.$var)?df11182.$var.app(id119563):R.ffi.throwNonFunApp(L[69],df11182.$var,[id119563]);
};
try {
if(--R.GAS > 0) {
$z566567 = $f572573();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f572573,
"from":L[69]});
}
} catch($e564565) {
if(R.isCont($e564565)) {
var $ss568569 = {"from":L[69],
"go":function(ann_DASH_check_DASH_temp136574) {
return $Hann_DASH_check_DASH_temp310575(ann_DASH_check_DASH_temp136574);
}};
$e564565.stack[R.EXN_STACKHEIGHT++] = $ss568569;
}
if(R.isPyretException($e564565)) {
$e564565.pyretStack.push(L[69]);
}
throw $e564565;
}
var $ret570571 = $Hann_DASH_check_DASH_temp310575($z566567);
++R.GAS;
return $ret570571;
});
var $z552553 = D;
var $f558559 = function(_) {
return R.isFunction(map3537)?map3537.app(anf_arg137560,ids_DASH_plus_DASH_import_DASH_names117548):R.ffi.throwNonFunApp(L[68],map3537,[anf_arg137560,ids_DASH_plus_DASH_import_DASH_names117548]);
};
try {
if(--R.GAS > 0) {
$z552553 = $f558559();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f558559,
"from":L[68]});
}
} catch($e550551) {
if(R.isCont($e550551)) {
var $ss554555 = {"from":L[68],
"go":function(repl_DASH_provide118561) {
return $Hrepl_DASH_provide347562(repl_DASH_provide118561,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e550551.stack[R.EXN_STACKHEIGHT++] = $ss554555;
}
if(R.isPyretException($e550551)) {
$e550551.pyretStack.push(L[68]);
}
throw $e550551;
}
var $ret556557 = $Hrepl_DASH_provide347562($z552553,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret556557;
};
var $Hrepl_DASH_provide347562 = function(repl_DASH_provide118561,A38,af11284,body11081,compile_DASH_env10559,df11182,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var anf_arg161586 = R.makeFunction(function(flds121590,elt122591) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[72],2,arguments);
}
var cases_DASH_val10640 = elt122591;
var anf_fun139602 = G(cases_DASH_val10640,"_match",L[73]);
var anf_obj144608 = R.makeFunction(function(name123626) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[78],1,arguments);
}
var anf_fun141637 = G(A38,"s-name",L[80]);
var $z629630 = D;
var $f635636 = function(_) {
return R.isFunction(anf_fun141637)?anf_fun141637.app(l10677,name123626):R.ffi.throwNonFunApp(L[79],anf_fun141637,[l10677,name123626]);
};
try {
if(--R.GAS > 0) {
$z629630 = $f635636();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f635636,
"from":L[79]});
}
} catch($e627628) {
if(R.isCont($e627628)) {
var $ss631632 = {"from":L[79],
"go":function(anf_arg142638) {
return $Hanf_arg313639(anf_arg142638,df11182,flds121590,link2735);
}};
$e627628.stack[R.EXN_STACKHEIGHT++] = $ss631632;
}
if(R.isPyretException($e627628)) {
$e627628.pyretStack.push(L[79]);
}
throw $e627628;
}
var $ret633634 = $Hanf_arg313639($z629630,df11182,flds121590,link2735);
++R.GAS;
return $ret633634;
});
var anf_obj157609 = R.makeFunction(function(name124610,fields125611) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[74],2,arguments);
}
var anf_fun146624 = G(list2336,"make",L[77]);
var anf_fun147622 = G(A38,"s-name",L[76]);
var $z614615 = D;
var $f620621 = function(_) {
return R.isFunction(anf_fun147622)?anf_fun147622.app(l10677,name124610):R.ffi.throwNonFunApp(L[75],anf_fun147622,[l10677,name124610]);
};
try {
if(--R.GAS > 0) {
$z614615 = $f620621();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f620621,
"from":L[75]});
}
} catch($e612613) {
if(R.isCont($e612613)) {
var $ss616617 = {"from":L[75],
"go":function(anf_arg148623) {
return $Hanf_arg321625(anf_arg148623,A38,anf_fun146624,df11182,fields125611,flds121590,l10677,map3537,_plus2);
}};
$e612613.stack[R.EXN_STACKHEIGHT++] = $ss616617;
}
if(R.isPyretException($e612613)) {
$e612613.pyretStack.push(L[75]);
}
throw $e612613;
}
var $ret618619 = $Hanf_arg321625($z614615,A38,anf_fun146624,df11182,fields125611,flds121590,l10677,map3537,_plus2);
++R.GAS;
return $ret618619;
});
var anf_arg158603 = R.makeObject({"builtin-id":anf_obj144608,
"module-bindings":anf_obj157609});
var anf_arg160604 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[73],0,arguments);
}
var ann_DASH_check_DASH_temp159607 = R.throwNoBranchesMatched(L[73],("cases"));
return ann_DASH_check_DASH_temp159607;
});
var $z594595 = D;
var $f600601 = function(_) {
return R.isFunction(anf_fun139602)?anf_fun139602.app(anf_arg158603,anf_arg160604):R.ffi.throwNonFunApp(L[72],anf_fun139602,[anf_arg158603,anf_arg160604]);
};
try {
if(--R.GAS > 0) {
$z594595 = $f600601();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f600601,
"from":L[72]});
}
} catch($e592593) {
if(R.isCont($e592593)) {
var $ss596597 = {"from":L[72],
"go":function(ann_DASH_check_DASH_temp138605) {
return $Hann_DASH_check_DASH_temp322606(ann_DASH_check_DASH_temp138605);
}};
$e592593.stack[R.EXN_STACKHEIGHT++] = $ss596597;
}
if(R.isPyretException($e592593)) {
$e592593.pyretStack.push(L[72]);
}
throw $e592593;
}
var $ret598599 = $Hann_DASH_check_DASH_temp322606($z594595);
++R.GAS;
return $ret598599;
});
var anf_arg162587 = G(compile_DASH_env10559,"bindings",L[71]);
var $z578579 = D;
var $f584585 = function(_) {
return R.isFunction(fold5134)?fold5134.app(anf_arg161586,repl_DASH_provide118561,anf_arg162587):R.ffi.throwNonFunApp(L[70],fold5134,[anf_arg161586,repl_DASH_provide118561,anf_arg162587]);
};
try {
if(--R.GAS > 0) {
$z578579 = $f584585();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f584585,
"from":L[70]});
}
} catch($e576577) {
if(R.isCont($e576577)) {
var $ss580581 = {"from":L[70],
"go":function(env_DASH_provide120588) {
return $Henv_DASH_provide346589(env_DASH_provide120588,A38,af11284,body11081,compile_DASH_env10559,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e576577.stack[R.EXN_STACKHEIGHT++] = $ss580581;
}
if(R.isPyretException($e576577)) {
$e576577.pyretStack.push(L[70]);
}
throw $e576577;
}
var $ret582583 = $Henv_DASH_provide346589($z578579,A38,af11284,body11081,compile_DASH_env10559,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret582583;
};
var $Henv_DASH_provide346589 = function(env_DASH_provide120588,A38,af11284,body11081,compile_DASH_env10559,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var anf_fun163651 = G(A38,"block-type-ids",L[82]);
var $z643644 = D;
var $f649650 = function(_) {
return R.isFunction(anf_fun163651)?anf_fun163651.app(body11081):R.ffi.throwNonFunApp(L[81],anf_fun163651,[body11081]);
};
try {
if(--R.GAS > 0) {
$z643644 = $f649650();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f649650,
"from":L[81]});
}
} catch($e641642) {
if(R.isCont($e641642)) {
var $ss645646 = {"from":L[81],
"go":function(type_DASH_ids127652) {
return $Htype_DASH_ids345653(type_DASH_ids127652,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e641642.stack[R.EXN_STACKHEIGHT++] = $ss645646;
}
if(R.isPyretException($e641642)) {
$e641642.pyretStack.push(L[81]);
}
throw $e641642;
}
var $ret647648 = $Htype_DASH_ids345653($z643644,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret647648;
};
var $Htype_DASH_ids345653 = function(type_DASH_ids127652,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var anf_fun164664 = G(safe_DASH_imports11596,"map",L[85]);
var anf_arg166665 = R.makeFunction(function(recv_DASH_11668) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[84],1,arguments);
}
var ann_DASH_check_DASH_temp165669 = G(recv_DASH_11668,"name",L[84]);
return ann_DASH_check_DASH_temp165669;
});
var $z656657 = D;
var $f662663 = function(_) {
return R.isFunction(anf_fun164664)?anf_fun164664.app(anf_arg166665):R.ffi.throwNonFunApp(L[83],anf_fun164664,[anf_arg166665]);
};
try {
if(--R.GAS > 0) {
$z656657 = $f662663();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f662663,
"from":L[83]});
}
} catch($e654655) {
if(R.isCont($e654655)) {
var $ss658659 = {"from":L[83],
"go":function(anf_arg167666) {
return $Hanf_arg344667(anf_arg167666,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,type_DASH_ids127652,_plus2);
}};
$e654655.stack[R.EXN_STACKHEIGHT++] = $ss658659;
}
if(R.isPyretException($e654655)) {
$e654655.pyretStack.push(L[83]);
}
throw $e654655;
}
var $ret660661 = $Hanf_arg344667($z656657,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,type_DASH_ids127652,_plus2);
++R.GAS;
return $ret660661;
};
var $Hanf_arg344667 = function(anf_arg167666,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,type_DASH_ids127652,_plus2) {
var anf_fun168680 = G(type_DASH_ids127652,"map",L[88]);
var anf_arg170681 = R.makeFunction(function(recv_DASH_12684) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[87],1,arguments);
}
var ann_DASH_check_DASH_temp169685 = G(recv_DASH_12684,"name",L[87]);
return ann_DASH_check_DASH_temp169685;
});
var $z672673 = D;
var $f678679 = function(_) {
return R.isFunction(anf_fun168680)?anf_fun168680.app(anf_arg170681):R.ffi.throwNonFunApp(L[86],anf_fun168680,[anf_arg170681]);
};
try {
if(--R.GAS > 0) {
$z672673 = $f678679();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f678679,
"from":L[86]});
}
} catch($e670671) {
if(R.isCont($e670671)) {
var $ss674675 = {"from":L[86],
"go":function(anf_arg171682) {
return $Hanf_arg343683(anf_arg171682,A38,af11284,anf_arg167666,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e670671.stack[R.EXN_STACKHEIGHT++] = $ss674675;
}
if(R.isPyretException($e670671)) {
$e670671.pyretStack.push(L[86]);
}
throw $e670671;
}
var $ret676677 = $Hanf_arg343683($z672673,A38,af11284,anf_arg167666,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret676677;
};
var $Hanf_arg343683 = function(anf_arg171682,A38,af11284,anf_arg167666,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var $z688689 = D;
var $f694695 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg167666,anf_arg171682):R.ffi.throwNonFunApp(L[89],_plus2,[anf_arg167666,anf_arg171682]);
};
try {
if(--R.GAS > 0) {
$z688689 = $f694695();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f694695,
"from":L[89]});
}
} catch($e686687) {
if(R.isCont($e686687)) {
var $ss690691 = {"from":L[89],
"go":function(type_DASH_ids_DASH_plus_DASH_import_DASH_names128696) {
return $Htype_DASH_ids_DASH_plus_DASH_import_DASH_names342697(type_DASH_ids_DASH_plus_DASH_import_DASH_names128696,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e686687.stack[R.EXN_STACKHEIGHT++] = $ss690691;
}
if(R.isPyretException($e686687)) {
$e686687.pyretStack.push(L[89]);
}
throw $e686687;
}
var $ret692693 = $Htype_DASH_ids_DASH_plus_DASH_import_DASH_names342697($z688689,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret692693;
};
var $Htype_DASH_ids_DASH_plus_DASH_import_DASH_names342697 = function(type_DASH_ids_DASH_plus_DASH_import_DASH_names128696,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var anf_arg173708 = R.makeFunction(function(id130711) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[91],1,arguments);
}
var $z714715 = D;
var $f720721 = function(_) {
return R.isFunction(af11284.$var)?af11284.$var.app(id130711):R.ffi.throwNonFunApp(L[91],af11284.$var,[id130711]);
};
try {
if(--R.GAS > 0) {
$z714715 = $f720721();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f720721,
"from":L[91]});
}
} catch($e712713) {
if(R.isCont($e712713)) {
var $ss716717 = {"from":L[91],
"go":function(ann_DASH_check_DASH_temp172722) {
return $Hann_DASH_check_DASH_temp323723(ann_DASH_check_DASH_temp172722);
}};
$e712713.stack[R.EXN_STACKHEIGHT++] = $ss716717;
}
if(R.isPyretException($e712713)) {
$e712713.pyretStack.push(L[91]);
}
throw $e712713;
}
var $ret718719 = $Hann_DASH_check_DASH_temp323723($z714715);
++R.GAS;
return $ret718719;
});
var $z700701 = D;
var $f706707 = function(_) {
return R.isFunction(map3537)?map3537.app(anf_arg173708,type_DASH_ids_DASH_plus_DASH_import_DASH_names128696):R.ffi.throwNonFunApp(L[90],map3537,[anf_arg173708,type_DASH_ids_DASH_plus_DASH_import_DASH_names128696]);
};
try {
if(--R.GAS > 0) {
$z700701 = $f706707();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f706707,
"from":L[90]});
}
} catch($e698699) {
if(R.isCont($e698699)) {
var $ss702703 = {"from":L[90],
"go":function(repl_DASH_type_DASH_provide129709) {
return $Hrepl_DASH_type_DASH_provide341710(repl_DASH_type_DASH_provide129709,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
}};
$e698699.stack[R.EXN_STACKHEIGHT++] = $ss702703;
}
if(R.isPyretException($e698699)) {
$e698699.pyretStack.push(L[90]);
}
throw $e698699;
}
var $ret704705 = $Hrepl_DASH_type_DASH_provide341710($z700701,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2);
++R.GAS;
return $ret704705;
};
var $Hrepl_DASH_type_DASH_provide341710 = function(repl_DASH_type_DASH_provide129709,A38,af11284,body11081,compile_DASH_env10559,env_DASH_provide120588,fold5134,l10677,link2735,list2336,map3537,safe_DASH_imports11596,_plus2) {
var anf_arg197734 = R.makeFunction(function(flds132738,elt133739) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[94],2,arguments);
}
var cases_DASH_val13788 = elt133739;
var anf_fun175750 = G(cases_DASH_val13788,"_match",L[95]);
var anf_obj180756 = R.makeFunction(function(name134774) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[100],1,arguments);
}
var anf_fun177785 = G(A38,"s-name",L[102]);
var $z777778 = D;
var $f783784 = function(_) {
return R.isFunction(anf_fun177785)?anf_fun177785.app(l10677,name134774):R.ffi.throwNonFunApp(L[101],anf_fun177785,[l10677,name134774]);
};
try {
if(--R.GAS > 0) {
$z777778 = $f783784();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f783784,
"from":L[101]});
}
} catch($e775776) {
if(R.isCont($e775776)) {
var $ss779780 = {"from":L[101],
"go":function(anf_arg178786) {
return $Hanf_arg326787(anf_arg178786,af11284,flds132738,link2735);
}};
$e775776.stack[R.EXN_STACKHEIGHT++] = $ss779780;
}
if(R.isPyretException($e775776)) {
$e775776.pyretStack.push(L[101]);
}
throw $e775776;
}
var $ret781782 = $Hanf_arg326787($z777778,af11284,flds132738,link2735);
++R.GAS;
return $ret781782;
});
var anf_obj193757 = R.makeFunction(function(name135758,fields136759) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[96],2,arguments);
}
var anf_fun182772 = G(list2336,"make",L[99]);
var anf_fun183770 = G(A38,"s-name",L[98]);
var $z762763 = D;
var $f768769 = function(_) {
return R.isFunction(anf_fun183770)?anf_fun183770.app(l10677,name135758):R.ffi.throwNonFunApp(L[97],anf_fun183770,[l10677,name135758]);
};
try {
if(--R.GAS > 0) {
$z762763 = $f768769();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f768769,
"from":L[97]});
}
} catch($e760761) {
if(R.isCont($e760761)) {
var $ss764765 = {"from":L[97],
"go":function(anf_arg184771) {
return $Hanf_arg334773(anf_arg184771,A38,af11284,anf_fun182772,fields136759,flds132738,l10677,map3537,_plus2);
}};
$e760761.stack[R.EXN_STACKHEIGHT++] = $ss764765;
}
if(R.isPyretException($e760761)) {
$e760761.pyretStack.push(L[97]);
}
throw $e760761;
}
var $ret766767 = $Hanf_arg334773($z762763,A38,af11284,anf_fun182772,fields136759,flds132738,l10677,map3537,_plus2);
++R.GAS;
return $ret766767;
});
var anf_arg194751 = R.makeObject({"type-id":anf_obj180756,
"type-module-bindings":anf_obj193757});
var anf_arg196752 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[95],0,arguments);
}
var ann_DASH_check_DASH_temp195755 = R.throwNoBranchesMatched(L[95],("cases"));
return ann_DASH_check_DASH_temp195755;
});
var $z742743 = D;
var $f748749 = function(_) {
return R.isFunction(anf_fun175750)?anf_fun175750.app(anf_arg194751,anf_arg196752):R.ffi.throwNonFunApp(L[94],anf_fun175750,[anf_arg194751,anf_arg196752]);
};
try {
if(--R.GAS > 0) {
$z742743 = $f748749();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f748749,
"from":L[94]});
}
} catch($e740741) {
if(R.isCont($e740741)) {
var $ss744745 = {"from":L[94],
"go":function(ann_DASH_check_DASH_temp174753) {
return $Hann_DASH_check_DASH_temp335754(ann_DASH_check_DASH_temp174753);
}};
$e740741.stack[R.EXN_STACKHEIGHT++] = $ss744745;
}
if(R.isPyretException($e740741)) {
$e740741.pyretStack.push(L[94]);
}
throw $e740741;
}
var $ret746747 = $Hann_DASH_check_DASH_temp335754($z742743);
++R.GAS;
return $ret746747;
});
var anf_arg198735 = G(compile_DASH_env10559,"types",L[93]);
var $z726727 = D;
var $f732733 = function(_) {
return R.isFunction(fold5134)?fold5134.app(anf_arg197734,repl_DASH_type_DASH_provide129709,anf_arg198735):R.ffi.throwNonFunApp(L[92],fold5134,[anf_arg197734,repl_DASH_type_DASH_provide129709,anf_arg198735]);
};
try {
if(--R.GAS > 0) {
$z726727 = $f732733();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f732733,
"from":L[92]});
}
} catch($e724725) {
if(R.isCont($e724725)) {
var $ss728729 = {"from":L[92],
"go":function(env_DASH_type_DASH_provide131736) {
return $Henv_DASH_type_DASH_provide340737(env_DASH_type_DASH_provide131736,A38,body11081,env_DASH_provide120588,l10677,safe_DASH_imports11596);
}};
$e724725.stack[R.EXN_STACKHEIGHT++] = $ss728729;
}
if(R.isPyretException($e724725)) {
$e724725.pyretStack.push(L[92]);
}
throw $e724725;
}
var $ret730731 = $Henv_DASH_type_DASH_provide340737($z726727,A38,body11081,env_DASH_provide120588,l10677,safe_DASH_imports11596);
++R.GAS;
return $ret730731;
};
var $Henv_DASH_type_DASH_provide340737 = function(env_DASH_type_DASH_provide131736,A38,body11081,env_DASH_provide120588,l10677,safe_DASH_imports11596) {
var anf_fun199801 = G(A38,"s-program",L[106]);
var anf_fun200802 = G(A38,"s-provide",L[105]);
var anf_fun201799 = G(A38,"s-obj",L[104]);
var $z791792 = D;
var $f797798 = function(_) {
return R.isFunction(anf_fun201799)?anf_fun201799.app(l10677,env_DASH_provide120588):R.ffi.throwNonFunApp(L[103],anf_fun201799,[l10677,env_DASH_provide120588]);
};
try {
if(--R.GAS > 0) {
$z791792 = $f797798();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f797798,
"from":L[103]});
}
} catch($e789790) {
if(R.isCont($e789790)) {
var $ss793794 = {"from":L[103],
"go":function(anf_arg202800) {
return $Hanf_arg339803(anf_arg202800,A38,anf_fun199801,anf_fun200802,body11081,env_DASH_type_DASH_provide131736,l10677,safe_DASH_imports11596);
}};
$e789790.stack[R.EXN_STACKHEIGHT++] = $ss793794;
}
if(R.isPyretException($e789790)) {
$e789790.pyretStack.push(L[103]);
}
throw $e789790;
}
var $ret795796 = $Hanf_arg339803($z791792,A38,anf_fun199801,anf_fun200802,body11081,env_DASH_type_DASH_provide131736,l10677,safe_DASH_imports11596);
++R.GAS;
return $ret795796;
};
var $Hanf_arg339803 = function(anf_arg202800,A38,anf_fun199801,anf_fun200802,body11081,env_DASH_type_DASH_provide131736,l10677,safe_DASH_imports11596) {
var $z806807 = D;
var $f812813 = function(_) {
return R.isFunction(anf_fun200802)?anf_fun200802.app(l10677,anf_arg202800):R.ffi.throwNonFunApp(L[107],anf_fun200802,[l10677,anf_arg202800]);
};
try {
if(--R.GAS > 0) {
$z806807 = $f812813();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f812813,
"from":L[107]});
}
} catch($e804805) {
if(R.isCont($e804805)) {
var $ss808809 = {"from":L[107],
"go":function(anf_arg203814) {
return $Hanf_arg338815(anf_arg203814,A38,anf_fun199801,body11081,env_DASH_type_DASH_provide131736,l10677,safe_DASH_imports11596);
}};
$e804805.stack[R.EXN_STACKHEIGHT++] = $ss808809;
}
if(R.isPyretException($e804805)) {
$e804805.pyretStack.push(L[107]);
}
throw $e804805;
}
var $ret810811 = $Hanf_arg338815($z806807,A38,anf_fun199801,body11081,env_DASH_type_DASH_provide131736,l10677,safe_DASH_imports11596);
++R.GAS;
return $ret810811;
};
var $Hanf_arg338815 = function(anf_arg203814,A38,anf_fun199801,body11081,env_DASH_type_DASH_provide131736,l10677,safe_DASH_imports11596) {
var anf_fun204826 = G(A38,"s-provide-types",L[109]);
var $z818819 = D;
var $f824825 = function(_) {
return R.isFunction(anf_fun204826)?anf_fun204826.app(l10677,env_DASH_type_DASH_provide131736):R.ffi.throwNonFunApp(L[108],anf_fun204826,[l10677,env_DASH_type_DASH_provide131736]);
};
try {
if(--R.GAS > 0) {
$z818819 = $f824825();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f824825,
"from":L[108]});
}
} catch($e816817) {
if(R.isCont($e816817)) {
var $ss820821 = {"from":L[108],
"go":function(anf_arg205827) {
return $Hanf_arg337828(anf_arg205827,anf_arg203814,anf_fun199801,body11081,l10677,safe_DASH_imports11596);
}};
$e816817.stack[R.EXN_STACKHEIGHT++] = $ss820821;
}
if(R.isPyretException($e816817)) {
$e816817.pyretStack.push(L[108]);
}
throw $e816817;
}
var $ret822823 = $Hanf_arg337828($z818819,anf_arg203814,anf_fun199801,body11081,l10677,safe_DASH_imports11596);
++R.GAS;
return $ret822823;
};
var $Hanf_arg337828 = function(anf_arg205827,anf_arg203814,anf_fun199801,body11081,l10677,safe_DASH_imports11596) {
var $z831832 = D;
var $f837838 = function(_) {
return R.isFunction(anf_fun199801)?anf_fun199801.app(l10677,anf_arg203814,anf_arg205827,safe_DASH_imports11596,body11081):R.ffi.throwNonFunApp(L[3],anf_fun199801,[l10677,anf_arg203814,anf_arg205827,safe_DASH_imports11596,body11081]);
};
try {
if(--R.GAS > 0) {
$z831832 = $f837838();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f837838,
"from":L[3]});
}
} catch($e829830) {
if(R.isCont($e829830)) {
var $ss833834 = {"from":L[3],
"go":function(ann_DASH_check_DASH_temp114839) {
return $Hann_DASH_check_DASH_temp336840(ann_DASH_check_DASH_temp114839);
}};
$e829830.stack[R.EXN_STACKHEIGHT++] = $ss833834;
}
if(R.isPyretException($e829830)) {
$e829830.pyretStack.push(L[3]);
}
throw $e829830;
}
var $ret835836 = $Hann_DASH_check_DASH_temp336840($z831832);
++R.GAS;
return $ret835836;
};
var $Hann_DASH_check_DASH_temp336840 = function(ann_DASH_check_DASH_temp114839) {
return ann_DASH_check_DASH_temp114839;
};
var $Hann_DASH_check_DASH_temp335754 = function(ann_DASH_check_DASH_temp174753) {
return ann_DASH_check_DASH_temp174753;
};
var $Hanf_arg334773 = function(anf_arg184771,A38,af11284,anf_fun182772,fields136759,flds132738,l10677,map3537,_plus2) {
var $z843844 = D;
var $f849850 = function(_) {
return R.isFunction(af11284.$var)?af11284.$var.app(anf_arg184771):R.ffi.throwNonFunApp(L[110],af11284.$var,[anf_arg184771]);
};
try {
if(--R.GAS > 0) {
$z843844 = $f849850();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f849850,
"from":L[110]});
}
} catch($e841842) {
if(R.isCont($e841842)) {
var $ss845846 = {"from":L[110],
"go":function(anf_array_val185851) {
return $Hanf_array_val333852(anf_array_val185851,A38,af11284,anf_fun182772,fields136759,flds132738,l10677,map3537,_plus2);
}};
$e841842.stack[R.EXN_STACKHEIGHT++] = $ss845846;
}
if(R.isPyretException($e841842)) {
$e841842.pyretStack.push(L[110]);
}
throw $e841842;
}
var $ret847848 = $Hanf_array_val333852($z843844,A38,af11284,anf_fun182772,fields136759,flds132738,l10677,map3537,_plus2);
++R.GAS;
return $ret847848;
};
var $Hanf_array_val333852 = function(anf_array_val185851,A38,af11284,anf_fun182772,fields136759,flds132738,l10677,map3537,_plus2) {
var $z855856 = D;
var $f861862 = function(_) {
return R.isFunction(anf_fun182772)?anf_fun182772.app([anf_array_val185851]):R.ffi.throwNonFunApp(L[99],anf_fun182772,[[anf_array_val185851]]);
};
try {
if(--R.GAS > 0) {
$z855856 = $f861862();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f861862,
"from":L[99]});
}
} catch($e853854) {
if(R.isCont($e853854)) {
var $ss857858 = {"from":L[99],
"go":function(anf_arg186863) {
return $Hanf_arg332864(anf_arg186863,A38,af11284,fields136759,flds132738,l10677,map3537,_plus2);
}};
$e853854.stack[R.EXN_STACKHEIGHT++] = $ss857858;
}
if(R.isPyretException($e853854)) {
$e853854.pyretStack.push(L[99]);
}
throw $e853854;
}
var $ret859860 = $Hanf_arg332864($z855856,A38,af11284,fields136759,flds132738,l10677,map3537,_plus2);
++R.GAS;
return $ret859860;
};
var $Hanf_arg332864 = function(anf_arg186863,A38,af11284,fields136759,flds132738,l10677,map3537,_plus2) {
var anf_arg190875 = R.makeFunction(function(f137878) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[111],1,arguments);
}
var anf_fun188889 = G(A38,"s-name",L[113]);
var $z881882 = D;
var $f887888 = function(_) {
return R.isFunction(anf_fun188889)?anf_fun188889.app(l10677,f137878):R.ffi.throwNonFunApp(L[112],anf_fun188889,[l10677,f137878]);
};
try {
if(--R.GAS > 0) {
$z881882 = $f887888();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f887888,
"from":L[112]});
}
} catch($e879880) {
if(R.isCont($e879880)) {
var $ss883884 = {"from":L[112],
"go":function(anf_arg189890) {
return $Hanf_arg328891(anf_arg189890,af11284);
}};
$e879880.stack[R.EXN_STACKHEIGHT++] = $ss883884;
}
if(R.isPyretException($e879880)) {
$e879880.pyretStack.push(L[112]);
}
throw $e879880;
}
var $ret885886 = $Hanf_arg328891($z881882,af11284);
++R.GAS;
return $ret885886;
});
var $z867868 = D;
var $f873874 = function(_) {
return R.isFunction(map3537)?map3537.app(anf_arg190875,fields136759):R.ffi.throwNonFunApp(L[111],map3537,[anf_arg190875,fields136759]);
};
try {
if(--R.GAS > 0) {
$z867868 = $f873874();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f873874,
"from":L[111]});
}
} catch($e865866) {
if(R.isCont($e865866)) {
var $ss869870 = {"from":L[111],
"go":function(anf_arg191876) {
return $Hanf_arg331877(anf_arg191876,anf_arg186863,flds132738,_plus2);
}};
$e865866.stack[R.EXN_STACKHEIGHT++] = $ss869870;
}
if(R.isPyretException($e865866)) {
$e865866.pyretStack.push(L[111]);
}
throw $e865866;
}
var $ret871872 = $Hanf_arg331877($z867868,anf_arg186863,flds132738,_plus2);
++R.GAS;
return $ret871872;
};
var $Hanf_arg331877 = function(anf_arg191876,anf_arg186863,flds132738,_plus2) {
var $z894895 = D;
var $f900901 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg186863,anf_arg191876):R.ffi.throwNonFunApp(L[114],_plus2,[anf_arg186863,anf_arg191876]);
};
try {
if(--R.GAS > 0) {
$z894895 = $f900901();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f900901,
"from":L[114]});
}
} catch($e892893) {
if(R.isCont($e892893)) {
var $ss896897 = {"from":L[114],
"go":function(anf_arg192902) {
return $Hanf_arg330903(anf_arg192902,flds132738,_plus2);
}};
$e892893.stack[R.EXN_STACKHEIGHT++] = $ss896897;
}
if(R.isPyretException($e892893)) {
$e892893.pyretStack.push(L[114]);
}
throw $e892893;
}
var $ret898899 = $Hanf_arg330903($z894895,flds132738,_plus2);
++R.GAS;
return $ret898899;
};
var $Hanf_arg330903 = function(anf_arg192902,flds132738,_plus2) {
var $z906907 = D;
var $f912913 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg192902,flds132738):R.ffi.throwNonFunApp(L[96],_plus2,[anf_arg192902,flds132738]);
};
try {
if(--R.GAS > 0) {
$z906907 = $f912913();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f912913,
"from":L[96]});
}
} catch($e904905) {
if(R.isCont($e904905)) {
var $ss908909 = {"from":L[96],
"go":function(ann_DASH_check_DASH_temp181914) {
return $Hann_DASH_check_DASH_temp329915(ann_DASH_check_DASH_temp181914);
}};
$e904905.stack[R.EXN_STACKHEIGHT++] = $ss908909;
}
if(R.isPyretException($e904905)) {
$e904905.pyretStack.push(L[96]);
}
throw $e904905;
}
var $ret910911 = $Hann_DASH_check_DASH_temp329915($z906907);
++R.GAS;
return $ret910911;
};
var $Hann_DASH_check_DASH_temp329915 = function(ann_DASH_check_DASH_temp181914) {
return ann_DASH_check_DASH_temp181914;
};
var $Hanf_arg328891 = function(anf_arg189890,af11284) {
var $z918919 = D;
var $f924925 = function(_) {
return R.isFunction(af11284.$var)?af11284.$var.app(anf_arg189890):R.ffi.throwNonFunApp(L[111],af11284.$var,[anf_arg189890]);
};
try {
if(--R.GAS > 0) {
$z918919 = $f924925();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f924925,
"from":L[111]});
}
} catch($e916917) {
if(R.isCont($e916917)) {
var $ss920921 = {"from":L[111],
"go":function(ann_DASH_check_DASH_temp187926) {
return $Hann_DASH_check_DASH_temp327927(ann_DASH_check_DASH_temp187926);
}};
$e916917.stack[R.EXN_STACKHEIGHT++] = $ss920921;
}
if(R.isPyretException($e916917)) {
$e916917.pyretStack.push(L[111]);
}
throw $e916917;
}
var $ret922923 = $Hann_DASH_check_DASH_temp327927($z918919);
++R.GAS;
return $ret922923;
};
var $Hann_DASH_check_DASH_temp327927 = function(ann_DASH_check_DASH_temp187926) {
return ann_DASH_check_DASH_temp187926;
};
var $Hanf_arg326787 = function(anf_arg178786,af11284,flds132738,link2735) {
var $z930931 = D;
var $f936937 = function(_) {
return R.isFunction(af11284.$var)?af11284.$var.app(anf_arg178786):R.ffi.throwNonFunApp(L[115],af11284.$var,[anf_arg178786]);
};
try {
if(--R.GAS > 0) {
$z930931 = $f936937();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f936937,
"from":L[115]});
}
} catch($e928929) {
if(R.isCont($e928929)) {
var $ss932933 = {"from":L[115],
"go":function(anf_arg179938) {
return $Hanf_arg325939(anf_arg179938,flds132738,link2735);
}};
$e928929.stack[R.EXN_STACKHEIGHT++] = $ss932933;
}
if(R.isPyretException($e928929)) {
$e928929.pyretStack.push(L[115]);
}
throw $e928929;
}
var $ret934935 = $Hanf_arg325939($z930931,flds132738,link2735);
++R.GAS;
return $ret934935;
};
var $Hanf_arg325939 = function(anf_arg179938,flds132738,link2735) {
var $z942943 = D;
var $f948949 = function(_) {
return R.isFunction(link2735)?link2735.app(anf_arg179938,flds132738):R.ffi.throwNonFunApp(L[100],link2735,[anf_arg179938,flds132738]);
};
try {
if(--R.GAS > 0) {
$z942943 = $f948949();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f948949,
"from":L[100]});
}
} catch($e940941) {
if(R.isCont($e940941)) {
var $ss944945 = {"from":L[100],
"go":function(ann_DASH_check_DASH_temp176950) {
return $Hann_DASH_check_DASH_temp324951(ann_DASH_check_DASH_temp176950);
}};
$e940941.stack[R.EXN_STACKHEIGHT++] = $ss944945;
}
if(R.isPyretException($e940941)) {
$e940941.pyretStack.push(L[100]);
}
throw $e940941;
}
var $ret946947 = $Hann_DASH_check_DASH_temp324951($z942943);
++R.GAS;
return $ret946947;
};
var $Hann_DASH_check_DASH_temp324951 = function(ann_DASH_check_DASH_temp176950) {
return ann_DASH_check_DASH_temp176950;
};
var $Hann_DASH_check_DASH_temp323723 = function(ann_DASH_check_DASH_temp172722) {
return ann_DASH_check_DASH_temp172722;
};
var $Hann_DASH_check_DASH_temp322606 = function(ann_DASH_check_DASH_temp138605) {
return ann_DASH_check_DASH_temp138605;
};
var $Hanf_arg321625 = function(anf_arg148623,A38,anf_fun146624,df11182,fields125611,flds121590,l10677,map3537,_plus2) {
var $z954955 = D;
var $f960961 = function(_) {
return R.isFunction(df11182.$var)?df11182.$var.app(anf_arg148623):R.ffi.throwNonFunApp(L[116],df11182.$var,[anf_arg148623]);
};
try {
if(--R.GAS > 0) {
$z954955 = $f960961();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f960961,
"from":L[116]});
}
} catch($e952953) {
if(R.isCont($e952953)) {
var $ss956957 = {"from":L[116],
"go":function(anf_array_val149962) {
return $Hanf_array_val320963(anf_array_val149962,A38,anf_fun146624,df11182,fields125611,flds121590,l10677,map3537,_plus2);
}};
$e952953.stack[R.EXN_STACKHEIGHT++] = $ss956957;
}
if(R.isPyretException($e952953)) {
$e952953.pyretStack.push(L[116]);
}
throw $e952953;
}
var $ret958959 = $Hanf_array_val320963($z954955,A38,anf_fun146624,df11182,fields125611,flds121590,l10677,map3537,_plus2);
++R.GAS;
return $ret958959;
};
var $Hanf_array_val320963 = function(anf_array_val149962,A38,anf_fun146624,df11182,fields125611,flds121590,l10677,map3537,_plus2) {
var $z966967 = D;
var $f972973 = function(_) {
return R.isFunction(anf_fun146624)?anf_fun146624.app([anf_array_val149962]):R.ffi.throwNonFunApp(L[77],anf_fun146624,[[anf_array_val149962]]);
};
try {
if(--R.GAS > 0) {
$z966967 = $f972973();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f972973,
"from":L[77]});
}
} catch($e964965) {
if(R.isCont($e964965)) {
var $ss968969 = {"from":L[77],
"go":function(anf_arg150974) {
return $Hanf_arg319975(anf_arg150974,A38,df11182,fields125611,flds121590,l10677,map3537,_plus2);
}};
$e964965.stack[R.EXN_STACKHEIGHT++] = $ss968969;
}
if(R.isPyretException($e964965)) {
$e964965.pyretStack.push(L[77]);
}
throw $e964965;
}
var $ret970971 = $Hanf_arg319975($z966967,A38,df11182,fields125611,flds121590,l10677,map3537,_plus2);
++R.GAS;
return $ret970971;
};
var $Hanf_arg319975 = function(anf_arg150974,A38,df11182,fields125611,flds121590,l10677,map3537,_plus2) {
var anf_arg154986 = R.makeFunction(function(f126989) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[117],1,arguments);
}
var anf_fun1521000 = G(A38,"s-name",L[119]);
var $z992993 = D;
var $f998999 = function(_) {
return R.isFunction(anf_fun1521000)?anf_fun1521000.app(l10677,f126989):R.ffi.throwNonFunApp(L[118],anf_fun1521000,[l10677,f126989]);
};
try {
if(--R.GAS > 0) {
$z992993 = $f998999();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f998999,
"from":L[118]});
}
} catch($e990991) {
if(R.isCont($e990991)) {
var $ss994995 = {"from":L[118],
"go":function(anf_arg1531001) {
return $Hanf_arg3151002(anf_arg1531001,df11182);
}};
$e990991.stack[R.EXN_STACKHEIGHT++] = $ss994995;
}
if(R.isPyretException($e990991)) {
$e990991.pyretStack.push(L[118]);
}
throw $e990991;
}
var $ret996997 = $Hanf_arg3151002($z992993,df11182);
++R.GAS;
return $ret996997;
});
var $z978979 = D;
var $f984985 = function(_) {
return R.isFunction(map3537)?map3537.app(anf_arg154986,fields125611):R.ffi.throwNonFunApp(L[117],map3537,[anf_arg154986,fields125611]);
};
try {
if(--R.GAS > 0) {
$z978979 = $f984985();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f984985,
"from":L[117]});
}
} catch($e976977) {
if(R.isCont($e976977)) {
var $ss980981 = {"from":L[117],
"go":function(anf_arg155987) {
return $Hanf_arg318988(anf_arg155987,anf_arg150974,flds121590,_plus2);
}};
$e976977.stack[R.EXN_STACKHEIGHT++] = $ss980981;
}
if(R.isPyretException($e976977)) {
$e976977.pyretStack.push(L[117]);
}
throw $e976977;
}
var $ret982983 = $Hanf_arg318988($z978979,anf_arg150974,flds121590,_plus2);
++R.GAS;
return $ret982983;
};
var $Hanf_arg318988 = function(anf_arg155987,anf_arg150974,flds121590,_plus2) {
var $z10051006 = D;
var $f10111012 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg150974,anf_arg155987):R.ffi.throwNonFunApp(L[120],_plus2,[anf_arg150974,anf_arg155987]);
};
try {
if(--R.GAS > 0) {
$z10051006 = $f10111012();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10111012,
"from":L[120]});
}
} catch($e10031004) {
if(R.isCont($e10031004)) {
var $ss10071008 = {"from":L[120],
"go":function(anf_arg1561013) {
return $Hanf_arg3171014(anf_arg1561013,flds121590,_plus2);
}};
$e10031004.stack[R.EXN_STACKHEIGHT++] = $ss10071008;
}
if(R.isPyretException($e10031004)) {
$e10031004.pyretStack.push(L[120]);
}
throw $e10031004;
}
var $ret10091010 = $Hanf_arg3171014($z10051006,flds121590,_plus2);
++R.GAS;
return $ret10091010;
};
var $Hanf_arg3171014 = function(anf_arg1561013,flds121590,_plus2) {
var $z10171018 = D;
var $f10231024 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg1561013,flds121590):R.ffi.throwNonFunApp(L[74],_plus2,[anf_arg1561013,flds121590]);
};
try {
if(--R.GAS > 0) {
$z10171018 = $f10231024();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10231024,
"from":L[74]});
}
} catch($e10151016) {
if(R.isCont($e10151016)) {
var $ss10191020 = {"from":L[74],
"go":function(ann_DASH_check_DASH_temp1451025) {
return $Hann_DASH_check_DASH_temp3161026(ann_DASH_check_DASH_temp1451025);
}};
$e10151016.stack[R.EXN_STACKHEIGHT++] = $ss10191020;
}
if(R.isPyretException($e10151016)) {
$e10151016.pyretStack.push(L[74]);
}
throw $e10151016;
}
var $ret10211022 = $Hann_DASH_check_DASH_temp3161026($z10171018);
++R.GAS;
return $ret10211022;
};
var $Hann_DASH_check_DASH_temp3161026 = function(ann_DASH_check_DASH_temp1451025) {
return ann_DASH_check_DASH_temp1451025;
};
var $Hanf_arg3151002 = function(anf_arg1531001,df11182) {
var $z10291030 = D;
var $f10351036 = function(_) {
return R.isFunction(df11182.$var)?df11182.$var.app(anf_arg1531001):R.ffi.throwNonFunApp(L[117],df11182.$var,[anf_arg1531001]);
};
try {
if(--R.GAS > 0) {
$z10291030 = $f10351036();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10351036,
"from":L[117]});
}
} catch($e10271028) {
if(R.isCont($e10271028)) {
var $ss10311032 = {"from":L[117],
"go":function(ann_DASH_check_DASH_temp1511037) {
return $Hann_DASH_check_DASH_temp3141038(ann_DASH_check_DASH_temp1511037);
}};
$e10271028.stack[R.EXN_STACKHEIGHT++] = $ss10311032;
}
if(R.isPyretException($e10271028)) {
$e10271028.pyretStack.push(L[117]);
}
throw $e10271028;
}
var $ret10331034 = $Hann_DASH_check_DASH_temp3141038($z10291030);
++R.GAS;
return $ret10331034;
};
var $Hann_DASH_check_DASH_temp3141038 = function(ann_DASH_check_DASH_temp1511037) {
return ann_DASH_check_DASH_temp1511037;
};
var $Hanf_arg313639 = function(anf_arg142638,df11182,flds121590,link2735) {
var $z10411042 = D;
var $f10471048 = function(_) {
return R.isFunction(df11182.$var)?df11182.$var.app(anf_arg142638):R.ffi.throwNonFunApp(L[121],df11182.$var,[anf_arg142638]);
};
try {
if(--R.GAS > 0) {
$z10411042 = $f10471048();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10471048,
"from":L[121]});
}
} catch($e10391040) {
if(R.isCont($e10391040)) {
var $ss10431044 = {"from":L[121],
"go":function(anf_arg1431049) {
return $Hanf_arg3121050(anf_arg1431049,flds121590,link2735);
}};
$e10391040.stack[R.EXN_STACKHEIGHT++] = $ss10431044;
}
if(R.isPyretException($e10391040)) {
$e10391040.pyretStack.push(L[121]);
}
throw $e10391040;
}
var $ret10451046 = $Hanf_arg3121050($z10411042,flds121590,link2735);
++R.GAS;
return $ret10451046;
};
var $Hanf_arg3121050 = function(anf_arg1431049,flds121590,link2735) {
var $z10531054 = D;
var $f10591060 = function(_) {
return R.isFunction(link2735)?link2735.app(anf_arg1431049,flds121590):R.ffi.throwNonFunApp(L[78],link2735,[anf_arg1431049,flds121590]);
};
try {
if(--R.GAS > 0) {
$z10531054 = $f10591060();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10591060,
"from":L[78]});
}
} catch($e10511052) {
if(R.isCont($e10511052)) {
var $ss10551056 = {"from":L[78],
"go":function(ann_DASH_check_DASH_temp1401061) {
return $Hann_DASH_check_DASH_temp3111062(ann_DASH_check_DASH_temp1401061);
}};
$e10511052.stack[R.EXN_STACKHEIGHT++] = $ss10551056;
}
if(R.isPyretException($e10511052)) {
$e10511052.pyretStack.push(L[78]);
}
throw $e10511052;
}
var $ret10571058 = $Hann_DASH_check_DASH_temp3111062($z10531054);
++R.GAS;
return $ret10571058;
};
var $Hann_DASH_check_DASH_temp3111062 = function(ann_DASH_check_DASH_temp1401061) {
return ann_DASH_check_DASH_temp1401061;
};
var $Hann_DASH_check_DASH_temp310575 = function(ann_DASH_check_DASH_temp136574) {
return ann_DASH_check_DASH_temp136574;
};
var $Hanf_arg309112 = function(anf_arg127110,A38,anf_fun125111,l10677,name11498) {
var anf_fun1281073 = G(A38,"a-name",L[123]);
var $z10651066 = D;
var $f10711072 = function(_) {
return R.isFunction(anf_fun1281073)?anf_fun1281073.app(l10677,name11498):R.ffi.throwNonFunApp(L[122],anf_fun1281073,[l10677,name11498]);
};
try {
if(--R.GAS > 0) {
$z10651066 = $f10711072();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10711072,
"from":L[122]});
}
} catch($e10631064) {
if(R.isCont($e10631064)) {
var $ss10671068 = {"from":L[122],
"go":function(anf_arg1291074) {
return $Hanf_arg3081075(anf_arg1291074,anf_arg127110,anf_fun125111,l10677);
}};
$e10631064.stack[R.EXN_STACKHEIGHT++] = $ss10671068;
}
if(R.isPyretException($e10631064)) {
$e10631064.pyretStack.push(L[122]);
}
throw $e10631064;
}
var $ret10691070 = $Hanf_arg3081075($z10651066,anf_arg127110,anf_fun125111,l10677);
++R.GAS;
return $ret10691070;
};
var $Hanf_arg3081075 = function(anf_arg1291074,anf_arg127110,anf_fun125111,l10677) {
var $z10781079 = D;
var $f10841085 = function(_) {
return R.isFunction(anf_fun125111)?anf_fun125111.app(l10677,anf_arg127110,anf_arg1291074):R.ffi.throwNonFunApp(L[5],anf_fun125111,[l10677,anf_arg127110,anf_arg1291074]);
};
try {
if(--R.GAS > 0) {
$z10781079 = $f10841085();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10841085,
"from":L[5]});
}
} catch($e10761077) {
if(R.isCont($e10761077)) {
var $ss10801081 = {"from":L[5],
"go":function(ann_DASH_check_DASH_temp1241086) {
return $Hann_DASH_check_DASH_temp3071087(ann_DASH_check_DASH_temp1241086);
}};
$e10761077.stack[R.EXN_STACKHEIGHT++] = $ss10801081;
}
if(R.isPyretException($e10761077)) {
$e10761077.pyretStack.push(L[5]);
}
throw $e10761077;
}
var $ret10821083 = $Hann_DASH_check_DASH_temp3071087($z10781079);
++R.GAS;
return $ret10821083;
};
var $Hann_DASH_check_DASH_temp3071087 = function(ann_DASH_check_DASH_temp1241086) {
return ann_DASH_check_DASH_temp1241086;
};
var $Hanf_arg306128 = function(anf_arg119125,A38,anf_fun116126,anf_fun117127,l10677,name113113) {
var $z10901091 = D;
var $f10961097 = function(_) {
return R.isFunction(anf_fun117127)?anf_fun117127.app(l10677,anf_arg119125):R.ffi.throwNonFunApp(L[124],anf_fun117127,[l10677,anf_arg119125]);
};
try {
if(--R.GAS > 0) {
$z10901091 = $f10961097();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f10961097,
"from":L[124]});
}
} catch($e10881089) {
if(R.isCont($e10881089)) {
var $ss10921093 = {"from":L[124],
"go":function(anf_arg1201098) {
return $Hanf_arg3051099(anf_arg1201098,A38,anf_fun116126,l10677,name113113);
}};
$e10881089.stack[R.EXN_STACKHEIGHT++] = $ss10921093;
}
if(R.isPyretException($e10881089)) {
$e10881089.pyretStack.push(L[124]);
}
throw $e10881089;
}
var $ret10941095 = $Hanf_arg3051099($z10901091,A38,anf_fun116126,l10677,name113113);
++R.GAS;
return $ret10941095;
};
var $Hanf_arg3051099 = function(anf_arg1201098,A38,anf_fun116126,l10677,name113113) {
var anf_fun1211110 = G(A38,"s-id",L[126]);
var $z11021103 = D;
var $f11081109 = function(_) {
return R.isFunction(anf_fun1211110)?anf_fun1211110.app(l10677,name113113):R.ffi.throwNonFunApp(L[125],anf_fun1211110,[l10677,name113113]);
};
try {
if(--R.GAS > 0) {
$z11021103 = $f11081109();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11081109,
"from":L[125]});
}
} catch($e11001101) {
if(R.isCont($e11001101)) {
var $ss11041105 = {"from":L[125],
"go":function(anf_arg1221111) {
return $Hanf_arg3041112(anf_arg1221111,anf_arg1201098,anf_fun116126,l10677);
}};
$e11001101.stack[R.EXN_STACKHEIGHT++] = $ss11041105;
}
if(R.isPyretException($e11001101)) {
$e11001101.pyretStack.push(L[125]);
}
throw $e11001101;
}
var $ret11061107 = $Hanf_arg3041112($z11021103,anf_arg1201098,anf_fun116126,l10677);
++R.GAS;
return $ret11061107;
};
var $Hanf_arg3041112 = function(anf_arg1221111,anf_arg1201098,anf_fun116126,l10677) {
var $z11151116 = D;
var $f11211122 = function(_) {
return R.isFunction(anf_fun116126)?anf_fun116126.app(l10677,anf_arg1201098,anf_arg1221111):R.ffi.throwNonFunApp(L[9],anf_fun116126,[l10677,anf_arg1201098,anf_arg1221111]);
};
try {
if(--R.GAS > 0) {
$z11151116 = $f11211122();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11211122,
"from":L[9]});
}
} catch($e11131114) {
if(R.isCont($e11131114)) {
var $ss11171118 = {"from":L[9],
"go":function(ann_DASH_check_DASH_temp1151123) {
return $Hann_DASH_check_DASH_temp3031124(ann_DASH_check_DASH_temp1151123);
}};
$e11131114.stack[R.EXN_STACKHEIGHT++] = $ss11171118;
}
if(R.isPyretException($e11131114)) {
$e11131114.pyretStack.push(L[9]);
}
throw $e11131114;
}
var $ret11191120 = $Hann_DASH_check_DASH_temp3031124($z11151116);
++R.GAS;
return $ret11191120;
};
var $Hann_DASH_check_DASH_temp3031124 = function(ann_DASH_check_DASH_temp1151123) {
return ann_DASH_check_DASH_temp1151123;
};
var $Hann_DASH_check_DASH_temp302145 = function(ann_DASH_check_DASH_temp63144) {
return ann_DASH_check_DASH_temp63144;
};
var $Hids301169 = function(ids95168,A38,af92155,body90152,df91153,imports89151,l86148,make_DASH_safe_DASH_imports8038,map3537,_plus2) {
var $z11271128 = D;
var $f11331134 = function(_) {
return R.isFunction(make_DASH_safe_DASH_imports8038.$var)?make_DASH_safe_DASH_imports8038.$var.app(imports89151):R.ffi.throwNonFunApp(L[127],make_DASH_safe_DASH_imports8038.$var,[imports89151]);
};
try {
if(--R.GAS > 0) {
$z11271128 = $f11331134();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11331134,
"from":L[127]});
}
} catch($e11251126) {
if(R.isCont($e11251126)) {
var $ss11291130 = {"from":L[127],
"go":function(safe_DASH_imports961135) {
return $Hsafe_DASH_imports3001136(safe_DASH_imports961135,A38,af92155,body90152,df91153,ids95168,l86148,map3537,_plus2);
}};
$e11251126.stack[R.EXN_STACKHEIGHT++] = $ss11291130;
}
if(R.isPyretException($e11251126)) {
$e11251126.pyretStack.push(L[127]);
}
throw $e11251126;
}
var $ret11311132 = $Hsafe_DASH_imports3001136($z11271128,A38,af92155,body90152,df91153,ids95168,l86148,map3537,_plus2);
++R.GAS;
return $ret11311132;
};
var $Hsafe_DASH_imports3001136 = function(safe_DASH_imports961135,A38,af92155,body90152,df91153,ids95168,l86148,map3537,_plus2) {
var anf_fun831147 = G(safe_DASH_imports961135,"map",L[130]);
var anf_arg851148 = R.makeFunction(function(recv_DASH_51151) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[129],1,arguments);
}
var ann_DASH_check_DASH_temp841152 = G(recv_DASH_51151,"name",L[129]);
return ann_DASH_check_DASH_temp841152;
});
var $z11391140 = D;
var $f11451146 = function(_) {
return R.isFunction(anf_fun831147)?anf_fun831147.app(anf_arg851148):R.ffi.throwNonFunApp(L[128],anf_fun831147,[anf_arg851148]);
};
try {
if(--R.GAS > 0) {
$z11391140 = $f11451146();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11451146,
"from":L[128]});
}
} catch($e11371138) {
if(R.isCont($e11371138)) {
var $ss11411142 = {"from":L[128],
"go":function(anf_arg861149) {
return $Hanf_arg2991150(anf_arg861149,A38,af92155,body90152,df91153,ids95168,l86148,map3537,safe_DASH_imports961135,_plus2);
}};
$e11371138.stack[R.EXN_STACKHEIGHT++] = $ss11411142;
}
if(R.isPyretException($e11371138)) {
$e11371138.pyretStack.push(L[128]);
}
throw $e11371138;
}
var $ret11431144 = $Hanf_arg2991150($z11391140,A38,af92155,body90152,df91153,ids95168,l86148,map3537,safe_DASH_imports961135,_plus2);
++R.GAS;
return $ret11431144;
};
var $Hanf_arg2991150 = function(anf_arg861149,A38,af92155,body90152,df91153,ids95168,l86148,map3537,safe_DASH_imports961135,_plus2) {
var $z11551156 = D;
var $f11611162 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg861149,ids95168):R.ffi.throwNonFunApp(L[131],_plus2,[anf_arg861149,ids95168]);
};
try {
if(--R.GAS > 0) {
$z11551156 = $f11611162();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11611162,
"from":L[131]});
}
} catch($e11531154) {
if(R.isCont($e11531154)) {
var $ss11571158 = {"from":L[131],
"go":function(ids_DASH_plus_DASH_import_DASH_names971163) {
return $Hids_DASH_plus_DASH_import_DASH_names2981164(ids_DASH_plus_DASH_import_DASH_names971163,A38,af92155,body90152,df91153,l86148,map3537,safe_DASH_imports961135,_plus2);
}};
$e11531154.stack[R.EXN_STACKHEIGHT++] = $ss11571158;
}
if(R.isPyretException($e11531154)) {
$e11531154.pyretStack.push(L[131]);
}
throw $e11531154;
}
var $ret11591160 = $Hids_DASH_plus_DASH_import_DASH_names2981164($z11551156,A38,af92155,body90152,df91153,l86148,map3537,safe_DASH_imports961135,_plus2);
++R.GAS;
return $ret11591160;
};
var $Hids_DASH_plus_DASH_import_DASH_names2981164 = function(ids_DASH_plus_DASH_import_DASH_names971163,A38,af92155,body90152,df91153,l86148,map3537,safe_DASH_imports961135,_plus2) {
var anf_arg881175 = R.makeFunction(function(id991178) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[133],1,arguments);
}
var $z11811182 = D;
var $f11871188 = function(_) {
return R.isFunction(df91153.$var)?df91153.$var.app(id991178):R.ffi.throwNonFunApp(L[133],df91153.$var,[id991178]);
};
try {
if(--R.GAS > 0) {
$z11811182 = $f11871188();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11871188,
"from":L[133]});
}
} catch($e11791180) {
if(R.isCont($e11791180)) {
var $ss11831184 = {"from":L[133],
"go":function(ann_DASH_check_DASH_temp871189) {
return $Hann_DASH_check_DASH_temp2861190(ann_DASH_check_DASH_temp871189);
}};
$e11791180.stack[R.EXN_STACKHEIGHT++] = $ss11831184;
}
if(R.isPyretException($e11791180)) {
$e11791180.pyretStack.push(L[133]);
}
throw $e11791180;
}
var $ret11851186 = $Hann_DASH_check_DASH_temp2861190($z11811182);
++R.GAS;
return $ret11851186;
});
var $z11671168 = D;
var $f11731174 = function(_) {
return R.isFunction(map3537)?map3537.app(anf_arg881175,ids_DASH_plus_DASH_import_DASH_names971163):R.ffi.throwNonFunApp(L[132],map3537,[anf_arg881175,ids_DASH_plus_DASH_import_DASH_names971163]);
};
try {
if(--R.GAS > 0) {
$z11671168 = $f11731174();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11731174,
"from":L[132]});
}
} catch($e11651166) {
if(R.isCont($e11651166)) {
var $ss11691170 = {"from":L[132],
"go":function(repl_DASH_provide981176) {
return $Hrepl_DASH_provide2971177(repl_DASH_provide981176,A38,af92155,body90152,l86148,map3537,safe_DASH_imports961135,_plus2);
}};
$e11651166.stack[R.EXN_STACKHEIGHT++] = $ss11691170;
}
if(R.isPyretException($e11651166)) {
$e11651166.pyretStack.push(L[132]);
}
throw $e11651166;
}
var $ret11711172 = $Hrepl_DASH_provide2971177($z11671168,A38,af92155,body90152,l86148,map3537,safe_DASH_imports961135,_plus2);
++R.GAS;
return $ret11711172;
};
var $Hrepl_DASH_provide2971177 = function(repl_DASH_provide981176,A38,af92155,body90152,l86148,map3537,safe_DASH_imports961135,_plus2) {
var anf_fun891201 = G(A38,"block-type-ids",L[135]);
var $z11931194 = D;
var $f11991200 = function(_) {
return R.isFunction(anf_fun891201)?anf_fun891201.app(body90152):R.ffi.throwNonFunApp(L[134],anf_fun891201,[body90152]);
};
try {
if(--R.GAS > 0) {
$z11931194 = $f11991200();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f11991200,
"from":L[134]});
}
} catch($e11911192) {
if(R.isCont($e11911192)) {
var $ss11951196 = {"from":L[134],
"go":function(type_DASH_ids1001202) {
return $Htype_DASH_ids2961203(type_DASH_ids1001202,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,_plus2);
}};
$e11911192.stack[R.EXN_STACKHEIGHT++] = $ss11951196;
}
if(R.isPyretException($e11911192)) {
$e11911192.pyretStack.push(L[134]);
}
throw $e11911192;
}
var $ret11971198 = $Htype_DASH_ids2961203($z11931194,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,_plus2);
++R.GAS;
return $ret11971198;
};
var $Htype_DASH_ids2961203 = function(type_DASH_ids1001202,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,_plus2) {
var anf_fun901214 = G(safe_DASH_imports961135,"map",L[138]);
var anf_arg921215 = R.makeFunction(function(recv_DASH_61218) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[137],1,arguments);
}
var ann_DASH_check_DASH_temp911219 = G(recv_DASH_61218,"name",L[137]);
return ann_DASH_check_DASH_temp911219;
});
var $z12061207 = D;
var $f12121213 = function(_) {
return R.isFunction(anf_fun901214)?anf_fun901214.app(anf_arg921215):R.ffi.throwNonFunApp(L[136],anf_fun901214,[anf_arg921215]);
};
try {
if(--R.GAS > 0) {
$z12061207 = $f12121213();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12121213,
"from":L[136]});
}
} catch($e12041205) {
if(R.isCont($e12041205)) {
var $ss12081209 = {"from":L[136],
"go":function(anf_arg931216) {
return $Hanf_arg2951217(anf_arg931216,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,type_DASH_ids1001202,_plus2);
}};
$e12041205.stack[R.EXN_STACKHEIGHT++] = $ss12081209;
}
if(R.isPyretException($e12041205)) {
$e12041205.pyretStack.push(L[136]);
}
throw $e12041205;
}
var $ret12101211 = $Hanf_arg2951217($z12061207,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,type_DASH_ids1001202,_plus2);
++R.GAS;
return $ret12101211;
};
var $Hanf_arg2951217 = function(anf_arg931216,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,type_DASH_ids1001202,_plus2) {
var anf_fun941230 = G(type_DASH_ids1001202,"map",L[141]);
var anf_arg961231 = R.makeFunction(function(recv_DASH_71234) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[140],1,arguments);
}
var ann_DASH_check_DASH_temp951235 = G(recv_DASH_71234,"name",L[140]);
return ann_DASH_check_DASH_temp951235;
});
var $z12221223 = D;
var $f12281229 = function(_) {
return R.isFunction(anf_fun941230)?anf_fun941230.app(anf_arg961231):R.ffi.throwNonFunApp(L[139],anf_fun941230,[anf_arg961231]);
};
try {
if(--R.GAS > 0) {
$z12221223 = $f12281229();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12281229,
"from":L[139]});
}
} catch($e12201221) {
if(R.isCont($e12201221)) {
var $ss12241225 = {"from":L[139],
"go":function(anf_arg971232) {
return $Hanf_arg2941233(anf_arg971232,A38,af92155,anf_arg931216,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,_plus2);
}};
$e12201221.stack[R.EXN_STACKHEIGHT++] = $ss12241225;
}
if(R.isPyretException($e12201221)) {
$e12201221.pyretStack.push(L[139]);
}
throw $e12201221;
}
var $ret12261227 = $Hanf_arg2941233($z12221223,A38,af92155,anf_arg931216,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,_plus2);
++R.GAS;
return $ret12261227;
};
var $Hanf_arg2941233 = function(anf_arg971232,A38,af92155,anf_arg931216,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135,_plus2) {
var $z12381239 = D;
var $f12441245 = function(_) {
return R.isFunction(_plus2)?_plus2.app(anf_arg931216,anf_arg971232):R.ffi.throwNonFunApp(L[142],_plus2,[anf_arg931216,anf_arg971232]);
};
try {
if(--R.GAS > 0) {
$z12381239 = $f12441245();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12441245,
"from":L[142]});
}
} catch($e12361237) {
if(R.isCont($e12361237)) {
var $ss12401241 = {"from":L[142],
"go":function(type_DASH_ids_DASH_plus_DASH_import_DASH_names1011246) {
return $Htype_DASH_ids_DASH_plus_DASH_import_DASH_names2931247(type_DASH_ids_DASH_plus_DASH_import_DASH_names1011246,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135);
}};
$e12361237.stack[R.EXN_STACKHEIGHT++] = $ss12401241;
}
if(R.isPyretException($e12361237)) {
$e12361237.pyretStack.push(L[142]);
}
throw $e12361237;
}
var $ret12421243 = $Htype_DASH_ids_DASH_plus_DASH_import_DASH_names2931247($z12381239,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135);
++R.GAS;
return $ret12421243;
};
var $Htype_DASH_ids_DASH_plus_DASH_import_DASH_names2931247 = function(type_DASH_ids_DASH_plus_DASH_import_DASH_names1011246,A38,af92155,body90152,l86148,map3537,repl_DASH_provide981176,safe_DASH_imports961135) {
var anf_arg991258 = R.makeFunction(function(id1031261) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[144],1,arguments);
}
var $z12641265 = D;
var $f12701271 = function(_) {
return R.isFunction(af92155.$var)?af92155.$var.app(id1031261):R.ffi.throwNonFunApp(L[144],af92155.$var,[id1031261]);
};
try {
if(--R.GAS > 0) {
$z12641265 = $f12701271();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12701271,
"from":L[144]});
}
} catch($e12621263) {
if(R.isCont($e12621263)) {
var $ss12661267 = {"from":L[144],
"go":function(ann_DASH_check_DASH_temp981272) {
return $Hann_DASH_check_DASH_temp2871273(ann_DASH_check_DASH_temp981272);
}};
$e12621263.stack[R.EXN_STACKHEIGHT++] = $ss12661267;
}
if(R.isPyretException($e12621263)) {
$e12621263.pyretStack.push(L[144]);
}
throw $e12621263;
}
var $ret12681269 = $Hann_DASH_check_DASH_temp2871273($z12641265);
++R.GAS;
return $ret12681269;
});
var $z12501251 = D;
var $f12561257 = function(_) {
return R.isFunction(map3537)?map3537.app(anf_arg991258,type_DASH_ids_DASH_plus_DASH_import_DASH_names1011246):R.ffi.throwNonFunApp(L[143],map3537,[anf_arg991258,type_DASH_ids_DASH_plus_DASH_import_DASH_names1011246]);
};
try {
if(--R.GAS > 0) {
$z12501251 = $f12561257();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12561257,
"from":L[143]});
}
} catch($e12481249) {
if(R.isCont($e12481249)) {
var $ss12521253 = {"from":L[143],
"go":function(repl_DASH_type_DASH_provide1021259) {
return $Hrepl_DASH_type_DASH_provide2921260(repl_DASH_type_DASH_provide1021259,A38,body90152,l86148,repl_DASH_provide981176,safe_DASH_imports961135);
}};
$e12481249.stack[R.EXN_STACKHEIGHT++] = $ss12521253;
}
if(R.isPyretException($e12481249)) {
$e12481249.pyretStack.push(L[143]);
}
throw $e12481249;
}
var $ret12541255 = $Hrepl_DASH_type_DASH_provide2921260($z12501251,A38,body90152,l86148,repl_DASH_provide981176,safe_DASH_imports961135);
++R.GAS;
return $ret12541255;
};
var $Hrepl_DASH_type_DASH_provide2921260 = function(repl_DASH_type_DASH_provide1021259,A38,body90152,l86148,repl_DASH_provide981176,safe_DASH_imports961135) {
var anf_fun1001286 = G(A38,"s-program",L[148]);
var anf_fun1011287 = G(A38,"s-provide",L[147]);
var anf_fun1021284 = G(A38,"s-obj",L[146]);
var $z12761277 = D;
var $f12821283 = function(_) {
return R.isFunction(anf_fun1021284)?anf_fun1021284.app(l86148,repl_DASH_provide981176):R.ffi.throwNonFunApp(L[145],anf_fun1021284,[l86148,repl_DASH_provide981176]);
};
try {
if(--R.GAS > 0) {
$z12761277 = $f12821283();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12821283,
"from":L[145]});
}
} catch($e12741275) {
if(R.isCont($e12741275)) {
var $ss12781279 = {"from":L[145],
"go":function(anf_arg1031285) {
return $Hanf_arg2911288(anf_arg1031285,A38,anf_fun1001286,anf_fun1011287,body90152,l86148,repl_DASH_type_DASH_provide1021259,safe_DASH_imports961135);
}};
$e12741275.stack[R.EXN_STACKHEIGHT++] = $ss12781279;
}
if(R.isPyretException($e12741275)) {
$e12741275.pyretStack.push(L[145]);
}
throw $e12741275;
}
var $ret12801281 = $Hanf_arg2911288($z12761277,A38,anf_fun1001286,anf_fun1011287,body90152,l86148,repl_DASH_type_DASH_provide1021259,safe_DASH_imports961135);
++R.GAS;
return $ret12801281;
};
var $Hanf_arg2911288 = function(anf_arg1031285,A38,anf_fun1001286,anf_fun1011287,body90152,l86148,repl_DASH_type_DASH_provide1021259,safe_DASH_imports961135) {
var $z12911292 = D;
var $f12971298 = function(_) {
return R.isFunction(anf_fun1011287)?anf_fun1011287.app(l86148,anf_arg1031285):R.ffi.throwNonFunApp(L[149],anf_fun1011287,[l86148,anf_arg1031285]);
};
try {
if(--R.GAS > 0) {
$z12911292 = $f12971298();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f12971298,
"from":L[149]});
}
} catch($e12891290) {
if(R.isCont($e12891290)) {
var $ss12931294 = {"from":L[149],
"go":function(anf_arg1041299) {
return $Hanf_arg2901300(anf_arg1041299,A38,anf_fun1001286,body90152,l86148,repl_DASH_type_DASH_provide1021259,safe_DASH_imports961135);
}};
$e12891290.stack[R.EXN_STACKHEIGHT++] = $ss12931294;
}
if(R.isPyretException($e12891290)) {
$e12891290.pyretStack.push(L[149]);
}
throw $e12891290;
}
var $ret12951296 = $Hanf_arg2901300($z12911292,A38,anf_fun1001286,body90152,l86148,repl_DASH_type_DASH_provide1021259,safe_DASH_imports961135);
++R.GAS;
return $ret12951296;
};
var $Hanf_arg2901300 = function(anf_arg1041299,A38,anf_fun1001286,body90152,l86148,repl_DASH_type_DASH_provide1021259,safe_DASH_imports961135) {
var anf_fun1051311 = G(A38,"s-provide-types",L[151]);
var $z13031304 = D;
var $f13091310 = function(_) {
return R.isFunction(anf_fun1051311)?anf_fun1051311.app(l86148,repl_DASH_type_DASH_provide1021259):R.ffi.throwNonFunApp(L[150],anf_fun1051311,[l86148,repl_DASH_type_DASH_provide1021259]);
};
try {
if(--R.GAS > 0) {
$z13031304 = $f13091310();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13091310,
"from":L[150]});
}
} catch($e13011302) {
if(R.isCont($e13011302)) {
var $ss13051306 = {"from":L[150],
"go":function(anf_arg1061312) {
return $Hanf_arg2891313(anf_arg1061312,anf_arg1041299,anf_fun1001286,body90152,l86148,safe_DASH_imports961135);
}};
$e13011302.stack[R.EXN_STACKHEIGHT++] = $ss13051306;
}
if(R.isPyretException($e13011302)) {
$e13011302.pyretStack.push(L[150]);
}
throw $e13011302;
}
var $ret13071308 = $Hanf_arg2891313($z13031304,anf_arg1041299,anf_fun1001286,body90152,l86148,safe_DASH_imports961135);
++R.GAS;
return $ret13071308;
};
var $Hanf_arg2891313 = function(anf_arg1061312,anf_arg1041299,anf_fun1001286,body90152,l86148,safe_DASH_imports961135) {
var $z13161317 = D;
var $f13221323 = function(_) {
return R.isFunction(anf_fun1001286)?anf_fun1001286.app(l86148,anf_arg1041299,anf_arg1061312,safe_DASH_imports961135,body90152):R.ffi.throwNonFunApp(L[18],anf_fun1001286,[l86148,anf_arg1041299,anf_arg1061312,safe_DASH_imports961135,body90152]);
};
try {
if(--R.GAS > 0) {
$z13161317 = $f13221323();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13221323,
"from":L[18]});
}
} catch($e13141315) {
if(R.isCont($e13141315)) {
var $ss13181319 = {"from":L[18],
"go":function(ann_DASH_check_DASH_temp651324) {
return $Hann_DASH_check_DASH_temp2881325(ann_DASH_check_DASH_temp651324);
}};
$e13141315.stack[R.EXN_STACKHEIGHT++] = $ss13181319;
}
if(R.isPyretException($e13141315)) {
$e13141315.pyretStack.push(L[18]);
}
throw $e13141315;
}
var $ret13201321 = $Hann_DASH_check_DASH_temp2881325($z13161317);
++R.GAS;
return $ret13201321;
};
var $Hann_DASH_check_DASH_temp2881325 = function(ann_DASH_check_DASH_temp651324) {
return ann_DASH_check_DASH_temp651324;
};
var $Hann_DASH_check_DASH_temp2871273 = function(ann_DASH_check_DASH_temp981272) {
return ann_DASH_check_DASH_temp981272;
};
var $Hann_DASH_check_DASH_temp2861190 = function(ann_DASH_check_DASH_temp871189) {
return ann_DASH_check_DASH_temp871189;
};
var $Hanf_arg285184 = function(anf_arg78182,A38,anf_fun76183,l86148,name94170) {
var anf_fun791336 = G(A38,"a-name",L[153]);
var $z13281329 = D;
var $f13341335 = function(_) {
return R.isFunction(anf_fun791336)?anf_fun791336.app(l86148,name94170):R.ffi.throwNonFunApp(L[152],anf_fun791336,[l86148,name94170]);
};
try {
if(--R.GAS > 0) {
$z13281329 = $f13341335();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13341335,
"from":L[152]});
}
} catch($e13261327) {
if(R.isCont($e13261327)) {
var $ss13301331 = {"from":L[152],
"go":function(anf_arg801337) {
return $Hanf_arg2841338(anf_arg801337,anf_arg78182,anf_fun76183,l86148);
}};
$e13261327.stack[R.EXN_STACKHEIGHT++] = $ss13301331;
}
if(R.isPyretException($e13261327)) {
$e13261327.pyretStack.push(L[152]);
}
throw $e13261327;
}
var $ret13321333 = $Hanf_arg2841338($z13281329,anf_arg78182,anf_fun76183,l86148);
++R.GAS;
return $ret13321333;
};
var $Hanf_arg2841338 = function(anf_arg801337,anf_arg78182,anf_fun76183,l86148) {
var $z13411342 = D;
var $f13471348 = function(_) {
return R.isFunction(anf_fun76183)?anf_fun76183.app(l86148,anf_arg78182,anf_arg801337):R.ffi.throwNonFunApp(L[21],anf_fun76183,[l86148,anf_arg78182,anf_arg801337]);
};
try {
if(--R.GAS > 0) {
$z13411342 = $f13471348();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13471348,
"from":L[21]});
}
} catch($e13391340) {
if(R.isCont($e13391340)) {
var $ss13431344 = {"from":L[21],
"go":function(ann_DASH_check_DASH_temp751349) {
return $Hann_DASH_check_DASH_temp2831350(ann_DASH_check_DASH_temp751349);
}};
$e13391340.stack[R.EXN_STACKHEIGHT++] = $ss13431344;
}
if(R.isPyretException($e13391340)) {
$e13391340.pyretStack.push(L[21]);
}
throw $e13391340;
}
var $ret13451346 = $Hann_DASH_check_DASH_temp2831350($z13411342);
++R.GAS;
return $ret13451346;
};
var $Hann_DASH_check_DASH_temp2831350 = function(ann_DASH_check_DASH_temp751349) {
return ann_DASH_check_DASH_temp751349;
};
var $Hanf_arg282200 = function(anf_arg70197,A38,anf_fun67198,anf_fun68199,l86148,name93185) {
var $z13531354 = D;
var $f13591360 = function(_) {
return R.isFunction(anf_fun68199)?anf_fun68199.app(l86148,anf_arg70197):R.ffi.throwNonFunApp(L[154],anf_fun68199,[l86148,anf_arg70197]);
};
try {
if(--R.GAS > 0) {
$z13531354 = $f13591360();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13591360,
"from":L[154]});
}
} catch($e13511352) {
if(R.isCont($e13511352)) {
var $ss13551356 = {"from":L[154],
"go":function(anf_arg711361) {
return $Hanf_arg2811362(anf_arg711361,A38,anf_fun67198,l86148,name93185);
}};
$e13511352.stack[R.EXN_STACKHEIGHT++] = $ss13551356;
}
if(R.isPyretException($e13511352)) {
$e13511352.pyretStack.push(L[154]);
}
throw $e13511352;
}
var $ret13571358 = $Hanf_arg2811362($z13531354,A38,anf_fun67198,l86148,name93185);
++R.GAS;
return $ret13571358;
};
var $Hanf_arg2811362 = function(anf_arg711361,A38,anf_fun67198,l86148,name93185) {
var anf_fun721373 = G(A38,"s-id",L[156]);
var $z13651366 = D;
var $f13711372 = function(_) {
return R.isFunction(anf_fun721373)?anf_fun721373.app(l86148,name93185):R.ffi.throwNonFunApp(L[155],anf_fun721373,[l86148,name93185]);
};
try {
if(--R.GAS > 0) {
$z13651366 = $f13711372();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13711372,
"from":L[155]});
}
} catch($e13631364) {
if(R.isCont($e13631364)) {
var $ss13671368 = {"from":L[155],
"go":function(anf_arg731374) {
return $Hanf_arg2801375(anf_arg731374,anf_arg711361,anf_fun67198,l86148);
}};
$e13631364.stack[R.EXN_STACKHEIGHT++] = $ss13671368;
}
if(R.isPyretException($e13631364)) {
$e13631364.pyretStack.push(L[155]);
}
throw $e13631364;
}
var $ret13691370 = $Hanf_arg2801375($z13651366,anf_arg711361,anf_fun67198,l86148);
++R.GAS;
return $ret13691370;
};
var $Hanf_arg2801375 = function(anf_arg731374,anf_arg711361,anf_fun67198,l86148) {
var $z13781379 = D;
var $f13841385 = function(_) {
return R.isFunction(anf_fun67198)?anf_fun67198.app(l86148,anf_arg711361,anf_arg731374):R.ffi.throwNonFunApp(L[25],anf_fun67198,[l86148,anf_arg711361,anf_arg731374]);
};
try {
if(--R.GAS > 0) {
$z13781379 = $f13841385();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13841385,
"from":L[25]});
}
} catch($e13761377) {
if(R.isCont($e13761377)) {
var $ss13801381 = {"from":L[25],
"go":function(ann_DASH_check_DASH_temp661386) {
return $Hann_DASH_check_DASH_temp2791387(ann_DASH_check_DASH_temp661386);
}};
$e13761377.stack[R.EXN_STACKHEIGHT++] = $ss13801381;
}
if(R.isPyretException($e13761377)) {
$e13761377.pyretStack.push(L[25]);
}
throw $e13761377;
}
var $ret13821383 = $Hann_DASH_check_DASH_temp2791387($z13781379);
++R.GAS;
return $ret13821383;
};
var $Hann_DASH_check_DASH_temp2791387 = function(ann_DASH_check_DASH_temp661386) {
return ann_DASH_check_DASH_temp661386;
};
var $Hann_DASH_check_DASH_temp278216 = function(ann_DASH_check_DASH_temp43215) {
return ann_DASH_check_DASH_temp43215;
};
var $Hand_DASH_oper_DASH_277231 = function(and_DASH_oper_DASH_3230,bad_DASH_imports7930,i84217,not4) {
var if_helper481401 = R.makeFunction(function(if_helper_arg491421) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[33],1,arguments);
}
var $z14241425 = D;
var $f14301431 = function(_) {
return R.isFunction(not4)?not4.app(if_helper_arg491421):R.ffi.throwNonFunApp(L[32],not4,[if_helper_arg491421]);
};
try {
if(--R.GAS > 0) {
$z14241425 = $f14301431();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14301431,
"from":L[32]});
}
} catch($e14221423) {
if(R.isCont($e14221423)) {
var $ss14261427 = {"from":L[32],
"go":function(ann_DASH_check_DASH_temp451432) {
return $Hann_DASH_check_DASH_temp2731433(ann_DASH_check_DASH_temp451432);
}};
$e14221423.stack[R.EXN_STACKHEIGHT++] = $ss14261427;
}
if(R.isPyretException($e14221423)) {
$e14221423.pyretStack.push(L[32]);
}
throw $e14221423;
}
var $ret14281429 = $Hann_DASH_check_DASH_temp2731433($z14241425);
++R.GAS;
return $ret14281429;
});
var anf_if521420 = R.isBoolean(and_DASH_oper_DASH_3230);
if(R.isPyretTrue(anf_if521420)) {
if(R.isPyretTrue(and_DASH_oper_DASH_3230)) {
var anf_fun541398 = G(bad_DASH_imports7930,"member",L[159]);
var anf_bracket551403 = G(i84217,"file",L[158]);
var anf_arg561399 = G(anf_bracket551403,"mod",L[157]);
var $z13901391 = D;
var $f13961397 = function(_) {
return R.isFunction(anf_fun541398)?anf_fun541398.app(anf_arg561399):R.ffi.throwNonFunApp(L[33],anf_fun541398,[anf_arg561399]);
};
try {
if(--R.GAS > 0) {
$z13901391 = $f13961397();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f13961397,
"from":L[33]});
}
} catch($e13881389) {
if(R.isCont($e13881389)) {
var $ss13921393 = {"from":L[33],
"go":function(and_DASH_oper_DASH_41400) {
return $Hand_DASH_oper_DASH_2751402(and_DASH_oper_DASH_41400,if_helper481401);
}};
$e13881389.stack[R.EXN_STACKHEIGHT++] = $ss13921393;
}
if(R.isPyretException($e13881389)) {
$e13881389.pyretStack.push(L[33]);
}
throw $e13881389;
}
var $ret13941395 = $Hand_DASH_oper_DASH_2751402($z13901391,if_helper481401);
++R.GAS;
return $ret13941395;
} else {
var $z14061407 = D;
var $f14121413 = function(_) {
return R.isFunction(if_helper481401)?if_helper481401.app((false)):R.ffi.throwNonFunApp(L[33],if_helper481401,[(false)]);
};
try {
if(--R.GAS > 0) {
$z14061407 = $f14121413();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14121413,
"from":L[33]});
}
} catch($e14041405) {
if(R.isCont($e14041405)) {
var $ss14081409 = {"from":L[33],
"go":function(cont_tail_app531414) {
return $Hcont_tail_app2761415(cont_tail_app531414);
}};
$e14041405.stack[R.EXN_STACKHEIGHT++] = $ss14081409;
}
if(R.isPyretException($e14041405)) {
$e14041405.pyretStack.push(L[33]);
}
throw $e14041405;
}
var $ret14101411 = $Hcont_tail_app2761415($z14061407);
++R.GAS;
return $ret14101411;
}
} else {
var cont_tail_arg501418 = R.throwNonBooleanOp(L[160],("first"),("and"),and_DASH_oper_DASH_3230);
if(--R.GAS > 0) {
$z14161417 = R.isFunction(if_helper481401)?if_helper481401.app(cont_tail_arg501418):R.ffi.throwNonFunApp(L[160],if_helper481401,[cont_tail_arg501418]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1419) {
return R.isFunction(if_helper481401)?if_helper481401.app(cont_tail_arg501418):R.ffi.throwNonFunApp(L[160],if_helper481401,[cont_tail_arg501418]);
},
"from":L[160]});
}
++R.GAS;
return $z14161417;
}
};
var $Hand_DASH_oper_DASH_2751402 = function(and_DASH_oper_DASH_41400,if_helper481401) {
var anf_if591449 = R.isBoolean(and_DASH_oper_DASH_41400);
if(R.isPyretTrue(anf_if591449)) {
var $z14361437 = D;
var $f14421443 = function(_) {
return R.isFunction(if_helper481401)?if_helper481401.app(and_DASH_oper_DASH_41400):R.ffi.throwNonFunApp(L[33],if_helper481401,[and_DASH_oper_DASH_41400]);
};
try {
if(--R.GAS > 0) {
$z14361437 = $f14421443();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14421443,
"from":L[33]});
}
} catch($e14341435) {
if(R.isCont($e14341435)) {
var $ss14381439 = {"from":L[33],
"go":function(cont_tail_app601444) {
return $Hcont_tail_app2741445(cont_tail_app601444);
}};
$e14341435.stack[R.EXN_STACKHEIGHT++] = $ss14381439;
}
if(R.isPyretException($e14341435)) {
$e14341435.pyretStack.push(L[33]);
}
throw $e14341435;
}
var $ret14401441 = $Hcont_tail_app2741445($z14361437);
++R.GAS;
return $ret14401441;
} else {
var cont_tail_arg571448 = R.throwNonBooleanOp(L[161],("second"),("and"),and_DASH_oper_DASH_41400);
if(--R.GAS > 0) {
$z14461447 = R.isFunction(if_helper481401)?if_helper481401.app(cont_tail_arg571448):R.ffi.throwNonFunApp(L[161],if_helper481401,[cont_tail_arg571448]);
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":function(ignored1419) {
return R.isFunction(if_helper481401)?if_helper481401.app(cont_tail_arg571448):R.ffi.throwNonFunApp(L[161],if_helper481401,[cont_tail_arg571448]);
},
"from":L[161]});
}
++R.GAS;
return $z14461447;
}
};
var $Hcont_tail_app2741445 = function(cont_tail_app601444) {
return cont_tail_app601444;
};
var $Hcont_tail_app2761415 = function(cont_tail_app531414) {
return cont_tail_app531414;
};
var $Hann_DASH_check_DASH_temp2731433 = function(ann_DASH_check_DASH_temp451432) {
return ann_DASH_check_DASH_temp451432;
};
var $Hann_DASH_check_DASH_temp2721450 = function(ann_DASH_check_DASH_temp301451) {
return ann_DASH_check_DASH_temp301451;
};
var $Hanf_arg2711452 = function(anf_arg351453,anf_fun331454,bindings771455,link2735,types781456) {
var $z14591460 = D;
var $f14651466 = function(_) {
return R.isFunction(link2735)?link2735.app(anf_arg351453,types781456):R.ffi.throwNonFunApp(L[162],link2735,[anf_arg351453,types781456]);
};
try {
if(--R.GAS > 0) {
$z14591460 = $f14651466();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14651466,
"from":L[162]});
}
} catch($e14571458) {
if(R.isCont($e14571458)) {
var $ss14611462 = {"from":L[162],
"go":function(anf_arg361467) {
return $Hanf_arg2701468(anf_arg361467,anf_fun331454,bindings771455);
}};
$e14571458.stack[R.EXN_STACKHEIGHT++] = $ss14611462;
}
if(R.isPyretException($e14571458)) {
$e14571458.pyretStack.push(L[162]);
}
throw $e14571458;
}
var $ret14631464 = $Hanf_arg2701468($z14591460,anf_fun331454,bindings771455);
++R.GAS;
return $ret14631464;
};
var $Hanf_arg2701468 = function(anf_arg361467,anf_fun331454,bindings771455) {
var $z14711472 = D;
var $f14771478 = function(_) {
return R.isFunction(anf_fun331454)?anf_fun331454.app(bindings771455,anf_arg361467):R.ffi.throwNonFunApp(L[163],anf_fun331454,[bindings771455,anf_arg361467]);
};
try {
if(--R.GAS > 0) {
$z14711472 = $f14771478();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14771478,
"from":L[163]});
}
} catch($e14691470) {
if(R.isCont($e14691470)) {
var $ss14731474 = {"from":L[163],
"go":function(ann_DASH_check_DASH_temp321479) {
return $Hann_DASH_check_DASH_temp2691480(ann_DASH_check_DASH_temp321479);
}};
$e14691470.stack[R.EXN_STACKHEIGHT++] = $ss14731474;
}
if(R.isPyretException($e14691470)) {
$e14691470.pyretStack.push(L[163]);
}
throw $e14691470;
}
var $ret14751476 = $Hann_DASH_check_DASH_temp2691480($z14711472);
++R.GAS;
return $ret14751476;
};
var $Hann_DASH_check_DASH_temp2691480 = function(ann_DASH_check_DASH_temp321479) {
return ann_DASH_check_DASH_temp321479;
};
var $Hann_DASH_check_DASH_temp2681481 = function(ann_DASH_check_DASH_temp181482) {
return ann_DASH_check_DASH_temp181482;
};
var $Hanf_arg2671483 = function(anf_arg231484,anf_fun211485,bindings731486,link2735,types741487) {
var $z14901491 = D;
var $f14961497 = function(_) {
return R.isFunction(link2735)?link2735.app(anf_arg231484,bindings731486):R.ffi.throwNonFunApp(L[164],link2735,[anf_arg231484,bindings731486]);
};
try {
if(--R.GAS > 0) {
$z14901491 = $f14961497();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f14961497,
"from":L[164]});
}
} catch($e14881489) {
if(R.isCont($e14881489)) {
var $ss14921493 = {"from":L[164],
"go":function(anf_arg241498) {
return $Hanf_arg2661499(anf_arg241498,anf_fun211485,types741487);
}};
$e14881489.stack[R.EXN_STACKHEIGHT++] = $ss14921493;
}
if(R.isPyretException($e14881489)) {
$e14881489.pyretStack.push(L[164]);
}
throw $e14881489;
}
var $ret14941495 = $Hanf_arg2661499($z14901491,anf_fun211485,types741487);
++R.GAS;
return $ret14941495;
};
var $Hanf_arg2661499 = function(anf_arg241498,anf_fun211485,types741487) {
var $z15021503 = D;
var $f15081509 = function(_) {
return R.isFunction(anf_fun211485)?anf_fun211485.app(anf_arg241498,types741487):R.ffi.throwNonFunApp(L[165],anf_fun211485,[anf_arg241498,types741487]);
};
try {
if(--R.GAS > 0) {
$z15021503 = $f15081509();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15081509,
"from":L[165]});
}
} catch($e15001501) {
if(R.isCont($e15001501)) {
var $ss15041505 = {"from":L[165],
"go":function(ann_DASH_check_DASH_temp201510) {
return $Hann_DASH_check_DASH_temp2651511(ann_DASH_check_DASH_temp201510);
}};
$e15001501.stack[R.EXN_STACKHEIGHT++] = $ss15041505;
}
if(R.isPyretException($e15001501)) {
$e15001501.pyretStack.push(L[165]);
}
throw $e15001501;
}
var $ret15061507 = $Hann_DASH_check_DASH_temp2651511($z15021503);
++R.GAS;
return $ret15061507;
};
var $Hann_DASH_check_DASH_temp2651511 = function(ann_DASH_check_DASH_temp201510) {
return ann_DASH_check_DASH_temp201510;
};
var $Hanf_arg2641512 = function(anf_arg101513,C17,anf_fun61514,anf_fun81515,env671516,negate681517) {
var $z15201521 = D;
var $f15261527 = function(_) {
return R.isFunction(anf_fun81515)?anf_fun81515.app(anf_arg101513):R.ffi.throwNonFunApp(L[166],anf_fun81515,[anf_arg101513]);
};
try {
if(--R.GAS > 0) {
$z15201521 = $f15261527();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15261527,
"from":L[166]});
}
} catch($e15181519) {
if(R.isCont($e15181519)) {
var $ss15221523 = {"from":L[166],
"go":function(anf_arg111528) {
return $Hanf_arg2631529(anf_arg111528,C17,anf_fun61514,env671516,negate681517);
}};
$e15181519.stack[R.EXN_STACKHEIGHT++] = $ss15221523;
}
if(R.isPyretException($e15181519)) {
$e15181519.pyretStack.push(L[166]);
}
throw $e15181519;
}
var $ret15241525 = $Hanf_arg2631529($z15201521,C17,anf_fun61514,env671516,negate681517);
++R.GAS;
return $ret15241525;
};
var $Hanf_arg2631529 = function(anf_arg111528,C17,anf_fun61514,env671516,negate681517) {
var anf_bracket121544 = G(env671516,"types",L[170]);
var anf_fun131542 = G(anf_bracket121544,"filter",L[169]);
var anf_arg141540 = G(C17,"is-type-module-bindings",L[168]);
var $z15321533 = D;
var $f15381539 = function(_) {
return R.isFunction(negate681517.$var)?negate681517.$var.app(anf_arg141540):R.ffi.throwNonFunApp(L[167],negate681517.$var,[anf_arg141540]);
};
try {
if(--R.GAS > 0) {
$z15321533 = $f15381539();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15381539,
"from":L[167]});
}
} catch($e15301531) {
if(R.isCont($e15301531)) {
var $ss15341535 = {"from":L[167],
"go":function(anf_arg151541) {
return $Hanf_arg2621543(anf_arg151541,anf_arg111528,anf_fun131542,anf_fun61514);
}};
$e15301531.stack[R.EXN_STACKHEIGHT++] = $ss15341535;
}
if(R.isPyretException($e15301531)) {
$e15301531.pyretStack.push(L[167]);
}
throw $e15301531;
}
var $ret15361537 = $Hanf_arg2621543($z15321533,anf_arg111528,anf_fun131542,anf_fun61514);
++R.GAS;
return $ret15361537;
};
var $Hanf_arg2621543 = function(anf_arg151541,anf_arg111528,anf_fun131542,anf_fun61514) {
var $z15471548 = D;
var $f15531554 = function(_) {
return R.isFunction(anf_fun131542)?anf_fun131542.app(anf_arg151541):R.ffi.throwNonFunApp(L[171],anf_fun131542,[anf_arg151541]);
};
try {
if(--R.GAS > 0) {
$z15471548 = $f15531554();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15531554,
"from":L[171]});
}
} catch($e15451546) {
if(R.isCont($e15451546)) {
var $ss15491550 = {"from":L[171],
"go":function(anf_arg161555) {
return $Hanf_arg2611556(anf_arg161555,anf_arg111528,anf_fun61514);
}};
$e15451546.stack[R.EXN_STACKHEIGHT++] = $ss15491550;
}
if(R.isPyretException($e15451546)) {
$e15451546.pyretStack.push(L[171]);
}
throw $e15451546;
}
var $ret15511552 = $Hanf_arg2611556($z15471548,anf_arg111528,anf_fun61514);
++R.GAS;
return $ret15511552;
};
var $Hanf_arg2611556 = function(anf_arg161555,anf_arg111528,anf_fun61514) {
var $z15591560 = D;
var $f15651566 = function(_) {
return R.isFunction(anf_fun61514)?anf_fun61514.app(anf_arg111528,anf_arg161555):R.ffi.throwNonFunApp(L[37],anf_fun61514,[anf_arg111528,anf_arg161555]);
};
try {
if(--R.GAS > 0) {
$z15591560 = $f15651566();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15651566,
"from":L[37]});
}
} catch($e15571558) {
if(R.isCont($e15571558)) {
var $ss15611562 = {"from":L[37],
"go":function(ann_DASH_check_DASH_temp11567) {
return $Hann_DASH_check_DASH_temp2601568(ann_DASH_check_DASH_temp11567);
}};
$e15571558.stack[R.EXN_STACKHEIGHT++] = $ss15611562;
}
if(R.isPyretException($e15571558)) {
$e15571558.pyretStack.push(L[37]);
}
throw $e15571558;
}
var $ret15631564 = $Hann_DASH_check_DASH_temp2601568($z15591560);
++R.GAS;
return $ret15631564;
};
var $Hann_DASH_check_DASH_temp2601568 = function(ann_DASH_check_DASH_temp11567) {
return ann_DASH_check_DASH_temp11567;
};
var $Hanf_arg2591569 = function(anf_arg41570,not4) {
var $z15731574 = D;
var $f15791580 = function(_) {
return R.isFunction(not4)?not4.app(anf_arg41570):R.ffi.throwNonFunApp(L[172],not4,[anf_arg41570]);
};
try {
if(--R.GAS > 0) {
$z15731574 = $f15791580();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15791580,
"from":L[172]});
}
} catch($e15711572) {
if(R.isCont($e15711572)) {
var $ss15751576 = {"from":L[172],
"go":function(ann_DASH_check_DASH_temp31581) {
return $Hann_DASH_check_DASH_temp2581582(ann_DASH_check_DASH_temp31581);
}};
$e15711572.stack[R.EXN_STACKHEIGHT++] = $ss15751576;
}
if(R.isPyretException($e15711572)) {
$e15711572.pyretStack.push(L[172]);
}
throw $e15711572;
}
var $ret15771578 = $Hann_DASH_check_DASH_temp2581582($z15731574);
++R.GAS;
return $ret15771578;
};
var $Hann_DASH_check_DASH_temp2581582 = function(ann_DASH_check_DASH_temp31581) {
return ann_DASH_check_DASH_temp31581;
};
return R.loadModulesNew(NAMESPACE,[$C1722,$A3823,$arrays5924,$lists71025,$option91126,$error111227,$sets131328],function($C1722,$A3823,$arrays5924,$lists71025,$option91126,$error111227,$sets131328) {
var C17 = R.getField($C1722,"values");
var A38 = R.getField($A3823,"values");
var arrays59 = R.getField($arrays5924,"values");
var lists710 = R.getField($lists71025,"values");
var option911 = R.getField($option91126,"values");
var error1112 = R.getField($error111227,"values");
var sets1313 = R.getField($sets131328,"values");
var C214 = R.getField($C1722,"types");
var A415 = R.getField($A3823,"types");
var arrays616 = R.getField($arrays5924,"types");
var lists817 = R.getField($lists71025,"types");
var option1018 = R.getField($option91126,"types");
var error1219 = R.getField($error111227,"types");
var sets1420 = R.getField($sets131328,"types");
return R.safeCall(function() {
var List151583 = R.getDotAnn(L[173],"lists",lists817,"List");
var Option161584 = R.getDotAnn(L[173],"option",option1018,"Option");
var Array171585 = R.getDotAnn(L[173],"arrays",arrays616,"Array");
var Set181586 = R.getDotAnn(L[173],"sets",sets1420,"Set");
var array191725 = G(arrays59,"array",L[173]);
var build_DASH_array201724 = G(arrays59,"build-array",L[173]);
var array_DASH_from_DASH_list211723 = G(arrays59,"array-from-list",L[173]);
var is_DASH_array221722 = G(arrays59,"is-array",L[173]);
var list2336 = G(lists710,"list",L[173]);
var is_DASH_empty241721 = G(lists710,"is-empty",L[173]);
var is_DASH_link251720 = G(lists710,"is-link",L[173]);
var empty261719 = G(lists710,"empty",L[173]);
var link2735 = G(lists710,"link",L[173]);
var range281718 = G(lists710,"range",L[173]);
var repeat291717 = G(lists710,"repeat",L[173]);
var filter301716 = G(lists710,"filter",L[173]);
var partition311715 = G(lists710,"partition",L[173]);
var split_DASH_at321714 = G(lists710,"split-at",L[173]);
var any331713 = G(lists710,"any",L[173]);
var find341712 = G(lists710,"find",L[173]);
var map3537 = G(lists710,"map",L[173]);
var map2361711 = G(lists710,"map2",L[173]);
var map3371710 = G(lists710,"map3",L[173]);
var map4381709 = G(lists710,"map4",L[173]);
var map_n391708 = G(lists710,"map_n",L[173]);
var map2_n401707 = G(lists710,"map2_n",L[173]);
var map3_n411706 = G(lists710,"map3_n",L[173]);
var map4_n421705 = G(lists710,"map4_n",L[173]);
var each431704 = G(lists710,"each",L[173]);
var each2441703 = G(lists710,"each2",L[173]);
var each3451702 = G(lists710,"each3",L[173]);
var each4461701 = G(lists710,"each4",L[173]);
var each_n471700 = G(lists710,"each_n",L[173]);
var each2_n481699 = G(lists710,"each2_n",L[173]);
var each3_n491698 = G(lists710,"each3_n",L[173]);
var each4_n501697 = G(lists710,"each4_n",L[173]);
var fold5134 = G(lists710,"fold",L[173]);
var fold2521696 = G(lists710,"fold2",L[173]);
var fold3531695 = G(lists710,"fold3",L[173]);
var fold4541694 = G(lists710,"fold4",L[173]);
var index551693 = G(lists710,"index",L[173]);
var Option561692 = G(option911,"Option",L[173]);
var is_DASH_none571691 = G(option911,"is-none",L[173]);
var is_DASH_some581690 = G(option911,"is-some",L[173]);
var none591689 = G(option911,"none",L[173]);
var some601688 = G(option911,"some",L[173]);
var set611687 = G(sets1313,"set",L[173]);
var tree_DASH_set621686 = G(sets1313,"tree-set",L[173]);
var list_DASH_set631685 = G(sets1313,"list-set",L[173]);
var drop_DASH_module_DASH_bindings6433 = {"$var":D,
"$name":"drop-module-bindings"};
var add_DASH_global_DASH_binding6531 = {"$var":D,
"$name":"add-global-binding"};
var add_DASH_global_DASH_type_DASH_binding6632 = {"$var":D,
"$name":"add-global-type-binding"};
var anf_assign171587 = R.makeFunction(function(env671516) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[37],1,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[197],"C",C214,"CompileEnvironment")],[env671516],[L[197]],function() {
var negate681517 = {"$var":D,
"$name":"negate"};
var anf_assign51659 = R.makeFunction(function(f691672) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[195],1,arguments);
}
var ann_DASH_check_DASH_temp21673 = R.makeFunction(function(x701674) {
if(arguments.length !== 1) {
throw R.ffi.throwArityErrorC(L[172],1,arguments);
}
var $z16771678 = D;
var $f16831684 = function(_) {
return R.isFunction(f691672)?f691672.app(x701674):R.ffi.throwNonFunApp(L[196],f691672,[x701674]);
};
try {
if(--R.GAS > 0) {
$z16771678 = $f16831684();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16831684,
"from":L[196]});
}
} catch($e16751676) {
if(R.isCont($e16751676)) {
var $ss16791680 = {"from":L[196],
"go":function(anf_arg41570) {
return $Hanf_arg2591569(anf_arg41570,not4);
}};
$e16751676.stack[R.EXN_STACKHEIGHT++] = $ss16791680;
}
if(R.isPyretException($e16751676)) {
$e16751676.pyretStack.push(L[196]);
}
throw $e16751676;
}
var $ret16811682 = $Hanf_arg2591569($z16771678,not4);
++R.GAS;
return $ret16811682;
});
return ann_DASH_check_DASH_temp21673;
});
negate681517.$var = anf_assign51659;
var anf_fun61514 = G(C17,"compile-env",L[194]);
var anf_bracket71671 = G(env671516,"bindings",L[193]);
var anf_fun81515 = G(anf_bracket71671,"filter",L[192]);
var anf_arg91670 = G(C17,"is-module-bindings",L[191]);
var $z16621663 = D;
var $f16681669 = function(_) {
return R.isFunction(negate681517.$var)?negate681517.$var.app(anf_arg91670):R.ffi.throwNonFunApp(L[190],negate681517.$var,[anf_arg91670]);
};
try {
if(--R.GAS > 0) {
$z16621663 = $f16681669();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16681669,
"from":L[190]});
}
} catch($e16601661) {
if(R.isCont($e16601661)) {
var $ss16641665 = {"from":L[190],
"go":function(anf_arg101513) {
return $Hanf_arg2641512(anf_arg101513,C17,anf_fun61514,anf_fun81515,env671516,negate681517);
}};
$e16601661.stack[R.EXN_STACKHEIGHT++] = $ss16641665;
}
if(R.isPyretException($e16601661)) {
$e16601661.pyretStack.push(L[190]);
}
throw $e16601661;
}
var $ret16661667 = $Hanf_arg2641512($z16621663,C17,anf_fun61514,anf_fun81515,env671516,negate681517);
++R.GAS;
return $ret16661667;
});
});
drop_DASH_module_DASH_bindings6433.$var = anf_assign171587;
var anf_assign291588 = R.makeFunction(function(env711630,name721631) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[183],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[188],"C",C214,"CompileEnvironment"),$type$String6],[env711630,name721631],[L[188],L[189]],function() {
var cases_DASH_val11658 = env711630;
var anf_fun191642 = G(cases_DASH_val11658,"_match",L[184]);
var anf_obj251646 = R.makeFunction(function(bindings731486,types741487) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[165],2,arguments);
}
var anf_fun211485 = G(C17,"compile-env",L[187]);
var anf_fun221657 = G(C17,"builtin-id",L[186]);
var $z16491650 = D;
var $f16551656 = function(_) {
return R.isFunction(anf_fun221657)?anf_fun221657.app(name721631):R.ffi.throwNonFunApp(L[185],anf_fun221657,[name721631]);
};
try {
if(--R.GAS > 0) {
$z16491650 = $f16551656();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16551656,
"from":L[185]});
}
} catch($e16471648) {
if(R.isCont($e16471648)) {
var $ss16511652 = {"from":L[185],
"go":function(anf_arg231484) {
return $Hanf_arg2671483(anf_arg231484,anf_fun211485,bindings731486,link2735,types741487);
}};
$e16471648.stack[R.EXN_STACKHEIGHT++] = $ss16511652;
}
if(R.isPyretException($e16471648)) {
$e16471648.pyretStack.push(L[185]);
}
throw $e16471648;
}
var $ret16531654 = $Hanf_arg2671483($z16491650,anf_fun211485,bindings731486,link2735,types741487);
++R.GAS;
return $ret16531654;
});
var anf_arg261643 = R.makeObject({"compile-env":anf_obj251646});
var anf_arg281644 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[184],0,arguments);
}
var ann_DASH_check_DASH_temp271645 = R.throwNoBranchesMatched(L[184],("cases"));
return ann_DASH_check_DASH_temp271645;
});
var $z16341635 = D;
var $f16401641 = function(_) {
return R.isFunction(anf_fun191642)?anf_fun191642.app(anf_arg261643,anf_arg281644):R.ffi.throwNonFunApp(L[183],anf_fun191642,[anf_arg261643,anf_arg281644]);
};
try {
if(--R.GAS > 0) {
$z16341635 = $f16401641();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16401641,
"from":L[183]});
}
} catch($e16321633) {
if(R.isCont($e16321633)) {
var $ss16361637 = {"from":L[183],
"go":function(ann_DASH_check_DASH_temp181482) {
return $Hann_DASH_check_DASH_temp2681481(ann_DASH_check_DASH_temp181482);
}};
$e16321633.stack[R.EXN_STACKHEIGHT++] = $ss16361637;
}
if(R.isPyretException($e16321633)) {
$e16321633.pyretStack.push(L[183]);
}
throw $e16321633;
}
var $ret16381639 = $Hann_DASH_check_DASH_temp2681481($z16341635);
++R.GAS;
return $ret16381639;
});
});
add_DASH_global_DASH_binding6531.$var = anf_assign291588;
var anf_assign411589 = R.makeFunction(function(env751601,name761602) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[176],2,arguments);
}
return R.checkAnnArgs([R.getDotAnn(L[181],"C",C214,"CompileEnvironment"),$type$String6],[env751601,name761602],[L[181],L[182]],function() {
var cases_DASH_val21629 = env751601;
var anf_fun311613 = G(cases_DASH_val21629,"_match",L[177]);
var anf_obj371617 = R.makeFunction(function(bindings771455,types781456) {
if(arguments.length !== 2) {
throw R.ffi.throwArityErrorC(L[163],2,arguments);
}
var anf_fun331454 = G(C17,"compile-env",L[180]);
var anf_fun341628 = G(C17,"type-id",L[179]);
var $z16201621 = D;
var $f16261627 = function(_) {
return R.isFunction(anf_fun341628)?anf_fun341628.app(name761602):R.ffi.throwNonFunApp(L[178],anf_fun341628,[name761602]);
};
try {
if(--R.GAS > 0) {
$z16201621 = $f16261627();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16261627,
"from":L[178]});
}
} catch($e16181619) {
if(R.isCont($e16181619)) {
var $ss16221623 = {"from":L[178],
"go":function(anf_arg351453) {
return $Hanf_arg2711452(anf_arg351453,anf_fun331454,bindings771455,link2735,types781456);
}};
$e16181619.stack[R.EXN_STACKHEIGHT++] = $ss16221623;
}
if(R.isPyretException($e16181619)) {
$e16181619.pyretStack.push(L[178]);
}
throw $e16181619;
}
var $ret16241625 = $Hanf_arg2711452($z16201621,anf_fun331454,bindings771455,link2735,types781456);
++R.GAS;
return $ret16241625;
});
var anf_arg381614 = R.makeObject({"compile-env":anf_obj371617});
var anf_arg401615 = R.makeFunction(function() {
if(arguments.length !== 0) {
throw R.ffi.throwArityErrorC(L[177],0,arguments);
}
var ann_DASH_check_DASH_temp391616 = R.throwNoBranchesMatched(L[177],("cases"));
return ann_DASH_check_DASH_temp391616;
});
var $z16051606 = D;
var $f16111612 = function(_) {
return R.isFunction(anf_fun311613)?anf_fun311613.app(anf_arg381614,anf_arg401615):R.ffi.throwNonFunApp(L[176],anf_fun311613,[anf_arg381614,anf_arg401615]);
};
try {
if(--R.GAS > 0) {
$z16051606 = $f16111612();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f16111612,
"from":L[176]});
}
} catch($e16031604) {
if(R.isCont($e16031604)) {
var $ss16071608 = {"from":L[176],
"go":function(ann_DASH_check_DASH_temp301451) {
return $Hann_DASH_check_DASH_temp2721450(ann_DASH_check_DASH_temp301451);
}};
$e16031604.stack[R.EXN_STACKHEIGHT++] = $ss16071608;
}
if(R.isPyretException($e16031604)) {
$e16031604.pyretStack.push(L[176]);
}
throw $e16031604;
}
var $ret16091610 = $Hann_DASH_check_DASH_temp2721450($z16051606);
++R.GAS;
return $ret16091610;
});
});
add_DASH_global_DASH_type_DASH_binding6632.$var = anf_assign411589;
var anf_fun421600 = G(list2336,"make",L[175]);
var $z15921593 = D;
var $f15981599 = function(_) {
return R.isFunction(anf_fun421600)?anf_fun421600.app([("exec")]):R.ffi.throwNonFunApp(L[174],anf_fun421600,[[("exec")]]);
};
try {
if(--R.GAS > 0) {
$z15921593 = $f15981599();
} else {
R.EXN_STACKHEIGHT = 0;
throw R.makeCont({"go":$f15981599,
"from":L[174]});
}
} catch($e15901591) {
if(R.isCont($e15901591)) {
var $ss15941595 = {"from":L[174],
"go":function(bad_DASH_imports7930) {
return $Hbad_DASH_imports37629(bad_DASH_imports7930,A38,A415,C17,C214,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,drop_DASH_module_DASH_bindings6433,fold5134,link2735,list2336,map3537,_plus2,builtins3,not4,nothing5);
}};
$e15901591.stack[R.EXN_STACKHEIGHT++] = $ss15941595;
}
if(R.isPyretException($e15901591)) {
$e15901591.pyretStack.push(L[174]);
}
throw $e15901591;
}
var $ret15961597 = $Hbad_DASH_imports37629($z15921593,A38,A415,C17,C214,add_DASH_global_DASH_binding6531,add_DASH_global_DASH_type_DASH_binding6632,drop_DASH_module_DASH_bindings6433,fold5134,link2735,list2336,map3537,_plus2,builtins3,not4,nothing5);
++R.GAS;
return $ret15961597;
},function(moduleVal) {
R.modules["$src/arr/compiler/repl-support.arr21"] = moduleVal
return moduleVal;
});
});
}
};
});
define('js/repl-lib',["q", "js/eval-lib", "compiler/repl-support.arr"], function(Q, eval, rs) {

  var defer = function(f) { setTimeout(f, 0); }
  function createRepl(runtime, namespace, initialCompileEnv, options) {
    var dialect = options.dialect || "Pyret";
    var mainName = options.name || "repl-main";
    return runtime.loadModules(namespace, [rs], function(replSupport) {
      var toRun = [];
      var somethingRunning = false;
      function get(obj, fld) { return runtime.getField(obj, fld); }
      var mainCompileEnv = initialCompileEnv;
      var initialReplCompileEnv = get(replSupport, "drop-module-bindings").app(mainCompileEnv);
      var replCompileEnv = initialReplCompileEnv;
      
      function evaluate(toEval) {
        if (toEval.beforeRun) { toEval.beforeRun(); }
        var envToUse = toEval.isMain ? mainCompileEnv : replCompileEnv;
        eval.evalParsedPyret(runtime, toEval.ast, { sync: false, name: toEval.name, namespace: namespace, compileEnv: envToUse }, 
          function(result) {
            if(runtime.isSuccessResult(result)) {
              var provided = get(get(result.result, "provide-plus-types"), "values");
              runtime.getFields(provided).forEach(function(f) {
                  namespace = namespace.set(f, get(provided, f));
                  replCompileEnv = get(replSupport, "add-global-binding").app(replCompileEnv, runtime.makeString(f));
                });
              var providedTypes = get(get(result.result, "provide-plus-types"), "types");
              Object.keys(providedTypes).forEach(function(f) {
                namespace = namespace.set("$type$" + f, providedTypes[f]);
                replCompileEnv = get(replSupport, "add-global-type-binding").app(replCompileEnv, runtime.makeString(f));
              });
            }
            toEval.onRun(result);
          });
      }
      function makeEvaluator(toEval) {
        return function() { evaluate(toEval); };
      }
      function runIfFree() {
        if (!somethingRunning && toRun.length > 0) {
          var thisRun = toRun.pop();
          somethingRunning = true;
          defer(makeEvaluator(thisRun));
        }
      }
      function makeResumer(deferred) {
        return function(result) {
          somethingRunning = false;
          runIfFree();
          return deferred.resolve(result);
        };
      }
      function restartInteractions(code) {
        var deferred = Q.defer();
        toRun = [];
        eval.parsePyret(runtime, code, { name: mainName, dialect: dialect }, function(astResult) {
          if(runtime.isSuccessResult(astResult)) {
            runtime.runThunk(function() {
              return get(replSupport, "make-provide-for-repl-main").app(astResult.result, initialCompileEnv);
            },
            function(result) {
              if(!runtime.isSuccessResult(result)) { throw "Bad result in repl-lib"; }
              else {
                toRun.unshift({
                    isMain: true,
                    ast:  result.result,
                    beforeRun: function() {
                      replCompileEnv = initialReplCompileEnv;
                    },
                    name: mainName,
                    onRun: makeResumer(deferred)
                  });
              }
            });
          } else {
            deferred.resolve(astResult);
          }
          runIfFree();
        });
        return deferred.promise;
      }
      function run(code, name) {
        var deferred = Q.defer();
        if (typeof name === "undefined") { name = "interactions "; }
        eval.parsePyret(runtime, code, { name: name, dialect: dialect }, function(astResult) {
          if(runtime.isSuccessResult(astResult)) {
            runtime.runThunk(function() {
              return get(replSupport, "make-provide-for-repl").app(astResult.result);
            },
            function(result) {
              if(!runtime.isSuccessResult(result)) { throw "Bad result in repl-lib"; }
              toRun.unshift({
                  isMain: false,
                  ast: result.result,
                  name: name,
                  onRun: makeResumer(deferred)
                });
             });
          } else {
            deferred.resolve(astResult);
          }
          runIfFree();
        });
        return deferred.promise;
      }
      function pause(afterPause) {
        runtime.schedulePause(function(resumer) {
          afterPause(resumer);
        });
      }
      function stop() {
        runtime.breakAll();
        toRun = [];
        somethingRunning = false;
      }
      return {
        restartInteractions: restartInteractions,
        run: run,
        pause: pause,
        stop: stop,
        runtime: runtime
      }
    });
  }

  return {
    create: createRepl
  }

});

